#!/usr/bin/python 
# -*- coding: utf-8 -*-
#---------------------------------------------------------------------
# Name:        tashkeel 
# Purpose:     Arabic automatic vocalization. # 
# Author:      Taha Zerrouki (taha.zerrouki[at]gmail.com) 
# Created:     2015-03-25
#  Copyright:   (c) Taha Zerrouki 2011 # Licence:     GPL 
#---------------------------------------------------------------------
"""
    Arabic Tashkeel Class of unknown words, based on wordlist
"""

Table={
u"داعش":u"دَاعِش",
u"البنتاجون":u"الْبِنْتَاجُون",
u"السيسي":u"السِّيسِي",
u'ءأعجمي': u'ءأعجمي', #1
u'ءأقررتم': u'ءَأَقْرَرْتُمْ', #1
u'ءالآن': u'ءَالآنَ', #1
u'ءالذكرين': u'ءَالذَّكَرَيْنِ', #2
u'ءالله': u'ءَاللَّهُ', #2
u'ءأنتم': u'ءَأَنْتُمْ', #4
u'ا': u'اُ', #1
u'ا': u'ا', #141113
u'ا': u'اَ', #15
u'ا': u'اِ', #38
u'ا': u'َا', #4
u'اء': u'اءُ', #1
u'أءشفقتم': u'أَءَشْفَقْتُمْ', #1
u'أءنتم': u'أَءَنْتُمْ', #3
u'أءنذرتهم': u'أَءَنْذَرْتَهُمْ', #2
u'أءوب': u'أَءُوب', #1
u'أءوب': u'أَءُوبَ', #1
u'-اا': u'-اا', #1
u'آآ': u'آآ', #4
u'آآآ': u'آآآ', #1
u'ااا': u'ااا', #3
u'اااا': u'اااا', #13
u'أأتسوك': u'أَأَتَسَوَّكُ', #1
u'أاتي': u'أَاتِي', #1
u'أاتيهم': u'أَاتِيَهُمْ', #1
u'أأجمرتنا': u'أَأَجْمَرْتنَا', #1
u'أإذا': u'أَإِذَا', #1
u'أأصع': u'أَأْصُعَ', #1
u'أأعرابى': u'أَأَعْرَابِىٌّ', #1
u'أأل': u'أَأْلٌ', #2
u'أألخير': u'أَأَلْخَيْرُ', #5
u'أالله': u'أَاللَّهِ', #14
u'آالله': u'آاللَّهُ', #2
u'االله': u'االله', #2
u'أألهة': u'أَأْلِهَةٌ', #1
u'اأمره': u'اُأْمُرْهُ', #1
u'أأممة': u'أَأْمِمَةٍ', #1
u'أإنا': u'أَإِنَّا', #1
u'آأنت': u'آأَنْتَ', #3
u'أأهكنا': u'أَأَهّكْنَا', #1
u'اب': u'اب', #1
u'ابا': u'ابا', #3
u'اباءهم': u'اباءهم', #1
u'إبابة': u'إبَابَةً', #1
u'أباة': u'أُبَاةُ', #1
u'أباجاد': u'أباجاد', #1
u'أباجاد': u'أَبَاجَادَ', #3
u'اباحة': u'اباحة', #1
u'إباحه': u'إباحه', #2
u'إباد': u'إبَادٍ', #1
u'أبآر': u'أَبَآَّرً', #1
u'إبار': u'إبَارٌ', #1
u'إبار': u'إبَارِ', #1
u'إبار': u'إبَارٍ', #2
u'إبار': u'إبَارُ', #3
u'إبار': u'إبَارَ', #4
u'إبارتنا': u'إبَارَتُنَا', #2
u'إبارتهم': u'إبَارَتِهِمْ', #1
u'إباره': u'إبَارِهِ', #1
u'إباره': u'إبَارُهُ', #2
u'إباره': u'إبَارَهُ', #5
u'إبارها': u'إبَارُهَا', #2
u'إبارها': u'إبَارِهَا', #7
u'إبارهم': u'إبَارُهُمْ', #1
u'ابازدا': u'ابازدا', #1
u'إباض،': u'إِبَاضٍ،', #1
u'آباق': u'آباقِ', #1
u'إباق': u'إبَاقُ', #10
u'إباق': u'إبَاقٌ', #16
u'إباق': u'إبَاقَ', #19
u'إباق': u'إبَاقٍ', #24
u'إباق': u'إبَاقِ', #46
u'أباقا': u'أُبَّاقًا', #1
u'إباقا': u'إبَاقًا', #27
u'إباقته': u'إبَاقَتِهِ', #2
u'إباقك': u'إِبَاقُكَ', #1
u'إباقه': u'إِبَاقُهُ', #1
u'إباقه': u'إِبَاقِهِ', #1
u'إباقه': u'إبَاقِهِ', #142
u'إباقه': u'إبَاقُهُ', #20
u'إباقه': u'إبَاقَهُ', #55
u'إباقها': u'إبَاقُهَا', #2
u'إباقها': u'إبَاقِهَا', #9
u'ابال': u'ابال', #1
u'إباله': u'إبّالُهُ', #1
u'أبانان': u'أَبَانَانِ', #1
u'أباهلكم': u'أُبَاهِلْكُمْ', #1
u'آبآؤكم': u'آبَآؤُكُمْ', #1
u'أباوهب': u'أباوهب', #1
u'آبائى': u'آبَائِى', #2
u'إباية': u'إبَايَةٌ', #1
u'إباية': u'إبَايَةَ', #1
u'إباية': u'إبَايَةُ', #1
u'إباية': u'إبَايَةِ', #6
u'أبايت': u'أُبَايِت', #1
u'إبايته': u'إِبَايَتُهُ', #1
u'إبايته': u'إبَايَتُهُ', #3
u'إبايته': u'إبَايَتِهِ', #7
u'إبايتها': u'إبَايَتِهَا', #1
u'إبايتهم': u'إبَايَتُهُمْ', #1
u'إبايتهم': u'إبَايَتِهِمْ', #1
u'إبايتهما': u'إبَايَتِهِمَا', #1
u'اباين': u'اباين', #1
u'أبة،': u'أَبَةِ،', #1
u'أبة': u'أبة', #2
u'أبة': u'أَبَةِ', #6
u'ابتأر': u'ابتأر', #1
u'ابتأر': u'ابْتَأَرَ', #2
u'ابتاعى': u'ابْتَاعِى', #5
u'إبتال': u'إِبْتَالِ', #1
u'ابتدءوا،': u'ابْتَدَءُوا،', #1
u'ابتدءوا': u'ابْتَدَءُوا', #31
u'ابتدءوه': u'ابْتَدَءُوهُ', #1
u'ابتدا': u'ابْتِدَا', #7
u'أبتدأت': u'أَبْتَدَأَتْ', #1
u'ابتدار': u'ابْتِدَارَ', #2
u'ابتدارا': u'ابْتِدَارًا', #2
u'ابتدارهم': u'ابْتِدَارِهِمْ', #1
u'ابتداك': u'ابْتَدَاك', #1
u'ابتدالا': u'ابْتِدَالَا', #1
u'ابتداه': u'ابْتَدَاهُ', #1
u'ابتدر': u'ابْتَدَرْ', #1
u'ابتدر': u'ابْتَدَرَ', #8
u'ابتدراه': u'ابْتَدَرَاهُ', #1
u'ابتدرت': u'ابْتَدَرْت', #1
u'ابتدرته': u'ابْتَدَرَتْهُ', #8
u'ابتدرن': u'ابْتَدَرْنَ', #3
u'ابتدرنا': u'ابْتَدَرْنَا', #1
u'ابتدرها': u'اِبْتَدَرَهَا', #1
u'ابتدرها': u'ابْتَدَرَهَا', #7
u'ابتدروا': u'ابتدروا', #1
u'ابتدروا': u'ابْتَدَرُوا', #18
u'ابتدروه،': u'ابتدروه،', #1
u'ابتدروه': u'ابْتَدَرُوهُ', #6
u'ابتدروها': u'ابْتَدِرُوهَا', #1
u'ابتدروها': u'ابْتَدَرُوهَا', #4
u'إبتدع': u'إبْتَدِعْ', #1
u'ابتدل': u'ابْتَدَلَ', #1
u'ابتدوا،': u'ابْتَدُوا،', #1
u'ابتدي': u'اُبْتُدِيَ', #2
u'ابتدى': u'ابْتَدَى', #2
u'أبتدي': u'أَبْتَدِي', #7
u'ابتسرت': u'ابْتَسَرْتُ', #1
u'ابتسط': u'ابْتَسَطَ', #1
u'ابتسطوها': u'ابْتَسِطُوهَا', #1
u'أبتسليمة': u'أَبِتَسْلِيمَةٍ', #3
u'آبتعتها؟': u'آبْتَعْتَهَا؟', #1
u'ابتعثنى': u'ابْتَعَثَنِى', #1
u'ابتعلت': u'ابْتَعَلَتْ', #1
u'إبتغاء': u'إبْتِغَاءِ', #1
u'ابتلانى': u'ابْتَلاَنِى', #1
u'ابتلانيا': u'ابْتَلَانِيَا', #1
u'ابتلعتيها': u'ابْتَلَعْتِيهَا', #1
u'ابتليتنى': u'ابْتَلَيْتَنِى', #2
u'ابتهارا': u'ابْتِهَارًا', #1
u'أبتهر': u'أبتهر', #1
u'أبتهر': u'أَبْتَهِرْ', #1
u'ابتهر': u'ابْتَهَرَ', #6
u'ابتهروا': u'ابْتَهَرُوا', #1
u'أبج': u'أبج', #1
u'ابجر': u'ابجر', #5
u'أبحتكه': u'أَبَحْتُكَهُ', #4
u'ابحل': u'ابحل', #2
u'أبحناكها': u'أَبَحْنَاكَهَا', #1
u'أبخع': u'أبخع', #1
u'أبخلناكم': u'أَبْخَلْنَاكُمْ', #1
u'ابدءوا': u'ابْدَءُوا', #65
u'أبداSاستشهاد': u'أَبَدًاSاسْتِشْهَادُ', #1
u'ابدا': u'ابدا', #3
u'إبدار': u'إبْدَارِ', #2
u'إبداره': u'إبْدَارِهِ', #1
u'أبدان': u'أَبَدَانً', #2
u'ابدراتم': u'ابدراتم', #3
u'أبدلنى': u'أَبْدِلْنِى', #1
u'أبدوحى': u'أبدوحى', #1
u'ابدئى': u'ابْدَئِى', #2
u'أبذ': u'أَبَذَّ', #1
u'إبذال': u'إبْذَالِ', #1
u'ابذعروا': u'ابذعَرّوا', #1
u'ابذعروا': u'ابْذَعَرّوا', #2
u'ابذقر': u'ابْذَقَرَّ', #2
u'أبرءوا': u'أَبَرَءُوا', #1
u'أبرءوا': u'أَبْرَءُوا', #18
u'ابرءوا': u'ابْرَءُوا', #4
u'أبرءوه': u'أَبَرَءُوهُ', #2
u'أبرءوه': u'أَبْرَءُوهُ', #9
u'أبرءوهم': u'أَبْرَءُوهُمْ', #1
u'إبراءة': u'إبْرَاءَةِ', #1
u'أبرأتيني': u'أبرأتيني', #1
u'أبرأتيني': u'أَبْرَأْتِينِي', #9
u'إبراد': u'إبْرَادٌ', #1
u'إبراد': u'إبْرَادَ', #3
u'إبراد': u'إبْرَادٍ', #4
u'إبراده': u'إبْرَادُهُ', #1
u'إبراده': u'إبْرَادِهِ', #2
u'إبرادها': u'إِبْرَادِهَا', #1
u'ابراسوما': u'ابْرَاسُومَا', #1
u'أبراشا': u'أَبْرَاشًا', #1
u'إبراك': u'إبْرَاكُ', #1
u'إبراكه': u'إبْرَاكِهِ', #1
u'إبراهام': u'إبْرَاهَامُ', #1
u'إبراهم': u'إِبْرَاهِمْ', #1
u'أبراهيم': u'أبراهيم', #1
u'ابراهيم،': u'ابْرَاهِيمَ،', #1
u'ابراهيم،': u'ابراهيم،', #3
u'ابراهيم': u'ابراهيم', #6
u'إبراهيمأنه': u'إِبْرَاهِيمَأَنَّهُ', #1
u'إبراهيمعن': u'إِبْرَاهِيمَعَنْ', #1
u'إبراهيمقال': u'إِبْرَاهِيمقَالَ', #1
u'إبراهيموالوجه': u'إِبْرَاهِيمُوَالْوَجْهُ', #1
u'إبردة': u'إبْرِدَةٌ', #1
u'إبردة': u'إبْرِدَةٍ', #1
u'إبردة': u'إِبْرِدَةٍ', #1
u'أبردونى': u'أَبْرَدُونِى', #1
u'ابرسرزني': u'ابرسرزني', #1
u'أبرشهر،': u'أبْرَشَهْر،', #1
u'آبره': u'آبُرُهُ', #2
u'إبرهيم': u'إِبْرَهِيمُ', #1
u'إبرهيم': u'إِبْرَهِيمَ', #17
u'إبرهيم،': u'إِبْرَهِيمَ،', #5
u'إبرهيموالوجه': u'إِبْرَهِيمَوَالْوَجْهُ', #1
u'أبرؤا': u'أَبَرُؤَا', #1
u'أبرويز': u'أَبَرْوَيْزُ', #1
u'إبرويز': u'إبْرُوِيزُ', #1
u'أبرويز': u'أَبْرِوِيزُ', #2
u'أبرويز': u'أَبْرَوَيْزَ', #3
u'أبرويز': u'أبرويز', #9
u'إبرويس': u'إبرويس', #1
u'آبرى': u'آبَرَى', #1
u'أبرىء': u'أبرىء', #1
u'آبرية': u'آبُرِيَّةٌ', #1
u'إبريسم': u'إبْرَيْسَمِ', #1
u'إبريسم': u'إِبْرَيْسَمٍ', #1
u'إبريسم': u'إبْرَيْسَمٌ', #22
u'إبريسم': u'إبْرَيْسَمَ', #24
u'إبريسم': u'إبْرَيْسَمٍ', #37
u'إبريسم': u'إبْرَيْسَمُ', #4
u'إبريسم': u'إبْرَيْسِمَ', #6
u'إبريسما': u'إبْرِيسَمًا', #1
u'إبريسما': u'إبْرَيْسَمًا', #29
u'إبريسمي': u'إبْرِيسَمِي', #1
u'ابزني': u'اُبْزُنِي', #1
u'أبزى،': u'أبْزى،', #1
u'أبزى': u'أَبْزَى', #129
u'أبزى': u'أبزى', #3
u'أبزى؟': u'أَبْزَى؟', #3
u'أبزى،': u'أَبْزَى،', #32
u'أبزى،': u'أبزى،', #7
u'أبزىكان': u'أَبْزَىكَانَ', #1
u'إبساس': u'إبْسَاسِ', #3
u'آبستن': u'آبستن', #1
u'ابستن': u'ابستن', #1
u'أبشاركم': u'أَبْشَارَكُمْ', #3
u'أبشارهم،': u'أَبْشَارُهُمْ،', #1
u'أبشارهم': u'أَبْشَارُهُمْ', #2
u'أبشرتنى': u'أَبَشَّرْتَنِى', #1
u'أبشما': u'أَبَشِمًا', #1
u'أبصرنى': u'أَبْصَرَنِى', #1
u'إبضاع': u'إبْضَاعٍ', #1
u'إبضاع': u'إبْضَاعُ', #1
u'إبضاع': u'إبْضَاعِ', #1
u'أبضاع': u'أَبْضَاعٌ', #2
u'أبضاع': u'أَبْضَاعِ', #3
u'إبضاع': u'إبْضَاعٌ', #38
u'أبضاعا': u'أَبْضَاعًا', #1
u'إبضاعا': u'إبْضَاعًا', #9
u'إبضاعه': u'إبْضَاعَهُ', #1
u'إبضاعه': u'إبْضَاعُهُ', #2
u'أبضاعهن': u'أَبْضَاعهنَّ', #1
u'أبضاعهن؟': u'أَبْضَاعِهِنَّ؟', #1
u'أبضاعهن': u'أَبْضَاعِهِنَّ', #8
u'أبضعتكه': u'أَبْضَعْتُكَهُ', #2
u'أبطأوا': u'أَبْطَأُوا', #1
u'ابطها': u'ابطها', #1
u'إبطى': u'إِبْطَىْ', #1
u'إبعاض': u'إبْعَاضِ', #1
u'إبعاضه': u'إبْعَاضِهِ', #4
u'إبعاضها': u'إبْعَاضِهَا', #1
u'أبعتنيه': u'أَبِعْتَنِيهِ', #1
u'ابعد': u'اُبْعُدْ', #1
u'ابعد': u'ابْعَدْ', #3
u'ابعدي': u'ابْعِدِي', #1
u'ابعدي': u'ابْعَدِي', #2
u'ابعدي': u'اُبْعُدِي', #5
u'أبغضنى': u'أَبْغَضَنِى', #1
u'ابغنى': u'ابْغِنِى', #1
u'ابغنيه،': u'ابْغِنِيهِ،', #1
u'ابغونى': u'ابْغُونِى', #2
u'آبق': u'آبِقِ', #1
u'آبق': u'آبِقَ', #10
u'آبق': u'آبِقٌ', #146
u'آبق': u'آبِقٍ', #271
u'آبق': u'آبِق', #4
u'آبقا': u'آبِقَا', #2
u'آبقا': u'آبِقًا', #252
u'إبقالها': u'إبْقَالَهَا', #1
u'إبقالها': u'إبْقَالُهَا', #1
u'آبقة': u'آبِقَةٍ', #1
u'آبقة': u'آبِقَةً', #10
u'آبقة': u'آبِقَةُ', #3
u'آبقة': u'آبِقَةَ', #4
u'آبقة': u'آبِقَةٌ', #9
u'آبقنا': u'آبِقُنَا', #1
u'آبقه': u'آبِقَهُ', #1
u'آبقه': u'آبِقِهِ', #4
u'آبقها': u'آبِقهَا', #1
u'آبقها': u'آبِقَهَا', #1
u'آبقها': u'آبِقِهَا', #1
u'آبقهم': u'آبِقُهُمْ', #2
u'آبقي': u'آبَقِيَ', #1
u'آبقي': u'آبِقِيٌّ', #1
u'آبقي': u'آبِقِي', #22
u'أبقيتنى': u'أَبْقَيْتَنِى', #1
u'آبقين': u'آبِقَيْنِ', #6
u'أبلانى': u'أَبْلاَنِى', #2
u'أبلس': u'أَبْلَسَ', #1
u'أبلس': u'أُبْلِسَ', #3
u'أبلسه': u'أَبْلَسَهُ', #3
u'أبلسوا': u'أُبْلِسُوا', #1
u'أبلغكموه': u'أُبلِّغكموه', #1
u'أبلغكموه': u'أُبَلّغَكُمُوهُ', #1
u'أبلغكموه': u'أُبْلِغَكُمُوهُ', #1
u'أبلغيته': u'أَبْلَغِيَّتَهُ', #1
u'أبلغيته': u'أَبْلَغِيَّتُهُ', #1
u'أبلغيتها': u'أَبْلَغِيَّتَهَا', #1
u'أبلغيتها': u'أَبْلَغِيَّتُهَا', #1
u'أبلغيتها': u'أَبْلَغِيَّتِهَا', #2
u'أبلوجة': u'أُبْلُوجَةٌ', #1
u'إبلى': u'إِبِلِى', #3
u'إبليسقوله': u'إِبْلِيسُقَوْلُهُ', #1
u'ابن': u'ابْنًَ', #1
u'إبنا،': u'إبناً،', #1
u'ابناء': u'ابناء', #2
u'ابنالماجشون': u'ابْنِالْمَاجِشُونِ', #1
u'ابنالماجشون': u'ابْنُالْمَاجِشُونِ', #5
u'ابنت': u'ابْنَتٍ', #1
u'ابنت': u'ابْنَتَ', #1
u'ابنت': u'ابْنَتُ', #1
u'ابنتا': u'ابْنَتًا', #4
u'ابنتى': u'ابْنَتَىَّ', #1
u'ابنتى': u'ابْنَتَىْ', #1
u'ابنتى': u'ابْنَتِى', #19
u'ابنتى': u'ابْنَتِىْ', #2
u'ابنسحنون': u'ابْنُسَحْنُونٍ', #2
u'ابنسيرين': u'ابْنُسِيرِينَ', #1
u'ابنم': u'ابْنُمِ', #1
u'ابنى': u'ابْنىَّ', #1
u'ابنى': u'ابْنِىْ', #2
u'ابنى؟': u'ابْنِى؟', #3
u'ابنى': u'ابنى', #4
u'ابنى': u'ابْنَىْ', #47
u'ابنى': u'ابْنَىِ', #6
u'ابنى': u'ابْنِى', #83
u'ابهار': u'ابهار', #2
u'ابهار': u'ابْهَارَّ', #6
u'ابهرار': u'ابْهِرَارِ', #1
u'أبهرى': u'أَبْهَرِى', #2
u'ابهزا': u'ابْهَزَا', #1
u'أبهق': u'أَبْهَقَ', #2
u'ابو': u'ابو', #3
u'أبوالأحوص،': u'أَبُوالأَحْوَصِ،', #1
u'أبوالحجاج': u'أَبُوالْحَجَّاجِ', #1
u'أبوالحسن': u'أَبُوالْحَسَنِ', #1
u'أبوالدرداء': u'أَبُوالدَّرْدَاءِ', #2
u'أبوالدرداء،أن': u'أَبُوالدَّرْدَاءِ،أَنَّ', #1
u'أبوالربيع': u'أَبُوالرَّبِيعِ', #1
u'أبوالطاهر': u'أَبُوالطَّاهِرٍ', #1
u'أبوالعالية': u'أَبُوالْعَالِيَةِ', #1
u'أبوالفضل': u'أبوالفضل', #1
u'أبوالقاسم': u'أَبُوالْقَاسِمِ', #1
u'أبوالمليح،': u'أبوالْمَلِيحِ،', #1
u'أبوأمية': u'أَبُوأُمَيَّةَ', #1
u'ابواها': u'ابواها', #1
u'أبواى': u'أَبَوَاىَ', #2
u'أبوأيوب': u'أَبُوأَيُّوبَ', #1
u'أبوبة': u'أَبْوِبَةٍ', #2
u'أبوبشر،': u'أَبوبِشْرٍ،', #1
u'أبوبكر': u'أَبُوبَكْرٍ', #1
u'أبوخيثمة،': u'أَبُوخَيْثَمَةَ،', #1
u'أبوسلمة،': u'أَبُوسلمة،', #1
u'أبوسهل،': u'أَبُوسَهْلٍ،', #1
u'أبوعاصم،': u'أَبُوعَاصِمٍ،', #1
u'أبوعبد': u'أَبُوعَبْدِ', #1
u'أبوعبيد': u'أَبُوعُبَيْدِ', #1
u'أبوعتبة': u'أَبُوعُتْبَةَ', #1
u'أبوعثمان': u'أَبُوعُثْمَانَ', #2
u'أبوعوانة': u'أَبُوعَوَانَةَ', #1
u'أبوعوانة،': u'أَبُوعَوَانَةَ،', #1
u'أبوغسان،': u'أَبُوغَسَّانَ،', #2
u'ابوك': u'ابوك', #1
u'ابوك؟': u'ابوك؟', #1
u'أبومحمد': u'أَبُومُحَمَّدٍ', #1
u'أبومحمد': u'أَبُوَمُحَمَّدٍ', #1
u'أبومعاوية': u'أَبُومُعَاوِيَةَ', #1
u'أبومليح،': u'أَبومليحٍ،', #1
u'ابوندن': u'ابوندن', #1
u'ابونعيم': u'ابونُعَيْمٌ', #1
u'أبوهمو': u'أَبُوهُمُو', #1
u'أبوهينهى': u'أَبُوهُيَنْهَى', #1
u'أبوى': u'أَبَوَىَّ', #18
u'أبوى؟': u'أَبَوَىَّ؟', #2
u'أبي،': u'أُبَيًّ،', #1
u'ابى': u'ابى', #13
u'ابي': u'ابي', #2
u'أبيار': u'أَبْيَارُ', #1
u'أبيار': u'أَبْيَارَ', #3
u'أبيإنما': u'أَبِيإِنَّمَا', #1
u'أبيثت': u'أُبِيثَتْ', #2
u'أبيجهيم': u'أَبِيجُهَيْمٍ', #1
u'أبيرج': u'أبيرج', #1
u'أبيرق': u'أبَيْرِقٍ', #1
u'أبيرق': u'أُبَيْرِقٍ', #18
u'أبيرق': u'أُبَيْرِقِ', #2
u'أبيرق،': u'أُبَيْرِقٍ،', #2
u'أبيعكه': u'أَبِيعَكَهُ', #1
u'أبيعكه': u'أَبِيعُكَهُ', #2
u'أبيعكها': u'أَبِيعَكهَا', #1
u'أبيعكها': u'أَبِيعُكَهَا', #5
u'أبيعكها': u'أَبِيعُكهَا', #7
u'أبيعكهما': u'أَبِيعُكَهُمَا', #1
u'أبيلة': u'أُبَيْلَةٌ', #2
u'أبيناء': u'أُبَيْنَاءُ', #1
u'أبيناي': u'أَبِينَايَ', #1
u'أبينى': u'أُبَيْنِىَّ', #1
u'أبينى': u'أُبَيْنَى', #2
u'ابيه': u'ابيه', #1
u'ابيه،': u'ابيه،', #10
u'أبيهأنه': u'أَبِيهِأَنَّهُ', #1
u'أبيهوأما': u'أَبِيهِوَأَمَّا', #1
u'أبيويعرض': u'أَبِيوَيَعْرِضُ', #1
u'اة': u'اة', #1
u'ات': u'ات', #1
u'أتابك': u'أَتَابِكَ', #2
u'أتاتين': u'أَتَاتِين', #1
u'أتاتين': u'أَتَاتِينَ', #2
u'اتأد': u'اتَّأَدَ', #1
u'اتأد': u'اِتَّأَدَ', #1
u'أتأمت': u'أَتَأَمَّتْ', #1
u'أتأمت': u'أَتْأَمَتْ', #2
u'آتاناه': u'آتَانَاهُ', #1
u'أتانة': u'أَتَانَةٌ', #1
u'آتانى': u'آتَانِىَ', #1
u'أتانى': u'أَتَانِىَ', #1
u'آتانى': u'آتَانِى', #2
u'أتانى': u'أَتَانِى', #61
u'أتأيم': u'أَتَأَيَّمُ', #1
u'أتأيم': u'أَتَأَيَّمِ', #1
u'أتأيم': u'أَتَأَيَّمْ', #3
u'اتباعى؟': u'اتِّبَاعِى؟', #1
u'اتبعتنى': u'اتَّبَعْتَنِى', #2
u'إتبعه': u'إتَّبَعَهُ', #1
u'إتبعوا': u'إِتَّبِعُوا', #1
u'أتبيعنى': u'أَتَبِيعُنِى', #1
u'أتبيعنيه': u'أَتَبِيعَنِيهِ', #1
u'أتبيعنيه': u'أَتَبِيعُنِيهِ', #6
u'أتتنى': u'أَتَتْنِى', #6
u'أتتهمنى': u'أَتَتَّهِمُنِى', #2
u'اتثاق': u'اتِّثَاقُ', #1
u'اتجهه': u'اتَّجَهَهُ', #1
u'أتحآجوننا': u'أَتُحَآجُّونَنَا', #1
u'أتحالم': u'أَتَحَالَمُ', #2
u'أتحسبينى': u'أَتَحْسَبِينِى', #1
u'أتحفنى': u'أَتْحِفْنِى', #1
u'إتخاذ': u'إتخاذ', #2
u'إتخاذها': u'إتخاذها', #2
u'أتخافنى': u'أَتَخَافُنِى', #1
u'أتخذت': u'أَتَّخَذْتَ', #2
u'أتخذتم': u'أَتّخَذْتُمْ', #4
u'أتخذتم': u'أَتَّخَذْتُمْ', #7
u'اتخذنى': u'اتَّخَذَنِى', #1
u'أتخلفنى': u'أَتُخَلِّفُنِى', #1
u'أتدريان': u'أَتَدْرِيَانِ', #4
u'إترابا': u'إتْرَابًا', #1
u'أترانى': u'أَتَرَانِى', #2
u'أترانى': u'أَتُرَانِى', #2
u'أترضحني': u'أَتَرْضَحُنِي', #1
u'أترنجة': u'أُتْرُنْجَة', #1
u'أترنجة': u'أُتْرُنْجَةً', #1
u'أترونا': u'أَتَرَوْنَا', #1
u'أترونى': u'أَتُرَوْنِى', #1
u'أتريان': u'أَتَرَيَانِ', #1
u'اتزره': u'اتَّزَرَهُ', #1
u'اتزرى': u'اتَّزِرِى', #1
u'إتساع': u'إتْسَاعِ', #1
u'أتستحي': u'أَتَسْتَحِي', #1
u'أتستهزيء': u'أَتَسْتَهْزِيءُ', #1
u'آتش': u'آتش', #1
u'آتش،': u'آتَشَ،', #1
u'أتش': u'أَتْشٍ', #2
u'أتش،': u'أَتَشَ،', #3
u'اتصافة': u'اتِّصَافَةٌ', #1
u'اتصافة': u'اتِّصَافَةِ', #1
u'اتصالة': u'اتِّصَالَةُ', #1
u'اتضاع': u'اتِّضَاعٌ', #1
u'اتضاع': u'اتِّضَاعِ', #1
u'اتضع': u'اتَّضَعَ', #5
u'اتضع': u'اتَّضِعْ', #5
u'اتضعت': u'اُتُّضِعَتْ', #1
u'اتضعت': u'اتَّضَعَتْ', #2
u'أتطؤها': u'أَتَطَؤُهَا', #1
u'أتطئها': u'أَتّطِئُهَا', #2
u'اتعد': u'اُتّعِدَ', #1
u'اتعدت': u'اتّعَدَتْ', #1
u'اتعدت': u'اتّعَدْت', #1
u'اتعدت': u'اتّعَدْتُ', #1
u'اتعدت': u'اتَّعَدْت', #1
u'اتعدت': u'اتَّعَدْتُ', #2
u'اتعدتم': u'اتّعَدْتُمْ', #2
u'اتعدوا': u'اتّعَدُوا', #2
u'أتعرفنى؟': u'أَتَعْرِفُنِى؟', #1
u'أتعرفنى': u'أَتَعْرِفُنِى', #2
u'أتعطيان': u'أَتُعْطِيَانِ', #3
u'أتعلمنى': u'أَتُعَلِّمُنِى', #2
u'اتغر': u'اتَّغَرَ', #6
u'أتغمص': u'أَتَغْمِصُ', #1
u'اتفاقى': u'اِتِفَاقِىٌّ', #1
u'اتفقاهما': u'اتَّفَقَاهُمَا', #1
u'أتفقت': u'أَتَّفَقَتْ', #1
u'اتقار': u'اِتِّقَار', #1
u'اتقان': u'اتَّقَانِ', #1
u'أتقاني': u'أَتْقَانِيًٌ', #2
u'أتقرءون': u'أَتَقْرَءُونَ', #4
u'اتقف': u'اتَّقَفَ', #1
u'أتقفأ': u'أَتَقَفَّأُ', #1
u'اتقلت': u'اتَقَلَّتْ', #1
u'أتقنح': u'أتقنح', #1
u'أتقيأها': u'أَتَقَيَّأُهَا', #1
u'اتقيتن': u'اِتَّقَيْتُنَّ', #1
u'اتقيتن': u'اتَّقَيْتُنَّ', #9
u'أتكاراها': u'أَتَكَارَاهَا', #3
u'اتكيت': u'اتَّكَيْتُ', #2
u'اتلأب': u'اتْلَأَبّ', #2
u'إتلائها': u'إتْلَائِهَا', #1
u'اتلج': u'اتّلَجَ', #1
u'اتلفاه': u'اتْلَفَاهُ', #1
u'أتلومنى': u'أَتَلُومُنِى', #1
u'أتمحضت': u'أَتَمَحَّضَتْ', #1
u'أتمدونن': u'أَتُمِدُّونَنِ', #7
u'اتممش': u'اتممش', #1
u'أتنهانى': u'أَتَنْهَانِى', #1
u'اتنهونى': u'اتَنْهَوْنِى', #1
u'اتهاب': u'اتِّهَابٍ', #18
u'اتهاب': u'اتِّهَابُ', #3
u'اتهاب': u'اتِّهَابِ', #6
u'اتهابا': u'اتِّهَابًا', #4
u'اتهابه': u'اتِّهَابُهُ', #10
u'اتهابه': u'اتِّهَابِهِ', #6
u'اتهابه': u'اتِّهَابَهُ', #7
u'اتهابها': u'اتِّهَابُهَا', #1
u'إتهام': u'إتْهَامٌ', #1
u'إتهام': u'إتْهَامِ', #1
u'إتهامها': u'إتْهَامُهَا', #1
u'اتهب': u'اتَّهَبَ', #33
u'اتهب': u'اُتُّهِبَ', #6
u'اتهبا': u'اتَّهَبَا', #1
u'اتهباه': u'اتَّهَبَاهُ', #4
u'اتهبت': u'اتَّهَبْت', #8
u'اتهبته': u'اتَّهَبْتُهُ', #5
u'اتهبته': u'اتَّهَبْته', #8
u'اتهبتها': u'اتَّهَبْتهَا', #1
u'اتهبتها': u'اتَّهَبْتُهَا', #1
u'اتهبنا': u'اتَّهَبْنَا', #1
u'اتهبنا': u'اُتُّهِبْنَا', #1
u'أتهبننى': u'أَتَهَبْنَنِى', #1
u'اتهبه': u'اتَّهِبْهُ', #1
u'اتهبه': u'اتَّهَبَهُ', #47
u'اتهبها': u'اتَّهَبَهَا', #12
u'اتهمنى': u'اتَّهَمَنِى', #1
u'إتواء': u'إتواء', #1
u'إتواء': u'إتْوَاءِ', #17
u'إتواء': u'إتْوَاءٍ', #2
u'إتواء': u'إتْوَاءُ', #3
u'إتواء': u'إتْوَاءً', #4
u'إتواء': u'إتْوَاءَ', #9
u'أتواالنبي': u'أَتَوُاالنَّبِيَّ', #1
u'أتؤاجرني': u'أَتُؤَاجِرُنِي', #1
u'أتؤديان': u'أَتُؤَدِّيَانِ', #5
u'أتوما': u'أُتُومًا', #1
u'أتؤمنونى': u'أَتُؤْمِنُونِى', #1
u'اتى': u'اتى', #5
u'اتئد': u'اُتُّئِدَ', #2
u'اتئد': u'اتَّئِدْ', #5
u'اتئدا': u'اتَّئِدَا', #1
u'اتئدوا': u'اتَّئِدُوا', #3
u'أتياالنبي': u'أَتَيَاالنَّبِيَّ', #1
u'إتياح': u'إتْيَاحَ', #1
u'أتىالنبي': u'أَتَىالنَّبِيَّ', #2
u'إتيانالغائط': u'إتْيَانِالْغَائِطِ', #1
u'أتيانى': u'أَتَيَانِى', #2
u'آتيتنى': u'آتَيْتَنِى', #1
u'أتيتنى': u'أَتَيْتَنِى', #3
u'آتيكا': u'آتِيكَا', #1
u'أتيناكي': u'أَتَيْنَاكِي', #2
u'أث': u'أَثَّ', #1
u'أث': u'أث', #2
u'أثا': u'أَثَا', #1
u'أثا،': u'أَثَّا،', #1
u'أثأت': u'أَثْأَتْ', #1
u'أثاثة': u'أثاثة', #1
u'أثاثة': u'أُثَاثَة', #1
u'أثاثة': u'أُثَاثَةُ', #1
u'أثاثة،': u'أُثَاثَةَ،', #1
u'أثاثة': u'أَثَاثَةٌ', #4
u'أثاثة': u'أَثَاثَةَ', #4
u'أثاثة': u'أُثَاثَةَ', #48
u'أثأل': u'أَثْأَلُ', #1
u'أثال،': u'أُثال،', #1
u'أثال': u'أَثَالُ', #1
u'أثال': u'أُثَالَ', #1
u'أثال': u'أُثَالِ', #1
u'أثال،': u'أُثَالٍ،', #1
u'أثال': u'أَثَالٍ', #15
u'أثال': u'أُثَال', #2
u'أثال': u'أُثَالُ', #2
u'أثال': u'أُثَالٍ', #55
u'أثالة': u'أُثَالَةَ', #1
u'اثاوره': u'اثاوره', #1
u'أثايا': u'أَثَايَا', #2
u'أثاية': u'أُثَايَةَ', #1
u'أثاية': u'أَثَايَة', #2
u'أثباج': u'أَثْبَاجِ', #1
u'إثبانه': u'إثْبَانُهُ', #1
u'أثبنى': u'أَثِبْنِى', #1
u'اثتغر': u'اثْتَغَرَ', #6
u'اثتلم': u'اِثْتَلَمَ', #1
u'أثرSالقصيدة': u'أَثَرُSالْقَصِيدَةُ', #1
u'أثر': u'أَثَرً', #1
u'أثرالسجود': u'أَثَرَالسُّجُودِ', #1
u'أثرم': u'أثرم', #1
u'أثرم': u'أَثْرَمَ', #1
u'إثرى': u'إِثْرِى', #1
u'أثط،': u'أثطَ،', #1
u'أثط': u'أَثَطَّ', #1
u'أثعل': u'أَثْعَلُ', #1
u'اثغار': u'اثِّغَارِ', #1
u'أثغارها': u'أَثْغَارُهَا', #1
u'اثغر': u'اثَّغَرَ', #6
u'أثفال': u'أَثَفَالُ', #1
u'أثفال': u'أَثْفَالُ', #1
u'أثفاله': u'أَثَفَالَهُ', #1
u'أثفرتها': u'أَثْفَرْتهَا', #1
u'أثفيان': u'أَثْفِيَانَ', #2
u'أثفيان': u'أَثَفَيَانِ', #3
u'اثما': u'اثماً', #1
u'أثمتموه': u'أَثَّمْتُمُوهُ', #1
u'إثمد': u'إثْمِدٍ', #8
u'إثمدا': u'إثْمِدًا', #2
u'اثمه': u'اثْمُهُ', #1
u'إثمى': u'إِثْمِى', #1
u'أثنا': u'أثْنَا', #1
u'اثناء': u'اثِّنَاءَ', #1
u'اثناء': u'اثِّنَاءِ', #2
u'إثنان': u'إثنان', #1
u'إثنان': u'إثْنَان', #1
u'أثنان': u'أَثْنَانِ', #2
u'اثنانيون': u'اثْنَانِيُّونَ', #1
u'اثنائها': u'اثِّنَائِهَا', #2
u'أثنائهمقاما': u'أَثْنَائِهِمُقَامًا', #1
u'اثنتاهما': u'اثْنَتَاهُمَا', #2
u'اثنتى': u'اثْنَتَى', #1
u'اثنتى': u'اثْنَتَىْ', #11
u'اثنى': u'اِثَّنَى', #1
u'اثنى': u'اثْنَى', #16
u'اثنى': u'اثنى', #2
u'اثنى': u'اثْنَىْ', #73
u'اثنينيا': u'اثْنَيْنِيًّا', #1
u'اثنينية': u'اثْنَيْنِيَّةٌ', #1
u'اثنينية': u'اثْنَيْنِيَّةَ', #1
u'أثوع': u'أَثْوَعَ', #1
u'أثيبج': u'أُثُيْبِجَ', #1
u'أثيبج': u'أُثَيْبِجَ', #4
u'أثيث': u'أَثِيثٌ', #1
u'أثيثا': u'أثيثًا', #1
u'أثيع': u'أُثَيْعٍ', #1
u'أجأ': u'أَجَأً', #2
u'أجإ': u'أَجَإٍ', #2
u'أجاءوا': u'أَجَاءُوا', #1
u'اجابه': u'اجابه', #1
u'أجاجير': u'أَجَاجِيرِ', #1
u'أجاجيرك': u'أَجَاجِيرَكِ', #1
u'إجاحة': u'إجَاحَةِ', #2
u'أجادب': u'أَجَادِبُ', #2
u'اجارة': u'اجارة', #1
u'إجارت': u'إجَارَتِ', #1
u'اجارت': u'اجارت', #1
u'اجاره': u'اجاره', #2
u'أجازنى': u'َأَجَازَنِى', #1
u'أجاشك': u'أَجَاشَكَ', #1
u'أجاصا': u'أَجَاصًّا', #1
u'إجافة': u'إجَافَةٍ', #15
u'آجال': u'آجَالً', #1
u'إجانات': u'إجَّانَاتُ', #1
u'إجانات': u'إجَّانَاتٍ', #10
u'أجايز': u'أَجَايِزَ', #1
u'إجباء': u'إجْبَاءً', #1
u'أجبتوني': u'أَجَبْتُونِي', #1
u'أجبيل': u'أَجُبَيْلُ', #1
u'اجتاب': u'اجتاب', #1
u'اجتال': u'اجتال', #1
u'اجتباذا': u'اجْتِبَاذًا', #1
u'اجتبذه': u'اجْتَبَذَهُ', #1
u'أجتثثته': u'أَجْتَثَثْته', #1
u'اجتحفها': u'اجْتَحَفَهَا', #2
u'اجتدائك': u'اجْتِدَائِك', #1
u'اجتدي': u'اجْتُدِي', #2
u'اجتدي': u'اُجْتُدِيَ', #2
u'اجترءوا': u'اجْتَرَءُوا', #2
u'أجترأ': u'أَجْتَرَأَ', #1
u'اجترم': u'اجْتَرَمَ', #5
u'اجترمتها': u'اجْتَرَمَتْهَا', #1
u'اجترمه': u'اجْتَرَمَهُ', #2
u'اجترموا': u'اجْتَرَمُوا', #2
u'اجتزءوا': u'اجتزءوا', #2
u'اجتزءوا': u'اجْتَزَءُوا', #3
u'اجتزأ': u'اجْتَزَأَ', #18
u'اجتزاء': u'اجْتِزَاءَ', #1
u'اجتزاء': u'اجْتِزَاءً', #3
u'اجتزأت': u'اجْتَزَأْتَ', #2
u'أجتزر': u'أَجْتَزِرُ', #1
u'اجتزراها': u'اجْتَزَرَاهَا', #3
u'اجتزى': u'اجْتَزَى', #2
u'اجتزئ': u'اُجْتُزِئَ', #11
u'اجتزئ': u'اجْتَزِئْ', #2
u'أجتسها': u'أَجْتَسُّهَا', #1
u'اجتعل': u'اجْتَعَلَ', #1
u'أجتلي': u'أَجْتَلِي', #1
u'اجتمالها': u'اجْتِمَالِهَا', #1
u'إجتمع': u'إجْتَمَعَ', #1
u'أجتمعا': u'أَجْتَمَعَا', #1
u'اجتمعاهما': u'اجْتَمَعَاهُمَا', #2
u'إجتمعوا': u'إجتمعوا', #1
u'اجتنان': u'اجْتِنَانُ', #1
u'اجتنان': u'اجْتِنَانِ', #2
u'اجتنانا': u'اجْتِنَانًا', #1
u'اجتنانه': u'اجْتِنَانِهِ', #5
u'إجتنب': u'إجْتَنِبِ', #1
u'اجتنبى': u'اجْتَنِبِى', #1
u'اجتنح': u'اجْتَنَحَ', #1
u'إجتهد': u'إجتهد', #1
u'اجتهلته': u'اجْتَهَلَتْهُ', #9
u'اجتوروا': u'اجْتَوَرُوا', #1
u'اجتووا': u'اِجْتَوَوْا', #1
u'اجتووا': u'اجتووا', #3
u'اجتووا': u'اجْتَوَوْا', #4
u'اجتووها': u'اجْتَوَوْهَا', #1
u'أجتوي': u'أَجْتَوِي', #1
u'اجتويت': u'اِجْتَوَيْت', #1
u'اجتويت': u'اجْتَوَيْتُ', #2
u'اجتوينا': u'اجْتَوَيْنَا', #5
u'اجثوا': u'اجْثُوا', #1
u'اجثوا': u'اُجْثُوا', #2
u'أجحارها': u'أَجْحَارُهَا', #1
u'أجحارها': u'أَجْحَارِهَا', #2
u'أجحرتهن': u'أَجْحُرَتِهِنَّ', #1
u'أجحظ': u'أَجْحَظْ', #1
u'أجحفتها': u'أَجْحَفَتْهَا', #1
u'أجحفها': u'أَجْحَفَهَا', #11
u'أجحمت': u'أَجْحَمَتْ', #2
u'أجداف': u'أَجْدَافٍ', #1
u'اجدح': u'اجْدَحْ', #2
u'اجدح': u'اجدح', #3
u'أجدنى': u'أَجِدْنِى', #1
u'أجدنى': u'أَجِدُنِى', #6
u'إجذاذه': u'إجْذَاذِهِ', #1
u'إجذاعه': u'إجْذَاعُهُ', #1
u'إجذاعها': u'إجْذَاعُهَا', #1
u'إجذاعها': u'إجْذَاعِهَا', #1
u'أجذعة': u'أَجْذِعَة', #1
u'أجذعة': u'أَجْذِعَةً', #2
u'أجراع': u'أَجْرَاعِ', #1
u'آجرتكه': u'آجَرْتُكَهُ', #2
u'أجرتكه': u'أَجَرْتُكَهُ', #3
u'أجرتكها': u'أَجَرْتُكهَا', #11
u'أجرتكها': u'أَجَرْتُكَهَا', #14
u'آجرتكها': u'آجَرْتُكهَا', #20
u'أجرتكها': u'أَجَرَتْكهَا', #6
u'آجرتكها': u'آجَرْتُكَهَا', #9
u'أجرتكها': u'أَجَّرْتُكَهَا', #9
u'آجرتنيها': u'آجَرْتَنِيهَا', #1
u'أجرتنيها': u'أَجَّرْتَنِيهَا', #1
u'أجرتنيها': u'أَجَرْتَنِيهَا', #2
u'أجرتى': u'أُجْرَتِى', #1
u'أجرل': u'أَجْرَلَ', #4
u'أجرنى': u'أَجِرْنِى', #1
u'اجرني': u'اجُرْنِي', #1
u'أجرنى': u'أْجُرْنِى', #3
u'أجرنيه': u'أَجَرَنِيهِ', #1
u'أجرنيه': u'أَجَّرَنِيهِ', #1
u'آجرنيه': u'آجَرَنِيهِ', #13
u'أجرنيها': u'أَجَّرَنِيهَا', #1
u'أجرنيها': u'أَجِّرْنِيهَا', #1
u'آجرنيها': u'آجَرَنِيهَا', #2
u'أجره': u'أَجْرَهًًًًُ', #1
u'اجره': u'اجْرِهِ', #1
u'أجرؤكم': u'أَجْرَؤُكُمْ', #16
u'اجروها': u'اجْرُوهَا', #1
u'أجرؤهم': u'أَجْرَؤُهُمْ', #5
u'أجزأة': u'أَجْزِأَةٍ', #1
u'أجزاعا': u'أَجْزَاعًا', #1
u'أجزأكوروي': u'أَجْزَأَكَوَرُوِيَ', #1
u'أجزرتكها،': u'أَجْزَرْتُكَهَا،', #1
u'أجعلتنى': u'أَجَعَلْتَنِى', #1
u'اجعلنى': u'اجْعَلْنِى', #5
u'اجعلى': u'اجعلى', #1
u'اجعلى': u'اجْعَلِى', #1
u'أجلح': u'أجلح', #2
u'أجلح،': u'أَجْلَحَ،', #5
u'أجلح': u'أَجْلَحَ', #7
u'أجلح': u'أَجْلَحُ', #8
u'أجلسانى': u'أَجْلِسَانِى', #3
u'أجلسنى': u'أَجْلِسْنِى', #1
u'اجلسى': u'اجْلِسِى', #2
u'أجلنيها': u'أَجِّلْنِيهَا', #1
u'أجلهوالوجه': u'أَجَلِهِوَالْوَجْهُ', #1
u'أجلوروي': u'أَجَلٌوَرُوِيَ', #1
u'أجليبيب': u'أَجُلَيْبِيبٌ', #4
u'إجماء': u'إجْمَاءٌ', #1
u'إجماد': u'إجْمَادِ', #1
u'إجمار': u'إجْمَارَ', #2
u'إجمارا': u'إِجْمَارًا', #2
u'أجمعو': u'أَجْمَعُو', #1
u'اجمعى': u'اجْمَعِى', #3
u'أجنأ': u'أَجْنَأَ', #2
u'إجناء': u'إجْنَاءً', #1
u'إجناء': u'إجْنَاءُ', #1
u'إجناب': u'إجْنَابَ', #1
u'إجنابا': u'إجْنَابًا', #1
u'أجنأت': u'أَجَنَأْت', #1
u'أجنأت': u'أَجْنَأْت', #1
u'أجنادين،': u'أجنادين،', #1
u'أجنادين،': u'أَجنادين،', #1
u'أجنادين،': u'أجْنادين،', #1
u'أجنادين': u'أَجَنَادِينُ', #1
u'أجنادين': u'أَجْنَادِينُ', #1
u'أجنادين': u'أَجَنَادَيْنُ', #1
u'أجنادين،': u'أَجْنَادَيْنَ،', #1
u'إجنادين': u'إجْنَادِينَ', #1
u'أجنادين': u'أَجْنَادِينَ', #12
u'أجنادين': u'أَجَنَادَيْنَ', #3
u'أجنادين': u'أَجْنَادَيْنَ', #7
u'أجنزه': u'أَجْنِزُهُ', #1
u'أجنيبا': u'أَجَنِيبًا', #1
u'أجنيبة': u'أَجَنِيبَةٍ', #1
u'اجه': u'اجه', #1
u'اجورهم': u'اجورهم', #1
u'أجىء': u'أَجِىءُ', #1
u'أجىء': u'أَجِىءَ', #2
u'أجيبى': u'أَجِيبِى', #3
u'اجير': u'اجير', #1
u'أجير': u'أَجِيرً', #2
u'أجيزى': u'أَجِيزِى', #1
u'أجيئك': u'أَجِيئُك', #3
u'أجيئه؟': u'أَجِيئَهُ؟', #1
u'أجيئهن': u'أَجِيئَهُنَّ', #1
u'أحابستى': u'أَحَابِسَتِى', #1
u'أحابيشا': u'أحابِيشًا', #1
u'أحابيشا': u'أَحَابِيشًا', #1
u'أحاديثا': u'أَحَادِيثاً', #1
u'أحاديثا': u'أَحَادِيثَا', #1
u'أحاديثا': u'أَحَادِيثًا', #3
u'أحاديثا،': u'أَحَادِيثًا،', #4
u'أحاصهم': u'أُحَاصُّهُمْ', #1
u'أحانه': u'أَحَانَهُ', #1
u'أحانهم': u'أَحَانَهُمُ', #2
u'إحبار': u'إحْبَارَ', #1
u'أحبلنى': u'أَحْبَلَنِى', #1
u'احبنطأ': u'احْبَنْطَأَ', #2
u'أحبنطي': u'أَحْبَنْطِي', #1
u'أحبنى': u'أَحَبَّنِى', #4
u'احتاجاه': u'احْتَاجَاهُ', #1
u'احتاجته': u'احْتَاجَتْهُ', #4
u'احتاجتهما': u'احْتَاجَتْهُمَا', #1
u'أحتاجه': u'أَحْتَاجَهُ', #1
u'أحتاجه': u'أَحْتَاجُهُ', #2
u'احتاجه': u'احْتَاجَهُ', #92
u'أحتاجها': u'أَحْتَاجُهَا', #1
u'احتاجها': u'احْتَاجَهَا', #7
u'احتاجهم': u'احْتَاجَهُمْ', #1
u'احتاجهما': u'احْتَاجَهُمَا', #5
u'احتاجوه': u'احْتَاجُوهُ', #5
u'احتاجوها': u'احْتَاجُوهَا', #3
u'احتاز': u'احْتَازَ', #1
u'احتازه': u'احْتَازَهُ', #1
u'احتازها': u'احْتَازَهَا', #12
u'احتاطته': u'احْتَاطَتْهُ', #1
u'احتاطه': u'احْتَاطَهُ', #2
u'احتالها': u'احْتَالَهَا', #1
u'إحتام': u'إحْتَامُ', #1
u'إحتام': u'إحْتَامِ', #1
u'احتباك': u'احْتِبَاكٌ', #18
u'احتباك': u'احْتِبَاكُ', #2
u'احتباك': u'احْتِبَاكٍ', #7
u'احتباكا': u'احْتِبَاكًا', #14
u'أحتبست': u'أُحْتُبِسْتُ', #1
u'احتثي': u'احْتَثِي', #1
u'احتثى': u'احْتَثَى', #1
u'احتجاره': u'احْتِجَارُهُ', #2
u'احتجام': u'احْتِجَامٌ', #1
u'احتجام': u'احْتِجَامٍ', #1
u'احتجامة': u'احْتِجَامَةً', #2
u'احتجامه': u'احْتِجَامَهُ', #1
u'احتجامه': u'احْتِجَامِهِ', #1
u'احتجبى': u'احْتَجِبِى', #3
u'احتجر': u'اُحْتُجِرَ', #1
u'احتجر': u'احْتَجَرَ', #10
u'احتجرها': u'احْتَجَرَهَا', #1
u'احتجروا': u'احْتَجَرُوا', #1
u'احتجم': u'احْتَجِمُ', #1
u'احتجم': u'اُحْتُجِمَ', #1
u'احتجم': u'احتجم', #2
u'احتجم،': u'احْتَجَمَ،', #2
u'احتجم': u'احْتَجَمَ', #317
u'أحتجم': u'أَحْتَجِمُ', #4
u'احتجم': u'احْتَجِمْ', #6
u'احتجم': u'اِحْتَجَمَ', #6
u'احتجمت': u'احْتَجَمْت', #2
u'احتجمت': u'احْتَجَمْتُ', #4
u'احتجموا': u'احْتَجِمُوا', #1
u'احتجناه': u'احْتَجْنَاهُ', #1
u'احتجناهم': u'احْتَجْنَاهُمْ', #2
u'احتراز': u'احْتِرَازً', #2
u'احتربت': u'اُحْتُرِبَتْ', #1
u'احتربوا': u'احْتَرَبُوا', #1
u'احترثوا': u'احْتَرَثُوا', #1
u'احترسها': u'احْتَرَسَهَا', #1
u'احترشها،': u'احْتَرَشَهَا،', #2
u'احترشها': u'احْتَرَشَهَا', #4
u'احتز': u'احْتَزَّ', #6
u'احتزاز': u'احْتِزَازٌ', #6
u'احتزام': u'احْتِزَامٍ', #4
u'احتزتيه': u'احْتَزْتِيهِ', #1
u'احتزم': u'احْتَزَمَ', #6
u'احتزوا': u'احْتَزّوا', #1
u'احتزوا': u'احْتَزُّوا', #2
u'احتساباوالوجه': u'احْتِسَابًاوَالْوَجْهُ', #1
u'أحتسبت': u'أَحْتَسَبَتْ', #1
u'احتسبى': u'احْتَسِبِى', #1
u'احتش': u'احْتَشَّ', #14
u'أحتش': u'أَحْتَشُّ', #2
u'احتشا': u'احْتَشَّا', #1
u'احتشا': u'اُحْتُشَّا', #1
u'احتشاش': u'احْتِشَاشُ', #1
u'احتشاش': u'احْتِشَاشِ', #1
u'احتشاش': u'احْتِشَاشٍ', #8
u'احتشاشه': u'احْتِشَاشَهُ', #2
u'احتشاشها': u'احْتِشَاشِهَا', #1
u'احتشت': u'احْتَشَتْ', #15
u'احتشته': u'احْتَشَّتْهُ', #3
u'احتشتها': u'احْتَشَّتْهَا', #1
u'احتشه': u'احْتَشَّهُ', #9
u'احتشوه': u'احْتَشَوْهُ', #1
u'احتشي': u'اِحْتَشِي', #1
u'احتشي': u'احْتَشِي', #4
u'احتشى': u'احْتَشَى', #5
u'احتضرتي': u'احْتَضَرْتِي', #1
u'احتظر': u'احْتَظَرَ', #1
u'احتظر': u'احتظر', #2
u'احتظرت': u'احْتَظَرْت', #1
u'احتظرت': u'احْتَظَرْتَ', #1
u'احتظرت': u'اِحْتَظَرْت', #3
u'احتظرت': u'احْتَظَرْتِ', #4
u'احتفار': u'احْتِفَارِ', #2
u'احتفاف': u'احْتِفَافَ', #1
u'احتفاف': u'احْتِفَافِ', #2
u'احتفافه': u'احْتِفَافِهِ', #2
u'احتفافها': u'احْتِفَافُهَا', #1
u'احتفر': u'احْتُفِرَ', #1
u'احتفر': u'احْتَفِرْ', #2
u'احتفر': u'اُحْتُفِرَ', #5
u'احتفر': u'احْتَفَرَ', #59
u'احتفرت': u'اُحْتُفِرَتْ', #1
u'احتفرت': u'احْتَفَرَتْ', #3
u'احتفرتها': u'احْتَفَرَتْهَا', #4
u'احتفره': u'احْتَفَرَهُ', #13
u'احتفرها': u'احتفرها', #1
u'احتفرها': u'احْتَفَرَهَا', #20
u'احتفروا': u'احْتَفَرُوا', #2
u'احتفز': u'احتفز', #1
u'احتفز': u'اِحْتَفَزَ', #1
u'احتفز': u'احْتَفَزَ', #2
u'احتقاب': u'احْتِقَابِ', #1
u'احتقب': u'احْتَقَبَ', #1
u'احتقبها': u'احْتَقَبَهَا', #1
u'احتلط': u'احْتَلَطَ', #1
u'احتلفا': u'احْتَلَفَا', #2
u'احتلفته': u'احْتَلَفْتُهُ', #1
u'احتلق': u'احْتَلَقَ', #1
u'احتملنى': u'احْتَمَلَنِى', #1
u'احتنكا': u'احْتَنَكَا', #1
u'احتواش': u'احْتِوَاشِ', #2
u'احتواشه': u'احْتِوَاشِهِ', #2
u'احتواشها': u'احْتِوَاشِهَا', #1
u'احتوش': u'احْتَوَشَ', #2
u'احتوشته': u'احْتَوَشَتْهُ', #3
u'احتوشتها': u'احْتَوَشَتْهَا', #3
u'احتوشه': u'احْتَوَشَهُ', #9
u'احتوشوه': u'احْتَوَشُوهُ', #1
u'احتولتا': u'احْتَوَلَتَا', #1
u'احتياجة': u'احْتِيَاجَةِ', #1
u'احتياز': u'احْتِيَازَ', #1
u'احتياز': u'احْتِيَازِ', #2
u'احتيازها': u'احْتِيَازِهَا', #1
u'أحتيج': u'أَحْتِيجَ', #1
u'إحجاج': u'إحْجَاجَ', #1
u'إحجاج': u'إحْجَاجِ', #11
u'إحجاج': u'إحْجَاجُ', #38
u'إحجاجه': u'إحْجَاجِهِ', #1
u'إحجاجه': u'إحْجَاجُهُ', #12
u'إحجاجه': u'إحْجَاجَهُ', #9
u'إحجاجها': u'إحْجَاجِهَا', #5
u'إحجاجها': u'إحْجَاجُهَا', #9
u'أحجنى': u'أَحِجَّنِى', #2
u'أحدSالرسول': u'أُحُدٍSالرّسُولُ', #1
u'أحد': u'أَحَدً', #1
u'إحد': u'إِحْدَ', #1
u'أحد': u'أحدً', #3
u'إحدا': u'إحْدَا', #1
u'احدا،': u'احداً،', #1
u'أحدأبويها': u'أَحَدَأَبَوَيْهَا', #1
u'إحداد': u'إِحْدَادَ', #1
u'إحداد': u'إِحْدَادٌ', #2
u'إحداد': u'إحْدَادٌ', #29
u'إحداد': u'إحْدَادَ', #45
u'إحداد': u'إحْدَادِ', #5
u'إحداد': u'إحْدَادُ', #7
u'إحداد': u'إحْدَادٍ', #8
u'إحدادا': u'إحْدَادًا', #11
u'إحداده': u'إحْدَادِهِ', #9
u'إحدادها': u'إحْدَادِهَا', #2
u'أحداستقبل': u'أُحُدٍاسْتَقْبَلَ', #1
u'أحدافنجوت': u'أُحُدًافَنَجَوْت', #1
u'أحدأقواله،': u'أَحَدِأَقْوَالِهِ،', #1
u'أحدامع': u'أُحُدًامَعَ', #1
u'احداهما': u'احداهما', #1
u'أحداهي': u'أُحُدًاهِيَ', #1
u'أحدبأيام': u'أُحُدٍبِأَيّامٍ', #1
u'أحدبملك': u'أُحُدٍبِمَلَكٍ', #1
u'أحدبينه': u'أَحَدٌبَيْنَهُ', #1
u'أحدثالإمام': u'أَحْدَثَالْإِمَامُ', #1
u'أحدثكموه': u'أُحَدِّثُكُمُوه', #1
u'أحدثكموه،': u'أُحَدِّثَكُمُوهُ،', #1
u'أحدثكموه': u'أُحَدِّثْكُمُوهُ', #2
u'أحدثكموه': u'أُحَدِّثُكُمُوهُ', #7
u'أحدثكموه': u'أُحَدِّثَكُمُوهُ', #8
u'أحدجعلوا': u'أُحُدٍجَعَلُوا', #1
u'أحدذنبا': u'أُحُدٍذَنْبًا', #1
u'أحدفأسرع': u'أُحُدٍفَأَسْرَعَ', #1
u'أحدفرس': u'أُحُدٍفَرَسٌ', #1
u'أحدلو': u'أُحُدٍلَوْ', #1
u'أحدهماأن': u'أحدهماأَنَّ', #1
u'أحدهمانهي': u'أَحَدُهُمَانُهِيَ', #1
u'أحدهملئن': u'أَحَدُهُمْلَئِنْ', #1
u'أحدووليت': u'أُحُدٍوَوَلّيْت', #1
u'إحدى': u'إِحْدًى', #2
u'إحديهما': u'إحْدَيْهِمَا', #1
u'إحديهما': u'إِحْدَيْهِمَا', #3
u'إحديهما،': u'إِحْدَيْهِمَا،', #3
u'إحذار': u'إحْذَارَ', #1
u'أحذركها': u'أُحَذِّرُكَهَا', #1
u'أحذم': u'أَحْذِمُ', #1
u'إحراثهم': u'إحْرَاثِهِمْ', #1
u'أحراروالوجه': u'أحراروَالْوَجْهُ', #1
u'إحرامى': u'إِحْرَامِى', #1
u'أحزاء': u'أحزاء', #1
u'احزألت': u'احْزَأَلَّتْ', #1
u'احزألت': u'احْزَأَلّتْ', #5
u'أحزننى': u'أَحْزَنَنِى', #1
u'أحزى': u'أَحْزَى', #1
u'أحسبنى': u'أَحْسَبُنِى', #1
u'أحسنيتها': u'أَحْسَنِيَّتَهَا', #1
u'أحشاف': u'أَحْشَافِ', #1
u'إحشاف': u'إحْشَافِ', #2
u'إحشافها': u'إحْشَافِهَا', #1
u'إحشافهما': u'إحْشَافِهِمَا', #1
u'احشرنى': u'احْشُرْنِى', #1
u'احشى': u'احْشِى', #2
u'إحصار': u'إِحْصَار', #1
u'إحصار': u'إحْصَارُ', #2
u'إحصار': u'إحْصَارَ', #21
u'إحصار': u'إحْصَارٍ', #25
u'إحصار': u'إحْصَارِ', #6
u'إحصار': u'إحْصَارٌ', #7
u'إحصارا': u'إحْصَارًا', #3
u'إحصاره': u'إحْصَارَهُ', #1
u'إحصاره': u'إحْصَارِهِ', #17
u'إحصاره': u'إحْصَارُهُ', #9
u'إحصارها': u'إحْصَارَهَا', #1
u'إحصارهم': u'إحْصَارُهُمْ', #2
u'إحصال': u'إحْصَالٍ', #1
u'إحضاء': u'إحْضَاءِ', #1
u'إحضان': u'إحْضَانُ', #1
u'إحضان': u'إحْضَانِ', #1
u'أحضرالحديبية': u'أَحْضُرْالْحُدَيْبِيَةَ', #1
u'أحضير': u'أَحُضَيْرُ', #1
u'إحظار': u'إِحْظَار', #1
u'إحفاء': u'إحْفَاءً', #1
u'إحفاء': u'إِحْفَاء', #1
u'إحفاء': u'إِحْفَاءَ', #1
u'إحفاء': u'إحْفَاءَ', #2
u'إحفاء': u'إحْفَاءِ', #3
u'إحفاء': u'إحْفَاءُ', #4
u'إحفاءه': u'إحْفَاءَهُ', #3
u'أحفاش': u'أَحْفَاشٌ', #1
u'إحفاؤه': u'إحْفَاؤُهُ', #5
u'إحفائه': u'إحْفَائِهِ', #1
u'احفنى': u'احْفِنِى', #2
u'أحفياء': u'أَحْفِيَاءُ', #2
u'احقلى': u'احْقِلِى', #1
u'أحقيته': u'أَحَقِّيَّتَهُ', #1
u'أحقيته': u'أَحَقِّيَّتِهِ', #2
u'أحقيته': u'أَحَقِّيَّتُهُ', #4
u'أحقيتهم': u'أَحَقِّيَّتُهُمْ', #3
u'أحقيتهما': u'أَحَقِّيَّتُهُمَا', #1
u'أحكامات': u'أَحْكَامَاتٍ', #1
u'أحكامات': u'أَحْكَامَاتِ', #1
u'احكمى': u'احْكُمِى', #2
u'احلقى': u'احْلِقِى', #3
u'أحللتيها': u'أَحْلَلْتِيهَا', #2
u'إحماد': u'إحْمَادُ', #1
u'احمار': u'احْمَارَّ', #2
u'إحماله': u'إحْمَالُهُ', #1
u'إحمالها': u'إحْمَالِهَا', #1
u'أحمد': u'أًحْمَدُ', #1
u'أحمدبن': u'أَحْمَدَبْنُ', #1
u'أحمدبن': u'أَحْمَدُبْنُ', #1
u'أحمرS': u'أَحْمَرِS', #1
u'أحمرأن': u'أَحْمَرَأَنَّ', #2
u'احمرة': u'احمرة', #1
u'أحمزها': u'أَحَمْزَهَا', #1
u'أحمزها': u'أَحْمَزُهَا', #24
u'أحمزها': u'أَحَمْزُهَا', #9
u'أحمش': u'أحْمش', #1
u'أحمشت': u'أَحْمَشْتُ', #1
u'احملنى': u'احْمِلْنِى', #1
u'احملونى': u'احْمِلُونِى', #1
u'أحموقة': u'أُحْمُوقَةِ', #2
u'أحموقة': u'أُحْمُوقَةٍ', #3
u'أحنأ': u'أَحَنَأَ', #1
u'أحنجته': u'أَحْنَجْتُهُ', #1
u'أحى': u'أَحَىٌّ', #3
u'احياء': u'احْيَاءِ', #1
u'أحياءالوجه': u'أَحْيَاءٌالْوَجْهُ', #1
u'أحياز': u'أَحْيَازٍ', #1
u'أحيتني': u'أَحْيَتْنِي', #1
u'أحيجة': u'أحيجة', #1
u'أحيحة': u'أحيحة', #1
u'أحيحة': u'أُحَيْحةَ', #1
u'أحيحة،': u'أُحَيْحَةَ،', #1
u'أحيحة': u'أحَيحة', #2
u'أحيحة': u'أُحَيْحَةَ', #42
u'أحيحة': u'أُحَيْحَةُ', #6
u'أحيمر': u'أُحَيْمِر', #1
u'أحيمر': u'أُحَيْمِرٌ', #2
u'أحيمر': u'أُحَيْمِرَ', #6
u'أحيمر': u'أُحَيْمِرُ', #8
u'أحيمرا': u'أُحَيْمِرًا', #1
u'أحيمق،': u'أُحَيْمَقُ،', #1
u'أحينى': u'أَحْيِنِى', #6
u'احيى،': u'احيى،', #1
u'أحيى': u'أُحْيِىَ', #2
u'أحيى': u'أُحْيَى', #4
u'أحيى،': u'أُحْيَى،', #4
u'اخ': u'اخْ', #1
u'إخ': u'إِخْ', #10
u'اخ': u'اخ', #8
u'آخا': u'آخا', #1
u'أخابث': u'أَخَابِثَ', #1
u'أخابث': u'أَخَابِثِ', #1
u'إخابها': u'إخَابَهَا', #1
u'إخارتها': u'إخَارَتُهَا', #1
u'اخاف': u'اخاف', #1
u'أخافيق': u'أَخَافِيقِ', #3
u'أخاقيق': u'أَخَاقِيقِ', #3
u'إخال': u'إِخالُ', #1
u'إخال': u'إخَال', #1
u'إخال': u'إخَالُ', #13
u'إخال': u'إِخَالُ', #6
u'إخالك': u'إخَالُكِ', #1
u'إخالك': u'إِخَالُك', #1
u'إخالك': u'إخَالُكَ', #21
u'إخالك': u'إخَالُك', #3
u'إخالك': u'إِخَالُكَ', #5
u'إخالكم': u'إخَالُكُمْ', #1
u'إخالني': u'إِخَالُنِي', #1
u'إخالنى': u'إِخَالُنِى', #1
u'إخاله': u'إخَالهُ', #1
u'إخاله': u'إخَالُهُ', #19
u'إخاله': u'إِخَالُهُ', #6
u'إخاهم': u'إخَاهُمُ', #1
u'إخبارته': u'إخْبَارَتُهُ', #1
u'اخبارهم،': u'اخبارهم،', #1
u'أخبرانى': u'أَخْبَرَانِى', #2
u'أخبرتمونى': u'أَخْبَرْتُمُونِى', #2
u'أخبرتنى': u'أَخْبَرَتَنِى', #1
u'أخبرتنى': u'أَخْبَرَتْنِى', #45
u'أخبرتنى': u'أَخْبَرْتِنِى', #5
u'أخبرتنى': u'أَخْبَرْتَنِى', #8
u'أخبرتنيه': u'أَخْبَرْتَنِيهِ', #1
u'أخبرتنيه': u'أَخْبَرَتْنِيهِ', #3
u'أخبرتيني،': u'أَخْبَرْتِينِي،', #1
u'أخبرتيني': u'أَخْبَرْتِينِي', #3
u'أخبرعباده': u'أخبرعباده', #1
u'أخبركموه': u'أُخْبِركُمُوهُ', #1
u'أخبرناأبو': u'أَخْبَرَنَاأَبُو', #2
u'أخبرناالشيخ': u'أَخْبَرَنَاالشَّيْخُ', #1
u'أخبرناعبد': u'أَخْبَرَنَاعَبْدُ', #1
u'أخبرنامعمر': u'أَخْبَرَنَامَعْمَرٌ', #1
u'أخبرنى': u'أَُخْبَرَنِى', #1
u'أخبرنى': u'أخْبَرَنِى', #2
u'أخبرنى': u'أخبرنى', #3
u'أخبرنى': u'أَخْبَرْنِى', #3
u'أخبرنى': u'أَخْبَرَنِى', #4431
u'أخبرنى': u'أَخْبِرْنِى', #55
u'أخبرنى': u'أَخْبَرَنَى', #8
u'أخبرنيأسامة': u'أَخْبَرَنِيأُسَامَةُ', #1
u'أخبرنيه': u'أخْبَرَنيه', #1
u'أخبرنيه': u'أَخْبَرَنِيهِ', #38
u'أخبرنيها': u'أَخْبَرَنِيهَا', #1
u'أخبرهأن': u'أَخْبَرَهُأَنّ', #2
u'أخبرهأنهم': u'أَخْبَرَهُأَنَّهُمْ', #1
u'أخبرهمأنه': u'أَخْبَرَهُمُأَنَّهُ', #1
u'أخبرونى': u'أَخْبَرُونِى', #3
u'أخبرونى': u'أَخْبِرُونِى', #7
u'أخبرينى': u'أَخْبِرِينِى', #5
u'اخبزى': u'اخْبِزِى', #1
u'اخت': u'اخْتِ', #1
u'اختارتنى': u'اخْتَارَتْنِى', #2
u'اختارنى': u'اخْتَارَنِى', #1
u'إختاروا': u'إختاروا', #1
u'إختاروا': u'إِخْتَارُوا', #1
u'اختارى': u'اخْتَارِى', #3
u'إختانهم': u'إخْتَانَهُمْ', #1
u'أختبأت': u'أختبأت', #1
u'اختبط': u'اخْتَبَطَ', #1
u'اختبطوا': u'اخْتُبِطُوا', #2
u'اختبى': u'اخْتَبَى', #3
u'اختدعها': u'اخْتَدَعَهَا', #1
u'أختدمه': u'أَخْتَدِمُهُ', #1
u'اختدمه': u'اخْتَدَمَهُ', #8
u'اخترام': u'اخْتِرَامِ', #6
u'اختراميا': u'اخْتِرَامِيًّا', #1
u'اخترتيني': u'اخْتَرْتِينِي', #1
u'أخترط': u'أَخْتَرِطَ', #1
u'اخترط': u'اخترط', #3
u'اخترط': u'اخْتَرَطَ', #3
u'اخترطت': u'اخْتَرَطْتُ', #6
u'اخترطوا': u'اخْتَرَطُوا', #1
u'اخترمته': u'اخْتَرَمَتْهُ', #6
u'اخترمه': u'اخْتَرَمَهُ', #1
u'اختززت': u'اخْتَزَزْتُ', #1
u'اختصاء': u'اخْتِصَاءَ', #1
u'اختصمها': u'اخْتَصَمَهَا', #1
u'أختصي': u'أَخْتَصِي', #1
u'أختصي': u'أَخْتَصِيَ', #1
u'أختصى': u'أَخْتَصِىَ', #1
u'اختصى': u'اخْتَصَى', #1
u'أختضبت': u'أَخْتَضَبَتْ', #1
u'اختطب': u'اخْتَطَبَ', #2
u'اختلاع': u'اخْتِلَاعَ', #1
u'اختلاع': u'اخْتِلَاعِ', #12
u'اختلاع': u'اخْتِلَاعٌ', #2
u'اختلاع': u'اخْتِلَاعٍ', #2
u'اختلاع': u'اخْتِلَاعُ', #26
u'اختلاعا': u'اخْتِلَاعًا', #2
u'اختلاعه': u'اخْتِلَاعُهُ', #8
u'اختلاعها': u'اخْتِلَاعِهَا', #20
u'اختلاعها': u'اخْتِلَاعَهَا', #3
u'اختلاعها': u'اخْتِلَاعُهَا', #6
u'اختلطه': u'اخْتَلَطَهُ', #1
u'اختلع': u'اخْتَلَعْ', #1
u'أختلع': u'أَخْتَلِعَ', #2
u'اختلع': u'اخْتَلَعَ', #34
u'أختلع': u'أَخْتَلِعُ', #4
u'اختلع': u'اخْتَلِعْ', #5
u'اختلعا': u'اخْتَلَعَا', #8
u'أختلعت': u'أَخْتُلِعَتْ', #1
u'اختلعت': u'اخْتَلَعْت', #12
u'اختلعت': u'اُخْتُلِعَتْ', #20
u'اختلعت': u'اخْتَلَعْتُ', #31
u'اختلعت': u'اخْتَلَعْتِ', #4
u'اختلعت': u'اخْتَلَعَتْ', #409
u'اختلعتا': u'اخْتَلَعَتَا', #4
u'اختلعتها': u'اخْتَلَعْتُهَا', #7
u'اختلعن': u'اخْتَلَعْنَ', #1
u'اختلعني': u'اخْتَلِعْنِي', #8
u'اختلعها': u'اِخْتَلَعَهَا', #1
u'اختلعها': u'اخْتَلَعَهَا', #15
u'اختلعها': u'اخْتَلِعْهَا', #2
u'اختلعي': u'اخْتَلِعِي', #30
u'أختلفا': u'أَخْتَلَفَا', #3
u'اختلفو': u'اخْتَلَفُو', #1
u'أختلفوا': u'أَخْتَلَفُوا', #1
u'اختناث': u'اخْتِنَاثُ', #1
u'اختناث': u'اِخْتِنَاث', #1
u'اختناث': u'اخْتِنَاثِ', #23
u'اختناثه': u'اخْتِنَاثُهُ', #1
u'اختنث': u'اخْتَنَثَ', #1
u'اختنث': u'اِخْتَنَثَ', #1
u'أختى': u'أُخْتِى', #58
u'اختيارة': u'اخْتِيَارَةٍ', #2
u'اختيارة': u'اخْتِيَارَةً', #39
u'أختيته': u'أُخْتِيَّتُهُ', #2
u'أختيتها': u'أُخْتِيَّتِهَا', #1
u'إخدارهم': u'إخْدَارَهُمْ', #2
u'إخدام': u'إخْدَامٍ', #11
u'إخدام': u'إخْدَامِ', #11
u'إخدام': u'إخْدَامَ', #15
u'إخدام': u'إخْدَامُ', #16
u'إخدام': u'إخْدَامٌ', #5
u'إخدامه': u'إخْدَامِهِ', #1
u'إخدامه': u'إخْدَامُهُ', #8
u'إخدامها': u'إخْدَامِهَا', #2
u'إخدامها': u'إخْدَامَهَا', #3
u'إخدامها': u'إخْدَامُهَا', #53
u'إخدامهما': u'إخْدَامُهُمَا', #1
u'أخدج': u'أَخْدَجَ', #1
u'أخدجت': u'أَخَدَجَتْ', #1
u'أخدجت': u'أَخْدَجَتْ', #1
u'اخدرى': u'اخدرى', #1
u'آخذ': u'آخِذً', #1
u'اخذ': u'اخذ', #2
u'أخذانى': u'أَخَذَانِى', #1
u'أخذتنى': u'أَخَذْتَنِى', #2
u'أخذتنى': u'أَخَذَتْنِى', #3
u'أخذو': u'أَخْذُو', #1
u'آخر': u'آخِرً', #1
u'اخر،': u'اخر،', #1
u'إخراب': u'إخْرَابِ', #2
u'إخرابه': u'إخْرَابَهُ', #1
u'إخراق': u'إخْرَاقٌ', #1
u'إخراق': u'إخْرَاقِ', #1
u'إخراق': u'إخْرَاقُ', #3
u'إخراقا': u'إخْرَاقًا', #3
u'أخراوان': u'أُخْرَاوَانِ', #1
u'أخراوين،': u'أُخْرَاوَيْنِ،', #1
u'أخراوين': u'أُخْرَاوَيْنِ', #9
u'آخرتى': u'آخِرَتِى', #1
u'أخرجتنى': u'أَخْرَجْتَنِى', #1
u'أخرجنى': u'أَخْرَجَنِى', #3
u'اخرجوني': u'اخْرِجُونِي', #1
u'اخرجى': u'اخْرُجِى', #1
u'أخرجى': u'أَخْرِجِى', #3
u'اخره،': u'اخره،', #1
u'آخرهموالوجه': u'آخِرِهِمْوَالْوَجْهُ', #1
u'أخروان': u'أَخْرَوَانِ', #1
u'أخرون': u'أَخَّرُونِ', #1
u'آخرونليقولن': u'آخَرُونَلَيَقُولَنَّ', #1
u'أخرىSالشهادة': u'أُخْرَىSالشّهَادَةُ', #1
u'اخرى': u'اخرى', #1
u'آخرية': u'آخِرِيَّةٌ', #1
u'آخرية': u'آخِرِيَّةُ', #1
u'آخرية': u'آخِرِيَّةِ', #1
u'آخرية': u'آخِرِيَّةً', #2
u'آخريته': u'آخِرِيَّتِهِ', #1
u'أخرين': u'أخرين', #1
u'آخرينفذلك': u'آخَرِينَفَذَلِكَ', #1
u'أخزم،': u'أخزم،', #1
u'أخزم': u'أَخَزَمَ', #1
u'أخزم،': u'أَخْزَمَ،', #12
u'أخزم': u'أَخْزَمَ', #15
u'أخزم': u'أخزم', #4
u'اخس': u'اخْسَ', #2
u'أخساء': u'أَخِسَّاءَ', #1
u'أخساء': u'أَخِسَّاءِ', #1
u'أخسمه': u'أخسمه', #1
u'اخسئوا': u'اخْسَئُوا', #13
u'اخشنوا': u'اخْشَنُوا', #1
u'أخص': u'أَخَصًّ', #2
u'إخصاء': u'إخْصَاءٌ', #1
u'إخصاء': u'إخْصَاءَ', #3
u'إخصاء': u'إِخْصَاءَ', #3
u'إخصاء': u'إِخْصَاءِ', #3
u'إخصاء': u'إخْصَاءِ', #6
u'إخصاء': u'إخْصَاءُ', #7
u'أخصائه': u'أَخِصَّائِهِ', #1
u'إخصائه': u'إخْصَائِهِ', #1
u'أخصريته': u'أَخْصَرِيَّتِهِ', #2
u'اخضل': u'اخْضَلَّ', #2
u'أخضل': u'أَخْضَلَ', #5
u'اخضلت': u'اِخْضَلَّتْ', #1
u'اخضلت': u'اخْضَلّتْ', #2
u'اخضلت': u'اخْضَلَّتْ', #2
u'أخضلوا': u'أَخْضَلّوا', #1
u'أخضلوا': u'أَخْضَلُوا', #10
u'أخطأوا': u'أَخْطَأُوا', #1
u'أخطأوا': u'أَخْطَأُوُا', #1
u'اخطئوا': u'اخْطَئُوا', #1
u'إخفار': u'إخْفَارِ', #1
u'إخفار': u'إِخْفَارُ', #1
u'إخفار': u'إخْفَارٌ', #3
u'إخفار': u'إخْفَارُ', #3
u'إخفارا': u'إخْفَارًا', #1
u'إخفاري': u'إخْفَارِي', #2
u'اخفضى': u'اخْفِضِى', #1
u'أخقوق': u'أُخْقُوقٍ', #1
u'إخلاق': u'إخْلَاقٍ', #1
u'إخلاق': u'إخْلَاقُ', #2
u'إخلاق': u'إخْلَاقِ', #4
u'إخلاقا': u'إخْلَاقًا', #1
u'أخلفنى': u'أَخْلَفَنِى', #3
u'إخماص': u'إخْمَاصُ', #2
u'إخمال': u'إخْمَالَ', #1
u'إخمال': u'إخْمَالُ', #1
u'أخميم': u'أَخْمِيمَ', #1
u'إخميم': u'إخْمِيمَ', #1
u'إخنا': u'إخْنَا', #1
u'أخنأ': u'أَخْنَأُ', #2
u'أخنوخ': u'أَخْنُوخَ', #1
u'أخنوخ': u'أَخْنُوخُ', #1
u'أخنوخ': u'أخنوخ', #4
u'إخواته،': u'إخواته،', #1
u'أخواتى': u'أَخَوَاتِى', #1
u'اخوانه': u'اخوانه', #1
u'اخوانه،': u'اخوانه،', #1
u'إخوانى': u'إِخْوَانِى', #6
u'أخواها': u'أَخَوَاهًا', #1
u'إخوتاه': u'إخْوَتَاهُ', #1
u'إخوتاه': u'إخْوَتَاهْ', #1
u'إخوتاه،': u'إِخْوَتَاهُ،', #1
u'إخوتاه': u'إِخْوَتَاهُ', #2
u'إخوتاه': u'إِخْوَتَاهْ', #2
u'أخوتى': u'أُخْوَتِى', #1
u'إخوتى': u'إِخْوَتِى', #2
u'أخوفنى': u'أَخْوَفُنِى', #2
u'أخولاS': u'أَخْوَلَاS', #1
u'أخوهما': u'أَخُوهُمًا', #1
u'أخى': u'أخَى', #1
u'أخى؟': u'أَخِى؟', #1
u'أخى': u'أخى', #3
u'أخى': u'أُخَىَّ', #3
u'أخى': u'أَخِى', #339
u'أخيات': u'أُخَيَّاتٌ', #4
u'أخيالهموالوجه': u'أَخْيَالَهُمْوَالْوَجْهُ', #1
u'أخيبس': u'أُخَيْبِسَ', #1
u'أخية': u'أَخِيَّةُ', #1
u'أخية': u'أُخَيّة', #1
u'أخية': u'أُخَيَّةَ', #1
u'أخية': u'أُخَيَّةِ', #1
u'أخية،': u'أُخَيَّةُ،', #1
u'أخية،': u'أُخَيَّةِ،', #1
u'أخية': u'أُخَيَّةُ', #12
u'أخية': u'أُخَيّةُ', #6
u'أخيس': u'أَخِيسُ', #5
u'أخيضر': u'أُخَيْضِرُ', #1
u'أخيفش': u'أُخَيْفِشُ', #1
u'أخيكا': u'أَخِيكَا', #1
u'أخيمر': u'أخيمر', #1
u'أخيمر': u'أُخَيْمِرَ', #1
u'اد': u'اد', #2
u'إدا': u'إدًّا', #1
u'أدا': u'أَدَا', #6
u'أداخ': u'أداخ', #1
u'أداخ': u'أَدَاخَ', #1
u'إدار': u'إدَارٍ', #2
u'أداريهمو': u'أُدَارِيهُمُو', #1
u'ادان': u'ادَّانَ', #50
u'ادانا': u'ادَّانَا', #1
u'اداناه': u'ادَّانَاهُ', #1
u'أدانة': u'أَدَانَة', #1
u'ادانه': u'ادَّانَهُ', #4
u'إداوتى': u'إِدَاوَتِى', #1
u'اداوى': u'اداوى', #1
u'أدائ': u'أَدَائِ', #1
u'إدايته': u'إِدَايَته', #1
u'ادب': u'ادب', #1
u'أدبرى': u'أَدْبِرِى', #1
u'ادبست': u'ادبست', #1
u'آدة': u'آدة', #1
u'آدة': u'آدَةَ', #1
u'أدتان': u'أَدَّتَانِ', #1
u'ادتان': u'ادْتَانَ', #1
u'ادترع': u'ادْتَرَعَ', #1
u'ادتين': u'ادْتَيَنَ', #1
u'أدحية': u'أَدِحْيَةً', #1
u'إدخاره': u'إدْخَارُهُ', #2
u'ادخال': u'ادِّخَالُ', #1
u'أدخلتمانى': u'أَدْخَلْتُمَانِى', #1
u'أدخلتمونى': u'أَدْخَلْتُمُونِى', #1
u'أدخلتنى': u'أَدْخَلَتْنِى', #1
u'أدخلمالك': u'أَدْخَلَمَالِكٌ', #1
u'أدخلنى': u'أَدْخَلَنِى', #1
u'أدخلنى': u'أَدْخِلْنِى', #3
u'أدخلنيها': u'أَدْخِلْنِيهَا', #2
u'أدخلى': u'أَدْخِلِى', #2
u'ادخلى': u'ادْخُلِى', #2
u'آدد': u'آدَدَ', #1
u'ادد': u'ادد', #1
u'اددرع': u'ادْدَرَعَ', #1
u'آدر': u'آدَر', #1
u'آدر': u'آدَرٌ', #1
u'آدر': u'آدُرُ', #1
u'آدر،': u'آدَرُ،', #1
u'آدر': u'آدَرُ', #10
u'ادرءوا': u'ادْرَءُوا', #119
u'إدرادا': u'إدْرَادًا', #1
u'إدران': u'إدران', #1
u'إدرة': u'إدْرَةَ', #1
u'آدرد': u'آدرد', #1
u'أدرد': u'أَدْرَدَ', #1
u'أدرد': u'أَدْرَدُ', #1
u'أدركتنى': u'أَدْرَكَتْنِى', #1
u'أدركنى': u'أَدْرِكْنِى', #1
u'أدركنى': u'أَدْرَكَنِى', #9
u'ادركهم': u'ادركهم', #1
u'أدريس': u'أَدَرِيسَ', #1
u'إدريسا': u'إدْرِيسَا', #1
u'إدريسقوله': u'إِدْرِيسُقَوْلُهُ', #1
u'ادعا': u'ادَّعَا', #1
u'أدعج': u'أَدْعَج', #1
u'أدعج،': u'أَدْعَجَ،', #1
u'أدعج': u'أَدْعَجَ', #10
u'أدعج': u'أَدْعَجُ', #10
u'ادعو': u'ادعو', #2
u'ادعونى': u'ادْعُونِى', #1
u'إدغار': u'إِدْغَارِ', #1
u'أدفر': u'أَدْفَرَ', #1
u'أدفر': u'أَدْفَرُ', #2
u'ادفنونى': u'ادْفِنُونِى', #4
u'ادكار': u'ادِّكَارٌ', #1
u'أدلات': u'أَدِلَّاتِ', #1
u'إدلاع': u'إدْلَاعَ', #1
u'إدلاع': u'إدْلَاعُ', #1
u'إدلال': u'إدْلَالِ', #1
u'إدلال': u'إدْلَالٌ', #2
u'إدلال': u'إدْلَالَ', #4
u'إدلالا': u'إدْلَالًا', #5
u'إدلاله': u'إدْلَالُهُ', #1
u'إدلاله': u'إدْلَالِهِ', #2
u'إدلالهم': u'إدْلَالِهِمْ', #2
u'ادللني': u'ادْلُلْنِي', #1
u'ادللني': u'اُدْلُلْنِي', #3
u'أدلم': u'أَدْلَمْ', #1
u'أدلم': u'أَدْلَمَ', #3
u'أدلم': u'أَدْلَمُ', #3
u'آدلين': u'آدِلِينَ', #1
u'آدما': u'آدَمَا', #1
u'آدمأما': u'آدَمَأَمَا', #1
u'آدمقوله': u'آدَمَقَوْلُهُ', #1
u'آدمى': u'آدَمِىٌّ', #3
u'آدمى': u'آدَمِىٍّ', #6
u'إدمين': u'إدْمَيْنِ', #1
u'ادناك': u'ادناك', #2
u'ادناه': u'ادناه', #1
u'أدننى': u'أَدْنِنِى', #3
u'ادنني': u'اُدْنُنِي', #4
u'ادنه،': u'ادْنُهْ،', #1
u'ادنه،': u'ادْنُهُ،', #2
u'ادنه': u'اُدْنُهُ', #3
u'ادنه': u'ادْنُهُ', #4
u'ادنه': u'ادْنُهْ', #40
u'ادنو': u'ادْنُو', #1
u'ادنوه': u'ادْنُوهُ', #1
u'ادنى': u'ادْنِى', #1
u'ادهان': u'ادِّهَانٌ', #1
u'ادهان': u'ادِّهَانِ', #1
u'ادهان': u'ادِّهَانٍ', #4
u'ادهانه': u'ادِّهَانِهِ', #3
u'ادوا': u'ادُوا', #1
u'أدوأ': u'أَدْوَأُ', #7
u'أدونيته': u'أَدْوَنِيَّتَهُ', #1
u'آدى': u'آدَى', #1
u'أديتيني': u'أَدَّيْتِينِي', #1
u'ادين': u'ادين', #1
u'اذ': u'اذ', #1
u'اذا': u'اذا', #3
u'إذاأجمع': u'إِذَاأَجْمَعَ', #1
u'آذاد،': u'آذَادَ،', #1
u'أذار': u'أَذَارٍ', #1
u'أذار': u'أَذَارَ', #1
u'إذالة': u'إذَالَةٍ', #1
u'إذالة': u'إذَالَةِ', #1
u'إذالنبي': u'إذالنبي', #1
u'آذانى': u'آذَانِى', #5
u'اذاهم': u'اذاهم', #1
u'أذاود': u'أَذَاوُدٌ', #2
u'إذائه': u'إذَائِهِ', #1
u'إذاية': u'إذَايَةٍ', #1
u'إذاية': u'إذَايَةُ', #12
u'إذاية': u'إذَايَةِ', #12
u'إذاية': u'إذَايَةٌ', #18
u'إذاية': u'إِذَايَةِ', #2
u'إذاية': u'إذَايَةً', #4
u'إذاية': u'إذَايَةَ', #4
u'إذايته': u'إذَايَتَهُ', #1
u'إذايته': u'إذَايَتُهُ', #1
u'إذايته': u'إَذايَتِهِ', #2
u'إذايته': u'إِذَايَتَهُ', #2
u'إذايته': u'إِذَايَتِهِ', #2
u'إذايته': u'إذَايَتِهِ', #6
u'إذايتها': u'إذايتها', #1
u'إذايتها': u'إذَايَتَهَا', #1
u'إذايتها': u'إذَايَتُهَا', #1
u'إذايتهم': u'إذَايَتِهِمْ', #2
u'إذايتهما': u'إذَايَتِهِمَا', #4
u'أذبة': u'أَذِبَّةٌ', #6
u'إذخر': u'إذْخَرُ', #1
u'إذخر': u'إذْخِرَ', #1
u'إذخر': u'إذْخِرٌ', #10
u'إذخر': u'إِذْخِرٍ', #2
u'إذخر': u'إذْخِرٍ', #4
u'إذخر': u'إِذْخِرٌ', #9
u'إذخرا': u'إذْخِرًا', #5
u'إذخرا': u'إِذْخِرًا', #7
u'إذخرة': u'إذْخِرَةٍ', #2
u'إذخرة': u'إذْخِرَةٌ', #6
u'إذخرها': u'إذْخِرَهَا', #1
u'إذخرها': u'إذْخِرُهَا', #1
u'أذرعاتالوجه': u'أَذْرُعَاتَالْوَجْهُ', #1
u'أذرماه': u'أذرماه', #1
u'اذرونى': u'اذْرُونِى', #1
u'آذغاغ': u'آذغاغ', #1
u'أذغاغ': u'أَذْغَاغِ', #1
u'أذفر': u'أَذْفَرَ', #1
u'أذفر': u'أَذْفَرْ', #1
u'أذفر': u'أَذْفَرُ', #13
u'إذفونش': u'إذفونش', #1
u'إذكار': u'إذْكَارِ', #1
u'إذكاره': u'إذْكَارَهُ', #1
u'أذكرتنيها': u'أَذْكَرْتَنِيهَا', #4
u'أذكرتيني': u'أَذْكَرْتِينِي', #1
u'أذكركمف': u'أذكِّرُكُمف', #1
u'أذكرنى': u'أَذْكَرَنِى', #4
u'أذكرنيها': u'أَذْكَرَنِيهَا', #1
u'أذلفته': u'أَذْلَفَتْهُ', #1
u'أذلم': u'أَذْلَمَ', #1
u'أذلم': u'أَذْلَمُ', #1
u'إذنS': u'إذَنْS', #1
u'اذن': u'اذن', #1
u'أذناى': u'أُذُنَاىَ', #20
u'أذنة': u'أَذَنَةً', #1
u'أذنة': u'أَذَنَةٌ', #1
u'أذنة': u'أَذَنَةَ', #1
u'آذنتمونى': u'آذَنْتُمُونِى', #10
u'آذنتنى': u'آذَنْتَنِى', #1
u'آذنونى': u'آذِنُونِى', #1
u'إذنى': u'إِذْنِى', #1
u'أذنى': u'أُذُنَىَّ', #8
u'أذنى': u'أُذُنِى', #9
u'إذهب': u'إذْهَبْ', #1
u'اذهبى': u'اذَهَبِى', #1
u'اذهبى': u'اذْهَبِى', #19
u'أذواء': u'أَذْوَاءَ', #1
u'أذؤب': u'أَذْؤُبٌ', #1
u'أذوه': u'أَذُوهُ', #2
u'أذينة': u'أذينة', #1
u'أذينة': u'أُذَيْنَةٌ', #1
u'أذينة،': u'أُذَيْنَةَ،', #2
u'أذينة': u'أُذَيْنَةَ', #25
u'إراءة': u'إرَاءَةٌ', #1
u'إراءة': u'إرَاءَةً', #3
u'إراءة': u'إرَاءَةَ', #5
u'إراءة': u'إرَاءَةِ', #5
u'إراءة': u'إرَاءَةُ', #7
u'إراءته': u'إرَاءَتِهِ', #2
u'إراءته': u'إرَاءَتُهُ', #4
u'إراءتها': u'إرَاءَتُهَا', #1
u'إراءتها': u'إرَاءَتِهَا', #3
u'أرآد': u'أَرْآدٌ', #1
u'أرأد': u'أَرَأَدَ', #1
u'أرأد': u'أَرَأْد', #1
u'إراد': u'إراد', #1
u'اراد': u'اراد', #2
u'أرأدت': u'أَرَأَدَتْ', #1
u'إرادتهموه': u'إرَادَتُهُمُوهُ', #1
u'أرادمالك': u'أَرَادَمَالِكٌ', #1
u'أرادنى': u'أَرَادَنِى', #1
u'أرادونى': u'أَرَادُونِى', #1
u'أرادى': u'أُرَادَى', #1
u'إراش': u'إرَاشٍ', #2
u'إراش': u'إرَاشَ', #4
u'إراش': u'إرَاشُ', #4
u'إراش': u'إرَاشِ', #7
u'إراشة': u'إرَاشَةً', #1
u'إراشة': u'إرَاشَةُ', #1
u'إراشة': u'إرَاشَةَ', #13
u'إراشيا': u'إرَاشِيّا', #1
u'أرانى': u'أَرَانِىَ', #1
u'أرانى': u'أُرَانِى', #11
u'أرانى': u'أَرَانِى', #8
u'أراهط': u'أَرَاهِطَ', #1
u'أرائيه': u'أُرَائِيه', #1
u'إرباح': u'إرْبَاحٌ', #1
u'إرباح': u'إرْبَاحٍ', #2
u'إربة': u'إرْبَةً', #1
u'إربة': u'إِرْبَةٍ', #1
u'إربة': u'إرْبَةٍ', #5
u'أربحنى': u'أَرْبَحَنِى', #1
u'اربخوريم': u'اربخوريم', #1
u'إربد': u'إربد', #1
u'إربد،': u'إِرْبِدٍ،', #1
u'أربع': u'أَرْبَعً', #2
u'اربعة': u'اربعة', #1
u'اربعين': u'ارْبَعِينَ', #1
u'اربعين': u'ارْبَعِينِ', #1
u'أربعينه': u'أَرْبَعِينِهِ', #5
u'أربما': u'أَرُبَّمَا', #1
u'أربيل': u'أَرْبِيلَ', #1
u'أربيل': u'أَرْبِيلِ', #1
u'آرة': u'آرَةَ', #1
u'إرة': u'إرَةٍ', #1
u'أرت': u'أَرَتًّ', #1
u'إرتابوا': u'إرْتَابُوا', #1
u'إرتاجا': u'إرْتَاجًا', #2
u'ارتاض': u'ارْتَاضَ', #2
u'ارتاضت': u'ارْتَاضَتْ', #1
u'إرتاما': u'إرْتَامًا', #2
u'ارتآها': u'ارْتَآهَا', #1
u'إرتباط': u'إرتباط', #1
u'ارتباكة': u'ارْتِبَاكَةٌ', #1
u'ارتبع': u'ارْتَبَعَ', #1
u'ارتبعوا': u'ارْتَبَعُوا', #1
u'ارتتاق': u'ارْتِتَاقَ', #3
u'ارتتجا': u'ارْتَتَجَا', #1
u'ارتتق': u'ارْتَتَقَ', #9
u'ارتث': u'ارتُثَّ', #1
u'ارتث': u'اُرْتُثّ', #1
u'ارتث': u'اُرْتُثَّ', #17
u'ارتث': u'ارْتَثَّ', #5
u'ارتثا': u'ارْتَثَّا', #1
u'ارتثا': u'اُرْتُثَّا', #1
u'ارتثاث': u'ارْتِثَاثٌ', #1
u'ارتثاثا': u'ارْتِثَاثًا', #3
u'ارتجاجة': u'ارْتِجَاجَةً', #1
u'ارتجاز': u'ارْتِجَازُ', #8
u'ارتجاس': u'ارْتِجَاسِ', #1
u'أرتجز': u'أَرْتَجِز', #1
u'ارتجز،': u'ارْتَجَزَ،', #1
u'ارتجز': u'ارْتَجَزَ', #4
u'ارتجزوا': u'ارْتَجَزُوا', #1
u'ارتجس': u'ارْتَجَسَ', #1
u'ارتجست': u'ارْتَجَسَتْ', #1
u'ارتجع': u'ارْتَجَعْ', #1
u'ارتجع': u'ارْتَجِعْ', #1
u'ارتجع': u'اُرْتُجِعَ', #1
u'ارتجع': u'ارْتَجَعَ', #63
u'ارتجعا': u'ارْتَجَعَا', #1
u'ارتجعت': u'اُرْتُجِعَتْ', #1
u'ارتجعت': u'ارْتَجَعْت', #5
u'ارتجعت': u'ارْتَجَعْتُ', #5
u'أرتجعتك': u'أَرْتَجَعْتُكِ', #1
u'ارتجعتك': u'ارْتَجَعْتُكِ', #5
u'ارتجعتك': u'ارْتَجَعْتُك', #8
u'ارتجعتها': u'ارْتَجَعْتهَا', #18
u'ارتجعتها': u'ارْتَجَعْتُهَا', #21
u'ارتجعه': u'ارْتَجِعْهُ', #1
u'ارتجعه': u'ارْتَجَعَهُ', #3
u'ارتجعها': u'ارْتَجِعْهَا', #6
u'ارتجعها': u'ارْتَجَعَهَا', #82
u'ارتجعوا': u'ارْتَجَعُوا', #1
u'ارتحلنى': u'ارْتَحَلَنِى', #1
u'ارتخص': u'ارْتَخَصَ', #1
u'ارتداف': u'ارْتِدَافُ', #1
u'ارتداف': u'ارْتِدَافِ', #1
u'ارتدف': u'اُرْتُدِفَ', #2
u'ارتدف': u'ارْتَدَفَ', #4
u'ارتدفت': u'ارْتَدَفْتُ', #3
u'ارتدمت': u'ارْتَدَمَتْ', #2
u'ارتص': u'ارْتَصَّ', #1
u'ارتصاص': u'ارْتِصَاصِ', #1
u'ارتصاصهم': u'ارْتِصَاصِهِمْ', #1
u'ارتضاع': u'ارْتِضَاعٌ', #1
u'ارتضاع': u'ارْتِضَاعُ', #3
u'ارتضاع': u'ارْتِضَاعِ', #3
u'ارتضاعة': u'ارْتِضَاعَةِ', #1
u'ارتضاعه': u'ارْتِضَاعِهِ', #13
u'ارتضاعه': u'ارْتِضَاعَهُ', #2
u'ارتضاعه': u'ارْتِضَاعُهُ', #3
u'ارتضاعها': u'ارْتِضَاعُهَا', #4
u'ارتضاعها': u'ارْتِضَاعِهَا', #5
u'ارتضاعهما': u'ارْتِضَاعِهِمَا', #1
u'ارتضخ': u'ارْتَضَخَ', #1
u'ارتضع': u'ارْتَضَعْ', #1
u'ارتضع': u'ارْتَضِعْ', #1
u'ارتضع': u'ارْتَضَعَ', #136
u'ارتضع': u'اُرْتُضِعَ', #3
u'ارتضعا': u'ارْتَضِعَا', #1
u'ارتضعا': u'ارْتَضَعَا', #12
u'ارتضعت': u'اُرْتُضِعَتْ', #3
u'ارتضعت': u'ارْتَضَعَتْ', #63
u'ارتضعتا': u'ارْتَضَعَتَا', #2
u'ارتضعته': u'ارْتَضَعَتْهُ', #1
u'ارتضعن': u'ارْتَضَعْنَ', #2
u'ارتضعه': u'ارْتَضَعَهُ', #1
u'ارتعته': u'ارْتَعَتْهُ', #1
u'ارتعجت': u'ارتعجت', #1
u'ارتفاض': u'ارْتِفَاضِ', #14
u'ارتفاض': u'ارْتِفَاضُ', #4
u'ارتفاض': u'ارْتِفَاضَ', #6
u'ارتفاضه': u'ارْتِفَاضِهِ', #1
u'ارتفاضها': u'ارْتِفَاضَهَا', #5
u'ارتفاق': u'ارْتِفَاقَ', #1
u'ارتفاق': u'ارْتِفَاقِ', #15
u'ارتفاق': u'ارْتِفَاقٍ', #24
u'ارتفاق': u'ارْتِفَاقٌ', #40
u'ارتفاق': u'ارْتِفَاقُ', #9
u'ارتفاقا': u'ارْتِفَاقًا', #31
u'ارتفاقه': u'ارْتِفَاقُهُ', #2
u'ارتفاقه': u'ارْتِفَاقَهُ', #3
u'ارتفاقه': u'ارْتِفَاقِهِ', #4
u'ارتفاقهم': u'ارْتِفَاقَهُمْ', #1
u'ارتفاقهم': u'ارْتِفَاقِهِمْ', #1
u'ارتفض': u'اُرْتُفِضَ', #2
u'ارتفض': u'ارْتَفَضَ', #27
u'ارتفض': u'ارْتُفِضَ', #4
u'ارتفضا': u'ارْتَفَضَا', #1
u'ارتفضت': u'ارْتَفَضَتْ', #11
u'ارتفضت': u'ارْتُفِضَتْ', #7
u'ارتفعى': u'ارْتَفِعِى', #3
u'ارتفق': u'ارْتَفِقْ', #2
u'ارتفق': u'ارْتَفَقَ', #48
u'ارتفقت': u'ارْتَفَقَتْ', #1
u'ارتفقت': u'ارْتَفَقْتَ', #1
u'ارتفقت': u'ارْتَفَقْتُ', #1
u'ارتفقت': u'ارْتَفَقْت', #3
u'ارتفقوا': u'ارْتَفَقُوا', #1
u'أرتمت': u'أَرْتَمْت', #1
u'أرتمت': u'أَرْتَمْتُ', #1
u'ارتمس': u'اُرْتُمِسَ', #1
u'أرتمى': u'أَرْتَمِى', #1
u'ارتهاب': u'ارْتِهَابِ', #1
u'ارتهناه': u'ارْتَهَنَاهُ', #7
u'ارتهنته': u'ارْتَهَنَتْهُ', #1
u'ارتهنته': u'ارْتَهَنْتَهُ', #1
u'ارتهنته': u'ارْتَهَنْتُهُ', #5
u'ارتهنته': u'ارْتَهَنْته', #6
u'ارتهنتها': u'ارْتَهَنْتُهَا', #1
u'ارتهنتها': u'ارْتَهَنْتهَا', #5
u'ارتهنتهما': u'ارْتَهَنْتُهُمَا', #2
u'ارتهنه': u'ارْتَهِنْهُ', #1
u'ارتهنه': u'ارْتَهَنَهُ', #42
u'ارتهنها': u'ارْتَهَنَهَا', #22
u'ارتهنهما': u'ارْتَهَنَهُمَا', #2
u'ارتهنوه': u'ارْتَهَنُوهُ', #1
u'ارتوبستاند': u'ارتوبستاند', #1
u'أرتوى': u'أرتوى', #1
u'أرتوى': u'أَرْتَوِى', #1
u'ارتياض': u'ارْتِيَاضِ', #1
u'ارتياضه': u'ارْتِيَاضِهِ', #1
u'إرثاء': u'إرْثَاءُ', #1
u'آرثخ': u'آرثخ', #1
u'إرثيهما': u'إرْثَيْهِمَا', #1
u'إرجع': u'إرْجِعْ', #1
u'ارجعون': u'ارْجِعُونِ', #6
u'ارجعى': u'ارْجِعِى', #18
u'إرحاق': u'إِرْحَاقَ', #1
u'ارحكم': u'ارحكم', #1
u'ارحمنى': u'ارْحَمْنِى', #3
u'ارحمون': u'ارْحَمُونِ', #1
u'أرحنى': u'أَرِحْنِى', #1
u'أرحية': u'أَرْحِيَةً', #3
u'أرحيتهم': u'أَرْحِيَتِهِمْ', #1
u'إرخاص': u'إرْخَاصٌ', #1
u'إرخاص': u'إِرْخَاصٍ', #1
u'آرد': u'آرد', #1
u'آرد': u'آرِدّ', #5
u'إردب': u'إِرْدَبٌّ', #1
u'إردب': u'إِرْدَبُّ', #1
u'إردب': u'إرْدَبٍّ', #187
u'إردب': u'إِرْدَبٍّ', #2
u'إردب': u'إِرْدَبِّ', #2
u'إردب': u'إرْدَبَّ', #23
u'إردب': u'إرْدَبّ', #3
u'إردب': u'إرْدَبِّ', #67
u'إردب': u'إرْدَبٌّ', #7
u'إردب': u'إرْدَبُّ', #9
u'أردبا': u'أَرْدَبًّا', #1
u'إردبا': u'إِرْدَبًّا', #1
u'إردبا': u'إرْدَبًّا', #98
u'إردبان': u'إرْدَبَّانِ', #2
u'إردبه': u'إرْدَبِّهِ', #1
u'إردبها': u'إِرْدَبَّهَا', #3
u'إردبي': u'إرْدَبَّيْ', #1
u'إردبين': u'إرْدَبَّيْنِ', #30
u'آردتر': u'آردتر', #1
u'أردتمونى': u'أَرْدَتُمُونِى', #1
u'آردده': u'آردده', #1
u'اردرم': u'اردرم', #2
u'أردشير': u'أردشير', #2
u'أردشير': u'أَرْدَشِيرَ', #3
u'أردفنى': u'أَرْدِفْنِى', #1
u'أردفنى': u'أَرْدَفَنِى', #9
u'آردكند': u'آردكند', #1
u'أردوان': u'أردوان', #1
u'ارريسمان': u'ارريسمان', #1
u'أرزإ': u'أُرْزَإِ', #1
u'إرزاق': u'إرْزَاقٌ', #1
u'إرزاقه': u'إرْزَاقُهُ', #1
u'ارزانى': u'ارزانى', #1
u'ارزقناها': u'اُرْزُقْنَاهَا', #3
u'ارزقنى': u'ارْزُقْنِى', #2
u'أرسال': u'أَرْسَالُ', #1
u'أرسالا': u'أرسالًا', #1
u'أرسالا،': u'أَرْسَالا،', #1
u'أرسالا،': u'أَرْسَالًا،', #1
u'أرسالا': u'أَرْسَالًا', #31
u'أرسالا': u'أَرْسَالاً', #5
u'أرسح': u'أَرْسَحَ', #1
u'أرسطا': u'أَرْسَطَا', #1
u'أرسطا': u'أَرِسْطَا', #2
u'أرسطاطاليس': u'أَرِسْطَاطَالِيسُ', #1
u'أرسطاطاليس': u'أرسطاطاليس', #2
u'أرسطوطاليس': u'أَرِسْطُوطَالِيس', #1
u'أرسطوطاليس': u'أَرِسْطُوطَالِيسُ', #1
u'أرسلتمونى': u'أَرْسَلْتُمُونِى', #1
u'أرسلتنى': u'أَرْسَلْتَنِى', #2
u'أرسلتنى': u'أَرْسَلَتْنِى', #5
u'ارسلته': u'ارسلته', #1
u'آرسلك': u'آرْسَلَكَ', #2
u'أرسلننى': u'أَرْسَلْنَنِى', #4
u'أرسلنى': u'أَرْسِلْنِى', #2
u'أرسلنى': u'أَرْسَلَنِى', #42
u'أرسلونى': u'أَرْسَلُونِى', #5
u'أرسلى': u'أَرْسِلِى', #4
u'أرشديته': u'أَرْشَدِيَّتِهِ', #1
u'أرشديته': u'أَرْشَدِيَّتُهُ', #2
u'أرشديته': u'أَرْشَدِيَّتَهُ', #7
u'أرشديتها': u'أَرْشَدِيَّتُهَا', #1
u'إرشيا': u'إرَشِيّا', #1
u'أرض': u'أَرْضً', #1
u'ارضا': u'ارضاً', #1
u'ارضحي': u'ارْضَحِي', #1
u'ارضخى': u'ارضخى', #1
u'ارضخى': u'ارْضَخِى', #3
u'أرضعتنى': u'أَرْضَعَتْنِى', #13
u'أرضعتيني': u'أَرْضَعْتِينِي', #1
u'أرضعتيه': u'أَرْضَعْتِيهِ', #3
u'أرضعنى': u'أَرْضَعَنِى', #4
u'أرضعونى': u'أَرْضَعُونِى', #1
u'آرضوا': u'آرَضُوا', #1
u'أرطأة': u'أَرْطَأةَ', #1
u'أرطأة': u'أَرَطْأَة', #1
u'أرطاة،': u'أَرْطَاةُ،', #1
u'ارطاة': u'ارطاة', #1
u'أرطأة': u'أَرْطَأَةُ', #10
u'أرطأة': u'أرطأة', #11
u'أرطاة': u'أَرْطَاة', #15
u'أرطأة': u'أَرْطَأَةَ', #19
u'أرطأة': u'أَرَطْأَةَ', #2
u'أرطأة،': u'أَرْطَأَةُ،', #2
u'أرطاة،': u'أَرْطَاةَ،', #26
u'أرطاة': u'أَرْطَاةَ', #302
u'أرطأة،': u'أَرْطَأَةَ،', #32
u'أرطأة،': u'أرطأة،', #5
u'أرطاة': u'أرطاة', #7
u'أرطاة': u'أَرْطَاةُ', #9
u'أرطبون': u'أَرْطَبُونَ', #1
u'أرطى': u'أَرْطَى', #1
u'أرعوفتها': u'أُرْعُوفَتِهَا', #1
u'إرغاب': u'إرْغَابِ', #2
u'أرغاف': u'أَرْغَافٍ', #1
u'أرغوان': u'أُرْغُوَانُ', #1
u'أرغيان': u'أَرْغِيَانَ', #1
u'إرفاثا': u'إرْفَاثًا', #1
u'أرفاغه': u'أَرْفَاغِهِ', #1
u'أرفة': u'أُرْفَةٍ', #1
u'أرفخشاذ': u'أرفخشاذ', #1
u'أرفخشد': u'أرفخشد', #1
u'أرفخشذ': u'أرْفخْشَذ', #1
u'أرفخشذ،': u'أَرْفَخْشَذَ،', #1
u'ارفخشذ': u'ارْفَخْشَذَ', #1
u'أرفخشذ': u'أرْفَخْشَذ', #5
u'أرفخشذ': u'أَرْفَخْشَذَ', #5
u'ارفضت': u'ارْفَضَّتْ', #1
u'ارفضت': u'ارْفَضّتْ', #3
u'ارفعونى': u'ارْفَعُونِى', #2
u'أرقأ': u'أَرْقَأَ', #1
u'إرقاب': u'إرْقَابٍ', #2
u'إرقابا': u'إرْقَابًا', #1
u'إرقابه': u'إرْقَابُهُ', #1
u'إرقابها': u'إرْقَابُهَا', #3
u'إرقابهما': u'إرْقَابُهُمَا', #1
u'ارقاط': u'ارْقَاطّ', #1
u'إرقاق': u'إرْقَاقَ', #26
u'إرقاق': u'إرْقَاقُ', #43
u'إرقاق': u'إرْقَاقِ', #52
u'إرقاق': u'إرْقَاقٍ', #7
u'إرقاقا': u'إرْقَاقًا', #1
u'إرقاقه': u'إرْقَاقَهُ', #2
u'إرقاقه': u'إرْقَاقِهِ', #23
u'إرقاقه': u'إرْقَاقُهُ', #29
u'إرقاقها': u'إرْقَاقُهَا', #13
u'إرقاقها': u'إرْقَاقِهَا', #6
u'إرقاقهم': u'إرْقَاقِهِمْ', #2
u'إرقاقهم': u'إرْقَاقُهُمْ', #3
u'إرقاقهما': u'إرْقَاقُهُمَا', #1
u'إرقاقهما': u'إرْقَاقِهِمَا', #1
u'إرقال': u'إِرْقال', #1
u'إرقال': u'إرْقَالٌ', #2
u'إرقال': u'إرْقَالَ', #2
u'أرقبتكه': u'أَرْقَبْتُكَهُ', #2
u'أرقبتكها': u'أَرْقَبْتُكَهَا', #2
u'اركسهما': u'ارْكُسْهُمَا', #1
u'آرم': u'آرُمّ', #4
u'إرما': u'إرَمًا', #1
u'أرماث': u'أَرْمَاثٍ', #2
u'أرماكا': u'أَرْمَاكًا', #2
u'إرمالا': u'إرْمَالًا', #1
u'أرمائيل': u'أَرْمَائِيلَ', #1
u'أرمدا4664id': u'أرمدا4664id', #1
u'ارمرا': u'ارمرا', #1
u'ارمننجر': u'ارمننجر', #1
u'إرمنى': u'إِرْمِنِىُّ', #1
u'ارمنى': u'ارْمِنِى', #1
u'إرمني': u'إرْمَنِيُّ', #2
u'إرمنية': u'إرْمِنْيَةَ', #1
u'أرمهان': u'أرمهان', #1
u'أرمهانا': u'أَرْمَهَانًا', #1
u'أرمياء': u'أَرْمِيَاءَ', #1
u'أرمياء': u'أَرْمِيَاءُ', #1
u'إرمياء': u'إرْمِيَاءَ', #2
u'إرميني': u'إرْمِينِيُّ', #1
u'إرمينية': u'إرْمِينِيَةُ', #1
u'إرمينية': u'إرْمِينِيّةُ', #1
u'إرمينية': u'إرْمِينْيَةَ', #3
u'أرند': u'أرند', #1
u'آرنده': u'آرَنْده', #1
u'أرهجوا': u'أَرْهَجُوا', #1
u'أرهنتكه': u'أَرْهَنْتُكَهُ', #1
u'أرهنتنيه': u'أَرْهَنْتَنِيهِ', #1
u'أرهنكه': u'أَرْهَنَكَهُ', #1
u'أرهنكها': u'أَرْهَنْكَهَا', #2
u'إرواد': u'إرْوَادٍ', #1
u'إروادا': u'إرْوَادًا', #1
u'أروان': u'أَرْوَانُ', #1
u'أروان،': u'أَرْوَانَ،', #1
u'أروان': u'أَرْوَانَ', #19
u'أرومهاSوأنشد': u'أُرُومُهَاSوَأَنْشَدَ', #1
u'أرونى': u'أَرُونِى', #7
u'أرونيه': u'أَرُونِيهِ', #5
u'أرويعينا': u'أَرُوَيْعِينَا', #1
u'آرى': u'آرَى', #1
u'آرى': u'آرى', #6
u'أرياط': u'أرْياط', #1
u'أرياط': u'أَرِيَاطٌ', #1
u'أرياط': u'أَرْيَاطُ', #1
u'أرياط': u'أَرْيَاطٌ', #12
u'أرياط': u'أَرْيَاط', #19
u'أرياط': u'أَرْيَاطَ', #2
u'أرياط': u'أَرْيَاطٍ', #5
u'أرياطا': u'أَرِيَاطًا', #1
u'أرياطا': u'أَرْيَاطًا', #3
u'أريتنى': u'أَرَيْتَنِى', #1
u'أريجدة': u'أَرْيَجْدَةُ', #1
u'أريحاء': u'أَرِيحَاءَ', #1
u'أريحاء': u'أَرِيحَاءُ', #1
u'أريسح': u'أُرَيْسِحَ', #3
u'أريصح': u'أُرَيْصِحَ', #3
u'أريطانس': u'أريطانس', #1
u'أريقط': u'أُرَيْقِط', #1
u'أريقط': u'أُرَيْقِطَ', #1
u'أريقط': u'أُرَيْقِطُ', #1
u'أريقط': u'أُرَيْقِطٍ', #5
u'أريكموه': u'أُرِيَكُمُوهُِِِِِِِِ', #1
u'أريكه': u'أُرِيَكَهُ', #1
u'أريكه': u'أُرِيكَهُ', #4
u'إرين': u'إرِينَ', #1
u'أرينق': u'أُرَيْنَقُ', #1
u'أرينق': u'أُرَيْنِقٍ', #1
u'أرينق': u'أُرَيْنِق', #2
u'أرىوروي': u'أَرَىوَرُوِيَ', #1
u'اريوفردازن': u'اريوفردازن', #1
u'إز': u'إز', #1
u'از': u'ازْ', #2
u'از': u'از', #22
u'ازابشان': u'ازابشان', #1
u'إزاد،': u'إِزَادٍ،', #1
u'آزاد': u'آزَادَ', #13
u'آزاد': u'آزاد', #4
u'آزادزن': u'آزادزن', #1
u'آزادكن': u'آزادكن', #1
u'آزادكن': u'آزَادَكُنَّ', #1
u'ازادم': u'ازادم', #1
u'إزادى': u'إزادى', #2
u'آزادىء': u'آزادىء', #2
u'آزاذ': u'آزاذ', #1
u'آزاذ': u'آزَاذَ', #2
u'ازاراست': u'ازاراست', #1
u'إزاركفرفعته،': u'إِزَارَكَفَرَفَعْتُهُ،', #1
u'آزاره': u'آزَارِهِ', #1
u'إزارى': u'إِزَارِى', #16
u'ازآزادى': u'ازآزادى', #1
u'ازان': u'ازان', #9
u'ازانجا': u'ازانجا', #1
u'ازانخانه': u'ازانخانه', #1
u'ازانروزكه': u'ازانروزكه', #1
u'أزانكه': u'أزانكه', #1
u'ازانكه': u'ازانكه', #1
u'ازاول': u'ازاول', #1
u'ازايشان': u'ازايشان', #3
u'إزب': u'إزْبُ', #1
u'ازبا': u'ازبا', #1
u'أزبة': u'أَزِبَةٍ', #1
u'أزبة': u'أَزْبَةٍ', #1
u'ازبراي': u'ازبراي', #2
u'ازبس': u'ازبس', #1
u'ازبها': u'ازبها', #1
u'أزبهر': u'أزبهر', #1
u'ازبهر': u'ازبهر', #3
u'ازبهرا': u'ازبهرا', #1
u'ازبهشت': u'ازبهشت', #1
u'ازبوبستا': u'ازبوبستا', #1
u'آزت': u'آزَتِ', #1
u'آزت': u'آزَتْ', #1
u'ازتجر': u'ازْتَجَرَ', #1
u'ازتركه': u'ازتركه', #2
u'أزتو': u'أزتو', #1
u'ازتو': u'ازتو', #7
u'أزتوجندين': u'أزتوجندين', #1
u'ازتود': u'ازتود', #1
u'ازتودانم': u'ازتودانم', #1
u'ازتومي': u'ازتومي', #1
u'ازتووا': u'ازتووا', #1
u'ازتويا': u'ازتويا', #1
u'ازتياد': u'ازْتِيَادٌ', #1
u'أزج': u'أَزَجًّ', #1
u'إزجا': u'إزْجًا', #1
u'ازجان': u'ازجان', #2
u'ازجرى': u'ازْجُرِى', #1
u'ازجمله': u'ازجمله', #1
u'أزجنك': u'أزجنك', #1
u'ازجنك': u'ازجنك', #2
u'ازحقهاي': u'ازحقهاي', #1
u'ازحل': u'ازْحَلْ', #1
u'ازخانة': u'ازخانة', #1
u'ازخانه': u'ازخانه', #1
u'ازخدا': u'ازخدا', #1
u'أزخداي': u'أزخداي', #1
u'ازخداي': u'ازخداي', #4
u'ازخرنده': u'ازخرنده', #1
u'أزخزانه': u'أزخزانه', #1
u'ازخيانت': u'ازخيانت', #1
u'ازد': u'ازد', #2
u'أزدادت': u'أَزْدَادَتْ', #1
u'ازدانشمدي': u'ازدانشمدي', #1
u'ازدراع': u'ازْدِرَاعَ', #1
u'ازدراع': u'ازْدِرَاعٍ', #5
u'أزدراعها': u'أَزْدِرَاعَهَا', #1
u'ازدراعها': u'ازْدِرَاعِهَا', #1
u'أزدرع': u'أَزْدَرَعَ', #1
u'ازدرع': u'ازْدَرَعَ', #4
u'ازدرعوا': u'ازْدَرَعُوا', #1
u'أزدشنوءة': u'أَزْدَشَنُوءَةَ', #1
u'أزدشير': u'أَزْدَشِيرَ', #3
u'أزدشير': u'أَزْدَشِيرِ', #4
u'أزدشير': u'أَزْدَشِيرُ', #8
u'ازدلافه': u'ازْدِلَافِهِ', #2
u'ازدلف': u'ازْدَلَفَ', #2
u'ازدلفا': u'ازْدَلَفَا', #1
u'ازدلفوا': u'ازْدَلَفُوا', #5
u'ازدمل': u'ازْدَمَلَ', #1
u'ازدهاق': u'ازدهاق', #1
u'أزدوزخ': u'أزدوزخ', #1
u'أزدي': u'أَزْدِيّ', #1
u'أزدي': u'أزدي', #2
u'أزدي': u'أَزْدِيٌّ', #2
u'أزدي': u'أَزْدِيٍّ', #3
u'أزديا': u'أَزْدِيًّا', #8
u'أزرأت': u'أَزْرَأْتَ', #1
u'إزرار': u'إزْرَارٍ', #1
u'أزرة': u'أُزْرَةَ', #1
u'أزرة': u'أُزْرَةُ', #1
u'إزرة': u'إزْرَةِ', #1
u'إزرة': u'إزْرَةُ', #14
u'إزرة': u'إِزْرَةُ', #15
u'أزرة': u'أُزْرَةٍ', #3
u'أزرة': u'أُزْرَةٌ', #5
u'أزرتنى': u'أَزَّرَتْنِى', #1
u'إزرته': u'إزْرَتَهُ', #1
u'إزرته': u'إِزْرَتَهُ', #1
u'أزرم': u'أَزْرَمَ', #1
u'آزرمن': u'آزرمن', #1
u'آزرى': u'آزَرَى', #1
u'أزز': u'أَزَزَ', #1
u'اززمين': u'اززمين', #1
u'اززن': u'اززن', #1
u'اززني': u'اززني', #2
u'ازسه': u'ازسه', #1
u'ازسيصد': u'ازسيصد', #1
u'ازشهر': u'ازشهر', #1
u'ازشير': u'ازشير', #1
u'أزطي': u'أَزُطِّيٌّ', #1
u'ازعرش': u'ازعرش', #1
u'ازعورات': u'ازعورات', #1
u'ازفلان': u'ازفلان', #1
u'أزفلة': u'أَزْفَلَةٍ', #1
u'ازقبض': u'ازقبض', #1
u'أزقتم': u'أَزَقْتُمْ', #1
u'ازقرآن': u'ازقرآن', #1
u'أزقلة،': u'أَزْقَلَةَ،', #1
u'ازكار': u'ازكار', #1
u'ازكذشتن': u'ازكذشتن', #1
u'ازكنشت': u'ازكنشت', #1
u'ازكوه': u'ازكوه', #1
u'إزلاق': u'إزْلَاقَ', #1
u'ازلذتهاى': u'ازلذتهاى', #1
u'آزلين': u'آزِلِينَ', #1
u'ازماربد': u'ازماربد', #1
u'ازمال': u'ازمال', #4
u'ازماه': u'ازماه', #1
u'ازمتولي': u'ازمتولي', #1
u'ازمتولى': u'ازمتولى', #1
u'ازمدينه': u'ازمدينه', #1
u'ازمزرعه': u'ازمزرعه', #2
u'ازمسلماني': u'ازمسلماني', #1
u'ازمننجر': u'ازمننجر', #1
u'أزموضعى': u'أزموضعى', #1
u'أزميت': u'أزميت', #2
u'إزمير': u'إزمير', #4
u'ازميراث': u'ازميراث', #1
u'ازميرث': u'ازميرث', #1
u'إزميري': u'إزميري', #1
u'أزنرد': u'أزنرد', #1
u'ازنك': u'ازنك', #1
u'أزهزار': u'أزهزار', #1
u'ازهمين': u'ازهمين', #1
u'ازواجه': u'ازواجه', #1
u'أزوجكه': u'أُزَوِّجَكِهِ', #1
u'أزوجكها': u'أُزَوِّجُكهَا', #1
u'أزوجكها،': u'أُزَوِّجُكَهَا،', #1
u'أزوجكها': u'أُزَوِّجُكَهَا', #6
u'أزودة،': u'أَزْوِدَةٌ،', #1
u'ازورثه': u'ازورثه', #1
u'ازوفات': u'ازوفات', #1
u'ازوى': u'ازوى', #2
u'أزيب': u'أُزَيْبٍ', #1
u'أزيب،': u'أُزَيْبٍ،', #1
u'أزيب': u'أَزْيَبَ', #8
u'أزيبة': u'أَزْيَبَةٌ', #1
u'آزيت': u'آزَيْت', #1
u'أزيدنيه': u'أَزَيْدَنِيهِ', #2
u'أزيرق': u'أُزَيْرِقُ', #1
u'ازيس': u'ازيس', #1
u'إزين': u'إزين', #1
u'ازين': u'ازين', #16
u'ازين': u'ازَّيَّنَ', #7
u'أزيهر': u'أُزَيْهِرٍ', #29
u'أزيهر': u'أُزَيْهِر', #3
u'اس': u'اس', #1
u'اس': u'اسْ', #2
u'اساء': u'اساء', #1
u'أساءوا': u'أَسَاءُوا', #66
u'أساببت': u'أَسَابَبْتَ', #1
u'أساتير': u'أَسَاتِيرَ', #11
u'أساجيع': u'أَسَاجِيعَ', #1
u'أساجيع': u'أَسَاجِيعُ', #4
u'إساخة': u'إسَاخَةَ', #1
u'أسأر': u'أَسْأَرَ', #6
u'إسارى': u'إِسَارِى', #1
u'أساريع': u'أَسَارِيعَ', #2
u'اساس': u'اساس', #2
u'أساف': u'أساف', #1
u'أساف': u'أَسَافَ', #1
u'أساف': u'أَسَافِ', #1
u'إساف': u'إسَافِ', #1
u'إساف،': u'إِسَافٌ،', #1
u'إساف': u'إِسَافٌ', #2
u'إساف': u'إسَافٍ', #20
u'إساف': u'إِسَافَ', #3
u'إساف': u'إِسَافٍ', #4
u'إساف': u'إِسَافُ', #4
u'إساف': u'إسَافٌ', #8
u'إساف': u'إسَافَ', #8
u'إساف': u'إسَافُ', #8
u'إسافا': u'إِسَافًا', #4
u'إسافا': u'إسَافًا', #9
u'إسافهم': u'إسَافَهُمْ', #1
u'آسال': u'آسَالٍ', #1
u'إسامة': u'إسَامَةُ', #13
u'إسامة': u'إسَامَةِ', #14
u'أسامة،': u'أًسَامَةَ،', #2
u'إسامة': u'إسَامَةٍ', #2
u'إسامة': u'إسَامَةَ', #6
u'إسامة': u'إسَامَةً', #7
u'إسامته': u'إسَامَتَهُ', #1
u'إسامته': u'إسَامَتِهِ', #3
u'إسامته': u'إسَامَتُهُ', #4
u'إسامتها': u'إسَامَتِهَا', #5
u'إسامتها': u'إسَامَتَهَا', #6
u'إسباطة': u'إسْبَاطَةً', #1
u'اسبطرت': u'اسْبَطَرَّتِ', #1
u'إسبندياذ': u'إسبندياذ', #1
u'إسبهبدية': u'إسبهبدية', #2
u'اسبهدية': u'اسبهدية', #1
u'إسبيجاب': u'إسْبِيجَابِ', #1
u'إسبيجاب': u'إسْبِيجَابَ', #3
u'أست': u'أَسْتً', #1
u'إست': u'إسْتِ', #1
u'است': u'اسْت', #1
u'است': u'اسْتٌ', #1
u'است': u'اسْتٍ', #1
u'است': u'اسْتَ', #10
u'است': u'اسْتُ', #2
u'است': u'است', #267
u'إست': u'إست', #4
u'است': u'اسْتِ', #6
u'استا': u'اسْتًا', #1
u'استاءه': u'اسْتَاءَهُ', #1
u'أستأجرتك': u'أَسْتَأْجَرْتُك', #2
u'استأجرتكها': u'اسْتَأجَرْتُكَهَا', #1
u'استأجل': u'اسْتَأْجَلَ', #1
u'استأخرى': u'اسْتَأْخِرِى', #1
u'استأدانى': u'اسْتَأْدَانِى', #1
u'استأداه': u'اسْتَأْدَاهُ', #1
u'استأدى': u'اسْتَأْدَى', #3
u'استأديت': u'اسْتَأْدَيْتُ', #1
u'أستأذنته': u'أَسْتَأْذَنْتُهُ', #1
u'أستأذنتهما': u'أَسْتَأْذَنْتَهُمَا', #1
u'استأذنونى': u'اسْتَأْذَنُونِى', #3
u'استأذى': u'اسْتَأْذَى', #1
u'إستارا': u'إسْتَارًا', #15
u'استارا': u'اسْتَارَا', #2
u'استاس': u'اسْتَاسَ', #2
u'استأسر،': u'اسْتَأْسَرَ،', #1
u'استأسر': u'اسْتَأْسَرَ', #5
u'استأسرا': u'اسْتَأْسِرَا', #2
u'استأسروا': u'اسْتَأْسِرُوا', #1
u'استأسروا': u'اسْتَأْسَرُوا', #2
u'استاع': u'اسْتَاعَ', #1
u'استاق': u'اسْتَاقَ', #1
u'استاقوا': u'اسْتَاقُوا', #2
u'استاك': u'اسْتَاك', #14
u'استاك': u'اسْتَاكَ', #80
u'استأكلت': u'اسْتَأْكَلَتْ', #1
u'استاكوا': u'اسْتَاكُوا', #17
u'استألفهم': u'اسْتَأْلَفَهُمْ', #1
u'استام': u'اسْتَامَ', #14
u'استأمرتيني': u'اسْتَأْمَرْتِينِي', #1
u'استأمرتيني': u'اِسْتَأْمَرْتِينِي', #1
u'استأمن': u'اسْتَأْمَنَ', #58
u'استأمنا': u'اسْتَأْمَنَا', #5
u'استأمنت': u'اسْتَأْمَنَتْ', #1
u'استأمنت': u'اسْتَأْمَنْت', #1
u'استأمنتك': u'اسْتَأْمَنْتُكَ', #1
u'استأمنتك': u'اسْتَأْمَنْتُك', #8
u'استأمنته': u'اسْتَأْمَنَتْهُ', #1
u'استأمنكم': u'اسْتَأْمَنَكُمْ', #1
u'استأمنه': u'اسْتَأْمَنَهُ', #13
u'استأمنوا': u'اسْتَأْمِنُوا', #1
u'استأمنوا': u'اسْتَأْمَنُوا', #17
u'استأمنوهم': u'اسْتَأْمَنُوهُمْ', #1
u'استامه': u'اسْتَامَهُ', #1
u'استامها': u'اسْتَامَهَا', #2
u'استأميتها': u'اسْتَأْمَيْتَهَا', #1
u'استأناه': u'اسْتَأْنَاهُ', #1
u'إستانبول': u'إسْتَانْبُولَ', #12
u'إستانبول': u'إسْتَانْبُولْ', #2
u'أستأنفت': u'أَسْتَأْنَفَتْ', #1
u'أستأنفتها': u'أَسْتَأْنَفَتْهَا', #1
u'آستانه': u'آستانه', #1
u'استانها': u'استانها', #1
u'استأنى': u'اسْتَأْنَى', #4
u'استأنيت': u'اسْتَأْنَيْت', #4
u'استأنيت': u'اسْتَأْنَيْتُ', #4
u'استأنيتم': u'اسْتَأْنَيْتُمْ', #1
u'استاه': u'اسْتَاهُ', #1
u'استاهكم': u'اسْتَاهِكُمْ', #1
u'أستاهكم': u'أَسْتَاهِكُمْ', #2
u'إستاهم،': u'إِسْتَاهِمْ،', #1
u'أستاهنا': u'أَسْتَاهُنَا', #1
u'أستاههم': u'أَسْتَاههمْ', #1
u'أستاههم': u'أَسْتَاهِهِمْ', #11
u'أستاههم،': u'أَسْتَاهِهِمْ،', #2
u'أستاههن': u'أَسْتَاهِهِنَّ', #2
u'أستائهم': u'أَسْتَائِهِمْ', #1
u'استائهم': u'اسْتَائِهِمْ', #1
u'استب': u'اسْتَبَّ', #12
u'استبا': u'اسْتَبَّا', #8
u'استبار': u'اسْتِبَارٌ', #1
u'استباع': u'اسْتِبَاع', #1
u'استباع': u'اسْتِبَاعَ', #1
u'استباع': u'اسْتَبَاعَ', #9
u'استباعه': u'اسْتَبَاعَهُ', #1
u'استبتا': u'اسْتَبَّتَا', #1
u'استبحر': u'اسْتَبْحَرَ', #9
u'استبذال': u'اسْتِبْذَالَ', #1
u'استبذال': u'اسْتِبْذَالِ', #1
u'استبذال': u'اسْتِبْذَالٌ', #2
u'استبذالها': u'اسْتِبْذَالُهَا', #1
u'استبذالها': u'اسْتِبْذَالِهَا', #1
u'استبذالهم': u'اسْتِبْذَالِهِمْ', #2
u'استبذلوا': u'استَبْذَلُوا', #1
u'استبرءوها': u'اسْتَبْرَءُوهَا', #1
u'استبرا': u'اسْتَبِرَا', #1
u'استبرا': u'اسْتِبْرَا', #2
u'استبراءا': u'اسْتِبْرَاءًا', #1
u'استبره': u'استبره', #1
u'استبري': u'اسْتَبْرِي', #3
u'استبريت': u'اسْتَبْرَيْت', #1
u'استبريت': u'اسْتَبْرَيْتَ', #1
u'استبريت': u'اسْتَبْرَيْتُ', #1
u'استبريتها': u'اسْتَبْرَيْتَهَا', #1
u'استبرين': u'اسْتَبْرَيْنَ', #1
u'استبريه': u'اسْتَبْرِيهِ', #1
u'استبضع': u'اسْتَبْضَعَ', #3
u'استبضعناه': u'اسْتَبْضَعْنَاهُ', #1
u'استبضعناها': u'اسْتَبْضَعْنَاهَا', #1
u'استبضعوه': u'اسْتَبْضَعُوهُ', #1
u'استبضعى': u'اسْتَبْضِعِى', #1
u'استبعثني': u'اسْتَبْعَثَنِي', #1
u'استبكى': u'اسْتَبْكَى', #2
u'استبل': u'اسْتُبِلّ', #2
u'استبل': u'اسْتَبَلّ', #4
u'استبلج': u'اسْتَبْلَجَ', #1
u'استبينته': u'اِسْتَبْيَنْتَهُ', #1
u'استتاب': u'اسْتَتَابَ', #10
u'استتابة': u'اسْتِتَابَةً', #1
u'استتابة': u'اسْتِتَابَةُ', #17
u'استتابة': u'اسْتِتَابَةٌ', #2
u'استتابة': u'اسْتِتَابَةِ', #22
u'استتابة': u'اسْتِتَابَةَ', #3
u'استتابة': u'اسْتِتَابَةٍ', #61
u'استتابته': u'اسْتِتَابَتُهُ', #22
u'استتابته': u'اسْتِتَابَتَهُ', #5
u'استتابته': u'اسْتِتَابَتِهِ', #54
u'استتابتها': u'اسْتِتَابَتِهَا', #2
u'استتابتهم': u'اسْتِتَابَتِهِمْ', #1
u'استتابتهم': u'اسْتِتَابَتُهُمْ', #2
u'استتابه': u'اسْتَتَابَهُ', #8
u'استتابها': u'اسْتَتَابَهَا', #1
u'استتابهم': u'اسْتَتَابَهُمْ', #4
u'استتبناه': u'اسْتَتَبْنَاهُ', #1
u'استتبهم': u'اسْتَتِبْهُمْ', #3
u'استتجره': u'اسْتَتْجَرَهُ', #1
u'استتم': u'استتمٌ', #1
u'استتم': u'اسْتَتَمْ', #1
u'استتم': u'اسْتَتَمّ', #3
u'استتم': u'اسْتَتَمَّ', #63
u'استتمام': u'اسْتِتْمَامَ', #1
u'استتمام': u'اسْتِتْمَامُ', #1
u'استتمام': u'اسْتِتْمَامِ', #2
u'استتمامه': u'اسْتِتْمَامِهِ', #1
u'استتممت': u'اسْتَتْمَمْتُ', #1
u'استتيب': u'اسْتُتِيبَ', #1
u'استتيب': u'اُسْتُتِيبَ', #45
u'استتيبوا': u'اُسْتُتِيبُوا', #1
u'استثبات': u'اسْتِثْبَاتٍ', #1
u'استثباتا': u'اسْتِثْبَاتًا', #1
u'استثبت': u'اسْتَثْبَتَّ', #1
u'استثبت': u'اسْتَثْبَتُّ', #1
u'استثبت': u'اسْتَثْبَتَ', #4
u'استثبتت': u'اسْتَثْبَتَتْ', #1
u'استثفار': u'اسْتِثْفَارٌ', #1
u'استثفار': u'اسْتِثْفَارٍ', #3
u'استثفر': u'اسْتَثْفَرَ', #3
u'استثفرت': u'اسْتَثْفَرَتْ', #1
u'استثفرى': u'استثفرى', #1
u'استثفرى': u'اسْتَثْفِرِى', #1
u'استثفري': u'اسْتَثْفِرِي', #2
u'استثنا': u'اسْتِثْنَا', #1
u'استجادته': u'اسْتِجَادَتَهُ', #1
u'استجاز': u'اسْتَجَازَ', #23
u'استجازا': u'اسْتَجَازَا', #1
u'استجازة': u'اسْتِجَازَةً', #1
u'استجازة': u'اسْتِجَازَةِ', #1
u'استجازة': u'اسْتِجَازَةَ', #5
u'استجازت': u'اسْتَجَازَتْ', #2
u'استجازتها': u'اسْتِجَازَتِهَا', #1
u'استجازه': u'اسْتَجَازَهُ', #2
u'استجازوا': u'اسْتَجَازُوا', #4
u'استجازوه': u'اسْتَجَازُوهُ', #4
u'استجاش': u'اسْتَجَاشَ', #1
u'استجبنت': u'اسْتَجْبَنَتْ', #1
u'أستجة': u'أُسْتُجَةٌ', #1
u'استجذ': u'اسْتَجَذَّ', #1
u'استجرأ': u'اسْتَجْرَأَ', #1
u'استجمار': u'اسْتِجْمَارَ', #1
u'استجمار': u'اسْتِجْمَارِ', #1
u'استجمار': u'اسْتِجْمَارٌ', #15
u'استجمار': u'اسْتِجْمَارٍ', #19
u'استجمارا': u'اسْتِجْمَارًا', #8
u'استجماره': u'اسْتِجْمَارِهِ', #19
u'استجماره': u'اسْتِجْمَارُهُ', #3
u'استجمارهم': u'اسْتِجْمَارِهِمْ', #1
u'استجمر،': u'استجمر،', #1
u'استجمر': u'اسْتجمر', #1
u'استجمر': u'اسْتَجْمَرَ', #163
u'استجمر': u'اِسْتَجْمَرَ', #3
u'استجمر': u'اسْتَجْمِرْ', #4
u'استجمرت': u'اِسْتَجْمَرْت', #1
u'استجمرت': u'اسْتَجْمَرْتَ', #8
u'استجن': u'اسْتَجَنَّ', #1
u'استجن': u'اسْتَجِنُّ', #1
u'استجنح': u'اسْتَجْنَحَ', #2
u'استجنى': u'اسْتَجْنَى', #1
u'استجهالا': u'اسْتِجْهَالاً', #1
u'استجهدتني': u'اسْتَجْهَدْتَنِي', #2
u'استجهل': u'اسْتَجْهَلَ', #1
u'استجهلت': u'اسْتَجْهَلْتُ', #1
u'استجهلهم': u'اسْتَجْهِلْهُمْ', #1
u'استح': u'اسْتَحِ', #2
u'استحارك': u'اسْتِحَارُك', #1
u'استحاض': u'اسْتَحَاضَ', #1
u'استحاض': u'اُسْتَحَاضُ', #1
u'استحاضة': u'اِسْتِحَاضَة', #1
u'استحاضة': u'اسْتِحَاضَةِ', #2
u'استحاضة': u'اسْتِحَاضَةٌ', #261
u'استحاضة': u'اسْتِحَاضَةٍ', #62
u'استحاضة': u'اسْتِحَاضَةً', #72
u'استحاضت': u'اسْتَحَاضَتْ', #7
u'استحاضتها': u'اسْتِحَاضَتُهَا', #10
u'استحاضتها': u'اسْتِحَاضَتِهَا', #11
u'استحاضتها': u'اسْتِحَاضَتَهَا', #2
u'استحبابية': u'اسْتِحْبَابِيَّةُ', #1
u'استحبابية': u'اسْتِحْبَابِيَّةِ', #1
u'استحبابيته': u'اسْتِحْبابِيَّتِه', #1
u'استحت': u'اسْتَحَتْ', #1
u'استحجر': u'اسْتَحْجَرَ', #5
u'استحد': u'اسْتَحَدَّ', #1
u'استحداد': u'اسْتِحْدَادٍ', #1
u'استحداد': u'اسْتِحْدَادٌ', #2
u'استحدادا': u'اسْتِحْدَادًا', #2
u'استحدادها': u'اسْتِحْدَادِهَا', #2
u'استحديها': u'اسْتَحِدِّيهَا', #2
u'استحر': u'اُسْتُحِرَّ', #1
u'استحر': u'اسْتَحَرَّ', #10
u'استحر': u'اسْتَحَرّ', #2
u'استحشاف': u'اسْتِحْشَافٍ', #5
u'استحشافها': u'اسْتِحْشَافُهَا', #1
u'استحشافها': u'اسْتِحْشَافِهَا', #1
u'استحشف': u'اسْتَحْشَفَ', #1
u'استحشف': u'اُسْتُحْشِفَ', #1
u'استحشفت': u'اسْتَحْشَفَتْ', #1
u'استحصنت': u'اسْتَحْصَنَتْ', #2
u'استحضت': u'اسْتَحَضْتُ', #3
u'استحضت': u'اسْتُحِضْتُ', #3
u'استحضت': u'اُسْتُحِضْت', #3
u'استحضن': u'اسْتَحَضْنَ', #1
u'استحضن': u'اُسْتُحِضْنَ', #1
u'استحفافا': u'اسْتِحْفَافًا', #2
u'استحفظتكه': u'اسْتَحْفَظْتُكَهُ', #1
u'استحفظتكها': u'اسْتَحْفَظْتُكَهَا', #1
u'استحفيت': u'اسْتَحْفَيْتَ', #1
u'استحقاقة': u'اسْتِحْقَاقَةَ', #1
u'استحقاقيته': u'استحقاقيته', #1
u'استحقب': u'اُسْتُحْقِبَ', #1
u'استحقبته': u'اسْتَحْقَبْتَهُ', #1
u'أستحقت': u'أَسْتُحِقَّتْ', #1
u'استحقيت': u'اسْتَحْقَيْت', #1
u'استحقيت': u'اسْتَحْقَيْتُ', #1
u'استحقيتما': u'اسْتَحَقَّيْتُمَا', #1
u'استحقيناه': u'اسْتَحَقَّيْنَاهُ', #1
u'استحكته': u'اسْتَحْكَتْهُ', #1
u'استحلبا': u'اُسْتُحْلِبَا', #1
u'استحلفتنى': u'اسْتَحْلَفْتَنِى', #1
u'استحلفنى': u'اسْتَحْلَفَنِى', #1
u'استحمق': u'اِسْتَحْمَقَ', #1
u'استحمقت': u'اسْتَحْمَقْتُ', #1
u'استحمقت': u'استحمقتُ', #2
u'استحى،': u'استحى،', #1
u'استحى': u'اسْتَحَى', #14
u'أستحى': u'أَسْتَحِى', #2
u'استحيت': u'استحيت', #1
u'استحيت': u'اسْتَحَيْتَ', #2
u'استحيت': u'اسْتَحَيْتُ', #4
u'استحيت': u'اسْتَحْيَتْ', #6
u'استحيضت،': u'اسْتُحِيضَتْ،', #1
u'استحيضت': u'اُسْتُحِيضَتْ', #139
u'استحيضت': u'اسْتُحِيضَتْ', #35
u'استحيضت': u'اسْتُحِيضَتِ', #5
u'إستحيوها': u'إسْتَحْيَوْهَا', #1
u'استحيى': u'اسْتَحْيَى', #1
u'أستحيى': u'أَسْتَحْيِى', #10
u'أستحيى': u'أَسْتَحْيِىَ', #3
u'استخار': u'اسْتَخَارَ', #19
u'استخارت': u'اسْتَخَارَتْ', #2
u'استخارت': u'اِسْتَخَارَتْ', #2
u'استخارني': u'اسْتَخَارَنِي', #1
u'استخاره': u'اسْتَخَارَهُ', #1
u'استخاروه': u'اسْتَخَارُوهُ', #1
u'استخانة': u'اسْتِخَانَةً', #1
u'استخبأت': u'اسْتَخْبَأْتُ', #2
u'استخباث': u'اسْتِخْبَاثٍ', #2
u'استخباثه': u'اسْتِخْبَاثِهِ', #1
u'استخبتا': u'استخبتا', #1
u'استخبتا': u'اسْتَخَبَتَا', #1
u'استخبتا،': u'اسْتَخَبَتَا،', #1
u'استخبثته': u'اسْتَخْبَثَتْهُ', #4
u'استخبثه': u'اسْتَخْبَثَهُ', #2
u'استخبثوه': u'اسْتَخْبَثُوهُ', #6
u'استخبيت': u'اسْتَخْبَيْت', #1
u'استخداعه': u'استخداعه', #1
u'استخر': u'اسْتَخِرْ', #5
u'استخرت': u'اسْتَخَرْتُ', #2
u'استخرت': u'اسْتَخَرْت', #5
u'استخصك': u'اسْتَخَصَّكِ', #1
u'استخضره': u'اسْتَخْضَرَهُ', #1
u'استخلاء': u'اسْتِخْلَاءٍ', #1
u'استخمر': u'اسْتَخْمَرَ', #4
u'استخيره': u'اسْتَخْيَرَهُ', #1
u'استد': u'استد', #1
u'استد': u'اسْتَدَّ', #6
u'استداد': u'اسْتِدَادِ', #2
u'استداده': u'اسْتِدَادَهُ', #1
u'استداده': u'اسْتِدَادِهِ', #1
u'استدت': u'اسْتَدَّتْ', #2
u'استدخال': u'استدخال', #1
u'استدخال': u'اسْتِدْخَالٍ', #2
u'استدخال': u'اسْتِدْخَالَ', #21
u'استدخال': u'اسْتِدْخَالٌ', #5
u'استدخال': u'اسْتِدْخَالُ', #50
u'استدخال': u'اسْتِدْخَالِ', #51
u'استدخاله': u'اسْتِدْخَالِهِ', #15
u'استدخالها': u'اسْتِدْخَالَهَا', #2
u'استدخالها': u'اسْتِدْخَالُهَا', #9
u'استدخالها': u'اسْتِدْخَالِهَا', #9
u'استدخل': u'اسْتُدْخِلَ', #2
u'استدخل': u'اسْتَدْخَلَ', #5
u'استدخلت': u'اسْتَدْخَلْت', #1
u'استدخلت': u'اسْتَدْخَلَتْ', #160
u'استدخلت': u'اسْتَدْخَلَتِ', #3
u'استدخلته': u'اسْتَدْخَلْتَهُ', #2
u'استدخلته': u'اسْتَدْخَلَتْهُ', #26
u'استدخلتها': u'اسْتَدْخَلَتْهَا', #4
u'استدخله': u'اسْتَدْخَلَهُ', #3
u'استدخلها': u'اسْتَدْخَلَهَا', #1
u'استدرته': u'اسْتَدَرْتُهُ', #1
u'استدررت': u'اسْتَدْرَرْت', #1
u'استدنيني': u'اسْتَدْنِينِي', #1
u'استذرته': u'اسْتَذْرَتْهُ', #1
u'استذفرت': u'اسْتَذْفَرَتْ', #1
u'استذفري': u'اسْتَذْفِرِي', #1
u'استذل': u'اسْتَذَلّ', #1
u'استذل': u'اسْتَذَلَّ', #2
u'استذلال': u'اسْتِذْلَالٍ', #1
u'استذلال': u'اسْتِذْلَالِ', #1
u'استذلال': u'اسْتِذْلَالٌ', #2
u'استذلال': u'اسْتِذْلَالُ', #3
u'استذلالا': u'اسْتِذْلَالًا', #1
u'استذلاله': u'اسْتِذْلَالُهُ', #1
u'استذلاله': u'اسْتِذْلَالِهِ', #1
u'استذله': u'اسْتَذَلَّهُ', #2
u'استذمت': u'اُسْتُذِمَّتْ', #1
u'استراء': u'اسْتِرَاءٌ', #1
u'استراب': u'اسْتَرَابَ', #22
u'استرابة': u'اسْتِرَابَةً', #1
u'استرابة': u'اسْتِرَابَةٍ', #2
u'استرابة': u'اسْتِرَابَةٌ', #3
u'استرابت': u'اسْتَرَابَتْ', #3
u'استرابه': u'اسْتَرَابَهُ', #3
u'استراث': u'اسْتَرَاثَ', #2
u'استراحه': u'اسْتِرَاحَهْ', #1
u'استراض': u'اسْتَرَاضَ', #1
u'استراقة': u'اسْتِرَاقَةِ', #1
u'استرباح': u'اسْتِرْبَاحٌ', #1
u'استرباح': u'اسْتِرْبَاحٍ', #1
u'استرباح': u'اسْتِرْبَاحَ', #1
u'استرباحا': u'اسْتِرْبَاحًا', #1
u'استرباحه': u'اسْتِرْبَاحُهُ', #1
u'استرباحه': u'اسْتِرْبَاحَهُ', #4
u'استربت': u'اسْتَرَبْت', #1
u'استربتم': u'اسْتَرَبْتُمْ', #1
u'استربح': u'اسْتَرْبَحَ', #7
u'استربحه': u'اسْتَرْبَحَهُ', #2
u'استرجم': u'اسْتَرْجَمَ', #1
u'استرحام': u'اسْتِرْحَامٌ', #1
u'استرحمت': u'اُسْتُرْحِمَتْ', #1
u'استرحموا': u'اُسْتُرْحِمُوا', #3
u'استرحموا': u'اسْتُرْحِمُوا', #8
u'استردادة': u'اسْتِرْدَادَةٍ', #1
u'استردتيه': u'اسْتَرَدَّتِيهِ', #1
u'استرذل': u'اُسْتُرْذِلَ', #2
u'استرذل': u'اسْتَرْذَلَ', #5
u'استرذله': u'اسْتَرْذَلَهُ', #2
u'استرطبان': u'اسْترطُبان', #2
u'استرطبان': u'اسْتُرْطُبَان', #3
u'استرفاع': u'اسْتِرْفَاعِ', #2
u'استرفقه': u'اسْتَرْفَقَهُ', #1
u'استرقاء': u'اسْتِرْقَاءُ', #1
u'استرقاق': u'اسْتِرْقَاقْ', #1
u'استرقاق': u'اسْتِرْقَاقٌ', #11
u'استرقاق': u'اسْتِرْقَاقٍ', #19
u'استرقاق': u'اسْتِرْقَاقَ', #29
u'استرقاق': u'اسْتِرْقَاقِ', #47
u'استرقاق': u'اسْتِرْقَاقُ', #50
u'استرقاقا': u'اسْتِرْقَاقًا', #3
u'استرقاقه': u'اسْتِرْقَاقَهُ', #14
u'استرقاقه': u'اسْتِرْقَاقِهِ', #45
u'استرقاقه': u'اسْتِرْقَاقُهُ', #73
u'استرقاقها': u'اسْتِرْقَاقَهَا', #5
u'استرقاقها': u'اسْتِرْقَاقِهَا', #5
u'استرقاقها': u'اسْتِرْقَاقُهَا', #9
u'استرقاقهم': u'اسْتِرْقَاقِهِمْ', #24
u'استرقاقهم': u'اسْتِرْقَاقُهُمْ', #47
u'استرقاقهم': u'اسْتِرْقَاقَهُمْ', #6
u'استرقاقهما': u'اسْتِرْقَاقَهُمَا', #2
u'استرقاقهما': u'اسْتِرْقَاقُهُمَا', #2
u'استرقاقهن': u'اسْتِرْقَاقِهِنَّ', #1
u'استرقاؤه': u'اسْتِرْقَاؤُهُ', #1
u'استرقد': u'اسْتَرْقَدَ', #1
u'استرققن': u'اُسْتُرْقِقْنَ', #1
u'استرقى': u'اسْتَرْقَى', #10
u'استرقيت': u'اسْتَرْقَيْتَ', #1
u'استرقيت،': u'اسْتَرْقَيْتُ،', #1
u'استرقيت': u'اسْتَرْقَيْتُ', #2
u'استرقيتم': u'اسْتَرْقَيْتُمْ', #1
u'استرك': u'اسْتَرَكَّ', #1
u'استرم': u'اُسْتُرِمَّ', #1
u'استرم': u'اسْتَرَمَّ', #12
u'استرمت': u'اسْتَرَمَّتْ', #5
u'استرهنه': u'اسْتَرْهَنَهُ', #2
u'استروج': u'اسْتَرْوَجَ', #1
u'استروشني': u'اسْتُرُوشْنِيٌّ', #1
u'استريب': u'اُسْتُرِيبَ', #4
u'استريبت': u'اسْتُرِيبَتْ', #4
u'استزارتهم': u'اسْتِزَارَتُهُمْ', #1
u'استزاره': u'اسْتَزَارَهُ', #1
u'استزبنهم': u'اسْتَزْبَنَهُمْ', #1
u'استزراء': u'اسْتِزْرَاءِ', #1
u'استزكاه': u'استزكاه', #1
u'استزكاه': u'اسْتَزْكَاهُ', #1
u'استزكائه': u'اسْتِزْكَائِهِ', #2
u'استزكى': u'اسْتَزْكَى', #3
u'إستزلهم': u'إسْتَزَلَّهُمُ', #1
u'استسحنت': u'اسْتَسْحَنَتْ', #1
u'استسر': u'استَسَرَّ', #1
u'استسر': u'اسْتَسَرْ', #1
u'استسر': u'اُسْتُسِرَّ', #1
u'استسر': u'اسْتَسَرَّ', #5
u'استسرج': u'اسْتَسْرَجَ', #1
u'استسرج': u'اُسْتُسْرِجَ', #1
u'استسرر': u'اسْتَسْرَرَ', #1
u'استسرع': u'اُسْتُسْرِعَ', #2
u'استسرها': u'اسْتَسَرَّهَا', #1
u'استسعاء': u'اسْتِسْعَاءٍ', #1
u'استسعاء': u'اسْتِسْعَاءُ', #24
u'استسعاء': u'اسْتِسْعَاءِ', #32
u'استسعاء': u'اسْتِسْعَاءَ', #36
u'استسعاء': u'اسْتِسْعَاءٌ', #7
u'استسعاءه': u'اسْتِسْعَاءَهُ', #16
u'استسعاه': u'اسْتَسْعَاهُ', #39
u'استسعاها': u'اسْتَسْعَاهَا', #5
u'استسعاهما': u'اسْتَسْعَاهُمَا', #1
u'استسعاؤه': u'اسْتِسْعَاؤُهُ', #8
u'استسعائه': u'اسْتِسْعَائِهِ', #6
u'استسعائها': u'اسْتِسْعَائِهَا', #3
u'استسعائهما': u'اسْتِسْعَائِهِمَا', #1
u'استسعت': u'اسْتَسْعَتْ', #3
u'استسعوا': u'اسْتَسْعَوْا', #15
u'استسعوه': u'اسْتَسْعَوْهُ', #5
u'استسعى': u'اسْتُسْعِىَ', #10
u'استسعى': u'اسْتَسْعَى', #177
u'استسعي': u'اسْتُسْعِيَ', #3
u'استسعي': u'اُسْتُسْعِيَ', #6
u'استسعيا': u'اسْتَسْعَيَا', #1
u'استسعيت': u'اُسْتُسْعِيَتْ', #1
u'استسلاف': u'اسْتِسْلَافُ', #2
u'استسلف': u'اِسْتَسْلَفَ', #3
u'استسلف': u'اسْتَسْلَفَ', #60
u'استسلفت': u'اسْتَسْلَفْت', #1
u'استسلفت': u'اسْتَسْلَفْتُ', #1
u'استسلفه': u'اسْتَسْلَفَهُ', #7
u'استسلفها': u'اسْتَسْلَفَهَا', #2
u'استسماحا': u'اسْتِسْمَاحًا', #1
u'استسمان': u'اسْتِسْمَانُ', #1
u'استسمانها': u'اسْتِسْمَانُهَا', #6
u'استشارنى': u'اسْتَشَارَنِى', #1
u'استشراه': u'اسْتَشْرَاهُ', #1
u'استشراها': u'اسْتَشْرَاهَا', #1
u'استشريته': u'اسْتَشْرَيْتُهُ', #2
u'استشعرالإسلام': u'اسْتَشْعَرَالْإِسْلَامَ', #1
u'استشفاق': u'اسْتِشْفَاقٌ', #1
u'استشفاقا': u'اسْتِشْفَاقًا', #2
u'استشفر': u'اسْتَشْفَرَ', #1
u'استشفعه': u'اسْتَشْفَعَهُ', #2
u'استشفعها': u'اسْتَشْفَعَهَا', #1
u'استشكلته': u'اسْتَشْكَلْتُهُ', #1
u'استشكله': u'اسْتَشْكَلَهْ', #2
u'استشكله': u'اسْتَشْكَلَهُ', #204
u'استشكلها': u'اسْتَشْكَلَهَا', #4
u'استشكلوه': u'اسْتَشْكَلُوهُ', #2
u'استشلاه': u'اسْتَشْلَاهُ', #2
u'استشم': u'اسْتَشَمَّ', #4
u'استشمه': u'اسْتَشَمَّهُ', #5
u'استشنع': u'اسْتَشْنَعَ', #1
u'استصبح': u'اسْتَصْبَحَ', #1
u'استصبح': u'اُسْتُصْبِحَ', #3
u'استصبحوا': u'اسْتَصْبِحُوا', #6
u'استصر': u'اسْتَصَرَّ', #1
u'استصفيته': u'اسْتَصْفَيْتَهُ', #3
u'استصناع': u'اسْتِصْنَاعٌ', #23
u'استصناع': u'اسْتِصْنَاعِ', #3
u'استصناع': u'اسْتِصْنَاعُ', #4
u'استصناع': u'اسْتِصْنَاعَ', #6
u'استصناع': u'اسْتِصْنَاعٍ', #9
u'استصناعا': u'اسْتِصْنَاعًا', #23
u'استصناعه': u'اسْتِصْنَاعُهُ', #2
u'استصناعه': u'اسْتِصْنَاعِهِ', #2
u'استصناعها': u'اسْتِصْنَاعِهَا', #1
u'استصناعها': u'اسْتِصْنَاعُهَا', #3
u'استصنع': u'اسْتَصْنِعْ', #1
u'استصنع': u'اسْتَصْنَعَ', #40
u'استصنع': u'اُسْتُصْنِعَ', #8
u'استصنعت': u'اسْتَصْنَعْتَ', #1
u'استصنعت': u'اسْتَصْنَعْت', #2
u'استصنعني': u'اسْتَصْنَعَنِي', #1
u'استصنعه': u'اسْتَصْنَعَهُ', #17
u'استصنعوا': u'اسْتَصْنَعُوا', #1
u'استصنعوهم': u'اسْتَصْنَعُوهُمْ', #2
u'استضاءوا': u'اسْتَضَاءُوا', #1
u'استضحك': u'اسْتَضْحَكَ', #1
u'استضر': u'اسْتَضَرَّ', #11
u'استضرا': u'اسْتَضَرَّا', #1
u'استضرار': u'اسْتِضْرَارِ', #2
u'استضرارا': u'اسْتِضْرَارًا', #1
u'استضرارها': u'اسْتِضْرَارِهَا', #1
u'استضرارهم': u'اسْتِضْرَارَهُمْ', #1
u'استضربه': u'استضربه', #1
u'استضرت': u'اسْتَضَرَّتْ', #2
u'استضررت': u'اسْتَضْرَرْت', #1
u'استضروا': u'اسْتَضَرَّوْا', #1
u'استضروا': u'اسْتَضَرُّوا', #3
u'استطباب': u'اسْتِطْبَابُ', #2
u'استطباب': u'اسْتِطْبَابِ', #2
u'استطبابه': u'اسْتِطْبَابُهُ', #1
u'استطبابه': u'اسْتِطْبَابِهِ', #2
u'استطبابهم': u'اسْتِطْبَابُهُمْ', #2
u'استطحنوهم': u'اسْتَطْحَنُوهُمْ', #1
u'استطراق': u'اسْتِطْرَاقِ', #12
u'استطراق': u'اسْتِطْرَاقَ', #2
u'استطراق': u'اسْتِطْرَاقٌ', #3
u'استطراق': u'اسْتِطْرَاقُ', #5
u'استطراق': u'اسْتِطْرَاقٍ', #7
u'استطراقا': u'اسْتِطْرَاقًا', #19
u'استطراقه': u'اسْتِطْرَاقُهُ', #13
u'استطراقه': u'اسْتِطْرَاقَهُ', #3
u'استطراقه': u'اسْتِطْرَاقِهِ', #5
u'استطراقها': u'اسْتِطْرَاقُهَا', #1
u'استطرحت': u'اسْتَطْرَحْت', #1
u'استطرده': u'اسْتَطْرَدَهُ', #1
u'استطردها': u'اسْتَطْرَدَهَا', #1
u'استطرق': u'اسْتَطْرَقَ', #2
u'استطرقت': u'اسْتَطْرَقْت', #1
u'استعاذك': u'اسْتَعَاذَكَ', #2
u'استعاذك': u'اسْتَعَاذَك', #3
u'استعاذكم': u'اسْتَعَاذَكُمْ', #3
u'استعاذنى': u'اسْتَعَاذَنِى', #2
u'استعاذني': u'اسْتَعَاذَنِي', #4
u'استعاذه': u'اسْتَعَاذَهُ', #1
u'استعاط': u'اسْتِعَاطٍ', #2
u'استعبر': u'اسْتَعْبَرَ', #5
u'استعبراه،': u'اسْتَعْبَرَاهُ،', #2
u'استعبرت': u'اسْتَعْبَرْت', #1
u'استعبرت': u'اسْتَعْبَرْتُ', #1
u'استعجاب': u'اسْتِعْجَابٍ', #2
u'استعجابا': u'اِسْتِعْجَابًا', #1
u'استعذر': u'اسْتَعْذَرَ', #2
u'استعذرت': u'اسْتَعْذَرَتْ', #1
u'استعذرته': u'اسْتَعْذَرْتَهُ', #1
u'استعرتيه': u'استعرتيه', #1
u'استعز': u'اسْتُعِزَّ', #2
u'استعز': u'اُسْتُعِزّ', #3
u'استعز': u'اسْتَعَزّ', #4
u'استعزوا': u'اسْتَعَزُّوا', #1
u'استعضدته': u'اسْتَعْضَدْتَهُ', #1
u'استعطرت،': u'استعطرت،', #1
u'استعطرت': u'اِسْتَعْطَرَتْ', #1
u'استعطرت': u'اسْتَعْطَرَتْ', #9
u'استعفى': u'اسْتَعْفَى', #8
u'استعفيت': u'اسْتَعْفَيْت', #2
u'استعقاب': u'اسْتِعْقَابَ', #2
u'استعقاب': u'اسْتِعْقَابِ', #6
u'استعقابا': u'اسْتِعْقَابًا', #1
u'استعقابه': u'اسْتِعْقَابِهِ', #1
u'استعقابها': u'اسْتِعْقَابِهَا', #1
u'استعقب': u'اسْتَعْقَبَ', #15
u'استعقبا': u'اسْتَعْقَبَا', #1
u'استعقبت': u'اسْتَعْقَبَتْ', #2
u'استعقبه': u'اسْتَعْقَبَهُ', #2
u'استعلاج': u'اسْتِعْلَاجٍ', #3
u'إستعمالهما': u'إستعمالهما', #1
u'استعمام': u'اسْتِعْمَامِ', #1
u'استعملتنيه': u'اسْتَعْمَلْتَنِيهِ', #2
u'استعملنى': u'اسْتَعْمَلَنِى', #9
u'استعواه': u'اسْتَعْوَاهُ', #1
u'استعوى': u'اسْتَعْوَى', #2
u'استغدرت': u'اسْتَغْدَرَتْ', #3
u'استغزار': u'اسْتِغْزَارَ', #2
u'استغسلتم': u'اسْتُغْسِلْتُمْ', #13
u'استغضب': u'اُسْتُغْضِبَ', #6
u'استغفارة': u'اسْتِغْفَارَةً', #2
u'استغفارى': u'اسْتِغْفَارِى', #1
u'أستغفرت': u'أَسْتَغْفَرَتَ', #1
u'أستغفرت': u'أَسْتَغْفَرْت', #1
u'أستغفرت': u'أَسْتَغْفَرْتَ', #1
u'استغلقه': u'اسْتَغْلَقَهُ', #1
u'استغنام': u'اسْتِغْنَامٍ', #1
u'استغنام': u'اسْتِغْنَامِ', #1
u'استغنام': u'اسْتِغْنَامَ', #2
u'استغناما': u'اسْتِغْنَامًا', #1
u'استغنامه': u'اسْتِغْنَامَهُ', #1
u'استغنم': u'اسْتَغْنَمَ', #1
u'استغنم': u'اسْتَغْنِمْ', #1
u'أستغنيت': u'أَسْتَغْنَيْت', #1
u'استغواء': u'اسْتِغْوَاءِ', #2
u'استغوار': u'اسْتِغْوَارٍ', #3
u'استفاء': u'اسْتَفَاءَ', #4
u'استفاده': u'اسْتَفَادَهُ', #94
u'استفادها': u'اسْتَفَادَهَا', #26
u'استفادهما': u'اسْتَفَادَهُمَا', #1
u'استفادوه': u'اسْتَفَادُوهُ', #2
u'استفادوها': u'اسْتَفَادُوهَا', #2
u'استفال': u'اسْتِفَالٌ', #1
u'استفاله': u'اسْتِفَالِهِ', #1
u'استفحاشا': u'اسْتِفْحَاشًا', #1
u'استفحش': u'اسْتَفْحَشَ', #2
u'استفحشه': u'اسْتَفْحَشَهُ', #4
u'استفدته': u'اسْتَفَدْتَهُ', #1
u'استفدته': u'اسْتَفَدْته', #3
u'استفدتها': u'اسْتَفَدْتهَا', #1
u'استفدناه': u'اسْتَفَدْنَاهُ', #10
u'استفراخها': u'اسْتِفْرَاخِهَا', #1
u'استفراش': u'اسْتِفْرَاشِ', #11
u'استفراش': u'اسْتِفْرَاشَ', #2
u'استفراش': u'اسْتِفْرَاشُ', #2
u'استفراشه': u'اسْتِفْرَاشِهِ', #2
u'استفراشها': u'اسْتِفْرَاشُهَا', #1
u'استفراشها': u'اسْتِفْرَاشِهَا', #1
u'استفرجت': u'اِسْتُفْرِجْت', #1
u'استفرشت': u'اسْتَفْرَشَتْ', #1
u'استفرشها': u'استفرشها', #1
u'استفرشها': u'اسْتَفْرَشَهَا', #2
u'استفسد': u'اسْتَفْسَدَ', #2
u'استفشى': u'اسْتَفْشَى', #1
u'استفصال': u'اسْتِفْصَالٌ', #1
u'استفصال': u'اسْتِفْصَالِ', #1
u'استفصال': u'اسْتِفْصَالَ', #2
u'استفصال': u'اسْتِفْصَالٍ', #6
u'استفصال': u'اسْتِفْصَالُ', #6
u'استفصاله': u'اسْتِفْصَالِهِ', #10
u'استفصاله': u'اسْتِفْصَالُهُ', #18
u'استفصالها': u'اسْتِفْصَالَهَا', #1
u'استفصالها': u'اسْتِفْصَالُهَا', #1
u'استفصالها': u'اسْتِفْصَالِهَا', #2
u'استفصالهما': u'اسْتِفْصَالُهُمَا', #4
u'استفصل': u'اسْتُفْصِلَ', #2
u'استفصل': u'اسْتَفْصَلَ', #4
u'استفصله': u'اسْتَفْصَلَهُ', #12
u'استفصلهم': u'اسْتَفْصَلَهُمْ', #2
u'استفضال': u'اسْتِفْضَالٌ', #4
u'استفضل': u'اسْتَفْضَلَ', #6
u'استفضلتماه': u'اسْتَفْضَلْتُمَاهُ', #1
u'استفضله': u'اسْتَفْضَلَهُ', #1
u'استفعال': u'اسْتِفْعَالُ', #1
u'استفعال': u'اِسْتِفْعَال', #1
u'استفعال': u'اسْتِفْعَالٌ', #28
u'استفعل': u'اسْتَفْعِلْ', #1
u'استفعل': u'اِسْتَفْعَلَ', #1
u'استفعل': u'اسْتَفْعَلَ', #15
u'استفكاك': u'اسْتِفْكَاكِ', #1
u'استفكه': u'اسْتَفَكَّهُ', #1
u'استفل': u'اسْتَفَلَ', #1
u'استفلا': u'اسْتَفَلَا', #1
u'استفلت': u'اسْتَفَلَّتْ', #1
u'استفلتوا': u'اسْتَفْلَتُوا', #1
u'استفلحي': u'اسْتَفْلِحِي', #2
u'استفلحى': u'اسْتَفْلِحِى', #2
u'استقاءة': u'اسْتِقَاءَةٌ', #2
u'استقاءته': u'اسْتِقَاءَتُهُ', #3
u'استقاد': u'اسْتَقَادَ', #10
u'استقادتهم': u'اسْتِقَادَتُهُمْ', #1
u'استقادوا': u'اسْتَقَادُوا', #3
u'استقاف': u'اسْتَقَافَ', #4
u'استقامواوروي': u'اسْتَقَامُواوَرُوِيَ', #1
u'استقبالالقبلة': u'اسْتِقْبَالِالْقِبْلَةِ', #1
u'استقباليته': u'اسْتِقْبَالِيَّتُهُ', #1
u'استقبلنى': u'اسْتَقْبَلَنِى', #2
u'استقتل': u'اُسْتُقْتِلَ', #1
u'استقد': u'اسْتَقِدْ', #7
u'استقدت': u'اسْتَقَدْتِ', #1
u'استقدت': u'اسْتَقَدْتُ', #2
u'استقذر': u'اسْتَقْذَرَ', #2
u'استقذر': u'اُسْتُقْذِرَ', #5
u'استقذرت': u'اسْتَقْذَرْتُ', #1
u'استقذرت': u'اُسْتُقْذِرَتْ', #1
u'استقذرته': u'اسْتَقْذَرْتَهُ', #1
u'استقذرها': u'اسْتَقْذَرَهَا', #1
u'استقذف': u'اسْتَقْذَفَ', #3
u'استقراب': u'اسْتِقْرَابِ', #2
u'استقراب': u'اسْتِقْرَابُ', #5
u'استقرابه': u'اسْتِقْرَابِهِ', #1
u'استقرابه': u'اسْتِقْرَابُهُ', #2
u'استقرب': u'اسْتَقْرَبَ', #21
u'استقربته': u'اسْتَقْرَبْتُهُ', #1
u'استقربناه': u'اسْتَقْرَبْنَاهُ', #1
u'استقربه': u'اسْتَقْرَبَهُ', #1
u'استقرض': u'استقرض', #1
u'استقرض': u'اسْتَقْرَض', #1
u'استقرض': u'اُسْتُقْرِضَ', #1
u'استقرض': u'اسْتَقْرَضَ', #450
u'استقرض': u'اسْتَقْرِضْ', #5
u'استقرض': u'اِسْتَقْرَضَ', #5
u'استقرضا': u'اسْتَقْرَضَا', #7
u'استقرضت': u'اسْتَقْرَضْتَ', #1
u'استقرضت': u'اسْتَقْرَضْتُ', #25
u'استقرضت': u'اسْتَقْرَضْت', #36
u'استقرضت': u'اسْتَقْرَضَتْ', #7
u'استقرضته': u'اسْتَقْرَضْته', #1
u'استقرضته': u'اسْتَقْرَضَتْهُ', #3
u'استقرضته': u'اسْتَقْرَضْتُهُ', #5
u'استقرضتها': u'اسْتَقْرَضْتُهَا', #1
u'استقرضتها': u'اسْتَقْرَضْتهَا', #4
u'استقرضك': u'اسْتَقْرَضَكَ', #1
u'استقرضك': u'اسْتَقْرَضَك', #3
u'استقرضنا': u'اسْتَقْرَضَنَا', #3
u'استقرضه': u'اسْتَقْرِضْهُ', #1
u'استقرضه': u'اسْتَقْرَضَهُ', #62
u'استقرضها': u'اسْتَقْرَضَهَا', #23
u'استقرضهما': u'اسْتَقْرَضَهُمَا', #1
u'استقرضوا': u'اسْتَقْرَضُوا', #1
u'استقرضوها': u'اسْتَقْرَضُوهَا', #1
u'استقرضي': u'اسْتَقْرِضِي', #4
u'استقصا': u'اسْتِقْصَا', #1
u'استقصار': u'اسْتِقْصَارٌ', #1
u'استقصار': u'اسْتِقْصَارٍ', #2
u'استقصار': u'اسْتِقْصَارُ', #2
u'استقصار': u'اِسْتِقْصَار', #2
u'استقصر': u'اسْتَقْصَرَ', #1
u'استقصرت': u'اسْتَقْصَرَتْ', #3
u'استقصره': u'اسْتَقْصَرَهُ', #1
u'استقصروا': u'اسْتَقْصَرُوا', #4
u'استقصروه': u'اسْتَقْصَرُوهُ', #1
u'استقض': u'اسْتَقْضِ', #3
u'استقضاء': u'اسْتِقْضَاءِ', #2
u'استقضاه': u'اسْتَقْضَاهُ', #17
u'استقضاؤه': u'اسْتِقْضَاؤُهُ', #1
u'استقضاؤها': u'اسْتِقْضَاؤُهَا', #1
u'استقضائهم': u'اسْتِقْضَائِهِمْ', #1
u'استقضى،': u'استقَضَى،', #1
u'استقضي': u'اُسْتُقْضِيَ', #15
u'استقضى': u'اسْتَقْضَى', #32
u'استقضيت': u'اُسْتُقْضِيَتْ', #3
u'استقطر': u'اُسْتُقْطِرَ', #1
u'استقطر': u'اِسْتَقْطَرَ', #2
u'استقطرت': u'اسْتَقْطَرَتْ', #1
u'استقطرت': u'اُسْتُقْطِرَتْ', #1
u'استقلالة': u'اسْتِقْلَالَةِ', #2
u'استقلعها': u'اسْتَقْلَعَهَا', #1
u'استقوينا': u'اسْتَقْوَيْنَا', #2
u'استقيدوا': u'اسْتَقِيدُوا', #1
u'استك': u'اسْتَكْ', #1
u'استك': u'اسْتُكَ', #1
u'استك': u'اسْتِكَ', #1
u'استك': u'اسْتُك', #6
u'أستكبرت': u'أَسْتَكْبَرْت', #1
u'استكتام': u'اسْتِكْتَامَ', #2
u'استكتام': u'اسْتِكْتَامُ', #2
u'استكتاما': u'اسْتِكْتَامًا', #1
u'استكتامه': u'اسْتِكْتَامِهِ', #1
u'استكتم': u'اسْتَكْتُمْ', #10
u'استكتم': u'اسْتَكْتَمَ', #2
u'استكتمت': u'اُسْتُكْتِمْت', #1
u'استكتمه': u'اُسْتُكْتِمَهُ', #1
u'استكتموا': u'اُسْتُكْتِمُوا', #1
u'إستكثره،': u'إستكثره،', #1
u'استكد': u'اسْتَكَدَّ', #1
u'استكدها': u'اسْتَكَدَّهَا', #1
u'استكدوني': u'اسْتَكَدُونِي', #1
u'استكديت': u'اسْتَكْدَيْتَ', #1
u'استكر': u'اسْتَكْرِ', #1
u'استكراء': u'اسْتِكْرَاءَ', #1
u'استكراء': u'اسْتِكْرَاءُ', #12
u'استكراء': u'اسْتِكْرَاءِ', #3
u'استكراهما': u'اسْتَكْرَاهُمَا', #2
u'استكراؤه': u'اسْتِكْرَاؤُهُ', #2
u'استكرائها': u'اسْتِكْرَائِهَا', #1
u'استكرش': u'اسْتَكْرَشَ', #1
u'استكروها': u'اسْتَكْرَوْهَا', #1
u'استكري': u'اُسْتُكْرِيَ', #1
u'استكرى': u'اسْتَكْرَى', #58
u'استكريا': u'اسْتَكْرَيَا', #1
u'استكريت': u'اسْتَكْرَيْت', #2
u'استكريت': u'اسْتَكْرَيْتَ', #2
u'استكريت': u'اُسْتُكْرِيَتْ', #30
u'استكريت': u'اسْتَكْرَيْتُ', #6
u'استكريتك': u'اسْتَكْرَيْتك', #1
u'استكساب': u'اسْتِكْسَابَ', #1
u'استكسب': u'اسْتَكْسَبَ', #1
u'استكسبت': u'اسْتَكْسَبَتْ', #1
u'استكسيت': u'استكسيت', #1
u'استكسيت': u'اسْتَكْسَيْت', #1
u'استكسيت': u'اسْتَكْسَيْتُ', #2
u'استكف': u'اسْتَكَفّ', #1
u'استكف': u'اسْتَكَفَّ', #1
u'استكف': u'اُسْتُكِفّ', #1
u'استكفاء': u'اسْتِكْفَاءٍ', #1
u'استكفاء': u'اسْتِكْفَاءُ', #1
u'استكفاء': u'اسْتِكْفَاءً', #2
u'استكفاف': u'اسْتِكْفَافٍ', #1
u'استكفاف': u'اسْتِكْفَافِ', #1
u'استكفافا': u'اسْتِكْفَافًا', #2
u'استكفاني': u'اسْتَكْفَانِي', #1
u'استكفى': u'اسْتَكْفَى', #3
u'استكفيتك': u'اسْتَكْفَيْتُك', #1
u'استلبث': u'استلبث', #1
u'استلبث': u'اسْتَلْبَثَ', #14
u'استلج': u'اِسْتَلَجَّ', #1
u'استلج': u'اسْتَلَجَّ', #7
u'استلجاجه': u'اسْتِلْجَاجِهِ', #1
u'استلجج': u'اِسْتَلْجَجَ', #1
u'استلجج': u'اسْتَلْجَجَ', #7
u'استلحاقة': u'اسْتِلْحَاقَةِ', #1
u'استلحق': u'اُسْتُلْحِقَ', #14
u'استلحق': u'اسْتَلْحَقَ', #210
u'استلحق': u'اسْتُلْحِقَ', #5
u'استلحقا': u'اسْتَلْحَقَا', #1
u'استلحقاه': u'اسْتَلْحَقَاهُ', #9
u'استلحقت': u'اُسْتُلْحِقَتْ', #1
u'استلحقته': u'اسْتَلْحَقَتْهُ', #11
u'استلحقه': u'اِسْتَلْحَقَهُ', #2
u'استلحقه': u'اسْتَلْحَقَهُ', #262
u'استلحقها': u'اسْتَلْحَقَهَا', #12
u'استلحقهم': u'اسْتَلْحَقَهُمْ', #4
u'استلحقهما': u'اسْتَلْحَقَهُمَا', #1
u'استلحقوه': u'اسْتَلْحَقُوهُ', #1
u'استلحقى': u'اسْتَلْحِقِى', #1
u'استلحمت': u'استلحمت', #1
u'استلحمه': u'استلْحمه', #1
u'استمتعى': u'اسْتَمْتِعِى', #1
u'استمخروا': u'اسْتَمْخِرُوا', #1
u'استمرى': u'اسْتَمْرَى', #2
u'استمشيت': u'اسْتَمْشَيْت', #1
u'استمشيت': u'اسْتَمْشَيْتُ', #1
u'استمكن': u'اسْتَمْكَنَ', #9
u'استمكنا': u'استمكنا', #1
u'استمكنا': u'اسْتَمْكَنّا', #2
u'استمكنت': u'اسْتَمْكَنَتْ', #1
u'استمكنت': u'اسْتَمْكَنْت', #1
u'استمكنت': u'اسْتَمْكَنْتُ', #6
u'استمكنوا': u'اسْتَمْكَنُوا', #3
u'استملك': u'اسْتَمْلَكَ', #1
u'استملك': u'اسْتُمْلِكَ', #1
u'استمنى': u'اسْتَمْنَى', #30
u'أستن': u'أَسْتَنُّ', #1
u'استن': u'اسْتَنَّ', #16
u'أستن': u'أَسْتَنَّ', #2
u'استن': u'اسْتَنّ', #2
u'استن': u'اُسْتُنَّ', #2
u'استن': u'اِسْتَنَّ', #3
u'استناب': u'اسْتَنَابَ', #202
u'استناباه': u'اسْتَنَابَاهُ', #3
u'استنابت': u'اسْتَنَابَتْ', #5
u'استنابنا': u'اسْتَنَابَنَا', #1
u'استنابه': u'اسْتَنَابَهُ', #75
u'استنابها': u'اسْتَنَابَهَا', #1
u'استناصوا': u'اسْتَنَاصُوا', #1
u'استنان': u'اسْتِنَانٍ', #1
u'استنان': u'اسْتِنَانِ', #21
u'استنان': u'اسْتِنَانٌ', #4
u'استنان': u'اِسْتِنَان', #6
u'استنان': u'اسْتِنَانَ', #7
u'استنان': u'اسْتِنَانُ', #8
u'استنانا': u'اسْتِنَانًا', #155
u'استنانه': u'اِسْتِنَانه', #1
u'استنانه': u'اسْتِنَانُهُ', #2
u'استنانه': u'اسْتِنَانَهُ', #3
u'استنانه': u'اسْتِنَانِهِ', #7
u'استنانها': u'اسْتِنَانَهَا', #1
u'استنانها': u'اسْتِنَانِهَا', #1
u'استنانها': u'اسْتِنَانُهَا', #3
u'استنب': u'اسْتَنِبْ', #5
u'استنبت': u'اسْتَنَبْت', #1
u'استنبت': u'اسْتَنَبْتَ', #1
u'استنبت': u'اسْتُنِبْتَ', #8
u'استنبت': u'اسْتَنْبَتَ', #9
u'استنبتك': u'اسْتَنَبْتُك', #4
u'استنبتك': u'اسْتَنَبْتُكَ', #6
u'استنبته': u'اسْتَنْبَتَهُ', #6
u'استنبتوه': u'اسْتَنْبَتُوهُ', #2
u'استنبه': u'اسْتَنْبَهَ', #1
u'استنت': u'استنت', #2
u'استنت': u'اسْتَنَّتْ', #7
u'استنتر': u'اسْتَنْتَرَ', #3
u'استنتلت': u'اسْتَنْتَلْتُ', #1
u'استنثار': u'اسْتِنْثَارِ', #1
u'استنثار': u'اسْتِنْثَارٌ', #3
u'استنثارا': u'اسْتِنْثَارًا', #7
u'استنثاره': u'اسْتِنْثَارُهُ', #2
u'استنثر،': u'اسْتَنْثَرَ،', #1
u'استنثر': u'اسْتَنْثَرَ', #11
u'استنثرت': u'اسْتَنْثَرْتَ', #1
u'استنثروا': u'اسْتَنْثِرُوا', #7
u'استنجاء': u'اسْتِنْجَاءً', #11
u'استنجاء': u'اسْتِنْجَاءٌ', #14
u'استنجاء': u'اسْتِنْجَاءَ', #15
u'استنجاء': u'اسْتِنْجَاءٍ', #28
u'استنجاء': u'اسْتِنْجَاءِ', #4
u'استنجاز': u'اسْتِنْجَازٌ', #1
u'استنجازا': u'اسْتِنْجَازًا', #1
u'استنجاؤه': u'اسْتِنْجَاؤُهُ', #7
u'استنجاؤها': u'اسْتِنْجَاؤُهَا', #1
u'استنجائه': u'اسْتِنْجَائِهِ', #29
u'استنجائها': u'اسْتِنْجَائِهَا', #6
u'استنجائهم': u'اسْتِنْجَائِهِمْ', #1
u'استنجزها': u'اسْتَنْجَزَهَا', #1
u'استنحت': u'اسْتَنَحْت', #2
u'استنزاه': u'اسْتِنْزَاهِ', #4
u'استنزهوا': u'اسْتَنْزِهُوا', #37
u'استنسأت': u'اسْتَنْسَأْتُ', #1
u'استنسبوا': u'اسْتَنْسَبُوا', #1
u'استنشدنى': u'اسْتَنْشَدَنِى', #1
u'استنصاته': u'اسْتِنْصَاتَهُ', #1
u'استنصاحه': u'اسْتِنْصَاحِهِ', #2
u'استنصت': u'اسْتَنْصَتَ', #2
u'استنصت': u'اِسْتَنْصِتْ', #2
u'استنصت': u'اسْتَنْصِتِ', #3
u'استنصت': u'اسْتَنْصِتْ', #7
u'استنصتني': u'اسْتَنْصَتَّنِي', #2
u'استنصته': u'اسْتَنْصَتَهُ', #1
u'استنصح': u'اُسْتُنْصِحَ', #1
u'استنصح': u'اسْتَنْصَحَ', #10
u'استنصحتني': u'اسْتَنْصَحْتنِي', #1
u'استنصحك': u'اسْتَنْصَحَك', #12
u'استنصحك': u'اسْتَنْصَحَكَ', #6
u'استنصحه': u'اسْتَنْصَحَهُ', #14
u'استنضه': u'اسْتَنَضَّهُ', #7
u'استنظاره': u'اسْتِنْظَارَهُ', #2
u'استنظارهم': u'اسْتِنْظَارَهُمْ', #2
u'استنظر': u'اسْتَنْظَرَ', #4
u'استنظرتك': u'اسْتَنْظَرْتُك', #1
u'استنظرك': u'اسْتَنْظَرَك', #17
u'استنظرك': u'اسْتَنْظَرَكَ', #5
u'استنظره': u'اسْتَنْظَرَهُ', #2
u'استنظروه': u'اسْتَنْظَرُوهُ', #5
u'استنفجنا': u'استنفجنا', #1
u'استنفعوا': u'اسْتَنْفِعُوا', #1
u'استنفق': u'اسْتَنْفَقَ', #1
u'استنفق': u'اسْتَنْفِقْ', #4
u'استنفقت': u'اسْتَنْفَقَتْ', #1
u'استنفقه': u'اسْتَنْفَقَهُ', #1
u'استنفقها': u'اسْتَنْفِقْهَا', #1
u'استنفقها': u'استنفقها', #2
u'استنفقها': u'اسْتَنْفَقَهَا', #3
u'استنفقوا': u'اسْتَنْفَقُوا', #1
u'استنفقوه': u'اسْتَنْفَقُوهُ', #3
u'استنقاص': u'اسْتِنْقَاصٌ', #1
u'استنقاص': u'اسْتِنْقَاصِ', #4
u'استنقاص': u'اسْتِنْقَاصُ', #6
u'استنقاع': u'اسْتِنْقَاعَ', #1
u'استنقائه': u'اسْتِنْقَائِهِ', #1
u'استنقده': u'اسْتَنْقِدْهُ', #2
u'استنقص': u'اِسْتَنْقَصَ', #1
u'استنقص': u'اسْتَنْقَصَ', #2
u'استنقصت': u'اسْتَنْقَصْتُ', #1
u'استنقصتم': u'اسْتَنْقَصْتُمْ', #1
u'استنقصها': u'اسْتَنْقَصَهَا', #1
u'استنقع': u'اسْتَنْقَعَ', #10
u'استنقعت': u'اسْتَنْقَعَتْ', #3
u'استنقعتم': u'اسْتَنْقَعْتُمْ', #1
u'استنقيت': u'اسْتَنْقَيْتُ', #1
u'استنكاح': u'اسْتِنْكَاحٍ', #1
u'استنكاح': u'اسْتِنْكَاحَ', #5
u'استنكاحا': u'اسْتِنْكَاحًا', #1
u'استنكاحه': u'اسْتِنْكَاحِهِ', #1
u'استنكاحها': u'اسْتِنْكَاحَهَا', #1
u'استنكاهه': u'اسْتِنْكَاهُهُ', #7
u'استنكحه': u'اسْتَنْكَحَهُ', #68
u'استنكه': u'استنكه', #1
u'استنكهوه': u'اسْتَنْكَهُوهُ', #1
u'استنكهوه': u'اسْتَنْكِهُوهُ', #1
u'استنما': u'اسْتَنْمَا', #3
u'استنماء': u'اسْتِنْمَاءَ', #1
u'استنماء': u'اسْتِنْمَاءٌ', #2
u'استنماء': u'اسْتِنْمَاءُ', #3
u'استنماء': u'اسْتِنْمَاءِ', #3
u'استنماءه': u'اسْتِنْمَاءَهَ', #1
u'استنماؤه': u'اسْتِنْمَاؤُهُ', #1
u'استنمائه': u'اسْتِنْمَائِهِ', #1
u'استنمت': u'اسْتَنْمَتْ', #2
u'استننت': u'اسْتَنَنْتُ', #1
u'استنهيناك': u'اسْتَنْهَيْنَاكَ', #3
u'استنوا': u'اسْتَنُّوا', #2
u'استنوق': u'اسْتَنْوَقَ', #3
u'استنيب': u'اُسْتُنِيبَ', #18
u'استنينا': u'اسْتَنَيْنَا', #1
u'إسته،': u'إِسْتَهُ،', #1
u'استه': u'اسْتَهُ', #1
u'استه،': u'اسْتِهِ،', #1
u'استه؟': u'اسْتَهُ؟', #1
u'استه': u'اسْتِهِ', #37
u'استه': u'اسْتُهُ', #4
u'إستها': u'إِسْتِهَا', #1
u'استها،': u'اسْتَهَا،', #1
u'استها': u'اسْتِهَا', #8
u'استهام': u'اسْتِهَامُ', #1
u'استهام': u'اِسْتِهَام', #1
u'استهدامه': u'اسْتِهْدَامِهِ', #1
u'استهدم': u'اسْتَهْدَمَ', #10
u'استهدم': u'اسْتُهْدِمَ', #24
u'استهدما': u'اسْتُهْدِمَا', #1
u'استهدمت': u'اسْتَهْدَمَتْ', #1
u'استهدمت': u'اسْتُهْدِمَتْ', #8
u'استهرموه': u'اسْتَهْرَمُوهُ', #1
u'استهزءوا': u'استهزءوا', #1
u'استهزءوا': u'اسْتَهْزَءُوا', #5
u'استهزأوا': u'اسْتَهْزَأُوا', #1
u'استهزؤا': u'اسْتَهْزَؤُا', #1
u'استهزى': u'اسْتَهْزَى', #1
u'استهزيتم': u'اسْتَهْزَيْتُمْ', #1
u'استهم': u'استهم', #1
u'استهما': u'اسْتَهُمَا', #1
u'استهما': u'اسْتِهِمَا', #1
u'استهما': u'اسْتَهَمَا', #2
u'استهما': u'اسْتَهِمَا', #28
u'استهموا': u'اسْتَهَمُّوا', #1
u'استهموا': u'اسْتَهَمُوا', #16
u'استوجه': u'اسْتَوْجَهُ', #1
u'استوجه': u'اسْتَوْجَهَ', #21
u'استوجهته': u'اسْتَوْجَهَتْهُ', #1
u'استوجهته': u'اسْتَوْجَهْتُهُ', #2
u'استوجهه': u'اسْتَوْجَهَهُ', #61
u'استوخم': u'اسْتَوْخَمَ', #3
u'استوخمنا': u'اسْتَوْخَمْنَا', #1
u'استوخموا': u'استوخموا', #1
u'استوخموا': u'اسْتَوْخَمُوا', #1
u'استوخموها': u'اسْتَوْخَمُوهَا', #1
u'استودعتكه': u'اسْتَوْدَعْتُكَهُ', #1
u'استودعتكها': u'اسْتَوْدَعَتْكهَا', #1
u'استودعتكها': u'اسْتَوْدَعْتُكَهَا', #4
u'أستودعكها': u'أَسْتَوْدِعُكَهَا', #1
u'أستودعكها': u'أَسْتَوْدِعْكَهَا', #1
u'استودعناكه': u'اسْتَوْدَعْنَاكَهُ', #1
u'استودعنيه': u'اسْتَوْدَعَنِيهِ', #2
u'استودعنيها': u'اسْتَوْدَعَنِيهَا', #2
u'استوزرتك': u'اسْتَوْزَرْتُكَ', #2
u'استوزره': u'اسْتَوْزَرَهُ', #2
u'استوسقوا': u'اسْتَوْسِقُوا', #2
u'استوضعه': u'اسْتَوْضَعَهُ', #2
u'استوطأ': u'اسْتَوْطَأَ', #1
u'استوعى': u'اسْتُوعِىَ', #3
u'استوعى': u'اسْتَوْعَى', #3
u'استوفز': u'اسْتَوْفَزَ', #2
u'استوفقه': u'اسْتَوْفَقَهُ', #1
u'أستوفيت': u'أَسْتُوْفِيَتْ', #1
u'استوكف': u'اسْتَوْكَفَ', #1
u'استوكف؟': u'اسْتَوْكَفَ؟', #1
u'استوكف': u'اِسْتَوْكَفَ', #2
u'استولاد': u'اسْتِوْلَادٌ', #1
u'استولاه': u'اسْتَوْلَاهُ', #1
u'استولته': u'اسْتَوْلَتْهُ', #2
u'استولج': u'اسْتُولِجَ', #2
u'استؤمن': u'اُسْتُؤْمِنَ', #9
u'استؤني': u'اسْتُؤْنِيَ', #1
u'استؤني': u'اُسْتُؤْنِيَ', #49
u'استوهب': u'اسْتَوْهِبْ', #1
u'استوهب': u'اُسْتُوْهِبَ', #2
u'استوهب': u'اسْتَوْهَبَ', #8
u'استوهبتك': u'اسْتَوْهَبْتُك', #1
u'استوهبته': u'اسْتَوْهَبَتْهُ', #1
u'استوهبتها': u'اسْتَوْهَبَتْهَا', #1
u'استوهبه': u'اسْتَوْهَبَهُ', #11
u'استوهبها': u'اسْتَوْهَبَهَا', #4
u'أستوى': u'أَسْتَوَى', #1
u'أستويا': u'أَسْتَوَيَا', #1
u'استويتا': u'اسْتَوَيَتَا', #5
u'استى': u'اسْتِى', #1
u'استي': u'اسْتِي', #7
u'استئجرت': u'اسْتُئْجِرَتْ', #1
u'استئداء': u'اسْتِئْدَاءُ', #1
u'إستئذنك': u'إستئذنك', #1
u'استئناء': u'اسْتِئْنَاءٌ', #1
u'استئناء': u'اسْتِئْنَاءَ', #1
u'استئناءه': u'اسْتِئْنَاءَهُ', #1
u'استئناؤهما': u'اسْتِئْنَاؤُهُمَا', #1
u'استياق': u'اسْتِيَاقُ', #1
u'استياك': u'اسْتِيَاكُ', #1
u'استياك': u'اسْتِيَاكِ', #1
u'استياك': u'اسْتِيَاكٍ', #5
u'استياك': u'اسْتِيَاكٌ', #6
u'استياكا': u'اسْتِيَاكًا', #7
u'استياكه': u'اسْتِيَاكَهُ', #1
u'استياكه': u'اسْتِيَاكُهُ', #2
u'استياكه': u'اسْتِيَاكِهِ', #2
u'استيام': u'اسْتِيَامٍ', #2
u'استيام': u'اسْتِيَامِ', #3
u'استيام': u'اسْتِيَامٌ', #5
u'استياما': u'اسْتِيَامًا', #8
u'استيثار': u'اسْتِيثَارُ', #1
u'استيثار': u'اسْتِيثَارِ', #1
u'استيثاره': u'اسْتِيثَارُهُ', #1
u'استيجاء': u'اسْتِيجَاءِ', #1
u'استيجاه': u'اسْتِيجَاهُ', #2
u'استيجاه': u'اسْتِيجَاهِ', #2
u'استيجاهه': u'اسْتِيجَاهِهِ', #1
u'استيجاهه': u'اسْتِيجَاهُهُ', #4
u'استيفاز': u'اسْتِيفَازِ', #3
u'آستيفاؤه': u'آسْتِيفَاؤُهُ', #1
u'استيق': u'اسْتِيقَ', #1
u'استيقت': u'اُسْتِيقَتْ', #1
u'استيمارها': u'اسْتِيمَارِهَا', #1
u'استيمان': u'اسْتِيمَانِ', #2
u'استيمانا': u'اسْتِيمَانًا', #1
u'استيناء': u'استيناء', #1
u'استيناء': u'اسْتِينَاءً', #1
u'استيناء': u'اسْتِينَاءٍ', #17
u'استيناء': u'اسْتِينَاءَ', #6
u'استينانا': u'اسْتِينَانًا', #1
u'استيهاب': u'اسْتِيهَابٍ', #1
u'استيهاب': u'اسْتِيهَابَ', #1
u'استيهاب': u'اسْتِيهَابُ', #1
u'استيهاب': u'اسْتِيهَابٌ', #2
u'استيهابه': u'اسْتِيهَابُهُ', #1
u'استيهابه': u'اسْتِيهَابَهُ', #2
u'أسجاعة': u'أَسَجَّاعَةٌ', #1
u'إسجال': u'إسْجَالُ', #2
u'إسجال': u'إسْجَالَ', #3
u'إسجال': u'إسْجَالِ', #4
u'إسجالا': u'إسْجَالًا', #1
u'إسجالات': u'إسْجَالَاتِ', #1
u'إسجاله': u'إسْجَالُهُ', #1
u'إسجاله': u'إسْجَالِهِ', #5
u'إسجالي': u'إسْجَالَيْ', #1
u'أسجح': u'أسجح', #1
u'اسحاق': u'اسحاق', #1
u'إسحاقإذا': u'إِسْحَاقَإِذَا', #1
u'إسحاقالحكيم': u'إِسْحَاقَالْحَكِيمُ', #1
u'إسحاقالعذاب': u'إِسْحَاقَالْعَذَابُ', #1
u'إسحاقالعزيز': u'إِسْحَاقَالْعَزِيزُ', #2
u'إسحاقإنه': u'إِسْحَاقَإِنَّهُ', #1
u'إسحاقثم': u'إِسْحَاقَثُمَّ', #1
u'إسحاقفأوحى': u'إِسْحَاقَفَأَوْحَى', #1
u'إسحاقفلما': u'إِسْحَاقَفَلَمَّا', #4
u'إسحاقفي': u'إِسْحَاقَفِي', #1
u'إسحاققال': u'إِسْحَاقَقَالَ', #1
u'إسحاققوله': u'إِسْحَاقَقَوْلُهُ', #1
u'إسحاقوإن': u'إِسْحَاقَوَإِنْ', #1
u'إسحاقوعلى': u'إِسْحَاقَوَعَلَى', #2
u'إسحاقوكان': u'إِسْحَاقَوَكَانَ', #2
u'أسحال': u'أَسْحَالٌ', #1
u'إسحق': u'إِسْحَق', #1
u'إسحق': u'إسْحَقَ', #20
u'إسحق': u'إِسْحَقَ', #32
u'إسحق': u'إِسْحَقُ', #5
u'اسحقونى': u'اسْحَقُونِى', #2
u'اسحكوني': u'اسْحَكُونِي', #1
u'أسحيم': u'أَسُحَيْمٌ', #1
u'أسدفا': u'أَسْدَفَا', #1
u'آسدكه': u'آسدكه', #1
u'إسرا': u'إسْرَا', #5
u'إسراده': u'إسْرَادَهُ', #1
u'إسرار': u'إسْرَارٌ', #2
u'إسرار': u'إسْرَارَ', #4
u'إسرار': u'إسْرَارِ', #6
u'إسرار': u'إسْرَارٍ', #7
u'إسرار': u'إسْرَارُ', #9
u'إسراره': u'إسْرَارِهِ', #12
u'إسراره': u'إسْرَارُهُ', #15
u'إسراره': u'إسْرَارَهُ', #2
u'إسرارها': u'إسْرَارُهَا', #6
u'إسرارهم': u'إسْرَارُهُمْ', #4
u'إسرافيل': u'إِسْرَافِيلُ', #1
u'إسرافيل': u'إسْرَافِيلَ', #12
u'إسرافيل': u'إسْرَافِيلُ', #13
u'إسرافيل': u'إِسْرَافِيلَ', #13
u'إسرافيل،': u'إِسْرَافِيلُ،', #2
u'إسرافيل،': u'إِسْرَافِيلَ،', #3
u'أسرائكم': u'أُسَرَائِكُمْ', #3
u'إسرائل': u'إسرائل', #1
u'أسرائنا': u'أُسَرَائِنَا', #1
u'أسرائها': u'أُسَرَائِهَا', #1
u'أسرائهم': u'أَسْرَائهُمْ', #1
u'أسرائهم': u'أَسْرَائِهِمْ', #1
u'أسرائهم': u'أُسَرَائِهِمْ', #7
u'اسرائيل': u'اسرائيل', #1
u'اسرائيل،': u'اسرائيل،', #2
u'إسرايين': u'إسْرَايِينُ', #1
u'أسرجة': u'أَسْرِجَةٍ', #3
u'اسرزنش': u'اسرزنش', #1
u'أسرغ': u'أسرغ', #2
u'اسرف': u'اسْرَفَ', #1
u'أسروشني': u'أُسْرُوشَنِيٌّ', #2
u'إسرئيل،': u'إسرئيلُ،', #1
u'أسطار': u'أَسْطَارٍ', #1
u'إسطاع': u'إسْطَاعَ', #2
u'اسطاع': u'اسْطَاعَ', #2
u'اسطاعوا': u'اسْطَاعُوا', #12
u'إسطام': u'إسْطَامٌ', #1
u'إسطاما': u'إسْطَامًا', #3
u'إسطاما': u'إِسْطَامًا', #3
u'أسطحة': u'أَسْطُحَةِ', #1
u'أسطحة': u'أَسْطِحَةٍ', #3
u'أسطحة': u'أَسْطِحَةِ', #7
u'اسطعت': u'اسْطَعْتَ', #4
u'أسطوان': u'أُسطوان', #1
u'أسطوان': u'أُسْطُوَانٌ', #1
u'أسطوان': u'أُسْطُوَانِ', #1
u'أسطوان': u'أُسْطُوَانُ', #2
u'أسطوان': u'أُسْطُوَانٍ', #4
u'أسطوانا': u'أَسْطُوَانًا', #1
u'أسطوانا': u'أُسْطُوَانًا', #4
u'أسطوانه': u'أُسْطُوَانِهِ', #1
u'أسطوانها': u'أُسْطُوَانِهَا', #1
u'أسطوم': u'أُسْطُومَ', #1
u'إسطياعا': u'إِسْطِيَاعًا', #1
u'إسعاط': u'إسْعَاطُ', #1
u'إسعاط': u'إسْعَاطٌ', #7
u'إسعاط': u'إسْعَاطٍ', #8
u'أسعدتنى': u'أَسْعَدَتْنِى', #2
u'أسعدونى': u'أَسْعَدُونِى', #2
u'أسعط': u'أَسُعِطَ', #1
u'أسعط': u'أُسْعِطَ', #1
u'أسعط': u'أَسَعْطَ', #2
u'أسعط': u'أَسْعَطَ', #2
u'أسعطه': u'أَسْعَطَهُ', #2
u'اسعيوا': u'اسْعَيُوا', #1
u'أسفرو': u'أَسْفِرُو', #1
u'إسفست': u'إسْفِسْتٌ', #1
u'اسفله': u'اسفله', #3
u'إسفندياذ': u'إسفندياذ', #4
u'أسفنديار': u'أسفنديار', #1
u'إسفنديار': u'إسفنديار', #1
u'أسفى': u'أَسَفَى', #23
u'أسفيداج': u'أسفيداج', #1
u'إسفيداج': u'إسْفِيدَاجِ', #1
u'اسفيدناجات': u'اسفيدناجات', #1
u'إسفيذاج': u'إسْفِيذَاجٌ', #2
u'إسفيذاج': u'إسْفِيذَاجُ', #2
u'اسفيذاج': u'اسْفِيذَاجٌ', #2
u'إسق': u'إسْقِ', #1
u'إسق': u'إِسْقُ', #1
u'إسق،': u'إِسْقٍ،', #1
u'إسقاء': u'إسْقَاءَ', #1
u'إسقاء': u'إسْقَاءِ', #4
u'إسقاط': u'إسْقَاطً', #1
u'إسقاطة': u'إسْقَاطَةِ', #1
u'إسقام': u'إِسْقَامِ', #1
u'أسقانى': u'أَسْقَانِى', #1
u'أسقانيها': u'أَسْقَانِيهَا', #1
u'إسقاؤه': u'إسْقَاؤُهُ', #5
u'إسقاؤها': u'إسْقَاؤُهَا', #1
u'إسقائه': u'إسْقَائِهِ', #2
u'إسقائها': u'إسْقَائِهَا', #8
u'أسقطو': u'أَسَقْطُو', #1
u'أسقفة': u'أَسْقُفَّةِ', #1
u'اسقنى': u'اسْقِنِى', #2
u'إسكاتة': u'إسْكَاتَةً', #1
u'إسكاتة،': u'إِسْكَاتَةً،', #1
u'اسكبى': u'اسْكُبِى', #4
u'إسكتا': u'إسْكِتَا', #1
u'اسكتاها': u'اسْكَتَاهَا', #1
u'إسكتاها': u'إسْكَتَاهَا', #4
u'إسكتي': u'إِسْكَتَيْ', #1
u'اسكتى': u'اسْكُتِى', #5
u'إسكتيها': u'إسْكَتَيْهَا', #1
u'اسكدار': u'اسكدار', #2
u'أسكفة': u'أَسْكُفَّةِ', #1
u'أسكفة': u'أَسْكِفَةِ', #1
u'أسكفة': u'أُسْكُفَّةَ', #1
u'أسكفة': u'أُسْكُفَّة', #2
u'أسكفة': u'أُسْكُفَّةِ', #25
u'أسكنتكها': u'أَسْكَنْتُكهَا', #1
u'أسكنتكها': u'أَسْكَنْتُكَهَا', #1
u'أسكنتنيه': u'أَسْكَنْتنِيهِ', #2
u'إسكنجبيل': u'إسْكَنْجَبِيل', #1
u'إسكندر': u'إسْكَنْدَرَ', #1
u'إسكندراني': u'إسْكَنْدَرَانِيٌّ', #2
u'إسكندرانيا': u'إسْكَنْدَرانِيًّا', #1
u'اسكندروس': u'اسكندروس', #1
u'اسكنى': u'اسْكُنِى', #1
u'اسكنيوروي': u'اسْكُنِيوَرُوِيَ', #1
u'إسلال': u'إسلال', #1
u'إسلال': u'إِسْلَالَ', #1
u'إسلال': u'إِسْلاَلَ', #1
u'إسلال': u'إسْلَالَ', #7
u'إسلامبول': u'إسلامبول', #1
u'إسلامبول': u'إسْلَامْبُول', #2
u'إسلامبول': u'إسْلَامْبُولَ', #3
u'إسلامبول': u'إسْلَامْبُولْ', #4
u'إسلامهSوأما': u'إسْلَامِهِSوَأَمّا', #1
u'أسلفتكه': u'أَسْلَفْتُكَهُ', #2
u'أسلفنى': u'أسلفنى', #1
u'أسلمأن': u'أَسْلَمَأَنَّ', #1
u'أسلمإن': u'أَسْلَمَإِنَّ', #1
u'اسلمت': u'اسلمت', #1
u'اسلمت،': u'اسلمت،', #1
u'أسلمعن': u'أَسْلَمَعَنْ', #1
u'أسلمو': u'أَسْلَمُو', #1
u'إسم': u'إسْمِ', #1
u'إسم': u'إسم', #5
u'اسماء': u'اسماء', #1
u'اسماعيل': u'اسماعيل', #1
u'اسماعيل': u'اسْمَاعِيلُ', #2
u'إسماعيلعن': u'إِسْمَاعِيلَعَنْ', #1
u'آسمان': u'آسَمَانِ', #1
u'إسمان': u'إسْمَانُ', #1
u'آسمان': u'آسْمَانِ', #3
u'أسماو': u'أَسْمَاوٌ', #1
u'أسمخة': u'أسمخة', #1
u'أسمختهم': u'أَسْمِخَتِهِمْ', #1
u'اسمدى': u'اسْمُدِى', #1
u'أسمعونى': u'أَسْمِعُونِى', #1
u'اسمعى': u'اسْمَعِى', #2
u'إسمعيل': u'إسْمَعِيلَ', #1
u'إسمعيل': u'إِسْمَعِيلَ', #11
u'إسمعيل': u'إِسْمَعِيلُ', #3
u'اسمى': u'اسْمِى', #14
u'اسميته': u'اسْمِيَّتِهِ', #1
u'اسميتها': u'اسْمِيَّتُهَا', #1
u'اسميتها': u'اسْمِيَّتِهَا', #1
u'إسنادة': u'إِسْنَادَة', #2
u'إسنادى': u'إِسْنَادِى', #1
u'أسنانى': u'أَسْنَانِى', #1
u'أسنتت': u'أَسْنَتَتِ', #1
u'أسنتوا': u'أَسْنَتُوا', #3
u'أسنع': u'أسنع', #1
u'أسنع': u'أَسْنَعَ', #2
u'اسنع': u'اسنع', #2
u'إسنوي': u'إسْنَوِيٌّ', #5
u'إسهم': u'إسهم', #1
u'أسوجة': u'أَسْوِجَةٌ', #1
u'أسودSشرح': u'أَسْوَدُSشَرْحُ', #1
u'إسود': u'إِسْوَدَّ', #2
u'أسودة': u'أَسْوَدَةٌ', #1
u'أسودة': u'أَسْوِدَةً', #1
u'أسودة،': u'أَسْوِدَةٌ،', #1
u'أسودة': u'أَسْوِدَةٌ', #12
u'أسودة': u'أَسْوَدَةً', #2
u'اسودين': u'اسودين', #1
u'أسوكتهم': u'أَسْوِكَتُهُمْ', #1
u'اسى': u'اسى', #1
u'آسيتن': u'آسَيْتُنّ', #2
u'اسيد': u'اسيد', #1
u'أسير': u'أَسِيرًًًًُ', #1
u'اسيست': u'اسيست', #1
u'أسيفع': u'أُسَيْفِعَ', #13
u'أسيفع': u'أُسَيْفِعُ', #2
u'أسيفع': u'أُسَيْفِعِ', #3
u'أسيلة': u'أَسِيلَةُ', #2
u'آش': u'آشٍ', #1
u'اش': u'اش', #1
u'اش': u'اشُ', #1
u'اش': u'اشِ', #1
u'أشاءة': u'أَشَاءَةٌ', #1
u'إشاءة': u'إِشَاءَة', #1
u'أشارإليه': u'أَشَارَإِلَيْهِ', #1
u'أشأزة': u'أَشْأَزَة', #1
u'أشأزه': u'أَشْأَزَهُ', #1
u'إشالة': u'إشَالَةُ', #3
u'إشالته': u'إشَالَتُهُ', #1
u'إشالته': u'إشَالَتِهِ', #1
u'إشالتها': u'إشَالَتِهَا', #1
u'أشاؤه': u'أَشَاؤُهُ', #2
u'أشبة': u'أَشَبَّةٌ', #1
u'أشبيب': u'أَشَبِيبٌ', #1
u'أشبيب': u'أَشُبَيْبٌ', #1
u'اشتاك': u'اشْتَاكَ', #1
u'أشتبهت': u'أَشْتَبَهَتْ', #1
u'أشتبهتا': u'أَشْتَبَهَتَا', #1
u'اشتبهتها': u'اشْتَبَهَتْهَا', #1
u'اشتبهه': u'اشْتَبَهَهُ', #1
u'أشتة': u'أُشْتَةَ', #1
u'اشتجار': u'اشْتِجَارٍ', #2
u'اشتجر': u'اشْتَجَرَ', #2
u'اشتجرا': u'اشْتَجَرَا', #2
u'اشتجروا،': u'اشْتَجَرُوا،', #1
u'اشتجروا': u'اِشْتَجَرُوا', #1
u'اشتجروا': u'اشْتَجَرُوا', #23
u'أشتدت': u'أشتدّت', #1
u'أشتدت': u'أَشْتَدَّتْ', #1
u'اشترا': u'اشْتَرَا', #1
u'اشتراك': u'اشْتِرَاكً', #1
u'اشترانى': u'اشْتَرَانِى', #1
u'أشتراه': u'أَشْتَرَاهُ', #1
u'أشتراها': u'أَشْتَرَاهَا', #1
u'اشترتنى': u'اشْتَرَتْنِى', #1
u'أشترطوه': u'أَشْتَرَطُوهُ', #1
u'اشترطى': u'اشْتَرِطِى', #3
u'أشتركك': u'أَشْتَرِكُكَ', #1
u'اشتركهما': u'اشْتَرَكَهُمَا', #1
u'آشتري': u'آشْتَرِي', #1
u'أشتريت': u'أشتريتِ', #1
u'أشتريت': u'أَشْتَرَيْت', #2
u'اشترينى': u'اشْتَرِينِى', #2
u'اشتغله': u'اشْتَغَلَهُ', #1
u'اشتغلها': u'اشْتَغَلَهَا', #1
u'اشتغلوها': u'اشْتَغَلُوهَا', #1
u'اشتفيت': u'اشْتَفَيْت', #1
u'اشتفيت': u'اشْتَفَيْتَ', #1
u'اشتفيت': u'اشْتَفَيْتُ', #1
u'اشتكاه': u'اشْتَكَاهُ', #1
u'اشتكاها': u'اشْتَكَاهَا', #2
u'اشتكاهما': u'اشْتَكَاهُمَا', #1
u'اشتكته': u'اِشْتَكَتْهُ', #1
u'اشتكل': u'اشْتَكَلَ', #1
u'أشتكها': u'أَشْتَكِهَا', #1
u'آشتكى': u'آشْتَكَى', #1
u'أشتكى': u'أَشْتَكَى', #1
u'أشتكى': u'أَشْتَكِى', #7
u'اشتكيتني': u'اشْتَكَيْتنِي', #1
u'اشتكيتها': u'اشتكيتُها', #1
u'اشتكيتها': u'اشْتَكَيْتُهَا', #1
u'أشتكيك': u'أَشْتَكِيك', #1
u'اشتمله': u'اشْتَمَلَهُ', #1
u'اشتوروا،': u'اشْتَوَرُوا،', #1
u'اشتووا': u'اشْتَوَوْا', #1
u'اشتووها': u'اشْتَوَوْهَا', #1
u'اشتوى': u'اشْتَوَى', #1
u'آشتى': u'آشَتَّى', #1
u'اشجتين': u'اشَّجَّتَيْنِ', #1
u'إشحان': u'إشْحَانُ', #1
u'إشحان': u'إشْحَانِ', #1
u'إشخاص': u'إشْخَاصَ', #1
u'إشخاص': u'إشْخَاصِ', #1
u'إشخاص': u'إشْخَاصُ', #3
u'إشخاصه': u'إشْخَاصَهُ', #1
u'إشخاصها': u'إشْخَاصِهَا', #1
u'أشدالوجه': u'أَشَدَّالْوَجْهُ', #1
u'إشدد': u'إشدد', #1
u'أشدهماويستخرجا': u'أَشُدَّهُمَاوَيَسْتَخْرِجَا', #1
u'أشراج': u'أَشْرَاجٌ', #1
u'اشرار': u'اشرار', #1
u'اشرافكم': u'اشرافكم', #1
u'أشرافيا': u'أَشْرَافِيًّا', #1
u'أشرافية': u'أَشْرَافِيَّةٌ', #1
u'إشراه': u'إِشْرَاهٍ', #1
u'اشربى': u'اشْرَبِى', #1
u'أشرفيته': u'أَشَرَفِيَّتَهُ', #1
u'أشرفيته': u'أَشْرَفِيَّتِهِ', #1
u'أشركتمون': u'أَشْرَكْتُمُونِ', #4
u'أشطأ': u'أَشْطَأَ', #2
u'إشطاطا': u'إشْطَاطًا', #1
u'اشعت': u'اشعت', #1
u'أشغاني': u'أَشْغَانِي', #1
u'أشغانيون': u'أشغانيون', #1
u'أشغلنى': u'أَشْغَلَنِى', #1
u'أشغى': u'أَشْغَى', #1
u'إشفاع': u'إشْفَاعٍ', #3
u'إشفاعا': u'إشْفَاعًا', #1
u'إشفاعه': u'إشْفَاعِهِ', #1
u'اشفعو': u'اشْفَعُو', #1
u'اشفنى': u'اشْفِنِى', #1
u'أشقاص': u'أَشْقَاصٍ', #4
u'أشقاصا': u'أَشْقَاصًا', #3
u'أشقاصه': u'أَشْقَاصُهُ', #1
u'إشقاقه': u'إشْقَاقُهُ', #4
u'أشقحت': u'أَشَقَحَتْ', #1
u'أشقياء': u'أَشْقِيَاءً', #1
u'أشكاب،': u'أَشْكَابٍ،', #1
u'إشكاب،': u'إشكاب،', #1
u'إشكاب،': u'إِشْكَابِ،', #1
u'إشكاب': u'إِشْكَابٍ', #11
u'إشكاب،': u'إِشْكَابَ،', #14
u'إشكاب،': u'إِشْكَابٍ،', #17
u'أشكاب': u'أشْكَابَ', #2
u'أشكاب،': u'أشْكَابَ،', #2
u'أشكاب': u'أَشْكَابٍ', #2
u'أشكاب،': u'أَشْكَابَ،', #3
u'إشكاب': u'إشْكَابَ', #3
u'إشكاب': u'إِشْكَابَ', #9
u'آشكار': u'آشكار', #1
u'آشكارا': u'آشكارا', #2
u'اشكمت': u'اشكمت', #1
u'اشكمت': u'اشِكَمَتْ', #2
u'إشكيب': u'إشْكِيبَ', #1
u'إشكيب،': u'إِشْكِيبَ،', #1
u'إشلاء': u'إشْلَاءً', #3
u'إشلائه': u'إشْلَائِهِ', #1
u'أشليت': u'أَشْلَيْتُ', #1
u'أشليت': u'أُشْلِيَتْ', #2
u'أشليته': u'أَشْلَيْتَهُ', #1
u'أشمذ': u'أَشْمَذَ', #1
u'أشمذان': u'أَشْمَذَانُ', #1
u'أشمذين': u'أَشْمَذِينَ', #2
u'أشمذين': u'أَشْمَذَيْنِ', #8
u'أشمط': u'أشمط', #1
u'أشمط': u'أَشَمَطَ', #1
u'أشمط': u'أَشَمَطُ', #1
u'أشمط': u'أَشْمَطَ', #4
u'أشمط': u'أَشْمَطُ', #6
u'اشمك': u'اشمك', #1
u'أشمويل': u'أَشْمَوِيلَ', #1
u'آشنا': u'آشَنًّا', #1
u'آشناء': u'آشناء', #1
u'أشنابى': u'أشنابى', #1
u'اشنابي': u'اشنابي', #1
u'آشناست': u'آشناست', #1
u'اشناست': u'اشناست', #2
u'إشنان': u'إشْنَانٌ', #2
u'أشنانة': u'أُشْنَانَةَ', #1
u'أشناى': u'أشناى', #1
u'اشناى': u'اشناى', #1
u'آشنايء': u'آشنايء', #1
u'أشهبيرد': u'أَشْهَبُيَرُدُّ', #1
u'أشهدنى': u'أَشْهَدَنِى', #1
u'اشهدى': u'اشْهَدِى', #1
u'أشهلى': u'أَشْهَلِىٌّ', #1
u'أشوابا': u'أَشْوَابًا', #1
u'أشىء': u'أَشَىْءٌ', #11
u'أشياءهموروي': u'أَشْيَاءَهُمْوَرُوِيَ', #1
u'أشياخى': u'أَشْيَاخِى', #1
u'أشياف': u'أَشْيَافَ', #1
u'أشيافا': u'أَشْيَافًا', #1
u'أشيافا': u'أَشِيَافًا', #2
u'أشيمط': u'أُشَيْمِطٌ', #1
u'أصابتنى': u'أَصَابَتْنِى', #11
u'أصابع': u'أَصَابِعً', #5
u'أصابعى': u'أَصَابِعِى', #5
u'أصابنى': u'أصابنى', #1
u'أصابنى': u'أَصَابَنِى', #12
u'أصاحيب': u'أَصَاحِيبُ', #1
u'آصاع': u'آصَاعٍ', #1
u'اصاف': u'اصَّافَّ', #1
u'إصانة': u'إصَانَةُ', #1
u'إصباغ': u'إصْبَاغٌ', #2
u'أصبتنى': u'أَصَبْتَنِى', #1
u'أصبحى': u'أَصْبِحِى', #1
u'اصبرنى': u'اصْبِرْنِى', #2
u'اصبرى': u'اصْبِرِى', #1
u'إصبعاك': u'إصْبَعَاك', #1
u'إصبعاك': u'إِصْبَعَاكَ', #1
u'إصبعان': u'إصْبَعَانِ', #13
u'إصبعاها': u'إصْبَعَاهَا', #2
u'إصبعى': u'إِصْبَعَىَّ', #2
u'إصبعى': u'إِصْبَعِى', #3
u'إصبعين': u'إِصْبَعَيْنِْْْْ', #1
u'اصبعين': u'اصْبَعِينِ', #1
u'إصبعين': u'إِصْبَعَيْنِ', #15
u'إصبعين،': u'إِصْبَعَيْنِ،', #2
u'إصبعين': u'إصْبَعَيْنِ', #36
u'أصبهان': u'أَصْبِهَانَ', #1
u'أصبهان،': u'أَصْبَهَانَ،', #1
u'أصبهان،': u'أصبهان،', #3
u'أصبهان': u'أَصْبَهَان', #3
u'إصبهان،': u'إِصْبَهَانَ،', #3
u'أصبهان': u'أصبهان', #4
u'أصبهان': u'أَصْبَهَانُ', #4
u'أصبهان': u'أَصْبَهَانَ', #52
u'أصبهاني': u'أَصْبَهَانِيٌّ', #3
u'أصبهانيا': u'أَصْبَهَانِيًّا', #1
u'أصبهانية': u'أَصْبَهَانِيَّةٍ', #1
u'أصبهبد': u'أَصْبَهْبُدَ', #1
u'إصبهبذ': u'إِصْبَهْبَذَ', #1
u'أصبوع': u'أُصْبُوعٍ', #1
u'أصبوع': u'أُصْبُوعٌ', #6
u'أصبوعا': u'أُصْبُوعًا', #2
u'أصبوعا': u'أُصْبُوعَا', #2
u'أصبوعين': u'أُصْبُوعَيْنِ', #1
u'أصحاء': u'أَصِحَّاءً', #1
u'أصحاب': u'أَصْحَابً', #1
u'اصحاب': u'اصحاب', #4
u'اصحابك': u'اصحابك', #1
u'اصحابه،': u'اصحابه،', #1
u'اصحابه': u'اصحابه', #5
u'أصحابيSقصة': u'أَصْحَابِيSقِصّةُ', #1
u'أصحابى؟': u'أَصْحَابِى؟', #2
u'أصحابى': u'أَصْحَابِى', #62
u'اصحبنى': u'اصْحَبْنِى', #2
u'أصحمة': u'أَصْحَمَةِ', #1
u'أصحمة': u'أَصْحَمَةَ', #12
u'أصحمة': u'أَصْحَمَةُ', #16
u'أصحمة': u'أَصْحَمَة', #2
u'أصخيان': u'أَصْخِيَانٍ', #2
u'اصدت': u'اِصَّدت', #1
u'أصدقنيه': u'أَصْدَقَنِيهِ', #2
u'اصدقى': u'اصْدُقِى', #1
u'إصراف': u'إصْرَافٌ', #1
u'إصرافة': u'إصْرَافَةٍ', #1
u'إصرام': u'إصْرَامِ', #1
u'أصرطة': u'أَصْرِطَةٌ', #1
u'أصرورة': u'أَصَرُورَةٌ', #1
u'إصريا': u'إِصْرِيَا', #1
u'أصطال': u'أَصْطَالٍ', #1
u'اصطبار': u'اصْطِبَارٌ', #1
u'اصطبار': u'اصْطِبَارٍ', #1
u'اصطبار': u'اصْطِبَارَ', #1
u'اصطبار': u'اصْطِبَارِ', #1
u'اصطباري': u'اصْطِبَارِي', #1
u'أصطبة': u'أُصْطُبَّةً', #1
u'أصطبة': u'أُصْطُبَّةٍ', #1
u'أصطبح': u'أَصْطَبِحْ', #1
u'اصطبح': u'اصْطَبَحَ', #5
u'اصطبخ': u'اُصْطُبِخَ', #1
u'إصطخر': u'إصْطَخر', #1
u'إصطخر': u'إصْطَخْرِ', #1
u'إصطخر': u'إِصْطَخَرٍ', #1
u'إصطخر': u'إِصْطَخَرَ', #1
u'إصطخر،': u'إِصْطَخْرَ،', #1
u'اصطخر،': u'اصطخر،', #1
u'إصطخر': u'إصْطَخْرَ', #2
u'اصطخر': u'اصْطَخْرَ', #2
u'إصطخر': u'إِصْطَخْرَ', #3
u'إصطخر': u'إِصْطَخْرُ', #3
u'إصطخر': u'إصْطَخْر', #6
u'إصطخري': u'إصْطَخْرِي', #1
u'اصطرف': u'اصْطَرَفَ', #9
u'اصطرفا': u'اصْطَرَفَا', #1
u'اصطرما': u'اصْطَرَمَا', #1
u'اصطلام': u'اصْطِلَامِ', #1
u'اصطلامهم': u'اصْطِلَامِهِمْ', #2
u'اصطلحته': u'اصْطَلَحْته', #1
u'أصطلحناه': u'أَصْطَلَحْنَاهُ', #2
u'اصطلحناه': u'اصْطَلَحْنَاهُ', #79
u'اصطلحه': u'اصْطَلَحَهُ', #3
u'أصطلحوا': u'أَصْطَلَحُوا', #1
u'اصطلم': u'اصْطَلَمَ', #24
u'اصطلمت': u'اصْطَلَمَتْ', #1
u'اصطلمت': u'اُصْطُلِمَتْ', #1
u'اصطلمتا': u'اصْطُلِمَتَا', #1
u'اصطلمتا': u'اُصْطُلِمَتَا', #1
u'اصطلمتا': u'اصْطَلَمَتَا', #3
u'اصطلمته': u'اصْطَلَمَتْهُ', #2
u'اصطلمه': u'اصْطَلَمَهُ', #3
u'اصطلمهم': u'اصْطَلَمَهُمْ', #1
u'آصع': u'آصُعٍ', #128
u'آصع': u'آصُعَ', #36
u'آصع': u'آصُعٌ', #4
u'آصع': u'آصُعِ', #5
u'آصعا': u'آصُعًا', #13
u'اصعادهم': u'اصْعَادُهُمْ', #1
u'إصعار': u'إصْعَارَ', #2
u'أصعر': u'أصعر', #1
u'أصعر،': u'أَصْعَرُ،', #1
u'أصعر': u'أَصْعَرُ', #2
u'آصعها': u'آصُعِهَا', #2
u'آصف': u'آصف', #1
u'آصف': u'آصَفَ', #1
u'آصف': u'آصَفِ', #1
u'آصف': u'آصْفٌ', #1
u'آصف': u'آصَفُ', #2
u'آصف': u'آصِفَ', #2
u'آصف': u'آصِفُ', #2
u'آصف': u'آصِفٌ', #3
u'آصفا': u'آصِفًا', #1
u'أصلحيته': u'أَصْلَحِيَّتُهُ', #1
u'أصلم': u'أَصْلَمُ', #1
u'آصلها': u'آصِلُهَا', #1
u'أصم': u'أَصَمًّ', #4
u'أصمع': u'أَصْمَعَ', #2
u'أصمعا': u'أَصْمَعَا', #1
u'أصمنيها': u'أَصَمَّنِيهَا', #3
u'أصميت': u'أَصْمَيْتَ', #13
u'أصميت': u'أَصَمَيْت', #3
u'أصميت': u'أَصْمَيْت', #3
u'أصميته': u'أَصْمَيْتَهُ', #1
u'اصنعى': u'اصْنَعِى', #2
u'إصهار': u'إصْهَارٍ', #1
u'أصؤع': u'أَصْؤُعَ', #2
u'أصي': u'أَصِي', #1
u'أصيبغ': u'أُصَيْبَغَ', #1
u'أصيحاب': u'أُصَيْحَاب', #1
u'أصيحابى': u'أُصَيْحَابِى', #2
u'أصيحابي': u'أُصَيْحَابِي', #4
u'أصيرم': u'أُصَيْرِمٍ', #1
u'أصيرم': u'أُصَيْرِم', #2
u'أصيرم': u'أُصَيْرِمُ', #2
u'أصيفر': u'أُصَيْفِرُ', #2
u'أصيلال': u'أُصَيْلَالٌ', #1
u'أصيلال': u'أُصَيْلَالٍ', #1
u'أصيلالا': u'أُصَيْلَالًا', #1
u'أصيلانا': u'أُصَيْلَانًا', #3
u'أصيلع': u'أُصَيْلِعَ', #1
u'أصيه': u'أَصِيهِ', #3
u'إضاء': u'إضَاءٌ', #2
u'أضاءة': u'أَضَاءَةٌ', #1
u'أضاءة': u'أَضَاءَةَ', #1
u'أضاءة': u'أَضَاءَةُ', #1
u'أضاءة': u'أَضَاءَةِ', #2
u'أضاة': u'أَضَاةً', #1
u'أضاة': u'أَضَاةٌ', #1
u'أضاة': u'أَضَاةٍ', #1
u'إضاة': u'إضَاةِ', #1
u'أضاة': u'أَضَاةِ', #12
u'أضاة': u'أَضَاة', #2
u'أضاة': u'أَضَاةَ', #2
u'أضاة': u'أَضَاةُ', #2
u'إضاحة': u'إضَاحَةِ', #3
u'أضاحى': u'أَضَاحِىَّ', #2
u'إضاقة': u'إضَاقَةُ', #1
u'إضاقة': u'إضَاقَةِ', #1
u'إضاقته': u'إضَاقَتِهِ', #1
u'أضبطيتها': u'أَضَبْطِيَّتُهَا', #1
u'اضتباع': u'اضْتِبَاعٌ', #1
u'اضتبع': u'اضْتَبَعَ', #2
u'أضجم': u'أَضْجَمُ', #1
u'إضحاة': u'إضْحَاةٌ', #1
u'اضحى': u'اضحى', #1
u'أضحيات': u'أُضْحِيَّاتٍ', #6
u'أضحيان': u'أَضْحِيَانٍ', #1
u'أضحيان': u'أَضْحِيَانَ', #1
u'إضحيان': u'إِضْحِيَانَ', #1
u'إضحيان،': u'إِضْحِيَانَ،', #1
u'إضحيان،': u'إِضْحِيَانٍ،', #2
u'إضداده': u'إضْدَادِهِ', #1
u'أضراسى': u'أَضْرَاسِى', #1
u'أضشوع،': u'أَضْشُوعٍ،', #1
u'اضطباع': u'اضْطِبَاعِ', #1
u'اضطباع': u'اضْطِبَاعٌ', #12
u'اضطباع': u'اضْطِبَاعٍ', #3
u'اضطباع': u'اضْطِبَاعَ', #4
u'اضطباعا': u'اضْطِبَاعًا', #6
u'اضطباعه': u'اضْطِبَاعُهُ', #1
u'اضطبع': u'اضْطَبَعَ', #22
u'اضطبعوا': u'اضْطَبَعُوا', #2
u'اضطراد': u'اضْطِرَادٍ', #1
u'اضطراد': u'اضْطِرَادِ', #1
u'اضطراده': u'اضْطِرَادِهِ', #1
u'اضطرد': u'اضْطَرَدَ', #4
u'اضطردت': u'اضْطَرَدَتْ', #1
u'اضطم': u'اضْطَمَّ', #1
u'اضطنى': u'اضْطَنَى', #1
u'اضطهار': u'اضْطِهَارٌ', #1
u'أضلنى': u'أَضَلَّنِى', #1
u'إضم': u'إضَم', #1
u'إضم،': u'إِضَمٍ،', #1
u'إضم': u'إضَمٍ', #11
u'إضم': u'إضَمٌ', #3
u'إضم': u'إِضَمٍ', #4
u'إضم': u'إِضَمَ', #6
u'إضم': u'إضَمَ', #7
u'إضما': u'إضَمًا', #3
u'أضوإ': u'أَضْوَإِ', #5
u'أضى': u'أضًى', #1
u'أضئون': u'أَضْئُونٌ', #1
u'أضيبع': u'أُضَيْبِعَ', #2
u'إضين': u'إضِينَ', #1
u'أط': u'أَطَّ', #1
u'إطابات': u'إطَابَاتٌ', #2
u'إطابة': u'إطَابَةً', #1
u'أطاشه': u'أَطَاشَهُ', #1
u'أطاعنى': u'أَطَاعَنِى', #10
u'اطاعهم،': u'اطاعهم،', #1
u'آطام': u'آطَامٌ', #2
u'آطام': u'آطَامُ', #2
u'آطام': u'آطَامِ', #9
u'آطامها': u'آطَامِهَا', #2
u'آطامهم': u'آطَامِهِمْ', #4
u'اطباء': u'اِطِّبَاء', #1
u'أطت': u'أَطَّتِ', #1
u'أطت': u'أَطَّتْ', #7
u'اطتلب': u'اطْتَلَبَ', #1
u'اطحنى': u'اطْحَنِى', #1
u'اطراح': u'اطِّرَاحٍ', #1
u'اطراح': u'اطِّرَاحِ', #1
u'اطراح': u'اطِّرَاحَ', #2
u'اطراح': u'اطِّرَاحُ', #3
u'إطراح': u'إطْرَاحِ', #5
u'إطراح': u'إطْرَاحُ', #7
u'إطراحا': u'إطْرَاحًا', #2
u'إطراحه': u'إطْرَاحِهِ', #1
u'إطراحه': u'إطْرَاحُهُ', #4
u'اطراحه': u'اطِّرَاحُهُ', #5
u'إطراحها': u'إطْرَاحَهَا', #1
u'إطراحها': u'إطْرَاحِهَا', #1
u'اطراحها': u'اطِّرَاحُهَا', #1
u'إطراحها': u'إطْرَاحُهَا', #2
u'إطراد': u'إطْرَادَ', #1
u'إطراد': u'إطْرَادُ', #1
u'إطراد': u'إطْرَادِ', #3
u'إطرادا': u'إطْرَادًا', #1
u'إطراده': u'إطْرَادُهُ', #1
u'إطراده': u'إطْرَادِهِ', #1
u'إطرادها': u'إطْرَادَهَا', #1
u'إطرادها': u'إطْرَادُهَا', #3
u'اطرافها': u'اطْرَافِهَا', #1
u'إطرة': u'إطْرَةِ', #1
u'اطرحته': u'اطَّرَحْتُهُ', #1
u'اطرغم': u'اطْرَغَمّ', #1
u'أطروشا': u'أُطْرُوشًا', #2
u'اطعام': u'اطِّعَامٍ', #1
u'اطعام': u'اطِّعَامِ', #1
u'أطعتيه': u'أَطَعْتِيهِ', #1
u'أطعمتكه': u'أَطْعَمْتُكَهُ', #2
u'أطعمتنى': u'أَطْعَمَتْنِى', #1
u'أطعمكموها': u'أَطْعَمَكُمُوهَا', #7
u'أطعمنى': u'أَطْعَمَنِى', #2
u'أطعمنى': u'أَطْعِمْنِى', #4
u'أطعمنيها': u'أَطْعَمَنِيهَا', #7
u'أطفاره': u'أَطِّفَارَهُ', #1
u'اطفها': u'اطْفُهَا', #2
u'أطفيته': u'أَطْفَيْتَهُ', #1
u'أطفيحي': u'أَطْفِيحِيٌّ', #1
u'إطفيحي': u'إطفيحي', #1
u'إطفيحي': u'إطْفِيحِيٌّ', #46
u'إطل': u'إطْلٍ', #1
u'إطلا': u'إطْلًا', #1
u'إطلا': u'إطْلَا', #2
u'إطلاء': u'إطْلَاءً', #1
u'إطلاء': u'إطْلَاءِ', #1
u'اطلاء': u'اطِّلَاءً', #1
u'اطلاء': u'اطِّلَاءٍ', #1
u'اطلاعة،': u'اطِّلَاعَةً،', #1
u'اطلاعة': u'اطِّلاَعَةً', #2
u'اطلاعة': u'اطِّلاعَةً', #3
u'اطلاعة': u'اطّلَاعَةً', #3
u'اطلاعة': u'اطِّلَاعَةً', #3
u'إطلاعة': u'إطْلَاعَةً', #4
u'اطلاعة،': u'اطِّلاعَةً،', #6
u'اطلاق': u'اطِّلَاقٌ', #1
u'اطلاقات': u'اطِّلَاقَاتٌ', #1
u'اطلاقات': u'اطِّلَاقَاتٍ', #1
u'إطلاقة': u'إطْلَاقَةُ', #1
u'إطلاقة': u'إطْلَاقَةِ', #1
u'اطلاقين': u'اطِّلَاقَيْنِ', #1
u'أطلعانى': u'أَطْلَعَانِى', #2
u'اطلعى': u'اطْلُعِى', #1
u'أطلقهمالنبي': u'أَطْلَقَهُمُالنَّبِيُّ', #1
u'اطلى': u'اِطَّلَى', #1
u'اطلى': u'اطَّلَى', #8
u'اطليت': u'اِطَّلَيْت', #1
u'أطمة': u'أَطَمَةِ', #1
u'أطمة': u'أُطُمَةَ', #1
u'أطمة': u'أَطَمَةٍ', #2
u'أطمة': u'أُطُمَةٍ', #2
u'اطمين': u'اطْمِينَ', #1
u'إطهارهن': u'إِطْهَارِهَنَّ', #1
u'أطؤ': u'أَطَؤُ', #1
u'أطواء': u'أَطْوَاءِ', #5
u'أطواف': u'أَطَوَافً', #1
u'أطواؤها': u'أَطْوَاؤُهَا', #4
u'أطوشه': u'أُطَوِّشْهُ', #1
u'أطوفة': u'أَطْوِفَةً', #1
u'أطوفة': u'أَطْوِفَةٍ', #1
u'أطؤك': u'أَطَؤُكَ', #1
u'أطؤك': u'أَطَؤُك', #116
u'أطؤك': u'أَطَؤُكِ', #70
u'أطؤكما': u'أَطَؤُكُمَا', #1
u'أطؤكن': u'أَطَؤُكُنَّ', #13
u'أطوليتها': u'أَطْوَلِيَّتِهَا', #1
u'أطؤه': u'أَطَؤُهُ', #1
u'أطؤها': u'أَطَؤُهَا', #54
u'أطؤهما': u'أَطَؤُهُمَا', #2
u'اطيب': u'اطيب', #1
u'أطيبيته': u'أَطْيَبِيَّتِهِ', #4
u'اطيرنا': u'اطَّيَّرْنَا', #1
u'اطيرنا': u'اطَّيْرَنَا', #2
u'أطيط': u'أطيط', #1
u'أطيط': u'أَطِيط', #1
u'أطيط': u'أَطِيطَ', #8
u'أطيطا': u'أَطِيطًا', #1
u'أطيعى': u'أَطِيعِى', #1
u'أطيفير': u'أطيفيرَ', #1
u'أطيفير،': u'أطيفير،', #1
u'أطيفير،': u'أُطَيْفِيرَ،', #1
u'أطيفير،': u'أُطَيْفِيرُ،', #1
u'أطيفير': u'أُطَيْفِيرُ', #4
u'اظاهر': u'اظَّاهَرَ', #1
u'اظاهرا': u'اظَّاهُرًا', #1
u'اظطلم': u'اظْطَلَمَ', #1
u'أظفارى': u'أَظْفَارِى', #5
u'أظفور': u'أُظْفُورٌ', #5
u'أظلتنى': u'أَظَلَّتْنِى', #1
u'أظننى': u'أَظُنُّنِى', #1
u'إظهار': u'إظْهَارً', #1
u'أظهر': u'أَظُهْرً', #1
u'اظهرا': u'اظَّهُّرًا', #1
u'أظهريته': u'أَظَهْرِيَّتِهِ', #1
u'أظؤر': u'أَظْؤُرٌ', #1
u'إعاتة': u'إعاتة', #1
u'إعاده': u'إعَادَهْ', #1
u'أعاذنى': u'أَعَاذَنِى', #1
u'إعارت': u'إعَارَتُ', #1
u'أعارنيه': u'أَعَارَنِيهِ', #12
u'أعاروكيه': u'أَعَارُوكِيهِ', #1
u'أعاطاه': u'أَعَاطَاهُ', #1
u'أعاننى': u'أَعَانَنِى', #2
u'اعتاص': u'اعْتَاصَ', #1
u'اعتاف': u'اعْتَافَ', #1
u'اعتافها': u'اعْتَافَهَا', #1
u'اعتاق': u'اعْتَاقَ', #2
u'اعتاقا': u'اعْتَاقَا', #2
u'اعتاقه': u'اعْتَاقَهُ', #6
u'اعتاقها': u'اعْتَاقَهَا', #1
u'اعتانوا': u'اعْتَانُوا', #1
u'أعتاهم': u'أَعْتَاهُمْ', #1
u'اعتباد': u'اعْتِبَادُ', #1
u'اعتبار': u'اعْتِبَارً', #1
u'اعتبد': u'اِعْتَبَدَ', #1
u'اعتبد': u'اعْتَبَدَ', #4
u'اعتجارا': u'اعْتِجَارًا', #2
u'اعتجر': u'اعْتَجَرَ', #3
u'أعتددت': u'أَعْتَدَدْتَ', #1
u'اعتذره': u'اعْتَذَرَهُ', #1
u'اعترارا': u'اعْتِرَارًا', #1
u'اعترضنى': u'اعْتَرَضَنِى', #1
u'اعترقت': u'اِعْتَرَقْت', #2
u'اعتزائه': u'اعْتِزَائِهِ', #2
u'إعتزلوا': u'إِعْتَزَلُوا', #1
u'أعتزي': u'أَعْتَزِي', #1
u'أعتزى': u'أَعْتَزَى', #1
u'اعتزى': u'اعْتَزَى', #15
u'اعتزيا': u'اعْتَزَيَا', #2
u'اعتضاد': u'اعْتِضَادٌ', #1
u'اعتضاد': u'اعْتِضَادِ', #4
u'اعتضاد': u'اعْتِضَادُ', #5
u'اعتضادا': u'اعْتِضَادًا', #2
u'اعتضاده': u'اعْتِضَادِهِ', #13
u'اعتضاده': u'اعْتِضَادُهُ', #5
u'اعتضادها': u'اعْتِضَادِهَا', #1
u'اعتضادهم': u'اعْتِضَادِهِمْ', #3
u'اعتضاضا': u'اعْتِضَاضًا', #1
u'اعتضد': u'اُعْتُضِدَ', #44
u'اعتضد': u'اعْتَضَدَ', #73
u'اعتضدت': u'اعْتَضَدَتْ', #11
u'اعتضدت': u'اُعْتُضِدَتْ', #2
u'اعتقاقها': u'اعْتِقَاقِهَا', #1
u'اعتقبه': u'اعْتَقَبَهُ', #1
u'أعتقتنى': u'أَعْتَقَتْنِى', #2
u'أعتقتنى': u'أَعْتَقْتَنِى', #2
u'أعتقتيه': u'أَعْتَقْتِيهِ', #1
u'أعتقنى': u'أَعْتَقَنِى', #1
u'أعتقنى؟': u'أَعْتَقَنِى؟', #1
u'إعتقي': u'إعتقي', #1
u'اعتكاف': u'اعْتِكافً', #1
u'أعتكفت': u'أَعْتَكَفْت', #2
u'أعتكفه': u'أَعْتَكِفُهُ', #1
u'اعتكفه': u'اعْتَكَفَهُ', #19
u'اعتكفها': u'اعْتَكَفَهَا', #4
u'اعتكفهن': u'اعْتَكَفَهُنَّ', #1
u'اعتلافها': u'اعْتِلَافِهَا', #3
u'اعتلاق': u'اعْتِلَاقُ', #1
u'اعتلج': u'اعْتَلَجَ', #1
u'اعتلف': u'اُعْتُلِفَ', #1
u'اعتلف': u'اعْتَلَفَ', #2
u'أعتلفت': u'أَعْتَلَفَتْ', #1
u'اعتلفت': u'اعْتَلَفَتْ', #23
u'اعتلفته': u'اعْتَلَفَتْهُ', #1
u'اعتلفه': u'اعْتَلَفَهُ', #1
u'اعتلق': u'اعْتَلَقَ', #2
u'اعتلق': u'اعْتَلَقْ', #7
u'اعتلقنا': u'اعتلقنا', #1
u'اعتمرتها': u'اعْتَمَرْتهَا', #1
u'اعتمره': u'اعْتَمَرَهُ', #17
u'اعتمرها': u'اعْتَمَرَهَا', #4
u'اعتمروها': u'اعْتَمَرُوهَا', #1
u'اعتمرى': u'اعْتَمِرِى', #2
u'اعتمل': u'اعْتَمَلَ', #1
u'أعتمل': u'أَعْتَمِلُ', #2
u'اعتملها': u'اعْتَمَلَهَا', #1
u'اعتملوا': u'اعْتَمَلُوا', #1
u'اعتوار': u'اعْتِوَارِ', #1
u'اعتور': u'اعْتَوَرَ', #1
u'اعتوراني': u'اعْتَوَرَانِي', #1
u'أعتى': u'أَعْتَى', #15
u'إعثار': u'إعْثَارِ', #1
u'أعجبتنى': u'أَعْجَبَتْنِى', #7
u'أعجبنى': u'أَعْجَبَنِى', #3
u'أعجمى': u'أَعْجَمِىَّ', #1
u'أعجمى': u'أَعْجَمِىُّ', #1
u'أعداس': u'أَعْدَاسٍ', #1
u'أعدائى': u'أَعْدَائِى', #1
u'إعراء': u'إعْرَاءَ', #1
u'إعراء': u'إعْرَاءُ', #1
u'إعراء': u'إِعْرَاء', #1
u'إعراء': u'إعْرَاءِ', #2
u'إعراء': u'إعْرَاءً', #3
u'أعرابى': u'أَعْرَابِىٍّ', #10
u'أعرابى': u'أَعْرَابِىُّ', #5
u'أعرابى': u'أَعْرَابِىٌّ', #80
u'إعراسا': u'إعْرَاسًا', #1
u'إعراضة': u'إعْرَاضَةً', #1
u'إعراؤه': u'إعْرَاؤُهُ', #1
u'إعرائه': u'إعْرَائِهِ', #5
u'إعرائها': u'إعْرَائِهَا', #1
u'أعرتكه': u'أَعَرْتُكَهُ', #13
u'أعرتكها': u'أَعَرْتُكَهَا', #6
u'أعرتكها': u'أَعَرْتُكهَا', #8
u'أعرتنيه': u'أَعَرْتنِيهِ', #1
u'أعرتنيه': u'أَعَرْتَنِيهِ', #1
u'أعرتنيها': u'أَعَرْتنِيهَا', #12
u'أعرتنيها': u'أَعَرْتَنِيهَا', #6
u'أعرص': u'أَعَرْصُ', #1
u'أعرص': u'أَعْرَصُ', #1
u'أعرضتمو': u'أَعْرَضْتُمُو', #1
u'أعرناكه': u'أَعَرْنَاكَهُ', #1
u'أعرناكهما': u'أَعَرْنَاكَهُمَا', #1
u'أعرنيه': u'أَعِرْنِيهِ', #1
u'أعرنيها': u'أَعِرْنِيهَا', #1
u'اعرورى': u'اعْرَوْرَى', #5
u'اعروريت': u'اعْرَوْرَيتُ', #2
u'اعروريت': u'اعْرَوْرَيْتُ', #2
u'اعروريته': u'اعْرَوْرَيْته', #1
u'أعزير': u'أَعُزَيْرٌ', #1
u'أعزيرا': u'أَعُزَيْرًا', #1
u'أعزيهود': u'أَعَزّيَهُودِ', #1
u'إعساله': u'إعْسَالَهُ', #1
u'إعساله': u'إعْسَالِهِ', #1
u'أعسم': u'أَعْسَمٍ', #1
u'أعسم': u'أَعْسَمَ', #3
u'أعشم': u'أَعْشَمَ', #1
u'أعصرتيه': u'أَعَصَرْتِيهِ', #2
u'أعصرتيها؟': u'أَعَصَرْتِيهَا؟', #1
u'إعضاده': u'إعْضَادُهُ', #1
u'إعضال': u'إعْضَالٍ', #1
u'إعضالا': u'إعْضَالًا', #2
u'إعضاله': u'إعْضَالِهِ', #1
u'إعضالها': u'إعْضَالَهَا', #1
u'أعضائى': u'أَعْضَائِى', #1
u'أعضب': u'أَعْضَبُ', #4
u'أعطاكموه': u'أَعْطَاكُمُوهُ', #1
u'أعطاكموها': u'أَعْطَاكُمُوهَا', #7
u'أعطاكه': u'أَعْطَاكَهُ', #32
u'أعطاكيه': u'أَعْطَاكِيهِ', #1
u'أعطان': u'أَعْطَانٍ', #1
u'أعطان': u'أَعْطَانِ', #51
u'أعطاناه': u'أَعْطَانَاهُ', #1
u'أعطاناها': u'أَعْطَانَاهَا', #1
u'أعطانه': u'أَعْطَانِهِ', #1
u'أعطانها': u'أَعْطَانُهَا', #1
u'أعطانها': u'أَعْطَانِهَا', #8
u'أعطانى': u'أَعْطَانِىَ', #1
u'أعطانى': u'أَعْطَانِى', #21
u'أعطانيه': u'أعطانيه', #1
u'أعطانيه': u'أَعْطَانِيهِ', #18
u'أعطانيها،': u'أَعْطَانِيهَا،', #1
u'أعطانيها': u'أَعْطَانِيهَا', #13
u'أعطانيهما': u'أَعْطَانِيهِمَا', #4
u'أعطانيهن،': u'أَعْطَانِيهِنَّ،', #1
u'أعطانيهن': u'أَعْطَانِيهِنَّ', #3
u'أعطاهموه': u'أَعْطَاهُمُوهُ', #3
u'أعطكه': u'أُعْطِكِهِ', #1
u'أعطكه': u'أُعْطِكَهُ', #5
u'أعطكها': u'أُعْطِكَهَا', #10
u'أعطنى': u'أعطنى', #1
u'أعطنى': u'أَعْطِنِى', #13
u'أعطنيه': u'أُعْطِنِيهِ', #1
u'أعطنيه': u'أَعْطِنِيهِ', #9
u'أعطنيها': u'أَعْطِنِيهَا', #2
u'أعطنيهن': u'أَعْطِنِيهِنَّ', #2
u'أعطونى': u'أَعْطُونِى', #1
u'أعطونى': u'أَعْطَوْنِى', #1
u'أعطونيه': u'أَعْطُونِيهِ', #1
u'أعطيات': u'أَعْطِيَاتٍ', #1
u'أعطيات': u'أُعْطَيَاتِ', #1
u'أعطيات': u'أُعْطِيَاتِ', #1
u'أعطيات': u'أُعْطِيَاتُ', #3
u'أعطيات': u'أَعْطِيَاتِ', #6
u'أعطياتكم،': u'أعطياتكم،', #1
u'أعطياتكم': u'أَعْطِيَاتِكُمْ', #2
u'أعطياتهم': u'أَعْطِيَاتِهُمْ', #1
u'أعطياتهم': u'أُعْطِيَاتِهِمْ', #1
u'أعطياتهم،': u'أُعْطِيَاتِهِمْ،', #1
u'أعطياتهم': u'أُعْطِيَّاتِهِمْ', #2
u'أعطياتهم': u'أَعْطِيَاتِهِمْ', #26
u'أعطياتهن': u'أَعْطِيَاتِهِنَّ', #1
u'أعطيتكموه': u'أَعْطَيْتُكُمُوهُ', #2
u'أعطيتكه': u'أعطيتُكَهُ', #1
u'أعطيتكه': u'أَعْطَيْتُكَهُ', #14
u'أعطيتكها،': u'أَعْطَيْتُكَهَا،', #1
u'أعطيتكها': u'أَعْطَيْتُكهَا', #11
u'أعطيتكها': u'أَعْطَيْتُكَهَا', #18
u'أعطيتنى': u'أَعْطَيْتَنِى', #6
u'أعطيتنيه': u'أَعْطَيْتنِيهِ', #3
u'أعطيتنيه': u'أَعْطَيْتَنِيهِ', #5
u'أعطيتنيها': u'أَعْطَيْتنِيهَا', #16
u'أعطيتنيها': u'أَعْطَيْتَنِيهَا', #5
u'اعطيته': u'اعطيته', #1
u'أعطيتيني': u'أَعْطَيْتِينِي', #26
u'أعطيكماه': u'أُعْطِيكُمَاهُ', #1
u'أعطيكه': u'أُعْطِيكَهُ', #26
u'أعطيكه': u'أُعْطِيَكَهُ', #6
u'أعطيكها': u'أُعْطِيَكهَا', #1
u'أعطيكها': u'أُعْطِيكَهَا', #16
u'أعطيكها': u'أُعْطِيكهَا', #4
u'أعطينيه': u'أَعْطِينِيهِ', #1
u'أعطينيه،': u'أَعْطِينِيهِ،', #1
u'أعفل': u'أَعْفُلْ', #1
u'إعقاق': u'إعْقَاقٌ', #2
u'أعقة': u'أَعِقَّةٌ', #1
u'أعقة': u'أَعِقَّةٍ', #1
u'أعكاما': u'أَعْكَامًا', #2
u'أعكامي،': u'أَعْكَامِي،', #1
u'أعكانها': u'أَعْكَانَهَا', #1
u'أعكانها': u'أَعْكَانُهَا', #1
u'أعكانها': u'أَعْكَانِهَا', #9
u'أعكرم': u'أعكرم', #1
u'أعكرم': u'أَعَكْرِمُ', #1
u'أعكرم': u'أَعِكْرِمَ', #1
u'إعلاف': u'إعْلَافِ', #1
u'إعلافه': u'إعْلَافِهِ', #2
u'إعلاق': u'إعْلَاقٍ', #5
u'اعلاه،': u'اعلاه،', #1
u'إعلم': u'إعلم', #1
u'إعلم': u'إعْلَمْ', #1
u'أعلمإلا': u'أَعْلَمُإِلَّا', #1
u'أعلمأنه': u'أَعْلَمُأَنَّهُ', #1
u'أعلمتمونى': u'أَعْلَمْتُمُونِى', #1
u'أعلمكها': u'أُعَلِّمَكَهَا', #1
u'أعلمكها': u'أُعَلِّمُكَهَا', #1
u'أعلمنى': u'أَعْلِمْنِى', #3
u'اعلوط': u'اعْلَوِّطْ', #1
u'اعمالهم': u'اعمالهم', #3
u'أعمالهموالوجه': u'أَعْمَالِهِمْوَالْوَجْهُ', #1
u'أعمالى': u'أَعْمَالِى', #1
u'أعمرتكها': u'أَعْمَرْتُكَهَا', #2
u'اعمشتا': u'اعْمَشَّتَا', #1
u'اعمني': u'اعْمِنِي', #2
u'اعناب': u'اعْنَابٍ', #2
u'أعنتنى': u'أَعَنْتَنِى', #1
u'اعوجاجة،': u'اعْوِجَاجَةً،', #1
u'أعونة': u'أَعْوِنَةٌ', #1
u'أعونة': u'أَعْوِنَةُ', #1
u'أعى': u'أَعِى', #2
u'أعيانى': u'أَعْيَانِى', #1
u'أعيتنى': u'أَعْيَتْنِى', #1
u'أعيجه': u'أُعِيجَهُ', #1
u'أعيركها': u'أُعِيرُكهَا', #1
u'أعيمش': u'أُعَيْمِشٌ', #1
u'اعينهم': u'اعْيُنُهُمْ', #2
u'أعينونى': u'أَعِينُونِى', #1
u'أعيى': u'أَعْيَى', #4
u'اعييتموني': u'اعييتموني', #1
u'أغا': u'أَغَا', #9
u'إغابة': u'إغَابَةِ', #1
u'إغابتها': u'إغَابَتِهَا', #4
u'أغاجي': u'أغاجي', #1
u'أغافصه': u'أَغَافَصَهُ', #3
u'أغانى': u'أَغَانِى', #1
u'أغاورهم': u'أغاورهم', #1
u'أغاولهم': u'أغاولهم', #1
u'إغباء': u'إغْبَاءٌ', #1
u'أغبس': u'أَغْبَسُ', #1
u'أغبط': u'أغبط', #1
u'أغبط': u'أَغْبَطِ', #1
u'أغبط': u'أَغْبِط', #1
u'أغبط': u'أُغْبَطُ', #1
u'أغبط': u'أَغْبَطُ', #19
u'أغبط': u'أَغْبِطُ', #2
u'أغبط': u'أُغْبِطَ', #2
u'أغبط': u'أَغْبَط', #3
u'أغبط': u'أَغْبَطَ', #39
u'أغبطا': u'أَغْبَطَا', #1
u'أغبطه': u'أَغْبِطُهُ', #1
u'أغبطها': u'أَغْبَطُهَا', #3
u'أغبطهما': u'أَغْبَطُهُمَا', #1
u'أغبق': u'أغبق', #1
u'أغبق': u'أَغْبُقُ', #1
u'أغبق': u'أَغْبِقَ', #1
u'أغبق': u'أَغْبِقُ', #5
u'أغبنن': u'أُغْبَنَنْ', #1
u'اغتاض': u'اغْتَاضَ', #1
u'أغتاما': u'أَغْتَامًا', #1
u'أغتبتك': u'أَغْتَبْتُكَ', #1
u'اغتبتيها': u'اغْتَبْتِيهَا', #6
u'اغتبق': u'اغْتَبَقَ', #1
u'أغتدي': u'أَغْتَدِي', #1
u'اغترام': u'اغْتِرَامٌ', #2
u'اغتراؤه': u'اغْتِرَاؤُهُ', #1
u'اغترسه': u'اغْتَرَسَهُ', #1
u'اغترق': u'اغْتَرَقَ', #11
u'اغترقت': u'اغْتَرَقَتْ', #5
u'اغترقه': u'اغْتَرَقَهُ', #7
u'اغتريا': u'اغْتَرَيَا', #1
u'اغتزاءه': u'اغْتِزَاءَهُ', #2
u'اغتزى': u'اغْتَزَى', #2
u'اغتزيا': u'اغْتَزَيَا', #3
u'اغتسالة': u'اغْتِسَالَةً', #1
u'اغتسله': u'اغْتَسَلَهُ', #1
u'اغتسلى': u'اغْتَسِلِى', #15
u'اغتص': u'اغْتَصَّ', #6
u'اغتصبنيها': u'اغْتَصَبَنِيهَا', #2
u'اغتصبنيها': u'اغْتَصَبْنِيهَا', #2
u'اغتفال': u'اغْتِفَالِ', #1
u'اغتفالها': u'اِغْتِفَالُهَا', #1
u'أغتفرت': u'أَغْتُفِرَتْ', #1
u'اغتفل': u'اغْتَفَلَ', #1
u'اغتفله': u'اغْتَفَلَهُ', #2
u'اغتلال': u'اغْتِلَالِ', #1
u'اغتلال': u'اغْتِلَالٍ', #8
u'اغتلالا': u'اغْتِلَالًا', #1
u'اغتلم': u'اغتلم', #1
u'اغتلم': u'اغْتَلَمَ', #1
u'اغتلم،': u'اغْتَلَمَ،', #1
u'اغتلمت': u'اِغْتَلَمَتْ', #1
u'اغتلمت': u'اغْتَلَمَتْ', #4
u'اغتلوا': u'اغْتَلُّوا', #2
u'اغتماض': u'اغْتِمَاضُ', #1
u'اغتمر': u'اغْتُمِرَ', #4
u'اغتمضي': u'اغْتَمِضِي', #1
u'أغثنى': u'أَغِثْنِى', #15
u'اغدودن': u'اغْدَوْدِنْ', #1
u'إغذاذا': u'إِغْذَاذًا', #1
u'إغرار': u'إغْرَارَ', #1
u'إغرار': u'إغْرَارٌ', #2
u'إغرار': u'إِغْرَارَ', #2
u'إغرارا': u'إِغْرَارًا', #1
u'إغرارا': u'إغْرَارًا', #4
u'أغرل': u'أَغْرَل', #1
u'أغرل': u'أغرل', #3
u'أغرل': u'أَغْرَلَ', #3
u'أغرل': u'أَغْرَلُ', #5
u'إغريض': u'إغْرِيضٌ', #1
u'إغريضا': u'إغْرِيضًا', #1
u'إغزاء': u'إغْزَاءَ', #1
u'إغزائهم': u'إغْزَائِهِمْ', #1
u'أغزني': u'أغزني', #1
u'اغسلنى': u'اغْسِلْنِى', #2
u'اغسلى': u'اغْسِلِى', #2
u'إغضاض': u'إغْضَاضُ', #1
u'اغطأل': u'اغْطَأَلّ', #1
u'إغفاره': u'إِغْفَارِهِ', #1
u'إغفارها': u'إِغْفَارُهَا', #1
u'أغلاث': u'أَغْلَاثِ', #1
u'أغلبس': u'أُغْلَبَس', #1
u'أغلوطات': u'أُغْلُوطَاتِ', #1
u'إغمارا': u'إغْمَارًا', #1
u'اغمزى': u'اغْمِزِى', #1
u'أغمى': u'أُغْمِى', #1
u'أغمى': u'أُغْمِىَ', #19
u'أغميت': u'أُغْمِيَتْ', #1
u'أغنط': u'أَغْنَطَ', #1
u'أغنط': u'أَغْنَطُ', #1
u'اغنني': u'اغْنَنِي', #1
u'اغنني': u'اغْنِنِي', #1
u'اغنوهم': u'اغْنَوْهُمْ', #1
u'اغنوهم': u'اغْنُوهُمْ', #5
u'أغنياء،': u'أَغْنِيَاءً،', #1
u'أغنياء': u'أَغْنِيَاءً', #11
u'اغنيت،': u'اغنيت،', #1
u'أغواث': u'أَغْوَاثٍ', #1
u'إغياء': u'إغْيَاءً', #2
u'إغياء': u'إغْيَاءٌ', #2
u'إغياما': u'إغْيَامًا', #1
u'إغيائه': u'إغْيَائِهِ', #1
u'آغية': u'آغِيَةٌ', #1
u'أغيت': u'أَغْيَتْ', #1
u'أغيلمة': u'أُغَيْلِمَةُ', #1
u'أغيلمة': u'أُغَيْلِمَةِ', #1
u'أغيلمة،': u'أُغَيْلِمَةٌ،', #1
u'أغيلمة': u'أُغَيْلِمَةٌ', #2
u'أغيلمة': u'أُغَيْلِمَةٍ', #2
u'أغيلمة': u'أُغَيْلِمَة', #3
u'أغيلمة': u'أُغَيْلِمَةً', #3
u'أغيلمة': u'أُغَيْلِمَةَ', #9
u'إف': u'إفَ', #1
u'إفاتة': u'إفَاتَةً', #3
u'إفاتة': u'إفَاتَةُ', #3
u'إفاتة': u'إفَاتَةِ', #5
u'إفاتته': u'إفَاتَتَهُ', #1
u'إفاتته': u'إفَاتَتِهِ', #1
u'إفاتته': u'إفَاتَتُهُ', #3
u'إفاتتها': u'إفَاتَتِهَا', #1
u'آفاد': u'آفَادَ', #1
u'أفادة': u'أَفَادَّةِ', #1
u'أفأسترقى': u'أَفَأَسْتَرْقِى', #1
u'أفأسترقي': u'أَفَأَسْتَرْقِي', #2
u'أفأستسر': u'أَفَأَسْتَسِرُّ', #1
u'أفاستنان': u'أَفَاسْتِنَانٌ', #2
u'أفاعين': u'أَفَاعِينُ', #1
u'أفائل': u'أَفَائِلَ', #3
u'أفإين': u'أَفَإِينْ', #1
u'أفإين': u'أَفَإيِنْ', #6
u'أفة': u'أَفَّةٌ', #1
u'افتات': u'اِفْتَاتَ', #1
u'افتات': u'افْتَاتَ', #21
u'افتادم': u'افتادم', #1
u'افتاده': u'افتاده', #1
u'افتاديم': u'افتاديم', #2
u'أفتانى': u'أَفْتَانِى', #3
u'أفتبيعنيه': u'أَفَتَبِيعُنِيهِ', #1
u'افتتلت': u'افْتَتَلَتْ', #1
u'افتتلت': u'افْتُتِلَتْ', #4
u'أفتدت': u'أَفْتَدَتْ', #1
u'افتراع': u'افْتِرَاعِ', #6
u'افتراعها': u'افْتِرَاعَهَا', #1
u'افترصوها،': u'افْتَرَصُوهَا،', #1
u'افترعها': u'افْتَرَعَهَا', #1
u'افتض': u'افْتَضَّ', #23
u'افتضاء': u'افْتِضَاءِ', #1
u'افتضاها': u'افْتَضَّاهَا', #1
u'افتضت': u'اُفْتُضَّتْ', #4
u'افتضخ': u'افْتُضِخَ', #1
u'افتضضتك': u'افْتَضَضْتُكِ', #2
u'افتضضتك': u'افْتَضَضْتُك', #4
u'افتضك': u'افْتَضَّك', #1
u'افتضك': u'افْتَضَّكِ', #1
u'أفتضك': u'أَفْتَضُّك', #2
u'أفتضك': u'أَفْتَضُّكِ', #2
u'افتضني': u'افْتَضَّنِي', #3
u'أفتضها': u'أَفْتَضَّهَا', #1
u'افتضها': u'افْتَضَّهَا', #35
u'افتضهما': u'افْتَضَّهُمَا', #1
u'أفتقرت': u'أفتقرت', #1
u'افتكاك': u'افْتِكَاكَ', #2
u'افتكاك': u'افْتِكَاكُ', #3
u'افتكاك': u'افْتِكَاكِ', #6
u'افتكاكا': u'افْتِكَاكًا', #1
u'افتكاكه': u'افْتِكَاكُهُ', #1
u'افتكاكه': u'افْتِكَاكِهِ', #13
u'افتكاكه': u'افْتِكَاكَهُ', #2
u'افتكاكها': u'افْتِكَاكِهَا', #5
u'افتكاكهم': u'افْتِكَاكِهِمْ', #6
u'افتكت': u'اُفْتُكَّتْ', #1
u'افتككته': u'افْتَكَكْتَهُ', #1
u'افتككته': u'افْتَكَكْتُهُ', #2
u'افتكيته': u'افْتَكَّيْتُهُ', #1
u'افتلاتا': u'افْتِلَاتًا', #1
u'افتلاتا': u'افْتِلَاتَا', #1
u'افتلتت': u'افْتَلَتَتْ', #2
u'افتلتت': u'افتلتت', #3
u'افتلتت': u'اُفْتُلِتَتْ', #5
u'افتلتت': u'افْتُلِتَتْ', #9
u'افتلته': u'اِفْتَلَتَهُ', #2
u'افتلتها': u'اِفْتَلَتَهَا', #1
u'أفتلومنى': u'أَفَتَلُومُنِى', #1
u'أفتنى': u'أَفْتِنِى', #6
u'افتوات': u'افْتِوَاتٌ', #1
u'افتئت': u'اُفْتُئِتَ', #1
u'افتيات': u'افْتِيَاتٌ', #18
u'افتيات': u'افْتِيَاتٍ', #6
u'افتيات': u'افْتِيَاتَ', #7
u'افتياتا': u'افْتِيَاتًا', #33
u'افتياته': u'افْتِيَاتَهُ', #1
u'افتياته': u'افْتِيَاتِهِ', #1
u'افتياته': u'افْتِيَاتُهُ', #2
u'افتياتهم': u'افْتِيَاتِهِمْ', #1
u'افتيت': u'اُفْتِيتَ', #17
u'أفحوصة': u'أفحوصة', #1
u'أفدة': u'أَفِدَةٌ', #1
u'أفدتناه': u'أَفَدْتنَاهُ', #1
u'إفراء': u'إفْرَاءُ', #1
u'إفراز': u'إفْرَازً', #1
u'إفراغة': u'إفْرَاغَةُ', #1
u'أفرائيم': u'أَفْرَائِيمَ', #1
u'أفردنى': u'أَفْرِدْنِى', #1
u'افرستا': u'افرستا', #1
u'إفرض': u'إِفْرِضْ', #1
u'افركى': u'افْرُكِى', #1
u'إفرنسي': u'إفْرِنْسِيٌّ', #1
u'إفرنسي': u'إفْرِنْسِيٍّ', #2
u'إفرنسيا': u'إفْرِنْسِيًّا', #1
u'إفرنسية': u'إفْرِنْسِيَّةٌ', #1
u'آفريد': u'آفريد', #2
u'آفريده': u'آفريده', #2
u'أفريذون': u'أَفْرِيذُونُ', #1
u'أفريذون': u'أفريذون', #2
u'أفريقس': u'أفريقس', #1
u'أفزاع': u'أَفْزَاعِ', #2
u'أفساحك': u'أَفَسَاحَك', #1
u'إفسوس': u'إفسوس', #1
u'أفشىء': u'أَفَشَىْءٌ', #1
u'إفضاحه': u'إفْضَاحُهُ', #1
u'أفضكها': u'أَفُضَّكَهَا', #2
u'افضى': u'افضى', #1
u'أفظعنى': u'أَفْظَعَنِى', #1
u'أفظعيته': u'أَفْظَعِيَّتَهُ', #1
u'افع': u'افْعَ', #1
u'افع': u'افْعِ', #1
u'افع': u'افْعٌ', #3
u'أفعاء': u'أَفْعَاءُ', #1
u'إفعال': u'إفْعَالُ', #1
u'إفعال': u'إفْعَالِ', #1
u'إفعال': u'إفْعَالٌ', #4
u'إفعال': u'إفْعَالٍ', #5
u'إفعالا': u'إفْعَالًا', #1
u'إفعان': u'إفْعَانٌ', #1
u'إفعل': u'إفَّعَلُ', #2
u'افعلال': u'افْعِلَالٌ', #1
u'إفعلان': u'إفْعِلَانٌ', #1
u'إفعلوا،': u'إفْعَلُوا،', #1
u'افعلى': u'افْعَلِى', #2
u'افعوعل': u'اِفْعَوْعَل', #1
u'افعوعل': u'اِفْعَوْعَلَ', #1
u'إفعيل': u'إفْعِيلٌ', #1
u'إفعيلاء': u'إفْعِيلَاءُ', #1
u'أفقرنى': u'أَفْقَرَنِى', #1
u'أفقهيتهم': u'أَفْقَهِيَّتَهُمْ', #1
u'آفقي': u'آفَقِيٌّ', #1
u'إفكاكها': u'إفْكَاكِهَا', #1
u'افكندم': u'افكندم', #2
u'افكندن': u'افكندن', #1
u'أفلاء': u'أَفْلَاء', #2
u'أفلاء': u'أَفْلَاءٌ', #2
u'أفلاء': u'أَفْلَاءُ', #2
u'أفلاءها': u'أَفْلَاءَهَا', #2
u'أفلاطون': u'أَفْلَاطُونُ', #5
u'أفلاطون': u'أَفْلَاطُونَ', #6
u'أفلائها': u'أَفْلَائِهَا', #1
u'افلعلت': u'افْلَعَلّتْ', #1
u'إفناد': u'إفْنَادِ', #4
u'أفنائه': u'أَفْنَائِهِ', #1
u'أفنائها': u'أَفْنَائِهَا', #1
u'أفنائهم': u'أَفْنَائِهِمْ', #1
u'أفنتكتم': u'أَفَنَتَكَتَّمُ', #1
u'أفنيتموها': u'أَفْنَيْتُمُوهَا', #1
u'أفهق': u'أفهق', #1
u'أفهقت': u'أَفْهَقْتُ', #1
u'أفهقناه': u'أَفْهَقْنَاهُ', #1
u'أفهقها': u'أَفْهَقَهَا', #1
u'أفهمنى': u'أَفْهَمَنِى', #1
u'أفواز': u'أَفْوَازَ', #1
u'أفوس': u'أفوس', #1
u'أفى': u'أَفِى', #26
u'اق': u'اق', #2
u'اق': u'اُقْ', #2
u'أقارير': u'أَقَارِيرَ', #2
u'أقارير': u'أَقَارِيرُ', #2
u'أقارير': u'أَقَارِيرِ', #3
u'أقاريره': u'أَقَارِيرِهِ', #5
u'أقاريرهم': u'أَقَارِيرِهِمْ', #3
u'أقاطيع': u'أَقَاطِيعُ', #1
u'إقاله': u'إقَالَهْ', #4
u'أقالوناها': u'أَقَالُونَاهَا', #1
u'إقام': u'إقَامِ', #1
u'إقام': u'إِقَامَ', #1
u'إقام': u'إِقَامِ', #12
u'إقام': u'إِقَام', #2
u'إقام': u'إِقَامُ', #3
u'إقامةالعيد': u'إقَامَةِالْعِيدِ', #1
u'أقامنى': u'أَقَامَنِى', #3
u'آقامه': u'آقَامَهُ', #1
u'إقامه': u'إقَامِهِ', #2
u'أقاهيد': u'أقاهيد', #1
u'إقباض': u'إقْبَاضُ', #12
u'إقباض': u'إقْبَاضٌ', #13
u'إقباض': u'إقْبَاضٍ', #31
u'إقباض': u'إقْبَاضِ', #38
u'إقباض': u'إقْبَاضَ', #4
u'إقباضا': u'إقْبَاضًا', #10
u'إقباضه': u'إقْبَاضَهُ', #14
u'إقباضه': u'إقْبَاضُهُ', #23
u'إقباضه': u'إقْبَاضِهِ', #77
u'إقباضها': u'إقْبَاضِهَا', #17
u'إقباضها': u'إقْبَاضَهَا', #2
u'إقباضها': u'إقْبَاضُهَا', #5
u'إقباضهم': u'إقْبَاضِهِمْ', #1
u'إقباضهما': u'إقْبَاضَهُمَا', #1
u'إقباضهما': u'إقْبَاضِهِمَا', #7
u'أقبرس': u'أقبرس', #1
u'اقبسنى': u'اقْبِسْنِى', #1
u'أقبضتكه': u'أَقْبَضْتُكَهُ', #1
u'أقبضتكها': u'أَقْبَضْتُكهَا', #1
u'أقبضتكها': u'أَقْبَضْتُكَهَا', #1
u'أقبضتنيه': u'أَقْبَضَتْنِيهِ', #1
u'أقبضتيني': u'أَقْبَضْتِينِي', #2
u'اقبضنى': u'اقْبِضْنِى', #1
u'أقبضنيه': u'أَقْبَضَنِيهِ', #1
u'أقبضنيه': u'أَقْبِضْنِيهِ', #1
u'إقبل': u'إقْبَلْ', #1
u'أقبلى': u'أَقْبِلِى', #1
u'أقة': u'أُقَّةِ', #3
u'أقة': u'أُقَّةً', #5
u'أقة': u'أُقَّةَ', #5
u'أقة': u'أُقَّةٍ', #9
u'أقتاب': u'أقتاب', #1
u'أقتاب': u'أَقْتَابِ', #1
u'أقتاب': u'أَقْتَابٍ', #2
u'أقتاب': u'أَقْتَابُ', #8
u'أقتابا': u'أَقْتَابًا', #2
u'أقتابه': u'أَقْتَابُهُ', #8
u'اقتاس': u'اقْتَاسَ', #2
u'أقتب': u'أَقَتَبَ', #1
u'اقتبال': u'اقْتِبَالِ', #1
u'اقتدا': u'اقْتِدَا', #7
u'اقتداح': u'اقْتِدَاحِ', #1
u'أقتدوا': u'أَقْتَدَوْا', #1
u'أقتديتم': u'أَقْتَدَيْتُمْ', #1
u'اقترأ': u'اقْتَرَأَ', #4
u'اقترانيا': u'اقْتِرَانِيًّا', #1
u'اقترانيين': u'اقْتِرَانِيَّيْنِ', #1
u'اقترأها': u'اقْتَرَأَهَا', #1
u'اقتربه': u'اقْتَرَبَهُ', #1
u'اقتسارا': u'اقْتِسَارًا', #1
u'أقتسما': u'أَقْتَسَمَا', #1
u'اقتصاه': u'اقْتَصَّاهُ', #1
u'اقتصته': u'اقْتَصَّتْهُ', #1
u'اقتضاض': u'اقْتِضَاضٍ', #1
u'اقتضاض': u'اقْتِضَاضُ', #1
u'اقتضاض': u'اقْتِضَاضِ', #5
u'اقتضاضها': u'اقْتِضَاضُهَا', #1
u'أقتضت': u'أَقْتَضَتْ', #1
u'اقتضضتك': u'اقْتَضَضْتُكِ', #4
u'اقتطرها': u'اقْتَطَرَهَا', #1
u'اقتعاط': u'اقْتِعَاطٌ', #1
u'اقتعاط': u'اقْتِعَاطَ', #1
u'اقتعاط': u'اقْتِعَاطُ', #2
u'اقتعاطا': u'اقْتِعَاطًا', #2
u'اقتعط': u'اقْتَعَطَ', #1
u'اقتعطها': u'اقْتَعَطَهَا', #1
u'اقتلنى': u'اقْتُلْنِى', #3
u'اقتلونى': u'اقْتُلُونِى', #1
u'اقجة': u'اقجة', #1
u'اقجه': u'اقجه', #1
u'إقدار': u'إقْدَارِ', #2
u'إقدارا': u'إقْدَارًا', #1
u'إقداره': u'إقْدَارَهُ', #1
u'اقدعوا': u'اقْدَعُوا', #1
u'أقدمنيها': u'أَقْدَمَنِيهَا', #1
u'أقدنى': u'أَقِدْنِى', #11
u'أقرءوا': u'أَقْرَءُوا', #1
u'اقرءوا': u'اقرءوا', #1
u'اقرءوا،': u'اقْرَءُوا،', #1
u'اقرءوا': u'اقْرَءُوا', #159
u'اقرءوه': u'اِقْرَءُوهُ', #1
u'اقرءوها': u'اقْرَءُوهَا', #5
u'آقرأ': u'آقْرَأُ', #1
u'اقرا': u'اقْرَا', #1
u'اقرإ': u'اقْرَإِ', #16
u'اقرأا': u'اقْرَأَا', #1
u'أقراباذين': u'أقراباذين', #1
u'اقرأباسم': u'اقْرَأْبِاسْمِ', #1
u'أقرأتكه': u'أَقْرَأْتُكَهُ', #2
u'أقرأتنى': u'أَقْرَأْتَنِى', #1
u'أقرأتنيها': u'أَقْرَأْتنِيهَا', #1
u'أقرأتنيها': u'أَقْرَأْتَنِيهَا', #6
u'إقرار': u'إقْرَارً', #1
u'إقرارة': u'إقرارة', #1
u'إقرارته': u'إقْرَارَتِهِ', #1
u'أقرأكها': u'أَقْرَأَكَهَا', #3
u'أقرانى': u'أَقْرَانِى', #1
u'أقرأنى': u'أَقْرَأَنِى', #5
u'أقرأنيه': u'أَقْرَأَنِيهِ', #2
u'أقرأنيها': u'أقرأنيها', #1
u'أقرأنيها': u'أَقْرَأَنِيهَا', #28
u'اقرأوا': u'اقرأوا', #2
u'اقرأوا': u'اقْرَأُوا', #2
u'أقرائك': u'أَقْرَائِكَ', #1
u'أقرائك': u'أَقْرَائِكِ', #7
u'أقرائك': u'أَقْرَائِك', #9
u'أقرائها': u'أقرائها', #1
u'أقرائها،': u'أَقْرَائِهَا،', #1
u'أقرائها': u'أَقْرَائِهَا', #99
u'أقربيته': u'أَقْرَبِيَّتَهُ', #1
u'أقربيته': u'أَقْرَبِيَّتِهِ', #2
u'أقربيته': u'أَقْرَبِيَّتُهُ', #4
u'أقربيتها': u'أَقْرَبِيَّتِهَا', #1
u'أقربيتهما': u'أَقْرَبِيَّتِهِمَا', #1
u'أقرضتكه': u'أَقْرَضْتُكَهُ', #1
u'أقرضتكها': u'أَقْرَضْتُكهَا', #5
u'أقرضتكها': u'أَقْرَضْتُكَهَا', #9
u'أقرضتنيه': u'أَقْرَضْتَنِيهِ', #1
u'أقرضكها': u'أَقْرَضَكهَا', #1
u'أقرضنيه': u'أَقْرِضْنِيهِ', #2
u'أقرضنيه': u'أَقْرَضَنِيهِ', #21
u'أقرضنيها': u'أَقْرَضَنِيهَا', #3
u'أقرقف،': u'أُقَرْقِفُ،', #1
u'أقرم': u'أقرم', #1
u'أقرم،': u'أَقْرَمَ،', #1
u'أقرم،': u'أقرم،', #3
u'أقرم': u'أَقْرَمَ', #32
u'أقرؤ': u'أَقْرُؤٍ', #2
u'اقرؤا': u'اقْرَؤا', #1
u'أقسام': u'أَقَسَامً', #1
u'إقسامة': u'إقْسَامَةُ', #1
u'أقشارش': u'أقشارش', #1
u'اقصى': u'اقصى', #1
u'إقضائه': u'إقْضَائِهِ', #1
u'اقضنى': u'اقْضِنِى', #3
u'اقضنيه': u'اقْضِنِيهِ', #1
u'اقضى': u'اقْضِى', #2
u'أقضيكه': u'أَقْضِيَكَهُ', #3
u'أقضيكه': u'أَقْضِيكَهُ', #4
u'أقضيكها': u'أَقْضِيكَهَا', #8
u'اقضيوا': u'اقْضِيُوا', #1
u'اقطار': u'اقطار', #1
u'أقطعنى': u'أَقْطَعَنِى', #1
u'أقطعنيه': u'أَقْطَعَنِيهِ', #1
u'اقطعى': u'اقطعى', #1
u'أقعدنى': u'أَقْعَدَنِى', #1
u'اقعدى': u'اقْعُدِى', #3
u'أقعصت': u'أقعصت', #2
u'اقعنسس': u'اقْعَنْسِسْ', #1
u'أقلحي': u'أَقْلَحِيّ', #1
u'أقلفان': u'أَقْلَفَانِ', #1
u'أقلنى': u'أَقِلْنِى', #3
u'أقلنيوقوله': u'أَقِلْنِيوَقَوْلُهُ', #1
u'إقليدس': u'إقْلِيدِسْ', #1
u'أقم': u'أَقِمًًًًْ', #1
u'أقمأ': u'أَقْمَأَ', #1
u'أقمأتك': u'أَقْمَأَتْك', #1
u'أقمأك': u'أَقْمَأَكَ', #1
u'إقمالا': u'إقْمَالًا', #1
u'أقمأه': u'أَقْمَأَهُ', #3
u'إقناؤه': u'إقْنَاؤُهُ', #1
u'إقنى': u'إقْنَى', #1
u'اقنى': u'اقْنَى', #1
u'أقواز': u'أَقْوَازَ', #1
u'اقواما': u'اقواماً', #1
u'آقول': u'آقَوْلَ', #1
u'أقيال': u'أَقْيَالٌ', #1
u'أقيال': u'أَقْيَالِ', #2
u'أقيالا': u'أَقْيَالًا', #1
u'أقيدكها': u'أُقَيِّدُكَهَا', #1
u'أقيش': u'أقيش', #1
u'أقيش': u'أُقَيْش', #1
u'أقيش،': u'أُقَيْشٍ،', #1
u'أقيش،': u'أُقْيَشٍ،', #1
u'أقيش': u'أُقَيْشٍ', #28
u'أقيش': u'أُقَيْشِ', #3
u'أقيلو': u'أَقِيلُو', #1
u'أك': u'أَكُ', #13
u'إكاء': u'إِكَاءٍ', #1
u'إكاءة': u'إكَاءَةً', #1
u'أكاريسا': u'أَكَارِيسًا', #1
u'أكاريسا': u'أَكَارِيسَا', #1
u'إكاف': u'إكَاف', #1
u'إكاف،': u'إِكَافٌ،', #1
u'إكاف،': u'إِكَافٍ،', #1
u'إكاف': u'إكَافِ', #10
u'إكاف': u'إكَافُ', #2
u'إكاف': u'إكَافٌ', #21
u'إكاف': u'إكَافٍ', #34
u'إكاف': u'إِكَافٍ', #4
u'إكاف': u'إِكَافٌ', #7
u'إكافا': u'إكَافًا', #12
u'إكافه': u'إكَافَهُ', #1
u'إكافه': u'إكَافُهُ', #3
u'إكافها': u'إكَافِهَا', #3
u'إكافها': u'إكَافَهَا', #8
u'أكالئه': u'أُكَالِئُهُ', #1
u'إكام': u'إكَامٌ', #1
u'إكام': u'إكَامٍ', #5
u'آكاه': u'آكَاهٍ', #1
u'أكاويبه': u'أَكَاوِيبه', #1
u'اكتبتا': u'اكْتَبَتَا', #1
u'أكتبنى': u'أَكْتِبْنِى', #2
u'اكتبنيه': u'اكْتُبْنِيهِ', #1
u'اكتحلى': u'اكْتَحِلِى', #2
u'أكتراه': u'أَكْتَرَاهُ', #2
u'أكتراها': u'أَكْتَرَاهَا', #4
u'اكترعنا': u'اكْتَرَعْنَا', #1
u'أكتروها': u'أَكْتَرَوْهَا', #1
u'أكتريا': u'أَكْتَرَيَا', #1
u'أكتريتها': u'أَكْتَرَيْتُهَا', #1
u'اكتسا': u'اكْتَسَا', #1
u'أكتع': u'أَكْتَع', #1
u'أكتع': u'أَكْتَعَ', #2
u'أكتع': u'أَكْتَعُ', #3
u'أكتفى': u'أَكْتَفَى', #1
u'أكتفيت': u'أَكْتَفَيْت', #3
u'أكتمكموه': u'أَكْتُمْكُمُوهُ', #1
u'أكتمكموه': u'أَكْتُمُكُمُوهُ', #2
u'اكتنانه': u'اكْتِنَانُهْ', #1
u'اكتناؤك': u'اكْتِنَاؤُكَ', #1
u'اكتنائي': u'اكْتِنَائِي', #1
u'أكتنفاه': u'أَكْتَنَفَاهُ', #1
u'اكتنى': u'اكْتَنِى', #1
u'اكتني': u'اكْتَنِي', #2
u'اكتنى': u'اكْتَنَى', #6
u'اكتنيت': u'اكتنيتَ', #1
u'اكتنيت': u'اكْتَنَيْتَ', #1
u'اكتنين': u'اكْتَنَيْنَ', #1
u'اكثرت': u'اكثرت', #1
u'أكثمة': u'أَكْثَمَةَ', #1
u'آكدا': u'آكَدًا', #1
u'آكدا': u'آكِدًا', #1
u'إكداد': u'إكْدَادَ', #1
u'آكدية': u'آكَدِيَّةِ', #3
u'آكدية': u'آكَدِيَّةُ', #4
u'آكديته': u'آكَدِيَّتِهُ', #1
u'آكديته': u'آكَدِيَّتِهِ', #2
u'آكديتها': u'آكَدِيَّتِهَا', #3
u'آكديتهما': u'آكَدِيَّتُهُمَا', #1
u'إكديشا': u'إكْدِيشًا', #1
u'إكديشه': u'إكْدِيشَهُ', #2
u'أكذى': u'أَكْذَى', #1
u'اكرا': u'اكرا', #2
u'اكراخداي': u'اكراخداي', #2
u'إكراز': u'إكراز', #1
u'اكراز': u'اكراز', #2
u'اكرازدرم': u'اكرازدرم', #1
u'أكرازديك': u'أكرازديك', #1
u'اكرازغلة': u'اكرازغلة', #1
u'اكرآزين': u'اكرآزين', #1
u'اكرازين': u'اكرازين', #2
u'أكرامر': u'أكرامر', #1
u'اكرامشب': u'اكرامشب', #1
u'اكراورابزند': u'اكراورابزند', #1
u'اكراين': u'اكراين', #2
u'أكراين': u'أكراين', #3
u'أكراينكا': u'أكراينكا', #1
u'اكراينكار': u'اكراينكار', #1
u'اكراينكاركند': u'اكراينكاركند', #1
u'أكرباتوخيم': u'أكرباتوخيم', #1
u'أكربخانه': u'أكربخانه', #1
u'اكربدهي': u'اكربدهي', #1
u'اكربر': u'اكربر', #1
u'اكربكار': u'اكربكار', #1
u'اكربماند': u'اكربماند', #1
u'اكرتا': u'اكرتا', #1
u'اكرترا': u'اكرترا', #3
u'أكرترابزنم': u'أكرترابزنم', #1
u'اكرتو': u'اكرتو', #2
u'اكرتودرم': u'اكرتودرم', #1
u'اكرجنين': u'اكرجنين', #1
u'اكرجه': u'اكرجه', #1
u'اكرخدمت': u'اكرخدمت', #1
u'اكرداده': u'اكرداده', #1
u'اكردختر': u'اكردختر', #1
u'اكردد': u'اكردد', #1
u'أكردر': u'أكردر', #1
u'اكردرروز': u'اكردرروز', #1
u'اكردست': u'اكردست', #1
u'اكرده': u'اُكْرُدْهُ', #1
u'اكردى': u'اكردى', #1
u'اكررشته': u'اكررشته', #2
u'اكرريسمان': u'اكرريسمان', #1
u'أكرزبرتوزن': u'أكرزبرتوزن', #1
u'اكرزدن': u'اكرزدن', #1
u'اكرسيم': u'اكرسيم', #2
u'اكرشويان': u'اكرشويان', #1
u'اكرفلان': u'اكرفلان', #1
u'اكركاري': u'اكركاري', #1
u'اكركسي': u'اكركسي', #1
u'اكرمر': u'اكرمر', #4
u'اكرمرا': u'اكرمرا', #1
u'اكرمراد': u'اكرمراد', #1
u'اكرمردى': u'اكرمردى', #1
u'اكرمزا': u'اكرمزا', #1
u'اكرمك': u'اكرمك', #1
u'اكرند': u'اكرند', #1
u'أكرنكويي': u'أكرنكويي', #1
u'أكرنيه': u'أَكْرَنِيهِ', #2
u'اكرهمه': u'اكرهمه', #3
u'اكرو': u'اكرو', #1
u'إكروى': u'إكروى', #1
u'اكروى': u'اكروى', #1
u'اكروير': u'اكروير', #1
u'أكريتكها': u'أَكْرَيْتُكَهَا', #2
u'أكريتنيه': u'أَكْرَيْتَنِيهِ', #1
u'اكريكماه': u'اكريكماه', #1
u'اكريكي': u'اكريكي', #1
u'اكريكى': u'اكريكى', #2
u'أكريناكها': u'أَكْرَيْنَاكهَا', #2
u'اكرينكاركنم': u'اكرينكاركنم', #1
u'أكسع': u'أَكْسَعُ', #1
u'اكسنى': u'اكْسُنِى', #1
u'اكسنيها': u'اكْسُنِيهَا', #1
u'اكسنيها؟': u'اكْسُنِيهَا؟', #1
u'أكسوتنيها': u'أَكَسَوْتَنِيهَا', #1
u'أكسوتنيها،': u'أَكَسَوْتَنِيهَا،', #1
u'اكسية': u'اكسية', #1
u'اكشفى': u'اكْشِفِى', #2
u'اكففا': u'اكْفُفَا', #1
u'أكفكموها': u'أَكْفِكُمُوهَا', #1
u'أكفلنيها': u'أَكْفِلْنِيهَا', #3
u'اكفنى': u'اكْفِنِى', #5
u'اكفئوا': u'اكْفَئُوا', #9
u'اكفئوها': u'اكْفَئُوهَا', #1
u'اكفئوها': u'اكْفِئُوهَا', #1
u'أكفيكماه': u'أَكْفِيكُمَاهُ', #1
u'أكفيكماها': u'أَكْفِيكُمَاهَا', #3
u'أكفيكه': u'أَكْفِيَكَهُ', #3
u'أكفيكه': u'أَكْفِيكَهُ', #5
u'أكلتهامرتين': u'أَكَلَتْهَامَرَّتَيْنِ', #1
u'أكلنى': u'أَكَلَنِى', #2
u'آكنده': u'آكنده', #1
u'أكنع': u'أَكْنَعَ', #2
u'اكنون': u'اكْنُونِ', #1
u'اكنون': u'اكنون', #2
u'أكه': u'أَكّهُ', #1
u'أكه': u'أَكَّهْ', #1
u'أكه': u'أَكّهْ', #2
u'أكيدر': u'أكيدر', #1
u'أكيدر': u'أُكَيْدَر', #1
u'أكيدر': u'أُكَيْدَرِ', #1
u'أكيدر،': u'أُكَيْدَر،', #1
u'أكيدر،': u'أُكَيْدِرٍ،', #1
u'أكيدر': u'أُكَيْدِرٍ', #10
u'أكيدر': u'أُكَيْدِرِ', #15
u'أكيدر،': u'أُكَيْدِرٌ،', #2
u'أكيدر': u'أُكَيْدِرَ', #21
u'أكيدر': u'أُكَيْدِرُ', #6
u'أكيدر': u'أُكَيْدِرٌ', #8
u'أكيدرا': u'أُكَيْدِرًا', #6
u'أكيمة': u'أُكَيْمَةَ', #30
u'أكينة': u'أَكَيْنَة', #1
u'أكينة': u'أَكْيَنَةَ', #1
u'الـ': u'الـ', #185
u'ال': u'ال', #19
u'ال': u'الْ', #52
u'ال': u'الِ', #6
u'ال': u'َالَ', #8
u'إلإ': u'إِلإَّ', #1
u'إلا': u'إلًا', #1
u'الإ': u'الْإِ', #1
u'إلا': u'إلاً', #2
u'إلا': u'إِلًّا', #2
u'إلا': u'إلًّا', #22
u'الا': u'الا', #22
u'الإالعطاش': u'الْإِالْعِطَاشُ', #1
u'ألاإنما': u'أَلَاإنّمَا', #1
u'إلاأنه': u'إِلاأَنَّهُ', #24
u'إلاأنه': u'إِلاأنه', #3
u'الأبا': u'الْأَبَا', #2
u'الإبا': u'الْإِبَا', #2
u'الأباء': u'الْأَبَاءَ', #1
u'الأباء': u'الْأَبَاءِ', #10
u'الأباءة': u'الْأَبَاءَةَ', #4
u'الأباب': u'الْأُبَابِ', #1
u'الاباحة': u'الاباحة', #1
u'الإباحه': u'الإباحه', #1
u'الأبادي،': u'الأبادي،', #1
u'الإبار،': u'الإبار،', #1
u'الإبار،': u'الإِبَارِ،', #1
u'الإبار': u'الْإِبَّارُ', #1
u'الإبار': u'الْإِبَّارِ', #1
u'الإبار': u'الْإِبَارُ', #13
u'الإبار': u'الْإِبَارَ', #2
u'الإبار': u'الإِبَارِ', #3
u'الإبار': u'الْإِبَارِ', #72
u'الأبازين': u'الْأَبَازِينِ', #1
u'الأباضية': u'الأَبَاضِيَّةُ', #1
u'الأباضية': u'الأَبَاضِيَّةِ', #2
u'الأباطل': u'الْأَبَاطِلِ', #3
u'الأباطيح': u'الْأَبَاطِيحُ', #1
u'الإباعة': u'الْإِبَاعَةُ', #1
u'الإباق': u'الْإِبَاق', #1
u'الإباق': u'الْإِبَاقَ', #108
u'الأباق': u'الْأُبَّاقُ', #2
u'الإباق': u'الْإِبَاقِ', #293
u'الأباق': u'الْأُبَّاقَ', #3
u'الأباق': u'الْأُبَّاقِ', #4
u'الإباق': u'الْإِبَاقُ', #61
u'الأبالج': u'الْأَبَالِجِ', #1
u'الأباهر': u'الْأَبَاهِرِ', #3
u'الأبائي': u'الْأَبَّائِي', #1
u'الأباية': u'الْأَبَايَةِ', #1
u'الإباية': u'الْإِبَايَةِ', #13
u'الإباية': u'الْإِبَايَةُ', #3
u'الإبة': u'الْإِبَةُ', #1
u'الإبتات': u'الْإِبْتَاتِ', #1
u'الابتدا': u'الِابْتِدَا', #6
u'الإبتداء': u'الإِبْتِدَاءَ', #1
u'الابتدار': u'الِابْتِدَارِ', #1
u'الابتدار': u'الِابْتِدَارُ', #5
u'الابتدال': u'الِابْتِدَالِ', #1
u'الأبترية': u'الْأَبْتَرِيَّةِ', #1
u'الابتعاض': u'الِابْتِعَاضُ', #2
u'الابتغاوية': u'الِابْتِغَاوِيَّةِ', #1
u'الابتنا': u'الِابْتِنَا', #1
u'الابتهار': u'الاِبْتِهَارُ', #1
u'الابتيار': u'الاِبْتِيَارُ', #1
u'الأبجي': u'الْأَبَجِيِّ', #1
u'الأبح،': u'الأَبَحَّ،', #1
u'الأبح،': u'الأَبَحُّ،', #1
u'الأبح': u'الْأَبَحّ', #1
u'الأبح': u'الْأَبَحُّ', #1
u'الأبح': u'الأَبَحِّ', #2
u'الأبح،': u'الأَبَحِّ،', #2
u'الأبخاش': u'الْأَبْخَاشِ', #1
u'الأبخر': u'الْأَبْخَرَ', #1
u'الأبخر': u'الْأَبْخَرُ', #2
u'الأبخر': u'الْأَبْخَرِ', #4
u'الإبداد': u'الْإِبْدَادِ', #4
u'الإبدار': u'الْإِبْدَارِ', #1
u'الأبدار': u'الْأَبْدَارِ', #2
u'الآبدي': u'الْآبِدِيُّ', #1
u'الأبر': u'الْأَبْرُ', #1
u'الابرا': u'الِابْرَا', #1
u'الأبراء': u'الْأَبْرَاءِ', #1
u'الإبراد': u'الإِبْرَادُ', #1
u'الإبراد': u'الْإِبْرَادُ', #103
u'الإبراد': u'الْإِبْرَاد', #13
u'الإبراد': u'الْإِبْرَادَ', #25
u'الإبراد': u'الإِبْرَادِ', #4
u'الإبراد': u'الْإِبْرَادِ', #80
u'الأبرام': u'الْأَبْرَامُ', #2
u'الأبرجة': u'الْأَبْرِجَةَ', #2
u'الأبرجة': u'الْأَبْرِجَةِ', #8
u'الأبرحة': u'الْأَبْرِحَةِ', #2
u'الأبرد': u'الْأَبْرَدِ', #1
u'الأبرد': u'الْأَبْرَدُ', #2
u'الأبرد': u'الأَبْرَدِ', #8
u'الأبرق': u'الْأَبْرَقِ', #2
u'الأبرقوهي': u'الأَبَرْقُوهِيُّ', #1
u'الأبرقوهي': u'الْأَبَرْقُوهِيُّ', #1
u'الأبرهي': u'الْأَبْرَهِيّ', #1
u'الآبري': u'الْآبُرِيُّ', #1
u'الأبرئة': u'الْأَبْرِئَةِ', #1
u'الإبريسم': u'الْإِبْرِيسَم', #1
u'الإبريسم': u'الْإِبْرَيْسِمَ', #1
u'الإبريسم': u'الْإِبْرَيْسَمَ', #14
u'الإبريسم': u'الْإِبْرَيْسَمُ', #29
u'الإبريسم': u'الْإِبْرَيْسَمِ', #92
u'الإبريسمية': u'الإبْرَيْسَمِيَّة', #1
u'الإبزم': u'الإِبْزَمُ', #1
u'الأبزى': u'الْأَبْزَى', #2
u'الأبشار': u'الْأَبْشَارُ', #1
u'الأبشيطي': u'الْأَبْشِيطِيُّ', #1
u'الإبشيطي': u'الْإِبْشِيطِيُّ', #2
u'الأبصاري،': u'الأَبْصَارِيُّ،', #1
u'الأبضاع': u'الْأَبْضَاعَ', #14
u'الإبضاع': u'الْإِبْضَاعَ', #20
u'الإبضاع': u'الْإِبْضَاعُ', #28
u'الأبضاع': u'الْأَبْضَاعُ', #3
u'الإبضاع': u'الْإِبْضَاعِ', #52
u'الأبضاع': u'الْأَبْضَاعِ', #76
u'الأبظر': u'الأَبْظَرَ', #1
u'الإبعاض': u'الْإِبْعَاضِ', #1
u'الإبعاض': u'الْإِبْعَاضَ', #2
u'إلابعد': u'إِلَّاِِِِبَعْدَ', #1
u'الأبعرة': u'الْأَبْعِرَة', #1
u'الأبعرة': u'الْأَبْعِرَةُ', #2
u'الأبعرة': u'الْأَبْعِرَةَ', #3
u'الأبعرة': u'الْأَبْعِرَةِ', #5
u'الأبق': u'الْأَبْقَ', #1
u'الآبق': u'الآبِقَ', #2
u'الآبق': u'الْآبِقُ', #221
u'الآبق': u'الْآبِقَ', #226
u'الآبق': u'الآبِقُ', #3
u'الأبق': u'الْأَبْقِ', #3
u'الآبق': u'الْآبِق', #7
u'الآبق': u'الآبِقِ', #8
u'الآبق': u'الْآبِقِ', #888
u'الآبقة': u'الْآبِقَةِ', #17
u'الآبقة': u'الْآبِقَةَ', #2
u'الآبقة': u'الْآبِقَةُ', #8
u'الأبقرة': u'الْأَبْقِرَةَ', #1
u'الأبقع': u'الأبقع', #1
u'الأبقع': u'الْأَبْقَعِ', #17
u'الأبقع': u'الأَبْقَعَ', #2
u'الأبقع': u'الْأَبْقَع', #3
u'الأبقع': u'الْأَبْقَعُ', #38
u'الأبقع': u'الأَبْقَعُ', #7
u'الأبقع': u'الْأَبْقَعَ', #7
u'الأبل،': u'الأبل،', #1
u'الابل': u'الابل', #2
u'الأبل': u'الأبل', #4
u'الأبلة': u'الأبلة', #1
u'الأبلة،': u'الأُبُلَّةَ،', #1
u'الأبلة؟': u'الأُبُلَّةِ؟', #1
u'الأبلة': u'الْأُبُلَّةَ', #1
u'الأبلة': u'الْأُبُلَّةُ', #1
u'الأبلة،': u'الْأُبُلَّةَ،', #1
u'الأبلة': u'الأُبُلَّة', #2
u'الأبلة،': u'الأُبُلَّة،', #2
u'الأبلة': u'الأُبُلَّةِ', #3
u'الأبلة': u'الْأُبُلَّةِ', #7
u'الأبلج': u'الْأَبْلَجِ', #1
u'الأبلج': u'الْأَبْلَجَ', #2
u'الأبلج': u'الْأَبْلَجُ', #4
u'الأبلخ': u'الْأَبْلَخِ', #1
u'الأبلغية': u'الأبلغية', #1
u'الأبلغية': u'الْأَبْلَغِيِّةِ', #1
u'الأبلغية': u'الْأَبْلَغِيَّةُ', #10
u'الأبلغية': u'الْأَبْلَغِيَّةِ', #22
u'الأبلغية': u'الْأَبْلَغِيَّةَ', #9
u'الأبلي': u'الْأَبْلِيّ', #1
u'الأبلي': u'الْأُبَلِيُّ', #1
u'الأبلى': u'الأَبُلِى', #1
u'الأبلى': u'الأُبُلِّىَّ', #1
u'الأبلي،': u'الأبلي،', #2
u'الأبلي،': u'الأُبَلِّيُّ،', #2
u'الأبلي': u'الْأُبُلِّيُّ', #2
u'الأبلي،': u'الأُبُلِّيِّ،', #4
u'الأبلى': u'الأُبُلِّىُّ', #4
u'الأبلي': u'الأُبُلِّيُّ', #5
u'الأبلي': u'الْأُبُلِّيِّ', #5
u'الأبلي،': u'الأُبُلِّيُّ،', #7
u'الإبليق': u'الإبليق', #1
u'الأبن': u'الْأَبْنَ', #1
u'الإبن': u'الإِبْنُ', #1
u'الأبناسي': u'الْأَبْنَاسِيُّ', #2
u'الإبنان': u'الْإِبْنَانِ', #1
u'الأبناوي،': u'الأبناوي،', #1
u'الأبناوي': u'الأَبْنَاوِيُّ', #1
u'الأبناوي،': u'الأَبْنَاوِيُّ،', #1
u'الأبناوي،': u'الْأَبْنَاوِيُّ،', #1
u'الأبناوى': u'الأَبْنَاوِىُّ', #1
u'الأبناوي،': u'الأَبْنَاوِيِّ،', #2
u'الأبنة': u'الْأَبْنَةَ', #1
u'الأبنة': u'الْأُبْنَةُ', #2
u'الأبنة': u'الْأُبْنَةَ', #3
u'الأبنة': u'الْأُبْنَةِ', #4
u'الأبنوس': u'الْأَبَنُوسَ', #1
u'الأبنوس': u'الْأَبَنُوسِ', #1
u'الأبنوس': u'الْأَبَنُوسُ', #4
u'الأبهرى': u'الأَبْهَرِىُّ', #1
u'الأبهرى': u'الأَبْهُرِىُّ', #1
u'الأبهل': u'الْأَبْهَلِ', #1
u'الأبواء،': u'الأَبْوَاءَ،', #1
u'الأبواء،': u'الأَبْوَاءِ،', #1
u'الأبواء': u'الْأَبْوَاءُ', #1
u'الأبواء': u'الْأَبْوَاءَ', #11
u'الأبواء': u'الْأَبْوَاء', #2
u'الأبواء': u'الْأَبْوَاءِ', #30
u'الأبوار': u'الأبوار', #3
u'الإبياري': u'الْإِبْيَارِيّ', #1
u'الأبياري': u'الْأَبْيَارِيِّ', #3
u'الإبياري': u'الْإِبْيَارِيَّ', #3
u'الأبياري': u'الْأَبْيَارِيُّ', #5
u'الإبياري': u'الْإِبْيَارِيِّ', #8
u'الإبياري': u'الْإِبْيَارِيُّ', #84
u'الإبياني': u'الْإِبْيَانِيِّ', #13
u'الأبياني': u'الْأَبْيَانِيَّ', #2
u'الأبياني': u'الْأَبْيَانِيِّ', #2
u'الإبياني': u'الْإِبْيَانِيُّ', #23
u'الأبياني': u'الْأَبْيَانِيُّ', #8
u'الأبيرق': u'الْأُبَيْرِقِ', #2
u'الأبيش': u'الأبيش', #1
u'الأبيش': u'الْأُبَيْشِ', #1
u'الأبيضية': u'الْأَبْيَضِيَّةَ', #1
u'الأبينية': u'الْأَبْيَنِيَّةِ', #1
u'الأبيوردي': u'الْأَبِيوَرْدِيَّ', #1
u'الأبيوردي': u'الْأَبِيوَرْدِيُّ', #1
u'الأبيوردي': u'الْأَبِيوَرْدِيِّ', #2
u'الأبيوردى': u'الأَبِيوَرْدِىُّ', #3
u'الأتابكية': u'الْأَتَابِكِيَّةِ', #1
u'الأتاتين': u'الْأَتَاتِينَ', #1
u'الأتاوة': u'الْأَتَاوَةَ', #1
u'الأتاي': u'الأتاي', #1
u'الأتاي': u'الْأَتَاي', #1
u'الأتاي': u'الْأَتَايْ', #1
u'الأتبان': u'الْأَتْبَانِ', #1
u'الأتبعة': u'الْأَتْبِعَةِ', #5
u'الأتبية': u'الأُتْبِيَّةَ', #1
u'الأتبية،': u'الأُتْبِيَّةَ،', #1
u'الأتبية،': u'الأُتْبِيَّةِ،', #2
u'الأتبية': u'الأُتْبِيَّةِ', #4
u'الاتحاف': u'الِاتِّحَافِ', #1
u'الأتحمي': u'الْأَتْحَمِيّ', #1
u'الاتخام': u'الِاتِّخَامِ', #1
u'الإتراب': u'الْإِتْرَابُ', #1
u'الإتراب': u'الْإِتْرَابِ', #1
u'الإترازي': u'الْإِتْرَازِيُّ', #1
u'الأترازي': u'الْأَتْرَازِيُّ', #2
u'الأترنج،': u'الأُتْرُنْجَ،', #1
u'الأترنج،': u'الأُتْرُنْجِ،', #1
u'الأترنج،': u'الْأُتْرُنْجِ،', #1
u'الأترنج': u'الْأُتْرُنْجِ', #2
u'الأترنج': u'الْأُتْرُنْجُ', #3
u'الأترنجة': u'الْأُتْرُنْجَة', #1
u'الإتريبي': u'الْإِتْرِيبِيِّ', #1
u'الأتريبي': u'الأتريبي', #2
u'الإتساع': u'الْإِتْسَاعُ', #1
u'الإتساع': u'الْإِتْسَاعِ', #1
u'الأتقاني': u'الْأَتْقَانِيّْ', #1
u'الأتقاني': u'الْأَتْقَانِيُّ', #1314
u'الأتقاني': u'الْأَتْقَانِيِّ', #43
u'الأتقاني': u'الْأَتْقَانِيَّ', #5
u'الأتقاني': u'الأتقاني', #72
u'الأتقنية': u'الْأَتْقَنِيَّةِ', #3
u'الأتلد': u'الْأَتْلَدِ', #3
u'الأتلدا': u'الأْتلَدا', #1
u'الأتلدا': u'الأَتْلَدَا', #1
u'الأتلدا': u'الْأَتْلَدَا', #6
u'الإتماما': u'الْإِتْمَامَا', #2
u'الأتمية': u'الْأَتَمِّيَّةِ', #1
u'الاتهاب': u'الِاتِّهَابُ', #1
u'الاتهاب': u'الِاتِّهَابِ', #13
u'الاتهاب': u'الِاتِّهَابَ', #2
u'الإتهام': u'الْإِتْهَامُ', #1
u'الإتهام': u'الْإِتْهَامِ', #1
u'الإتواء': u'الْإِتْوَاءِ', #2
u'الأتوار': u'الْأَتْوَارِ', #2
u'الآتيتا': u'الْآتِيَتَا', #2
u'الآتيتي': u'الْآتِيَتِي', #1
u'الآتيتي': u'الْآتِيَتَيْ', #5
u'الآتيي': u'الْآتِيَيْ', #2
u'الإثاث': u'الْإِثَاثِ', #1
u'الأثاري': u'الْأَثَارِي', #1
u'الأثاني': u'الْأَثَانِيَ', #1
u'الأثاني': u'الْأَثَانِي', #5
u'الأثانين': u'الْأَثَانِينِ', #2
u'الأثانين': u'الْأَثَانِينَ', #26
u'الأثائث': u'الْأَثَائِثِ', #2
u'الأثاية': u'الأَثَايَةِ', #1
u'الأثاية': u'الْأَثَايَة', #1
u'الأثاية': u'الْأُثَايَةَ', #1
u'الأثاية': u'الْأُثَايَةِ', #1
u'الأثبت': u'الأَثْبَتِ', #2
u'الأثبت': u'الْأَثْبَتِ', #2
u'الأثبت': u'الْأَثْبَتُ', #5
u'الأثبج': u'الأَثْبَجَ', #1
u'الأثبج،': u'الأَثْبَجُ،', #1
u'الأثبرة': u'الْأَثْبِرَةِ', #1
u'الأثرم': u'الأَثْرَمَ', #1
u'الأثرم': u'الأَثْرَمِ', #1
u'الأثرم': u'الْأَثْرَمِ', #177
u'الأثرم': u'الأَثْرَمُ', #2
u'الأثرم،': u'الأَثْرَمُ،', #3
u'الأثرم،': u'الأَثْرَمِ،', #3
u'الأثرم': u'الْأَثْرَم', #3
u'الأثرم': u'الْأَثْرَمَ', #3
u'الأثرم': u'الْأَثْرَمُ', #614
u'الأثعبان': u'الْأُثْعُبَانُ', #1
u'الأثعل': u'الأثعل', #1
u'الأثعل': u'الْأَثْعَلُ', #1
u'الأثعل': u'الْأَثْعُلُ', #1
u'الأثغار': u'الْأَثْغَارِ', #2
u'الاثغار': u'الِاثِّغَارُ', #2
u'الاثغار': u'الِاثِّغَارِ', #5
u'الإثفار': u'الْإِثْفَارُ', #1
u'الأثقاف': u'الْأَثْقَافِ', #1
u'الأثلب': u'الْأَثْلَبِ', #1
u'الأثلب': u'الْأَثْلَبُ', #5
u'الاثم': u'الاثم', #1
u'الأثم': u'الْأَثِمَ', #4
u'الأثم': u'الْأَثِمُ', #4
u'الأثم': u'الْأَثِمِ', #6
u'الأثمانا': u'الْأَثْمَانَا', #2
u'الإثمد': u'الإِثْمِدِ', #1
u'الإثمد': u'الْإِثْمِدُ', #17
u'الإثمد': u'الْإِثْمِدِ', #25
u'الإثمد': u'الْإِثْمِد', #3
u'الإثمد': u'الإِثْمِدُ', #4
u'الإثمد': u'الْإِثْمِدَ', #4
u'الاثنا': u'الْاِثْنَا', #1
u'الاثنا': u'الِاثْنَا', #72
u'الاثناء': u'الِاثِّنَاء', #1
u'الإثنان': u'الإِثْنَانِ', #1
u'الاثنتا': u'الِاثْنَتَا', #9
u'الاثنتي': u'الِاثْنَتَيْ', #34
u'الأثني': u'الأثني', #1
u'الاثني': u'الْاِثْنَي', #1
u'الاثنى': u'الاثنى', #1
u'الاثنى': u'الاِثْنَىْ', #1
u'الاثني': u'الِاثْنَيْ', #257
u'الاثنى': u'الِاثْنَى', #5
u'الأثنين': u'الأثنين', #1
u'الاثنينات': u'الِاثْنِينَاتِ', #1
u'الاثنينية': u'الِاثْنِينِيَّةِ', #1
u'الأثوار': u'الأثوار', #1
u'الأثوار': u'الْأَثْوَارُ', #2
u'الأثوار': u'الْأَثْوَارِ', #5
u'الأثوبة': u'الْأَثْوِبَةِ', #2
u'الأثوبية': u'الْأَثْوَبِيَّةِ', #1
u'الأثوع': u'الْأَثْوَعِ', #5
u'الأجابين': u'الْأَجَابِينِ', #1
u'ألاجات': u'أَلَاجَّات', #2
u'الأجاجير': u'الأَجَاجِيرِ', #1
u'الأجاجير': u'الْأَجَاجِيرِ', #1
u'الأجادب': u'الأجادب', #1
u'الأجارع': u'الْأَجَارِعُ', #1
u'الإجاره': u'الْإِجَارَهْ', #2
u'الإجافة': u'الْإِجَافَةُ', #3
u'الإجافة': u'الْإِجَافَةِ', #8
u'الإجام': u'الْإِجَامِ', #1
u'الإجانات': u'الْإِجَّانَاتِ', #17
u'الإجانات': u'الْإِجَّانَاتُ', #5
u'الأجانة': u'الْأَجَانَةُ', #1
u'الأجانة': u'الْأَجَانَةِ', #1
u'الأجانة': u'الْأَجَّانَةُ', #1
u'الأجايز': u'الْأَجَايِزِ', #1
u'الأجب': u'الْأَجَبّ', #2
u'الاجتداء': u'الِاجْتِدَاءِ', #1
u'الاجتزاء': u'الِاجْتِزَاءِ', #12
u'الاجتزاء': u'الِاجْتِزَاءَ', #3
u'الاجتزاء': u'الِاجْتِزَاءُ', #7
u'الاجتعال': u'الاِجْتِعَالِ', #1
u'الاجتماعلقراءة': u'الِاجْتِمَاعِلِقِرَاءَةِ', #1
u'الاجتنان': u'الِاجْتِنَانِ', #10
u'الاجتهادإن': u'الِاجْتِهَادِإِنْ', #1
u'الاجتيال': u'الِاجْتِيَالَ', #1
u'ألاجتين': u'أَلَاجَّتَيْنِ', #1
u'ألاجتين': u'أَلَّاجَتَيْنِ', #1
u'الأجحم': u'الْأَجْحَمِ', #2
u'الإجداد': u'الْإِجْدَادُ', #1
u'الأجداف': u'الأجداف', #1
u'الأجداف': u'الْأَجْدَافِ', #3
u'الإجذاع': u'الْإِجْذَاعَ', #1
u'الإجذاع': u'الْإِجْذَاعُ', #3
u'الإجذاع': u'الْإِجْذَاعِ', #3
u'الأجذع': u'الْأَجْذَعُ', #1
u'الأجذع': u'الْأَجْذَعِ', #1
u'الأجذمى': u'الأَجْذَمِىُّ', #1
u'الأجرع': u'الْأَجْرَعِ', #4
u'الأجرود': u'الْأَجْرُودُ', #1
u'الأجرود': u'الْأَجْرُودِ', #1
u'الأجرومية': u'الْأُجْرُومِيَّةِ', #1
u'الآجرومية': u'الْآجُرُّومِيَّةِ', #2
u'الأجرومية': u'الْأَجْرُومِيَّةِ', #2
u'الآجرى': u'الآجُرِىُّ', #1
u'الآجرى': u'الآجُرِّىُّ', #1
u'الأجزئة': u'الْأَجْزِئَةَ', #1
u'الأجزية': u'الْأَجْزِيَةِ', #30
u'الأجزية': u'الْأَجْزِيَةَ', #7
u'الأجزية': u'الْأَجْزِيَةُ', #8
u'الأجعال': u'الْأَجْعَالَ', #1
u'الأجعال': u'الْأَجْعَالِ', #1
u'الأجغم': u'الأجغم', #2
u'الأجفلي': u'الْأَجْفَلِيَّ', #1
u'الأجفلي': u'الْأَجْفَلِيُّ', #2
u'الأجلاب': u'الأَجْلابُ', #1
u'الأجلاب': u'الأَجْلاَبُ', #1
u'الأجلاب': u'الْأَجْلَاب', #1
u'الأجلاب': u'الْأَجْلَابَ', #1
u'الأجلاب': u'الْأَجْلَابُ', #1
u'الأجلاب': u'الْأَجْلَابِ', #1
u'الإجلالا': u'الْإِجْلالا', #1
u'الأجلح': u'الْأَجْلَحَ', #1
u'الأجلح،': u'الْأَجْلَحِ،', #1
u'الأجلح': u'الأَجْلَحِ', #13
u'الأجلح،': u'الأَجْلَحِ،', #13
u'الأجلح': u'الْأَجْلَحِ', #14
u'الأجلح': u'الْأَجْلَحُ', #17
u'الأجلح': u'الْأَجْلَح', #2
u'الأجلح،': u'الْأَجْلَحُ،', #2
u'الأجلح،': u'الأَجْلَحَ،', #3
u'الأجلح،': u'الأَجْلَحُ،', #7
u'الأجلح': u'الأَجْلَحُ', #9
u'الأجلع،': u'الأَجْلَعِ،', #1
u'الأجلى': u'الْأَجْلَى', #7
u'الإجمار': u'الْإِجْمَارَ', #3
u'الإجمار': u'الْإِجْمَارُ', #5
u'الأجمال': u'الْأَجْمَالِ', #1
u'الإجناب': u'الْإِجْنَابِ', #1
u'الإجناب': u'الْإِجْنَابُ', #4
u'الإجناب': u'الْإِجْنَابَ', #8
u'الأجنب': u'الْأَجْنَبُ', #1
u'الأجنتان': u'الْأَجْنَتَانِ', #1
u'الأجنف': u'الْأَجْنَفِ', #4
u'الأجنياء': u'الْأَجْنِيَاءُ', #1
u'الأجهوري': u'الْأُجْهُورِيِّ', #161
u'الأجهوري': u'الْأَجْهُورِيِّ', #2
u'الأجهوري': u'الْأُجْهُورِيَّ', #25
u'الأجهوري': u'الْأُجْهُورِيُّ', #452
u'الأجهوري': u'الْأَجْهُورِيُّ', #7
u'الأجهوري': u'الَأُجْهُورِيُّ', #83
u'الأجودا': u'الْأَجْوَدَا', #5
u'الأجودية': u'الْأَجْوَدِيَّةُ', #4
u'الأجودية': u'الْأَجْوَدِيَّةَ', #5
u'الأجوزية': u'الْأَجْوَزِيَّةَ', #1
u'الأجوزية': u'الْأَجْوَزِيَّةِ', #1
u'الأجيزي': u'الأجيزي', #1
u'الأحابش': u'الأَحَابِشَ', #1
u'الأحابش': u'الْأَحَابِشَ', #1
u'الأحابش': u'الْأَحَابِشُ', #1
u'الأحابش': u'الْأَحَابِشِ', #1
u'الأحامدة': u'الْأَحَامِدَةِ', #2
u'الأحامسا': u'الْأَحَامِسَا', #3
u'الأحاوم': u'الْأَحَاوِمَ', #1
u'الاحبار': u'الاحبار', #1
u'الأحباق': u'الأحباق', #1
u'الأحبش': u'الْأَحْبَشُ', #1
u'الأحبل': u'الْأَحْبُلُ', #1
u'الأحبل': u'الْأَحْبُلِ', #2
u'الأحبن': u'الْأَحْبَنُ', #1
u'الأحبه': u'الْأَحِبَّهْ', #5
u'الاحتباك': u'الِاحْتِبَاكَ', #1
u'الاحتباك': u'الاِحْتِبَاكُ', #1
u'الاحتباك': u'الِاحْتِبَاك', #3
u'الاحتباك': u'الِاحْتِبَاكُ', #5
u'الاحتباك': u'الِاحْتِبَاكِ', #9
u'الاحتبال': u'الِاحْتِبَالِ', #1
u'الاحتجار': u'الِاحْتِجَارَ', #1
u'الاحتجار': u'الِاحْتِجَارُ', #1
u'الاحتجار': u'الِاحْتِجَارِ', #1
u'الاحتجام': u'الِاحْتِجَامُ', #10
u'الاحتجام': u'الِاحْتِجَامِ', #6
u'الاحتزاز': u'الِاحْتِزَازَ', #1
u'الاحتزاز': u'الِاحْتِزَازِ', #1
u'الاحتزاز': u'الِاحْتِزَازُ', #2
u'الاحتزام': u'الِاحْتِزَامُ', #5
u'الاحتزام': u'الِاحْتِزَامَ', #6
u'الاحتزام': u'الِاحْتِزَامِ', #6
u'الاحتشاش': u'الِاحْتِشَاشَ', #1
u'الاحتشاش': u'الِاحْتِشَاشِ', #14
u'الاحتشاش': u'الِاحْتِشَاشُ', #7
u'الاحتقاق': u'الِاحْتِقَاقِ', #1
u'الاحتلاق': u'الِاحْتِلَاقُ', #1
u'الاحتواش': u'الِاحْتِوَاشَ', #1
u'الاحتواش': u'الِاحْتِوَاشُ', #3
u'الاحتواش': u'الِاحْتِوَاشِ', #6
u'الاحتياز': u'الِاحْتِيَازِ', #1
u'الإحجاج': u'الْإِحْجَاجِ', #31
u'الإحجاج': u'الْإِحْجَاجَ', #8
u'الإحجاج': u'الْإِحْجَاجُ', #82
u'الأحجال': u'الْأَحْجَال', #1
u'الأحداد': u'الْأَحْدَاد', #1
u'الإحداد': u'الإِحْدَادُ', #1
u'الإحداد': u'الْإِحْدَادِ', #123
u'الإحداد': u'الْإِحْدَادُ', #211
u'الإحداد': u'الإِحْدَادِ', #3
u'الإحداد': u'الْإِحْدَادَ', #55
u'الإحداد': u'الْإِحْدَاد', #9
u'الأحدون': u'الْأَحَدُونَ', #1
u'الإحدى': u'الْإِحْدَى', #60
u'الأحراس': u'الْأَحْرَاسُ', #1
u'الأحراس': u'الأَحْرَاسُ', #2
u'الأحراص': u'الأحراص', #2
u'الأحراض': u'الْأَحْرَاضُ', #1
u'الأحراض': u'الْأَحْرَاضِ', #1
u'الأحرد': u'الْأَحْرَدِ', #1
u'الأحرز': u'الْأَحْرَزَ', #1
u'الأحرز': u'الْأَحْرَزُ', #1
u'الأحرز': u'الْأَحْرَزِ', #5
u'الأحرز': u'الأَحْرَزِ', #7
u'الأحروية': u'الْأَحْرَوِيَّةَ', #1
u'الأحروية': u'الْأَحْرَوِيَّةُ', #1
u'الأحروية': u'الْأَحْرَوِيَّةِ', #10
u'الإحزاء': u'الْإِحْزَاءَ', #1
u'الإحزاء': u'الْإِحْزَاءِ', #1
u'الأحزم': u'الأحزم', #1
u'الأحسنية': u'الْأَحْسَنِيَّةُ', #10
u'الأحسنية': u'الْأَحْسَنِيَّةِ', #13
u'الأحسنية': u'الْأَحْسَنِيَّةَ', #5
u'الأحشاش': u'الْأَحْشَاشِ', #1
u'الإحصاد': u'الْإِحْصَادِ', #1
u'الإحصار': u'الإِحْصَارَ', #1
u'الإحصار': u'الْإِحْصَارُ', #119
u'الإحصار': u'الإِحْصَارُ', #2
u'الإحصار': u'الْإِحْصَار', #3
u'الإحصار': u'الإِحْصَارِ', #4
u'الإحصار': u'الْإِحْصَارِ', #470
u'الإحصار': u'الْإِحْصَارَ', #49
u'الأحصر': u'الْأَحْصَرُ', #1
u'الأحصر': u'الْأَحْصَرِ', #1
u'الإحضان': u'الْإِحْضَانَ', #1
u'الإحضان': u'الْإِحْضَانُ', #3
u'الأحطية': u'الْأَحَطِّيَّةِ', #1
u'الأحظ': u'الْأَحُظِّ', #1
u'الأحظ': u'الْأَحَظَّ', #28
u'الأحظ': u'الْأَحُظُّ', #4
u'الأحظ': u'الْأَحَظُّ', #53
u'الأحظ': u'الْأَحَظِّ', #86
u'الأحظية': u'الْأَحَظِّيَّةِ', #12
u'الإحفاء': u'الإِحْفَاءَ', #1
u'الإحفاء': u'الْإِحْفَاءِ', #1
u'الإحفاء': u'الْإِحْفَاء', #10
u'الإحفاء': u'الْإِحْفَاءَ', #2
u'الإحفاء': u'الإِحْفَاءِ', #3
u'الإحفاء': u'الْإِحْفَاءُ', #6
u'الأحفظ': u'الْأَحْفَظَ', #1
u'الأحفظ': u'الْأَحْفَظُ', #2
u'الأحفظ': u'الْأَحْفَظِ', #3
u'الأحقاف،': u'الأحقاف،', #1
u'الأحقاف': u'الْأحقاف', #1
u'الأحقاف': u'الأَحْقَافِ', #1
u'الأحقاف،': u'الْأَحْقَافِ،', #1
u'الأحقاف': u'الْأَحْقَافِ', #16
u'الأحقاف': u'الْأَحْقَافُ', #3
u'الأحقاف': u'الأحقاف', #4
u'الأحقاف': u'الْأَحْقَافَ', #4
u'الأحقال': u'الْأَحْقَالِ', #1
u'الأحكار': u'الْأَحْكَارَ', #1
u'الإحكار': u'الْإِحْكَارُ', #1
u'الأحكار': u'الْأَحْكَارُ', #4
u'الأحكار': u'الْأَحْكَارِ', #5
u'الأحكاميون': u'الْأَحْكَامِيُّونَ', #1
u'الأحلاب': u'الْأَحْلَابِ', #4
u'الأحلاك': u'الْأَحْلَاكُ', #1
u'الإحلام': u'الْإِحْلَام', #1
u'الأحم': u'الْأَحَمُّ', #1
u'الأحمري،': u'الأَحْمَرِيُّ،', #1
u'الأحمري': u'الْأَحْمَرِيِّ', #2
u'الأحمرى': u'الأَحْمَرِىِّ', #3
u'الأحمرى': u'الأَحْمَرِىُّ', #4
u'الأحمز': u'الْأَحْمَزِ', #2
u'الأحمز': u'الْأَحْمَزَ', #7
u'الأحمسي،': u'الأحْمَسي،', #1
u'الأحمسي،': u'الأَحَمْسِيُّ،', #1
u'الأحمسي،': u'الأَحْمَسِيَّ،', #1
u'الأحمسي': u'الْأَحْمَسِي', #1
u'الأحمسي': u'الْأَحْمَسِيَّ', #1
u'الأحمسي': u'الْأَحْمُسِيِّ', #1
u'الأحمسى': u'الأَحْمُسَىِّ', #1
u'الأحمسي': u'الْأَحْمَسِيِّ', #12
u'الأحمسي،': u'الأَحْمَسِيُّ،', #130
u'الأحمسي،': u'الأَحْمَسِيِّ،', #18
u'الأحمسي،': u'الأحمسي،', #2
u'الأحمسي،': u'الْأَحْمَسِيُّ،', #2
u'الأحمسى': u'الأَحْمَسِىِّ', #2
u'الأحمسي': u'الأَحْمَسِيُّ', #20
u'الأحمسى': u'الأَحْمَسِىُّ', #29
u'الأحمسي': u'الأحمسي', #3
u'الأحمسى': u'الأَحْمُسِىُّ', #3
u'الأحمسي': u'الأَحْمَسِيِّ', #4
u'الأحمسية': u'الأحمسية', #1
u'الأحمسية': u'الأَحْمَسِيَّةِ', #1
u'الأحمسية': u'الْأَحْمَسِيَّةَ', #1
u'الأحمسية': u'الْأَحْمَسِيَّةُ', #1
u'الأحمسية': u'الأَحْمَسِيَّةُ', #3
u'الأحمسية': u'الْأَحْمَسِيَّةِ', #4
u'الأحمش': u'الأحمش', #1
u'الأحمقي،': u'الأَحْمَقِيُّ،', #1
u'الأحموسي،': u'الأَحْمُوسِيُّ،', #1
u'الأحموسي': u'الْأُحْمُوسِيُّ', #1
u'الأحموقة': u'الْأُحْمُوقَةَ', #1
u'الأحمى': u'الْأَحْمَى', #1
u'الأحمية': u'الْأَحْمِيَةُ', #1
u'الأحمية': u'الْأَحْمِيَةِ', #2
u'الأحواج': u'الْأَحْوَاجِ', #1
u'الأحوجية': u'الْأَحْوَجِيَّةِ', #1
u'الأحوجية': u'الْأَحْوَجِيَّةَ', #2
u'الأحوذي': u'الْأَحْوَذِيُّ', #1
u'الأحوذي': u'الْأَحْوَذِيِّ', #6
u'الأحورية': u'الْأَحْوَرِيَّةَ', #1
u'الأحوط': u'الْأَحْوَطُ', #175
u'الأحوط': u'الْأَحْوَطِ', #19
u'الأحوط': u'الْأَحْوَط', #4
u'الأحوط': u'الْأَحْوَطَ', #60
u'الأحوطية': u'الْأَحْوَطِيَّةَ', #1
u'الأحوية': u'الْأَحْوِيَةُ', #2
u'الإحيا': u'الْإِحْيَا', #1
u'الأحيا': u'الْأَحْيَا', #5
u'الأحياز': u'الْأَحْيَازِ', #2
u'الأحيد': u'الْأَحْيَدِ', #1
u'الأخابث': u'الْأَخَابِثِ', #2
u'الإخارة': u'الْإِخَارَةِ', #1
u'الأخاشب': u'الأَخَاشِبِ', #1
u'الأخاشب': u'الْأَخَاشِب', #1
u'الأخاشب': u'الْأَخَاشِبَ', #1
u'الأخاشب': u'الْأَخَاشِبِ', #17
u'الأخاشب': u'الْأَخَاشِبُ', #2
u'الأخاط': u'الْأَخَاطُ', #4
u'الأخافش': u'الْأَخَافِشِ', #1
u'الأخامص': u'الْأَخَامِصُ', #1
u'الأخباري،': u'الأَخْبَارِيُّ،', #1
u'الأخبارى': u'الأَخْبَارِىُّ', #1
u'الأخباريون': u'الْأَخْبَارِيُّونَ', #1
u'الأخباريين': u'الْأَخْبَارِيّينَ', #1
u'الأخباز': u'الْأَخْبَازُ', #2
u'الأخباز': u'الْأَخْبَازَ', #4
u'الأخباز': u'الْأَخْبَازِ', #6
u'الأخبر': u'الْأَخْبَرُ', #3
u'الأخبئة': u'الْأَخْبِئَةَ', #1
u'الإختان': u'الْإِخْتَانِ', #1
u'الاخترام': u'الِاخْتِرَامُ', #1
u'الاختصاء': u'الاختصاء', #1
u'الاختصاء،': u'الاخْتِصَاءِ،', #1
u'الاختصاء': u'الِاخْتِصَاءِ', #4
u'الاختصاء': u'الِاخْتِصَاء', #8
u'الاختلاع،': u'الاخْتِلاعِ،', #1
u'الاختلاع': u'الاِخْتِلاَعِ', #1
u'الاختلاع': u'الِاخْتِلَاعِ', #29
u'الاختلاع': u'الِاخْتِلَاعُ', #4
u'الاختلاع': u'الِاخْتِلَاعَ', #6
u'الإختلاف': u'الإِخْتِلاَفِ', #1
u'الاختناث': u'الاخْتِنَاثِ', #1
u'الاختناث': u'الاِخْتِنَاثُ', #1
u'الاختناث': u'الاختناث', #3
u'الإختيار': u'الإختيار', #1
u'الاختيارة': u'الِاخْتَيَارَةَ', #1
u'الاختيارة': u'الِاخْتِيَارَةَ', #12
u'الاختيارة': u'الِاخْتِيَارَةِ', #18
u'الاختيارة': u'الِاخْتِيَارَةُ', #8
u'الأخثم': u'الْأَخْثَمِ', #2
u'الإخدام': u'الْإِخْدَامُ', #30
u'الإخدام': u'الْإِخْدَامِ', #40
u'الإخدام': u'الْإِخْدَامَ', #9
u'الأخدعين،': u'الأَخْدَعَيْنِ،', #1
u'الأخدعين': u'الْأَخْدَعَيْنِ', #12
u'الأخدعين': u'الأَخْدَعَيْنِ', #3
u'الأخراء': u'الْأُخَرَاءِ', #1
u'الإخراق': u'الْإِخْرَاقِ', #1
u'الإخراق': u'الْإِخْرَاقُ', #2
u'الآخرةوالوجه': u'الآخِرَةِوَالْوَجْهُ', #1
u'الأخرتان': u'الْأُخَرَتَانِ', #1
u'الأخرتان': u'الْأُخْرَتَانِ', #1
u'الأخرتين': u'الْأَخِرَتَيْنِ', #2
u'الأخرتين': u'الْأُخَرَتَيْنِ', #5
u'الأخرتين': u'الْأُخْرَتَيْنِ', #8
u'الأخرج': u'الْأَخْرَجِ', #5
u'الأخرز': u'الْأَخْرَزِ', #1
u'الأخرص': u'الْأَخْرَصُ', #1
u'الآخره': u'الآخره', #1
u'الآخره،': u'الآخره،', #1
u'الآخره،': u'الآخِرَه،', #1
u'الآخره': u'الْآخِرَه', #1
u'الآخره': u'الآخِرَهْ', #14
u'الآخره': u'الْآخِرَهْ', #35
u'الآخره،': u'الآخِرَهْ،', #5
u'الأخروان': u'الْأُخْرَوَانِ', #1
u'الآخروروي': u'الآخَرِوَرُوِيَ', #1
u'الأخرون': u'الأخرون', #1
u'الآخرى': u'الآُخْرَى', #1
u'الآخرية': u'الْآخِرِيَّة', #1
u'الآخرية': u'الْآخِرِيَّةُ', #1
u'الآخرية': u'الْآخِرِيَّةَ', #11
u'الآخرية': u'الْآخِرِيَّةِ', #24
u'الأخرين': u'الْأَخِرِينَ', #2
u'الأخزاف': u'الْأَخْزَافِ', #1
u'الأخزر': u'الْأَخْزَرِ', #10
u'الأخزر': u'الْأَخْزَرُ', #2
u'الأخس': u'الْأَخَسَّ', #10
u'الأخس': u'الْأَخَسِّ', #11
u'الأخس': u'الْأَخَسُّ', #5
u'الأخساء': u'الْأَخِسَّاءِ', #15
u'الأخساس': u'الْأَخْسَاسِ', #1
u'الأخستري': u'الْأَخْسَتْرِيِّ', #1
u'الأخسكتي': u'الْأَخْسَكْتِيُّ', #1
u'الأخسيكتي': u'الْأَخْسِيكَتِيُّ', #1
u'الأخسيكثي': u'الْأَخْسِيكَثِيِّ', #3
u'الأخشاد': u'الْأَخْشَادِ', #2
u'الأخشبان': u'الْأَخْشَبَانِ', #4
u'الأخشبين،': u'الأَخْشَبَيْنِ،', #1
u'الأخشبين،': u'الْأَخْشَبَيْنِ،', #1
u'الأخشبين': u'الْأَخْشَبَيْنِ', #13
u'الأخشبين': u'الأَخْشَبَيْنِ', #5
u'الأخشم': u'الْأَخْشَمِ', #19
u'الأخشم': u'الْأَخْشَمُ', #3
u'الإخشيد': u'الْإِخْشِيدِ', #1
u'الإخصاء': u'الإِخْصَاءُ', #1
u'الإخصاء': u'الْإِخْصَاءَ', #1
u'الإخصاء': u'الإِخْصَاءِ', #2
u'الإخصاء': u'الْإِخْصَاءُ', #3
u'الإخصاء': u'الْإِخْصَاءِ', #5
u'الإخصاص': u'الْإِخْصَاص', #1
u'الإخصاص': u'الْإِخْصَاصُ', #1
u'الإخصاص': u'الْإِخْصَاصِ', #1
u'الأخصر': u'الْأَخْصَرُ', #123
u'الأخصر': u'الْأَخْصَرَ', #14
u'الأخصر': u'الْأَخْصَرِ', #4
u'الأخصرية': u'الْأَخْصَرِيِّةُ', #1
u'الأخصرية': u'الْأَخْصَرِيَّةُ', #5
u'الأخصية': u'الْأَخَصِّيَّةَ', #10
u'الأخصية': u'الْأَخَصِّيَّةِ', #13
u'الأخصية': u'الْأَخَصِّيَّةُ', #5
u'الأخضار': u'الْأَخْضَارِ', #1
u'الأخضري': u'الْأَخْضَرِيُّ', #1
u'الأخطب': u'الْأَخْطَبَ', #1
u'الأخطب': u'الْأَخْطَبُ', #1
u'الإخفات': u'الإخفات', #1
u'الإخفات': u'الْإِخْفَاتِ', #1
u'الإخفات': u'الْإِخْفَاتُ', #3
u'الإخفار': u'الْإِخْفَارِ', #3
u'الأخفضية': u'الْأَخْفَضِيَّةِ', #1
u'الأخفياء': u'الْأَخْفِيَاء', #1
u'الأخفياء': u'الْأَخْفِيَاءُ', #1
u'الأخفياء': u'الْأَخْفِيَاءَ', #2
u'الأخلاطي': u'الأخلاطي', #1
u'الأخلاطي': u'الْأَخْلَاطِيِّ', #162
u'الإخلالبإتمام': u'الْإِخْلَالَبِإِتْمَامِ', #1
u'الأخلص': u'الْأَخْلَصِ', #2
u'الأخلية': u'الْأَخْلِيَةَ', #2
u'الأخلية': u'الْأَخْلِيَةُ', #4
u'الأخلية': u'الْأَخْلِيَةِ', #41
u'الأخميمي': u'الْأَخْمِيمِيِّ', #1
u'الإخميمي': u'الْإِخْمِيمِيِّ', #1
u'الإخميمى': u'الإِخْمِيمِىُّ', #1
u'الإخميمي': u'الْإِخْمِيمِيُّ', #4
u'الأخنائي': u'الْأَخْنَائِيّ', #1
u'الأخنائي': u'الْأَخْنَائِيِّ', #1
u'الأخنسي،': u'الأخنسي،', #1
u'الأخنسي،': u'الأَخْنَسِيُّ،', #1
u'الأخنسي': u'الْأَخْنَسِيُّ', #1
u'الأخنسى': u'الأَخْنَسِىُّ', #1
u'الأخنسي': u'الْأَخْنَسِيِّ', #2
u'الأخنسي،': u'الْأَخْنَسِيِّ،', #2
u'الأخنسى': u'الأَخْنَسِىِّ', #3
u'الأخنسي': u'الْأَخْنَسِيّ', #4
u'الأخنسية': u'الْأَخْنَسِيَّةُ', #1
u'الأخنع': u'الأخنع', #1
u'الأخنم': u'الْأَخْنَمُ', #1
u'الأخنم': u'الْأَخْنَمِ', #1
u'الأخوض': u'الْأَخْوَضِ', #1
u'الأخية': u'الْأَخِيَّةُ', #1
u'الأخيذ': u'الْأَخِيذُ', #1
u'الأخيذة': u'الْأَخِيذَةِ', #1
u'الأخيرية': u'الْأَخْيَرِيَّةَ', #1
u'الأخيف': u'الْأَخْيَف', #1
u'الأخيف': u'الْأَخْيَفِ', #24
u'الأخيل،': u'الأَخْيَلِ،', #1
u'الأخيل': u'الْأَخْيَلَ', #1
u'الأخيلية': u'الأخيلية', #1
u'الأخيلية': u'الأخْيَلِيَّةَ', #1
u'الأخيلية': u'الأخْيَلِيَّةُ', #1
u'الأخيلية،': u'الأَخْيَلِيَّةَ،', #1
u'الأخيلية': u'الأَخْيَلِيَّةُ', #2
u'الأخينس': u'الأخينس', #1
u'الأدا': u'الْأَدَا', #13
u'الأداف': u'الْأُدَافِ', #1
u'الأدانيا': u'الْأَدَانِيَا', #2
u'الأداوة': u'الأداوة', #1
u'الأداوى': u'الأَدَاوَى', #1
u'الأداوى': u'الْأَدَاوَى', #1
u'الإدبارة': u'الْإِدْبَارَةُ', #1
u'الأدبب،': u'الأَدْبَبِ،', #1
u'الأدبب': u'الْأَدْبَبِ', #1
u'الأدبيون': u'الْأَدَبِيُّونَ', #1
u'الإدخار': u'الْإِدْخَارَ', #1
u'الإدخار': u'الْإِدْخَارِ', #3
u'الإدخار': u'الْإِدْخَارُ', #5
u'الآدر': u'الْآدَرِ', #1
u'الآدر': u'الْآدُرِ', #1
u'الأدر': u'الْأَدَرِ', #1
u'الآدر': u'الْآدَرُ', #2
u'الآدر': u'الآدر', #3
u'الأدر': u'الْأَدَرُ', #3
u'الأدراء': u'الْأَدْرَاءُ', #1
u'الإدراب': u'الْإِدْرَابِ', #2
u'الأدراع،': u'الأدراع،', #1
u'الأدراع؟': u'الأدراع؟', #1
u'الأدراع': u'الْأَدْرَاعِ', #2
u'الأدراع': u'الْأَدْرَاعَ', #4
u'الادراك': u'الِادِّرَاكِ', #2
u'الأدرة': u'الْأُدْرَةَ', #4
u'الأدرة': u'الْأُدْرَةُ', #5
u'الأدرة': u'الْأُدْرَةِ', #7
u'الأدرم': u'الْأَدْرَمَ', #1
u'الأدرم': u'الْأَدْرَمِ', #7
u'الأدرمي': u'الْأَدْرَمِيّ', #1
u'الأدرنوي': u'الْأَدِرْنَوِيِّ', #1
u'الإدعاء': u'الإدعاء', #1
u'الأدعج': u'الْأَدْعَجُ', #1
u'الأدعج': u'الْأَدْعَجْ', #2
u'الأدعيه': u'الْأَدْعِيَهْ', #1
u'الإدغال': u'الْإِدْغَالُ', #1
u'الادغام': u'الِادِّغَام', #1
u'الادغام': u'الِادِّغَامِ', #3
u'الأدفع': u'الْأَدْفَعِ', #1
u'الأدفوي': u'الْأُدْفَوِيَّ', #1
u'الأدفوي': u'الْأُدْفُوِيِّ', #1
u'الأدفوي': u'الْأُدْفُوِيُّ', #3
u'الادكار': u'الِادِّكَارِ', #1
u'الإدلال': u'الْإِدْلَالِ', #14
u'الإدلال': u'الْإِدْلَالُ', #7
u'الأدلع': u'الْأَدْلَعِ', #5
u'الآدم': u'الْآدَمُ', #1
u'الآدم': u'الْآدَمِ', #4
u'الآدم': u'الآدم', #6
u'الأدماء': u'الْأَدْمَاءُ', #2
u'الأدمان': u'الْأُدْمَانُ', #1
u'الآدمى': u'الآَدَمِىُّ', #1
u'الأدمى': u'الأَدَمِىُّ', #38
u'الآدمى': u'الآدَمِىِّ', #4
u'الآدمى': u'الآدَمِىُّ', #7
u'الآدمين': u'الْآدِمِينَ', #1
u'الأدناء': u'الْأَدْنَاء', #1
u'الأدنوية': u'الْأَدْنَوِيَّةَ', #1
u'الأدنوية': u'الْأَدْنَوِيَّةُ', #1
u'الأدنوية': u'الْأَدْنَوِيَّةِ', #1
u'الإدهان': u'الإدهان', #1
u'الادهان': u'الاِدِّهَانِ', #1
u'الإدهان': u'الْإِدْهَانِ', #11
u'الادهان': u'الِادِّهَانَ', #12
u'الإدهان': u'الإِدْهَانُ', #2
u'الادهان': u'الادِّهَانُ', #2
u'الادهان': u'الِادِّهَانُ', #21
u'الادهان': u'الِادِّهَانِ', #26
u'الإدهان': u'الْإِدْهَانُ', #8
u'الأدوا': u'الْأَدْوَا', #1
u'الأدوم': u'الْأَدْوَمِ', #1
u'الأدون': u'الْأَدْوَنُ', #16
u'الأدون': u'الْأَدْوَنَ', #19
u'الأدون': u'الْأَدْوَن', #2
u'الأدون': u'الْأَدْوَنِ', #82
u'الأدونية': u'الْأَدْوَنِيَّةِ', #1
u'الأدونية': u'الْأَدْوَنِيَّةَ', #4
u'الأدية': u'الأدية', #1
u'الأدين': u'الْأَدْيَنَ', #1
u'الأدين': u'الْأَدْيُنِ', #1
u'الأدين': u'الْأَدْيَنُ', #16
u'الأدين': u'الْأَدْيَنِ', #9
u'الإذالة': u'الْإِذَالَة', #1
u'الأذانا': u'الْأَذَانَا', #1
u'الإذانة': u'الْإِذَانَةِ', #2
u'الإذايات': u'الْإِذَايَاتِ', #1
u'الإذاية': u'الْإِذَايَةُ', #2
u'الإذاية': u'الْإِذَايَةِ', #21
u'الإذاية': u'الْإِذَايَةَ', #5
u'الأذبة': u'الْأَذِبَّةِ', #1
u'الأذبح': u'الْأَذْبَحِ', #1
u'الإذخر': u'الإِذْخَرِ', #1
u'الإذخر،': u'الإِذْخِرِ،', #1
u'الإذخر----': u'الْإِذْخِرِ----', #1
u'الإذخر': u'الْإِذْخَر', #1
u'الإذخر': u'الْإِذْخِرَُُُُ', #1
u'الإذخر،': u'الْإِذْخَرِ،', #1
u'الإذخر': u'الْإِذْخِرَ', #133
u'الإذخر': u'الإذخر', #2
u'الإذخر': u'الإِذْخِرَ', #27
u'الإذخر': u'الْإِذْخِرُ', #38
u'الإذخر': u'الْإِذْخِر', #4
u'الإذخر،': u'الإِذْخِرَ،', #5
u'الإذخر': u'الْإِذْخِرِ', #51
u'الإذخر': u'الإِذْخِرِ', #7
u'الإذخرة': u'الْإِذْخِرَةُ', #1
u'الإذراء': u'الْإِذْرَاءِ', #1
u'الأذرعي': u'الْأَذْرَعِيِّ', #1001
u'الأذرعي': u'الأذرعي', #2
u'الأذرعي': u'الْأَذْرَعِيَّ', #216
u'الأذرعي': u'الْأَذْرَعِيُّ', #8085
u'الآذرمي': u'الآذَرْمِيُّ', #1
u'الآذرمى': u'الآذَرْمِىُّ', #1
u'الآذرمى': u'الآَذَرْمِىُّ', #1
u'الأذرمي،': u'الْأَذْرَمِيُّ،', #1
u'الأذرمى': u'الأَذْرَمِىِّ', #1
u'الأذرمى': u'الأَذْرَمِىُّ', #2
u'الأذرمي،': u'الأَذْرَمِيُّ،', #3
u'الأذري': u'الْأَذْرِيَّ', #1
u'الأذعار': u'الأذْعار', #1
u'الأذعار': u'الْأَذْعَارِ', #8
u'الأذغاغ': u'الأذغاغ', #1
u'الأذفر': u'الْأَذْفَرِ', #3
u'الأذفر': u'الْأَذْفَرُ', #6
u'الإذكار': u'الْإِذْكَارِ', #5
u'الأذكارية': u'الْأَذْكَارِيَّةِ', #1
u'الأذمى،': u'الأذمى،', #1
u'الأذنى': u'الأَذَنِىُّ', #1
u'الاذنين،': u'الاذنين،', #1
u'الأذواء': u'الْأَذْوَاءِ', #1
u'الأذيب': u'الْأَذْيَبِ', #1
u'الأذىوقال': u'الْأَذَىوَقَالَ', #1
u'الأر': u'الْأَرْ', #1
u'الإر': u'الْإِرَ', #1
u'الإرا': u'الْإِرَا', #2
u'الإراء': u'الْإِرَاءِ', #1
u'الإراءة': u'الإراءة', #1
u'الإراءة': u'الْإِرَاءَةِ', #13
u'الإراءة': u'الْإِرَاءَة', #4
u'الإراءة': u'الْإِرَاءَةَ', #4
u'الإراده': u'الْإِرَادَهْ', #1
u'الأرازل': u'الْأَرَازِلِ', #1
u'الإراش': u'الْإِرَاشِ', #2
u'الأراشي': u'الْأَرَاشِيّ', #1
u'الإراشي': u'الْإِرَاشِيّ', #10
u'الأراضى': u'الأَرْاضِى', #1
u'الأراضى': u'الأَرَاضِى', #2
u'الأراضين': u'الأراضين', #1
u'الأراقم': u'الْأَرَاقِمِ', #1
u'الأراقم': u'الْأَرَاقِمَ', #3
u'الآراك': u'الْآرَاكْ', #1
u'الأرائح': u'الأرائح', #1
u'الآرائيين': u'الْآرَائِيِّينَ', #1
u'الأرائيين': u'الْأرَائِيِّينَ', #1
u'الأرايح': u'الأرايح', #1
u'الأرايح': u'الْأَرَايِحُ', #1
u'الإرباح': u'الْإِرْبَاحِ', #1
u'الإرباض': u'الْإِرْبَاضُ', #1
u'الإرباض': u'الْإِرْبَاضِ', #2
u'الإربة': u'الْإِرْبَة', #2
u'الإربة': u'الإِرْبَةِ', #20
u'الإربة': u'الْإِرْبَةِ', #42
u'الأربعا': u'الْأَرْبَعَا', #1
u'الأربعانية': u'الْأَرْبَعَانِيَّة', #1
u'الأربعه': u'الْأَرْبَعَهْ', #2
u'الأربعينا': u'الْأَرْبَعِينَا', #2
u'الأربلي': u'الْأَرْبِلِّيُّ', #1
u'الإربلي': u'الْإِرْبِلِيُّ', #2
u'الإربلي': u'الْإِرْبِلِيِّ', #3
u'الإرة': u'الإِرَةِ', #1
u'الإرة': u'الْإِرَةِ', #1
u'الأرت': u'الَأرَتّ', #1
u'الأرت': u'الْأَرَتَّ', #1
u'الأرت': u'الأَرَتِّ', #11
u'الأرت': u'الْأَرَتّ', #18
u'الأرت': u'الأرتّ', #2
u'الأرت،': u'الأرت،', #2
u'الأرت': u'الأَرَتِ', #2
u'الأرت': u'الأرت', #4
u'الأرت': u'الْأَرَتُّ', #4
u'الأرت': u'الْأَرَتِّ', #43
u'الأرت،': u'الأَرَتِّ،', #5
u'الإرتاج': u'الْإِرْتَاجِ', #1
u'الارتتاق': u'الِارْتِتَاقُ', #2
u'الارتتاق': u'الِارْتِتَاقِ', #7
u'الارتثاث': u'الِارْتِثَاثُ', #1
u'الارتثاث': u'الِارْتِثَاثِ', #11
u'الارتثاث': u'الِارْتِثَاثَ', #5
u'الارتداف': u'الِارْتِدَافَ', #1
u'الارتضاع': u'الِارْتِضَاع', #1
u'الارتضاع': u'الِارْتِضَاعُ', #14
u'الارتضاع': u'الِارْتِضَاعِ', #42
u'الارتضاع': u'الِارْتِضَاعَ', #8
u'الارتفاض': u'الارتفاض', #1
u'الارتفاض': u'الِارْتِفَاضَ', #1
u'الارتفاض': u'الِارْتِفَاضُ', #2
u'الارتفاض': u'الِارْتِفَاضِ', #4
u'الارتفاق': u'الِارْتِفَاق', #1
u'الارتفاق': u'الِارْتِفَاقِ', #132
u'الارتفاق': u'الِارْتِفَاقُ', #56
u'الارتفاق': u'الِارْتِفَاقَ', #58
u'الارتفاقات': u'الارتفاقات', #1
u'الارتفاقات': u'الِارْتِفَاقَاتِ', #4
u'الارتقاق': u'الِارْتِقَاقِ', #2
u'الأرتم': u'الأَرْتَمِ', #1
u'الارتهاب': u'الِارْتِهَابُ', #1
u'الارتياض': u'الِارْتِيَاضُ', #1
u'الارتياض': u'الِارْتِيَاضِ', #6
u'الأرث': u'الْأَرَثُّ', #1
u'الأرث': u'الْأُرْثَ', #1
u'الأرث': u'الْأُرَثِ', #3
u'الأرثم': u'الْأَرْثَم', #1
u'الأرثم': u'الْأَرْثَمِ', #1
u'الأرثم': u'الأَرْثَمُ', #3
u'الأرثم': u'الْأَرْثَمُ', #3
u'الإرثيه': u'الْإِرْثِيَّهْ', #1
u'الأرجاز': u'الْأَرْجَازِ', #1
u'الأرجاف': u'الأَرْجَافِ', #1
u'الأرجاني،': u'الأرجاني،', #1
u'الأرجاني': u'الْأَرْجَانِيُّ', #2
u'الأرحبي،': u'الأرحبي،', #1
u'الأرحبي': u'الأَرْحَبِيِّ', #1
u'الأرحبي،': u'الأَرْحَبِيِّ،', #1
u'الأرحبي': u'الْأَرْحَبِيِّ', #1
u'الأرحبى': u'الأَرْحَبِىِّ', #1
u'الأرحبي،': u'الأرحبيّ،', #2
u'الأرحبي': u'الْأَرْحَبِيُّ', #2
u'الأرحبية': u'الْأَرْحَبِيَّةَ', #1
u'الأرحبية': u'الْأَرْحَبِيَّةُ', #1
u'الأرحبية': u'الْأَرْحَبِيَّةِ', #11
u'الأرحضية': u'الْأَرْحَضِيَّةِ', #1
u'الأرحى': u'الْأَرْحَى', #1
u'الأرحية': u'الْأَرْحِيَةَ', #1
u'الأرحية': u'الْأَرْحِيَةِ', #3
u'الإرخاص': u'الإِرْخَاصَ', #1
u'الإرخاص': u'الْإِرْخَاصِ', #2
u'الإرخاص': u'الْإِرْخَاصَ', #3
u'الأردا': u'الْأَرْدَا', #1
u'الإرداع': u'الْإِرْدَاعِ', #1
u'الأردانيون': u'الْأَرْدَانِيّونَ', #1
u'الإردب': u'الْإِرْدَبُ', #1
u'الإردب': u'الْإِرْدَبَّ', #14
u'الإردب': u'الْإِرْدَبِّ', #27
u'الإردب': u'الْإِرْدَبُّ', #9
u'الإردبان': u'الْإِرْدَبَّانِ', #1
u'الأردبيلي': u'الْأَرْدَبِيلِيُّ', #2
u'الأردبيلي': u'الْأَرْدَبِيلِيِّ', #2
u'الإردبين': u'الْإِرْدَبَّيْنِ', #2
u'الأردستانى': u'الأَرْدَسَتَانِىُّ', #1
u'الأردستانى': u'الأَرْدَسْتَانِىَّ', #1
u'الأردستانى': u'الأَرْدَسْتَانِىِّ', #1
u'الأردستانى': u'الأَرْدِسْتَانِىُّ', #1
u'الأردستانى': u'الأَرْدَسْتَانِىُّ', #70
u'الأردوان': u'الْأَرْدَوَانُ', #1
u'الأردوان': u'الْأَرْدَوَانِ', #1
u'الأردى': u'الْأَرْدَى', #2
u'الإرزاق': u'الْإِرْزَاقِ', #2
u'الأرزاقات': u'الْأَرْزَاقَاتِ', #1
u'الأرزق': u'الأَرْزَقُ', #1
u'الأرزن': u'الأَرْزَنَ', #1
u'الأرزن': u'الْأَرْزَنُ', #1
u'الأرزن': u'الْأَرْزَنِ', #2
u'الأرزنانى': u'الأَرْزُنَانِىُّ', #1
u'الأرسابندي': u'الأرسابندي', #1
u'الأرسال': u'الأرسال', #1
u'الأرسال': u'الْأَرْسَالَ', #1
u'الأرسال': u'الْأَرْسَالِ', #1
u'الإرسالا': u'الْإِرْسَالَا', #4
u'الارسان': u'الارسان', #1
u'الأرسح': u'الْأَرْسَحِ', #1
u'الأرسطاليسية': u'الأرسطاليسية', #1
u'الأرسوفي': u'الأرْسُوفيّ', #1
u'الأرسوفي،': u'الأرْسُوفيّ،', #1
u'الأرسوفي،': u'الأَرْسُوفِيُّ،', #1
u'الأرسوفي،': u'الأُرْسُوفِيُّ،', #1
u'إلارسول': u'إِلارَسُولٌ', #2
u'الأرش': u'الْأَرْشُ', #1238
u'الأرش': u'الْأَرْشِ', #1458
u'الأرش': u'الأَرْشَ', #2
u'الأرش': u'الْأَرْشَ', #738
u'الأرش': u'الْأَرْش', #8
u'الأرشا': u'الْأَرْشَا', #1
u'الإرشاق': u'الْإِرْشَاقُ', #1
u'الإرشاق': u'الْإِرْشَاقِ', #1
u'الأرشان': u'الْأَرْشَانِ', #4
u'الأرشدية': u'الْأَرْشَدِيَّةَ', #14
u'الأرشدية': u'الْأَرْشَدِيَّةِ', #19
u'الأرشدية': u'الْأَرْشَدِيَّةُ', #7
u'الأرشين': u'الْأَرْشَيْنِ', #12
u'الأرصح': u'الْأَرْصَحِ', #1
u'الأرض': u'الْأَرْضً', #1
u'الارض': u'الارض', #1
u'الإرضاخ': u'الْإِرْضَاخُ', #1
u'الإرضاخ': u'الْإِرْضَاخِ', #1
u'الإرضاعة': u'الْإِرْضَاعَةُ', #3
u'الأرضتقدم': u'الأَرْضِتَقَدَّمَ', #1
u'الأرضوالوجه': u'الأَرْضِوَالْوَجْهُ', #1
u'الأرضوروي': u'الأَرْضِوَرُوِيَ', #2
u'الأرضينقوله': u'الْأَرَضِينَقَوْلُهُ', #1
u'الإرعواء': u'الْإِرْعِوَاء', #1
u'الإرغاب': u'الْإِرْغَابِ', #1
u'الأرغل': u'الأَرْغَلِ', #1
u'الأرغي': u'الْأَرْغِيِّ', #1
u'الأرغياني،': u'الأَرْغِيَانِيِّ،', #1
u'الأرغيانى': u'الأَرْغَيَانِىُّ', #1
u'الأرغيانى': u'الأَرْغِيَانِىُّ', #1
u'الأرغيانى': u'الأَرْغِيَانِىِّ', #1
u'الأرغياني': u'الْأَرْغِيَانِيُّ', #2
u'الأرف': u'الأُرَفُ', #1
u'الأرف': u'الْأُرَفُ', #1
u'الأرف': u'الْأَرْفَ', #2
u'الإرفاء': u'الإِرْفَاءِ', #1
u'الأرفاض': u'الْأَرْفَاضِ', #1
u'الأرفاغ': u'الْأَرْفَاغِ', #2
u'الأرفاق': u'الْأَرْفَاقُ', #1
u'الأرفاق': u'الْأَرْفَاقِ', #1
u'الأرفق': u'الْأَرْفَق', #1
u'الأرفق': u'الْأَرْفَقَ', #16
u'الأرفق': u'الْأَرْفَقُ', #30
u'الأرفق': u'الْأَرْفَقِ', #9
u'الأرفقية': u'الْأَرْفَقِيَّةِ', #2
u'الأرقا': u'الْأَرِقَّا', #1
u'الإرقاء': u'الْإِرْقَاءِ', #3
u'الإرقاب': u'الْإِرْقَابِ', #7
u'الإرقاق': u'الْإِرْقَاقُ', #2
u'الإرقاق': u'الْإِرْقَاقِ', #23
u'الإرقاق': u'الْإِرْقَاقَ', #5
u'الأرقس': u'الْأَرْقَسِ', #1
u'الأركان': u'الْأَرْكَانًًًًِ', #1
u'الأركون،': u'الأَرْكُونِ،', #1
u'الأرماث': u'الْأَرْمَاثَ', #1
u'الإرماث': u'الإِرْمَاثِ', #1
u'الأرماس': u'الْأَرْمَاسِ', #1
u'الإرماض': u'الْإِرْمَاضِ', #2
u'الأرماك': u'الْأَرْمَاكِ', #4
u'الأرماك': u'الْأَرْمَاكَ', #5
u'الإرمال': u'الْإِرْمَالِ', #1
u'الأرملية': u'الْأَرْمَلِيَّةَ', #1
u'الأرملية': u'الْأَرْمَلِيَّةُ', #1
u'الأرمنتي': u'الْأَرْمِنْتِيِّ', #1
u'الإرمني': u'الْإِرْمَنِي', #1
u'الإرمني': u'الْإِرْمَنِيُّ', #1
u'الإرمني': u'الْإِرْمَنِيِّ', #1
u'الأرمهان': u'الأرمهان', #3
u'الأرموي،': u'الأرموي،', #1
u'الأرموي': u'الأَرْمَوِيُّ', #1
u'الأرموى': u'الأَرْمَوْىُّ', #1
u'الأرموى': u'الأُرَمَوِىُّ', #1
u'الأرموي': u'الْأُرْمَوِيُّ', #10
u'الأرموي': u'الْأُرْمَوِيِّ', #2
u'الأرموى': u'الأَرْمَوِىُّ', #2
u'الأرموى': u'الأُرْمَوِىُّ', #4
u'الأرمي': u'الْأَرْمِيُّ', #1
u'الإرنان': u'الْإِرْنَانِ', #1
u'الأرنؤوط': u'الأرنؤوط', #1
u'الأروام': u'الْأَرْوَامُ', #2
u'الأروام': u'الْأَرْوَامِ', #7
u'الأروج': u'الْأُرُوجِ', #1
u'الأروج': u'الْأَرْوَجَ', #2
u'الأروج': u'الْأَرْوَجِ', #21
u'الأروج': u'الْأَرْوَجُ', #3
u'الأرؤس': u'الْأَرْؤُسَ', #1
u'الأرؤس': u'الْأَرْؤُسِ', #1
u'الأروش': u'الْأُرُوشَ', #1
u'الأروش': u'الْأُرُوشُ', #1
u'الأروش': u'الْأُرُوشِ', #17
u'الأروى': u'الْأَرْوَى', #15
u'الأريبا': u'الْأَرِيبَا', #1
u'الأريسين': u'الْأَرِيسِينَ', #1
u'الأريسين': u'الْأَرِيسِيِّنَ', #1
u'الأريسيون': u'الأريسيون', #1
u'الأريسيون': u'الْأَرِيسِيُّونَ', #4
u'الإريسيين': u'الإِرِّيسِيِّينَ', #1
u'الأريسيين': u'الْأَرِيسِيِّينَ', #11
u'الأريسيين': u'الأَرِيسِيِّينَ', #5
u'الأريقط': u'الأُرَيْقِطِ', #1
u'الأريقط': u'الْأُرَيْقِطُ', #1
u'الأريقط': u'الْأُرَيْقِطِ', #8
u'الأرين': u'الْأَرِينَ', #1
u'الأرينا': u'الأرِينا', #1
u'الأرينا': u'الْأَرِينَا', #2
u'الأزارقة': u'الْأزَارِقَةِ', #1
u'الأزارقة،': u'الأَزَارِقَةُ،', #1
u'الأزارقة،': u'الأَزَّارِقَةُ،', #1
u'الأزارقة،': u'الْأَزْارِقَةِ،', #1
u'الأزارقة': u'الأَزَارِقَةُ', #2
u'الأزارقة،': u'الأَزَارِقَةَ،', #2
u'الأزارقة': u'الْأَزَارِقَةِ', #2
u'الأزارقة': u'الأَزَارِقَةَ', #3
u'الأزارقة': u'الأَزَارِقَةِ', #3
u'الأزارقة،': u'الأَزَارِقَةِ،', #3
u'الأزارقة': u'الْأَزَارِقَةَ', #4
u'الأزارقة': u'الْأَزَارِقَةُ', #4
u'الأزب': u'الْأَزَبِّ', #1
u'الإزب': u'الْإِزْبِ', #1
u'الإزب': u'الْإِزْبُ', #2
u'الأزب': u'الْأَزَبّ', #8
u'الأزبي': u'الْأَزَبَّيْ', #1
u'الأزج': u'الْأَزَجَ', #1
u'الأزج': u'الْأَزَجُ', #2
u'الأزج': u'الْأَزَجُّ', #2
u'الأزج': u'الْأَزَجِّ', #2
u'الأزج': u'الْأَزَجِ', #4
u'الأزجي': u'الْأَزِجِي', #1
u'الأزجي': u'الْأَزِجِيَّ', #1
u'الأزجي': u'الْأَزَجِيِّ', #100
u'الأزجي': u'الْأَزَجِيُّ', #330
u'الأزد': u'الأزْد', #1
u'الأزد': u'الأَزْدُ', #1
u'الأزد': u'الْأَزْدَ', #1
u'الأزد؟': u'الْأَزْدِ؟', #1
u'الأزد،': u'الأَزْدِ،', #12
u'الأزد': u'الأزد', #15
u'الأزد،': u'الأزد،', #2
u'الأزد': u'الأَزْد', #2
u'الأزد': u'الأَزْدِ', #26
u'الأزد،': u'الْأَزْدِ،', #4
u'الأزد': u'الْأَزْدِ', #69
u'الأزد': u'الْأَزْدُ', #7
u'الازدراع': u'الِازْدِرَاعَ', #1
u'الازدراع': u'الِازْدِرَاعُ', #1
u'الازدراع': u'الِازْدِرَاعِ', #7
u'الأزدشير': u'الْأَزْدِشِيرُ', #1
u'الازدلاف': u'الِازْدِلَافِ', #10
u'الازدلاف': u'الِازْدِلَافُ', #3
u'الأزدي،': u'الأزديّ،', #1
u'الأزدي،': u'الأزْدي،', #1
u'الأزدي،': u'الأزْديٍّ،', #1
u'الأزدي': u'الأزْدِي', #1
u'الأزدي': u'الأزْدِيّ', #1
u'الأزدي': u'الأَزَدِيُّ', #1
u'الأزدي': u'الأَزْدُيُّ', #1
u'الأزدي،': u'الأَزْدِيّ،', #1
u'الأزدي،': u'الْأَزْدِيَّ،', #1
u'الأزدى،': u'الأزدى،', #1
u'الأزدى': u'الأَزْدِى', #1
u'الأزدى': u'الْأَزْدِىُّ', #1
u'الأزدي': u'الْأَزْدِيّ', #12
u'الأزدي': u'الْأَزْدِيَّ', #12
u'الأزدي': u'الأَزْدِيِّ', #14
u'الأزدي': u'الْأَزْدِيُّ', #167
u'الأزدي': u'الأزدي', #19
u'الأزدي': u'الأَزْدِيَّ', #2
u'الأزدي،': u'الأَزْدِيَّ،', #2
u'الأزدي،': u'الْأَزْدِيِّ،', #2
u'الأزدى': u'الأَزْدِىِّ', #20
u'الأزدي': u'الأَزْدِيُّ', #24
u'الأزدي': u'الأزديّ', #3
u'الأزدي،': u'الْأَزْدِيُّ،', #3
u'الأزدي،': u'الأزدي،', #33
u'الأزدي': u'الْأُزْدِيّ', #4
u'الأزدى': u'الأَزْدِىَّ', #4
u'الأزدي،': u'الأَزْدِيِّ،', #41
u'الأزدي': u'الْأَزْدِيِّ', #57
u'الأزدى': u'الأَزْدِىُّ', #62
u'الأزدي،': u'الأَزْدِيُّ،', #88
u'الأزدية': u'الأَزْدِيَّةُ', #1
u'الأزدية،': u'الأَزْدِيَّةِ،', #1
u'الأزدية': u'الْأَزْدِيَّةُ', #2
u'الأزدية': u'الأَزْدِيَّةِ', #3
u'الأزدية': u'الْأَزْدِيَّةِ', #7
u'الأزديين': u'الْأَزْدِيّيْنِ', #2
u'الإزرار': u'الْإِزْرَارِ', #2
u'الأزرة': u'الْأَزْرَةُ', #1
u'الأزرة': u'الْأَزْرَةِ', #1
u'الإزرة': u'الْإِزْرَةَ', #1
u'الأزرة': u'الْأُزْرَةِ', #2
u'الأزرة': u'الْأُزْرَةُ', #3
u'الأزرع': u'الأَزْرَعِ', #1
u'الأزرقي،': u'الْأَزْرَقِيُّ،', #1
u'الأزرقي': u'الْأَزْرَقِيّ', #10
u'الأزرقي': u'الْأَزْرَقِيِّ', #20
u'الأزرقي': u'الْأَزْرَقِيُّ', #56
u'الأزرقى': u'الأَزْرَقِىُّ', #6
u'الأزرقي،': u'الأَزْرَقِيُّ،', #7
u'الأزرمي': u'الْأَزْرَمِيِّ', #1
u'الأزفر،': u'الأَزْفَرُ،', #1
u'الإزلاق': u'الْإِزْلَاقِ', #3
u'الأزلم': u'الْأَزْلَمَ', #1
u'الأزلم': u'الْأَزْلَمِ', #4
u'الأزم': u'الأَزْمِ', #1
u'الأزم': u'الْأَزْم', #1
u'الأزم': u'الْأَزْمِ', #1
u'الأزم': u'الْأَزْمُ', #2
u'الأزمع': u'الأَزْمُعِ', #1
u'الأزمع': u'الأَزْمَعِ', #5
u'الأزمع': u'الْأَزْمَعِ', #5
u'الأزمنه': u'الْأَزْمِنَهْ', #1
u'الإزميري': u'الإزميري', #1
u'الإزميري': u'الْإِزْمِيرِيُّ', #1
u'الأزهاد': u'الْأَزْهَادِ', #1
u'الأزهد': u'الْأَزْهَدِ', #1
u'الأزهد': u'الْأَزْهَدُ', #2
u'الأزهرى': u'الأَزْهَرِىُّ', #2
u'الأزور': u'الأزور', #1
u'الأزور،': u'الأَزْوَرِ،', #1
u'الأزور،': u'الْأَزْوَرِ،', #1
u'الأزور': u'الْأَزْوَرِ', #20
u'الأزور': u'الأَزْوَرِ', #7
u'الأزيب': u'الأَزْيَبُ', #1
u'الإساء': u'الْإِسَاءُ', #1
u'الأساجيع': u'الْأَسَاجِيعَ', #2
u'الأسارون': u'الأسارون', #1
u'الأسارى؟،': u'الأُسَارَى؟،', #1
u'الأسارى؟': u'الْأُسَارَى؟', #1
u'الأسارى': u'الْأُسَارَى', #191
u'الأسارى،': u'الأُسَارَى،', #3
u'الأسارى؟': u'الأُسَارَى؟', #3
u'الأسارى،': u'الْأُسَارَى،', #3
u'الأسارى': u'الأُسَارَى', #30
u'الأسارى': u'الْأَسَارَى', #69
u'الأسافلة': u'الْأَسَافِلَةِ', #1
u'الأساقف': u'الْأَسَاقِفْ', #1
u'الأسالة': u'الْأَسَالَة', #1
u'الأسالفة': u'الْأَسَالِفَةِ', #1
u'الأسامة': u'الْأُسَامَةِ', #1
u'الإسامة': u'الْإِسَامَةَ', #12
u'الإسامة': u'الْإِسَامَةُ', #15
u'الإسامة': u'الْإِسَامَةِ', #49
u'الأسامى': u'الأَسَامِىَ', #1
u'الأساود': u'الأساود', #1
u'الأساود،': u'الأساود،', #1
u'الأساود': u'الأَسَاوِدِ', #1
u'الأساود': u'الْأَسَاوِدَ', #1
u'الأساود': u'الْأَسَاوِدِ', #2
u'الأساودة': u'الْأَسَاوِدَةِ', #1
u'الأساوره': u'الْأَسَاوِرَهْ', #3
u'الأسبات': u'الْأَسْبَاتِ', #1
u'الإسبانيكي': u'الْإسْبَانِيكِيِّ', #1
u'الأسبذى': u'الأَسْبَذِىُّ', #1
u'الأسبذى': u'الأَسْبَذِىِّ', #2
u'الأسبذيين': u'الأَسْبَذِيِّينَ', #1
u'الأسبط': u'الْأَسْبِطِ', #1
u'الأسبقا': u'الْأَسْبَقَا', #1
u'الأسبك': u'الْأَسْبَكُ', #35
u'الأسبك': u'الْأَسْبَكَ', #5
u'الأسبلة': u'الْأَسْبِلَةِ', #2
u'الإسبهبدية': u'الإسبهبدية', #1
u'الاسبهدية': u'الاسبهدية', #1
u'الإسبيجابي': u'الْإِسْبِيجَابِيّ', #1
u'الإسبيجابي': u'الْإِسْبِيجَابِيِّ', #155
u'الإسبيجابي': u'الْإِسْبِيجَابِيُّ', #577
u'الإسبيجابي': u'الْإِسْبِيجَابِيَّ', #7
u'الإست': u'الْإِسْت', #1
u'الاست': u'الاست', #1
u'الاست،': u'الاسْتَ،', #1
u'الاست': u'الِاسْتَ', #2
u'الاست': u'الِاسْتُ', #4
u'الاست': u'الِاسْتِ', #5
u'الإستار': u'الْإِسْتَارُ', #1
u'الأستاه': u'الأستاه', #1
u'الاستباع': u'الِاسْتِبَاعُ', #1
u'الاستبذار': u'الِاسْتِبْذَارِ', #1
u'الاستبرا': u'الِاسْتِبْرَا', #3
u'الاستبضاع،': u'الاسْتِبْضَاعِ،', #1
u'الاستبضاع': u'الِاسْتِبْضَاعَ', #1
u'الاستبضاع': u'الِاسْتِبْضَاعُ', #1
u'الاستبضاع': u'الاِسْتِبْضَاعِ', #1
u'الاستبضاع': u'الِاسْتِبْضَاعِ', #4
u'الاستتابة': u'الِاسْتِتَابَةِ', #140
u'الاستتابة': u'الِاسْتِتَابَةَ', #15
u'الاستتابة': u'الاِسْتِتَابَةَ', #2
u'الاستتابة': u'الِاسْتِتَابَةُ', #22
u'الاستثابة': u'الِاسْتِثَابَةَ', #1
u'الاستثبات': u'الِاسْتِثْبَاتُ', #2
u'الاستثبات': u'الِاسْتِثْبَاتِ', #5
u'الاستثفار': u'الِاسْتِثْفَار', #1
u'الاستثفار': u'الِاسْتِثْفَارِ', #1
u'الاستثفار': u'الِاسْتِثْفَارُ', #4
u'الاستثقالوالوجه': u'الاسْتَثْقَالُوَالْوَجْهُ', #1
u'الاستثنا': u'الِاسْتِثْنَا', #1
u'الإستثناء': u'الإستثناء', #1
u'الاستثياق': u'الِاسْتِثْيَاقِ', #1
u'الاستجازة': u'الِاسْتِجَازَةُ', #1
u'الاستجبار': u'الِاسْتِجْبَارِ', #1
u'الاستجرار': u'الِاسْتِجْرَارُ', #1
u'الاستجرار': u'الِاسْتِجْرَارِ', #7
u'الاستجعال': u'الِاسْتِجْعَالِ', #1
u'الإستجمار': u'الإِسْتِجْمَارِ', #1
u'الاستجمار': u'الاسْتِجْمَارُ', #1
u'الاستجمار': u'الاسْتِجْمَارِ', #1
u'الاستجمار': u'الِاسْتِجْمَارُ', #111
u'الاستجمار': u'الِاسْتِجْمَارِ', #157
u'الاستجمار': u'الاِسْتِجْمَارُ', #2
u'الاستجمار': u'الاِسْتِجْمَارِ', #2
u'الاستجمار': u'الِاسْتِجْمَارَ', #35
u'الاستجهال': u'الِاسْتِجْهَالِ', #1
u'الاستحاضة': u'الِاسْتِحَاضَةِ', #305
u'الاستحاضة': u'الِاسْتِحَاضَةُ', #37
u'الاستحاضة': u'الِاسْتِحَاضَةَ', #47
u'الاستحاضة': u'الِاسْتِحَاضَة', #6
u'الاستحبابي': u'الِاسْتِحْبَابِيِّ', #1
u'الاستحبابية': u'الِاسْتِحْبابِيَّة', #1
u'الاستحداد': u'الِاسْتِحْدَادَ', #1
u'الاستحداد': u'الِاسْتِحْدَادُ', #10
u'الاستحداد': u'الِاسْتِحْدَادِ', #3
u'الاستحراز': u'الِاسْتِحْرَازِ', #1
u'الاستحشاف': u'الِاسْتِحْشَافَ', #1
u'الاستحكار': u'الِاسْتِحْكَارِ', #1
u'الاستحكار': u'الِاسْتِحْكَارُ', #3
u'الاستحماد': u'الِاسْتِحْمَادِ', #1
u'الاستخباث': u'الِاسْتِخْبَاثِ', #1
u'الاستخذاء': u'الاسْتِخْذَاءُ', #1
u'الاستدار': u'الِاسْتِدَارِ', #1
u'الاستدخال': u'الاستدخال', #1
u'الاستدخال': u'الِاسْتِدْخَالَ', #13
u'الاستدخال': u'الِاسْتِدْخَالُ', #13
u'الاستدخال': u'الِاسْتِدْخَالِ', #33
u'الاستذلال': u'الِاسْتِذْلَالِ', #5
u'الإسترابادي': u'الإسترابادي', #1
u'الأستراباذي': u'الأستراباذي', #2
u'الإستراباذي': u'الْإِسْتِرَابَاذِي', #3
u'الإستراباذي': u'الإستراباذي', #6
u'الاسترابة': u'الِاسْتِرَابَةَ', #2
u'الاسترابة': u'الِاسْتِرَابَةُ', #2
u'الاسترابة': u'الِاسْتِرَابَةِ', #5
u'الاسترباح': u'الِاسْتِرْبَاح', #1
u'الاسترباح': u'الِاسْتِرْبَاحَ', #10
u'الاسترباح': u'الِاسْتِرْبَاحِ', #28
u'الاسترباح': u'الِاسْتِرْبَاحُ', #41
u'الاسترباحي': u'الاسترباحي', #1
u'الاسترباحي': u'الِاسْتِرْبَاحِيِّ', #1
u'الاسترقاء': u'الِاسْتِرْقَاء', #1
u'الاسترقاء': u'الِاسْتِرْقَاءِ', #19
u'الاسترقاء': u'الِاسْتِرْقَاءُ', #5
u'الاسترقاء': u'الِاسْتِرْقَاءَ', #8
u'الاسترقاق': u'الِاسْتِرْقَاقِ', #167
u'الاسترقاق': u'الِاسْتِرْقَاقَ', #30
u'الاسترقاق': u'الِاسْتِرْقَاقُ', #56
u'الأستروشني': u'الأستروشني', #8
u'الأستروشنية': u'الأُسْتُروشَنِيَّة', #3
u'الأستري': u'الأستري', #1
u'الاستزكاء': u'الِاسْتِزْكَاءِ', #11
u'الاستزكاء': u'الِاسْتِزْكَاءَ', #2
u'الاستزكاء': u'الاستزكاء', #5
u'الاستزكاء': u'الِاسْتِزْكَاءُ', #8
u'الاستسراء': u'الِاسْتِسْرَاءُ', #1
u'الاستسراج': u'الِاسْتِسْرَاجِ', #1
u'الإستسعاء': u'الإِسْتِسْعَاءِ', #1
u'الاستسعاء': u'الِاسْتِسْعَاءِ', #148
u'الاستسعاء': u'الاِسْتِسْعَاءَ', #3
u'الاستسعاء': u'الِاسْتِسْعَاءُ', #50
u'الاستسعاء': u'الِاسْتِسْعَاءَ', #67
u'الاستسعاء': u'الاِسْتِسْعَاءِ', #8
u'الاستسقاءالذي': u'الِاسْتِسْقَاءُالَّذِي', #1
u'الاستسقاءعلى': u'الِاسْتِسْقَاءُعَلَى', #1
u'الاستسقاءكم': u'الِاسْتِسْقَاءِكَمْ', #1
u'الاستسقاط': u'الِاسْتِسْقَاطِ', #1
u'الاستسلاف': u'الاسْتِسْلافِ', #1
u'الاستسلاف': u'الِاسْتِسْلَافِ', #1
u'الاستسلاف': u'الاِسْتِسْلاَفِ', #2
u'الاستسلاف': u'الِاسْتِسْلَافَ', #4
u'الاستسمان': u'الاستسمان', #1
u'الاستشرار': u'الِاسْتِشْرَارِ', #1
u'الإستشفاء': u'الإستشفاء', #1
u'الاستشفاق': u'الِاسْتِشْفَاقَ', #1
u'الاستشفاق': u'الِاسْتِشْفَاقِ', #1
u'الاستصحاء': u'الِاسْتِصْحَاءِ', #1
u'الاستصناع': u'الِاسْتِصْنَاعِ', #113
u'الاستصناع': u'الِاسْتِصْنَاعَ', #43
u'الاستصناع': u'الِاسْتِصْنَاعُ', #59
u'الاستضرار': u'الِاسْتِضْرَارَ', #1
u'الاستضرار': u'الِاسْتِضْرَارُ', #3
u'الاستضرار': u'الِاسْتِضْرَارِ', #3
u'الاستطراق': u'الِاسْتِطْرَاقَ', #25
u'الاستطراق': u'الِاسْتِطْرَاقُ', #46
u'الاستطراق': u'الِاسْتِطْرَاقِ', #75
u'الاستطهار': u'الاِسْتِطْهَارِ', #1
u'الاستعاذ': u'الِاسْتِعَاذُ', #1
u'الاستعاط': u'الِاسْتِعَاطُ', #1
u'الاستعاط': u'الِاسْتِعَاطِ', #2
u'الاستعجاب': u'الِاسْتِعْجَابِ', #1
u'الاستعلان': u'الِاسْتِعْلَانَ', #1
u'الاستعلان،': u'الِاسْتِعْلَانَ،', #1
u'الاستعواض': u'الِاسْتِعْوَاضَ', #1
u'الاستغزار': u'الِاسْتِغْزَارِ', #2
u'الاستغسال': u'الاِسْتِغْسَالِ', #1
u'الاستغسال': u'الِاسْتِغْسَالُ', #2
u'الإستغفار': u'الإِسْتِغْفَارِ', #2
u'الاستغنام': u'الِاسْتِغْنَامِ', #11
u'الاستغنام': u'الِاسْتِغْنَامُ', #3
u'الاستفحاش': u'الِاسْتِفْحَاشُ', #2
u'الاستفراش': u'الِاسْتِفْرَاشُ', #12
u'الاستفراش': u'الِاسْتِفْرَاشِ', #16
u'الاستفراش': u'الِاسْتِفْرَاشَ', #9
u'الاستفراق': u'الِاسْتِفْرَاقَ', #1
u'الاستفصال': u'الِاسْتِفْصَالَ', #15
u'الاستفصال': u'الِاسْتِفْصَالُ', #16
u'الاستفصال': u'الاستفصال', #3
u'الاستفصال': u'الِاسْتِفْصَالِ', #58
u'الاستفضال': u'الِاسْتِفْضَالِ', #1
u'الاستفعال': u'الِاسْتِفْعَالُ', #1
u'الاستفعال': u'الِاسْتِفْعَالِ', #4
u'الاستقا': u'الِاسْتِقَا', #1
u'الإستقاء': u'الإستقاء', #1
u'الاستقاءة': u'الِاسْتِقَاءَةِ', #14
u'الاستقاءة': u'الِاسْتِقَاءَةَ', #2
u'الاستقاءة': u'الِاسْتِقَاءَةُ', #4
u'الاستقدار': u'الِاسْتِقْدَارِ', #1
u'الاستقضاء': u'الِاسْتِقْضَاءِ', #2
u'الاستكان': u'الِاسْتِكَانُ', #1
u'الاستكتام': u'الِاسْتِكْتَامُ', #1
u'الاستكتام': u'الِاسْتِكْتَامِ', #1
u'الاستكراء': u'الِاسْتِكْرَاءَ', #1
u'الاستكراء': u'الِاسْتِكْرَاءِ', #2
u'الاستكساب': u'الِاسْتِكْسَابُ', #1
u'الاستكفاء': u'الِاسْتِكْفَاءَ', #1
u'الاستكفاء': u'الِاسْتِكْفَاءِ', #9
u'الاستكفاف': u'الِاسْتِكْفَافِ', #1
u'الاستكنان': u'الِاسْتِكْنَانُ', #1
u'الإستماع،': u'الإِسْتِمَاعُ،', #1
u'الاستمانة': u'الِاسْتِمَانَةُ', #2
u'الاستمطار': u'الِاسْتِمْطَارُ', #1
u'الاستمطار': u'الِاسْتِمْطَارِ', #1
u'الاستمطار': u'الْاسْتِمْطَارِ', #1
u'الاستمطار': u'الاِسْتِمْطَارِ', #1
u'الاستناب': u'الِاسْتِنَابُ', #1
u'الاستنادة': u'الِاسْتِنَادَةُ', #1
u'الاستنان': u'الاِسْتِنَانُ', #1
u'الاستنان': u'الِاسْتِنَانِ', #10
u'الاستنان': u'الِاسْتِنَانَ', #2
u'الاستنان': u'الِاسْتِنَان', #5
u'الاستنان': u'الِاسْتِنَانُ', #7
u'الاستنتار': u'الِاسْتِنْتَارِ', #1
u'الاستنثار': u'الاسْتِنْثَارِ', #1
u'الاستنثار': u'الاِسْتِنْثَارِ', #1
u'الاستنثار': u'الِاسْتِنْثَارُ', #11
u'الاستنثار': u'الِاسْتِنْثَار', #2
u'الاستنثار': u'الِاسْتِنْثَارِ', #21
u'الاستنثار': u'الِاسْتِنْثَارَ', #8
u'الاستنجا': u'الِاسْتِنْجَا', #1
u'الإستنجاء،': u'الإِسْتِنْجَاءَ،', #1
u'الاستنجاء': u'الاسْتِنْجَاءَ', #1
u'الاستنجاء': u'الاِسْتِنْجَاءِ', #13
u'الاستنجاء': u'الِاسْتِنْجَاءَ', #175
u'الاستنجاء': u'الِاسْتِنْجَاء', #21
u'الاستنجاء': u'الاسْتِنْجَاءِ', #3
u'الاستنجاء': u'الاِسْتِنْجَاءَ', #3
u'الاستنجاء': u'الاِسْتِنْجَاءُ', #3
u'الاستنجاء': u'الِاسْتِنْجَاءُ', #360
u'الاستنجاء': u'الاستنجاء', #6
u'الاستنجاء': u'الِاسْتِنْجَاءِ', #977
u'الاستنزاه': u'الِاسْتِنْزَاهُ', #1
u'الاستنصاح': u'الِاسْتِنْصَاحِ', #1
u'الاستنظار': u'الاِسْتِنْظَارِ', #1
u'الاستنظار': u'الِاسْتِنْظَارَ', #2
u'الاستنظاف': u'الِاسْتِنْظَافُ', #2
u'الاستنفاع': u'الِاسْتِنْفَاعِ', #1
u'الاستنفاق': u'الِاسْتِنْفَاقُ', #1
u'الاستنفاق': u'الِاسْتِنْفَاقِ', #1
u'الاستنقاء': u'الِاسْتِنْقَاءُ', #1
u'الاستنقاص': u'الِاسْتِنْقَاصُ', #1
u'الاستنقاص': u'الِاسْتِنْقَاصِ', #1
u'الاستنكاح': u'الِاسْتِنْكَاحَ', #1
u'الاستنكاح': u'الِاسْتِنْكَاحِ', #2
u'الاستنكاه': u'الِاسْتِنْكَاهِ', #5
u'الاستنماء': u'الِاسْتِنْمَاءُ', #2
u'الاستنماء': u'الِاسْتِنْمَاءِ', #27
u'الاستنماء': u'الِاسْتِنْمَاءَ', #4
u'الإستهام': u'الإِسْتِهَامِ', #1
u'الاستهام': u'الِاسْتِهَامَ', #1
u'الاستهام': u'الاِسْتِهَامِ', #1
u'الاستهام': u'الِاسْتِهَامِ', #9
u'الاستهدام': u'الِاسْتِهْدَام', #1
u'الاستهزا': u'الِاسْتِهْزَا', #1
u'الاستوا': u'الِاسْتِوَا', #2
u'الاستئجال': u'الِاسْتِئْجَالِ', #1
u'الاستئناء': u'الِاسْتِئْنَاءِ', #3
u'الاستياك': u'الِاسْتِيَاك', #1
u'الاستياك': u'الِاسْتِيَاكَ', #20
u'الاستياك': u'الاِسْتِيَاكِ', #4
u'الاستياك': u'الِاسْتِيَاكِ', #49
u'الاستياك': u'الِاسْتِيَاكُ', #61
u'الاستيام': u'الاسْتِيَامَ', #1
u'الاستيام': u'الاِسْتِيَامِ', #1
u'الاستيام': u'الِاسْتِيَامَ', #12
u'الاستيام': u'الِاسْتِيَامُ', #12
u'الاستيام': u'الِاسْتِيَامِ', #12
u'الاستيثار': u'الِاسْتِيثَارِ', #2
u'الاستيجاه': u'الِاسْتِيجَاهُ', #1
u'الاستيراء': u'الِاسْتِيرَاءِ', #1
u'الاستيصال': u'الِاسْتِيصَالُ', #1
u'الاستيصال': u'الِاسْتِيصَالِ', #2
u'الاستيضاء': u'الِاسْتِيضَاءِ', #1
u'الاستيفاز': u'الِاسْتِيفَازِ', #1
u'الاستيمارات': u'الِاسْتَيمَارَاتِ', #1
u'الاستيمارات': u'الِاسْتِيمَارَاتِ', #2
u'الاستيمان': u'الِاسْتِيمَانَ', #2
u'الاستيمان': u'الِاسْتِيمَانِ', #4
u'الاستيمان': u'الِاسْتِيمَانُ', #5
u'الاستيناء': u'الاِسْتِينَاءِ', #3
u'الاستيناء': u'الِاسْتِينَاءُ', #30
u'الاستيناء': u'الِاسْتِينَاءَ', #5
u'الاستيناء': u'الِاسْتِينَاءِ', #56
u'الاستيناف': u'الِاسْتِينَافُ', #1
u'الاستيهاب': u'الِاسْتِيهَابَ', #1
u'الاستيهاب': u'الِاسْتِيهَابُ', #2
u'الاستيهاب': u'الِاسْتِيهَابِ', #4
u'الإسجال': u'الْإِسْجَالِ', #3
u'الإسجال': u'الْإِسْجَالُ', #4
u'الأسجال': u'الْأَسْجَالِ', #6
u'الإسجالات': u'الْإِسْجَالَاتِ', #1
u'الإسحات': u'الْإِسْحَاتَ', #2
u'الإسحاقي': u'الْإِسْحَاقِيُّ', #1
u'الإسحاقي': u'الْإِسْحَاقِيِّ', #1
u'الاسحم': u'الاسحم', #1
u'الأسدأباذى': u'الأَسَدَأَبَاذِىُّ', #1
u'الأسداباذى': u'الأَسَدَابَاذِىُّ', #4
u'الأسدى': u'الأَسْدِىُّ', #2
u'الأسدى': u'الأَسْدِىِّ', #3
u'الأسدى': u'الأَسَدِىِّ', #42
u'الأسدى': u'الأَسَدِىَّ', #7
u'الأسدى': u'الأَسَدِىُّ', #80
u'الأسراء': u'الْأُسَرَاء', #1
u'الأسراء': u'الْأُسَرَاءَ', #25
u'الأسراء': u'الْأُسَرَاءُ', #36
u'الأسراء': u'الْأُسَرَاءِ', #68
u'الإسرار': u'الإِسْرَارُ', #1
u'الإسرار': u'الْإِسْرَارُ', #111
u'الإسرار': u'الْإِسْرَار', #2
u'الإسرار': u'الْإِسْرَارَ', #31
u'الإسرار': u'الإِسْرَارِ', #4
u'الإسرار': u'الْإِسْرَارِ', #83
u'الإسرائليات': u'الإسرائليات', #9
u'الأسرب': u'الْأُسْرُبُّ', #4
u'الأسرشني': u'الْأُسْرُشَنِيِّ', #2
u'الأسروشني': u'الْأَسْرُوشَنِيُّ', #1
u'الأسروشني': u'الْأُسْرُوشُنِيِّ', #1
u'الأسروشني': u'الْأُسْرُوشِنِيُّ', #1
u'الأسروشني': u'الأسروشني', #2
u'الأسروشني': u'الْأُسْرُوشَنِيّ', #2
u'الأسروشني': u'الْأُسْرُوشَنِي', #3
u'الأسروشني': u'الْأُسْرُوشَنِيُّ', #51
u'الأسروشني': u'الْأُسْرُوشَنِيِّ', #58
u'الأسروشنية': u'الأسروشنية', #29
u'الأسروشنية': u'الْأُسْرُوشَنِيَّة', #4
u'الأسطحة': u'الْأَسْطِحَةِ', #6
u'الاسطلاء': u'الِاسْطِلَاءُ', #1
u'الأسطوان': u'الأُسْطُوَانَ', #1
u'الأسطوان': u'الأُسْطُوَانِ', #1
u'الأسطوان': u'الْأُسْطُوَانُ', #1
u'الأسطوان': u'الْأُسْطُوَانِ', #6
u'الاسطوخودس': u'الاسطوخودس', #2
u'الإسعاط': u'الْإِسْعَاطِ', #1
u'الأسعر': u'الْأَسْعَرُ', #4
u'الأسعردي': u'الْأَسْعَرْدِيُّ', #1
u'الأسفاطي،': u'الأسفَاطِيُّ،', #1
u'الأسفاطى': u'الأَسْفَاطِىَّ', #1
u'الأسفاطي،': u'الأسفاطي،', #2
u'الأسفاطي': u'الأَسْفَاطِيِّ', #2
u'الأسفاطي،': u'الأَسْفَاطِيِّ،', #3
u'الأسفاطى': u'الأَسْفَاطِىِّ', #3
u'الأسفاطي،': u'الأَسْفَاطِيُّ،', #5
u'الأسفاطي،': u'الأُسْفَاطِيُّ،', #7
u'الأسفاطى': u'الأَسْفَاطِىُّ', #87
u'الأسفاطي،ح': u'الأَسْفَاطِيُّ،ح', #1
u'الإسفاناخ': u'الْإِسْفَانَاخَ', #1
u'الأسفاه': u'الْأَسْفَاهَ', #1
u'الأسفاه': u'الْأَسْفَاهِ', #1
u'الإسفاه': u'الْإِسْفَاهِ', #2
u'الإسفرانية': u'الإسفرانية', #1
u'الإسفرائني': u'الإِسْفَرَائِنِيُّ', #1
u'الإسفرائنى': u'الإِسْفَرَائِنِىُّ', #42
u'الإسفرائنى': u'الإِسْفِرَائِنِىُّ', #6
u'الإسفرائيني،': u'الإِسْفَرَائِينِيُّ،', #1
u'الإسفرائينى': u'الإِسَفَرَائِينِىُّ', #1
u'الإسفرائينى': u'الإِسْفَرِائِينِىُّ', #1
u'الإسفرائينى': u'الإِسْفَرَائِينِىُّ', #126
u'الإسفرائينى': u'الإِسْفِرَائِينِىُّ', #18
u'الإسفرائينيان': u'الإِسْفَرَائِينِيَّانِ', #1
u'الإسفراينى': u'الإسفراينى', #1
u'الإسفراينيان': u'الإِسْفِرَاينِيَانِ', #1
u'الإسفراييني': u'الْإسْفَرايِينِيُّ', #1
u'الإسفراييني': u'الإِسْفِرايِينِي', #1
u'الإسفراييني،': u'الإِسْفَرَايِينِيُّ،', #1
u'الإسفراييني،': u'الإِسْفَرَايِينِيِّ،', #1
u'الإسفراييني': u'الْإِسْفَرَايِينِي', #1
u'الإسفرايينى': u'الإِسْفَرَايِينِىُّ', #1
u'الإسفرايينى': u'الإِسْفَرَايينِىُّ', #2
u'الإسفراييني': u'الْإسْفَرايِينِيّ', #245
u'الإسفراييني': u'الإسفراييني', #4
u'الإسفراييني': u'الْإسْفَرايِينِيِّ', #4
u'الإسفرايينية': u'الْإسْفرَايِينيَّة', #1
u'الأسفست': u'الأسفست', #1
u'الإسفست': u'الْإِسْفِسْتُ', #1
u'الإسفست': u'الْإِسْفِسْتِ', #1
u'الأسفع': u'الْأَسْفَعُ', #1
u'الأسفع': u'الْأَسْفَعِ', #1
u'الأسفع': u'الْأَسْفِعِ', #1
u'الإسفناخ': u'الْإِسْفِنَاخُ', #1
u'الإسفنارية': u'الإسفنارية', #1
u'الإسفنارية': u'الْإِسْفَنَارِيَّة', #1
u'الأسفه': u'الْأَسْفَهُ', #1
u'الإسفيدري': u'الْإِسْفِيدَرِيِّ', #1
u'الأسفيدناج': u'الأسفيدناج', #1
u'الإسقاء': u'الْإِسْقَاءُ', #1
u'الإسقاء': u'الْإِسْقَاءِ', #1
u'الإسقام': u'الْإِسْقَام', #1
u'الأسك': u'الأسك', #1
u'الإسكتان': u'الإسكتان', #1
u'الإسكتين': u'الْإِسْكَتَيْنِ', #1
u'الأسكتين': u'الْأَسْكَتَيْنِ', #3
u'الأسكر': u'الْأَسْكَرِ', #1
u'الأسكركة': u'الْأُسْكَرْكَةُ', #1
u'الأسكفة': u'الأسكفة', #3
u'الأسكفة': u'الْأُسْكُفَّةُ', #5
u'الإسكندر': u'الْإِسْكَنْدَرِ', #12
u'الإسكندر': u'الْإِسْكَنْدَرُ', #19
u'الإسكندر': u'الْإِسْكَنْدَرَ', #3
u'الإسكندراني': u'الإِسْكَنْدَرَانِي', #1
u'الإسكندراني': u'الإِسْكَنْدَرَانِيَّ', #1
u'الإسكندراني،': u'الإِسْكَنَدْرَانِيُّ،', #1
u'الإسكندراني،': u'الإِسْكَنْدَرَانِيِّ،', #1
u'الإسكندراني': u'الإِسْكَنْدَرَانِيُّ', #2
u'الإسكندراني،': u'الإِسْكَنْدَرَانِيُّ،', #20
u'الإسكندراني': u'الْإِسْكَنْدَرَانِيُّ', #3
u'الإسكندراني': u'الإسكندراني', #7
u'الإسكندرانى': u'الإِسْكَنْدَرَانِىُّ', #9
u'الإسكندراني،أنه': u'الإِسْكَنْدَرَانِيُّ،أَنَّهُ', #1
u'الأسكوبي': u'الْأُسْكُوبِيِّ', #1
u'الإسكوبي': u'الْإِسْكُوبِيُّ', #1
u'الأسكوبي': u'الْأُسْكُوبِيُّ', #2
u'الأسكي': u'الأسكي', #1
u'الأسلاس': u'الْأَسْلَاسِ', #2
u'الإسلال': u'الإِسلال', #1
u'إلاسلام،': u'إلاسلام،', #1
u'الأسلام': u'الأسلام', #2
u'الاسلام': u'الاسلام', #2
u'الإسلاما': u'الإسْلاَما', #1
u'الإسلامبول': u'الْإِسْلَامْبُولِ', #1
u'الإسلامقوله': u'الإِسْلامِقَوْلُهُ', #1
u'الإسلاموالوجه': u'الإِسْلامِوَالْوَجْهُ', #1
u'الإسلانبول': u'الْإِسْلَانْبُولِ', #1
u'الأسلت،': u'الأَسْلَتُ،', #1
u'الأسلت،': u'الأَسْلَتِ،', #1
u'الأسلت،': u'الْأَسْلَتِ،', #1
u'الأسلت': u'الأَسْلَتِ', #3
u'الأسلت': u'الْأَسْلَتِ', #34
u'الأسلع': u'الأَسْلَعُ', #1
u'الأسلع': u'الأَسْلَعِ', #1
u'الأسلع،': u'الأَسْلَعِ،', #1
u'الأسلع': u'الْأَسْلَعِ', #6
u'الأسلمي،': u'الأَسْلَميّ،', #1
u'الأسلمي': u'الأَسْلَمِيّ', #1
u'الأسلمي': u'الْأَسْلَمِي', #1
u'الأسلمي،': u'الْأَسْلَمِيَّ،', #1
u'الأسلمي،': u'الْأَسْلَمِيِّ،', #1
u'الأسلمى': u'الأَسْلَمِى', #1
u'الأسلمي': u'الْأَسْلَمِيِّ', #149
u'الأسلمي': u'الأسلمي', #16
u'الأسلمي': u'الأَسْلَمِيُّ', #18
u'الأسلمى': u'الأَسْلَمِىَّ', #18
u'الأسلمي،': u'الأسلميّ،', #2
u'الأسلمى': u'الأَسْلَمِىُّ', #25
u'الأسلمي،': u'الأَسْلَمِيُّ،', #29
u'الأسلمي،': u'الأَسْلَمِيِّ،', #29
u'الأسلمي،': u'الأسلمي،', #3
u'الأسلمي': u'الأَسْلَمِيِّ', #32
u'الأسلمي': u'الْأَسْلَمِيَّ', #33
u'الأسلمي،': u'الْأَسْلَمِيُّ،', #4
u'الأسلمى': u'الأَسْلَمِىِّ', #49
u'الأسلمي': u'الأَسْلَمِيَّ', #6
u'الأسلمي،': u'الأَسْلَمِيَّ،', #7
u'الأسلمي': u'الْأَسْلَمِيّ', #72
u'الأسلمي': u'الْأَسْلَمِيُّ', #72
u'الأسلميان': u'الْأَسْلَمِيَّانِ', #1
u'الأسلمية': u'الأَسْلَمِيَّةُ', #1
u'الأسلمية': u'الْأَسْلَمِيَّةَ', #11
u'الأسلمية': u'الْأَسْلَمِيَّةُ', #11
u'الأسلمية': u'الْأَسْلَمِيَّةِ', #13
u'الأسلمية': u'الْأَسْلَمِيّةُ', #2
u'الأسلمية': u'الْأَسْلَمِيّةِ', #2
u'الأسلمية': u'الأسلمية', #3
u'الأسلمية': u'الْأَسْلَمِيّة', #4
u'الأسلمية': u'الأَسْلَمِيَّةِ', #7
u'الأسلمية': u'الأَسْلَمِيَّةَ', #8
u'الأسلميون': u'الْأَسْلَمِيُّونَ', #1
u'الأسلميين،': u'الأَسْلَميِّينَ،', #1
u'الأسلميين': u'الْأَسْلَمِيّينَ', #1
u'الأسلميين': u'الأَسْلَمِيِّينَ', #2
u'الأسلميين': u'الْأَسْلَمِيِّينَ', #2
u'الإسماعيلى': u'الإَسْمَاعِيلِىُّ', #1
u'الإسماعيلى': u'الإِسْمَاعِيلِىِّ', #2
u'الإسماعيلى': u'الإِسْمَاعِيلِىُّ', #485
u'الأسمان': u'الْأَسْمَانِ', #1
u'الإسمان': u'الْإِسْمَانِ', #1
u'الأسمخة': u'الأسمخة', #1
u'الأسمرة': u'الْأَسْمِرَةِ', #1
u'الأسمطة': u'الْأَسْمِطَةِ', #3
u'الأسمعة': u'الْأَسْمِعَةَ', #1
u'الأسمعة': u'الْأَسْمِعَةِ', #10
u'الأسملي': u'الأَسْمَلِيُّ', #1
u'الأسملي،': u'الأَسْمَلِيُّ،', #1
u'الأسمية': u'الْأَسْمِيَةِ', #4
u'الاسناد': u'الاسناد', #1
u'الأسنائي': u'الْأَسْنَائِيُّ', #1
u'الإسنائي': u'الْإِسْنَائِيُّ', #1
u'الأسنه': u'الْأَسِنَّهِ', #1
u'الأسنه': u'الْأَسِنَّهْ', #1
u'الإسنوي': u'الْإِسْنَوِيَّ', #114
u'الإسنوي': u'الْإِسْنَوِيّ', #19
u'الإسنوي': u'الْإِسْنَوِيُّ', #4496
u'الإسنوي': u'الْإِسْنَوِيِّ', #982
u'الأسني': u'الْأَسْنَيْ', #2
u'الأسنى': u'الْأَسْنَى', #486
u'الأسو': u'الْأَسْوِ', #1
u'الإسواران': u'الْإِسْوَارَانِ', #1
u'الأسوارى': u'الأَسْوَارِىِّ', #3
u'الأسوارى': u'الأُسْوَارِىِّ', #3
u'الأسواف': u'الأَسْوَافُ', #1
u'الأسواف': u'الأَسْوَافِ', #1
u'الأسواف،': u'الأَسْوَافَ،', #1
u'الأسواف': u'الْأَسْوَافَ', #1
u'الأسواف': u'الْأَسْوَافِ', #1
u'الأسواف': u'الأَسْوَافَ', #2
u'الأسواني': u'الأَسْوَانِيُّ', #1
u'الأسواني،': u'الأَسْوَانِيُّ،', #1
u'الأسواني': u'الْأُسْوَانِيُّ', #2
u'الأسوانية': u'الْأُسْوَانِيَّةِ', #1
u'الأسودأنه': u'الأَسْوَدِأَنَّهُ', #1
u'الأسودة': u'الأسودة', #1
u'الأسودة': u'الْأَسْوِدَةَ', #1
u'الأسودة': u'الْأَسْوِدَةِ', #1
u'الأسودة': u'الأَسْوِدَةُ', #2
u'الأسودة': u'الْأَسْوِدَةُ', #3
u'الأسودعن': u'الْأَسْوَدِعَنْ', #1
u'الأسوقة': u'الْأَسْوِقَةُ', #2
u'الأسوكة': u'الْأَسْوِكَةُ', #1
u'الأسولة': u'الْأُسُولَةِ', #1
u'الأسيال': u'الأسيال', #1
u'الأسيال': u'الْأَسْيَالِ', #13
u'الأسيدي': u'الأُسَيْدِيُّ', #1
u'الأسيدي،': u'الأُسَيِّدِيُّ،', #1
u'الأسيدي': u'الْأَسِيدِيّ', #1
u'الأسيدي': u'الْأُسَيْدِيّ', #1
u'الأسيدى': u'الأسيدى', #1
u'الأسيدى': u'الأُسَيِّدِىُّ', #1
u'الأسيدي': u'الأُسَيْدِيِّ', #2
u'الأسيدي': u'الْأُسَيِّدِيِّ', #2
u'الأسيدي': u'الْأُسَيْدِيِّ', #3
u'الأسيدى': u'الأُسَيِّدِىِّ', #3
u'الأسيف': u'الأسيف', #1
u'الأسيفع': u'الْأُسَيْفِعُ', #1
u'الأسيفع': u'الْأُسَيْفِعَ', #10
u'الأسيفع': u'الأُسَيْفِعَ', #2
u'الأسيفع': u'الْأُسَيْفِعِ', #3
u'الأسيلم': u'الْأُسَيْلِمُ', #2
u'الأشاء': u'الأَشَّاءُ', #1
u'الأشاء': u'الْأَشَاءُ', #1
u'الإشاءة': u'الْإِشَاءَةُ', #1
u'الأشاءتين،': u'الأَشَاءَتَيْنِ،', #1
u'الأشاءتين': u'الْأَشَاءَتَيْنِ', #2
u'الإشابة': u'الْإِشَابَةِ', #1
u'الأشاتين': u'الأَشَاتَيْنِ', #2
u'الإشاره': u'الْإِشَارَهْ', #1
u'الأشاعر': u'الْأَشَاعِرِ', #1
u'الأشافي': u'الْأَشَافِي', #2
u'الإشالة': u'الْإِشَالَة', #1
u'الإشالة': u'الْإِشَالَةِ', #2
u'الأشأم': u'الْأَشْأَمَ', #1
u'الأشائم': u'الْأَشَائِمُ', #1
u'الأشائم': u'الْأَشَائِمِ', #2
u'الأشباب': u'الْأَشْبَابِ', #1
u'الأشبان': u'الْأَشْبَانِ', #1
u'الأشبة': u'الْأَشْبَةُ', #1
u'الأشبل': u'الْأَشْبُلِ', #2
u'الأشبهية': u'الْأَشْبَهِيَّةِ', #1
u'الأشبولي': u'الْأَشْبُولِيِّ', #2
u'الأشبيطي': u'الْأَشْبِيطِيُّ', #2
u'الأشبيطي': u'الْأَشْبِيطِيِّ', #2
u'الأشتر': u'الأشترَ', #1
u'الأشتر': u'الأشترُ', #1
u'الأشتر': u'الأَشْتَرَ', #1
u'الأشتر': u'الأَشْتَرُ', #1
u'الأشتر،': u'الأَشْتَرَ،', #1
u'الأشتر': u'الْأَشْتَرَ', #1
u'الأشتر،': u'الْأَشْتَرِ،', #10
u'الأشتر': u'الْأَشْتَرُ', #11
u'الأشتر': u'الْأَشْتَرِ', #23
u'الأشتر،': u'الأشتر،', #3
u'الأشتر،': u'الأَشْتَرِ،', #4
u'الأشتر': u'الأشتر', #9
u'الأشتر': u'الأَشْتَرِ', #9
u'الإشتراط': u'الإِشْتِرَاطَ', #1
u'الإشتراط': u'الإِشْتِرَاطِ', #1
u'الاشتمالة': u'الِاشْتِمَالَةُ', #1
u'الإشتيخنى': u'الإِشْتَيْخِنِى', #1
u'الأشج،': u'الأَشَجِ،', #1
u'الأشج،': u'الأَشَجٌّ،', #1
u'الأشج،،': u'الأَشَجُّ،،', #1
u'الأشج': u'الْأَشَجَّ', #1
u'الأشج': u'الأشج', #10
u'الأشج،': u'الأشج،', #10
u'الأشج': u'الأَشَجِّ', #117
u'الأشج': u'الْأَشَجِّ', #132
u'الأشج،': u'الْأَشَجُّ،', #15
u'الأشج': u'الأَشَجَّ', #2
u'الأشج': u'الأَشَجُّ', #228
u'الأشج': u'الْأَشَجُّ', #24
u'الأشج': u'الْأَشَجّ', #3
u'الأشج،': u'الأَشَجِّ،', #78
u'الأشج،': u'الأَشَجُّ،', #934
u'الأشجاب': u'الأشجاب', #1
u'الإشجار': u'الْإِشْجَار', #1
u'الإشجار': u'الْإِشْجَارِ', #1
u'الأشجعي،': u'الأشجعيّ،', #1
u'الأشجعي': u'الأَشْجَعِيَّ', #1
u'الأشجعي': u'الْأَشْجَعِيُ', #1
u'الأشجعي': u'الْأَشْجَعِيََََََََُّ', #1
u'الأشجعي،': u'الْأَشْجَعِيُّ،', #1
u'الأشجعي': u'الأشجعي', #11
u'الأشجعي': u'الْأَشْجَعِيَّ', #12
u'الأشجعي،': u'الأَشْجَعِيَّ،', #2
u'الأشجعي،': u'الْأَشْجَعِيَّ،', #2
u'الأشجعي': u'الأَشْجَعِيِّ', #22
u'الأشجعي': u'الأَشْجَعِيُّ', #26
u'الأشجعي': u'الْأَشْجَعِيّ', #33
u'الأشجعي،': u'الأَشْجَعِيِّ،', #34
u'الأشجعي،': u'الأَشْجَعِيُّ،', #38
u'الأشجعي،': u'الأشجعي،', #5
u'الأشجعى': u'الأَشْجَعِىَّ', #5
u'الأشجعى': u'الأَشْجَعِىِّ', #62
u'الأشجعي': u'الْأَشْجَعِيُّ', #72
u'الأشجعى': u'الأَشْجَعِىُّ', #78
u'الأشجعي': u'الْأَشْجَعِيِّ', #94
u'الأشجعية': u'الأَشْجَعِيَّةُ', #1
u'الأشجعية': u'الْأَشْجَعِيَّةَ', #1
u'الأشجعية': u'الْأَشْجَعِيَّةُ', #1
u'الأشجعية': u'الْأَشْجَعِيِّةِ', #1
u'الأشجعية': u'الأشجعية', #2
u'الأشجعية': u'الأَشْجَعِيَّةِ', #3
u'الأشجعية': u'الْأَشْجَعِيَّةِ', #5
u'الأشجعيين': u'الْأَشْجَعِيِّينَ', #1
u'الأشجعيين': u'الْأَشْجَعِيّينَ', #1
u'الأشجعيين': u'الْأَشْجَعِيَّيْنِ', #1
u'الإشخاص': u'الْإِشْخَاصُ', #1
u'الإشخاص': u'الْإِشْخَاصِ', #4
u'الأشخر': u'الْأَشْخَرُ', #1
u'الأشر': u'الأَشَرُ', #1
u'الأشر،': u'الأَشَرُ،', #1
u'الأشر': u'الْأَشَرَّ', #1
u'الأشر': u'الْأَشَرُّ', #1
u'الأشر': u'الْأَشِرُ', #1
u'الأشر': u'الأشر', #2
u'الأشر': u'الْأَشَرِّ', #2
u'الأشر': u'الْأَشَرُ', #3
u'الأشر': u'الْأَشَرِ', #4
u'الأشراطا': u'الْأَشْرَاطَا', #1
u'الإشراقيون': u'الْإِشْرَاقِيُّونَ', #3
u'الإشراكا': u'الْإِشْرَاكَا', #2
u'الأشربات': u'الْأَشْرِبَاتُ', #3
u'الأشرة': u'الْأَشِرَةَ', #1
u'الأشرفقال': u'الأَشْرَفِقَالَ', #1
u'الأشرفي': u'الْأَشْرَفِيَّ', #10
u'الأشرفي': u'الْأَشْرَفِيِّ', #13
u'الأشرفي': u'الْأَشْرَفِيُّ', #6
u'الأشرفية': u'الأشرفية', #1
u'الأشرفية': u'الْأَشْرَفِيَّةُ', #1
u'الأشرفية': u'الْأَشْرَفِيِّةِ', #3
u'الأشرفية': u'الْأَشْرَفِيَّةِ', #33
u'الأشرفية': u'الْأَشْرَفِيَّةَ', #4
u'الأشرفيين': u'الْأَشْرَفِيَّيْنِ', #1
u'الأشرين': u'الأَشِرِينَ', #1
u'الأشطاط': u'الأَشْطَاطِ', #1
u'الأشطاط': u'الْأَشْطَاطِ', #6
u'الأشظاظ': u'الْأَشْظَاظُ', #1
u'الأشعثي،': u'الأشعثي،', #1
u'الأشعثي': u'الأَشْعَثِيُّ', #1
u'الأشعثي،': u'الأَشْعَثَيُّ،', #1
u'الأشعثي': u'الْأَشْعَثِيُّ', #3
u'الأشعثى': u'الأَشْعَثِىِّ', #3
u'الأشعثى': u'الأَشْعَثِىُّ', #31
u'الأشعثي،': u'الأَشْعَثِيُّ،', #7
u'الأشعرون': u'الْأَشْعَرُونَ', #5
u'الأشعرى': u'الأَشْعَرِىِّ', #126
u'الأشعرى': u'الأَشْعَرِىَّ', #23
u'الأشعرى': u'الأَشْعَرِىُّ', #63
u'الأشعريأنتم': u'الأَشْعَرِيُّأَنْتُمُ', #1
u'الأشعله': u'الأَشْعلَّهِ', #1
u'الأشغاني': u'الأشغاني', #1
u'الأشغانية': u'الْأَشْغَانِيّةُ', #1
u'الأشغانيين': u'الأشغانيين', #2
u'الإشفاع': u'الْإِشْفَاعَ', #1
u'الإشفاع': u'الْإِشْفَاعُ', #13
u'الإشفاع': u'الْإِشْفَاعِ', #9
u'الأشفق': u'الْأَشْفَقَ', #1
u'الأشفق': u'الْأَشْفَقِ', #2
u'الأشفق': u'الْأَشْفَقُ', #4
u'الأشفى': u'الْأَشْفَى', #2
u'الأشفية': u'الْأَشْفِيَةِ', #1
u'الأشقاص': u'الْأَشْقَاص', #1
u'الأشقاص': u'الْأَشْقَاصُ', #2
u'الإشقاص': u'الْإِشْقَاصُ', #2
u'الأشقاص': u'الْأَشْقَاصِ', #23
u'الأشقاص': u'الْأَشْقَاصَ', #7
u'الإشقالة': u'الْإِشْقَالَةُ', #1
u'الإشقالة': u'الْإِشْقَالَةِ', #1
u'الأشقالية': u'الْأَشْقَالِيَةُ', #1
u'الأشقالية': u'الْأَشْقَالِيَةِ', #1
u'الأشقالية': u'الأشقالية', #3
u'الأشكري': u'الْأَشْكُرِيِّ', #1
u'الأشكل': u'الأشكل', #1
u'الإشلاء': u'الْإِشْلَاءِ', #1
u'الأشلع': u'الْأَشْلَعِ', #1
u'الإشمام': u'الْإِشْمَامِ', #2
u'الأشمذ': u'الْأَشْمَذِ', #1
u'الأشمذان': u'الْأَشْمَذَانِ', #1
u'الأشمط': u'الْأَشْمَطَ', #1
u'الاشمط': u'الاشمط', #1
u'الأشموني': u'الْأُشْمُونِيِّ', #13
u'الأشموني': u'الْأُشْمُونِيَّ', #3
u'الأشموني': u'الْأُشْمُونِيُّ', #50
u'الأشنان': u'الْأُشْنَانُ', #19
u'الأشنان': u'الْأُشْنَانِ', #19
u'الأشنان': u'الْأُشْنَانَ', #8
u'الأشنانى': u'الأَشْنَانِىُّ', #2
u'الأشنانى': u'الأُشْنَانِىُّ', #9
u'الأشنب': u'الْأَشْنَبِ', #1
u'الأشنب': u'الْأَشْنَبُ', #2
u'الأشنيهية': u'الْأَشْنِيهِيَّةِ', #1
u'الإشهادوالوجه': u'الإِشْهَادُوَالْوَجْهُ', #1
u'الأشهرية': u'الْأَشْهَرِيَّةِ', #1
u'الأشهلي': u'الأَشْهَلِيَّ', #1
u'الأشهلي': u'الَأَشْهَلِيِّ', #1
u'الأشهلي': u'الْأَشْهَلِيّ', #17
u'الأشهلي،': u'الأشهلي،', #2
u'الأشهلي،': u'الْأَشْهَلِيُّ،', #3
u'الأشهلى': u'الأَشْهَلِىِّ', #3
u'الأشهلي': u'الأشهليّ', #4
u'الأشهلي': u'الأَشْهَلِيِّ', #4
u'الأشهلى': u'الأَشْهَلِىُّ', #4
u'الأشهلي': u'الأشهلي', #5
u'الأشهلي': u'الْأَشْهَلِيِّ', #5
u'الأشهلي': u'الأَشْهَلِيُّ', #6
u'الأشهلي': u'الْأَشْهَلِيُّ', #9
u'الأشهلية': u'الْأَشْهَلِيّة', #1
u'الأشهلية': u'الْأَشْهَلِيَّةُ', #1
u'الأشهلية': u'الْأَشْهَلِيّةُ', #3
u'الأشهليون،': u'الْأَشْهَلِيُّونَ،', #1
u'الإشواء': u'الْإِشْوَاءِ', #1
u'الأشوع،': u'الأَشْوَعِ،', #1
u'الأشيم': u'الأَشْيَمِ', #1
u'الأشيمط': u'الْأُشَيْمِطِ', #1
u'ألاص': u'أَلَاصَ', #1
u'الأصابعا': u'الْأَصَابُعَا', #1
u'الإصاد': u'الْإِصَادِ', #1
u'الأصاغرا': u'الْأَصَاغِرَا', #1
u'الأصافر': u'الْأَصَافِرِ', #1
u'الأصافر': u'الْأَصَافِرُ', #4
u'الأصاهر': u'الْأَصَاهِرُ', #2
u'الأصب': u'الْأَصَبَّ', #1
u'الإصباغ': u'الْإِصْبَاغُ', #1
u'الأصباني': u'الْأَصْبَانِيُّ', #1
u'الأصبح': u'الْأَصْبَحُ', #1
u'الأصبح': u'الْأَصْبَحَ', #2
u'الأصبح': u'الْأَصْبَحِ', #2
u'الأصبحي،': u'الأَصْبَحِيَّ،', #1
u'الأصبحي،': u'الْأَصْبَحِيُّ،', #1
u'الأصبحي،': u'الْأَصْبَحِيِّ،', #1
u'الأصبحى': u'الأَصْبَحِىِّ', #1
u'الأصبحي،': u'الأَصْبَحِيِّ،', #2
u'الأصبحى': u'الأَصْبَحِىُّ', #3
u'الأصبحي': u'الأَصْبَحِيُّ', #4
u'الأصبحي': u'الأَصْبَحِيِّ', #4
u'الأصبحي': u'الْأَصْبَحِيِّ', #42
u'الأصبحي': u'الْأَصْبَحِيّ', #5
u'الأصبحي': u'الْأَصْبَحِيُّ', #52
u'الأصبحي': u'الْأَصْبَحِيَّ', #6
u'الإصبعان': u'الْإِصْبَعَانِ', #1
u'الإصبعين،': u'الإِصْبَعَيْنِ،', #1
u'الإصبعين': u'الْإِصْبَعَيْنِ', #12
u'الإصبعين': u'الإصبعين', #2
u'الإصبعين': u'الإِصْبَعَيْنِ', #3
u'الأصبهاني،': u'الأصبهانيّ،', #1
u'الأصبهاني،': u'الأَصْبهَانِيِّ،', #1
u'الأصبهاني': u'الأَصْبَهَانِيَّ', #1
u'الأصبهاني،': u'الأَصَبْهَانِيُّ،', #1
u'الأصبهاني': u'الْأَصْبَهَانِيَّ', #1
u'الأصبهاني': u'الْأَصْبِهَانِيُ', #1
u'الأصبهانى': u'الأَصْبِهَانِىُّ', #1
u'الأصبهانى': u'الأَصْبِهَانِىِّ', #1
u'الاصبهانى': u'الاصْبَهَانِى', #1
u'الأصبهاني': u'الأَصْبَهَانِيِّ', #10
u'الأصبهاني': u'الأَصْبَهَانِيُّ', #12
u'الأصبهاني': u'الْأَصْبَهَانِيّ', #14
u'الأصبهاني': u'الْأَصْبَهَانِي', #2
u'الأصبهاني،': u'الْأَصْبَهَانِيُّ،', #2
u'الأصبهاني،': u'الْأَصْبَهَانِيِّ،', #2
u'الأصبهانى': u'الأَصْبَهَانِى', #2
u'الأصبهانى': u'الأَصْبَهَانِىَّ', #3
u'الأصبهانى': u'الأَصْبَهَانِىِّ', #31
u'الأصبهاني': u'الأصبهاني', #4
u'الأصبهاني،': u'الأَصْبَهَانِيِّ،', #54
u'الأصبهاني': u'الْأَصْبَهَانِيُّ', #67
u'الأصبهاني،': u'الأصبهاني،', #7
u'الأصبهاني،': u'الأَصْبَهَانِيُّ،', #79
u'الأصبهاني': u'الْأَصْبَهَانِيِّ', #81
u'الأصبهانى': u'الأَصْبَهَانِىُّ', #842
u'الأصبهبدية': u'الأصْبَهْبدِيَّةُ', #1
u'الأصبهبذ': u'الأَصْبَهْبَذُ', #2
u'الأصبوع': u'الْأُصْبُوعُ', #1
u'الأصحية': u'الْأَصَحِّيَّةَ', #2
u'الأصحية': u'الْأَصَحِّيَّةُ', #3
u'الأصحين': u'الْأَصَحَّيْنِ', #1
u'الأصدف': u'الْأَصْدَفِ', #2
u'الأصدقة': u'الْأَصْدِقَةُ', #1
u'الأصدقة': u'الْأَصْدِقَةَ', #2
u'الأصدقة': u'الْأَصْدِقَةِ', #4
u'الإصراع': u'الْإِصْرَاعَ', #1
u'الإصرافات': u'الْإِصْرَافَاتِ', #3
u'الإصرافة': u'الْإِصَْرافَةِ', #1
u'الإصرافة': u'الْإِصْرَافَةُ', #2
u'الإصرافة': u'الْإِصْرَافَةَ', #3
u'الإصرافة': u'الْإِصْرَافَةِ', #6
u'الأصرام': u'الْأَصْرَامُ', #1
u'الأصرام': u'الْأَصْرَامِ', #3
u'الاصطباح': u'الِاصْطِبَاحُ', #1
u'الاصطبار': u'الِاصْطِبَارِ', #3
u'الأصطبة': u'الْأُصْطُبَّةِ', #2
u'الإصطخري،': u'الإصطخري،', #1
u'الإصطخري': u'الْإِصْطَخْرِيُ', #1
u'الإصطخري': u'الْإِصْطَخْرِيِ', #1
u'الإصطخري': u'الْإِصْطَخْرِيُّ', #108
u'الإصطخري،': u'الإِصْطَخْرِيُّ،', #3
u'الإصطخري': u'الْإِصْطَخْرِي', #3
u'الإصطخري': u'الْإِصْطَخْرِيَّ', #3
u'الإصطخرى': u'الإِصْطَخْرِىُّ', #3
u'الإصطخري': u'الْإِصْطَخْرِيِّ', #46
u'الإصطخودج': u'الإصطخودج', #1
u'الاصطراف': u'الِاصْطِرَافِ', #2
u'الاصطلام': u'الِاصْطِلَامُ', #1
u'الاصطلام': u'الِاصْطِلَامِ', #24
u'الاصطلام': u'الِاصْطِلَامَ', #5
u'الآصع': u'الآصع', #1
u'الآصع': u'الْآصُعُ', #2
u'الآصع': u'الْآصُعَ', #3
u'الآصع': u'الْآصُعِ', #5
u'الأصعير': u'الأصعير', #1
u'الإصغاءإليه': u'الْإِصْغَاءِإِلَيْهِ', #1
u'الأصفاطي': u'الْأَصْفَاطِيِّ', #1
u'الإصفرار': u'الْإِصْفِرَارِ', #1
u'الأصفهانى': u'الأَصْفِهَانِىُّ', #1
u'الأصفهانى': u'الأَصْفَهَانِىُّ', #15
u'الأصفوان': u'الْأَصْفَوَانُ', #1
u'الأصفوني': u'الْأَصْفُونِيِّ', #11
u'الأصفوني': u'الْأَصْفُونِيَّ', #2
u'الأصفوني': u'الْأَصْفُونِيُّ', #30
u'الأصفى': u'الْأَصْفَى', #1
u'الأصك': u'الْأَصَكِّ', #2
u'الأصلاء': u'الْأُصَلَاءِ', #1
u'الأصلحية': u'الْأَصْلَحِيَّةُ', #3
u'الأصلحية': u'الْأَصْلَحِيَّةِ', #8
u'الأصلوالوجه': u'الأَصْلِوَالْوَجْهُ', #1
u'الإصماء': u'الإِصْمَاءُ', #1
u'الإصماء': u'الْإِصْمَاءِ', #1
u'الإصماء': u'الْإِصْمَاءُ', #6
u'الأصمع': u'الأَصْمَعَ', #1
u'الأصمعي،': u'الأصمعي،', #1
u'الأصمعى': u'الأَصْمَعِىَّ', #1
u'الأصمعي': u'الْأَصْمَعِيَّ', #12
u'الأصمعي': u'الأَصْمَعِيُّ', #14
u'الأصمعي': u'الْأَصْمَعِيُّ', #182
u'الأصمعي': u'الأصمعيّ', #2
u'الأصمعي': u'الأَصْمَعِيَّ', #2
u'الأصمعى': u'الأَصْمَعِىِّ', #2
u'الأصمعى': u'الأَصْمَعِىُّ', #23
u'الأصمعي': u'الأصمعي', #3
u'الأصمعي،': u'الأَصْمَعِيِّ،', #3
u'الأصمعي': u'الْأَصْمَعِيّ', #35
u'الأصمعي': u'الْأَصْمَعِيِّ', #60
u'الأصمعي،': u'الأَصْمَعِيُّ،', #8
u'الأصنعة': u'الأصنعة', #1
u'الأصهبانى': u'الأَصْهَبَانِىُّ', #1
u'ألاصوا': u'أَلاصُوا', #1
u'الأصواء': u'الْأَصْوَاءِ', #1
u'الأصوبية': u'الْأَصْوَبِيَّةَ', #1
u'الأصوبية': u'الْأَصْوَبِيَّةِ', #2
u'الأصوع': u'الْأَصْوُعَ', #1
u'الأصوع': u'الْأَصْوُعِ', #1
u'الأصولمنظومة': u'الأصولمَنْظُومَةُ', #1
u'الأصولين': u'الْأُصُولِينَ', #1
u'الأصون': u'الْأَصْوَنُ', #1
u'الأصوني': u'الْأَصُونِيُّ', #1
u'الأصيد': u'الأَصْيَد', #1
u'الأصيد': u'الْأَصِيدِ', #1
u'الأصيد': u'الأصْيَد', #2
u'الأصيد': u'الْأَصْيَدُ', #2
u'الأصيد': u'الْأَصْيَدِ', #2
u'الأصيرم': u'الْأُصَيْرِمَ', #1
u'الأصيرم': u'الْأُصَيْرِمِ', #3
u'الأصيلع': u'الأصَيْلَعَ', #1
u'الأصيلع': u'الأُصَيْلِعِ', #1
u'الأصيلع': u'الْأُصَيْلِع', #1
u'الأصيلع': u'الأُصَيْلِعَ', #2
u'الأصيلع': u'الْأُصَيْلِعَ', #2
u'الأصيهب': u'الْأُصَيْهِبُ', #2
u'الأض': u'الْأَضّ', #1
u'الأضاة': u'الأضاة', #1
u'الأضاة': u'الْأَضَاةُ', #1
u'الأضاة': u'الْأَضَاة', #2
u'الأضاة': u'الْأَضَاةِ', #2
u'الأضاحى': u'الأَضَاحِى', #1
u'الأضاحى': u'الأَضَاحِىُّ', #1
u'الأضاحى؟': u'الأَضَاحِىِّ؟', #1
u'الأضاحى؟': u'الأَضَاحِىُّ؟', #2
u'الأضاحى': u'الأَضَاحِىِّ', #23
u'الأضاحى': u'الأضاحى', #3
u'الآضار': u'الْآضَارِ', #1
u'الإضاقة': u'الْإِضَاقَةِ', #8
u'الأضالع': u'الْأَضَالِعُ', #3
u'الإضبارات': u'الْإِضْبَارَاتِ', #1
u'الأضبع': u'الْأَضْبُعُ', #1
u'الأضحاة': u'الْأَضْحَاةُ', #1
u'الأضحي': u'الأضحي', #1
u'الإضحيان': u'الإضحيان', #1
u'الأضحيه': u'الْأُضْحِيَّهْ', #1
u'الإضداد': u'الْإِضْدَاد', #1
u'الأضر': u'الْأَضَرّ', #1
u'الأضر': u'الْأَضَرْ', #1
u'الأضر': u'الْأَضَرِّ', #16
u'الأضر': u'الْأَضَرَّ', #4
u'الأضر': u'الْأَضَرُّ', #8
u'الأضرب': u'الْأَضْرَبِ', #1
u'الأضرب': u'الْأَضْرُبِ', #7
u'الأضرس': u'الأضرس', #1
u'الاضطباع': u'الِاضْطِبَاع', #1
u'الاضطباع': u'الاِضْطِبَاعِ', #1
u'الاضطباع': u'الِاضْطِبَاعَ', #15
u'الاضطباع': u'الِاضْطِبَاعُ', #17
u'الاضطباع': u'الِاضْطِبَاعِ', #24
u'الإضطجاع': u'الإِضْطِجَاعِ', #1
u'الاضطراد': u'الِاضْطِرَادُ', #1
u'الأضعف': u'الْأَضْعَفَ', #19
u'الأضعف': u'الْأَضْعَف', #2
u'الأضعف': u'الْأَضْعَفُ', #40
u'الأضعف': u'الْأَضْعَفِ', #50
u'الاضلاع': u'الْاَضْلَاع', #1
u'الأضلية': u'الْأَضَلِّيَّةِ', #1
u'الأضمن': u'الْأَضْمَنُ', #1
u'الأضوج': u'الْأَضْوَجُ', #1
u'الأضوج': u'الْأَضْوَجِ', #1
u'الأضوج': u'الْأَضْوُجُ', #1
u'الأضوج': u'الْأَضْوُجْ', #2
u'الأضوج': u'الْأَضْوُجِ', #3
u'الأضياح': u'الْأَضْيَاحَ', #2
u'الأضيقة': u'الْأَضْيَقَةِ', #1
u'الأضيقية': u'الْأَضْيَقِيَّةِ', #1
u'الإضينا': u'الْإِضِينَا', #1
u'الأطالسة': u'الْأَطَالِسَةِ', #1
u'الآطام': u'الآطَامِ', #1
u'الآطام': u'الْآطَامَ', #1
u'الآطام': u'الْآطَامُ', #1
u'الآطام،': u'الْآطَامِ،', #1
u'الآطام': u'الْآطَامِ', #18
u'الاطباء': u'الِاطِّبَاءُ', #1
u'الأطحلة': u'الْأَطْحِلَةِ', #1
u'الأطرابلسي': u'الأطرابلسي', #1
u'الأطرابلسي،': u'الأَطْرَابُلُسِيُّ،', #1
u'الأطرابلسي،': u'الأَطْرَابُلْسِيُّ،', #1
u'الأطرابلسى': u'الأَطْرَابُلُسِىُّ', #1
u'الاطراح': u'الِاطِّرَاحِ', #1
u'الإطراد': u'الْإِطْرَادِ', #2
u'الإطراد': u'الْإِطْرَادُ', #3
u'الأطرف': u'الأَطْرَفُ', #1
u'الأطرف': u'الأَطْرَفِ', #1
u'الأطرف': u'الْأَطْرَفُ', #1
u'الأطرف': u'الْأَطْرَفِ', #2
u'الأطروش': u'الأُطْرُوشُ', #1
u'الأطروش': u'الْأُطْرُوشِ', #1
u'الأطروش': u'الْأُطْرُوشَ', #2
u'الأطروش': u'الْأُطْرُوشُ', #4
u'الإطرية': u'الْإِطْرِيَةِ', #1
u'الاطعام': u'الِاطِّعَامَ', #1
u'الاطعام': u'الِاطِّعَامُ', #1
u'الاطعام': u'الِاطِّعَامِ', #3
u'الأطعمه': u'الْأَطْعِمَهْ', #2
u'الأطغياء': u'الْأَطْغِيَاءِ', #1
u'الأطفالا': u'الْأَطْفَالَا', #1
u'الإطفيحي': u'الإطفيحي', #1
u'الإطفيحي': u'الْإِطْفِيحِيُّ', #25
u'الإطفيحي': u'الْإِطْفِيحِيِّ', #32
u'الإطل': u'الْإِطِلْ', #2
u'الاطلاء': u'الِاطِّلَاءِ', #2
u'الإطماع': u'الْإِطْمَاعُ', #1
u'الأطمان': u'الْأُطُمَانِ', #1
u'الإطنابة،': u'الإِطْنَابَةَ،', #1
u'الإطنابة': u'الْإِطَنَابَةِ', #1
u'الإطهار': u'الْإِطْهَارَ', #1
u'الإطهار': u'الْإِطْهَارِ', #1
u'الأطهر': u'الْأَطْهَر', #1
u'الأطهر': u'الْأَطْهَرِ', #1
u'الأطهرين': u'الْأَطْهَرِينَ', #1
u'الأطواء': u'الْأَطْوَاءُ', #1
u'الأطوع': u'الْأَطْوَعِ', #3
u'الأطوفة': u'الْأَطْوِفَةُ', #1
u'الأطوفة': u'الْأَطْوِفَةِ', #17
u'الأطوي': u'الْأَطْوِيُّ', #1
u'الأطيان': u'الْأَطْيَانِ', #3
u'الأطيبية': u'الْأَطْيَبِيَّةُ', #1
u'الأطيبية': u'الْأَطْيَبِيَّةِ', #6
u'الأطيط': u'الأطيط', #1
u'الأطيط': u'الْأَطِيط', #1
u'الآظار': u'الْآظَارِ', #1
u'الأظآر': u'الْأَظْآرِ', #11
u'الاظافر،': u'الاظافر،', #1
u'الأظرب': u'الْأَظْرُبِ', #2
u'الأظل': u'الْأَظَلّ', #1
u'الأظهرية': u'الْأَظْهَرِيَّةُ', #1
u'الأظهرية': u'الْأَظْهَرِيَّةَ', #2
u'الأظهرية': u'الْأَظْهَرِيَّةِ', #5
u'الأعاجمSشعر': u'الْأَعَاجِمِSشِعْرٌ', #1
u'الاعادة': u'الاعادة', #1
u'الأعاديا': u'الْأَعَادِيَا', #2
u'الإعاره': u'الْإِعَارَهْ', #1
u'الأعاشي': u'الْأَعَاشِي', #1
u'الأعاصر': u'الْأَعَاصِرُ', #4
u'الأعبد،': u'الأَعْبُدِ،', #1
u'الأعبد': u'الْأَعْبُدُ', #1
u'الأعبد': u'الْأَعْبُدِ', #14
u'الأعبد': u'الْأَعْبُدَ', #2
u'الأعتاد': u'الْأَعْتَادُ', #4
u'الإعتاقا': u'الْإِعْتَاقَا', #2
u'الاعتجار': u'الِاعْتِجَارِ', #4
u'الاعتجار': u'الِاعْتِجَارُ', #8
u'الأعتد': u'الْأَعْتُدُ', #1
u'الأعتداء': u'الأعْتِدَاءُ', #1
u'الاعتضاد': u'الِاعْتِضَادَ', #1
u'الاعتضاد': u'الِاعْتِضَادُ', #2
u'الاعتضاد': u'الِاعْتِضَادِ', #5
u'الاعتقاب': u'الاِعْتِقَابِ', #1
u'الاعتقاق': u'الِاعْتِقَاقَ', #1
u'الإعتكاف': u'الإِعْتِكَافِ', #1
u'الاعتلاث': u'الِاعْتِلَاثِ', #1
u'الاعتلاج': u'الِاعْتِلَاجُ', #1
u'الاعتلاف': u'الِاعْتِلَافِ', #15
u'الاعتلاف': u'الِاعْتِلَافُ', #5
u'الاعتمال': u'الِاعْتِمَال', #1
u'الاعتمال': u'الِاعْتِمَالُ', #2
u'الاعتمام': u'الِاعْتِمَامُ', #1
u'الاعتوان': u'الِاعْتِوَانِ', #1
u'الاعتياص': u'الِاعْتِيَاصُ', #1
u'الأعجام': u'الْأَعْجَامُ', #1
u'الأعجام': u'الْأَعْجَامِ', #2
u'الأعجل،': u'الأعجل،', #1
u'الأعجل': u'الأَعْجَلُ', #3
u'الأعجل': u'الْأَعْجَلُ', #4
u'الأعجمى': u'الأَعْجَمِىِّ', #1
u'الأعدام': u'الْأَعْدَامِ', #3
u'الأعدلي': u'الْأَعْدَلِيَّ', #1
u'الأعدلية': u'الْأَعْدَلِيَّةُ', #2
u'الأعدلية': u'الْأَعْدَلِيَّةِ', #5
u'الأعدم': u'الْأَعْدَمِ', #4
u'الإعذارا': u'الْإِعْذَارَا', #1
u'الإعراء': u'الْإِعْرَاءِ', #1
u'الإعراء': u'الْإِعْرَاءُ', #6
u'الأعرابى': u'الأَعْرَابِىَّ', #11
u'الأعرابى': u'الأَعْرَابِى', #2
u'الأعرابى': u'الأَعْرَابِىِّ', #298
u'الأعرابى': u'الأَعْرَابِىُّ', #38
u'الإعراف': u'الْإِعْرَافِ', #1
u'الأعرجي،': u'الأَعْرَجِيُّ،', #1
u'الأعرجى': u'الأَعْرَجِىُّ', #1
u'الأعرجي': u'الْأَعْرَجِيِّ', #3
u'الأعرض': u'الْأَعْرَضُ', #1
u'الإعزار': u'الْإِعْزَارَ', #1
u'الأعسم': u'الأَعْسَمُ', #3
u'الأعسم': u'الْأَعْسَمُ', #3
u'الأعسم': u'الْأَعْسَمِ', #3
u'الأعضا': u'الْأَعْضَا', #1
u'الإعضاء': u'الإِعْضَاءِ', #1
u'الأعضب': u'الْأَعْضَبِ', #4
u'الأعضل': u'الأعضل', #1
u'الأعط': u'الْأَعَطِّ', #1
u'الأعطان': u'الْأَعْطَان', #1
u'الأعطان': u'الْأَعْطَانُ', #1
u'الأعطان': u'الْأَعْطَانِ', #2
u'الأعطى': u'الْأَعْطَى', #1
u'الأعطيات': u'الْأُعْطَيَاتُ', #1
u'الأعطيات': u'الْأُعْطِيَّاتُ', #1
u'الأعطيات': u'الْأَعْطِيَاتِ', #12
u'الأعطيات': u'الْأَعْطِيَاتُ', #3
u'الاعظم': u'الاعظم', #1
u'الأعظمي': u'الأعظمي', #1
u'الأعظمية': u'الْأَعْظَمِيَّةُ', #2
u'الأعظمية': u'الْأَعْظَمِيَّةِ', #3
u'الإعقاق': u'الْإِعْقَاقُ', #1
u'الأعقلية': u'الْأَعْقَلِيَّةُ', #1
u'الأعكام': u'الْأَعْكَامَ', #1
u'الأعكام': u'الْأَعْكَامُ', #2
u'الأعكام': u'الْأَعْكَامِ', #2
u'الأعلاث': u'الْأَعْلَاثِ', #1
u'الإعلاق': u'الإعلاق', #1
u'الإعلاق': u'الإِعْلاَقِ', #1
u'الإعلاق': u'الْإِعْلَاقَ', #1
u'الإعلاق': u'الْإِعْلَاقِ', #11
u'الإعلاق': u'الْإِعْلَاقُ', #3
u'إلاعلم': u'إلاعلم', #1
u'الأعلمية': u'الْأَعْلَمِيَّةُ', #1
u'الأعلمية': u'الْأَعْلَمِيَّةَ', #4
u'الأعلمية': u'الْأَعْلَمِيَّةِ', #5
u'الأعلوية': u'الْأَعْلَوِيَّةَ', #1
u'الأعلوين': u'الْأَعْلَوَيْنَ', #1
u'الاعمال': u'الاعمال', #1
u'الأعمر': u'الْأَعْمَرِ', #1
u'الأعمر': u'الْأَعْمُرُ', #1
u'الأعمر': u'الْأَعْمَرُ', #5
u'الاعمش،': u'الاعمش،', #1
u'الأعمشي': u'الْأَعْمَشِيِّ', #1
u'الأعمشى': u'الأَعْمَشِىَّ', #1
u'الأعمشى': u'الأَعْمَشِىُّ', #1
u'الأعمية': u'الَأَعَمِّيَّةِ', #1
u'الأعمية': u'الْأَعَمِّيَّةُ', #10
u'الأعمية': u'الْأَعَمِّيَّةَ', #11
u'الأعمية': u'الْأَعَمِّيَّةِ', #26
u'الإعواض': u'الْإِعْوَاضَ', #2
u'الأعوجية': u'الْأَعْوَجِيّةُ', #2
u'الأعونة': u'الْأَعْوِنَةِ', #6
u'الأعياني': u'الْأَعْيَانِيُّ', #1
u'الأعيس': u'الأعيس', #1
u'الأعيس،': u'الأَعْيَسِ،', #1
u'الأعيق،': u'الأَعْيَقِ،', #1
u'الإغباء': u'الْإِغْبَاءَ', #1
u'الإغباب': u'الْإِغْبَابُ', #1
u'الأغبرماش': u'الأغبرماش', #1
u'الأغبط': u'الَأَغْبَطِ', #1
u'الأغبط': u'الْأَغْبَطَ', #22
u'الأغبط': u'الْأَغْبَطُ', #56
u'الأغبط': u'الْأَغْبَطِ', #89
u'الأغبطية': u'الْأَغْبَطِيَّةَ', #1
u'الأغبطية': u'الْأَغْبَطِيَّةِ', #1
u'الأغبطية': u'الْأَغْبَطِيَّةُ', #3
u'الأغتام': u'الْأَغْتَامُ', #1
u'الاغتداء': u'الِاغْتِدَاءَ', #1
u'الاغتراس': u'الِاغْتِرَاسُ', #1
u'الاغتراس': u'الِاغْتِرَاسِ', #1
u'الاغتصاص': u'الِاغْتِصَاصِ', #1
u'الاغتلال': u'الِاغْتِلَالِ', #5
u'الإغذاء': u'الْإِغْذَاءِ', #5
u'الأغرل': u'الْأَغْرَلُ', #1
u'الأغريسية': u'الْأَغْرِيسِيَّةِ', #1
u'الإغريسية': u'الْإِغْرِيسِيَّةِ', #2
u'الإغريض': u'الْإِغْرِيضَ', #1
u'الإغريض': u'الْإِغْرِيضُ', #2
u'الإغريض': u'الْإِغْرِيضِ', #6
u'الإغزاء': u'الْإِغْزَاءُ', #1
u'الإغزاء': u'الْإِغْزَاءِ', #1
u'الإغسال': u'الْإِغْسَال', #1
u'الإغسال': u'الْإِغْسَالُ', #1
u'الأغطس،': u'الأغطس،', #1
u'الإغلاس': u'الْإِغْلَاسُ', #1
u'الأغلاف': u'الْأَغْلَافِ', #1
u'الأغلاقي': u'الْأَغْلَاقِيِّ', #1
u'الأغلالا': u'الْأَغْلَالَا', #1
u'الأغلبي': u'الْأَغْلَبِيِّ', #1
u'الأغلظية': u'الْأَغْلَظِيَّةُ', #1
u'الأغلف،': u'الأَغْلَفِ،', #1
u'الأغلف': u'الْأَغْلَفُ', #6
u'الأغلف': u'الْأَغْلَفِ', #6
u'الأغلوطات': u'الْأُغْلُوطَاتِ', #9
u'الاغما': u'الِاغْمَا', #2
u'الإغمار': u'الْإِغْمَارُ', #1
u'الأغمض': u'الْأَغْمَضِ', #1
u'الأغواص': u'الْأَغْوَاصَ', #1
u'الأغوال': u'الْأَغْوَالِ', #1
u'الإغياء': u'الْإِغْيَاءِ', #16
u'الإغياء': u'الْإِغْيَاءَ', #2
u'الإغياء': u'الْإِغْيَاءُ', #3
u'الإغياءين': u'الْإِغْيَاءَيْنِ', #2
u'الأغياب': u'الْأَغْيَابُ', #1
u'الإغيائية': u'الْإِغْيَائِيَّةِ', #4
u'الأغيد': u'الْأَغْيَدُ', #4
u'الأغيلمة': u'الْأُغَيْلِمَةُ', #1
u'الإفاتة': u'الْإِفَاتَةَ', #14
u'الإفاتة': u'الْإِفَاتَةُ', #3
u'الإفاتة': u'الْإِفَاتَةِ', #9
u'الإفاده': u'الْإِفَادَهْ', #1
u'الأفاعل': u'الْأَفَاعِلِ', #1
u'الأفاعيا': u'الأفاعيا', #1
u'الأفاقي': u'الْأَفَاقِيُّ', #1
u'الأفاقي': u'الْأَفَاقِيِّ', #1
u'الأفاقي': u'الْأَفَّاقِيَّ', #1
u'الأفاقي': u'الْأَفَّاقِي', #2
u'الأفاقية': u'الْأَفَّاقِيَّةِ', #1
u'آلافالوجه': u'آلافالْوَجْهُ', #1
u'آلافالوجه': u'آلافٍالْوَجْهُ', #1
u'الأفانيا': u'الأفانيا', #1
u'الافتراع': u'الِافْتِرَاعِ', #1
u'الافتكاك': u'الِافْتِكَاكَ', #1
u'الافتكاك': u'الِافْتِكَاكُ', #1
u'الافتكاك': u'الِافْتِكَاكِ', #27
u'الافتلات': u'الِافْتِلَاتِ', #1
u'الافتيات': u'الِافْتِيَات', #1
u'الافتيات': u'الِافْتِيَاتُ', #27
u'الافتيات': u'الِافْتِيَاتِ', #35
u'الافتيات': u'الِافْتِيَاتَ', #8
u'الأفج': u'الْأَفَجِّ', #1
u'الأفجاج': u'الْأَفْجَاجِ', #1
u'الأفجج': u'الْأَفْجَجُ', #1
u'الأفجران': u'الأفجران', #2
u'الأفجرين': u'الْأَفْجَرِينَ', #1
u'الأفحشية': u'الْأَفْحَشِيَّةَ', #1
u'الأفحشية': u'الْأَفْحَشِيَّةِ', #1
u'الأفدان': u'الْأَفْدَانُ', #1
u'الأفدع': u'الْأَفْدَعِ', #1
u'الأفدق': u'الأفدق', #1
u'الإفراء': u'الْإِفْرَاءِ', #3
u'الأفرادي': u'الْأَفْرَادِيِّ', #1
u'الإفرار': u'الْإِفْرَارِ', #1
u'الأفراز': u'الْأَفْرَازِ', #1
u'الأفراس': u'الْأَفْرَاسِ', #16
u'الأفراس': u'الْأَفْرَاسُ', #5
u'الأفراس': u'الْأَفْرَاسَ', #7
u'الإفراض': u'الإِفْرَاضَ', #1
u'الإفراق': u'الْإِفْرَاقُ', #1
u'الأفربيون': u'الأفربيون', #1
u'الأفرق،': u'الأَفْرَقُ،', #1
u'الأفرق': u'الْأَفْرَقِ', #1
u'الأفرق': u'الْأَفْرَقُ', #4
u'الإفرنسية': u'الْإفْرِنْسِيَّةِ', #1
u'الأفرية': u'الْأَفْرِيَةَ', #1
u'الأفرية': u'الْأَفْرِيَةُ', #2
u'الأفرية': u'الْأَفْرِيَةِ', #2
u'الأفريقى': u'الأَفْرِيقِىَّ', #1
u'الإفريقى': u'الإِفْرِيقِىُّ', #1
u'الإفريقى': u'الإِفْرِيقِىِّ', #1
u'الإفريقى': u'الإِفْرِيقِىَّ', #2
u'الأفريقى': u'الأَفْرِيقِىُّ', #3
u'الأفريقى': u'الأَفْرِيقِىِّ', #3
u'الأفزاع': u'الْأَفْزَاعِ', #14
u'الأفزاع': u'الْأَفْزَاعُ', #2
u'الأفزر': u'الْأَفْزَرُ', #1
u'الأفسد': u'الْأَفْسَدِ', #1
u'الإفسنتين': u'الإفسنتين', #1
u'الأفشين': u'الْأَفْشِينَ', #1
u'الأفصحية': u'الْأَفْصَحِيَّةَ', #2
u'الإفضاح': u'الْإِفْضَاحِ', #1
u'الأفطسي،': u'الأفطسي،', #1
u'الأفطسي': u'الْأَفْطَسِيُّ', #1
u'الإفعال': u'الْإِفْعَالُ', #1
u'الإفعال': u'الْإِفْعَالِ', #15
u'الأفعل': u'الْأَفْعَلُ', #1
u'الأفعل': u'الْأَفْعَلِ', #2
u'الأفقا': u'الْأُفُقَا', #1
u'الأفقر': u'الْأَفْقَرُ', #3
u'الأفقر': u'الْأَفْقَرِ', #5
u'الأفقه': u'الْأَفْقَهَ', #31
u'الأفقه': u'الْأَفْقَهِ', #74
u'الأفقه': u'الْأَفْقَهُ', #98
u'الأفقهي': u'الْأَفْقَهِيِّ', #1
u'الأفقهية': u'الْأَفْقَهِيَّةِ', #1
u'الأفكل': u'الأفكل', #1
u'الأفلاج': u'الْأَفْلَاجِ', #1
u'الأفلس': u'الْأَفْلَسِ', #1
u'الأفن': u'الْأَفَنَ', #1
u'الأفن': u'الْأَفِنُ', #1
u'الأفن': u'الْأَفَنُ', #2
u'الأفن': u'الْأَفَنِ', #2
u'الأفن': u'الْأَفْنِ', #2
u'الأفوه': u'الْأَفْوَهِ', #1
u'الأفوه': u'الْأَفْوَهُ', #3
u'الأفياء': u'الْأَفْيَاءَ', #2
u'الأفياء': u'الْأَفْيَاءُ', #3
u'الأفيالا': u'الْأَفْيَالا', #1
u'الأفيح': u'الْأَفْيَحِ', #1
u'الأفيح': u'الأفيح', #2
u'الأفيدية': u'الْأَفْيَدِيَّةِ', #2
u'الأفيلة': u'الْأَفِيلَةِ', #1
u'الأفين': u'الْأَفِينِ', #1
u'الإقادة': u'الْإِقَادَةُ', #1
u'الإقادة': u'الْإِقَادَةِ', #6
u'الأقارير': u'الْأَقَارِيرَ', #14
u'الأقارير': u'الْأَقَارِير', #2
u'الأقارير': u'الْأَقَارِيرِ', #71
u'الأقارير': u'الْأَقَارِيرُ', #9
u'الإقاله': u'الْإِقَالَهْ', #3
u'الإقامه': u'الْإِقَامَهْ', #1
u'الأقاوية': u'الْأَقَاوِيَّةِ', #4
u'الأقايش': u'الْأَقَايِشِ', #1
u'الإقباض': u'الْإِقْبَاضِ', #164
u'الإقباض': u'الْإِقْبَاضُ', #37
u'الإقباض': u'الْإِقْبَاضَ', #49
u'الأقباطا': u'الْأَقْبَاطَا', #1
u'الإقباع': u'الْإِقْبَاعِ', #1
u'الأقباع': u'الْأَقْبَاعِ', #4
u'الإقبالة': u'الْإِقْبَالَةِ', #1
u'الإقبالة': u'الْإِقْبَالَةُ', #2
u'الأقبر': u'الأَقْبُرِ', #2
u'الأقبر': u'الْأَقْبُرِ', #2
u'الأقبل': u'الْأَقْبَلِ', #3
u'الأقبلية': u'الْأَقْبَلِيَّةِ', #1
u'إلاقة': u'إلَاقَةً', #1
u'الأقتاب': u'الأقتاب', #1
u'الأقتاب': u'الأَقتاب', #1
u'الأقتاب': u'الأَقْتَابِ', #3
u'الأقتاب': u'الْأَقْتَابُ', #4
u'الأقتاب': u'الْأَقْتَابِ', #4
u'الأقتار': u'الْأَقْتَارُ', #2
u'الأقتار': u'الْأَقْتَارِ', #2
u'الاقتبال': u'الِاقْتِبَالِ', #1
u'الاقتدا': u'الِاقْتِدَا', #3
u'الاقتداءبه': u'الِاقْتِدَاءِبِهِ', #2
u'الاقتراني': u'الِاقْتِرَانِيُّ', #3
u'الاقتراني': u'الِاقْتِرَانِيِّ', #8
u'الاقتضاض': u'الِاقْتِضَاضَ', #2
u'الاقتضاض': u'الِاقْتِضَاضُ', #2
u'الاقتضاض': u'الِاقْتِضَاضِ', #4
u'الاقتطار': u'الِاقْتِطَارُ', #1
u'الاقتعاط': u'الِاقْتِعَاطَ', #2
u'الاقتعاط': u'الِاقْتِعَاطُ', #4
u'الاقتعاط': u'الِاقْتِعَاطِ', #6
u'الاقتنا': u'الِاقْتِنَا', #1
u'الاقتياب': u'الِاقْتِيَابُ', #1
u'الأقجه': u'الأقجه', #1
u'الإقدار': u'الْإِقْدَارِ', #1
u'الإقدار': u'الْإِقْدَارُ', #14
u'الإقدار': u'الْإِقْدَارَ', #8
u'الأقدح': u'الْأَقْدَحُ', #1
u'الأقدسية': u'الْأَقْدَسِيَّةِ', #2
u'الأقدمينا': u'الْأَقْدَمِينَا', #2
u'الأقذر': u'الْأَقْذَرُ', #1
u'الأقذرية': u'الْأَقْذَرِيَّةِ', #1
u'الأقرا': u'الْأَقْرَا', #2
u'الأقراء؟': u'الأَقْرَاءُ؟', #1
u'الأقراء': u'الْأَقْرَاء', #2
u'الأقراء': u'الْأَقْرَاءِ', #452
u'الأقراء': u'الأَقْرَاءِ', #7
u'الأقراء': u'الْأَقْرَاءَ', #73
u'الأقراء': u'الأَقْرَاءُ', #8
u'الأقراء': u'الْأَقْرَاءُ', #92
u'الأقراب': u'الأَقْرَابِ', #1
u'الأقراب': u'الْأَقْرَابِ', #9
u'الأقربا': u'الْأَقْرَبَا', #1
u'الأقربية': u'الْأَقْرَبِيّة', #1
u'الأقربية': u'الْأَقْرَبِيَّة', #1
u'الأقربية': u'الْأَقْرَبِيَّةُ', #17
u'الأقربية': u'الْأَقْرَبِيَّةَ', #37
u'الأقربية': u'الْأَقْرَبِيَّةِ', #60
u'الأقرحة': u'الْأَقْرِحَةَ', #1
u'الأقرحة': u'الْأَقْرِحَةُ', #16
u'الأقرحة': u'الْأَقْرِحَةِ', #23
u'الأقرم': u'الأَقْرَمِ', #1
u'الأقرئية': u'الْأَقْرَئِيَّةِ', #2
u'الأقرئية': u'الْأَقْرَئِيَّةُ', #3
u'الإقريطشي': u'الإقريطشي', #1
u'الأقزاح': u'الْأَقْزَاحُ', #1
u'الأقساس': u'الأَقْسَاسِ', #1
u'الأقسما': u'الْأَقْسَمَا', #1
u'الأقسماء': u'الْأَقْسِمَاءَ', #1
u'الأقسماء': u'الْأَقْسِمَاءُ', #1
u'الأقشعريرة': u'الْأُقْشَعْرِيرَةِ', #1
u'الأقصاب': u'الْأَقْصَابِ', #7
u'الأقصراني': u'الَأَقْصُرَانِيِّ', #1
u'الأقصراني': u'الْأَقْصُرَانِيِّ', #1
u'الأقصراوي': u'الْأَقْصَرَاوِيُّ', #1
u'الأقصرائي': u'الْأَقْصِرَائِيُّ', #2
u'الإقضاء': u'الْإِقْضَاءَ', #1
u'الأقط': u'الأَقِطَ', #1
u'الأقط': u'الْأَقْطَ', #1
u'الأقط': u'الأقط', #10
u'الأقط': u'الْأَقِط', #2
u'الأقط': u'الْأَقِطَ', #31
u'الأقط': u'الأَقِطِ', #4
u'الأقط': u'الْأَقِطُ', #42
u'الأقط': u'الْأَقِطِ', #83
u'الأقطاع': u'الْأَقْطَاعَ', #1
u'الأقطاع': u'الْأَقْطَاعُ', #2
u'الأقطاع': u'الْأَقْطَاعِ', #3
u'الإقعا': u'الْإِقْعَا', #1
u'الاقعاء': u'الاقعاء', #1
u'الإقعاص': u'الإِقْعَاصُ', #1
u'الأقعدية': u'الْأَقْعَدِيَّةِ', #2
u'الأقعس': u'الْأَقْعَسَ', #1
u'الأقعس': u'الْأَقْعَسُ', #1
u'الأقفزة': u'الْأَقْفِزَةِ', #14
u'الأقفزة': u'الْأَقْفِزَةُ', #3
u'الأقفزة': u'الْأَقْفِزَةَ', #9
u'الأقفهسي': u'الْأَقْفَهْسِيّ', #1
u'الأقفهسي': u'الْأَقْفَهْسِيُّ', #105
u'الأقفهسي': u'الْأَقْفَهْسِيِّ', #36
u'ألاقل': u'أَلَاقُلْ', #1
u'الأقلاد': u'الْأَقْلَادِ', #1
u'الأقلح': u'الأقلح', #3
u'الأقلح،': u'الْأَقْلَحِ،', #3
u'الأقلح': u'الْأَقْلَحِ', #30
u'الأقلح': u'الأَقْلَحِ', #5
u'الأقلف': u'الأَقْلَفَ', #1
u'الأقلف': u'الْأَقْلَفُ', #15
u'الأقلف': u'الأَقْلَفِ', #2
u'الأقلف': u'الْأَقْلَفَ', #4
u'الأقلف': u'الْأَقْلَفِ', #58
u'الإقليدس': u'الْإِقْلِيدِسِ', #2
u'الأقليشي': u'الْأُقْلِيشِيُّ', #1
u'الإقليلي': u'الْإِقْلِيلِيّ', #1
u'الإقناء': u'الْإِقْنَاءِ', #1
u'الأقنع': u'الْأَقْنَعِ', #2
u'الأقنى': u'الْأَقْنَى', #1
u'الأقواد': u'الْأَقْوَادِ', #1
u'الأقوص': u'الْأَقْوَصِ', #1
u'الأقولة': u'الْأَقْوِلَةِ', #1
u'الأقووية': u'الْأَقْوَوِيَّةِ', #3
u'الأقوي': u'الْأَقْوَيْ', #1
u'الأقويا': u'الْأَقْوِيَا', #1
u'الأقيال': u'الْأَقْيَالِ', #2
u'الأقيال': u'الْأَقْيَالَ', #3
u'الأقيس': u'الْأَقْيَسَ', #12
u'الأقيس': u'الْأَقْيَسُ', #83
u'الأقيس': u'الْأَقْيَسِ', #98
u'الأقيشر': u'الأقَيْشر', #1
u'الآكار': u'الآكار', #2
u'الإكارة': u'الْإِكَارَةِ', #1
u'الإكاف': u'الإكاف', #1
u'الإكاف': u'الْإِكَافَ', #30
u'الإكاف': u'الْإِكَافُ', #36
u'الإكاف': u'الْإِكَافِ', #51
u'الأكاكي': u'الأكاكي', #1
u'الأكاميم': u'الْأَكَامِيمُ', #1
u'الأكباء': u'الْأَكْبَاءَ', #1
u'الأكباء': u'الْأَكْبَاءُ', #1
u'الأكبار': u'الْأَكْبَارُ', #1
u'الأكبار': u'الْأَكْبَارِ', #1
u'الأكبراااا': u'الْأَكْبَرِاااا', #1
u'الأكبرية': u'الْأَكْبَرِيَّةَ', #1
u'الاكتحالا': u'الِاكْتِحَالَا', #1
u'الاكترا': u'الِاكْتِرَا', #1
u'الاكتناء': u'الِاكْتِنَاء', #1
u'الاكتنان': u'الِاكْتِنَانِ', #1
u'الآكد': u'الْآكَدَ', #13
u'الآكد': u'الْآكِدَ', #2
u'الآكد': u'الْآكَدُ', #21
u'الآكد': u'الْآكَدِ', #23
u'الأكدار': u'الْأَكْدَارَ', #1
u'الأكدار': u'الْأَكْدَارِ', #5
u'الأكدرية': u'الأَكْدَرِيَةِ', #1
u'الأكدرية': u'الأَكْدَرِيَّةُ', #1
u'الأكدرية': u'الأَكْدَرِيَّةِ', #1
u'الأكدرية': u'الْأَكْدَرِيَّةُ', #13
u'الأكدرية': u'الْأَكْدَرِيَّةَ', #5
u'الأكدرية': u'الْأَكْدَرِيَّةِ', #97
u'الأكدريه': u'الْأَكْدَرِيَّهْ', #1
u'الأكدية': u'الْأَكْدِيَةُ', #1
u'الآكدية': u'الْآكَدِيَّةِ', #14
u'الآكدية': u'الْآكَدِيَّةُ', #3
u'الإكديش': u'الْإِكْدِيشَ', #1
u'الإكديش': u'الْإِكْدِيشُ', #1
u'الإكديش': u'الْإِكْدِيشِ', #1
u'الآكر': u'الْآكِرُ', #1
u'الإكرا': u'الْإِكْرَا', #1
u'الأكراء': u'الْأَكْرَاءُ', #1
u'الأكرار': u'الْأَكْرَارِ', #1
u'الإكرار': u'الْإِكْرَارِ', #1
u'الأكرمية': u'الْأَكْرَمِيَّةِ', #1
u'الأكرية': u'الْأَكْرِيَةِ', #23
u'الأكرية': u'الْأَكْرِيَةُ', #6
u'الأكرية': u'الْأَكْرِيَةَ', #9
u'الأكساب': u'الْأَكْسَابَ', #24
u'الأكساب': u'الْأَكْسَابُ', #38
u'الأكساب': u'الْأَكْسَابِ', #96
u'الأكسابا': u'الْأَكْسَابَا', #1
u'الإكسابا': u'الْإِكْسَابَا', #1
u'الأكشوت': u'الأكشوت', #1
u'الأكفاني': u'الْأَكْفَانِيِّ', #1
u'الأكفانى': u'الأَكَفَانِىُّ', #1
u'الأكفانى': u'الأَكْفَانِىُّ', #1
u'الأكفى': u'الْأَكْفَى', #1
u'الأكلبي': u'الْأَكْلَبِيّ', #1
u'الأكلفي': u'الْأَكْلُفِي', #1
u'الأكملي': u'الْأَكْمَلِيِّ', #2
u'الأكملية': u'الأكملية', #1
u'الأكملية': u'الْأَكْمَلِيَّةَ', #1
u'الأكملية': u'الْأَكْمَلِيَّةِ', #6
u'الأكنان': u'الْأَكْنَانَ', #1
u'الأكنفة': u'الْأَكْنِفَةَ', #2
u'الأكنفة': u'الْأَكْنِفَةِ', #7
u'الأكهب': u'الْأَكْهَبُ', #3
u'الأكهب': u'الْأَكْهَبِ', #3
u'الأكيدر': u'الْأُكَيْدِرُ', #1
u'الأكيدر': u'الْأُكَيْدِرِ', #1
u'آلال': u'آلَالٌ', #1
u'آلال': u'آلَالَ', #1
u'إلآل': u'إلْآلٍ', #1
u'الإل': u'الإِلُّ', #1
u'الإل': u'الإل', #14
u'إلال': u'إلَالُ', #2
u'الإل': u'الْإِلَ', #2
u'الإل': u'الْإِلّ', #2
u'الإل': u'الْإِلُّ', #2
u'الأل': u'الْأَلّ', #3
u'إلال': u'إلَالٌ', #8
u'ألالا': u'أَلَالًا', #3
u'الآلاءوروي،': u'الآلاءِوَرُوِيَ،', #1
u'الالآت': u'الْالَآتِ', #1
u'الألاف': u'الْأُلَّافُ', #2
u'الإلال': u'الْإِلَالُ', #1
u'الآلال': u'الْآلَالِ', #2
u'الألبيري': u'الْأَلْبِيرِيَّ', #1
u'الألة': u'الْأَلَّةِ', #1
u'الالتدام': u'الِالْتِدَامُ', #2
u'الالتعان': u'الِالْتِعَانِ', #13
u'الالتعان': u'الِالْتِعَانَ', #2
u'الالتعان': u'الِالْتِعَانُ', #2
u'الالتفاتتين': u'الِالْتِفَاتَتَيْنِ', #2
u'الالتفاع': u'الِالْتِفَاعَ', #1
u'الالتفاع': u'الِالْتِفَاعُ', #1
u'الالتوا': u'الِالْتِوَا', #1
u'الألثغي': u'الْأَلْثَغِيُّ', #1
u'الألحاظ': u'الْأَلْحَاظِ', #1
u'الألحن': u'الألحن', #1
u'الألحى': u'الْأَلْحَى', #1
u'الإلذاذ': u'الْإِلْذَاذُ', #1
u'الإلذاذ': u'الْإِلْذَاذِ', #1
u'الألزم': u'الْأَلْزَمُ', #1
u'الألزم': u'الْأَلْزَمِ', #1
u'الألس': u'الْأَلْسَ', #1
u'الألس': u'الْأَلْسِ', #1
u'الألغازية': u'الْأَلْغَازِيَّةُ', #1
u'الألفا': u'الْأَلْفَا', #1
u'الإلفين': u'الْإِلْفَيْنِ', #1
u'الألمعي': u'الْأَلْمَعِيُّ', #4
u'الألمعية': u'الْأَلْمَعِيَّةِ', #1
u'الألنجوج': u'الْأَلَنْجُوجُ', #1
u'الألندد': u'الْأَلَنْدَدُ', #2
u'الإلهات': u'الْإِلَهَاتِ', #2
u'الألهاني،': u'الألهاني،', #1
u'الألهاني': u'الأَلْهَانِيُّ', #1
u'الألهاني': u'الأُلْهَانِيِّ', #1
u'الألهاني،': u'الأَلْهَانِيَّ،', #1
u'الألهاني،': u'الْأَلْهَانِيُّ،', #1
u'الألهانى': u'الأَلْهَانِىَّ', #1
u'الألهانى': u'الأَلْهَانِىِّ', #1
u'الألهاني،': u'الأَلْهَانِيُّ،', #13
u'الألهاني،': u'الأَلْهَانِيِّ،', #2
u'الألهاني': u'الْأَلْهَانِيَّ', #2
u'الألهانى': u'الأَلْهَانِىُّ', #3
u'الألهاني': u'الألهاني', #5
u'الألهاني': u'الْأَلْهَانِيِّ', #5
u'الألهاني': u'الْأَلْهَانِيُّ', #6
u'الألهة': u'الأَلِهَةَ', #1
u'الإلهة': u'الْإِلَهَةَ', #1
u'الإلهة': u'الْإِلَهَةِ', #2
u'الآلهةوالله': u'الآلِهَةُوَاللَّهِ', #1
u'الآلهي': u'الْآلِهِيَّ', #1
u'الآلهية': u'الْآلِهِيَّةَ', #1
u'الآلهية': u'الْآلِهِيَّةُ', #1
u'الآلهية': u'الْآلِهِيَّةِ', #3
u'الألواث': u'الْأَلْوَاثِ', #1
u'الألوة': u'الْأَلُوَّة', #1
u'الألوة': u'الْأُلُوّةُ', #1
u'الألوة': u'الْأُلْوَةُ', #1
u'الألوة': u'الأَلُوَّةُ', #2
u'الألوة': u'الْأَلْوَةُ', #2
u'الألوة': u'الأَلُوَّةِ', #3
u'الألوة': u'الألوة', #4
u'الألوة': u'الْأَلُوَّةُ', #7
u'الألوغية': u'الْأَلْوَغِيَّةِ', #1
u'الألوك': u'الْأُلُوكِ', #3
u'الإلياسية': u'الْإِلْيَاسِيَّةِ', #1
u'إلألية،': u'إِلأَلْيَةُ،', #1
u'الإلية': u'الْإِلْيَةِ', #1
u'الإليتين': u'الإِلْيَتَيْنِ', #2
u'الإليتين،': u'الْإِلْيَتَيْنِ،', #2
u'الأليقية': u'الْأَلْيَقِيَّةُ', #1
u'الأليقية': u'الْأَلْيَقِيَّةِ', #2
u'الإما': u'الْإِمَا', #8
u'الأمات': u'الْأُمَّاتُ', #19
u'الأمات': u'الْأُمَّاتِ', #20
u'الأماجيد': u'الْأَمَاجِيدِ', #2
u'الإمارةوالوجه': u'الإِمَارَةُوَالْوَجْهُ', #1
u'الآماق': u'الْآمَاقِ', #2
u'الأماقي': u'الْأَمَاقِي', #1
u'الآمالا': u'الْآمَالَا', #1
u'الأمالى': u'الأَمَالِىِّ', #1
u'الإمالين': u'الْإِمَالَيْنِ', #1
u'الامام': u'الامام', #1
u'الإماما': u'الْإِمَامَا', #1
u'الإمامإذا': u'الْإِمَامِإِذَا', #1
u'الإمامالوجه': u'الإِمَامُالْوَجْهُ', #1
u'الإمامإلى': u'الْإِمَامُإِلَى', #1
u'الأمانى': u'الأَمَانِىُّ', #3
u'الأمانيا': u'الْأَمَانِيَا', #3
u'الإمائية': u'الْإِمَائِيَّةَ', #1
u'الإمة': u'الْإِمَةِ', #1
u'الامة': u'الامة', #1
u'الأمت': u'الأمت', #1
u'الامتراء': u'الِامْتِرَاء', #2
u'الأمتعات': u'الْأَمْتِعَاتُ', #1
u'الأمتعات': u'الْأَمْتِعَاتِ', #4
u'الامتلاخ': u'الِامْتِلَاخُ', #1
u'الإمتناع': u'الإمتناع', #1
u'الامتناعا': u'الِامْتِنَاعَا', #1
u'الآمدي': u'الْآمِدِيِّ', #104
u'الآمدي': u'الْآمِدِيّ', #3
u'الآمدي': u'الْآمِدِيَّ', #39
u'الآمدي': u'الْآمِدِيُّ', #643
u'الإمذاء': u'الْإِمْذَاءَ', #2
u'الإمذاء': u'الْإِمْذَاءِ', #2
u'الإمذاء': u'الْإِمْذَاءُ', #4
u'الإمر': u'الْإِمْرُ', #1
u'الامرأة': u'الاِمْرَأَةُ', #1
u'الأمراق': u'الْأَمْرَاقَ', #1
u'الأمراق': u'الْأَمْرَاقِ', #2
u'الأمرة': u'الْأَمَرَةِ', #1
u'الأمرخ': u'الْأَمْرَخِ', #1
u'الأمردية': u'الْأَمْرَدِيَّةِ', #1
u'الأمساح': u'الْأَمْسَاحِ', #1
u'الإمشاط': u'الْإِمْشَاط', #1
u'الأمشاطيين': u'الْأَمْشَاطِيِّينَ', #1
u'الأمصر': u'الأَمْصَرُ', #1
u'الإمعاء': u'الْإِمْعَاءُ', #1
u'الإمعاء': u'الْإِمْعَاءِ', #1
u'الإمعار': u'الْإِمْعَارُ', #1
u'الأمغر': u'الْأَمْغَرُ', #1
u'الأمكنه': u'الْأَمْكِنَهْ', #1
u'الأملا': u'الْأَمَلَا', #1
u'الإملا': u'الْإِمْلَا', #1
u'الأملاء': u'الْأَمْلَاءِ', #2
u'الإملاج': u'الْإِمْلَاجَ', #1
u'الإملاج': u'الْإِمْلَاجِ', #2
u'الإملاجة': u'الْإِمْلَاجَةُ', #16
u'الإملاجة': u'الْإِمْلَاجَةِ', #2
u'الإملاجة': u'الإملاجة', #3
u'الإملاجة': u'الإِمْلاَجَةُ', #5
u'الإملاجة،': u'الإِمْلاجَةُ،', #7
u'الإملاجتان': u'الْإِمْلَاجَتَانِ', #11
u'الإملاص': u'الإملاص', #1
u'الأملة': u'الْأَمَلَة', #1
u'الأملج': u'الْأَمْلَجِ', #4
u'الأملوك': u'الْأَمْلُوكِ', #1
u'الأملوك': u'الْأُمْلُوكَ', #1
u'الأملوك': u'الْأُمْلُوكُ', #2
u'الأملوك': u'الْأُمْلُوكِ', #3
u'الأملوكي،': u'الأملوكي،', #1
u'الأملوكي،': u'الأُمْلُوكِيِّ،', #1
u'الأملوكي': u'الْأَمْلُوكِيِّ', #1
u'الأملوكي': u'الْأُمْلُوكِيَّ', #1
u'الأملوكي': u'الْأُمْلُوكِيِّ', #1
u'الآملى': u'الآمُلِىِّ', #1
u'الآملى': u'الآمُلِىُّ', #15
u'الأملياء': u'الْأَمْلِيَاءَ', #1
u'الأملياء': u'الْأَمْلِيَاءِ', #8
u'الإمليسي': u'الْإِمْلِيسِيُّ', #1
u'الأمليسية': u'الْأَمْلِيسِيَّةِ', #3
u'الإمناء': u'الْإِمْنَاءِ', #30
u'الإمناء': u'الْإِمْنَاءَ', #8
u'الإمناء': u'الْإِمْنَاءُ', #8
u'الأمهة': u'الْأُمَّهَةُ', #1
u'الأمهر': u'الْأَمْهَرَ', #1
u'الأمهر': u'الْأَمْهَرُ', #2
u'الأموالوروي': u'الأَمْوَالِوَرُوِيَ', #1
u'الأمورSقتل': u'الْأُمُورِSقَتْلُ', #1
u'الأمول': u'الْأَمْوَلَ', #1
u'الأمول': u'الْأَمْوَلِ', #1
u'الأمومه': u'الْأُمُومَهْ', #1
u'الأموى': u'الأُمَوِىِّ', #2
u'الأموى': u'الأَمَوِىُّ', #20
u'الأموى': u'الأُمَوِىُّ', #43
u'الأمى': u'الأُمِّىُّ', #1
u'الأمى': u'الأُمِّىَّ', #2
u'الأمى': u'الأُمِّىِّ', #6
u'الامير': u'الامير', #1
u'الأمينية': u'الْأَمِينِيَّةِ', #2
u'الأنا': u'الْأَنَا', #4
u'الإنا': u'الْإِنَا', #5
u'الاناء': u'الاناء', #1
u'الأناثى': u'الْأَنَاثَى', #1
u'الإناحة': u'الْإِنَاحَةِ', #1
u'الأنادر': u'الْأَنَادِرُ', #2
u'الأنادر': u'الْأَنَادِرِ', #4
u'الأناملا': u'الْأَنَامِلَا', #1
u'الإنانة': u'الْإِنَانَةُ', #1
u'الأنبابي': u'الْأُنْبَابِيُّ', #2
u'الأنبابي': u'الْأُنْبَابِيِّ', #2
u'الأنبابي': u'الأنبابي', #6
u'الأنباري،': u'الأَنْبارِيُّ،', #1
u'الأنباري': u'الأَنْبَارِيُّ', #1
u'الأنباري،': u'الأَنْبَارِيِّ،', #1
u'الأنبارى': u'الأَنْبَارِىِّ', #1
u'الأنباري': u'الْأَنْبَارِيِّ', #122
u'الأنباري': u'الْأَنْبَارِيُّ', #16
u'الأنبارى': u'الأَنْبَارِىُّ', #17
u'الأنباري': u'الْأَنْبَارِيّ', #18
u'الأنباري': u'الأَنْبَارِيِّ', #2
u'الأنباري': u'الْأَنْبَارِيَّ', #2
u'الأنباري،': u'الأَنْبَارِيُّ،', #3
u'الأنباصني': u'الأنباصني', #1
u'الإنباه': u'الْإِنْبَاهِ', #1
u'الأنبجاني': u'الْأَنْبِجَانِيّ', #1
u'الأنبجانى': u'الأنبجانى', #1
u'الأنبجانية،': u'الأنبجانية،', #1
u'الأنبجانية': u'الْأَنبَجانِيَّةَ', #1
u'الأنبجانية': u'الأَنْبِجَانِيَّةِ', #1
u'الأنبجانية': u'الْأَنْبِجَانِيَّة', #1
u'الأنبجانية': u'الْأَنْبِجَانِيَّةِ', #2
u'الأنبجانية': u'الأنبجانية', #3
u'الانبعاق': u'الِانْبِعَاقَ', #1
u'الانبغاء': u'الِانْبِغَاء', #1
u'الانبغاء': u'الِانْبِغَاءَ', #1
u'الانبغاء': u'الِانْبِغَاءُ', #2
u'الانبغاء': u'الِانْبِغَاءِ', #3
u'الانبغاءين': u'الِانْبِغَاءَيْنِ', #1
u'الانبهام': u'الِانْبِهَامِ', #3
u'الأنبوردي': u'الأنبوردي', #1
u'الأنبيا': u'الأنْبِيَا', #1
u'الأنبيا': u'الْأَنْبِيَا', #2
u'الانبياء': u'الانبياء', #1
u'الأنبياءالوجه': u'الأَنْبِيَاءِالْوَجْهُ', #1
u'الأنبياءوالوجه': u'الأَنْبِيَاءِوَالْوَجْهُ', #1
u'الأنبية': u'الْأَنْبِيَّةَ', #1
u'الأنبية': u'الْأَنْبِيَّةِ', #1
u'الأنبيق': u'الْأَنْبِيقِ', #1
u'الإنتباذ': u'الإِنْتِبَاذِ', #1
u'الانتتاف': u'الِانْتِتَافِ', #6
u'الانتتاف': u'الِانْتِتَافُ', #8
u'الانتثار': u'الِانْتِثَارَ', #1
u'الانتثار': u'الِانْتِثَارُ', #1
u'الانتثار': u'الِانْتِثَارِ', #5
u'الانتجاز': u'الانتجاز', #2
u'الانتخاء': u'الِانْتِخَاءُ', #1
u'الانتساء': u'الِانْتِسَاءَ', #1
u'الانتشاف': u'الِانْتِشَافِ', #1
u'الإنتفاء': u'الإِنْتِفَاءِ', #1
u'الانتفاكة': u'الانْتِفَاكَةُ', #1
u'الانتقاب': u'الِانْتِقَابَ', #1
u'الانتقاب': u'الِانْتِقَابُ', #6
u'الانتقاب': u'الِانْتِقَابِ', #9
u'الانتقاع': u'الِانْتِقَاع', #1
u'الانتقاع': u'الِانْتِقَاعَ', #1
u'الانتقاع': u'الِانْتِقَاعُ', #4
u'الانتقاع': u'الِانْتِقَاعِ', #7
u'الإنتقال': u'الإنتقال', #1
u'الانتكاف': u'الانْتِكَافُ', #1
u'الانتها': u'الِانْتِهَا', #1
u'الانتوال': u'الانتوال', #1
u'الإنثار': u'الْإِنْثَارُ', #1
u'الأنثتين': u'الْأُنْثَتَيْنِ', #1
u'الأنجذانى': u'الأَنْجُذَانِىُّ', #1
u'الانجراح': u'الِانْجِرَاحِ', #1
u'الانجعاف': u'الانجعاف', #1
u'الانجلا': u'الِانْجِلَا', #1
u'الانجماد': u'الِانْجِمَادِ', #1
u'الأنجيل': u'الْأَنْجِيلَ', #2
u'الأنحال': u'الأَنْحَالُ', #1
u'الأنحال': u'الأَنْحَالِ', #1
u'الانحتام': u'الِانْحِتَامَ', #1
u'الانحتام': u'الِانْحِتَامِ', #1
u'الانحجار': u'الِانْحِجَارُ', #1
u'الانحجاز': u'الِانْحِجَازُ', #1
u'الانحفاظ': u'الِانْحِفَاظِ', #1
u'الانحياش': u'الِانْحِيَاشُ', #1
u'الانحياش': u'الِانْحِيَاشِ', #1
u'الانخلاط': u'الِانْخِلَاطَ', #1
u'الانخناس': u'الِانْخِنَاسِ', #1
u'الاندراء': u'الِانْدِرَاءُ', #2
u'الأندراني': u'الأندراني', #2
u'الأندراوردي': u'الْأَنْدَرَاوَرْدِيِّ', #1
u'الانذباح': u'الِانْذِبَاحُ', #2
u'الانذباح': u'الِانْذِبَاحِ', #2
u'الإنزاء': u'الْإِنْزَاءُ', #11
u'الإنزاء': u'الْإِنْزَاء', #3
u'الإنزاء': u'الْإِنْزَاءِ', #32
u'الإنزاء': u'الْإِنْزَاءَ', #5
u'الإنزاع': u'الْإِنْزَاعَ', #1
u'الأنزروت': u'الأنزروت', #2
u'الأنزع': u'الْأَنْزَعُ', #1
u'الأنزل': u'الْأَنْزَلَ', #1
u'الأنزل': u'الْأَنْزَلُ', #1
u'الأنزل': u'الْأَنْزَلِ', #2
u'الأنزه': u'الْأَنْزَهُ', #1
u'الأنزه': u'الْأَنْزَهِ', #1
u'الانزهاق': u'الِانْزِهَاقَ', #3
u'الأنزورت': u'الأنزورت', #1
u'الأنساك': u'الْأَنْسَاكِ', #19
u'الإنسانة': u'الإِنْسَانَةُ', #1
u'الإنسانة': u'الْإِنْسَانَةُ', #1
u'الأنسبية': u'الْأَنْسَبِيَّةُ', #1
u'الأنسبية': u'الْأَنْسَبِيَّةَ', #4
u'الأنسبية': u'الْأَنْسَبِيَّةِ', #8
u'الانسلالا': u'الِانْسِلَالَا', #1
u'الإنسى': u'الإِنْسِىَّ', #1
u'الانسياغ': u'الِانْسِيَاغِ', #1
u'الانشا': u'الِانْشَا', #1
u'الإنشا': u'الْإِنْشَا', #2
u'الأنشاب': u'الْأَنْشَابِ', #2
u'الإنشاز': u'الْإِنْشَازِ', #2
u'الإنشقاق': u'الإنشقاق', #1
u'الانشلاء': u'الِانْشِلَاءُ', #1
u'الأنصارى،': u'الأنصارى،', #1
u'الأنصارى': u'الْأَنْصَارىِّ', #1
u'الأنصارى': u'الْأَنْصَارِىُّ', #1
u'الأنصارى': u'الأَنْصَارِىَّ', #114
u'الأنصارى': u'الْأَنْصَارِىَّ', #2
u'الأنصارى': u'الأَنْصَارِىِّ', #341
u'الأنصارى': u'الأَنْصَارِىُّ', #371
u'الأنصاريأخبره،': u'الأَنْصَارِيَّأَخْبَرَهُ،', #1
u'الأنصبا': u'الْأَنْصِبَا', #2
u'الانصباغ': u'الِانْصِبَاغِ', #2
u'الإنطاع': u'الْإِنْطَاعُ', #1
u'الأنطاكى': u'الأَنْطَاكِىُّ', #24
u'الأنطرطوسي': u'الأنطرطوسي', #1
u'الأنطفا': u'الأنطفا', #1
u'الأنظر': u'الْأَنْظَرُ', #13
u'الأنظر': u'الْأَنْظَرَ', #3
u'الأنظر': u'الْأَنْظَرِ', #8
u'الأنظرية': u'الْأَنْظَرِيَّةِ', #1
u'الأنعات': u'الْأَنْعَاتَ', #1
u'الأنعات': u'الْأَنْعَاتُ', #1
u'الإنعاظ': u'الإِنْعَاظُ', #1
u'الإنعاظ': u'الْإِنْعَاظِ', #14
u'الإنعاظ': u'الْإِنْعَاظُ', #4
u'الإنعاظ': u'الْإِنْعَاظَ', #7
u'الأنعمي': u'الْأَنْعُمِيُّ', #1
u'الإنفاج': u'الْإِنْفَاج', #1
u'الأنفاسا': u'الأَنْفَاسَا', #1
u'الإنفاع': u'الْإِنْفَاعُ', #1
u'الإنفاع': u'الْإِنْفَاعَ', #2
u'الإنفاقا': u'الْإِنْفَاقَا', #1
u'الانفتال': u'الِانْفِتَالُ', #1
u'الانفتال': u'الِانْفِتَالِ', #14
u'الانفتال': u'الِانْفِتَالَ', #6
u'الإنفحة': u'الْإِنْفَحَةُ', #19
u'الأنفحة': u'الأَنْفَحَةُ', #2
u'الإنفحة': u'الْإِنْفَحَةَ', #2
u'الإنفحة': u'الْإِنْفَحَة', #3
u'الإنفحة': u'الْإِنْفَحَةِ', #37
u'الانفراض': u'الِانْفِرَاضِ', #1
u'الأنفسية': u'الْأَنْفَسِيَّةُ', #2
u'الأنفسية': u'الْأَنْفَسِيَّةِ', #2
u'الإنفطار': u'الإنفطار', #1
u'الانفهام': u'الانفهام', #1
u'الأنقال': u'الْأَنْقَالَ', #3
u'الأنقال': u'الْأَنْقَالُ', #3
u'الأنقال': u'الْأَنْقَالِ', #6
u'الأنقر': u'الْأَنْقَرِ', #3
u'الأنقروي': u'الْأَنْقِرْوِيَّ', #1
u'الأنقروي': u'الْأَنْقِرْوِيّ', #122
u'الأنقروي': u'الْأَنْقِرَوِيُّ', #15
u'الأنقروي': u'الْأَنْقِرْوِيُّ', #306
u'الأنقروي': u'الْأَنْقِرْوِيِّ', #66
u'الأنقروية': u'الْأَنْقِرَوِيَّةِ', #1
u'الأنقص': u'الْأَنْقَصِ', #32
u'الأنقص': u'الْأَنْقَصُ', #6
u'الانقضا': u'الِانْقِضَا', #4
u'الأنقل': u'الْأَنْقَلُ', #1
u'الآنك،': u'الآنُكُ،', #1
u'الآنك': u'الْآنُك', #1
u'الآنك': u'الْآنُكُ', #24
u'الآنك': u'الآنُكُ', #3
u'الإنكاء': u'الْإِنْكَاءِ', #1
u'الإنكاء': u'الْإِنْكَاءُ', #3
u'الإنكارا': u'الْإِنْكَارَا', #2
u'الأنكب': u'الْأَنْكَبِ', #4
u'الأنكحة': u'الأَنْكِحَةِ', #1
u'الأنكحة': u'الْأَنْكِحَةِ', #194
u'الأنكحة': u'الْأَنْكِحَةَ', #22
u'الأنكحة': u'الْأَنْكِحَةُ', #36
u'الإنكشارية': u'الإنكشارية', #3
u'الأنكوري': u'الْأَنْكُورِيُّ', #1
u'الأنماري': u'الأَنْمَارِيّ', #1
u'الأنماري،': u'الأَنْمَارِيِّ،', #1
u'الأنماري': u'الْأَنْمَارِيِّ', #16
u'الأنماري': u'الأَنْمَارِيَّ', #2
u'الأنماري': u'الْأَنْمَارِيَّ', #2
u'الأنماري': u'الْأَنْمَارِيُّ', #4
u'الأنماري': u'الأنماري', #5
u'الأنماري': u'الأَنْمَارِيِّ', #5
u'الأنمارى': u'الأَنْمَارِىِّ', #5
u'الأنماطي': u'الْأَنْمَاطِيِّ', #11
u'الأنماطي،': u'الأَنْمَاطِيُّ،', #13
u'الأنماطي': u'الْأَنْمَاطِيُّ', #14
u'الأنماطى': u'الأَنْمَاطِىُّ', #16
u'الأنماطي،': u'الأَنْمَاطِيِّ،', #2
u'الانمساح': u'الِانْمِسَاحُ', #6
u'الانمساس': u'الِانْمِسَاسِ', #1
u'الأنميان': u'الْأَنْمَيَانِ', #1
u'الإنهاش': u'الْإِنْهَاشُ', #1
u'الأنهج': u'الْأَنْهَجُ', #2
u'الانهزامة': u'الِانْهِزَامَةَ', #1
u'الأنهى': u'الْأَنْهَى', #2
u'الأنواط': u'الْأَنْوَاطِ', #1
u'الأنوثه': u'الْأُنُوثَهْ', #1
u'الإنى': u'الْإِنَى', #1
u'الإنيارجات': u'الإنيارجات', #1
u'الأنيال': u'الْأَنْيَالِ', #1
u'الإنية': u'الْإِنِّيَّةُ', #1
u'الأنيح': u'الْأَنِيحِ', #1
u'إلاها': u'إلَاهًا', #1
u'إلاها': u'إِلَاهًا', #1
u'الإهابين': u'الْإِهَابَيْنِ', #1
u'الإهالة': u'الْإِهَالَةَ', #1
u'الإهالة': u'الْإِهَالَةُ', #5
u'الإهالة': u'الْإِهَالَةِ', #6
u'الاهتضام': u'الِاهْتِضَامُ', #2
u'الأهثم': u'الْأَهْثَمِ', #2
u'الإهجيرا': u'الْإِهْجِيرَا', #1
u'الأهدر': u'الْأَهْدَرُ', #1
u'الأهذلي': u'الْأَهْذَلِيِّ', #3
u'الأهلب': u'الأهلب', #1
u'الأهله': u'الْأَهِلّهْ', #1
u'الأهلوالوجه': u'الأَهْلِوَالْوَجْهُ', #1
u'الآهلي': u'الآهلي', #1
u'الآهلي': u'الآهِلِيِّ', #1
u'الأهلى': u'الأَهْلِىُّ', #3
u'الأهلى': u'الأَهْلِىِّ', #3
u'الإهليلج': u'الْإِهْلِيلِجِ', #1
u'الإهليلج': u'الْإِهْلِيلَجِ', #3
u'الإهليلجة': u'الْإِهْلِيلِجَةَ', #1
u'الإهليلجة': u'الْإِهْلِيلِجَةُ', #1
u'الأهليه': u'الْأَهْلِيَّهْ', #1
u'الأهواد': u'الأهواد', #1
u'الأهوازى': u'الأَهْوَازِىِّ', #1
u'الأهوازى': u'الأَهْوَازِىُّ', #25
u'الأهوز،': u'الأَهْوَزَ،', #1
u'الأهوزاني': u'الأهوزاني', #1
u'الأهوية': u'الْأَهْوِيَةِ', #16
u'الأهوية': u'الْأَهْوِيَةُ', #2
u'إلاهي': u'إِلَاهِي', #1
u'الأوابق': u'الْأَوَابِقِ', #1
u'الأوارترقي': u'الْأَوَارْتَرَقِّي', #1
u'الأوارك': u'الْأَوَارِكِ', #6
u'الأواشح': u'الْأَوَاشِحْ', #2
u'الأواغي': u'الْأَوَاغِي', #3
u'الأواق': u'الأَوَاقِ', #2
u'الأوام': u'الْأُوَامَ', #1
u'ألاوإن': u'أَلَاوَإِنَّ', #1
u'الأوانى': u'الأَوَانِى', #4
u'الأواهالحفيظ،': u'الأَوَّاهُالْحَفِيظُ،', #1
u'الأواهالذي': u'الأَوَّاهُالَّذِي', #1
u'الأواهالموقن': u'الأَوَّاهُالْمُوقِنُ', #2
u'الأوباء': u'الْأَوْبَاءِ', #1
u'الأوجبية': u'الأوجبية', #1
u'الأوجزية': u'الْأَوْجَزِيَّةُ', #1
u'الأوجع': u'الْأَوْجَعُ', #2
u'الأوجلي': u'الْأَوْجَلِيُّ', #2
u'الأوجهية': u'الْأَوْجَهِيَّةِ', #3
u'الأوجهية': u'الْأَوْجَهِيَّةَ', #4
u'الأوحدي': u'الْأَوْحَدِيِّ', #1
u'الأوداء': u'الْأَوِدَّاءِ', #3
u'الأودة': u'الْأَوَدَةَ', #2
u'الأودني': u'الْأَوْدَنِيِّ', #1
u'الأودني': u'الْأَوْدَنِيُّ', #3
u'الأودى': u'الأَوْدِىَّ', #2
u'الأودى': u'الأَوْدِىُّ', #30
u'الأودى': u'الأَوْدِىِّ', #33
u'الأورطة': u'الأورطة', #1
u'الأورع': u'الْأَوْرَعِ', #39
u'الأورع': u'الْأَوْرَعُ', #43
u'الأورع': u'الْأَوْرَعَ', #6
u'الأوز': u'الْأَوِزِّ', #3
u'الأوزاع': u'الْأَوْزَاعُ', #1
u'الأوزاع': u'الْأَوْزَاعِ', #2
u'الأوزاعي': u'الأوزاعيّ', #1
u'الأوزاعي': u'الْأَوْزاعِيِّ', #1
u'الأوزاعي': u'الأَوْزَاعِيّ', #1
u'الأوزاعي': u'الْأَوْزَاعِّيُّ', #1
u'الأوزاعي،': u'الْأَوْزَاعِيَّ،', #1
u'الأوزاعى': u'الْأَوْزَاعِىُّ', #1
u'الاوزاعي': u'الاوزاعي', #1
u'الأوزاعي،': u'الأَوْزَاعِيُّ،', #178
u'الأوزاعي،': u'الأَوْزَاعِيِّ،', #181
u'الأوزاعي،': u'الأَوْزَاعِيَّ،', #19
u'الأوزاعى': u'الأَوْزَاعِىِّ', #222
u'الأوزاعى': u'الأَوْزَاعِىُّ', #256
u'الأوزاعي؟': u'الأَوْزَاعِيِّ؟', #3
u'الأوزاعي،': u'الْأَوْزَاعِيِّ،', #3
u'الأوزاعي': u'الأوزاعي', #33
u'الأوزاعي': u'الْأَوْزَاعِيِّ', #365
u'الأوزاعي': u'الْأَوْزَاعِيُّ', #386
u'الأوزاعي،': u'الأوزاعي،', #4
u'الأوزاعي': u'الأَوْزَاعِيُّ', #40
u'الأوزاعي': u'الْأَوْزَاعِيَّ', #40
u'الأوزاعى': u'الأَوْزَاعِىَّ', #48
u'الأوزاعي': u'الْأَوْزَاعِيّ', #5
u'الأوزاعي،': u'الْأَوْزَاعِيُّ،', #5
u'الأوزاعي': u'الأَوْزَاعِيَّ', #6
u'الأوزاعي': u'الأَوْزَاعِيِّ', #66
u'الأوزاعيخرج': u'الأَوْزَاعِيِّخَرَجَ', #1
u'الأوزاعي،في': u'الأَوْزَاعِيِّ،فِي', #2
u'الأوزجندي': u'الْأُوزْجَنْدِيّ', #12
u'الأوزجندي': u'الأوزجندي', #2
u'الأوزجندي': u'الْأُوزَجَنْدِيِّ', #2
u'الأوزجندي': u'الْأُوزَجَنْدِيُّ', #3
u'الأوزجندي': u'الْأُوزْجَنْدِيِّ', #37
u'الأوزجندي': u'الْأُوزْجَنْدِيُّ', #53
u'الأوزجندية': u'الْأُوزْجَنْديَّةِ', #1
u'الأوزغ': u'الْأَوْزُغِ', #1
u'الأوزنية': u'الْأَوْزَنِيَّةِ', #1
u'الأوسال': u'الْأَوْسَالِ', #1
u'الأوسعية': u'الْأَوْسَعِيَّةَ', #1
u'الأوسعية': u'الْأَوْسَعِيَّةِ', #1
u'الأوسق': u'الأَوْسُقَ', #1
u'الأوسق،': u'الأَوْسُقَ،', #1
u'الأوسق': u'الْأَوْسُقُ', #14
u'الأوسق': u'الأَوْسُقِ', #4
u'الأوسق': u'الْأَوْسُقِ', #62
u'الأوسق': u'الْأَوْسُقَ', #7
u'الأوسي': u'الأوسيّ', #1
u'الأوسي،': u'الأوسي،', #1
u'الأوسي': u'الأوْسيّ', #1
u'الأوسي': u'الَأوْسيّ', #1
u'الأوسي،': u'الْأَوْسِيُّ،', #1
u'الأوسي': u'الْأَوْسِيُّ', #11
u'الأوسى': u'الأَوْسِىِّ', #2
u'الأوسي': u'الأَوْسِيِّ', #3
u'الأوسي': u'الأوسي', #4
u'الأوسي': u'الأَوْسِيُّ', #4
u'الأوسي': u'الْأَوْسِيَّ', #6
u'الأوسي': u'الْأَوْسِيِّ', #6
u'الأوصابي': u'الأَوْصَابِيُّ', #1
u'الأوصابي،': u'الأَوْصَابِيُّ،', #1
u'الأوصابية': u'الأَوْصَابِيَّةُ', #2
u'الأوضار': u'الْأَوْضَارِ', #1
u'الأوضحية': u'الْأَوْضَحِيَّةَ', #1
u'الأوضحية': u'الْأَوْضَحِيَّةُ', #1
u'الأوضحية': u'الْأَوْضَحِيَّةِ', #2
u'الأوضية': u'الْأَوْضِيَةُ', #2
u'الأوضية': u'الْأَوْضِيَةَ', #4
u'الأوضية': u'الْأَوْضِيَةِ', #5
u'الأوطاء': u'الْأَوْطَاءَ', #1
u'الأوطاء': u'الْأَوْطَاءُ', #1
u'الأوطئة': u'الأَوْطِئَةِ', #1
u'الأوطئة': u'الْأَوْطِئَةِ', #1
u'الأوغاء': u'الْأَوْغَاءُ', #1
u'الأوغار': u'الْأَوْغَارِ', #2
u'الأوفاض': u'الأَوْفَاضِ', #1
u'الأوفاض': u'الْأَوْفَاضُ', #2
u'الأوفاض': u'الْأَوْفَاضِ', #2
u'الأوفاق': u'الْأَوْفَاقِ', #1
u'الأوفاق': u'الْأَوْفَاقُ', #4
u'الأوفران': u'الْأَوْفَرَانِ', #1
u'الأوق': u'الْأَوْقِ', #3
u'الأوقاتكصلاة': u'الْأَوْقَاتِكَصَلَاةِ', #1
u'الأوقاس': u'الأَوْقَاسُ', #1
u'الأوقاص': u'الأَوْقَاصُ', #1
u'الأوقاص': u'الأَوْقَاصِ', #2
u'الأوقاص': u'الْأَوْقَاصَ', #24
u'الأوقاص': u'الْأَوْقَاصِ', #31
u'الأوقاص': u'الْأَوْقَاصُ', #8
u'الأوقة': u'الْأُوقَةَ', #1
u'الأوقص': u'الْأَوْقَصُ', #1
u'الأوقص': u'الْأَوْقَصِ', #11
u'الأوقص': u'الأوقص', #2
u'الأوقص': u'الأَوْقَصِ', #3
u'الأوقعية': u'الْأَوْقَعِيَّةِ', #1
u'الأوقيانوس': u'الْأَوْقَيَانُوسِ', #1
u'الإوقيانوس': u'الإوقيانوس', #1
u'الأوقيانوس': u'الْأُوقْيَانُوسِ', #3
u'الأوكد': u'الْأَوْكَدَ', #1
u'الأوكد': u'الْأَوْكَدُ', #1
u'الأوكد': u'الْأَوْكَدِ', #8
u'الأوكية': u'الْأَوْكِيَةُ', #1
u'الاول': u'الاول', #1
u'الأولا': u'الْأَوَّلَا', #5
u'الأولاج': u'الْأَوْلَاجَ', #1
u'الأولاج': u'الْأَوْلَاجُ', #2
u'الأولاج': u'الْأَوْلَاجِ', #3
u'الإولاد': u'الْإِوْلَادِ', #1
u'الأولادأن': u'الأَوْلاَدِأَنَّ', #1
u'الأولادأيرققن': u'الأَوْلاَدِأَيُرْقَقْنَ', #1
u'الأولادية': u'الْأَوْلَادِيَّةِ', #1
u'الأولاسي': u'الْأَوْلَاسِيُّ', #1
u'الأولة': u'الْأُولَةِ', #1
u'الأولة': u'الْأَوِّلَةَ', #1
u'الأولة': u'الْأَوِّلَةُ', #1
u'الأولة': u'الْأَوْلَةُ', #1
u'الأولة': u'الْأَوْلَةِ', #1
u'الأولة': u'الْأَوَّلَةِ', #10
u'الأولة': u'الْأَوِّلَةِ', #19
u'الأولة': u'الْأُولَةَ', #2
u'الأولة': u'الْأَوَّلَةَ', #2
u'الأولتان': u'الْأَوَّلَتَانِ', #1
u'الأولتان': u'الْأُولَتَانِ', #13
u'الأولتين': u'الأولتين', #1
u'الأولتين': u'الأُولَتَيْنِ', #1
u'الأولتين': u'الْأُوَلَتَيْنِ', #1
u'الأولتين': u'الْأُولَتَيْنِ', #121
u'الأولتين': u'الْأَوَّلَتَيْنِ', #5
u'الأولتين': u'الْأَوِّلَتَيْنِ', #8
u'الأوله': u'الْأَوَّلَهْ', #6
u'الاولى': u'الاولى', #1
u'الأولى': u'الْأُولًى', #20
u'الأوليء': u'الأُولَيء', #1
u'الأوليا': u'الْأُولَيَا', #1
u'الأوليا': u'الْأَوْلِيَا', #1
u'الأولينا': u'الْأَوّلِينَا', #2
u'الأوهن': u'الْأَوْهَنُ', #1
u'الأويس،': u'الأُوَيْسُ،', #1
u'الأويس،': u'الأُوَيْسُّ،', #1
u'الأويسي،': u'الأُوَيْسِيِّ،', #1
u'الأويسي': u'الْأُوَيْسِيَّ', #1
u'الأويسي': u'الْأُوَيْسِيِّ', #1
u'الأويسي': u'الْأُوَيْسِيُّ', #11
u'الأويسى': u'الأُوَيْسِىِّ', #13
u'الأويسى': u'الأُوَيْسِىُّ', #16
u'الأويسي،': u'الأُوَيْسِيُّ،', #28
u'الأويسي': u'الأُوَيْسِيُّ', #3
u'الآى': u'الآىِ', #1
u'الأي': u'الْأَيْ', #1
u'الآى': u'الآىَ', #5
u'الإئتدام': u'الإئتدام', #1
u'الائتدام': u'الِائْتِدَامَ', #1
u'الائتدام': u'الِائْتِدَامُ', #1
u'الائتدام': u'الِائْتِدَامِ', #1
u'الائتزاز': u'الِائْتِزَازُ', #1
u'الائتساء': u'الِائْتِسَاءِ', #4
u'الائتفاكة': u'الائْتِفَاكَةُ', #4
u'الائتمام': u'الائْتِمَامِ', #2
u'الائتمام': u'الِائْتِمَام', #4
u'الائتمام': u'الِائْتِمَامَ', #45
u'الائتمام': u'الِائْتِمَامُ', #52
u'الائتمام': u'الِائْتِمَامِ', #65
u'الآئمة': u'الْآئِمَةَ', #1
u'الآئمة': u'الْآئِمَةِ', #2
u'الأئمه': u'الْأَئِمَّهْ', #1
u'الأئمه': u'الْأَئِّمَهْ', #1
u'الأيا': u'الْأَيّا', #1
u'الإيا': u'الْإِيَا', #4
u'الإياد': u'الْإِيَادِ', #2
u'الإيادي': u'الإِيَادِيُّ', #1
u'الإيادي': u'الْإِيَادِيَّ', #1
u'الإيادي،': u'الْإِيَادِيُّ،', #1
u'الإيادي،': u'الْإِيَادِيِّ،', #1
u'الإيادي': u'الْإِيَادِيّ', #11
u'الإيادى': u'الإِيَادِىُّ', #16
u'الإيادي': u'الإِيَادِيَّ', #2
u'الإيادي،': u'الإِيَادِيِّ،', #29
u'الإيادي': u'الْإِيَادِيُّ', #5
u'الإيادي': u'الْإِيَادِيِّ', #5
u'الإيادى': u'الإِيَادِىِّ', #5
u'الإيادية': u'الْإِيَادِيّة', #1
u'الإياس': u'الإِيَاسِ', #1
u'الإياس': u'الْإِيَاس', #1
u'الإياس': u'الْإِيَاسِ', #167
u'الإياس': u'الْإِيَاسَ', #35
u'الإياس': u'الْإِيَاسُ', #44
u'الإياسي': u'الْإِيَاسِيِّ', #1
u'الإيام': u'الْإِيَامِ', #3
u'الأيامي': u'الْأَيَامِيّ', #1
u'الأيامي': u'الْأَيَامِيَّ', #1
u'الأيامي': u'الْأَيَامِيِّ', #1
u'الإيامي،': u'الإيامي،', #1
u'الإيامي': u'الإِيَامِيِّ', #1
u'الإيامي': u'الْإِيَامِيَّ', #1
u'الإيامي': u'الْإِيَامِيُّ', #1
u'الإيامي،': u'الْإِيَامِيَّ،', #1
u'الأيامي،': u'الأَيَامِيِّ،', #2
u'الإيامي،': u'الإِيَامِيَّ،', #2
u'الإيامى': u'الإِيَامِىُّ', #2
u'الإيامى': u'الإِيَامِىِّ', #2
u'الإيامي': u'الْإِيَامِيِّ', #6
u'الآيب': u'الْآيِبُ', #1
u'الإيبا': u'الْإِيبَا', #1
u'الآيةأهي': u'الآيةأهي', #1
u'الآيةتدني': u'الْآيَةِتُدْنَي', #1
u'الآيةوالوجه': u'الآيَةِوَالْوَجْهُ', #1
u'الآيةيا': u'الآيَةَيَا', #1
u'الإيتان': u'الْإِيتَانِ', #2
u'الإيجادية': u'الْإِيجَادِيَّةُ', #1
u'الإيجارة': u'الْإِيجَارَةُ', #1
u'الإيجارة': u'الْإِيجَارَةِ', #3
u'الإيحار': u'الْإِيحَارِ', #1
u'الأيد': u'الأَيِّدُ', #1
u'الأيد': u'الْأَيِّدِ', #1
u'الأيد': u'الْأَيْدَ', #2
u'الأيد': u'الْأَيْدِ', #9
u'الأيدى': u'الأَيْدِى', #11
u'الإيذجي،': u'الإِيذَجِيُّ،', #1
u'الأيزم': u'الْأَيْزَمُ', #1
u'الآيس': u'الْآيِسُ', #3
u'الآيس': u'الْآيِسَ', #4
u'الآيس': u'الْآيِسِ', #7
u'الآيسات': u'الْآيِسَاتِ', #10
u'الآيسات': u'الْآيِسَاتُ', #2
u'الآيسة': u'الْآيِسَةِ', #119
u'الأيسة': u'الْأَيِسَةِ', #2
u'الآيسة': u'الْآيِسَةَ', #21
u'الآيسة': u'الْآيِسَةُ', #47
u'الأيسرون': u'الأَيْسَرُونَ', #2
u'الآيسين': u'الآيسين', #1
u'الآيسين': u'الْآيِسِينَ', #9
u'الإيصا': u'الْإِيصَا', #1
u'الأيض': u'الْأَيْضُ', #1
u'الأيضية': u'الْأَيْضِيَّةَ', #1
u'إلايعلمها': u'إلايعلمها', #1
u'الأيفع': u'الأيفع', #1
u'الأيفع': u'الأَيْفَعُ', #1
u'الأيفع': u'الْأَيْفَعُ', #1
u'الإيقاء': u'الْإِيقَاءُ', #1
u'الإيكاء': u'الْإِيكَاء', #2
u'الإيكاف': u'الْإِيكَافُ', #2
u'الإيكاف': u'الْإِيكَافِ', #6
u'الآيل': u'الْآيِلِ', #19
u'الآيل': u'الْآيِلُ', #3
u'الآيل': u'الْآيِلَ', #7
u'الإيلا': u'الْإِيَلَا', #1
u'الإيلا': u'الْإِيَّلَا', #7
u'الإيلاقي': u'الْإِيلَاقِيِّ', #1
u'الآيلة': u'الْآيِلَة', #1
u'الأيلة': u'الأَيْلَةِ', #1
u'الأيلة': u'الَأَيْلَةِ', #1
u'الأيلة': u'الْأَيْلَةِ', #1
u'الآيلة': u'الْآيِلَةُ', #2
u'الآيلة': u'الْآيِلَةِ', #4
u'الأيلهي': u'الْأَيْلَهِيُّ', #1
u'الأيلولة': u'الْأَيْلُولَةُ', #3
u'الأيلولة': u'الْأَيْلُولَةِ', #6
u'الأيلى': u'الأَيَلِىُّ', #1
u'الأيلى': u'الأَيْلِىَّ', #1
u'الأيلى': u'الْأَيْلِىُّ', #1
u'الإيلي،': u'الإِيلِيُّ،', #1
u'الإيلي،': u'الإِيَلِيُّ،', #1
u'الإيلي،': u'الإِيْلِيُّ،', #1
u'الأيلى': u'الأَيْلِىُّ', #160
u'الأيلى': u'الأَيْلِىِّ', #29
u'الإيلياء': u'الْإِيلِيَاءُ', #1
u'الإيمانقوله': u'الإِيمَانَقَوْلُهُ', #1
u'الأينيسون': u'الْأَيْنِيسُونَ', #1
u'الآيه': u'الآيه', #1
u'الأيه': u'الأيه', #1
u'الأيهقان': u'الْأَيْهَقَانِ', #1
u'إلب': u'إلْبٌ', #1
u'الب': u'الْب', #1
u'الب': u'الْبَ', #3
u'إلبا': u'إلْبًا', #1
u'إلبا': u'إِلْبًا', #2
u'البأ': u'الْبَأْ', #4
u'البابة': u'الْبَابَةِ', #1
u'البابرتي': u'الْبَابَرْتِيُّ', #1
u'البابسي': u'الْبَابَسِيِّ', #1
u'البابسيرى': u'الْبَابْسِيرِىُّ', #1
u'البابلتى': u'الْبَابْلُتِّىُّ', #1
u'البابلتي': u'الْبَابْلُتِّيُّ', #2
u'البابلتي،': u'الْبَابْلُتِّيُّ،', #5
u'الباجربقي': u'الْبَاجِرْبَقِيُّ', #2
u'الباجوري': u'الْبَاجُورِيُّ', #27
u'الباجوري': u'الْبَاجُورِيِّ', #3
u'الباجوري': u'الْبَاجُورِيّ', #4
u'الباد': u'الْبَادّ', #3
u'البادرائي': u'الْبَادَرَائِيُّ', #1
u'البادشي': u'الْبَادِشِيُّ', #1
u'البادهنجات': u'البادهنجات', #1
u'البادى': u'الْبَادِى', #2
u'الباديه': u'الْبَادِيَهْ', #1
u'الباذروج': u'الْبَاذَرُوجِ', #1
u'الباذش': u'الْبَاذِشِ', #1
u'الباذق': u'الْبَاذَقَ', #18
u'الباذق': u'الْبَاذَقِ', #19
u'الباذق': u'الْبَاذَق', #2
u'الباذق': u'الْبَاذَقُ', #22
u'الباذنجانة': u'الْبَاذِنْجَانَةِ', #2
u'الباذهنج': u'الْبَاذَهْنَجُ', #3
u'البارده': u'الْبَارِدَهْ', #1
u'البارزي': u'الْبَارِزِيُ', #1
u'البارزي': u'الْبَارِزِيُّ', #221
u'البارزي': u'الْبَارِزِيّ', #5
u'البارزي': u'الْبَارِزِيِّ', #57
u'البارزي': u'الْبَارِزِيَّ', #6
u'البارزية': u'الْبَارِزِيَّةِ', #1
u'البارقي': u'الْبَارِقِيّ', #1
u'البارقي،': u'الْبَارِقِيَّ،', #1
u'البارقي،': u'الْبَارِقِيُّ،', #1
u'البارقى': u'الْبَارِقِى', #1
u'البارقي': u'الْبَارِقِيَّ', #16
u'البارقى': u'الْبَارِقِىِّ', #17
u'البارقي': u'الْبَارِقِيُّ', #19
u'البارقي': u'البارقي', #2
u'البارقى': u'الْبَارِقِىَّ', #2
u'البارقى': u'الْبَارِقِىُّ', #2
u'البارقي': u'الْبَارِقِيِّ', #57
u'البارقي،': u'الْبَارِقِيِّ،', #6
u'البارقية': u'الْبَارِقِيّةُ', #2
u'البارىء': u'الْبَارِىءُ', #1
u'البآزر،': u'الْبَآزِرُ،', #1
u'البازري': u'الْبَازِرِيِّ', #4
u'البازري': u'الْبَازِرِيُّ', #6
u'البازى': u'الْبَازِى', #4
u'البازيار': u'البازيار', #1
u'الباس': u'الْبَاس', #1
u'الباس': u'الْبَاسُ', #2
u'الباس': u'الْبَاسِّ', #2
u'الباس': u'الْبَاسْ', #2
u'الباس': u'الْبَاسَ', #37
u'البأساءالفقر': u'الْبَأْسَاءُالْفَقْرُ', #1
u'الباساتي': u'الْبَاسَاتِيُّ', #1
u'الباسة': u'الْبَاسّةُ', #1
u'الباسة': u'الْبَاسَّةُ', #1
u'البأسوالوجه': u'الْبَأْسِوَالْوَجْهُ', #1
u'الباشاني،': u'الْبَاشَانِيِّ،', #1
u'الباشاني،': u'الْبَاشَانِيُّ،', #2
u'الباشانى': u'الْبَاشَانِىُّ', #8
u'الباشاه': u'الباشاه', #1
u'الباشاه': u'الْبَاشَاهْ', #1
u'الباشية': u'الْبَاشِيَّةِ', #1
u'الباطرقاني': u'الْبَاطِرْقَانِيُّ', #2
u'الباطلالوجه': u'الْبَاطِلِالْوَجْهُ', #1
u'الباطلون': u'الْبَاطِلُونَ', #1
u'الباعات': u'الْبَاعَاتِ', #2
u'الباعوني': u'الْبَاعُونِيُّ', #3
u'الباغ': u'الْبَاغُّ', #1
u'الباغ': u'الْبَاغِ', #4
u'الباغندي،': u'الْبَاغَنْدِيِّ،', #1
u'الباغندي': u'الْبَاغَنْدِيَّ', #2
u'الباغندى': u'الْبَاغَنْدِىُّ', #25
u'الباغندي': u'الْبَاغَنْدِيِّ', #3
u'الباغندي،': u'الْبَاغَنْدِيُّ،', #3
u'الباغندى': u'الْبَاغَنْدِىِّ', #3
u'الباغندي': u'الْبَاغَنْدِيُّ', #9
u'الباغى': u'الْبَاغِى', #1
u'الباغى': u'الْبَاغِىَ', #1
u'الباقاني': u'الْبَاقَانِيِّ', #19
u'الباقاني': u'الْبَاقَانِيُّ', #77
u'الباقرحى': u'الْبَاقَرْحَىُّ', #1
u'الباقرحى': u'الْبَاقَرْحِىُّ', #3
u'الباقلا': u'الْبَاقِلَا', #17
u'الباقلا': u'الْبَاقِلَّا', #36
u'الباقلاني': u'الْبَاقِلَّانِيَّ', #1
u'الباقلانى': u'الْبَاقِلاَنِىُّ', #1
u'الباقلاني': u'الْبَاقِلَّانِيُّ', #61
u'الباقلاني': u'الْبَاقِلَّانِيِّ', #63
u'الباقلائتين': u'الْبَاقِلَائِتَيْن', #1
u'الباقلائي': u'الْبَاقِلَّائِيِّ', #1
u'الباقلائيين': u'الباقلائيين', #1
u'الباقلتين': u'الْبَاقِلَّتَيْنِ', #1
u'الباقلى': u'الْبَاقِلَّى', #1
u'الباقورة': u'الْبَاقُورَةُ', #5
u'الباقورة': u'الْبَاقُورَةِ', #7
u'الباقورة': u'الْبَاقُورَةَ', #8
u'الباقى': u'الباقى', #1
u'الباقى': u'الْبَاقِىَ', #15
u'الباقى': u'الْبَاقِى', #35
u'الباقيا': u'الْبَاقِيَا', #1
u'الباقيه': u'الْبَاقِيَهْ', #1
u'الباكيا': u'الْبَاكِيَا', #2
u'البالسي،': u'البالسي،', #1
u'البالسي،': u'الْبَالِسِيِّ،', #1
u'البالسي': u'الْبَالِسِيَّ', #2
u'البالسي': u'الْبَالِسِيُّ', #21
u'البالسى': u'الْبَالِسِىُّ', #3
u'البالسي': u'الْبَالِسِيِّ', #4
u'البالسي،': u'الْبَالِسِيُّ،', #4
u'البالصوتي': u'الْبَالُصُوتِيُّ', #1
u'البالوع': u'الْبَالُوعَ', #1
u'البالوع': u'الْبَالُوعِ', #7
u'البالى': u'البالى', #8
u'البانكنوط': u'البانكنوط', #1
u'البانياسي': u'البانياسي', #1
u'الباه': u'الْبَاهَ', #14
u'الباه': u'الْبَاهِ', #19
u'الباه': u'الْبَاهُ', #2
u'الباهشين': u'الْبَاهِشِينَ', #1
u'الباهل': u'الباهل', #1
u'الباهل': u'الْبَاهِلُ', #1
u'الباهلة': u'الْبَاهِلَةُ', #1
u'الباهلة': u'الْبَاهِلَةِ', #1
u'الباهلي': u'الباهليّ', #1
u'الباهلي،': u'الْبَاهليُّ،', #1
u'الباهلي': u'الْبَاهِلِيّ', #11
u'الباهلي،': u'الْبَاهِلِيِّ،', #12
u'الباهلي': u'الباهلي', #15
u'الباهلي': u'الْبَاهِلِيَّ', #18
u'الباهلى': u'الْبَاهِلِىِّ', #20
u'الباهلي،': u'الْبَاهِلِيَّ،', #3
u'الباهلي،': u'الْبَاهِلِيُّ،', #37
u'الباهلى': u'الْبَاهِلِىُّ', #39
u'الباهلي،': u'الباهلي،', #4
u'الباهلى': u'الْبَاهِلِىَّ', #4
u'الباهلي': u'الْبَاهِلِيُّ', #64
u'الباهلي': u'الْبَاهِلِيِّ', #72
u'الباهلية': u'الْبَاهِلِيَّةِ', #1
u'الباهليون': u'الْبَاهِلِيُّونَ', #1
u'البائع': u'الْبَائِعً', #2
u'البائعه': u'الْبَائِعَهُ', #1
u'البائعه': u'الْبَائِعُهُ', #3
u'البائعية': u'الْبَائِعِيَّةِ', #1
u'البائغ': u'الْبَائِغُ', #1
u'البائنا': u'الْبَائِنَا', #2
u'البائئة': u'الْبَائِئَةِ', #1
u'البايزيدية': u'الْبَايَزِيدِيَّةِ', #1
u'الببغا': u'الْبَبَغَا', #1
u'الببغا': u'الْبَبَّغَا', #1
u'البتانى': u'الْبُتَانِىُّ', #1
u'البتح': u'البتح', #1
u'البترندي': u'الْبَتْرَنْدِيِّ', #1
u'البتع': u'الْبِتَعُ', #1
u'البتع': u'الْبِتْعَ', #1
u'البتع،': u'الْبِتْعَ،', #1
u'البتع': u'الْبِتْع', #2
u'البتع': u'الْبِتْعُ', #23
u'البتع': u'الْبِتْعِ', #24
u'البتع': u'البتع', #5
u'البتع،': u'الْبِتْعُ،', #5
u'البتع،': u'الْبِتْعِ،', #5
u'البتلة': u'البتلة', #1
u'البتلة': u'الْبَتْلَةُ', #3
u'البته': u'الْبَتَّهْ', #5
u'البتي،': u'الْبَتِّيُّ،', #1
u'البتي،': u'الْبَتِّيِّ،', #1
u'البتى': u'الْبَتِّى', #1
u'البتى': u'الْبَتِّىُّ', #1
u'البتي': u'الْبَتّيّ', #2
u'البتي': u'الْبَتِّيِّ', #24
u'البتي': u'الْبَتِّيُّ', #30
u'البتي': u'الْبَتِّيَّ', #4
u'البتير': u'الْبَتِيرِ', #1
u'البتيراء': u'الْبُتَيْرَاءُ', #15
u'البتيراء': u'الْبُتَيْرَاءِ', #22
u'البتيراء': u'الْبُتَيْرَاءَ', #5
u'البثراء': u'الْبَثْرَاءِ', #1
u'البثرات': u'الْبَثَرَاتِ', #19
u'البثرة': u'الْبَثْرَةُ', #1
u'البثرة': u'الْبَثْرَةِ', #11
u'البثرة': u'الْبَثْرَةَ', #2
u'البثق': u'الْبَثْقُ', #3
u'البثق': u'الْبَثْقِ', #5
u'البثنية': u'البَثْنِيَّةِ', #1
u'البثوق': u'الْبُثُوقُ', #1
u'البثوق': u'الْبُثُوقِ', #5
u'البجات': u'الْبَجَّاتِ', #5
u'البجاد': u'الْبِجَادِ', #2
u'البجادين': u'البِجادَيْن', #1
u'البجادين': u'البِجَادَيْن', #1
u'البجادين': u'الْبِجَادَيْنِ', #17
u'البجاني': u'البجاني', #1
u'البجائيون': u'الْبِجَائِيُّونَ', #1
u'البجائيين': u'الْبَجَائِيِّينَ', #4
u'البجد': u'الْبُجُدَ', #1
u'البجلي': u'البَجليّ', #1
u'البجلي،': u'البَجَلي،', #1
u'البجلي': u'البَجَلِيُّ', #1
u'البجلي': u'البَجْلِيِّ', #1
u'البجلي': u'الْبَجْلِيِّ', #1
u'البجلى،': u'البجلى،', #1
u'البجلي': u'الْبَجَلِيَّ', #13
u'البجلي،': u'الْبَجَلِيِّ،', #14
u'البجلي': u'الْبَجْلِيُّ', #2
u'البجلى': u'الْبَجَلِىِّ', #21
u'البجلي،': u'الْبَجَلِيُّ،', #41
u'البجلى': u'الْبَجَلِىُّ', #48
u'البجلي': u'الْبَجَلِيّ', #6
u'البجلي': u'الْبَجَلِيُّ', #62
u'البجلي،': u'البجلي،', #7
u'البجلى': u'الْبَجَلِىَّ', #7
u'البجلي': u'الْبَجَلِيِّ', #71
u'البجلي': u'البجلي', #8
u'البجلية': u'الْبَجَلِيّةَ', #1
u'البجليين': u'الْبَجْلِيِّينَ', #1
u'البجليين': u'الْبَجَلِيِّينَ', #2
u'البجليين': u'الْبَجَلِيّينَ', #4
u'البجود': u'الْبُجُودُ', #4
u'البجير': u'البجير', #1
u'البجير': u'الْبُجَيْرِ', #1
u'البجيرمي': u'البجيرمي', #1
u'البجيرمي': u'الْبُجْيَرِمِيُّ', #1
u'البجيرمي': u'الْبُجَيْرِمِيُّّ', #10
u'البجيرمي': u'الْبُجَيْرَمِيِّ', #113
u'البجيرمي': u'الْبُجَيْرِمِيِّّ', #14
u'البجيرمي': u'الْبُجَيْرِمِيُّ', #170
u'البجيرمي': u'الْبُجَيْرِمِيَّ', #2
u'البجيرمي': u'الْبُجْيَرِمِيِّ', #2
u'البجيرمي': u'الْبُجَيْرَمِيُّ', #34
u'البجيرمي': u'الْبُجَيْرِمِيِّ', #369
u'البجيلة': u'الْبَجِيلَة', #1
u'البحادلة،': u'الْبَحَادِلَةِ،', #1
u'البحاري': u'الْبَحَّارِيَّ', #1
u'البحائر،': u'الْبَحَائِرُ،', #1
u'البحائر': u'الْبَحَائِرَ', #3
u'البحائر': u'الْبَحَائِرِ', #3
u'البحترى': u'الْبَحْتَرِىِّ', #1
u'البحرانى': u'الْبَحْرَانِىَّ', #2
u'البحرانى': u'الْبَحْرَانِىُّ', #4
u'البحرة': u'الْبَحْرَةُ', #2
u'البحرة': u'الْبَحْرَةِ', #2
u'البحروروي': u'الْبَحْرُوَرُوِيَ', #1
u'البحرى': u'الْبَحْرِىِّ', #1
u'البحرى': u'الْبَحْرِىُّ', #3
u'البحرينالوجه': u'الْبَحْرَيْنِالْوَجْهُ', #1
u'البحونة': u'الْبَحُونَةِ', #1
u'البحير': u'الْبُحَيْرِ', #1
u'البحيرى': u'الْبَحِيرِىُّ', #1
u'البخاتي': u'البخاتي', #1
u'البخاتي': u'الْبَخَاتِي', #1
u'البخاتى': u'الْبَخَاتَى', #1
u'البخاتي': u'الْبَخَاتِيِّ', #10
u'البخاتي': u'الْبَخَاتِيُّ', #2
u'البخاتي': u'الْبَخَاتِيَّ', #6
u'البخارى': u'الْبُخَارِى', #1
u'البخارى': u'الْبُخَارِىُّ', #3917
u'البخارى': u'الْبُخَارِىِّ', #46
u'البخارى': u'الْبُخَارِىَّ', #58
u'البخاريون': u'الْبُخَارِيُّونَ', #10
u'البخاع': u'الْبُخَاعَ', #1
u'البخاع': u'الْبِخَاعُ', #1
u'البختج': u'الْبُخْتُج', #1
u'البختج': u'الْبَخْتُجُ', #3
u'البخترى،': u'البخترى،', #1
u'البخترى': u'الْبَخْتَرِىُّ', #8
u'البخترى': u'الْبَخْتَرِىِّ', #88
u'البخراء': u'الْبَخْرَاءُ', #3
u'البخسة': u'الْبَخْسَةِ', #1
u'البخع': u'الْبَخْعُ', #1
u'البخية': u'الْبَخِّيَّةَ', #1
u'البخية': u'الْبَخِّيَّةُ', #1
u'البخية': u'الْبَخِّيَّةِ', #2
u'البخيلا': u'الْبَخِيلَا', #1
u'البدءة': u'الْبَدْءَةِ', #1
u'البداء': u'الْبَدَّاءِ', #1
u'البداء': u'الْبِدَاءَ', #1
u'البداء': u'الْبِدَاءُ', #1
u'البداء': u'الْبِدَاءِ', #1
u'البداء': u'الْبَدَاءِ', #19
u'البداء': u'الْبَدَاءُ', #8
u'البداء': u'الْبَدَاءَ', #9
u'البداح': u'الْبَدّاحِ', #2
u'البداح': u'الْبَدَّاحِ', #27
u'البداح،': u'الْبَدَّاحِ،', #5
u'البداد': u'الْبِدَادُ', #1
u'البدار': u'الْبَدَارُ', #1
u'البدار': u'الْبَدَارِ', #1
u'البدار': u'الْبَدَارْ', #1
u'البدار': u'الْبِدَارَ', #14
u'البدار': u'الْبِدَارِ', #14
u'البدار': u'الْبِدَارُ', #38
u'البدح': u'الْبِدْحَ', #1
u'البدخشاني': u'البدخشاني', #1
u'البدخشي': u'الْبُدَخْشِيِّ', #10
u'البدخشي': u'الْبُدَخْشِيُّ', #40
u'البدرة': u'الْبَدْرَةَ', #1
u'البدرة': u'الْبَدْرَةُ', #1
u'البدرى': u'الْبَدْرِىُّ', #5
u'البدرى': u'الْبَدْرِىِّ', #6
u'البدريون': u'الْبَدْرِيُّونَ', #2
u'البدعات': u'الْبِدْعَاتِ', #1
u'البدلا': u'الْبَدَلَا', #2
u'البدنقوله': u'الْبُدْنَقَوْلُهُ', #1
u'البدوى': u'الْبَدَوِىِّ', #1
u'البديء': u'الْبَدِيءُ', #1
u'البديء': u'الْبَدِيءِ', #1
u'البدئ': u'الْبَدِئ', #3
u'البدية': u'الْبَدِيَّةِ', #1
u'البديعي': u'الْبَدِيعِيُّ', #2
u'البديعي': u'الْبَدِيعِيِّ', #4
u'البديعيات': u'الْبَدِيعِيَّاتِ', #1
u'البديعية': u'الْبَدِيعِيَّة', #1
u'البديعية': u'الْبَدِيعِيَّةِ', #14
u'البديهات': u'الْبَدِيهَاتِ', #1
u'البذاذة': u'الْبَذَاذَة', #2
u'البذاذة': u'الْبَذَاذَةُ', #20
u'البذاذة': u'الْبَذَاذَةِ', #6
u'البذاذة': u'الْبَذَاذَةَ', #9
u'البذة': u'الْبَذَّةِ', #1
u'البذخين': u'الْبَذِخِينَ', #1
u'البذرقة': u'الْبَذْرَقَةِ', #15
u'البذشى': u'الْبَذَشِىُّ', #1
u'البذي': u'الْبَذِيِّ', #1
u'البذي': u'الْبَذِيَّ', #3
u'البذي': u'الْبَذِيُّ', #3
u'البذىء': u'الْبَذِىءَ', #1
u'البذىء': u'الْبَذِىءِ', #2
u'البذية': u'الْبَذِيَّةِ', #3
u'البذية': u'الْبَذِيَّةُ', #4
u'البرآء': u'الْبُرَآءَ', #3
u'البرآء': u'الْبُرَآءِ', #5
u'البرابط،': u'الْبَرَابِطَ،', #1
u'البرابط': u'الْبَرَابِطُ', #2
u'البرابط': u'الْبَرَابِطَ', #3
u'البرابط': u'الْبَرَابِطِ', #3
u'البرابي': u'الْبَرَابِي', #4
u'البراجم،': u'البراجم،', #1
u'البراجم،': u'الْبَرَاجِمِ،', #1
u'البراجم': u'الْبَرَاجِمَ', #10
u'البراجم': u'البراجم', #2
u'البراجم': u'الْبَرَاجِمِ', #26
u'البراجم': u'الْبَرَاجِم', #4
u'البرادعي': u'البرادعي', #1
u'البرادعي': u'الْبَرَادِعِيُّ', #10
u'البرادعي': u'الْبَرَادِعِيِّ', #17
u'البرادعي': u'الْبَرَادِعِيَّ', #3
u'البراذع': u'الْبَرَاذِعُ', #4
u'البراذعي': u'الْبَرَاذِعِيُّ', #10
u'البراذعي': u'الْبَرَاذِعِيِّ', #11
u'البراذعي': u'الْبَرَاذِعِيَّ', #2
u'البراض': u'الْبَرَّاضَ', #1
u'البراض': u'الْبَرَّاضُ', #1
u'البراض': u'الْبِرَاضِ', #1
u'البراض': u'الْبَرّاضَ', #2
u'البراض': u'الْبَرَّاضِ', #2
u'البراض': u'الْبَرّاضِ', #3
u'البراض': u'الْبَرّاضُ', #8
u'البراك': u'البُرَاك', #1
u'البراوات': u'الْبَرَاوَاتِ', #1
u'البراوي': u'الْبَرَّاوِيُّ', #2
u'البراوي': u'الْبَرَّاوِيِّ', #3
u'البرائد': u'الْبَرَائِدِ', #1
u'البرايب': u'الْبَرَايِبِ', #1
u'البراية،': u'الْبِرَايَةَ،', #1
u'البراية': u'الْبُرَايَةِ', #3
u'البرأين': u'البرأين', #1
u'البرباريس': u'البرباريس', #1
u'البربرى': u'الْبَرْبَرِىُّ', #1
u'البربط': u'الْبَرْبَطَ', #1
u'البربط': u'الْبَرْبَطُ', #3
u'البربط': u'الْبَرْبَطِ', #8
u'البربهاري': u'البربهاري', #1
u'البربهارى': u'الْبَرَبَهَارِىُّ', #1
u'البربهاري': u'الْبَرْبَهَارِيُّ', #10
u'البربهاري،': u'الْبَرْبَهَارِيُّ،', #2
u'البربهاري،': u'الْبَرْبَهَارِيِّ،', #2
u'البربهارى': u'الْبَرْبَهَارِىُّ', #35
u'البرتاب': u'الْبِرْتَابِ', #2
u'البرتال': u'البرتال', #1
u'البرتي': u'البرتي', #1
u'البرتي': u'الْبِرْتِيِّ', #1
u'البرتى': u'الْبِرْتِىَّ', #1
u'البرتي': u'الْبِرْتِيُّ', #14
u'البرتي،': u'الْبِرْتِيُّ،', #25
u'البرتي،': u'الْبِرْتِيِّ،', #3
u'البرتى': u'الْبِرْتِىِّ', #4
u'البرتى': u'الْبِرْتِىُّ', #44
u'البرتى': u'الْبَرْتِىُّ', #7
u'البرث': u'الْبَرْثِ', #2
u'البرجاس': u'الْبُرْجَاسِ', #1
u'البرجاني': u'الْبَرْجَانِيَّ', #1
u'البرجاني': u'الْبَرْجَانِيُّ', #1
u'البرجلانى': u'الْبَرْجَلاَنِىُّ', #1
u'البرجلانى': u'الْبَرْجُلاَنِىُّ', #1
u'البرجلاني،': u'الْبُرْجُلانِيُّ،', #2
u'البرجلانى': u'الْبُرْجُلاَنِىُّ', #2
u'البرجمة': u'الْبُرْجُمَةُ', #1
u'البرجمي،': u'البرجمي،', #1
u'البرجمي': u'الْبُرْجُمِيِّ', #1
u'البرجمى': u'الْبَرْجَمِىُّ', #1
u'البرجمى': u'الْبَرْجَمِىِّ', #1
u'البرجمى': u'الْبُرْجُمِىِّ', #1
u'البرجمي': u'الْبُرْجُمِيّ', #2
u'البرجمي': u'الْبُرْجُمِيُّ', #2
u'البرجمي،': u'الْبُرْجُمِيُّ،', #2
u'البرجندي': u'الْبُرْجَنْدِيِّ', #107
u'البرجندي': u'الْبُرْجَنْدِيُّ', #52
u'البرجيني': u'الْبَرْجِينِيُّ', #1
u'البرجيني': u'الْبَرْجِينِيِّ', #1
u'البرحاء': u'البرحاء', #1
u'البرحاء': u'الْبُرَحَاءَ', #1
u'البرحاء،': u'الْبُرَحَاءِ،', #1
u'البرحاء': u'الْبُرَحَاءُ', #2
u'البرحاء': u'الْبُرَحَاءِ', #7
u'البردات': u'الْبَرَدَات', #1
u'البرداد': u'الْبَرْدَادِ', #1
u'البردادي': u'الْبَرْدَادِيَّ', #1
u'البرداني': u'الْبَرَدَانِيُّ', #1
u'البرداني': u'الْبَرَدَانِيِّ', #1
u'البردروي': u'الْبَرْدَرْوِيَّ', #1
u'البردى': u'الْبَرْدِىِّ', #1
u'البرديجي': u'الْبَرْدِيجِيُّ', #1
u'البرديجي': u'الْبَرْدِيجِيِّ', #1
u'البرذعى': u'الْبَرْذَعِىُّ', #2
u'البرذوي': u'الْبَرْذَوِيِّ', #1
u'البرذوي': u'الْبَرْذَوِيُّ', #2
u'البرره': u'الْبَرَرَهْ', #1
u'البرز': u'الْبَرْزِ', #1
u'البرز': u'الْبَرْزُ', #2
u'البرزاطي': u'الْبَرْزَاطِيُّ', #1
u'البرزاطي': u'الْبَرْزَاطِيِّ', #1
u'البرزاطي': u'الْبُرْزَاطِيِّ', #1
u'البرزاطي': u'البرزاطي', #5
u'البرزالي': u'الْبِرْزَالِيُّ', #6
u'البرزلي': u'البرزلي', #1
u'البرزلي': u'الْبُرْزُلُيِّ', #1
u'البرزلي': u'الْبُرْزُلِيِّ', #161
u'البرزلي': u'الْبُرْزُلِيُّ', #237
u'البرزلي': u'الْبُرْزُلِيَّ', #5
u'البرزنة': u'الْبَرْزَنَةُ', #1
u'البرزنجري': u'الْبَرْزَنْجِرِيُّ', #1
u'البرزي': u'الْبَرْزِيِّ', #2
u'البرزي': u'الْبَرَزِيِّ', #5
u'البرس': u'الْبُرْسِ', #1
u'البرس': u'الْبِرْسِ', #1
u'البرسام': u'البرسام', #1
u'البرسام،': u'الْبِرْسَامُ،', #1
u'البرسام': u'الْبِرْسَامِ', #12
u'البرسام': u'الْبِرْسَامَ', #2
u'البرسام': u'الْبَرْسَامِ', #3
u'البرسام': u'الْبَرْسَامُ', #4
u'البرسام': u'الْبِرْسَامُ', #8
u'البرساني': u'البُرْسَانِيَّ', #1
u'البرساني': u'البُرْسَانِيُّ', #1
u'البرساني': u'البُرْسَانِيِّ', #1
u'البرساني،': u'الْبُرْسَانِيَّ،', #1
u'البرسانى': u'البُرْسَانِىُّ', #1
u'البرساني': u'الْبُرْسَانِيُّ', #16
u'البرساني': u'البرساني', #2
u'البرساني': u'الْبُرْسَانِيِّ', #2
u'البرساني،': u'الْبُرْسَانِيُّ،', #20
u'البرساني،': u'الْبُرْسَانِيِّ،', #4
u'البرسانى': u'الْبُرْسَانِىُّ', #8
u'البرسبابي': u'الْبِرِسْبَابِيُّ', #1
u'البرسباي': u'البرسباي', #1
u'البرض': u'الْبَرَضِ', #1
u'البرعزية': u'الْبَرْعَزِيَّةِ', #1
u'البرغري': u'الْبُرَغْرِيِّ', #1
u'البرغزي': u'الْبَرْغَزِيِّ', #2
u'البرغوية': u'الْبَرْغَوِيَّةِ', #1
u'البرقاء': u'الْبَرْقَاءِ', #2
u'البرقات': u'الْبَرَقَاتُ', #1
u'البرقال': u'البِرْقَالُ', #1
u'البرقاني،': u'البرقاني،', #1
u'البرقاني': u'الْبُرْقَانِيّ', #1
u'البرقاني': u'الْبَرْقَانِيُّ', #28
u'البرقاني': u'الْبَرْقَانِيِّ', #3
u'البرقليطس': u'الْبَرْقَلِيطِسُ', #1
u'البرقى': u'الْبَرْقِىَّ', #1
u'البرقى': u'الْبَرَقِىُّ', #2
u'البرقى': u'الْبَرْقِىُّ', #3
u'البركانات': u'الْبَرْكَانَاتِ', #1
u'البركلي': u'الْبِرْكِلِيِّ', #1
u'البركه': u'الْبَرَكَهْ', #2
u'البركوي': u'الْبِرْكَوِيُّ', #15
u'البركوي': u'الْبِرْكَوِيِّ', #3
u'البركوية': u'الْبِرْكَوِيَّةِ', #2
u'البركى': u'الْبِرَكِىُّ', #1
u'البرلس': u'الْبُرُلُّسِ', #2
u'البرلسي': u'الْبُرُلُّسِيّ', #1
u'البرلسي،': u'الْبُرُلُّسِيِّ،', #1
u'البرلسى': u'الْبُرُلُّسِىَّ', #1
u'البرلسي': u'الْبُرُلُّسِيِّ', #126
u'البرلسي': u'الْبُرُلُّسِيُّ', #175
u'البرلسي،': u'الْبُرُلُّسِيُّ،', #2
u'البرلسي': u'الْبُرُلُّسِيَّ', #20
u'البرلسى': u'الْبُرُلُّسِىُّ', #8
u'البرماورد': u'الْبَرْمَاوَرْدُ', #1
u'البرماوي': u'الْبِرْمَاوِيِّ', #114
u'البرماوي': u'الْبِرْمَاوِيُّ', #156
u'البرماوي': u'الْبِرْمَاوِيَّ', #5
u'البرمكي': u'الْبَرْمَكِيِّ', #14
u'البرمكي': u'الْبَرْمَكِيّ', #2
u'البرمكي،': u'الْبَرْمَكِيُّ،', #2
u'البرمكي': u'الْبَرْمَكِيُّ', #47
u'البرموني': u'البرموني', #1
u'البرموني': u'الْبَرْمُونِيِّ', #14
u'البرموني': u'الْبَرْمُونِيُّ', #19
u'البرموني': u'الْبَرَمُونِيُّ', #2
u'البرموني': u'الْبَرْمُونِيَّ', #2
u'البرناسي': u'الْبُرْنَاسِيِّ', #2
u'البرند': u'البرند', #1
u'البرند': u'الْبِرِنْدِ', #1
u'البرند،': u'الْبِرِنْدِ،', #1
u'البرنطوشي': u'البرنطوشي', #1
u'البرنو': u'البرنو', #1
u'البرنى': u'البرنى', #1
u'البرهمتوشي': u'البرهمتوشي', #1
u'البروات': u'الْبَرَوَاتِ', #1
u'البرواطي': u'الْبِرْوَاطِيِّ', #1
u'البروجا': u'الْبُرُوجَا', #2
u'البروي': u'الْبَرَوِيُّ', #2
u'البروي': u'الْبَرَوِيِّ', #2
u'البرى': u'الْبَرَى', #1
u'البرى': u'الْبُرِّىُّ', #1
u'البرى': u'الْبُرِّىِّ', #1
u'البرى': u'الْبَرِّىُّ', #5
u'البرئي،': u'الْبرئِيُّ،', #1
u'البرير': u'الْبَرِيرَ', #1
u'البرير،': u'الْبَرِيرِ،', #1
u'البرير': u'الْبَرِيرِ', #2
u'البريه': u'الْبَرِيّه', #1
u'البريه': u'الْبَرِيّهْ', #1
u'البريه': u'الْبَرِيَّهْ', #2
u'البز': u'الْبِزّ', #1
u'البز،': u'الْبَزُّ،', #1
u'البز': u'الْبَزّ', #10
u'البز': u'الْبَزِّ', #161
u'البز': u'الْبَزُّ', #32
u'البز': u'الْبَزَّ', #60
u'البزابيز': u'الْبَزَابِيزِ', #2
u'البزارر': u'الْبَزَّارُر', #1
u'البزارى': u'البُزَارِىُّ', #1
u'البزارى': u'الْبَزَارِىُّ', #1
u'البزارى': u'الْبُزَارِىُّ', #2
u'البزارية': u'البزارية', #1
u'البزاغ': u'الْبَزَّاغَ', #2
u'البزاغ': u'الْبَزَّاغُ', #7
u'البزاغ': u'الْبَزَّاغِ', #8
u'البزدوي': u'الْبَزْدَوِيِّ', #116
u'البزدوي': u'الْبَزْدَوِيُّ', #195
u'البزدوي': u'الْبَزْدَوِيَّ', #3
u'البزدوية': u'الْبَزْدَوِيَّةِ', #2
u'البزراطي': u'البزراطي', #1
u'البزراطي': u'الْبُزْرَاطِيُّ', #2
u'البزراطي': u'الْبُزْرَاطِيِّ', #3
u'البزرى': u'الْبَزَرَى', #1
u'البزرى': u'الْبَزَرِى', #1
u'البزقة': u'الْبَزْقَةِ', #1
u'البزقة': u'الْبَزْقَةُ', #2
u'البزماورد': u'الْبَزْمَاوَرْدُ', #1
u'البزمهرانى': u'الْبَزْمَهْرَانِىُّ', #9
u'البزنانى': u'الْبُزْنَانِىُّ', #1
u'البزوري،': u'البزوري،', #1
u'البزوري،': u'الْبُزُورِيِّ،', #1
u'البزوري': u'البزوري', #2
u'البزورى': u'الْبُزُورِىُّ', #2
u'البزوري،': u'الْبُزُورِيُّ،', #3
u'البزوريين،': u'الْبُزُورِيِّينَ،', #1
u'البزوز': u'الّبُزُوزِ', #1
u'البزوز': u'الْبُزُوزَ', #1
u'البزوز': u'الْبُزُوزِ', #1
u'البزول': u'الْبُزُولِ', #2
u'البزى': u'البزى', #1
u'البزيعي': u'البزيعي', #1
u'البزيعي،': u'الْبَزِيعِيِّ،', #1
u'البزيعي': u'الْبَزِيعِيُّ', #2
u'البزيعي،': u'الْبَزِيعِيُّ،', #3
u'البزيون': u'البزيون', #1
u'البزيون': u'الْبِزْيُونِ', #1
u'البزيون': u'الْبِزْيَوْنِ', #1
u'البسارية': u'الْبَسَارِيَةِ', #1
u'البسائط': u'الْبَسَائِطَ', #1
u'البسائط': u'الْبَسَائِطُ', #1
u'البسائط': u'الْبَسَائِطِ', #4
u'البسبايج': u'البسبايج', #2
u'البستج': u'الْبَسْتَجِ', #1
u'البستنبان،': u'الْبُسْتَنْبَانِ،', #1
u'ألبستنيه': u'أَلْبَسْتَنِيهِ', #1
u'البستي': u'الْبُسْتِيّ', #1
u'البستي': u'الْبُسْتِيَّ', #1
u'البستي': u'الْبُسْتِيُّ', #10
u'البستي': u'الْبُسْتِيِّ', #12
u'البستى': u'الْبُسْتِىُّ', #5
u'البسرى': u'الْبُسْرِىُّ', #3
u'البسطامي،': u'البسطامي،', #1
u'البسطامي': u'الْبَسْطَامِيُّ', #1
u'البسطامي': u'الْبِسْطَامِيَّ', #1
u'البسطامي،': u'الْبِسْطَامِيِّ،', #1
u'البسطامي': u'الْبِسْطَامِيِّ', #14
u'البسطامي': u'الْبِسْطَامِيُّ', #17
u'البسطامي': u'الْبَسْطَامِيِّ', #2
u'البسطامي،': u'الْبَسْطَامِيُّ،', #2
u'البسطامى': u'الْبِسْطَامِىِّ', #2
u'البسطامي،': u'الْبِسْطَامِيُّ،', #3
u'البسطامى': u'الْبَسْطَامِىُّ', #3
u'البسطامى': u'الْبِسْطَامِىُّ', #38
u'البسطريين': u'الْبَسْطَرِيِّينَ', #1
u'البسطين': u'الْبَسْطَيْنِ', #6
u'ألبسكه': u'أَلْبَسَكَهُ', #2
u'البسل': u'الْبَسْلَ', #1
u'البسل': u'الْبَسْلُ', #2
u'البسل': u'الْبَسْلِ', #6
u'البسلا': u'الْبِسِلَّا', #2
u'البسلاء': u'الْبِسِلَّاءُ', #1
u'البسليت': u'البسليت', #1
u'البسمله': u'الْبَسْمَلَهْ', #2
u'البسندود': u'البسندود', #1
u'البسورة': u'الْبُسُورَةِ', #7
u'البسوطة': u'الْبُسُوطَةُ', #4
u'البسوطة': u'الْبُسُوطَةِ', #4
u'البسوطة': u'الْبُسُوطَةَ', #6
u'البسى': u'الْبَسِى', #1
u'البسيس': u'الْبَسِيسَ', #1
u'البسيس': u'الْبَسِيسُ', #1
u'البسيس': u'الْبَسِيسِ', #6
u'البسيسة': u'الْبَسِيسَةِ', #1
u'البسيلة': u'الْبَسِيلَةِ', #6
u'البسيلة': u'الْبَسِيلَةُ', #8
u'البشاخين': u'الْبَشَّاخِينَ', #1
u'البشبيشي': u'الْبِشْبِيشِيّ', #1
u'البشبيشي': u'الْبِشْبِيشِيُّ', #5
u'البشت': u'الْبَشْتِ', #1
u'البشتكي': u'البشتكي', #3
u'البشتي': u'الْبُشْتِيُّ', #1
u'البشتيك': u'البشتيك', #1
u'البشخانات': u'الْبَشْخَانَاتِ', #1
u'البشخانة': u'الْبَشْخَانَةِ', #1
u'البشخانة': u'الْبُشْخَانَةَ', #1
u'البشخانة': u'الْبُشْخَانَةِ', #1
u'البشخانة': u'الْبَشْخَانَةُ', #3
u'البشخانة': u'الْبُشْخَانَةُ', #3
u'البشره': u'الْبَشَرَهْ', #3
u'البشلك': u'البشلك', #6
u'البشم': u'الْبَشَمُ', #3
u'البشمة': u'الْبَشْمَةُ', #1
u'البشمة': u'الْبَشِمَةُ', #4
u'البشمقجي': u'الْبَشْمَقْجِيُّ', #1
u'البشنة': u'البشنة', #1
u'البشنخانة': u'البشنخانة', #1
u'البشوت': u'الْبُشُوتِ', #1
u'البشوت': u'البشوت', #2
u'البشيرى': u'الْبَشِيرِىُّ', #5
u'البشيع': u'الْبَشِيعِ', #3
u'البشيعة': u'الْبَشِيعَةِ', #1
u'البصال': u'الْبَصَّالُ', #1
u'البصال': u'الْبَصَّالِ', #1
u'البصة': u'الْبَصَّةِ', #1
u'البصراني،': u'الْبَصْرَانِيُّ،', #1
u'البصروي': u'الْبَصْرَوِيُّ', #3
u'البصرى': u'الْبَصْرِى', #1
u'البصرى': u'الْبِصْرِىِّ', #2
u'البصرى': u'الْبَصْرِىَّ', #3
u'البصرى': u'الْبَصْرِىُّ', #315
u'البصرى': u'الْبَصْرِىِّ', #79
u'البصريون': u'الْبَصْرِيّونَ', #2
u'البصريون': u'الْبَصْرِيُّونَ', #40
u'البضاعه': u'الْبِضَاعَهْ', #3
u'البضيع': u'الْبَضِيعِ', #4
u'البطارخ': u'الْبَطَارِخُ', #10
u'البطارخ': u'الْبَطَارِخَ', #2
u'البطارخ': u'الْبَطَارِخِ', #6
u'البطاطيخ': u'الْبَطَاطِيخُ', #1
u'البطاطيخ': u'الْبَطَاطِيخِ', #1
u'البطاطيخ': u'الْبَطَاطِيخَ', #6
u'البطرني': u'الْبَطْرَنِيُّ', #2
u'البطروني': u'الْبَطْرُونِيُّ', #1
u'البطروني': u'الْبَطْرُونِيِّ', #1
u'البطرين': u'الْبَطِرِينَ', #1
u'البطريني': u'الْبَطْرِينِيُّ', #1
u'البطط': u'الْبِطَطَ', #1
u'البططيين': u'البططيين', #1
u'البطوي': u'الْبَطَوِيِّ', #1
u'البطىء': u'البطىء', #1
u'البطىء': u'الْبَطِىءُ', #1
u'البطئ': u'الْبُطْئِ', #1
u'البطيحاء': u'البطيحاء', #1
u'البطيحاء': u'الْبُطَيْحَاءَ', #3
u'البعاد': u'الْبِعَادِ', #1
u'البعار،': u'الْبَعَّارِ،', #1
u'البعاق': u'الْبُعَاقِ', #1
u'البعدا': u'الْبُعْدَا', #1
u'البعديه': u'الْبَعْدِيَّهْ', #2
u'البعران': u'الْبُعْرَانِ', #1
u'البعضيه': u'الْبَعْضِيَّهْ', #2
u'البعور': u'الْبَعُورِ', #1
u'البعولية': u'الْبُعُولِيَّةِ', #1
u'البعيثران': u'الْبُعَيْثِرَانَ', #1
u'البعيثران': u'الْبُعَيْثِرَانِ', #1
u'البغا': u'الْبَغَّا', #2
u'البغاث': u'الْبُغَاثُ', #10
u'البغاث': u'الْبُغَاثِ', #6
u'البغاثة': u'الْبُغَاثَةُ', #1
u'البغاك': u'الْبِغَاكُ', #2
u'البغالة': u'الْبَغَّالَةِ', #1
u'البغاية': u'الْبِغَايَةِ', #1
u'البغدادى': u'الْبَغْدَادِىَّ', #1
u'البغدادى': u'الْبَغْدَادِىُّ', #134
u'البغدادى': u'البَغْدَادِىُّ', #18
u'البغدادى': u'البَغْدَادِىِّ', #3
u'البغدادى': u'الْبَغْدَادِىِّ', #9
u'البغضة': u'الْبُغْضَةِ', #1
u'البغضة': u'الْبِغْضَة', #1
u'البغضة': u'الْبِغْضَةَ', #1
u'البغضة': u'الْبُغْضَةَ', #2
u'البغضة': u'الْبِغْضَةُ', #4
u'البغضة': u'الْبِغْضَةِ', #7
u'البغلاني،': u'الْبَغْلانِيُّ،', #1
u'البغلطاق': u'الْبَغْلِطَاقِ', #2
u'البغماد': u'الْبِغْمَادِ', #1
u'البغوت': u'الْبَغُوتِ', #1
u'البغوي': u'الْبَغْوِيُّ', #1
u'البغوي': u'الْبُغَوِيُّ', #1
u'البغوى': u'البْغَوِىَّ', #1
u'البغوى': u'الْبَغَوِىُّ', #134
u'البغوي،': u'الْبَغَوِيُّ،', #15
u'البغوى': u'الْبَغَوِىِّ', #2
u'البغوي': u'الْبَغَوِيُّ', #22
u'البغوي': u'الْبَغَوِيَّ', #29
u'البغوي': u'الْبَغَوِيّ', #3284
u'البغوي': u'الْبَغَوِيِّ', #361
u'البغوي،': u'البغوي،', #4
u'البغوي،': u'الْبَغَوِيِّ،', #4
u'البغى': u'الْبَغْىُ', #1
u'البغى': u'البغى', #2
u'البغى': u'الْبَغْىِ', #20
u'البغى': u'الْبَغِىِّ', #24
u'البغيبغة': u'الْبُغَيْبِغَةُ', #1
u'البفت': u'البفت', #1
u'البفت': u'الْبَفْتِ', #1
u'البفتة': u'الْبُفْتَةِ', #1
u'البقابيق': u'الْبَقَابِيقُ', #1
u'البقابيق': u'الْبَقَابِيقِ', #1
u'البقار': u'الْبَقَّارِ', #18
u'البقار': u'الْبَقَّارُ', #37
u'البقار': u'الْبَقَّارَ', #8
u'البقاعي': u'الْبِقَاعِيِّ', #2
u'البقاعي': u'الْبِقَاعِيُّ', #8
u'البقاية': u'الْبِقَايَةَ', #1
u'البقاية': u'الْبِقَايَةُ', #1
u'البقج': u'البقج', #1
u'البقجة': u'البقجة', #1
u'البقجة': u'الْبُقْجَةِ', #1
u'البقرا': u'الْبَقَرَا', #4
u'البقرة': u'الْبَقَرَةًًًًِ', #1
u'البقره': u'البقره', #1
u'البقره': u'الْبَقَرَهْ', #1
u'البقس': u'الْبَقْسِ', #3
u'البقعه': u'الْبُقْعَهْ', #2
u'البقلة': u'الْبَقَلَةَ', #1
u'البقلة': u'الْبَقْلَةُ', #1
u'البقلة': u'الْبَقْلَةِ', #24
u'البقلة': u'الْبَقْلَةَ', #5
u'البقم': u'الْبَقّمُ', #1
u'البقم': u'الْبَقَّمُ', #2
u'البقم': u'الْبَقَّمِ', #5
u'البقور': u'الْبُقُورَ', #3
u'البقور': u'الْبُقُورِ', #4
u'البقوق': u'الْبُقُوقُ', #1
u'البقولات': u'الْبُقُولَاتِ', #2
u'البقوم': u'الْبُقُومِ', #3
u'البقيةإلى': u'الْبَقِيَّةَإِلَى', #1
u'البقير': u'الْبُقَيْرُ', #1
u'البقيعة': u'البقيعة', #1
u'البكاءون': u'الْبَكَّاءُونَ', #1
u'البكاءون،': u'الْبَكَّاءُونَ،', #1
u'البكاءون': u'الْبَكّاءُونَ', #6
u'البكاس': u'الْبَكَّاسُ', #1
u'البكال': u'الْبَكَّالِ', #1
u'البكالي': u'الْبَكَّالِيِّ', #1
u'البكالي': u'الْبُكَالِيِّ', #1
u'البكالى': u'الْبِكَالِىَّ', #1
u'البكالي': u'البكالي', #2
u'البكالي': u'الْبِكَالِيِّ', #2
u'البكالي،': u'الْبِكَالِيُّ،', #2
u'البكالي': u'الْبِكَالِيَّ', #3
u'البكالي،': u'الْبِكَالِيِّ،', #3
u'البكالي،': u'البكالي،', #6
u'البكالي': u'الْبِكَالِيُّ', #7
u'البكاليأن': u'الْبِكَالِيِّأَنَّ', #1
u'البكائى': u'البَّكَّائِىُّ', #1
u'البكائى': u'الْبَكَائِىُّ', #1
u'البكائى': u'الْبَكَّائِىِّ', #1
u'البكائى': u'الْبَكَّائِىَّ', #2
u'البكائى': u'الْبَكَّائِىُّ', #7
u'البكدرية': u'الْبَكْدَرِيَّةِ', #2
u'البكراوي': u'الْبكْرَاوِيُّ', #1
u'البكراوي،': u'الْبَكْرَاوِيِّ،', #1
u'البكراوى': u'الْبَكْرَاوِىِّ', #1
u'البكراوي': u'الْبَكْرَاوِيِّ', #2
u'البكراوى': u'الْبَكْرَاوِىُّ', #31
u'البكراوي،': u'الْبَكْرَاوِيُّ،', #34
u'البكراوي': u'الْبَكْرَاوِيُّ', #5
u'البكرى،': u'البكرى،', #1
u'البكرى': u'الْبَكْرِىِّ', #1
u'البكرى': u'الْبَكْرِىَّ', #2
u'البكرى': u'الْبَكْرِىُّ', #7
u'البكريون': u'الْبَكْرِيُّونَ', #1
u'البكى': u'الْبُكَى', #1
u'البكير،': u'الْبُكَيْرٍ،', #1
u'البكير': u'البُكَيْر', #2
u'البكير،': u'البُكَيْر،', #2
u'البكير،': u'الْبُكَيْرِ،', #2
u'البكير': u'البكير', #5
u'البكير': u'الْبَكِيرِ', #5
u'البكير': u'الْبُكَيْرِ', #65
u'البلا': u'الْبَلَا', #3
u'البلا': u'الْبِلَا', #6
u'البلادر': u'الْبَلَادِرَ', #1
u'البلادر': u'الْبَلَادِرِ', #5
u'البلاذر': u'الْبَلَاذِرِ', #2
u'البلاذري': u'الْبَلَاذِرِيِّ', #1
u'البلاذري': u'الْبَلاذُرِيُّ', #2
u'البلاذري': u'الْبَلَاذِرِيُّ', #3
u'البلازر': u'البلازر', #1
u'البلاص': u'الْبَلَّاصَ', #1
u'البلاغم': u'الْبَلَاغِمَ', #2
u'البلالى': u'الْبِلاَلِىُّ', #1
u'البلاليج': u'الْبَلَالِيجِ', #1
u'البلاليع': u'الْبَلَالِيعِ', #1
u'البلان': u'الْبَلَّانَ', #1
u'البلان': u'الْبَلَّانِ', #2
u'البلان': u'الْبَلَّانُ', #3
u'البلانة': u'الْبَلَّانَةَ', #1
u'البلانة': u'الْبَلَّانَةِ', #1
u'البلاوي': u'الْبَلَاوِيَ', #1
u'البلباني': u'الْبَلْبَانِيِّ', #2
u'البلباني': u'الْبَلْبَانِيُّ', #6
u'البلبيس': u'الْبِلْبِيسِ', #1
u'البلبيسي': u'الْبِلْبِيسِيِّ', #1
u'البلج': u'الْبَلَجَ', #1
u'البلج': u'الْبَلَجِ', #1
u'البلجاء': u'الْبَلْجَاءَ', #3
u'البلخ': u'الْبَلْخِ', #1
u'البلخش': u'الْبَلْخَشِ', #1
u'البلخي': u'البلخي', #1
u'البلخي': u'الْبَلْخِيِّ', #1
u'البلخى': u'الَبَلْخِىُّ', #1
u'البلخي،': u'البلخي،', #2
u'البلخى': u'الْبَلْخِىِّ', #2
u'البلخي': u'الْبَلْخِيّ', #252
u'البلخي،': u'الْبَلْخِيُّ،', #34
u'البلخى': u'الْبَلْخِىُّ', #42
u'البلخي': u'الْبَلْخِيُّ', #59
u'البلخي،': u'الْبَلْخِيِّ،', #8
u'البلخيان': u'الْبَلْخِيَّانِ', #1
u'البلخية': u'الْبَلْخِيَّةُ', #1
u'البلخيون': u'الْبَلْخِيُّونَ', #6
u'البلخيين': u'الْبَلْخِيِّينَ', #11
u'البلدا': u'الْبَلَدَا', #1
u'البلدانيات': u'الْبُلْدَانِيَّاتِ', #3
u'البلدانية': u'الْبُلْدَانِيَّةِ', #1
u'البلدى': u'الْبَلَدِىُّ', #9
u'البلس': u'الْبَلَسُ', #1
u'البلغ': u'الْبُلَغِ', #1
u'البلغ': u'الْبُلَّغُ', #3
u'البلغ': u'الْبُلَّغِ', #3
u'البلغم': u'الْبَلْغَم', #2
u'البلغم': u'الْبَلْغَمُ', #39
u'البلغم': u'الْبَلْغَمَ', #40
u'البلغم': u'الْبَلْغَمِ', #65
u'البلغمي': u'الْبَلْغَمِيَّ', #1
u'البلغمي': u'الْبَلْغَمِيُّ', #1
u'البلغمي': u'الْبَلْغَمِيِّ', #2
u'البلغمية': u'الْبَلْغَمِيَّةُ', #1
u'البلغمية': u'الْبَلْغَمِيَّةَ', #4
u'البلغمية': u'الْبَلْغَمِيَّةِ', #4
u'البلغيائي': u'الْبُلْغِيَائِيُّ', #1
u'البلغيائي': u'الْبُلْغِيَائِيِّ', #1
u'البلقا،': u'الْبَلْقَا،', #1
u'البلقة': u'الْبُلْقَةِ', #1
u'البلقة': u'الْبُلْقَةُ', #5
u'البلقع': u'الْبَلْقَعَ', #1
u'البلقيني': u'الُبُلْقِينِيّ', #1
u'البلقيني': u'الْبُلْقِينِيَّ', #100
u'البلقيني': u'الْبُلْقِينِيّ', #2
u'البلقيني': u'الْبُلْقِينِيُّ', #4950
u'البلقيني': u'الْبُلْقِينِيِّ', #622
u'البلمة': u'الْبَلَمَةَ', #1
u'البلند': u'الْبَلَنْدَ', #1
u'البلنسي': u'الْبَلَنْسِيُّ', #1
u'البلنسي': u'الْبَلَنْسِيِّ', #1
u'البلوع': u'الْبَلُوعِ', #1
u'البلولة': u'الْبُلُولَةِ', #2
u'البلى،': u'الْبِلَى،', #1
u'البلى': u'الْبِلَى', #67
u'البليدي': u'الْبَلِيدِي', #1
u'البليدي': u'الْبَلِيدِيَّ', #1
u'البليدي': u'الْبُلَيْدِيُّ', #17
u'البليدي': u'الْبُلَيْدِيِّ', #9
u'البناءون': u'الْبَنَّاءُونَ', #1
u'البنادقة': u'الْبَنَادِقَةُ', #1
u'البنادقة': u'الْبَنَادِقَةِ', #3
u'البنانة': u'الْبُنَانَةُ', #2
u'البنانى': u'الْبُنَانِىُّ', #31
u'البنانى': u'الْبُنَانِىَّ', #6
u'البنانى': u'الْبُنَانِىِّ', #60
u'البناوة': u'البناوة', #1
u'البنجر': u'الْبَنْجَرِ', #1
u'البنجرة': u'الْبَنْجَرَةِ', #1
u'البندار': u'الْبُنْدَارِ', #1
u'البندار': u'الْبُنْدَارُ', #2
u'البندفزكى': u'الْبَنْدَفَزْكِىُّ', #1
u'البندقداري': u'البندقداري', #1
u'البندقركى': u'اْلَبْنَدَقَرْكِىُّ', #1
u'البندنيجي': u'الْبَنْدَنِيجِيَّ', #13
u'البندنيجي': u'الْبَنْدَنِيجِيُّ', #247
u'البندنيجي': u'الْبَنْدَنِيجِيِّ', #95
u'البندوقي': u'الْبَنْدُوقِيَّ', #1
u'البنوفري': u'الْبَنَوْفَرِيِّ', #1
u'البنوفري': u'البنوفري', #2
u'البنوفري': u'الْبَنَوْفَرِيُّ', #9
u'البنوق': u'الْبُنُوقِ', #1
u'البهارات': u'الْبَهَارَاتِ', #4
u'البهراني': u'البهراني', #1
u'البهراني': u'البَهْراني', #1
u'البهراني،': u'الْبَهرَانِيُّ،', #1
u'البهرانى': u'الْبَهْرَانِىُّ', #4
u'البهراني': u'الْبَهْرَانِيُّ', #5
u'البهراني': u'الْبَهْرَانِيّ', #7
u'البهراني،': u'الْبَهْرَانِيِّ،', #7
u'البهراني': u'الْبَهْرَانِيِّ', #8
u'البهراني،': u'الْبَهْرَانِيُّ،', #9
u'البهرانى': u'الْبَهْرَانِىِّ', #9
u'البهرائي،': u'الْبُهْرَائِيُّ،', #1
u'البهزي': u'البَهْزي', #1
u'البهزي،': u'الْبَهْزِيِّ،', #1
u'البهزى': u'الْبَهْزِىَّ', #1
u'البهزي': u'الْبَهْزِيِّ', #22
u'البهزي': u'الْبَهْزِيَّ', #3
u'البهزى': u'الْبَهْزِىُّ', #3
u'البهزي': u'الْبَهْزِيّ', #4
u'البهزي': u'البهزي', #5
u'البهزي': u'الْبَهْزِيُّ', #5
u'البهزى': u'الْبَهْزِىِّ', #5
u'البهزية': u'الْبَهْزِيَّةَ', #1
u'البهزية': u'الْبَهْزِيَّةِ', #3
u'البهشمية': u'الْبَهْشَمِيَّةِ', #1
u'البهطة': u'الْبَهَطَّةَ', #1
u'البهق': u'الْبَهَقِ', #12
u'البهق': u'الْبَهَقَ', #3
u'البهق': u'الْبَهَقُ', #3
u'البهل': u'الْبَهْلُ', #1
u'البهل': u'الْبَهْلِ', #3
u'البهمى': u'الْبُهْمَى', #1
u'البهنسا': u'الْبَهْنَسَا', #1
u'البهنسي': u'الْبَهْنَسَيَّ', #1
u'البهنسي': u'الْبَهْنَسِيِّ', #11
u'البهنسي': u'الْبَهْنَسِيُّ', #18
u'البهوتي': u'الْبُهُوتِيِّ', #3
u'البهوتي': u'الْبُهُوتِيُّ', #46
u'البهى': u'الْبَهِىَّ', #1
u'البهى': u'الْبَهِىِّ', #11
u'البهيمه': u'الْبَهِيمَهْ', #1
u'البو': u'الْبَوَّ', #2
u'البوادى': u'الْبَوَادِى', #2
u'البواردية': u'الْبَوَارِدِيَّةَ', #1
u'البوارديين': u'البوارديين', #1
u'البواقى': u'البواقى', #2
u'البواقى': u'الْبَوَاقِى', #3
u'البوائق': u'البوائق', #1
u'البوائق': u'الْبَوَائِقِ', #5
u'البوذري': u'البوذري', #1
u'البوذري': u'الْبُوذَرِيُّ', #1
u'البورق': u'الْبُورَقُ', #2
u'البورق': u'البورق', #3
u'البوريا': u'الْبُورِيَّا', #2
u'البوريني': u'الْبُورِينِيُّ', #1
u'البوزة': u'الْبُوزَةُ', #1
u'البوزنجردى': u'الْبُوزَنْجَرْدِىُّ', #1
u'البوزنجردى': u'الْبُوزَنْجِرْدِىُّ', #1
u'البوسى': u'الْبُوسِىُّ', #1
u'البوسى': u'الْبَوْسِىُّ', #1
u'البوشنجي': u'الْبُوشنْجِيِّ', #1
u'البوشنجي': u'الْبُوشْنَجِيُّ', #1
u'البوشنجى': u'الْبُوشَنْجِىَّ', #1
u'البوشنجى': u'الْبُوشَنْجِىِّ', #1
u'البوشنجى': u'الْبُوشَنْجِىُّ', #117
u'البوشنجي،': u'الْبُوشَنْجِيُّ،', #2
u'البوشنجي': u'الْبُوشَنْجِيِّ', #28
u'البوشنجى': u'الْبُوَشَنْجِىُّ', #3
u'البوشنجي': u'الْبُوشَنْجِيَّ', #4
u'البوشنجي': u'الْبُوشَنْجِيُّ', #44
u'البوص': u'الْبُوصَ', #1
u'البوص': u'الْبَوْصُ', #1
u'البوص': u'الْبُوصُ', #4
u'البوصيري': u'الْبُوصِيرِيِّ', #1
u'البوصيري': u'الْبُوصِيرِيُّ', #4
u'البوظة': u'الْبُوظَةَ', #5
u'البوظة': u'الْبُوظَةِ', #5
u'البوقات': u'الْبُوقَاتِ', #1
u'البوقات': u'الْبُوقَاتُ', #2
u'البولاقي': u'الْبُولَاقِيِّ', #1
u'البولاقي': u'الْبُولَاقِيُّ', #2
u'البوليصة': u'الْبُولِيصَةُ', #1
u'البوئن': u'الْبَوَئِنِ', #1
u'البويب': u'الْبُوَيْبُ', #2
u'البويرة': u'الْبُوَيْرَة', #1
u'البويرة': u'الْبُوَيْرَةِ', #1
u'البويرة،': u'الْبُوَيْرَةُ،', #1
u'البويرة': u'الْبُوَيْرَةُ', #16
u'البويرة': u'الْبُوَيْرَةَ', #7
u'البويري': u'الْبُوَيْرِيِّ', #1
u'البويطي': u'الْبُوَيْطِيّ', #1
u'البويطي،': u'الْبُوَيْطِيُّ،', #1
u'البويطى': u'الْبُوَيْطَىِ', #1
u'البويطى': u'الْبُوَيْطِىَّ', #1
u'البويطى': u'الْبُوَيْطِىُّ', #2
u'البويطي': u'الْبُوَيْطِيِّ', #297
u'البويطي': u'الْبُوَيْطِيُّ', #41
u'البويطى': u'الْبُوَيْطِىِّ', #8
u'البويلة': u'الْبُوَيْلَةَ', #1
u'البي': u'الْبَيْ', #1
u'البئار': u'الْبِئَارُ', #1
u'البئار': u'الْبِئَارِ', #2
u'البياخي': u'الْبَيَاخِيِّ', #1
u'البياذقة': u'البياذقة', #1
u'البياذقة': u'الْبَيَاذِقَةِ', #1
u'البيارة': u'الْبَيَّارَةِ', #2
u'البياسي': u'الْبِيَاسِيّ', #1
u'البياضى': u'الْبَيَاضِىَّ', #2
u'البياضى': u'الْبَيَاضِىُّ', #3
u'البياضى': u'الْبَيَاضِىِّ', #7
u'البياعي': u'الْبَيَّاعِيِّ', #1
u'البيانيون': u'الْبَيَانِيُّون', #1
u'البيانيون': u'الْبَيَانِيُّونَ', #13
u'البيتSسلمان': u'الْبَيْتِSسَلْمَانُ', #1
u'البيتقوله': u'الْبَيْتِقَوْلُهُ', #1
u'البيتوتات': u'الْبَيْتُوتَاتِ', #1
u'البيتوتة': u'البيتوتة', #1
u'البيتوتة': u'الْبَيْتُوتَةُ', #31
u'البيتوتة': u'الْبَيْتُوتَةَ', #33
u'البيتوتة': u'الْبَيْتُوتَة', #8
u'البيتوتة': u'الْبَيْتُوتَةِ', #90
u'البيتوتي': u'الْبَيْتُوتِيِّ', #2
u'البيجوري': u'الْبَيْجُورِيِّ', #1
u'البيجوري': u'الْبَيْجُورِيُّ', #3
u'البيدج': u'الْبَيْدَجِ', #1
u'البيدح': u'الْبَيْدَحِ', #1
u'البيدخ': u'الْبَيْدَخِ', #2
u'البير': u'الْبِيرَ', #1
u'البير': u'الْبِيرُ', #1
u'ألبيرة': u'أَلْبِيرَةَ', #1
u'البيرة': u'الْبِيرَةِ', #2
u'البيروتى': u'الْبَيْرُوتِىُّ', #15
u'البيروني،': u'الْبَيْرُونِيُّ،', #1
u'البيروني': u'الْبَيْرُونِيُّ', #2
u'البيري': u'الْبِيرِيّ', #1
u'البيري': u'الْبِيرِيُّ', #125
u'البيري': u'الْبِيرِيَّ', #5
u'البيري': u'الْبِيرِيِّ', #70
u'البيسارية': u'الْبِيسَارِيَةِ', #2
u'البيسان،': u'الْبَيْسَانِ،', #1
u'البيساني،': u'الْبَيْسَانِيِّ،', #1
u'البيساني': u'الْبِيسَانِيِّ', #2
u'البيسري': u'الْبَيْسَرِيُّ', #1
u'البيسري،': u'الْبَيْسَرِيُّ،', #1
u'البيسرى': u'الْبَيْسَرِىُّ', #1
u'البيطارون': u'الْبَيْطَارُونَ', #4
u'البيظ': u'الْبَيْظَ', #1
u'البيعا': u'الْبِيَعَا', #1
u'البيقورا': u'الْبَيْقُورَا', #1
u'البيقيا': u'الْبِيقِيَا', #1
u'البيكندي': u'الْبَيْكَنْدِيُّ', #2
u'البيل': u'البيلِ', #1
u'البيلقاني': u'الْبَيْلَقَانِيُّ', #1
u'البيلماني،': u'البَيْلَمانيّ،', #1
u'البيلماني،': u'الْبَيْلَمَانِيُّ،', #1
u'البيلمانى': u'الْبَيْلَمَانِىُّ', #1
u'البيلماني،': u'الْبَيْلَمَانِيِّ،', #10
u'البيلمانى': u'الْبَيْلَمَانِىِّ', #26
u'البيلماني': u'الْبَيْلَمَانِيّ', #3
u'البيلماني': u'الْبَيْلَمَانِيُّ', #3
u'البيلماني': u'الْبَيْلَمَانِيِّ', #30
u'البيلوني': u'الْبَيْلُونِيِّ', #1
u'البيلي': u'الْبِيلِيِّ', #1
u'البينه': u'الْبَيِّنَهْ', #8
u'البينوني': u'الْبَيْنُونِيُّ', #1
u'البينين': u'الْبَيِّنَيْنِ', #1
u'البيهسى': u'الْبَيْهَسِىُّ', #1
u'البيهقي': u'البيهقيّ', #1
u'البيهقى': u'الْبَيْهَقِىَّ', #1
u'البيهقي': u'الْبَيْهَقِيِّ', #10
u'البيهقي': u'الْبَيْهَقِيُّ', #2902
u'البيهقي': u'الْبَيْهَقِيَّ', #34
u'البيهقي': u'البيهقي', #4
u'البيهقي،': u'الْبَيْهَقِيُّ،', #6
u'البيهقى': u'الْبَيْهَقِىُّ', #70
u'البيهقي': u'الْبَيْهَقِيّ', #747
u'البيوتة': u'الْبَيُّوتَةُ', #1
u'البيوعات': u'الْبُيُوعَاتِ', #16
u'البيونة': u'الْبَيُونَةَ', #1
u'البيونة': u'الْبَيُونَةِ', #1
u'البيونة': u'الْبُيُونَةِ', #1
u'البيونة': u'الْبَيُونَةُ', #2
u'ألة': u'أَلّةً', #2
u'ألة': u'أَلّةٍ', #2
u'الت': u'التّ', #1
u'الت': u'التَّ', #2
u'التا': u'التَّا', #3
u'التأبر': u'التَّأَبُّرُ', #1
u'التابعى': u'التابعى', #1
u'التابلتي': u'التابلتي', #1
u'التابوه': u'التَّابُوهُ', #4
u'التأتاء': u'التَّأْتَاءُ', #3
u'التأثل': u'التَّأَثُّلِ', #2
u'التاثوا': u'الْتَاثُوا', #1
u'التآجر': u'التَّآجُرِ', #3
u'التاجري': u'التَّاجِرِيِّ', #1
u'التاجري': u'التَّاجِرِيُّ', #2
u'التاجوري': u'التَّاجُورِيِّ', #2
u'التاجوري': u'التَّاجُورِيُّ', #5
u'التادلي': u'التَّادَلِي', #1
u'التادلي': u'التَّادَلِيّ', #1
u'التادلي': u'التَّادَلِيُّ', #27
u'التادلي': u'التَّادَلِيِّ', #5
u'التأدم': u'التَّأَدُّمَ', #3
u'التأدم': u'التَّأَدُّمُ', #4
u'التأدم': u'التَّأَدُّمِ', #8
u'التأدي': u'التَّأَدِّي', #15
u'التأذم': u'التَّأَذُّمُ', #1
u'التأذي': u'التَّأَذِّي', #124
u'التأذينة': u'التَّأْذِينَةَ', #1
u'التأريب': u'التَّأْرِيبِ', #5
u'التأريش': u'التَّأْرِيشِ', #1
u'التازغدري': u'التازغدري', #1
u'التازغدري': u'التَّازَغْدَرِيُّ', #1
u'التأزير': u'التَّأْزِيرَ', #2
u'التأزير': u'التَّأْزِيرِ', #3
u'التاسعه': u'التَّاسِعَهْ', #1
u'التاسعية': u'التَّاسِعِيَّةِ', #1
u'التاسومة': u'التَّاسُومَةِ', #5
u'التاسومة': u'التَّاسُومَةُ', #7
u'التأسيا': u'التَّأَسِّيَا', #1
u'التاط': u'الْتَاطَ', #1
u'التافة': u'التَّافَةُ', #1
u'التافلاتي': u'التَّافِلَاتِيُّ', #1
u'التافلاني': u'التَّافِلَانِيُّ', #1
u'التافلاني': u'التَّافِلَانِيِّ', #1
u'التأقت': u'التَّأَقُّتَ', #1
u'التأقيت': u'التَّأْقِيتِ', #126
u'التأقيت': u'التَّأْقِيتَ', #69
u'التأقيت': u'التَّأْقِيتُ', #84
u'التالات': u'التَّالَّاتُ', #1
u'التالات': u'التَّالَّاتِ', #1
u'التالة': u'التَّالَةَ', #1
u'التالة': u'التَّالَّةِ', #18
u'التالة': u'التَّالَةُ', #2
u'التالة': u'التَّالَةِ', #3
u'التالة': u'التَّالَّةُ', #5
u'التالة': u'التَّالَّةَ', #6
u'التالف': u'التَّالِف', #3
u'التالف': u'التَّالِفِ', #315
u'التالف': u'التَّالِفَ', #92
u'التالف': u'التَّالِفُ', #94
u'التالفان': u'التَّالِفَانِ', #1
u'التالفة': u'التَّالِفَةِ', #27
u'التالفة': u'التَّالِفَةَ', #3
u'التالفة': u'التَّالِفَةُ', #3
u'التالفين': u'التَّالِفِينَ', #1
u'التالفين': u'التَّالِفَيْنِ', #7
u'التاليه': u'التَّالِيَهْ', #2
u'التاموسة': u'التَّامُوسَةُ', #1
u'التأنى': u'التَّأَنِّى', #2
u'التانئ': u'التَّانِئُ', #1
u'التانئ': u'التَّانِئِ', #4
u'التاودي': u'التَّاوَدِيِّ', #8
u'التاودي': u'التَّاوَدِيُّ', #9
u'التأيم': u'التَّأَيُّمَ', #1
u'التبابع': u'التَّبَابِعُ', #1
u'التبابعة': u'التَّبَابِعَةَ', #1
u'التبابعة،': u'التَّبَابِعَةِ،', #1
u'التبابعة': u'التّبَابِعَةِ', #7
u'التبار': u'التّبَارِ', #2
u'التباعة': u'التَّبَاعَةُ', #1
u'التباعة': u'التَّبَاعَةِ', #1
u'التباعة': u'التِّبَاعَةُ', #2
u'التباعة': u'التِّبَاعَةِ', #2
u'التبانة': u'التّبَانَةِ', #1
u'التبائث': u'التّبَائِثِ', #1
u'التبايعة': u'التّبَايِعَةِ', #1
u'التبتيل': u'التَّبْتِيلُ', #1
u'التبتيل': u'التَّبْتِيلِ', #2
u'التبثيث': u'التبثيث', #1
u'التبحبح': u'التَّبَحْبُحَ', #2
u'التبخيل': u'التَّبْخِيل', #1
u'التبدع': u'التَّبَدُّعَ', #2
u'التبدئة': u'التَّبْدِئَةِ', #47
u'التبدئة': u'التَّبْدِئَةَ', #5
u'التبدئة': u'التَّبْدِئَةُ', #5
u'التبديع': u'التَّبْدِيعَ', #1
u'التبديلا': u'التَّبْدِيلاَ', #1
u'التبران': u'التِّبْرَانِ', #1
u'التبريء': u'التَّبْرِيءُ', #1
u'التبريء': u'التَّبْرِيءِ', #1
u'التبريص': u'التَّبْرِيصُ', #1
u'التبرين': u'التِّبْرَيْنِ', #3
u'التبزر': u'التَّبَزُّرِ', #1
u'التبصرة': u'التَّبْصِرَة', #1
u'التبصرة': u'التَّبْصِرَةَ', #5
u'التبصرة': u'التَّبْصِرَةُ', #5
u'التبصرة': u'التَّبْصِرَةِ', #714
u'التبطن': u'التَّبَطُّنِ', #1
u'التبطيل': u'التَّبْطِيلِ', #2
u'التبعد': u'التَّبَعُّد', #1
u'التبعد': u'التَّبَعُّدُ', #2
u'التبعض': u'التَّبَعُّضَ', #1
u'التبعل': u'التَّبَعُّلِ', #6
u'التبعى': u'التُّبَّعِىُّ', #1
u'التبقر': u'التبقر', #1
u'التبقر': u'التَّبَقُّرُ', #2
u'التبقر': u'التَّبَقُّرِ', #3
u'التبقيه': u'التَّبْقِيَهْ', #1
u'التبنة،': u'التبنة،', #1
u'التبنة': u'التَّبِنَةَ', #1
u'التبنى': u'التَّبَنِى', #1
u'التبوء': u'التَّبَوُّءُ', #1
u'التبوء': u'التَّبَوُّءِ', #3
u'التبوذكي': u'التَّبُوذكي', #1
u'التبوذكي،': u'التَّبُوذَكِيِّ،', #1
u'التبوذكى': u'التَّبُوذَكِىُّ', #1
u'التبوذكي': u'التَّبُوذَكِيُّ', #4
u'التبوذي': u'التبوذي', #1
u'التبوئة': u'التَّبْوِئَةُ', #23
u'التبوئة': u'التَّبْوِئَةِ', #61
u'التبوئة': u'التَّبْوِئَةَ', #8
u'التبوية': u'التَّبْوِيَةُ', #1
u'التبياني': u'التِّبْيَانِيَّ', #1
u'التبيت': u'التّبَيّتِ', #1
u'التبيت': u'التَّبَيُّتُ', #1
u'التبيت': u'التَّبَيُّتِ', #1
u'التبيع': u'التَّبِيعَ', #12
u'التبيع': u'التَّبِيع', #2
u'التبيع': u'التَّبِيعُ', #29
u'التبيع': u'التَّبِيعِ', #49
u'التبيعات': u'التَّبِيعَاتُ', #1
u'التبيعة': u'التَّبِيعَةَ', #3
u'التبيعة': u'التَّبِيعَةُ', #3
u'التبيعة': u'التَّبِيعَةِ', #3
u'التبيعين': u'التَّبِيعَيْنِ', #2
u'التتارخاني': u'التَّتَارْخَانِيِّ', #1
u'التتارخانية': u'التَّتَارْخَانِيَّةِ', #101
u'التتارخانية': u'التتارخانية', #224
u'التتارخانية': u'التَّتَارْخَانِيَّة', #2759
u'التتارك': u'التَّتَارُكُ', #1
u'التتارك': u'التَّتَارُكِ', #2
u'التتائي': u'التَّتَّائِيَّ', #5
u'التتائي': u'التَّتَّائِيِّ', #61
u'التتائي': u'التَّتَّائِيُّ', #81
u'التتبيب': u'التَّتْبِيبُ', #1
u'التتبيع': u'التَّتْبِيع', #1
u'التترس': u'التَّتَرُّسِ', #10
u'التتريب': u'التَّتْرِيب', #1
u'التتريب': u'التَّتْرِيبُ', #31
u'التتريب': u'التَّتْرِيبَ', #4
u'التتريب': u'التَّتْرِيبِ', #52
u'التتماج': u'التتماج', #1
u'التتمر': u'التَّتَمُّرُ', #1
u'التتمر': u'التَّتَمُّرِ', #3
u'التتمه': u'التَّتِمَّهْ', #2
u'التتميمة': u'التَّتْمِيمَةُ', #1
u'التتمين': u'التَّتْمِينِ', #1
u'التثاوب': u'التَّثَاوُبُ', #1
u'التثبط': u'التَّثَبُّطُ', #1
u'التثريد': u'التَّثْرِيدُ', #1
u'التثقلا': u'التَّثَقُّلَا', #1
u'التثلج': u'التَّثَلُّجُ', #1
u'التثم': u'الْتَثَمَ', #1
u'التثميل': u'التَّثْمِيلُ', #1
u'التثوب': u'التَّثَوُّبُ', #2
u'التجاحد': u'التَّجَاحُدَ', #1
u'التجاحد': u'التَّجَاحُدُ', #12
u'التجاحد': u'التَّجَاحُدِ', #45
u'التجارز': u'التَّجَارُزُ', #1
u'التجارؤ': u'التَّجَارُؤُ', #2
u'التجاعل': u'التَّجَاعُلِ', #1
u'التجافى': u'التَّجَافِى', #1
u'التجافيف': u'التَّجَافِيفَ', #1
u'التجافيف': u'التَّجَافِيفُ', #1
u'التجافيف': u'التَّجَافِيفِ', #1
u'التجانف': u'التَّجَانُفِ', #1
u'التجانن': u'التَّجَانُنَ', #1
u'التجانن': u'التَّجَانُنِ', #4
u'التجثيم': u'التَّجْثِيمِ', #1
u'التجثيم': u'التَّجْثِيم', #2
u'التجري': u'التَّجَرِّيَ', #1
u'التجري': u'التَّجَرِّي', #3
u'التجريج': u'التَّجْرِيجِ', #1
u'التجرين': u'التَّجْرِينِ', #1
u'التجزي': u'التَّجَزِّيَ', #14
u'التجزي': u'التجزي', #6
u'التجزي': u'التَّجَزِّي', #68
u'التجسيس': u'التَّجْسِيسُ', #1
u'التجشي': u'التَّجَشِّي', #3
u'التجلى': u'التَّجَلِّى', #2
u'التجم': u'الْتَجَمَ', #1
u'التجمر': u'التَّجَمُّرُ', #1
u'التجمر': u'التَّجَمُّرِ', #3
u'التجمير': u'التَّجْمِير', #1
u'التجمير': u'التَّجْمِيرَ', #1
u'التجمير': u'التَّجْمِيرُ', #4
u'التجمير': u'التَّجْمِيرِ', #5
u'التجنح': u'التَّجَنُّحَ', #1
u'التجوه': u'التَّجَوُّهِ', #1
u'التجوير': u'التَّجْوِيرِ', #6
u'التجيب': u'التُّجَيْبِ', #1
u'التجيبي،': u'التجيبي،', #1
u'التجيبي،': u'التُجيبي،', #1
u'التجيبي': u'التّجِيبِيّ', #1
u'التجيبي': u'التُّجِيبِيّ', #1
u'التجيبي': u'التُّجْيبِيِّ', #1
u'التجيبي،': u'التَّجِيبِيُّ،', #1
u'التجيبي': u'التُجَيْبيّ', #1
u'التجيبى': u'التُّجِيبِىَّ', #1
u'التجيبى': u'التُّجِيْبِىُّ', #1
u'التجيبي': u'التُّجِيبِيَّ', #12
u'التجيبي،': u'التُّجِيبِيَّ،', #2
u'التجيبي': u'التُّجِيبِيُّ', #21
u'التجيبي': u'التُّجِيبِيِّ', #25
u'التجيبى': u'التُّجِيبِىُّ', #38
u'التجيبي،': u'التُّجِيبِيِّ،', #5
u'التجيبى': u'التُّجِيبِىِّ', #5
u'التجيبي،': u'التُّجِيبِيُّ،', #8
u'التجيبيي': u'التجيبيي', #1
u'التجيي،': u'التَّجَيِيُّ،', #1
u'التحابب': u'التَّحَابُب', #1
u'التحابب': u'التَّحَابُبَ', #2
u'التحابب': u'التَّحَابُبُ', #3
u'التحابب': u'التَّحَابُبِ', #5
u'التحارس': u'التَّحَارُسُ', #1
u'التحاريم': u'التَّحَارِيمَ', #1
u'التحاص': u'التَّحَاصِّ', #2
u'التحاص': u'التَّحَاصُّ', #6
u'التحاصص': u'التَّحَاصُصُ', #11
u'التحاصص': u'التحاصص', #2
u'التحاصص': u'التَّحَاصُصِ', #6
u'التحالق': u'التَّحَالُقُ', #1
u'التحاميد': u'التَّحَامِيدِ', #4
u'التحتاء': u'التَّحْتَاءِ', #1
u'التحتيت': u'التَّحْتِيتُ', #1
u'التحجرا': u'التَّحَجُّرَا', #1
u'التحذر': u'التَّحَذُّرِ', #1
u'التحذر': u'التحذر', #2
u'التحذيف': u'التَّحْذِيفُ', #18
u'التحذيف': u'التَّحْذِيفِ', #32
u'التحرف': u'التَّحَرُّفِ', #15
u'التحرف': u'التَّحَرُّفُ', #2
u'التحرف': u'التَّحَرُّفَ', #9
u'التحرم': u'التَّحَرُّم', #10
u'التحرم': u'التَّحَرُّمُ', #21
u'التحرم': u'التَّحَرُّمِ', #365
u'التحرم': u'التَّحَرُّمَ', #53
u'التحرمات': u'التَّحَرُّمَاتِ', #1
u'التحرمين': u'التَّحَرُّمَيْنِ', #1
u'التحرى': u'التَّحَرِّى', #4
u'التحزن': u'التَّحَزُّن', #2
u'التحزن': u'التَّحَزُّنُ', #4
u'التحزن': u'التَّحَزُّنَ', #5
u'التحزن': u'التَّحَزُّنِ', #8
u'التحزير': u'التَّحْزِيرُ', #1
u'التحصب': u'التَّحَصُّبَ', #1
u'التحطيب': u'التَّحْطِيبُ', #1
u'التحفاء': u'التَّحْفَاءَ', #1
u'التحفل': u'التَّحَفُّلَ', #1
u'التحفل': u'التَّحَفُّلُ', #1
u'التحفل': u'التَّحَفُّلِ', #2
u'إلتحق': u'إلتَحَقَ', #1
u'التحقه': u'الْتَحَقَهُ', #2
u'التحكير': u'التَّحْكِيرُ', #2
u'التحللا': u'التَّحَلُّلَا', #2
u'التحلم': u'التَّحَلُّم', #1
u'التحلم': u'التَّحَلُّمِ', #1
u'التحلم': u'التَّحَلُّمُ', #2
u'التحلى': u'التَّحَلِىِّ', #2
u'التحلى': u'التَّحَلِّى', #2
u'التحميدة': u'التَّحْمِيدَةَ', #1
u'التحميدة': u'التَّحْمِيدَةُ', #3
u'التحميدة': u'التَّحْمِيدَةِ', #4
u'التحنف': u'التّحَنّفُ', #1
u'التحنك': u'التَّحَنُّكُ', #1
u'التحنك': u'التَّحَنُّكَ', #2
u'التحنك': u'التَّحَنُّكِ', #4
u'التحنن': u'التَّحَنُّنِ', #1
u'التحنيث': u'التَّحْنِيثَ', #1
u'التحنيث': u'التَّحْنِيثِ', #24
u'التحنيث': u'التَّحْنِيثُ', #4
u'التحور': u'التَّحَوُّرُ', #1
u'التحويلا': u'التَّحْوِيلَا', #1
u'التحيف': u'التَّحَيُّفَ', #1
u'التحيل': u'التَّحَيُّل', #1
u'التحيل': u'التَّحَيُّلَ', #14
u'التحيل': u'التَّحَيُّلِ', #35
u'التحيل': u'التَّحَيُّلُ', #38
u'التحييل': u'التَّحْيِيلِ', #1
u'التخارج': u'التَّخَارُجَ', #2
u'التخارج': u'التَّخَارُجِ', #32
u'التخارج': u'التَّخَارُجُ', #5
u'التخاريص': u'التَّخَارِيصِ', #1
u'التخاطؤ': u'التَّخَاطُؤِ', #1
u'التخاير': u'التَّخَايُرَ', #14
u'التخاير': u'التَّخَايُر', #2
u'التخاير': u'التَّخَايُرِ', #32
u'التخاير': u'التَّخَايُرُ', #7
u'التخبيب': u'التَّخْبِيبِ', #1
u'التخبيب': u'التَّخْبِيبُ', #2
u'التخبيز': u'التَّخْبِيزِ', #1
u'التخبيط': u'التَّخْبِيطِ', #3
u'التختروان': u'التَّخْتَرَوَانَ', #1
u'التختم': u'التختم', #1
u'التختم': u'التَّخَتُّمِ', #138
u'التختم': u'التَّخَتُّمَ', #51
u'التختم': u'التَّخَتُّم', #6
u'التختم': u'التَّخَتُّمُ', #61
u'التخرص': u'التَّخَرُّصِ', #1
u'التخريص': u'التَّخْرِيصِ', #12
u'التخريص': u'التَّخْرِيصَ', #8
u'التخريص': u'التَّخْرِيصُ', #8
u'التخشعوالوجه': u'التَّخَشُّعَوَالْوَجْهُ', #1
u'التخصر': u'التَّخَصُّرَ', #1
u'التخصر': u'التَّخَصُّرُ', #4
u'التخصر': u'التَّخَصُّرِ', #8
u'التخفف': u'التَّخَفُّفِ', #8
u'التخلى': u'التَّخَلِّى', #3
u'التخول': u'التَّخَوُّلِ', #1
u'التخون': u'التَّخَوُّنِ', #2
u'التخيلة': u'التَّخَيُّلَةَ', #1
u'التخييس': u'التَّخْيِيسِ', #3
u'التد': u'الْتَدَّ', #1
u'التدافن': u'التَّدَافُنُ', #1
u'التداوى': u'التَّدَاوِى', #11
u'التدت': u'الْتَدَّتْ', #2
u'التدرك': u'التَّدَرُّكُ', #1
u'التدفي': u'التدفي', #1
u'التدفي': u'التَّدَفِّيَ', #1
u'التدفي': u'التَّدَفِّي', #4
u'التذامر': u'التّذَامُرَ', #4
u'التذمم': u'التّذَمّمِ', #1
u'التذمم': u'التّذَمّمْ', #1
u'التذمم': u'التَّذَمُّمُ', #1
u'التذمم': u'التَّذَمُّمِ', #2
u'التر': u'التر', #1
u'الترا': u'التّرَا', #1
u'الترابص': u'التَّرَابُصِ', #1
u'الترات': u'التِّرَاتَ', #1
u'التراتيب': u'التَّرَاتِيبَ', #1
u'التراثا': u'التُّرَاثَا', #2
u'التراجيح': u'التَّرَاجِيحَ', #2
u'التراجيح': u'التَّرَاجِيحُ', #4
u'التراجيح': u'التَّرَاجِيحِ', #8
u'التراد': u'التَّرَادُّ', #10
u'التراد': u'التَّرَادِّ', #28
u'التراد': u'التَّرَادَّ', #6
u'التراسين': u'التَّرَّاسِينَ', #3
u'التراضى': u'التَّرَاضِى', #1
u'التراعي': u'التَّرَاعِي', #1
u'التراغمي': u'التراغِميّ', #1
u'التراغمي': u'التَّرَاغِمِيُّ', #1
u'التراق': u'التَّرَاقِ', #1
u'التراقيا': u'التَّرَاقِيَا', #1
u'التراكن': u'التَّرَاكُنَ', #1
u'التراكن': u'التَّرَاكُنُ', #2
u'التراكن': u'التَّرَاكُنِ', #9
u'الترامى': u'التَّرَامِى', #1
u'التربا': u'التّرْبَا', #2
u'التربجي': u'التُّرْبُجِيُّ', #1
u'التربعة': u'التَّرْبِعَةِ', #1
u'الترة': u'التّرَةِ', #1
u'الترة': u'التِّرَة', #1
u'الترة': u'التِّرَةُ', #1
u'الترترة': u'التَّرْتَرَةُ', #1
u'الترثية': u'التَّرْثِيَةِ', #1
u'الترثيث': u'التَّرْثِيثِ', #2
u'الترجمانى': u'التُّرْجُمَانِىُّ', #2
u'الترجمانى': u'التَّرْجُمَانِىُّ', #5
u'الترحة': u'التّرِحَةِ', #1
u'الترحل': u'التَّرَحُّلِ', #1
u'الترخص': u'التَّرَخُّص', #1
u'الترخص': u'التَّرَخُّصِ', #190
u'الترخص': u'التَّرَخُّصَ', #62
u'الترخص': u'التَّرَخُّصُ', #92
u'الترخصات': u'التَّرَخُّصَاتِ', #1
u'التردى': u'التَّرَدِّى', #1
u'الترزيق': u'التَّرْزِيقُ', #1
u'الترزيق': u'التَّرْزِيقِ', #1
u'الترشيش': u'التَّرْشِيشِ', #2
u'الترفيق': u'التَّرْفِيقُ', #1
u'الترقفي': u'التَّرَقُفِيُّ', #1
u'الترقفي': u'التَّرْقُفِيِّ', #1
u'الترقفي،': u'التُّرْقُفِيُّ،', #1
u'الترقفى': u'التَّرْقُفُىُّ', #1
u'الترقفي،': u'التَّرْقُفِيُّ،', #13
u'الترقفي': u'التَّرْقُفِيُّ', #2
u'الترقفى': u'التَّرْقُفِىُّ', #22
u'الترقفى': u'التُّرْقُفِىُّ', #4
u'الترقفي،': u'التَّرْقُفِيِّ،', #6
u'الترقيب': u'التَّرْقِيبِ', #2
u'الترقيح': u'التَّرْقِيحُ', #1
u'الترقيح': u'التَّرْقِيحِ', #3
u'التركه': u'التَّرِكَهْ', #2
u'الترمذى': u'التِّرِمِذِىِّ', #1
u'الترمذى': u'التِّرْمَذِىُّ', #1
u'الترمذى': u'التِّرْمِذِىِّ', #19
u'الترمذى': u'التِّرْمِذِىُّ', #72
u'الترمزي': u'الترمزي', #1
u'الترمزي،': u'الترمزي،', #1
u'الترنجبين': u'الترنجبين', #1
u'التروث': u'التَّرَوُّثِ', #1
u'التروك': u'التُّرُوكِ', #43
u'التروك': u'التُّرُوكَ', #6
u'التروك': u'التُّرُوكُ', #8
u'التروكات': u'التُّرُوكَاتِ', #1
u'الترويغ': u'التَّرْوِيغُ', #1
u'الترويغ': u'التَّرْوِيغِ', #3
u'التريب': u'التَّرَيُّبِ', #1
u'الترية': u'التَّرِيَةِ', #1
u'الترية': u'التَّرِيَّةَ', #1
u'الترية': u'التَّرِيَّةِ', #1
u'الترية': u'التِّرْيَةُ', #4
u'الترية': u'التَّرِيَّةُ', #6
u'التريئة': u'التَّرِيئَةُ', #1
u'التريئة': u'التَّرِيئَةَ', #2
u'التزاويق': u'التَّزَاوِيقِ', #1
u'التزريب': u'التَّزْرِيبَ', #1
u'التزريق': u'التَّزْرِيقُ', #1
u'التزريق': u'التَّزْرِيقِ', #2
u'التزعفر،': u'التزعفر،', #1
u'التزعفر': u'التَّزَعْفُرَ', #1
u'التزعفر': u'التَّزَعْفُرُ', #1
u'التزعفر': u'التَّزَعْفُرِ', #17
u'التزعفر،': u'التَّزَعْفُرِ،', #4
u'التزكيه': u'التَّزْكِيَهْ', #2
u'التزلع': u'التَّزَلُّعُ', #1
u'التزلق': u'التَّزَلُّق', #1
u'التزلق': u'التَّزَلُّقُ', #1
u'التزمنتي': u'التَّزْمَنْتِيِّ', #2
u'التزوجا': u'التَّزَوُّجَا', #1
u'التزويغ': u'التَّزْوِيغِ', #1
u'التزيد': u'التَّزَيُّدُ', #2
u'التزيد': u'التَّزَيُّدِ', #2
u'التزيدا': u'التَّزَيُّدَا', #1
u'التزيدية': u'التّزِيدِيّةُ', #2
u'التسارر': u'التَّسَارُرُ', #1
u'التسافل': u'التَّسَافُلُ', #1
u'التساكت': u'التَّسَاكُتِ', #3
u'التساوق': u'التَّسَاوُقَ', #1
u'التساوك': u'التَّسَاوُكِ', #2
u'التسبيت': u'التَّسْبِيتُ', #2
u'التسترى': u'التُّسْتَرِىِّ', #1
u'التسترى': u'التُّسْتَرِىُّ', #13
u'التسترى': u'التَّسْتُرِىُّ', #2
u'التسترى': u'التُّسْتُرِىُّ', #5
u'التسجيف': u'التَّسْجِيفِ', #1
u'التسجيف': u'التَّسْجِيفُ', #3
u'التسحب': u'التَّسَحُّبَ', #1
u'التسحب': u'التَّسَحُّبِ', #1
u'التسحب': u'التَّسَحُّبُ', #2
u'التسحر': u'التَّسَحُرِ', #1
u'التسحر': u'التَّسَحُّر', #1
u'التسحر': u'التَّسَحُّرُ', #15
u'التسحر': u'التَّسَحُّرَ', #8
u'التسحر': u'التَّسَحُّرِ', #9
u'التسخط': u'التَّسَخُّطِ', #12
u'التسخيم': u'التَّسْخِيمُ', #1
u'التسخيم': u'التَّسْخِيمِ', #5
u'التسرر': u'التَّسَرُّرِ', #1
u'التسرر': u'التَّسَرُّرَ', #3
u'التسرر': u'التَّسَرُّرُ', #4
u'التسرى': u'التَّسَرِّى', #1
u'التسرى': u'التَّسَرِّىَ', #1
u'التسري': u'التَّسَرِّي', #340
u'التسري': u'التَّسَرِّيَ', #41
u'التسعان': u'التُّسُعَانِ', #3
u'التسعان': u'التُّسْعَانِ', #5
u'التسعية': u'التِّسْعِيَّةَ', #1
u'التسقي': u'التَّسَقِّي', #1
u'التسلب': u'التَّسَلُّبَ', #1
u'التسليما': u'التَّسْلِيمَا', #1
u'التسليمة': u'التّسْلِيمَةَ', #1
u'التسليمة': u'التَّسْلِيمَةُ', #31
u'التسليمة': u'التَّسْلِيمَةَ', #39
u'التسليمة': u'التَّسْلِيمَةِ', #98
u'التسليمتان': u'التَّسْلِيمَتَانِ', #6
u'التسليمتين': u'التَّسْلِيمَتَيْنِ', #58
u'التسمح': u'التَّسَمُّحُ', #11
u'التسمح': u'التَّسَمُّحِ', #15
u'التسمح': u'التَّسَمُّحَ', #2
u'التسمن': u'التَّسَمُّنَ', #1
u'التسمى': u'التَّسَمِّى', #1
u'التسميه': u'التَّسْمِيهُ', #1
u'التسنبل': u'التَّسَنْبُلِ', #1
u'التسومة': u'التسومة', #1
u'التسويه': u'التَّسْوِيَهِ', #1
u'التسيار': u'التّسْيَارِ', #1
u'التسير': u'التَّسَيُّرُ', #1
u'التشابب': u'التَّشَابُبِ', #1
u'التشاحح': u'التَّشَاحُحِ', #5
u'التشادق': u'التَّشَادُقِ', #1
u'التشافع': u'التَّشَافُعِ', #1
u'التشاقق': u'التَّشَاقُقُ', #1
u'التشاقير': u'التَّشَاقِيرِ', #1
u'التشبيث': u'التَّشْبِيثَ', #1
u'التشبيها': u'التَّشْبِيهَا', #3
u'التشتي': u'التَّشَتِّي', #3
u'التشديخ': u'التَّشْدِيخِ', #2
u'التشديدة': u'التَّشْدِيدَةَ', #2
u'التشرع': u'التَّشَرُّعِ', #1
u'التشريج': u'التَّشْرِيجِ', #14
u'التشريج': u'التَّشْرِيجُ', #3
u'التشريج': u'التَّشْرِيجَ', #7
u'التشطر': u'التَّشَطُّرَ', #1
u'التشطر': u'التَّشَطُّرِ', #7
u'التشطية': u'التَّشْطِيَةِ', #1
u'التشغب': u'التَّشَغُّبُ', #1
u'التشقار': u'التِّشْقَارِ', #1
u'التشقيح': u'التَّشْقِيحُ', #1
u'التشقيص': u'التَّشْقِيصِ', #104
u'التشقيص': u'التَّشْقِيصُ', #23
u'التشقيص': u'التَّشْقِيصَ', #27
u'التشكية': u'التَّشْكِيَةُ', #1
u'التشكيكا': u'التَّشْكِيكَا', #2
u'التشهدا': u'التَّشَهُّدَا', #1
u'التشويص': u'التَّشْوِيصُ', #1
u'التشيخ': u'التَّشَيُّخُ', #1
u'التصاحيح': u'التَّصَاحِيحِ', #1
u'التصارف': u'التَّصَارُفُ', #1
u'التصارف': u'التَّصَارُفِ', #2
u'التصاون': u'التَّصَاوُنُ', #1
u'التصاون': u'التَّصَاوُنِ', #2
u'التصرخ': u'التَّصَرُّخَ', #1
u'التصرفا': u'التَّصَرُّفَا', #2
u'التصرية': u'التصرية', #1
u'التصرية': u'التَّصْرِيَةَ', #33
u'التصرية،': u'التَّصْرِيَةِ،', #4
u'التصرية': u'التَّصْرِيَةُ', #45
u'التصرية': u'التَّصْرِيَة', #6
u'التصرية': u'التَّصْرِيَةِ', #92
u'التصريج': u'التَّصْرِيجُ', #1
u'التصريحتين': u'التَّصْرِيحَتَيْنِ', #1
u'التصريفيون': u'التَّصْرِيفِيُّونَ', #2
u'التصفيقة': u'التَّصْفِيقَةِ', #1
u'التصمر': u'التَّصَمُّرِ', #1
u'التصوين': u'التَّصْوِينُ', #1
u'التصوين': u'التَّصْوِينِ', #1
u'التصير': u'التَّصَيُّرَ', #2
u'التصين': u'التَّصَيُّنِ', #1
u'التضاريب': u'التَّضَارِيبَ', #1
u'التضبب': u'التَّضَبُّبِ', #1
u'التضبب': u'التَّضَبُّبُ', #2
u'التضبيب': u'التَّضْبِيبُ', #12
u'التضبيب': u'التَّضْبِيبَ', #2
u'التضبيب': u'التَّضْبِيبِ', #8
u'التضحي': u'التَّضَحِّي', #2
u'التضرية': u'التَّضْرِيَةُ', #1
u'التضرية': u'التَّضْرِيَةِ', #1
u'التضعف': u'التَّضَعُّفِ', #1
u'التضمير': u'التَّضْمِير', #2
u'التطامن': u'التَّطَامُنُ', #4
u'التطرية': u'التَّطْرِيَةِ', #1
u'التطعم': u'التَّطَعُّمِ', #8
u'التطفية': u'التَّطْفِيَةِ', #1
u'التطفيل': u'التَّطْفِيلِ', #1
u'التطلق': u'التَّطَلُّقُ', #1
u'التطلقتين': u'التَّطَلُّقَتَيْنِ', #1
u'التطلي': u'التَّطَلِّي', #1
u'التطليقة؟،': u'التَّطْلِيقَةِ؟،', #1
u'التطليقة؟': u'التَّطْلِيقَةُ؟', #2
u'التطليقة': u'التَّطْلِيقَةُ', #28
u'التطليقة': u'التَّطْلِيقَة', #4
u'التطليقة؟': u'التَّطْلِيقَةِ؟', #4
u'التطليقة': u'التَّطْلِيقَةَ', #77
u'التطليقة': u'التَّطْلِيقَةِ', #99
u'التطليقتان': u'التَّطْلِيقَتَانِ', #10
u'التطليقتين': u'التَّطْلِيقَتَيْنِ', #56
u'التطمث': u'التَّطَمُّثِ', #1
u'التطمع': u'التَّطَمُّع', #1
u'التطوق': u'التَّطَوُّقِ', #2
u'التطول': u'التَّطَوُّلَ', #1
u'التطول': u'التَّطَوُّلِ', #1
u'التطيلس': u'التَّطَيْلُسَ', #2
u'التطيلس': u'التَّطَيْلُسِ', #4
u'التطين': u'التَّطَيُّنُ', #1
u'التطين': u'التَّطَيُّنِ', #8
u'التظهر': u'التَّظَهُّرِ', #1
u'التعاذير': u'التَّعَاذِيرَ', #1
u'التعاذير': u'التَّعَاذِيرُ', #1
u'التعاذير': u'التَّعَاذِيرِ', #2
u'التعاريض': u'التَّعَارِيضِ', #1
u'التعازير': u'التَّعَازِيرِ', #20
u'التعازير': u'التَّعَازِيرَ', #7
u'التعازير': u'التَّعَازِيرُ', #8
u'التعاسيف': u'التَّعَاسِيفَ', #1
u'التعاسيف': u'التَّعَاسِيفُ', #1
u'التعاسيف': u'التَّعَاسِيفِ', #19
u'التعاشير': u'التَّعَاشِيرُ', #1
u'التعاشير': u'التَّعَاشِيرِ', #1
u'التعاقل': u'التَّعَاقُلَ', #10
u'التعاقل': u'التَّعَاقُلُ', #4
u'التعاقل': u'التَّعَاقُلِ', #4
u'التعان': u'الْتِعَانِ', #4
u'التعانا': u'الْتِعَانًا', #1
u'التعانه': u'الْتِعَانُهُ', #2
u'التعانه': u'الْتِعَانِهِ', #7
u'التعانها': u'الْتِعَانُهَا', #1
u'التعانها': u'الْتِعَانِهَا', #6
u'التعانهما': u'الْتِعَانِهِمَا', #5
u'التعاني': u'التَّعَانِي', #1
u'التعاوض': u'التَّعَاوُضَ', #1
u'التعاوض': u'التَّعَاوُضِ', #1
u'التعاوض': u'التَّعَاوُضُ', #7
u'التعته': u'التَّعَتُّهُ', #1
u'التعجيلا': u'التَّعْجِيلَا', #1
u'التعدى': u'التَّعَدِّى', #3
u'التعرى': u'التَّعَرِّى', #1
u'التعريص': u'التَّعْرِيصُ', #4
u'التعريك': u'التَّعْرِيكُ', #1
u'التعزيل': u'التَّعْزِيلِ', #2
u'التعزيل': u'التَّعْزِيلُ', #3
u'التعصيبة': u'التَّعْصِيبَةُ', #1
u'التعصيبتين': u'التَّعْصِيبَتَيْنِ', #1
u'التعصية': u'التَّعْصِيَةُ', #2
u'التعصية': u'التَّعْصِيَةِ', #3
u'التعضوض': u'التَّعْضُوضَ', #2
u'التعفيش': u'التَّعْفِيشُ', #1
u'التعفيش': u'التَّعْفِيشِ', #3
u'التعفيف': u'التَّعْفِيفِ', #1
u'التعقيص': u'التَّعْقِيصَ', #1
u'التعكيس': u'التَّعْكِيسُ', #1
u'التعلقة': u'التَّعْلِقَةِ', #1
u'التعليقا': u'التَّعْلِيقَا', #1
u'التعليقه': u'التَّعْلِيقَهْ', #1
u'التعليما': u'التَّعْلِيمَا', #1
u'التعنن': u'التَّعَنُّنِ', #2
u'التعوار': u'التِّعْوَارِ', #1
u'التعيب': u'التَّعَيُّبَ', #18
u'التعيب': u'التَّعَيُّبُ', #38
u'التعيب': u'التَّعَيُّبِ', #49
u'التعيد': u'التَّعَيُّدِ', #2
u'التعير': u'التَّعَيُّرَ', #1
u'التعير': u'التَّعَيُّرِ', #1
u'التعيينا': u'التَّعْيِينَا', #2
u'التغاذي': u'التَّغَاذِي', #1
u'التغاطي': u'التَّغَاطِي', #1
u'التغالبة': u'التَّغَالِبَةِ', #1
u'التغالي': u'التَّغَالِي', #13
u'التغالي': u'التَّغَالِيَ', #2
u'التغاليب': u'التَّغَالِيبِ', #1
u'التغبير': u'التَّغْبِيرُ', #2
u'التغبير': u'التَّغْبِيرِ', #4
u'التغبير': u'التَّغْبِيرَ', #9
u'التغزير': u'التَّغْزِير', #1
u'التغسل': u'التَّغَسُّلُ', #1
u'التغلبى': u'التَّغْلِبِىِّ', #1
u'التغلبى': u'التَّغْلِبِىُّ', #5
u'التغوير': u'التّغْوِيرِ', #3
u'التغويط': u'التَّغْوِيط', #1
u'التغي': u'التَّغَيِّ', #1
u'ألتفا': u'أَلْتَفَّا', #1
u'التفاتة': u'الْتِفَاتَةِ', #1
u'التفاتة،': u'الْتِفَاتَةٌ،', #1
u'التفاتة': u'اِلْتِفَاتَة', #1
u'التفاتة': u'الْتِفَاتَةٌ', #14
u'التفاتة': u'الْتِفَاتَة', #2
u'التفاريع': u'التَّفَارِيعِ', #19
u'التفاريع': u'التَّفَارِيعُ', #5
u'التفاصل': u'التَّفَاصُلِ', #3
u'التفاوتا': u'التَّفَاوُتَا', #1
u'التفة': u'التَّفَّة', #1
u'التفة': u'التُّفَّةُ', #1
u'التفتازاني': u'التَّفْتَازَانِيُّ', #257
u'التفتازاني': u'التَّفْتَازَانِي', #3
u'التفتازاني': u'التَّفْتَازَانِيِّ', #62
u'التفتازاني': u'التَّفْتَازَانِيَّ', #7
u'التفث': u'التَّفِثُ', #1
u'التفث': u'التَّفَثَ', #12
u'التفث': u'التَّفَثِ', #121
u'التفث': u'التفث', #2
u'التفث': u'التَّفَث', #3
u'التفث': u'التَّفَثُ', #7
u'التفرح': u'التَّفَرُّحِ', #1
u'التفرخ': u'التَّفَرُّخِ', #1
u'التفرش': u'التَّفَرُّشَ', #1
u'التفرط': u'التَّفَرُّطِ', #1
u'التفرك': u'التَّفَرُّكِ', #1
u'التفروق': u'التُّفْرُوقُ', #1
u'التفشيلة': u'التَّفْشِيلَةَ', #1
u'التفصى': u'التفصى', #3
u'التفصيلة': u'التَّفْصِيلَةُ', #1
u'التفع': u'الْتَفَعَ', #3
u'التفعال': u'التِّفْعَالِ', #2
u'التفعل': u'التَّفَعُّلَ', #1
u'التفعل': u'التَّفَعُّلُ', #2
u'التفعل': u'التَّفَعُّلِ', #26
u'التفعلل': u'التَّفَعْلُلِ', #1
u'التفلة': u'التَّفِلَة', #1
u'التفلس': u'التَّفَلُّسِ', #1
u'التفوت': u'التَّفَوُّتِ', #1
u'التفوض': u'التَّفَوُّضِ', #1
u'التفول': u'التُّفُولِ', #1
u'التقابح': u'التقابح', #1
u'التقادر': u'التَّقَادُرَ', #1
u'التقادير': u'التَّقَادِيرِ', #103
u'التقادير': u'التَّقَادِير', #2
u'التقادير': u'التَّقَادِيرَ', #4
u'التقادير': u'التَّقَادِيرُ', #4
u'التقار': u'التَّقَارَّ', #2
u'التقاص': u'التَّقَاصِّ', #114
u'التقاص': u'التَّقَاصُّ', #161
u'التقاص': u'التَّقَاصَّ', #21
u'التقاصص': u'التَّقَاصُصِ', #1
u'التقاصي': u'التَّقَاصِي', #1
u'التقاضى': u'التَّقَاضِى', #3
u'التقاضيا': u'التَّقَاضِيَا', #2
u'إلتقاطها': u'إلتقاطها', #1
u'التقايؤ': u'التَّقَايُؤ', #1
u'التقايؤ': u'التَّقَايُؤُ', #3
u'التقايؤ': u'التَّقَايُؤِ', #7
u'التقاييد': u'التَّقَايِيدُ', #1
u'التقاييد': u'التَّقَايِيدِ', #10
u'التقحل': u'التَّقَحُّلَ', #4
u'التقديما': u'التَّقْدِيمَا', #1
u'التقرش': u'التّقَرّشَ', #1
u'التقرش': u'التَّقَرُّشُ', #1
u'التقرش': u'التّقَرّشُ', #2
u'التقرش': u'التّقَرّشِ', #4
u'التقطتيه': u'التقطتيه', #1
u'التقعدد': u'التَّقَعْدُدُ', #2
u'التقعس': u'التَّقَعُّسِ', #1
u'التقلح': u'التَّقَلُّحِ', #1
u'التقلل': u'التَّقَلُّلُ', #1
u'التقلل': u'التَّقَلُّلَ', #4
u'التقلل': u'التَّقَلُّلِ', #6
u'التقليس': u'التَّقْلِيس', #2
u'التقليس': u'التَّقْلِيسِ', #2
u'التقليس': u'التَّقْلِيسُ', #3
u'التقواد': u'التّقْوَادِ', #2
u'التقور': u'التَّقَوُّرِ', #2
u'التقويما': u'التَّقْوِيمَا', #1
u'التكأة': u'التّكَأَةُ', #1
u'التكأة': u'التُّكَأَةَ', #1
u'التكاميش': u'التَّكَامِيشِ', #1
u'التكاميش': u'التَّكَامِيشُ', #10
u'التكبيرفي': u'التَّكْبِيرَفِي', #1
u'التكدي': u'التَّكَدِّي', #17
u'التكذيبوالوجه': u'التَّكْذِيبِوَالْوَجْهُ', #1
u'التكرور': u'التَّكْرُورِ', #10
u'التكريب': u'التَّكْرِيبُ', #4
u'التكريب': u'التَّكْرِيبِ', #6
u'التكشط': u'التَّكَشُّطَ', #1
u'التكشط': u'التَّكَشُّطُ', #4
u'التكفر': u'التَّكَفُّرِ', #1
u'التكلان': u'التُّكْلاَنُ', #1
u'التكلان': u'التُّكْلَانُ', #9
u'التكلب': u'التكلب', #1
u'التكلب': u'التَّكَلُّبِ', #1
u'التكلثم': u'التَّكَلْثُمُ', #1
u'التكلثم': u'التَّكَلْثُمِ', #1
u'التكلما': u'التَّكَلُّمَا', #1
u'التكنى': u'التَّكَنِّى', #2
u'التكهل': u'التَّكَهُّلِ', #1
u'التكهين': u'التَّكْهِينِ', #2
u'التلا': u'التّلَا', #2
u'التلابس': u'التَّلَابُسِ', #1
u'التلأبيبة': u'التّلَأْبِيبَةُ', #1
u'التلاتل': u'التّلَاتِلُ', #1
u'التلاح': u'التَّلَاحِ', #1
u'التلاد': u'التِّلَادَ', #1
u'التلاد': u'التّلَادَ', #2
u'التلاعة': u'التَّلَاعَةُ', #2
u'التلاعة': u'التَّلَاعَةِ', #2
u'التلاف': u'التَّلَافِ', #1
u'التلاف': u'التَّلَافَ', #2
u'التلاق': u'التَّلَاقَ', #1
u'التلاق': u'التَّلَاقِ', #5
u'التلاق': u'التَّلَاقُ', #6
u'التلب': u'التلب', #1
u'التلب': u'التَّلِبَ', #1
u'التلب': u'التَّلِبِ', #1
u'التلب،': u'التَّلِبُ،', #1
u'التلب،': u'التَّلِبِ،', #1
u'التلبينة': u'التلبينة', #1
u'التلبينة': u'التَّلْبِينَةُ', #11
u'التلبينة': u'التَّلْبِينَةَ', #4
u'التلبيه': u'التَّلْبِيَهْ', #1
u'التلتلة': u'التَّلْتَلَةُ', #1
u'التلجم': u'التَّلَجُّمُ', #2
u'التلجم': u'التَّلَجُّمِ', #2
u'التلحلح': u'التّلَحْلُحَ', #1
u'التلحن': u'التَّلَحُّنِ', #1
u'التلحي': u'التَّلَحِّيَ', #1
u'التلحي': u'التَّلَحِّي', #3
u'التلحية': u'التَّلْحِيَةِ', #1
u'التلحية': u'التَّلْحِيَةَ', #3
u'التلذذا': u'التَّلَذُّذَا', #1
u'التلعفري': u'التَّلَعْفَرِيِّ', #1
u'التلفات': u'التَّلِفَاتِ', #1
u'التلفع': u'التَّلَفُّع', #1
u'التلفع': u'التَّلَفُّعَ', #1
u'التلفع': u'التَّلَفُّعُ', #2
u'التلق': u'التَّلَقٍّ', #1
u'التلقى': u'التَّلَقِّى', #5
u'التلمح': u'التَّلَمُّحِ', #1
u'التلمساني': u'التِّلِمْسَانِيَّ', #1
u'التلمساني': u'التِّلْمِسَانِيَّ', #1
u'التلمساني': u'التِّلْمِسَانِيُّ', #17
u'التلمساني': u'التِّلْمِسَانِيِّ', #18
u'التلمساني': u'التِّلِمْسَانِيُّ', #23
u'التلمساني': u'التِّلِمْسَانِيِّ', #29
u'التلمسانية': u'التِّلْمِسَانِيَّة', #13
u'التلمسانية': u'التِّلْمِسَانِيَّةِ', #4
u'التلمظ': u'التَّلَمُّظُ', #1
u'التلوط': u'التَّلَوُّطِ', #1
u'التلياني': u'التلياني', #1
u'التليس': u'التَّلِّيسُ', #1
u'التلييس': u'التَّلْيِيسَ', #1
u'التلييس': u'التَّلْيِيسِ', #1
u'التمادى': u'التَّمَادِىِّ', #1
u'التمادى': u'التَّمَادِى', #2
u'التمالؤ': u'التَّمَالُؤ', #1
u'التمالؤ': u'التَّمَالُؤَ', #1
u'التمالؤ': u'التَّمَالُؤِ', #16
u'التمالؤ': u'التَّمَالُؤُ', #3
u'التمالي': u'التَّمَالِي', #2
u'التماما': u'التَّمَامَا', #3
u'التمانع': u'التَّمَانُعَ', #1
u'التمانع': u'التَّمَانُعِ', #14
u'التمانع': u'التَّمَانُعُ', #29
u'ألتمة': u'أَلَتْمَة', #2
u'التمتان': u'التِّمْتَانَ', #1
u'التمتانين': u'التِّمْتَانَيْنِ', #1
u'التمجاني': u'التِّمْجَانِيِّ', #4
u'التمجس': u'التَّمَجُّسُ', #1
u'التمجس': u'التَّمَجُّسِ', #5
u'التمحاني': u'التَّمْحَانِيِّ', #2
u'التمحض': u'التَّمَحُّضُ', #1
u'التمحض': u'التَّمَحُّضِ', #7
u'التمحل': u'التَّمَحُّلَ', #1
u'التمحل': u'التَّمَحُّلُ', #3
u'التمحل': u'التَّمَحُّلِ', #6
u'التمحلات': u'التَّمَحُّلَاتِ', #4
u'التمحيض': u'التَّمْحِيضَ', #1
u'التمخي': u'التَّمَخِّي', #3
u'التمدح': u'التَّمَدُّحِ', #10
u'التمدح': u'التَّمَدُّحَ', #3
u'التمدح': u'التَّمَدُّحُ', #5
u'التمرا': u'التَّمْرَا', #2
u'التمرتاشي': u'التُّمُرْتَاشِيّ', #1
u'التمرتاشي': u'التُّمُرْتَاشِيِّ', #226
u'التمرتاشي': u'التُّمُرْتَاشِيُّ', #263
u'التمرتاشي': u'التُّمُرْتَاشِيَّ', #5
u'التمرتاشية': u'التُّمُرْتَاشِيَّةِ', #2
u'التمرشك': u'التَّمْرِشَكَّ', #1
u'التمرهندي': u'التَّمْرُهِنْدِيِّ', #1
u'إلتمس': u'إلتَمسَ', #1
u'التمش': u'التمش', #1
u'التمشك': u'التَّمَشُّك', #1
u'التمشك': u'التَّمَشُّكِ', #1
u'التمشك': u'التَّمَشُّكْ', #1
u'التمشك': u'التَّمَشُّكُ', #2
u'التمعش': u'التَّمَعُّشِ', #5
u'التمعش': u'التَّمَعُّشُ', #6
u'التمعك': u'التَّمَعُّك', #1
u'التمعك': u'التَّمَعُّكِ', #15
u'التمعك': u'التَّمَعُّكَ', #2
u'التمعيش': u'التَّمْعِيشُ', #1
u'التمعيش': u'التَّمْعِيشِ', #1
u'التميم': u'التَّمِيم', #1
u'التميم': u'التَّمِيمُ', #1
u'التميم': u'التَّمِيمِ', #3
u'التميمى': u'التَّمِيمِىُّ', #158
u'التميمى': u'التَّمِيمِىِّ', #18
u'التميمى': u'التَّمِيمِىَّ', #5
u'التميميون': u'التّمِيمِيّونَ', #1
u'التنابلة': u'التّنَابِلَةُ', #1
u'التنابيل': u'التَّنَابِيلُ', #4
u'التنابيل': u'التّنَابِيلُ', #5
u'التنابيه': u'التَّنَابِيهِ', #2
u'التناجز': u'التَّنَاجُزِ', #15
u'التناجز': u'التَّنَاجُزُ', #16
u'التناجز': u'التَّنَاجُزَ', #6
u'التناجش': u'التَّنَاجُشُ', #1
u'التناجش،': u'التَّنَاجُشِ،', #1
u'التناضب': u'التّناضِبَ', #1
u'التناضب': u'التّنَاضُبِ', #1
u'التناضب': u'التّنَاضِبِ', #1
u'التناضب': u'التَّنَاضُبُ', #1
u'التناضب': u'التَّنَاضِبَ', #1
u'التناضب': u'التَّنَاضِبِ', #1
u'التناضب': u'التّنَاضِبَ', #2
u'التناضب': u'التَّنَاضِبُ', #3
u'التنافذ': u'التَّنَافُذِ', #2
u'التنافذ': u'التَّنَافُذُ', #4
u'التنافيذ': u'التَّنَافِيذِ', #1
u'التنافيذ': u'التَّنَافِيذَ', #4
u'التناقد': u'التَّنَاقُدَ', #1
u'التناكل': u'التَّنَاكُلِ', #1
u'التنباك': u'التُّنْبَاكُ', #1
u'التنباك': u'التُّنْبَاكِ', #4
u'التنبكتي': u'التنبكتي', #1
u'التنبكتي': u'التَّنْبَكْتِيُّ', #2
u'التنبي': u'التَّنَبِّي', #2
u'التنبيل': u'التَّنْبِيلِ', #1
u'التنبيهة': u'التّنْبِيهَةِ', #1
u'التنجي': u'التَّنَجِّي', #2
u'التنحى': u'التَّنَحِّى', #1
u'التنخم': u'التَّنَخُّمَ', #1
u'التنخم': u'التَّنَخُّمُ', #1
u'التنخم': u'التَّنَخُّمِ', #1
u'التنديم': u'التَّنْدِيمِ', #1
u'التنزية': u'التَّنْزِيَةِ', #6
u'التنزيغ': u'التَّنْزِيغُ', #1
u'التنسيم': u'التَّنْسِيمَ', #1
u'التنضاض': u'التَّنْضَاضُ', #1
u'التنضال': u'التِّنْضَالُ', #1
u'التنضب': u'التَّنَضُّبِ', #1
u'التنضب': u'التّنْضُبِ', #2
u'التنضباوي': u'التَّنْضَبَاوِيّ', #1
u'التنضيض': u'التَّنْضِيضِ', #10
u'التنضيض': u'التَّنْضِيضَ', #8
u'التنضيض': u'التَّنْضِيضُ', #8
u'التنطف': u'التَّنَطُّفُ', #1
u'التنطف': u'التَّنَطُّفِ', #1
u'التنطيع': u'التَّنْطِيعِ', #1
u'التنظفا': u'التَّنَظُّفَا', #2
u'التنعي': u'التَّنعي', #1
u'التنعيل': u'التَّنْعِيلِ', #3
u'التنعيمة': u'التّنْعِيمَةِ', #1
u'التنفر': u'التَّنَفُّر', #1
u'التنفر': u'التَّنَفُّرِ', #1
u'التنفلا': u'التَّنَفُّلَا', #2
u'التنفلفيه': u'التَّنَفُّلِفِيهِ', #1
u'التنفلقبل': u'التَّنَفُّلِقَبْلَ', #1
u'التنقيث': u'التنقيث', #2
u'التنمص': u'التَّنَمُّص', #1
u'التنمص': u'التَّنَمُّصِ', #1
u'التنميص': u'التَّنْمِيصُ', #2
u'التنميص': u'التَّنْمِيصِ', #2
u'التنوخي': u'التنوخيّ', #1
u'التنوخي،': u'التنوخي،', #1
u'التنوخي': u'التّنُوخِيّ', #1
u'التنوخي،': u'التَّنُوخِيُّ،', #1
u'التنوخى': u'التَّنُوخِىَّ', #1
u'التنوخى': u'التَّنُّوخِىُّ', #1
u'التنوخي': u'التَّنُوخِيُّ', #10
u'التنوخي': u'التَّنُوخِيِّ', #12
u'التنوخي': u'التّنّوخِيّ', #2
u'التنوخي،': u'التَّنُوخِيِّ،', #2
u'التنوخى': u'التَّنُوخِىُّ', #27
u'التنوخي': u'التَّنُوخِيَّ', #5
u'التنوخى': u'التَّنُوخِىِّ', #6
u'التنورمن': u'التَّنُّورُمِنْ', #1
u'التنوفة': u'التّنُوفَةُ', #1
u'التنويما': u'التَّنْوِيمَا', #1
u'التنيسي،': u'التنيسي،', #1
u'التنيسي': u'التِّنِّيسِيَّ', #1
u'التنيسي،': u'التِّنِّيسِيَّ،', #1
u'التنيسي،': u'التِّنِّيسِيُّ،', #12
u'التنيسى': u'التِّنِّيسِىُّ', #12
u'التنيسي،': u'التِّنِّيسِيِّ،', #2
u'التنيسي': u'التِّنِّيسِيُّ', #3
u'التنيسي': u'التِّنِّيسِيِّ', #3
u'التهارج': u'التَّهَارُجِ', #7
u'التهازل': u'التَّهَازُلِ', #1
u'التهازل': u'التّهَازُلِ', #2
u'التهاليل': u'التَّهَالِيلِ', #1
u'التهانؤ': u'التَّهَانُؤُ', #1
u'التهاول': u'التّهاوُل', #1
u'التهاول': u'التّهَاوُلِ', #2
u'التهايل': u'التَّهَايُلُ', #1
u'التهايؤ': u'التَّهَايُؤَ', #52
u'التهايؤ': u'التَّهَايُؤِ', #71
u'التهايؤ': u'التَّهَايُؤُ', #88
u'التهدي': u'التَّهَدِّي', #2
u'التهرش': u'التَّهَرُّشُ', #1
u'التهري': u'التَّهَرِّي', #1
u'التهزي': u'التَّهَزِّي', #3
u'التهزي': u'التَّهَزِّيَ', #3
u'التهضم': u'التَّهَضُّمِ', #2
u'التهليلة': u'التَّهْلِيلَةُ', #1
u'التهليلة': u'التَّهْلِيلَةِ', #1
u'التهمم': u'التَّهَمُّمُ', #3
u'التهوع': u'التَّهَوُّعَ', #1
u'التهوك': u'التَّهَوُّكَ', #1
u'التهوك': u'التَّهَوُّكِ', #1
u'التوءمان': u'التّوْءمان', #1
u'التوءمة': u'التّوْءَمَةِ', #1
u'التوءمة': u'التَّوْءَمَةِ', #1
u'التوءمة،': u'التَّوْءَمَةِ،', #1
u'التواجب': u'التَّوَاجُبِ', #46
u'التواجيه': u'التَّوَاجِيهِ', #1
u'التوارة،': u'التَّوْارَةِ،', #1
u'التوارة؟': u'التَّوْارَةِ؟', #1
u'التوارة': u'التَّوْارَةُ', #2
u'التوارة': u'التَّوْارَةِ', #3
u'التواره': u'التواره', #1
u'التواسي': u'التَّوَاسِي', #1
u'التواسي': u'التواسي', #2
u'التوالتمة': u'التوالتمة', #1
u'التواليا': u'التَّوَالِيَا', #2
u'التؤام': u'التُّؤَام', #1
u'التؤامة': u'التَّؤْامَةِ', #1
u'التوامق': u'التّوَامُقُ', #1
u'التوامق': u'التّوَامُقِ', #1
u'التوتيا': u'التُّوتْيَا', #1
u'التوثقة': u'التَّوْثِقَةِ', #11
u'التوثقة': u'التَّوْثِقَةُ', #2
u'التوثقة': u'التَّوْثِقَةَ', #3
u'التوثن': u'التَّوَثُّنُ', #1
u'التوثن': u'التَّوَثُّنِ', #3
u'التوحية': u'التَّوْحِيَةِ', #1
u'التوحية': u'التَّوْحِيَةُ', #4
u'التوحيدا': u'التَّوْحِيدَا', #1
u'التور': u'التَّوْر', #1
u'التور': u'التَّوْرِ', #30
u'التور': u'التَّوْرَ', #4
u'التور': u'التَّوْرُ', #6
u'التور': u'التور', #7
u'التوراةوالوجه': u'التَّوْرَاةَوَالْوَجْهُ', #1
u'التوربشتي': u'التُّورْبَشَتَّي', #1
u'التوربشتي': u'التُّورْبَشْتِيّ', #1
u'التوربشتي': u'التوربشتي', #15
u'التوربشتي': u'التُّورْبَشْتِيُّ', #17
u'التوربشتي': u'التُّورْبَشْتِيِّ', #3
u'التورة': u'التَّوْرَةِ', #1
u'التورق': u'التَّوَرُّقَ', #1
u'التورق': u'التَّوَرُّقُ', #1
u'التورق': u'التَّوَرُّقِ', #6
u'التوريخ': u'التَّوْرِيخِ', #1
u'التوريض': u'التَّوْرِيضِ', #1
u'التوزي': u'التَّوْزِيُّ', #1
u'التوزى': u'التَّوْزِىُّ', #1
u'التوزى': u'التُّوزِىُّ', #2
u'التوزية': u'التوزية', #1
u'التوسوس': u'التَّوَسْوُسِ', #1
u'التوصف': u'التَّوَصُّفِ', #1
u'التوصيه': u'التَّوْصِيَهْ', #1
u'التوضي': u'التَّوَضِّي', #13
u'التوضيء': u'التَّوْضِيء', #1
u'التوضيء': u'التَّوْضِيءِ', #1
u'التوقادي': u'التَّوْقَادِيُّ', #1
u'التوقان': u'التَّوَقَانُ', #13
u'التوقان': u'التَّوَقَانِ', #47
u'التوقان': u'التَّوَقَانَ', #5
u'التوقاني': u'التَّوَقَانِيُّ', #1
u'التوقت': u'التَّوَقُّتِ', #1
u'التوقت': u'التَّوَقُّتُ', #2
u'التوقى': u'التَّوَقِّى', #1
u'التوكيلا': u'التَّوْكِيلَا', #5
u'التول': u'التَّوْلُ', #1
u'التولاء': u'التَّوْلَاءَ', #1
u'التولاء': u'التَّوْلَاءِ', #1
u'التولاء': u'التَّوْلَاءُ', #2
u'التولب': u'التّوْلَبِ', #1
u'التولة': u'التَّوَلَةُ', #1
u'التولة': u'التُّوَلَةِ', #1
u'التولة': u'التِّوَلَةُ', #1
u'التولة': u'التُّوَلَةُ', #3
u'التولة': u'التُّوَلَةَ', #4
u'التولى': u'التَّوَلِّى', #1
u'التولى': u'التَّوْلَى', #2
u'التوم': u'التُّومَ', #1
u'التوم': u'التُّومُ', #1
u'التوم': u'التُّومِ', #1
u'التوم': u'التّوَمِ', #1
u'التوم': u'التَّوْمَ', #2
u'التوم': u'التَّوْمِ', #2
u'التومان': u'التّوْمَانِ', #2
u'التومة': u'التُّومَةَ', #1
u'التومة': u'التّوَمَةِ', #1
u'التومة': u'التَّوْمَةِ', #2
u'التومنى': u'التُّوْمَنِىُّ', #1
u'التومه': u'التّوَمَه', #1
u'التويكى': u'التُّويَكِىُّ', #1
u'ألتى': u'أَلْتَى', #1
u'إلتي': u'إلَتِي', #1
u'التي': u'الَّتًي', #1
u'التى': u'الْتِى', #1
u'التى': u'التى', #97
u'التى': u'الَّتِى', #983
u'التيا': u'التّيّا', #2
u'التيابين': u'التَّيَّابِينَ', #2
u'التياح': u'التياح', #1
u'التياح': u'التَّيَّاحِ', #179
u'التياح': u'التّيّاحِ', #3
u'التياح،': u'التَّيَّاحِ،', #45
u'التياح،': u'التياح،', #6
u'التيامه': u'الْتِيَامَهُ', #1
u'التيامه': u'الْتِيَامُهُ', #2
u'التيبس': u'التَّيَبُّسِ', #1
u'التيتل': u'التَّيْتَلُ', #2
u'التيسيرا': u'التَّيْسِيرَا', #1
u'التيصلى': u'الَّتِيصَلَّى', #1
u'التيلة': u'التِّيلَةِ', #1
u'التيمار': u'التَّيْمَارَ', #1
u'التيمار': u'التَّيْمَارِ', #15
u'التيمارات': u'التَّيْمَارَاتِ', #1
u'التيمارخانه': u'التيمارخانه', #1
u'التيماري': u'التَّيْمَارِيُّ', #14
u'التيماري': u'التَّيْمَارِيِّ', #14
u'التيماري': u'التَّيْمَارِيَّ', #2
u'التيمارية': u'التَّيْمَارِيَّةِ', #1
u'التيماريين': u'التَّيْمَارِيِّينَ', #3
u'التيمما': u'التَّيَمُّمَا', #4
u'التيمى': u'التَّيْمِىُّ', #136
u'التيمى': u'التيمى', #2
u'التيمى': u'التَّيْمِىِّ', #203
u'التيمى': u'التَّيْمِىَّ', #22
u'التينجان': u'التّيْنُجَانَ', #1
u'التينجان': u'التّيْنُجَانُ', #1
u'التينجان': u'التّيْنُجَانِ', #1
u'التينجان': u'التّيْنُجان', #3
u'الثابتو': u'الثَّابِتُو', #1
u'الثأد': u'الثَّأَدِ', #2
u'الثار': u'الثَّارِّ', #1
u'الثأط': u'الثَّأْطُ', #1
u'الثاط؟': u'الثاط؟', #1
u'الثأل': u'الثَّأْلُ', #1
u'الثالة': u'الثَّالَّةِ', #1
u'الثالثه،': u'الثالثه،', #1
u'الثان': u'الثَّانِ', #2
u'الثانى': u'الثانى', #1
u'الثانى': u'الثَّانِىَ', #10
u'الثانى': u'الثَّانِى', #66
u'الثانيةثم': u'الثَّانِيَةَثُمَّ', #1
u'الثانيةفاستفتح': u'الثَّانِيَةَفَاسْتَفْتَحَ', #1
u'الثانيه': u'الثانيه', #1
u'الثانيه': u'الثَّانِيَهْ', #5
u'الثاوي': u'الثَّاوِي', #2
u'الثبة': u'الثُّبَةُ', #1
u'الثبة': u'الثُّبَةِ', #1
u'الثبث': u'الثَّبْثُ', #1
u'الثبج': u'الثبج', #1
u'الثبج': u'الثَّبَجُ', #2
u'الثبطة': u'الثَّبِطَةُ', #1
u'الثبطة': u'الثبطة', #2
u'الثجج': u'الثَّجَجِ', #1
u'الثجير': u'الثَّجِيرَ', #1
u'الثجير': u'الثَّجِيرُ', #11
u'الثجير': u'الثَّجِيرِ', #5
u'الثحامي': u'الثَّحَامِيِّ', #1
u'الثخانة': u'الثَّخَانَةَ', #1
u'الثخانة': u'الثَّخَانَةُ', #2
u'الثخانة': u'الثَّخَانَةِ', #7
u'الثخن': u'الثِّخَنَ', #1
u'الثخن': u'الثِّخَنِ', #2
u'الثخن': u'الثِّخَنُ', #5
u'الثدنة': u'الثّدَنَةِ', #1
u'الثدى': u'الثُّدِىَّ', #1
u'الثدى': u'الثَّدْىَ', #2
u'الثدى': u'الثَّدْىِ', #2
u'الثدى': u'الثُّدَىِّ', #2
u'الثدية': u'الثِّدْيَةِ', #1
u'الثدية': u'الثّدَيّةِ', #2
u'الثدية': u'الثُّدَيَّةِ', #8
u'الثر': u'الثّرْ', #1
u'الثرارى': u'الثَّرَارِىُّ', #1
u'الثرب': u'الثُّرُبَ', #1
u'الثرب،': u'الثَّرْبِ،', #1
u'الثرب': u'الثَّرْبِ', #8
u'الثرة': u'الثّرّةِ', #1
u'الثرة': u'الثَّرَّةِ', #1
u'الثرماء': u'الثَّرْمَاءُ', #1
u'الثرماء': u'الثَّرْمَاءِ', #1
u'الثروب': u'الثُّرُوبُ', #1
u'الثروب،': u'الثُرُوبِ،', #1
u'الثروب': u'الثُّرُوبِ', #2
u'الثريدة': u'الثَّرِيدَةَ', #1
u'الثط': u'الثّطّ', #1
u'الثطاط': u'الثّطَاطُ', #3
u'الثعارير؟': u'الثَّعَارِيرُ؟', #1
u'الثعارير': u'الثَّعَارِيرُ', #12
u'الثعارير': u'الثَّعَارِيرِ', #2
u'الثعالبي': u'الثّعَالِبِيّ', #1
u'الثعالبي': u'الثَّعَالِبِيَّ', #1
u'الثعالبي': u'الثَّعَالِبِيُّ', #29
u'الثعالبي': u'الثَّعَالِبِيِّ', #6
u'الثعالي': u'الثّعَالِي', #1
u'الثعالي': u'الثَّعَالِي', #1
u'الثعلبى': u'الثَّعْلَبِىُّ', #3
u'الثعلبى': u'الثَّعْلَبِىِّ', #5
u'الثعول؟،': u'الثَّعُولُ؟،', #1
u'الثغام': u'الثَّغَامِ', #2
u'الثغام،': u'الثَّغَامِ،', #3
u'الثغامة': u'الثَّغَامَةُ', #1
u'الثغامة،': u'الثُّغَامَةِ،', #1
u'الثغامة': u'الثغامة', #2
u'الثغامة،': u'الثَّغَامَةِ،', #3
u'الثغامة': u'الثَّغَامَةِ', #5
u'الثغرى': u'الثَّغْرِىُّ', #1
u'الثغول': u'الثغول', #1
u'الثفا': u'الثَّفَا', #3
u'الثفر': u'الثَّفْرَ', #1
u'الثفر': u'الثَّفْرُ', #1
u'الثفنات': u'الثَّفِنَات', #1
u'الثفور': u'الثُّفُورُ', #1
u'الثقةعنده': u'الثِّقَةِعِنْدَهُ', #1
u'الثقفيSعن': u'الثّقَفِيّSعَنْ', #1
u'الثقفي،': u'الثقفيّ،', #1
u'الثقفي': u'الثَّقفيّ', #1
u'الثقفي،': u'الثّقفي،', #1
u'الثقفي،': u'الثَّقفيّ،', #1
u'الثقفي،': u'الثَّقَفي،', #1
u'الثقفي': u'الثَقَفِيِّ', #1
u'الثقفي': u'الثّقَفِي', #1
u'الثقفي،': u'الثَّقَفِيّ،', #1
u'الثقفى': u'الثَّقَفِى', #1
u'الثقفى': u'الْثَقَفِىِّ', #1
u'الثقفي': u'الثَّقَفِيُّ', #174
u'الثقفي،': u'الثَّقَفِيُّ،', #184
u'الثقفي': u'الثَّقَفِيِّ', #204
u'الثقفي،': u'الثقفي،', #25
u'الثقفى': u'الثَّقَفِىُّ', #261
u'الثقفى': u'الثَّقَفِىَّ', #32
u'الثقفي': u'الثَّقَفِيّ', #4
u'الثقفي': u'الثقفي', #49
u'الثقفي': u'الثَّقَفِيَّ', #51
u'الثقفي،': u'الثَّقَفِيَّ،', #7
u'الثقفي،': u'الثَّقَفِيِّ،', #76
u'الثقفي': u'الثّقَفِيّ', #86
u'الثقفى': u'الثَّقَفِىِّ', #96
u'الثقفيات': u'الثَّقَفِيَّاتِ', #1
u'الثقفيان': u'الثقفيان', #1
u'الثقفية': u'الثّقَفِيّةُ', #1
u'الثقفية': u'الثَّقَفِيَّة', #1
u'الثقفية': u'الثَّقَفِيَّةِ', #16
u'الثقفية': u'الثقفية', #2
u'الثقفية': u'الثّقَفِيّةِ', #2
u'الثقفية،': u'الثَّقَفِيَّةِ،', #2
u'الثقفية': u'الثَّقَفِيَّةَ', #3
u'الثقفية': u'الثَّقَفِيَّةُ', #3
u'الثقفيين': u'الثَّقَفِيِّينَ', #1
u'الثقفيين': u'الثَّقَفِيَّيْنِ', #1
u'الثقفيين': u'الثّقَفِيّينَ', #2
u'الثقلة': u'الثَّقْلَةُ', #1
u'الثقلة': u'الثَّقْلَةِ', #1
u'ألثقها': u'أَلْثَقَهَا', #3
u'الثقيف': u'الثَّقِيفِ', #1
u'الثقيفة': u'الثَّقِيفَةِ', #1
u'الثكليات': u'الثَّكْلَيَاتِ', #1
u'الثلات': u'الثَّلَاتِ', #1
u'الثلاثا': u'الثَّلَاثَا', #1
u'الثلاثات': u'الثَّلَاثَاتِ', #1
u'الثلاثتين': u'الثَّلَاثَتَيْنِ', #8
u'الثلاثه': u'الثَّلَاثَهْ', #1
u'الثلت': u'الثُّلُتِ', #1
u'الثلثا': u'الثُّلُثَا', #1
u'الثلثمائة': u'الثَّلَثُمِائَةٍ', #1
u'الثلثمائة': u'الثَّلَثُمِائَةِ', #10
u'الثلثمائة': u'الثَّلَثَمِائَةِ', #14
u'الثلثمائة': u'الثَّلَثمِائَةِ', #2
u'الثلثمائة': u'الثَّلَثِمِائَةٍ', #2
u'الثلثمائة': u'الثَّلَثَمِائَةٍ', #3
u'الثلثمائة': u'الثَّلَثِمِائَةِ', #39
u'الثليث': u'الثَّلِيثُ', #1
u'الثمادSأبو': u'الثّمَادِSأَبُو', #1
u'الثماد': u'الثّمَادِ', #3
u'الثمالى': u'الثُمَالِىُّ', #1
u'الثمالى': u'الثُّمَالَى', #2
u'الثمالى': u'الثُّمَالِىِّ', #3
u'الثمالى': u'الثُّمَالِىُّ', #4
u'الثمام': u'الثّمَامَ', #1
u'الثمام': u'الثّمَامُ', #1
u'الثمام': u'الثُّمَامُ', #1
u'الثمام': u'الثُّمَامَ', #2
u'الثمام': u'الثّمَامِ', #4
u'الثمام': u'الثُّمَامِ', #7
u'الثمد': u'الثّمَدِ', #1
u'الثنا': u'الثّنَا', #2
u'الثنا': u'الثَّنَا', #2
u'الثناءات': u'الثَّنَاءَاتِ', #3
u'الثناءة': u'الثَّنَاءَةُ', #1
u'الثنتي': u'الثِّنْتَيْ', #4
u'الثندوة': u'الثُّنْدُوَةِ', #1
u'الثندوة': u'الثَّنْدُوَةَ', #2
u'الثندوة': u'الثَّنْدُوَةِ', #3
u'الثندوة': u'الثَّنْدُوَةُ', #7
u'الثندوتين': u'الثُّنْدُوَتَيْنِ', #1
u'الثندوتين': u'الثَّنْدُوَتَيْنِ', #2
u'الثنود': u'الثُّنُود', #1
u'الثنى': u'الثَّنَى', #1
u'الثنى': u'الثَّنِىِّ', #1
u'الثنى': u'الثِّنَى', #19
u'الثنى': u'الثَّنِىُّ', #5
u'الثنيا': u'الثُّنْيَا', #155
u'الثنيا،': u'الثُّنْيَا،', #2
u'الثنيا': u'الثَّنِيَّا', #29
u'الثنيا': u'الثنيا', #3
u'الثنيا': u'الثِّنْيَا', #7
u'الثنيات': u'الثَّنَيَاتِ', #1
u'الثنيات': u'الثَّنِيَّاتُ', #1
u'الثنيات': u'الثَّنِيَّاتِ', #4
u'الثوباء': u'الثَّوْبَاءَ', #1
u'الثؤباء': u'الثُّؤَبَاءُ', #3
u'الثوبالخلق': u'الثَّوْبِالْخَلِقِ', #1
u'الثورى': u'الثَّوْرِىَّ', #18
u'الثورى': u'الثَّوْرِىِّ', #268
u'الثورى': u'الثَّوْرِىُّ', #384
u'الثوريعن': u'الثَّوْرِيَّعَنْ', #1
u'الثوريفي': u'الثَّوْرِيِّفِي', #1
u'الثول': u'الثَّوَلُ', #1
u'الثول': u'الثَّوْلِ', #1
u'الثولاء': u'الثَّوْلَاءِ', #1
u'الثولاء': u'الثَّوْلَاءُ', #3
u'الثوى': u'الثَّوَى', #4
u'الثوية': u'الثَّوِيَّةِ', #1
u'الثيابة': u'الثِّيَابَةِ', #12
u'الثيابة': u'الثِّيَابَةَ', #13
u'الثيابة': u'الثِّيَابَةُ', #5
u'الثيابي': u'الثِّيَابِيِّ', #14
u'الثيابي': u'الثِّيَابِيَّ', #2
u'الثيابي': u'الثِّيَابِيُّ', #21
u'الثيابية': u'الثِّيَابِيَّةِ', #2
u'الثيبة': u'الثِّيبَةِ', #1
u'الثيبة': u'الثَّيِّبَةَ', #1
u'الثيبة': u'الثَّيِّبَةِ', #1
u'الثيروي': u'الثَّيْرَوِيُّ', #1
u'الثينية': u'الثِّينِيةَ', #1
u'الثيوبة': u'الثُّيُوبَةُ', #22
u'الثيوبة': u'الثُّيُوبَةَ', #25
u'الثيوبة': u'الثُّيُوبَةِ', #59
u'الجاءون': u'الْجَاءُونَ', #3
u'الجابري': u'الْجَابِرِيِّ', #1
u'الجابيه': u'الجابيه', #1
u'الجاثليق': u'الْجَاثَلِيقُ', #1
u'الجاثليق': u'الْجَاثَلِيقِ', #1
u'الجاثليق،': u'الْجَاثَلِيقِ،', #2
u'الجاجرمي': u'الجاجرمي', #1
u'الجاجرمي': u'الْجَاجَرْمِيِّ', #1
u'الجاجرمي': u'الْجَاجَرْمِيُّ', #6
u'الجآجي': u'الجآجي', #1
u'الجآجي': u'الْجَآجِي', #1
u'الجاذ': u'الْجَاذُّ', #1
u'الجآذر': u'الْجَآذِرُ', #1
u'الجاذي': u'الْجَاذِي', #1
u'الجاذي': u'الْجَاذِيَ', #1
u'الجارا': u'الْجَارَا', #1
u'الجاربردي': u'الْجَارْبُرْدِيِّ', #17
u'الجاربردي': u'الْجَارْبُرْدِيُّ', #23
u'الجارموق': u'الْجُارَمُوقِ', #1
u'الجارمي': u'الْجَارِمِيِّ', #1
u'الجارود،': u'الجارود،', #1
u'الجارود': u'الْجَارُود', #1
u'الجارود،': u'الْجَارُودُ،', #1
u'الجارود': u'الْجَارُودِ', #116
u'الجارود،': u'الْجَارُودِ،', #14
u'الجارود': u'الجَارُود', #2
u'الجارود': u'الْجَارُودُ', #34
u'الجارود': u'الْجَارُودَ', #7
u'الجارود': u'الجارود', #8
u'الجارودي،': u'الْجَارُودِيِّ،', #1
u'الجارودى': u'الْجَارُودِىَّ', #1
u'الجارودي': u'الْجَارُودِيَّ', #2
u'الجارودي': u'الْجَارُودِيِّ', #2
u'الجارودي': u'الْجَارُودِيُّ', #4
u'الجارودي،': u'الْجَارُودِيُّ،', #5
u'الجارودى': u'الْجَارُودِىُّ', #9
u'الجارودية': u'الْجَارُودِيَّةُ', #1
u'الجاروق': u'الْجَارُوقُ', #2
u'الجاروق': u'الْجَارُوقِ', #3
u'الجارى': u'الْجَارِى', #2
u'الجارى': u'الْجَارِىِّ', #2
u'الجارى': u'الْجَارِىُّ', #9
u'الجاريه': u'الجاريه', #1
u'الجازع': u'الْجَازِعِ', #1
u'الجازئ': u'الْجَازِئِ', #1
u'الجاشني': u'الجاشني', #1
u'الجاعرتان': u'الجاعرتان', #1
u'الجاعرتان': u'الْجَاعِرَتَانِ', #3
u'الجاعرتين': u'الْجَاعِرَتَيْنِ', #7
u'الجافى': u'الجافى', #1
u'الجافى': u'الْجَافِى', #1
u'الجالوت،': u'الْجَالُوتَ،', #1
u'الجالوت،': u'الْجَالُوتِ،', #1
u'الجالوت': u'الْجَالُوتِ', #3
u'الجالينوس': u'الجالينوس', #1
u'الجامزون': u'الْجَامِزُونَ', #2
u'الجامكيات': u'الْجَامِكِيَّاتِ', #2
u'الجامكيات': u'الْجَامَكِيَّاتِ', #3
u'الجامكية': u'الْجَامَكِيَّةَ', #1
u'الجامكية': u'الْجَامِكِيَّة', #1
u'الجامكية': u'الْجَامَكِيَّةُ', #2
u'الجامكية': u'الْجَامَكِيَّةِ', #2
u'الجامكية': u'الْجَامِكِيَّةُ', #4
u'الجامكية': u'الْجَامِكِيَّةِ', #45
u'الجامكية': u'الْجَامِكِيَّةَ', #8
u'الجانى': u'الْجَانِىَ', #1
u'الجانى': u'الْجَانِى', #5
u'الجاهات': u'الْجَاهَاتِ', #1
u'الجاهلينا': u'الْجَاهِلَيْنَا', #1
u'الجاهلينا': u'الْجَاهِلِينَا', #3
u'الجاهلينقوله': u'الْجَاهِلِينَقَوْلُهُ', #1
u'الجاورس': u'الجاورس', #1
u'الجاورس': u'الْجَاوْرَسُ', #1
u'الجاورس': u'الْجَاوْرَسِ', #2
u'الجاوشير': u'الجاوشير', #2
u'ألجأوهم': u'ألجأوهم', #1
u'الجاويش': u'الْجَاوِيشِ', #1
u'الجاويشية': u'الْجَاوِيشِيَّةِ', #1
u'الجائزا': u'الْجَائِزَا', #2
u'الجائفه': u'الْجَائِفَهْ', #1
u'الجائى': u'الْجَائِى', #2
u'الجبات': u'الْجُبَّاتِ', #1
u'الجباجب': u'الْجَبَاجِبَ', #1
u'الجباجب،': u'الْجَبَاجِبِ،', #1
u'الجباجب': u'الْجُبَاجِبِ', #2
u'الجباجب': u'الْجَبَاجِبُ', #3
u'الجباجب': u'الْجَبَاجِبِ', #7
u'الجباح': u'الْجِبَاحِ', #2
u'الجبالا': u'الْجِبَالَا', #2
u'الجباني': u'الْجَبَّانِيُّ', #1
u'الجبت': u'الْجِبْتُ', #11
u'الجبت': u'الْجِبْتِ', #16
u'الجبذة': u'الْجَبْذَةِ', #1
u'الجبران': u'الْجبرَان', #1
u'الجبران': u'الْجَبْرَانِ', #2
u'الجبران': u'الْجُبْرَان', #2
u'الجبران': u'الْجُبْرَانِ', #211
u'الجبران': u'الْجُبْرَانُ', #34
u'الجبران': u'الْجُبْرَانَ', #85
u'الجبرانات': u'الْجُبْرَانَاتِ', #23
u'الجبرانان': u'الْجُبْرَانَانِ', #1
u'الجبرانين': u'الْجُبْرَانَيْنِ', #1
u'الجبغا': u'الْجَبْغَا', #16
u'الجبلاني': u'الجبلاني', #1
u'الجبلاني،': u'الْجَبَلانِيُّ،', #1
u'الجبلاني': u'الْجُبْلَانِيُّ', #1
u'الجبلى': u'الْجَبُلِىُّ', #1
u'الجبنة': u'الْجُبْنَةُ', #1
u'الجبنة': u'الْجُبْنَةِ', #1
u'الجبنة': u'الْجُبْنَةَ', #3
u'الجبوب': u'الْجَبُوبِ', #1
u'الجبوب': u'الْجَبُوبَ', #2
u'الجبوب': u'الْجَبُوبُ', #2
u'الجبيذة': u'الْجُبَيْذَةِ', #3
u'الجبيرات': u'الْجَبِيرَاتُ', #1
u'الجبيرة': u'الْجَبِيرَةِ', #355
u'الجبيرة': u'الْجَبِيرَةُ', #72
u'الجبيرة': u'الْجَبِيرَةَ', #80
u'الجبيرتين': u'الْجَبِيرَتَيْنِ', #6
u'الجبيري': u'الْجُبَيْرِيُّ', #1
u'الجبيري،': u'الْجُبَيْرِيُّ،', #1
u'الجبيل': u'الْجُبَيْلُ', #2
u'الجبيلات': u'الْجُبَيْلَاتِ', #1
u'الجبيلي،': u'الْجُبَيْلِيُّ،', #1
u'الجثائث': u'الْجَثَائِثُ', #1
u'الجثوم': u'الْجُثُومُ', #3
u'الجثوم': u'الْجُثُومِ', #3
u'الجح': u'الْجَحُّ', #1
u'الجحاجح': u'الجحاجح', #1
u'الجحاجح': u'الْجَحَاجِحُ', #1
u'الجحاجح': u'الْجَحَاجِحْ', #2
u'الجحاجح': u'الْجَحَاجِحَ', #3
u'الجحادلة': u'الْجَحَادِلَةِ', #1
u'الجحاف': u'الجحاف', #1
u'الجحاف،': u'الجحّاف،', #1
u'الجحاف': u'الْجَحّافِ', #1
u'الجحاف': u'الْجُحَافَ', #1
u'الجحاف': u'الْجُحَافُ', #1
u'الجحاف': u'الْجُحَافِ', #1
u'الجحاف': u'الْجِحَافَ', #1
u'الجحاف': u'الْجِحَافِ', #1
u'الجحاف،': u'الْجُحَافِ،', #1
u'الجحاف': u'الْجَحّافُ', #5
u'الجحاف': u'الْجَحَّافِ', #5
u'الجحاف،': u'الْجَحَّافِ،', #7
u'الجحافأنه': u'الْجَحَّافِأَنَّهُ', #1
u'الجحة': u'الْجُحَّةِ', #1
u'الجحدري،': u'الْجَحْدَرِيَّ،', #1
u'الجحدرى': u'الْجَحْدَرِىَّ', #1
u'الجحدرى': u'الْجَحْدِرِىِّ', #1
u'الجحدري،': u'الجحدري،', #2
u'الجحدري،': u'الْجَحَدْرِيُّ،', #2
u'الجحدري،': u'الْجَحْدَرِيِّ،', #2
u'الجحدري،': u'الْجَحْدَرِيُّ،', #22
u'الجحدري': u'الْجَحْدَرِيُّ', #23
u'الجحدري': u'الجحدري', #3
u'الجحدرى': u'الْجَحْدَرِىِّ', #6
u'الجحدري': u'الْجَحْدَرِيِّ', #9
u'الجحدرى': u'الْجَحْدَرِىُّ', #96
u'الجحرة': u'الْجُحْرَةِ', #1
u'الجحرة': u'الْجِحَرَة', #1
u'الجحف': u'الْجَحَفُ', #1
u'الجحف': u'الْجُحُفِ', #1
u'الجحفة': u'الْجَحَفَةُ', #1
u'الجحفة': u'الْجُحْفَةِ', #198
u'الجحفة،': u'الجُحْفَة،', #2
u'الجحفة،': u'الْجُحْفَةَ،', #4
u'الجحفة،': u'الْجُحْفَةِ،', #4
u'الجحفة': u'الْجُحْفَةُ', #71
u'الجحفة': u'الْجُحْفَةَ', #78
u'الجحفة': u'الْجُحْفَة', #8
u'الجحفةمعتمرا': u'الْجُحْفَةِمُعْتَمِرًا', #1
u'الجحفلة': u'الْجَحْفَلَةِ', #2
u'الجحون': u'الْجُحُونِ', #1
u'الجدا': u'الْجَدَّا', #3
u'الجدابة': u'الْجَدَابَةُ', #1
u'الجداجد': u'الْجَدَاجِدَ', #1
u'الجداجد': u'الْجَدَاجِدُ', #1
u'الجداجد': u'الْجَدَاجِدِ', #3
u'الجدادين': u'الْجَدَّادِينَ', #1
u'الجدارا': u'الْجِدَارَا', #1
u'الجدالة': u'الْجَدَالَةِ', #2
u'الجدام': u'الْجُدَامِ', #1
u'الجدامة': u'الْجُدّامَةُ', #1
u'الجدان': u'الْجَدَّانِ', #4
u'الجداوي': u'الْجَدَّاوِيُّ', #1
u'الجداويل': u'الْجَدَاوِيلِ', #1
u'الجداية': u'الْجِدَايَةَ', #1
u'الجداية': u'الْجَدَايَةَ', #3
u'الجداية': u'الْجِدَايَةُ', #3
u'الجدبة': u'الجدبة', #1
u'الجدبة': u'الْجَدْبَةُ', #1
u'الجدبة': u'الْجَدْبَةِ', #4
u'الجدبة': u'الْجَدْبَةَ', #8
u'الجدحة': u'الْجَدَحَةِ', #1
u'الجدرات': u'الجدرات', #1
u'الجدرات': u'الْجِدَرَات', #1
u'الجدرة': u'الْجَدَرَةُ', #2
u'الجدرة': u'الْجَدَرَةَ', #3
u'الجدرة': u'الْجَدَرَةِ', #4
u'الجدرى': u'الْجُدَرِىُّ', #2
u'الجدعاني': u'الجدعاني', #1
u'الجدك': u'الْجَدَكِ', #2
u'الجدك': u'الْجَدَكُ', #5
u'الجدلى': u'الْجَدَلِىَّ', #1
u'الجدلى': u'الْجَدَلِىِّ', #12
u'الجدلى': u'الْجَدَلِىُّ', #2
u'الجده': u'الْجَدَّهْ', #1
u'الجدوب': u'الْجُدُوبِ', #1
u'الجدوب،': u'الْجُدُوبُ،', #1
u'الجدوبة': u'الْجُدُوبَةَ', #1
u'الجدوبة': u'الْجُدُوبَةُ', #1
u'الجدوبة': u'الْجُدُوبَةِ', #4
u'الجدودة': u'الْجُدُودَةُ', #12
u'الجدودة': u'الْجُدُودَةِ', #26
u'الجدودة': u'الْجُدُودَةَ', #8
u'الجدور': u'الْجُدُورُ', #1
u'الجدى': u'الْجَدِّىُّ', #1
u'الجدى': u'الْجَدْىَ', #1
u'الجدى': u'الْجُدِّىِّ', #2
u'الجدى': u'الْجُدِّىُّ', #3
u'الجدين': u'الْجِدّيْنِ', #1
u'الجدين': u'الْجَدَّيْنِ', #12
u'الجدين': u'الْجَدّيْنِ', #4
u'الجذاد': u'الْجُذَادِ', #1
u'الجذامى': u'الْجُذَامِىِّ', #1
u'الجذامى': u'الْجِذَامِىُّ', #1
u'الجذامى': u'الْجُذَامِىَّ', #2
u'الجذامى': u'الْجُذَامِىُّ', #7
u'الجذة': u'الْجَذَّةُ', #1
u'الجذة': u'الْجُذَّةُ', #1
u'الجذة': u'الْجَذَّةِ', #3
u'الجذعاء': u'الجذعاء', #1
u'الجذعاء': u'الجَذعاء', #1
u'الجذعاء': u'الْجَذْعَاءِ', #1
u'الجذعات': u'الْجَذَعَاتِ', #5
u'الجذعة': u'الْجَذْعَةَ', #1
u'الجذعة،': u'الْجَذَعَةَ،', #1
u'الجذعة': u'الْجَذَعَةَ', #24
u'الجذعة': u'الْجَذَعَة', #3
u'الجذعة': u'الْجَذَعَةُ', #33
u'الجذعة': u'الجَذعة', #7
u'الجذعة': u'الْجَذَعَةِ', #78
u'الجذلة': u'الْجِذْلَةِ', #1
u'الجذوعي': u'الْجُذُوعِيُّ', #1
u'الجذوعي،': u'الْجُذُوعِيِّ،', #1
u'الجذيذة': u'الْجَذِيذَةِ', #2
u'الجذيمي': u'الْجَذِيمِيّ', #1
u'الجراجري': u'الْجَرَاجِرِيِّ', #1
u'الجراحاتقوله': u'الْجِرَاحَاتُقَوْلُهُ', #1
u'الجراحى': u'الْجَرَّاحِىُّ', #14
u'الجرادات': u'الْجَرَادَاتِ', #2
u'الجرادين': u'الْجَرَادَيْنِ', #1
u'الجراشع': u'الْجَرَاشِعُ', #3
u'الجراعي': u'الجراعي', #1
u'الجراعي': u'الْجِرَاعِيِّ', #1
u'الجراكسة': u'الْجَرَاكِسَةِ', #5
u'الجرامقة': u'الْجَرَامِقَةِ', #1
u'الجرائحي': u'الْجَرَائِحِيُّ', #2
u'الجرائحي': u'الْجَرَائِحِيِّ', #4
u'الجرائحيون': u'الجرائحيون', #1
u'الجرائحيون': u'الْجَرَائِحِيُّونَ', #1
u'الجرائر': u'الْجَرَائِرِ', #2
u'الجراية': u'الْجِرَايَةُ', #2
u'الجراية': u'الْجِرَايَةَ', #3
u'الجرايحي': u'الْجَرَايِحِيِّ', #2
u'الجربزة': u'الْجَرْبَزَةَ', #1
u'الجربزة': u'الْجَرْبَزَةُ', #1
u'الجربزة': u'الْجَرْبَزَةِ', #2
u'الجرجاني': u'الجرجاني', #1
u'الجرجانى': u'الْجُرَجَانِىُّ', #1
u'الجرجانى': u'الْجِرْجَانِىُّ', #1
u'الجرجاني': u'الْجُرْجَانِيَّ', #15
u'الجرجاني،': u'الجرجاني،', #2
u'الجرجاني': u'الْجُرْجَانِيّ', #2
u'الجرجانى': u'الْجَرْجَانِىُّ', #2
u'الجرجانى': u'الْجُرْجَانِىَّ', #2
u'الجرجاني': u'الْجُرْجَانِيِّ', #262
u'الجرجانى': u'الْجُرْجَانِىُّ', #31
u'الجرجاني': u'الْجُرْجَانِيُّ', #315
u'الجرجاني،': u'الْجُرْجَانِيُّ،', #34
u'الجرجاني،': u'الْجُرْجَانِيِّ،', #7
u'الجرجانيات': u'الْجُرْجَانِيَّاتِ', #7
u'الجرجانية': u'الْجُرْجَانِيَّةِ', #1
u'الجرجر': u'الْجَرْجَرَ', #1
u'الجرجراني،': u'الجرجراني،', #1
u'الجرجرائي': u'الْجَرْجَرَائِيِّ', #1
u'الجرجرائي،': u'الْجَرْجَرَائِيُّ،', #4
u'الجرجرائى': u'الْجَرْجَرَائِىُّ', #6
u'الجرجسى': u'الْجُرْجُسِىُّ', #1
u'الجرجسى': u'الْجُرْجُسِىِّ', #1
u'الجرجسي،': u'الْجُرْجُسِيُّ،', #2
u'الجرجسي': u'الْجُرْجُسِيُّ', #3
u'الجرجماني': u'الْجُرْجُمَانِيُّ', #1
u'الجرحا': u'الْجُرْحَا', #1
u'الجردان': u'الْجَرْدَانُ', #1
u'الجردق': u'الجردق', #1
u'الجرشع': u'الْجُرْشُعُ', #1
u'الجرشى': u'الْجُرَشِىُّ', #2
u'الجرشى': u'الْجُرَشِىِّ', #4
u'الجرصن': u'الجرصن', #1
u'الجرصن': u'الْجُرْصُنُ', #2
u'الجرصن': u'الْجُرْصُنَ', #4
u'الجرصن': u'الْجُرْصُنِ', #7
u'الجرمقاني': u'الْجُرْمُقَانِيُّ', #2
u'الجرمقانية': u'الجُرْمُقَانِيّةِ', #1
u'الجرموق': u'الْجُرْمُوقُ', #29
u'الجرموق': u'الْجُرْمُوقَ', #45
u'الجرموق': u'الْجُرْمُوقِ', #99
u'الجرموقا': u'الْجُرْمُوقَا', #1
u'الجرموقان': u'الْجُرْمُوقَانِ', #3
u'الجرموقين': u'الْجُرْمُوقَيْنِ', #61
u'الجرمى': u'الْجَرْمِىِّ', #22
u'الجرمى': u'الْجَرْمِىُّ', #27
u'الجرمى': u'الْجَرْمِىَّ', #3
u'الجرن': u'الْجُرْنَ', #1
u'الجرن': u'الْجُرْنُ', #1
u'الجرن': u'الْجُرْنِ', #12
u'الجرهزي': u'الْجَرْهَزِيُّ', #1
u'الجرهزي': u'الْجَرْهَزِيِّ', #1
u'الجرهمي': u'الْجُرْهُمِيّ', #14
u'الجرهمي': u'الْجُرْهُمِيُّ', #2
u'الجرهميين': u'الْجُرْهُمِيّينَ', #1
u'الجروب': u'الْجُرُوبُ', #1
u'الجروهق': u'الجروهق', #1
u'الجروى': u'الْجَرَوِىِّ', #1
u'الجروى': u'الْجَرَوِىُّ', #2
u'الجرى': u'الجرى', #3
u'الجرىء': u'الْجَرِىءُ', #1
u'الجريال': u'الْجِرْيَالِ', #1
u'الجريب': u'الْجَرِيبِ', #18
u'الجريب': u'الْجَرِيبُ', #19
u'الجريب': u'الْجَرِيبَ', #4
u'الجريبين': u'الْجَرِيبَيْنِ', #1
u'الجريت': u'الجريت', #1
u'الجريث': u'الْجِرِّيثِ', #11
u'الجريث': u'الْجِرِّيثُ', #3
u'الجريث': u'الْجِرِّيثَ', #4
u'الجريرى': u'الجُرَيْرِىِّ', #1
u'الجريرى': u'الْجَرِيرِىُّ', #1
u'الجريرى': u'الْجُرَيْرِىَّ', #4
u'الجريرى': u'الْجُرَيْرِىُّ', #44
u'الجريرى': u'الْجُرَيْرِىِّ', #75
u'الجريسة': u'الْجَرِيسَةِ', #1
u'الجريش': u'الْجَرِيشِ', #1
u'الجريش': u'الْجَرِيشَ', #2
u'الجريم': u'الْجَرِيمِ', #2
u'الجرين': u'الْجَرِينَ', #10
u'الجرين': u'الْجَرِينِ', #105
u'الجرين': u'الْجَرِين', #3
u'الجرين': u'الْجَرِينُ', #64
u'الجزا': u'الْجَزَا', #7
u'الجزافين': u'الْجَزَّافِينَ', #1
u'الجزافين': u'الْجُزَافَيْنِ', #3
u'الجزرة': u'الْجَزْرَةِ', #1
u'الجزرة': u'الْجَزَرَةُ', #2
u'الجزرى': u'الْجَزَرِىُّ', #25
u'الجزرى': u'الْجَزَرِىِّ', #36
u'الجزرى': u'الْجَزَرِىَّ', #4
u'الجزما': u'الْجَزْمَا', #1
u'الجزمين': u'الْجَزْمَيْنِ', #2
u'الجزولي': u'الجزولي', #1
u'الجزولي': u'الْجُزُولِيُّ', #125
u'الجزولي': u'الْجُزُولِيِّ', #33
u'الجزولي': u'الْجُزُولِيَّ', #4
u'الجزولية': u'الْجُزُولِيَّةِ', #3
u'الجزوي': u'الْجَزَوِيُّ', #1
u'الجزوي،': u'الْجَزَوِيُّ،', #1
u'الجزى': u'الْجِزَى', #3
u'الجزيةوالوجه': u'الْجِزْيَةَوَالْوَجْهُ', #2
u'الجزيري': u'الْجَزِيرِيِّ', #36
u'الجزيري': u'الْجَزِيرِيُّ', #37
u'الجزيزة': u'الجزيزة', #1
u'الجزيزة،': u'الجزيزة،', #1
u'الجزيعة': u'الجزيعة', #1
u'الجزيلات': u'الْجَزِيلَاتِ', #2
u'الجساوندي': u'الْجَسَاوَنْدِيِّ', #1
u'الجسة': u'الْجَسَّةِ', #1
u'الجسة': u'الْجِسَّةِ', #1
u'الجسرى': u'الْجَسْرِىِّ', #1
u'الجسرى': u'الْجِسْرِىِّ', #1
u'الجشاشي،': u'الْجَشَّاشِيُّ،', #1
u'الجشر': u'الجشر', #1
u'الجشمى': u'الْجُشَمِىّ', #1
u'الجشمى': u'الْجُشَمِىِّ', #4
u'الجشمى': u'الْجُشَمِىُّ', #8
u'الجشني': u'الْجُشْنِيّ', #1
u'الجشيش': u'الْجَشِيشُ', #1
u'الجشيشة': u'الجشيشة', #1
u'الجشيم': u'الْجَشِيمِ', #2
u'الجصة': u'الْجَصَّةُ', #2
u'الجطارجي': u'الجطارجي', #1
u'الجعادب': u'الْجِعَادِبِ', #1
u'الجعادر': u'الْجَعَادِرُ', #1
u'الجعادر': u'الْجَعَادِرِ', #1
u'الجعادرة': u'الْجَعَادِرَةُ', #2
u'الجعالات': u'الْجَعَالَاتِ', #10
u'الجعالات': u'الْجِعَالَاتِ', #4
u'الجعالة': u'الْجُعَالَةِ', #1
u'الجعالة': u'الْجِعَالَة', #1
u'الجعالة': u'الْجِعَالَةِ', #144
u'الجعالة': u'الْجَعَالَة', #2
u'الجعالة': u'الْجِعَالَةَ', #21
u'الجعالة': u'الْجِعَالَةُ', #33
u'الجعالة': u'الْجَعَالَةِ', #378
u'الجعالة': u'الْجَعَالَةَ', #57
u'الجعالة': u'الْجَعَالَةُ', #87
u'الجعائل': u'الْجَعَائِلِ', #12
u'الجعائل': u'الْجَعَائِلُ', #3
u'الجعائل': u'الْجَعَائِلَ', #4
u'الجعبري': u'الْجَعْبَرِيَّ', #1
u'الجعبري': u'الْجَعْبَرِيُّ', #16
u'الجعبري': u'الْجَعْبَرِيِّ', #8
u'الجعدى': u'الْجَعْدِىِّ', #1
u'الجعر': u'الْجَعْرَ', #1
u'الجعران': u'الْجِعْرَانِ', #1
u'الجعرانة': u'الجِعِرّانة', #1
u'الجعرانة': u'الْجِعِرَّانَةُ', #1
u'الجعرانة': u'الْجِعْرَّانَةِ', #1
u'الجعرانة،': u'الْجُعْرَانَةِ،', #1
u'الجعرانة': u'الْجِعْرَانَةَ', #14
u'الجعرانة': u'الْجِعِرَّانَةِ', #16
u'الجعرانة': u'الْجِعْرَانَةِ', #168
u'الجعرانة': u'الجعرانة', #2
u'الجعرانة': u'الْجِعِرّانَةَ', #2
u'الجعرانة': u'الْجِعِرّانَةِ', #23
u'الجعرانة': u'الْجِعْرَانَةُ', #29
u'الجعرانة': u'الْجِعِرَّانَة', #3
u'الجعرانة': u'الْجِعِرَّانَةَ', #3
u'الجعرانة،': u'الْجِعْرَانَةِ،', #7
u'الجعرانه': u'الْجِعْرَانَهْ', #1
u'الجعرور': u'الْجُعْرُور', #2
u'الجعرور،': u'الْجُعْرُورِ،', #2
u'الجعرور': u'الْجُعْرُورِ', #3
u'الجعرور': u'الْجُعْرُورُ', #4
u'الجعشمي': u'الْجُعْشُمِيّ', #1
u'الجعظ': u'الْجَعْظُ', #1
u'الجعظري،': u'الْجَعْظَرِيُّ،', #1
u'الجعظري': u'الْجَعْظَرِيُّ', #2
u'الجعفر': u'الْجَعْفَرِ', #1
u'الجعفرى': u'الْجَعْفَرِىُّ', #2
u'الجعفي': u'الجُعْفيّ', #1
u'الجعفي،': u'الجُعْفِيّ،', #1
u'الجعفي': u'الْجُعْفيِّ', #1
u'الجعفي': u'الْجَعْفِيُّ', #1
u'الجعفي': u'الْجُعَفِيَّ', #1
u'الجعفي،': u'الْجُعَفِيُّ،', #1
u'الجعفى،': u'الجُعْفِىُّ،', #1
u'الجعفى': u'الْجُعَفِىُّ', #1
u'الجعفي': u'الْجُعْفِيَّ', #12
u'الجعفي،': u'الجعفي،', #14
u'الجعفى': u'الْجُعْفِىِّ', #20
u'الجعفي،': u'الْجُعْفِيَّ،', #3
u'الجعفي،': u'الْجُعْفِيِّ،', #33
u'الجعفي': u'الْجُعْفِيّ', #5
u'الجعفي': u'الْجُعْفِيِّ', #66
u'الجعفي': u'الجعفي', #7
u'الجعفى': u'الْجُعْفِىُّ', #75
u'الجعفى': u'الْجُعْفِىَّ', #8
u'الجعفي': u'الْجُعْفِيُّ', #94
u'الجعفي،': u'الْجُعْفِيُّ،', #98
u'الجعفية': u'الْجُعْفِيَّةِ', #1
u'الجعفي،وأبو': u'الْجُعْفِيِّ،وَأَبُو', #1
u'الجعلة': u'الْجُعَلَةِ', #1
u'الجعيد': u'الجعيد', #1
u'الجعيد،': u'الجعيد،', #1
u'الجعيد': u'الْجُعَيْدُ', #14
u'الجعيد،': u'الْجُعَيْدُ،', #3
u'الجعيد': u'الْجُعَيْدِ', #5
u'الجعيل': u'الْجَعِيلَ', #3
u'الجعيل': u'الْجَعِيلُ', #3
u'الجعيل': u'الْجَعِيلِ', #3
u'الجعيلة': u'الْجَعِيلَةُ', #3
u'الجفا': u'الْجِفَا', #2
u'الجفا': u'الْجَفَا', #3
u'الجفانة': u'الْجِفَانَةُ', #1
u'الجفرات': u'الْجَفْرَاتُ', #1
u'الجفلة': u'الْجَفْلَةِ', #1
u'الجفلى': u'الْجَفْلَى', #1
u'الجفلى': u'الْجَفَلَى', #16
u'الجفونا': u'الجُفونا', #1
u'الجفونا': u'الْجُفُونَا', #2
u'الجفير': u'الْجَفِيرِ', #1
u'الجكاني،': u'الْجَكَّانِيُّ،', #1
u'الجكانى': u'الْجَكَانِىُّ', #1
u'الجكانى': u'الْجَكَّانِىُّ', #4
u'الجكي': u'الجكي', #1
u'الجلا': u'الْجَلَا', #1
u'الجلاب': u'الْجُلَّابُ', #1
u'الجلاب': u'الْجُلاَّبُ', #1
u'الجلاب': u'الْجَلَّابُ', #151
u'الجلاب': u'الْجَلاَّبُ', #19
u'الجلاب': u'الْجُلَّابِ', #2
u'الجلاب،': u'الْجَلابِ،', #3
u'الجلاب': u'الْجَلَّابِ', #431
u'الجلاب،': u'الْجَلابُ،', #6
u'الجلاب': u'الْجَلَّابَ', #6
u'الجلاباذى': u'الْجُلاَبَاذِىُّ', #1
u'الجلابي': u'الْجُلَابِيِّ', #2
u'الجلابي': u'الْجَلَّابِيِّ', #25
u'الجلابي': u'الْجَلَّابِي', #4
u'الجلابي': u'الْجَلَّابِيُّ', #7
u'الجلابين': u'الْجَلَّابِينَ', #3
u'الجلاج': u'الجلاج', #1
u'الجلاجل': u'الجلاجل', #1
u'الجلاجل': u'الْجَلَاجِل', #1
u'الجلاجل': u'الْجُلَاجِلُ', #1
u'الجلاجل': u'الْجُلَاجِلِ', #2
u'الجلاجل': u'الْجَلَاجِلِ', #5
u'الجلاجلي': u'الْجَلَاجِلِيِّ', #1
u'الجلاح': u'الْجَلاحَ', #1
u'الجلاح': u'الجَلاحِ', #2
u'الجلاح': u'الْجُلاحِ', #2
u'الجلاح،': u'الْجَلاحِ،', #2
u'الجلاح': u'الْجُلاَحُ', #2
u'الجلاح': u'الْجُلَاحِ', #22
u'الجلاح': u'الْجِلَاحِ', #3
u'الجلاح': u'الْجُلَاحُ', #4
u'الجلاح': u'الْجُلاَحِ', #6
u'الجلاهق': u'الْجَلَاهِقُ', #1
u'الجلاهق': u'الْجُلَاهِقِ', #2
u'الجلاهقات': u'الجُلاهِقات', #1
u'الجلاوات': u'الجلاوات', #1
u'الجلاوات': u'الْجَلَاوَاتِ', #1
u'الجلاودة': u'الْجَلاوِدَةُ', #1
u'الجلاوزة': u'الْجَلَاوِزَةُ', #1
u'الجلائب': u'الْجَلَائِبِ', #3
u'الجلجل': u'الْجُلْجُلَ', #1
u'الجلجل': u'الْجُلْجُلِ', #1
u'الجلجل': u'الْجُلْجُل', #2
u'الجلجل': u'الْجُلْجُلُ', #6
u'الجلح': u'الْجَلَحُ', #1
u'الجلحاء': u'الْجَلْحَاءِ', #10
u'الجلحاء': u'الْجَلْحَاءَ', #2
u'الجلحاء': u'الْجَلْحَاءُ', #2
u'الجلحاء': u'الجلحاء', #3
u'الجلدا': u'الْجَلْدَا', #2
u'الجلدات': u'الْجَلَدَاتِ', #26
u'الجلدات': u'الْجَلْدَاتِ', #3
u'الجلس': u'الْجَلْسِ', #1
u'الجللا': u'الْجَلَلَا', #1
u'الجلم': u'الْجَلَم', #1
u'الجلم': u'الْجَلَمُ', #1
u'الجلمان': u'الْجَلَمَانُ', #2
u'الجلمين': u'الْجَلَمَيْنِ', #1
u'الجلندى': u'الْجُلُنْدَى', #1
u'الجلندى': u'الْجُلَنْدَى', #5
u'الجله': u'الْجَلَهِ', #1
u'الجلهات': u'الْجَلْهَاتُ', #1
u'الجلواز': u'الْجِلْوَازُ', #3
u'الجلودي': u'الْجُلُودِيُّ', #2
u'الجلودى': u'الْجُلُودِىُّ', #4
u'الجلوزة': u'الْجَلْوَزَةِ', #1
u'الجلولي،': u'الجلوليّ،', #1
u'الجلولي،': u'الْجَلُوليّ،', #1
u'الجليب': u'الْجَلِيبِ', #3
u'الجليبيب؟': u'الْجُلَيْبِيبُ؟', #1
u'الجليلا': u'الْجَلِيلَا', #1
u'الجليلي': u'الجليلي', #1
u'الجليلي': u'الجليليّ', #1
u'الجليلي،': u'الجليلّيّ،', #1
u'الجماء': u'الجماء', #1
u'الجماء': u'الْجَمّاء', #1
u'الجماء': u'الْجَمَّاءَ', #1
u'الجماء': u'الْجَمَّاءِ', #11
u'الجماء': u'الْجَمَّاءُ', #14
u'الجماء': u'الْجَمّاءِ', #2
u'الجماء': u'الْجَمّاءَ', #8
u'الجماعا': u'الْجِمَاعَا', #2
u'الجماعةفي': u'الْجَمَاعَةِفِي', #1
u'الجمانة': u'الْجُمَانَةِ', #1
u'الجماهر،': u'الجماهر،', #1
u'الجماهر': u'الْجَمَاهِرِ', #13
u'الجماهر،': u'الْجُمَاهِرِ،', #156
u'الجماهر': u'الْجُمَاهِرِ', #40
u'الجماهر،': u'الْجَمَاهِرِ،', #5
u'الجماوات': u'الْجَمَّاوَاتِ', #2
u'الجمجم': u'الْجُمْجُمَ', #2
u'الجمحي': u'الجمحي', #1
u'الجمحي،': u'الجُمَحيّ،', #1
u'الجمحي': u'الجُمَحّي', #1
u'الجمحي،': u'الْجُمَحِيَّ،', #1
u'الجمحي': u'الْجُمَحِيَّ', #11
u'الجمحي': u'الجُمَحي', #2
u'الجمحي،': u'الجُمَحي،', #2
u'الجمحى': u'الْجُمَحِىَّ', #3
u'الجمحي': u'الْجُمَحِيّ', #44
u'الجمحي': u'الْجُمَحِيِّ', #47
u'الجمحي،': u'الْجُمَحِيُّ،', #47
u'الجمحي': u'الجُمَحِيّ', #5
u'الجمحى': u'الْجُمَحِىُّ', #51
u'الجمحي': u'الْجُمَحِيُّ', #55
u'الجمحي،': u'الجمحي،', #9
u'الجمحي،': u'الْجُمَحِيِّ،', #9
u'الجمحى': u'الْجُمَحِىِّ', #9
u'الجمحية': u'الْجُمَحِيَّةِ', #1
u'الجمحيين': u'الْجُمَحِيِّين', #1
u'الجمحيين': u'الْجُمَحِيِّينَ', #2
u'الجمزى': u'الْجَمَزَى', #2
u'الجمعه': u'الْجُمُعَهْ', #9
u'الجمله': u'الْجُمْلَهْ', #1
u'الجملون': u'الْجَمَلُونِ', #2
u'الجمهر': u'الْجَمْهَرِ', #1
u'الجميح': u'الْجُمَيْحُ', #1
u'الجميش': u'الْجَمِيشُ', #1
u'الجميش': u'الْجَمِيشِ', #7
u'الجميعا': u'الْجَمِيعَا', #1
u'الجميعي': u'الْجَمِيعِيَّ', #1
u'الجميعي': u'الْجَمِيعِيِّ', #5
u'الجميعي': u'الْجَمِيعِيُّ', #6
u'الجميمة': u'الجميمة', #1
u'الجنابةاااااااا': u'الْجَنَابَةَاااااااا', #1
u'الجنابذ': u'الجنابذ', #1
u'الجنادبة': u'الْجَنَادِبَةِ', #1
u'الجنادرة': u'الْجَنَادِرَةِ', #1
u'الجنانة': u'الْجَنَانَةِ', #1
u'الجنايز،': u'الْجَنَايِزِ،', #1
u'الجنبذة': u'الجنبذة', #1
u'الجنبى': u'الْجَنَبِىُّ', #1
u'الجنبى': u'الْجَنْبِىُّ', #2
u'الجنبى': u'الْجَنْبِىِّ', #2
u'الجنةأنتم': u'الْجَنَّةَأَنْتُمْ', #1
u'الجنةوروي': u'الْجَنَّةُوَرُوِيَ', #1
u'الجندعي': u'الْجُنْدُعِيّ', #1
u'الجندعي': u'الْجُنْدُعِيُّ', #1
u'الجندعي،': u'الْجُنْدَعِيُّ،', #1
u'الجندعي': u'الْجُنْدُعِيِّ', #2
u'الجندعى': u'الْجُنْدَعِىِّ', #2
u'الجندعي': u'الْجُنْدَعِيُّ', #3
u'الجندعي،': u'الْجُنْدَعِيِّ،', #3
u'الجندعى': u'الْجُنْدَعِىُّ', #3
u'الجندعي': u'الْجُنْدَعِيِّ', #5
u'الجندعيين': u'الْجَنْدَعِيِّينَ', #1
u'الجندعيين،': u'الْجُنْدَعِيِّينَ،', #1
u'الجندعيين': u'الْجُنْدِعِيِّينَ', #2
u'الجندى': u'الْجَنَدِىُّ', #3
u'الجنديسابوري': u'الْجُنْدَيْسَابُورِيُّ', #1
u'الجنديسابوري،': u'الْجُنْدَيَسَابُورِيِّ،', #1
u'الجنديسابوري،': u'الْجُنْدَيْسَابُورِيِّ،', #1
u'الجنديسابورى': u'الْجُنْدَيَسَابُوْرِىُّ', #1
u'الجنديسابوري،': u'الْجُنْدِيسَابُورِيُّ،', #2
u'الجنديسابوري،': u'الْجُنْدِيسَابُورِيِّ،', #2
u'الجنديسابورى': u'الْجُنْدَيْسَابُورِىُّ', #4
u'الجنديسابوري،': u'الْجُنْدَيْسَابُورِيُّ،', #6
u'الجنز': u'الْجَنْزِ', #1
u'الجنزروذى': u'الْجَنْزَرُوذِىُّ', #1
u'الجنزروذى': u'الْجَنْزَرَوْذِىُّ', #1
u'الجنف': u'الْجَنَفِ', #1
u'الجنف': u'الْجَنَفُ', #2
u'الجنو': u'الجنو', #2
u'الجنيب،': u'الْجَنِيبِ،', #1
u'الجنيب': u'الجنيب', #2
u'الجنيب': u'الْجَنِيبَ', #2
u'الجنيب': u'الْجَنِيبُ', #4
u'الجنيب': u'الْجَنِيبِ', #4
u'الجنيبة': u'الْجَنِيبَة', #1
u'الجنيبة': u'الْجَنِيبَةُ', #1
u'الجنيبة': u'الْجَنِيبَةِ', #13
u'الجنيبة': u'الْجَنِيبَةَ', #4
u'الجنيد': u'الْجُنَيْدَ', #12
u'الجنيد،': u'الْجُنَيْدُ،', #2
u'الجنيد': u'الْجُنَيْدِ', #212
u'الجنيد،': u'الجنيد،', #26
u'الجنيد،': u'الْجُنَيْدِ،', #276
u'الجنيد': u'الْجُنَيْدُ', #49
u'الجنيد': u'الجنيد', #8
u'الجنيدب': u'الْجُنَيْدِبِ', #2
u'الجنيدي': u'الجنيدي', #1
u'الجنيدي': u'الْجُنَيُدِيّ', #1
u'الجنيدي': u'الْجُنَيْدِيَّ', #1
u'الجنيدي': u'الْجُنَيْدِيُّ', #1
u'الجنيدى': u'الْجُنَيْدِىُّ', #8
u'الجنيدية': u'الْجُنَيْدِيَّةِ', #1
u'الجنيون': u'الْجِنِّيُّونَ', #3
u'الجهاله': u'الْجَهَالَهْ', #1
u'الجهام': u'الْجَهَامِ', #2
u'الجهجاه': u'الْجَهْجَاهُ', #1
u'الجهدمة': u'الجهدمة', #1
u'الجهدمة': u'الْجَهْدَمَةِ', #1
u'الجهذمة': u'الْجَهْذَمَةِ', #1
u'الجهضم': u'الْجَهْضَمِ', #1
u'الجهضم،': u'الْجَهْضَمِ،', #1
u'الجهضمي': u'الجهضمي', #1
u'الجهضمى': u'الْجَهْضَمِىَّ', #1
u'الجهضمي،': u'الْجَهْضَمِيُّ،', #13
u'الجهضمي،': u'الجهضمي،', #2
u'الجهضمي': u'الْجَهْضَمِيَّ', #2
u'الجهضمي': u'الْجَهْضَمِيُّ', #3
u'الجهضمي': u'الْجَهْضَمِيِّ', #4
u'الجهضمي،': u'الْجَهْضَمِيِّ،', #4
u'الجهضمى': u'الْجَهْضَمِىِّ', #5
u'الجهضمى': u'الْجَهْضَمِىُّ', #62
u'الجهلا': u'الْجَهْلَا', #1
u'الجهلان': u'الْجَهْلَانِ', #1
u'الجهلين': u'الْجَهْلَيْنِ', #3
u'الجهمة': u'الْجَهْمَةُ', #1
u'الجهنميون': u'الْجَهَنَّمِيُّونَ', #22
u'الجهني': u'الجُهني', #1
u'الجهني،': u'الجُهنيُّ،', #1
u'الجهني': u'الجُهَنيّ', #1
u'الجهني،': u'الجُهَني،', #1
u'الجهني،': u'الجُهَنيّ،', #1
u'الجهني': u'الْجُهَنيّ', #1
u'الجهني،': u'الْجُهَنيِّ،', #1
u'الجهني': u'الْجُهَنِيٍّ', #1
u'الجهني،': u'الْجُهْنِيِّ،', #1
u'الجهنى': u'الْجُهَنِىِّ', #109
u'الجهني،': u'الْجُهَنِيُّ،', #19
u'الجهني،': u'الجهني،', #2
u'الجهني،': u'الجُهَنّي،', #2
u'الجهني': u'الجهني', #20
u'الجهنى': u'الْجُهَنِىَّ', #22
u'الجهني': u'الْجُهَنِيِّ', #295
u'الجهنى': u'الْجُهَنِىُّ', #34
u'الجهني': u'الْجُهَنِيّ', #39
u'الجهني،': u'الْجُهَنِيِّ،', #49
u'الجهني': u'الْجُهَنِيَّ', #53
u'الجهني': u'الْجُهَنِيُّ', #67
u'الجهني': u'الجُهَني', #7
u'الجهني،': u'الْجُهَنِيَّ،', #8
u'الجهنيان': u'الْجُهَنِيّانِ', #1
u'الجهنيان': u'الْجُهَنِيَّانِ', #1
u'الجهنية': u'الْجُهَنِيَّةَ', #1
u'الجهنية': u'الجهنية', #2
u'الجهنية': u'الْجُهَنِيَّةِ', #20
u'الجهنيون': u'الْجُهَنِيُّونَ', #4
u'الجهنيين،': u'الْجُهَنِيِّينَ،', #1
u'الجهنيين': u'الْجُهَنِيِّينَ', #3
u'الجهه': u'الْجِهَهْ', #1
u'الجهيد': u'الْجَهِيدَ', #1
u'الجهينة': u'الْجُهَيْنَةِ', #1
u'الجهيني': u'الْجُهَيْنِيِّ', #1
u'الجهينية': u'الْجُهَيْنِيَّةِ', #3
u'الجهينيون': u'الْجُهَيْنِيُّونَ', #2
u'الجوا': u'الْجَوَا', #1
u'الجوابرة': u'الجوابرة', #1
u'الجوابيا': u'الجوابيا', #1
u'الجؤار': u'الْجُؤَار', #1
u'الجؤار': u'الجؤار', #2
u'الجواربي،': u'الْجَوَارِبِيُّ،', #1
u'الجواربي': u'الْجَوَارِبِيُّ', #2
u'الجوارش': u'الْجَوَارِشَ', #1
u'الجوارش': u'الْجَوَارِشُ', #2
u'الجوارشنات': u'الجوارشنات', #1
u'الجوارى': u'الْجَوَارِى', #3
u'الجوازل': u'الْجَوَازِلِ', #1
u'الجواظ': u'الجواظ', #2
u'الجواظ،': u'الْجَوَّاظُ،', #2
u'الجواظ': u'الْجَوَّاظُ', #3
u'الجوالقات': u'الْجُوَالِقَاتِ', #1
u'الجواليف': u'الْجَوَالِيفِ', #1
u'الجواليقى': u'الْجَوَالِيقِىُّ', #2
u'الجواليقي،': u'الْجَوَالِيقِيِّ،', #3
u'الجواليقي،': u'الْجَوَالِيقِيُّ،', #4
u'الجواليقي': u'الْجَوَالِيقِيِّ', #6
u'الجواليقي': u'الْجَوَالِيقِيُّ', #8
u'الجوامك': u'الْجَوَامِكِ', #3
u'الجوامك': u'الْجَوَامِكُ', #5
u'الجوانية': u'الْجُوَّانِيَّةِ', #1
u'الجوانية': u'الْجَوَّانِيَّةِ', #2
u'الجوانية': u'الْجُوَّانِيَّةُ', #2
u'الجواهري': u'الْجَوَاهِرِيُّ', #2
u'الجوايح': u'الْجَوَايِحُ', #1
u'الجوباري': u'الْجُوبَارِيُّ', #1
u'الجوباري،': u'الْجُوبَارِيِّ،', #1
u'الجوبة': u'الجوبة', #1
u'الجوبة،': u'الْجَوْبَةِ،', #2
u'الجوبة': u'الْجَوْبَة', #3
u'الجوبة': u'الْجَوْبَةِ', #3
u'الجوبري': u'الجوبري', #1
u'الجوجان': u'الْجُوجَانُ', #2
u'الجوجري': u'الْجَوْجَرِيُّ', #220
u'الجوجري': u'الْجَوْجَرِيَّ', #30
u'الجوجري': u'الْجَوْجَرِيِّ', #64
u'الجوذاب': u'الْجُوذَابِ', #1
u'الجوراي': u'الجوراي', #1
u'الجورائي': u'الْجُورَائِيِّ', #1
u'الجوربذي،': u'الْجَوْرَبَذِيِّ،', #1
u'الجورة': u'الْجَوَرَة', #1
u'الجورة': u'الْجَوَرَةَ', #1
u'الجورة': u'الْجَوَرَةِ', #2
u'الجورق': u'الْجَوْرَقَ', #1
u'الجورقاني': u'الْجُورَقَانِيِّ', #1
u'الجوزاجاني': u'الْجَوْزَاجَانِيُّ', #1
u'الجوزاني': u'الْجَوْزَانِيُّ', #1
u'الجوزجان،': u'الجَوْزَجان،', #1
u'الجوزجاني': u'الْجُوزَجَانِيُ', #1
u'الجوزجاني': u'الْجَوْزَجَانِيّ', #1
u'الجوزجاني': u'الْجُوزَجَانِيِّ', #16
u'الجوزجاني': u'الْجَوْزَجَانِيُّ', #2
u'الجوزجاني،': u'الْجُوزَجَانِيُّ،', #3
u'الجوزجانى': u'الْجُوزَجَانِىُّ', #3
u'الجوزجانى': u'الْجَوْزَجَانِىُّ', #3
u'الجوزجاني': u'الْجُوزَجَانِيّ', #5
u'الجوزجاني': u'الْجُوزَجَانِيَّ', #6
u'الجوزجاني': u'الْجُوزَجَانِيُّ', #71
u'الجوزجانية': u'الْجُوزَجَانِيَّةُ', #1
u'الجوزق': u'الجوزق', #1
u'الجوزق': u'الْجَوْزَقَ', #2
u'الجوزق': u'الْجَوْزَقُ', #3
u'الجوزق': u'الْجَوْزَقِ', #3
u'الجوزقاني': u'الجوزقاني', #1
u'الجوزقة': u'الجوزقة', #1
u'الجوزقة': u'الْجَوْزَقَةِ', #3
u'الجوزقي': u'الْجَوْزَقِيُّ', #1
u'الجوزقي': u'الْجَوْزَقِيِّ', #1
u'الجوزنيج': u'الْجَوْزَنِيجُ', #1
u'الجوزنيق': u'الْجَوْزَنِيقَ', #1
u'الجوزنيق': u'الْجَوْزَنِيقِ', #1
u'الجوزى': u'الْجَوْزِىِّ', #1
u'الجوزى': u'الْجَوْزِىُّ', #5
u'الجوزينج': u'الجوزينج', #1
u'الجوزينج': u'الْجُوزَيَنْجُ', #1
u'الجوزينق': u'الْجَوْزَيْنَقِ', #1
u'الجوزينق': u'الْجَوْزَيْنَقْ', #1
u'الجوسة': u'الْجُوسَةِ', #1
u'الجوسقانى': u'الْجَوْسَقَانِىُّ', #3
u'الجوشن': u'الجوشن', #2
u'الجوشن': u'الْجَوْشَنُ', #2
u'الجوشن،': u'الْجَوْشَنِ،', #3
u'الجوشن': u'الْجَوْشَنِ', #30
u'الجوشية': u'الْجَوْشِيّةَ', #2
u'الجوشية': u'الْجَوْشِيَّةَ', #2
u'الجوشية': u'الْجَوْشِيَّةُ', #2
u'الجوك': u'الجوك', #1
u'الجوكان': u'الْجُوكَانُ', #1
u'الجولق': u'الجولق', #1
u'الجولق': u'الْجَوْلَقَ', #4
u'الجولقين': u'الْجَوْلَقَيْنِ', #1
u'الجؤنة': u'الجؤنة', #1
u'الجؤنة': u'الْجُؤْنَةُ', #1
u'الجونى': u'الْجَوْنِىُّ', #15
u'الجونى': u'الْجَوْنِىِّ', #31
u'ألجؤه': u'أَلْجَؤُهُ', #1
u'الجوهرى': u'الجَوْهَرِىُّ', #1
u'الجوهرى': u'الْجَوْهَرِىَّ', #1
u'الجوهرى': u'الْجَوْهِرِىُّ', #1
u'الجوهرى': u'الْجَوْهَرِىُّ', #134
u'ألجؤهم': u'أَلْجَؤُهُمْ', #1
u'الجويبر،': u'الْجُوَيْبِرِ،', #1
u'الجويري': u'الْجُوَيْرِيُّ', #1
u'الجويرية': u'الْجُوَيْرِيَةُ', #1
u'الجويرية': u'الْجُوَيْرِيَّةِ', #1
u'الجويرية': u'الْجُوَيْرِيَةِ', #25
u'الجويرية،': u'الْجُوَيْرِيَةِ،', #4
u'الجويني': u'الْجُوَيْنِيّ', #1
u'الجوينى': u'الْجُوَينِىُّ', #1
u'الجويني': u'الْجُوَيْنِيِّ', #131
u'الجويني': u'الْجُوَيْنِيُّ', #208
u'الجوينى': u'الْجُوَيْنِىُّ', #3
u'الجويني': u'الْجُوَيْنِيَّ', #8
u'الجيء': u'الْجِيءِ', #1
u'الجيء': u'الْجَيْءِ', #1
u'الجئوا': u'اِلْجَئُوا', #3
u'الجياب': u'الْجَيَّابِ', #1
u'الجيادية': u'الْجِيَادِيَّةَ', #1
u'الجيارون': u'الْجَيَّارُونَ', #1
u'الجياني': u'الْجَيَّانِيّ', #1
u'الجياني': u'الْجَيَّانِيِّ', #1
u'الجياني': u'الْجِيَانِيّ', #1
u'الجياني': u'الْجَيَّانِيُّ', #7
u'الجيائل': u'الْجَيَائِلُ', #2
u'الجيحون': u'الجيحون', #1
u'الجيحون': u'الْجَيْحُونِ', #2
u'الجيدراني': u'الْجَيْدَرانِيَّ', #1
u'الجيدراني': u'الْجَيْدَرانِيُّ', #1
u'الجيدراني': u'الْجَيْدَرانِيِّ', #1
u'الجيروني': u'الْجَيْرُونِيِّ', #1
u'الجيزة': u'الْجِيزَةُ', #1
u'الجيزة': u'الْجِيزَةِ', #9
u'الجيزي': u'الْجِيزِيِّ', #10
u'الجيزي،': u'الْجِيزِيُّ،', #13
u'الجيزي،': u'الجيزي،', #2
u'الجيزي': u'الْجِيزِيّ', #2
u'الجيزي': u'الْجِيزِيَّ', #4
u'الجيزي': u'الْجِيزِيُّ', #69
u'الجيزي،': u'الْجِيزِيِّ،', #8
u'الجيشانى': u'الْجَيْشَانِىِّ', #14
u'الجيشانى': u'الْجَيْشَانِىُّ', #2
u'الجيعان': u'الْجِيعَانِ', #4
u'الجيلاني': u'الْجِيلَانِيِّ', #1
u'الجيلاني': u'الْجِيلَانِيُّ', #3
u'الجيلوني': u'الْجِيلُونِيِّ', #1
u'الجيلوي': u'الجيلوي', #1
u'الجيلوي': u'الْجَيْلَوِيِّ', #1
u'الجيلوي': u'الْجَيْلَوِيُّ', #5
u'الجيند،': u'الجيند،', #1
u'الجيوشي': u'الْجُيُوشِيِّ', #1
u'الحا': u'َالِحًا', #1
u'الحا': u'الْحَا', #2
u'الحاتمي': u'الْحَاتِمِيُّ', #1
u'الحاتمي': u'الْحَاتِمِيِّ', #1
u'الحاجةقوله': u'الْحَاجَةِقَوْلُهُ', #1
u'الحاجوز': u'الْحَاجُوزِ', #1
u'الحاجوي': u'الْحَاجَوِيُّ', #1
u'الحادثا': u'الْحَادِثَا', #1
u'الحادثون': u'الْحَادِثُونَ', #30
u'الحادس': u'الْحَادِسَ', #1
u'الحادى': u'الْحَادِى', #5
u'الحاذ': u'الْحَاذ', #1
u'الحاذ': u'الْحَاذِ', #6
u'الحاذر': u'الْحَاذِرُ', #1
u'الحاربي،': u'الْحَارِبِيُّ،', #1
u'الحارت': u'الْحَارِتِ', #1
u'الحارثإذا': u'الْحَارِثِإِذَا', #1
u'الحارثما': u'الْحَارِثِمَا', #1
u'الحارثى': u'الْحَارِثِىَّ', #1
u'الحارثى': u'الْحَارِثِىُّ', #133
u'الحارثى': u'الْحَارِثِىِّ', #4
u'الحارثية': u'الحارثية', #1
u'الحارثية': u'الْحَارِثِيَّة', #1
u'الحارثية': u'الْحَارِثِيَّةِ', #1
u'الحارثية،': u'الْحَارِثِيَّةُ،', #1
u'الحارثية': u'الْحَارِثِيّةُ', #3
u'الحارثية': u'الْحَارِثِيّةِ', #6
u'الحارثىحدثنا': u'الْحَارِثِىُّحَدَّثَنَا', #1
u'الحارثيون': u'الْحَارِثِيُّونَ', #1
u'الحارثيون': u'الْحَارِثِيّونَ', #2
u'الحارثيين': u'الْحَارِثِيِّينَ', #1
u'الحارثيين': u'الْحَارِثِيَّيْنِ', #4
u'الحارسه': u'الْحَارِسَهْ', #1
u'الحارصة': u'الْحَارِصَةِ', #22
u'الحارصة': u'الْحَارِصَةُ', #23
u'الحارصة': u'الْحَارِصَةَ', #4
u'الحازمي': u'الْحَازِمِي', #1
u'الحازمي': u'الْحَازِمِيَّ', #1
u'الحازمي،': u'الْحَازِمِيُّ،', #2
u'الحازمي': u'الْحَازِمِيِّ', #3
u'الحازمي': u'الْحَازِمِيُّ', #35
u'الحازي': u'الْحَازِي', #2
u'الحاس': u'الْحَاسَّ', #1
u'الحاضرةقوله': u'الْحَاضِرَةَقَوْلُهُ', #1
u'الحاضرى': u'الْحَاضِرِىُّ', #2
u'الحاضنه': u'الْحَاضِنَهْ', #1
u'الحاطبي': u'الحاطبي', #1
u'الحاطبي': u'الْحَاطِبِيُّ', #1
u'الحاطبي،': u'الْحَاطِبِيُّ،', #1
u'الحاطبى': u'الْحَاطِبِىُّ', #1
u'الحاطبيون': u'الْحَاطِبِيُّونَ', #1
u'الحاظر': u'الْحَاظِرَ', #6
u'الحاظر': u'الْحَاظِرُ', #7
u'الحاظر': u'الْحَاظِرِ', #7
u'الحاظرة': u'الْحَاظِرَةُ', #1
u'الحاظرة': u'الْحَاظِرَةِ', #1
u'الحافظية': u'الْحَافِظِيَّةِ', #13
u'إلحاقة': u'إلْحَاقَةَ', #1
u'إلحاقة': u'إلْحَاقَةُ', #1
u'الحاقف': u'الْحَاقِف', #1
u'الحاقف': u'الْحَاقِفِ', #1
u'الحاقف': u'الْحَاقِفُ', #2
u'الحاقم': u'الْحَاقِمُ', #1
u'الحالوم': u'الْحَالُومُ', #1
u'الحالوم': u'الْحَالُومِ', #1
u'الحامدي': u'الْحَامِدِيُّ', #8
u'الحامدية': u'الحامدية', #1
u'الحامدية': u'الْحَامِدِيَّةِ', #147
u'الحامدية': u'الْحَامِدِيَّةُ', #9
u'الحامشا': u'الْحَامِشَا', #1
u'الحاملSشعر': u'الْحَامِلِSشِعْرُ', #1
u'الحاملية': u'الْحَامِلِيَّةَ', #1
u'الحاملية': u'الْحَامِلِيَّةِ', #1
u'الحامم': u'الْحَامِم', #1
u'الحاميSوذكر': u'الْحَامِيSوَذَكَرَ', #1
u'الحائش': u'الحائش', #1
u'الحبا': u'الْحُبَا', #1
u'الحبا': u'الْحَبَا', #2
u'الحبابا': u'الْحَبَابَا', #1
u'الحباس': u'الْحَبَّاسِ', #2
u'الحبالات': u'الْحِبَالَاتُ', #2
u'الحبالات': u'الْحِبَالَاتِ', #3
u'الحباني': u'الْحِبَّانِيُّ', #1
u'الحبةوالوجه': u'الْحَبَّةِوَالْوَجْهُ', #1
u'الحبحاب،': u'الحُبْحَابِ،', #1
u'الحبحاب': u'الْحَبْحَابُ', #1
u'الحبحاب،': u'الْحَبْحَابِ،', #10
u'الحبحاب': u'الْحَبْحَاب', #2
u'الحبحاب': u'الْحَبْحَابِ', #31
u'الحبحب': u'الْحَبْحَبُ', #1
u'الحبحب': u'الْحَبْحَبِ', #1
u'الحبراني،': u'الْحَبْرانِيُّ،', #1
u'الحبراني،': u'الْحُبرَانِيُّ،', #1
u'الحبراني': u'الْحَبْرَانِيُّ', #1
u'الحبراني': u'الْحَبْرَانِيِّ', #1
u'الحبراني': u'الْحُبْرَانِيّ', #1
u'الحبراني،': u'الْحَبْرَانِيُّ،', #1
u'الحبراني،': u'الْحَبْرَانِيِّ،', #1
u'الحبرانى': u'الْحُبْرَانِىُّ', #1
u'الحبراني': u'الحبراني', #2
u'الحبراني': u'الْحُبْرَانِيَّ', #2
u'الحبراني،': u'الحبراني،', #3
u'الحبراني،': u'الْحُبْرَانِيُّ،', #3
u'الحبرانى': u'الْحُبْرَانِىِّ', #4
u'الحبراني': u'الْحُبْرَانِيُّ', #6
u'الحبراني': u'الْحُبْرَانِيِّ', #7
u'الحبراوي': u'الْحَبْرَاوِيُّ', #1
u'الحبرى': u'الْحِبَرِىُّ', #2
u'الحبساء': u'الْحُبَسَاءُ', #1
u'الحبشةSرسوله': u'الْحَبَشَةِSرَسُولُهُ', #1
u'الحبشه': u'الحبشه', #1
u'الحبشى': u'الْحَبَشِىُّ', #2
u'الحبشى': u'الْحَبَشِىِّ', #3
u'الحبطي': u'الْحَبَطِيَّ', #1
u'الحبطي،': u'الْحَبَطِيُّ،', #4
u'الحبطي': u'الْحَبَطِيُّ', #6
u'الحبلا': u'الْحَبْلَا', #1
u'الحبلق': u'الْحَبَلّقِ', #4
u'الحبوبات': u'الْحُبُوبَاتِ', #3
u'الحبوسة': u'الْحُبُوسَةِ', #1
u'الحبون': u'الْحُبُونِ', #1
u'الحبير': u'الحبير', #1
u'الحبير': u'الْحَبِير', #1
u'الحبير': u'الْحَبِيرُ', #1
u'الحبير': u'الْحَبِيرْ', #1
u'الحبير': u'الْحَبِيرِ', #2
u'الحبيشي': u'الْحُبَيْشِيِّ', #1
u'الحبيق': u'الْحُبَيْقِ', #4
u'الحبيك': u'الحَبيك', #1
u'الحبيك': u'الْحَبِيكِ', #2
u'الحتوفا': u'الْحُتُوفَا', #3
u'الحثوة': u'الْحِثْوَةِ', #1
u'الحثي': u'الْحَثْيَ', #1
u'الحثي': u'الْحَثْي', #2
u'الحثي': u'الْحَثْيُ', #3
u'الحثي': u'الْحَثْيِ', #4
u'الحثيات': u'الْحَثَيَات', #1
u'الحثية': u'الْحَثْيَةِ', #3
u'الحج': u'الْحَجًًًًِّ', #1
u'الحجات': u'الْحَجَّاتِ', #2
u'الحجاجيقول': u'الْحَجَّاجَيَقُولُ', #1
u'الحجاح': u'الْحَجَّاحُ', #1
u'الحجاح': u'الْحَجَّاحِ', #1
u'الحجاره': u'الْحِجَارَهْ', #1
u'الحجازفقال': u'الْحِجَازِفَقَالَ', #1
u'الحجازكله': u'الْحِجَازِكُلّهِ', #1
u'الحجازى': u'الْحُجَازِىُّ', #1
u'الحجازى': u'الْحِجَازِىُّ', #8
u'الحجاف،': u'الْحَجَّافِ،', #1
u'الحجاف': u'الْحَجَّافِ', #2
u'الحجاوم': u'الحجاوم', #1
u'الحجاوي': u'الحجاوي', #1
u'الحجاوي': u'الْحَجَّاوِيِّ', #11
u'الحجاوي': u'الْحَجَّاوِيّ', #2
u'الحجاوي': u'الْحَجَّاوِيَّ', #2
u'الحجاوي': u'الْحَجَّاوِيُّ', #81
u'الحجبي': u'الحجبي', #1
u'الحجبي،': u'الحُجُبي،', #1
u'الحجبي،': u'الْحَجَبِيُّ،', #11
u'الحجبى': u'الْحَجَبِىِّ', #14
u'الحجبي': u'الْحَجَبِيُّ', #19
u'الحجبي،': u'الحجبي،', #2
u'الحجبي': u'الْحَجَبِيّ', #2
u'الحجبي،': u'الْحَجَبِيِّ،', #2
u'الحجبى': u'الْحَجَبِىُّ', #28
u'الحجبي': u'الْحَجَبِيَّ', #3
u'الحجبي': u'الْحَجَبِيِّ', #9
u'الحجبين': u'الْحَجْبَيْنِ', #1
u'الحجبيين': u'الْحَجَبِيِّينَ', #1
u'ألحجت': u'أَلَحَجْت', #1
u'الحجرا': u'الْحَجَرَا', #1
u'الحجرى': u'الْحَجْرِىُّ', #1
u'الحجرى': u'الْحَجَرِىُّ', #2
u'الحجرى': u'الْحَجْرِىِّ', #3
u'الحجف،': u'الحَجَف،', #1
u'الحجف': u'الْحَجَفَ', #1
u'الحجف': u'الْحَجَفِ', #1
u'الحجف': u'الْحَجَفُ', #3
u'الحجفة': u'الْحَجَفَة', #1
u'الحجفة': u'الْحَجَفَةَ', #1
u'الحجفة،': u'الْحَجَفَةَ،', #1
u'الحجفة،': u'الْحَجَفَةِ،', #1
u'الحجفة': u'الحجفة', #3
u'الحجمة': u'الْحَجْمَةِ', #2
u'الحجنة': u'الْحَجْنَةُ', #1
u'الحجواني': u'الحجواني', #1
u'الحجون': u'الْحَجُونُ', #1
u'الحجون،': u'الْحَجُونَ،', #1
u'الحجون': u'الْحُجُونُ', #2
u'الحجون،': u'الْحَجُونِ،', #2
u'الحجون': u'الْحَجُونَ', #3
u'الحجون': u'الْحَجُونِ', #33
u'الحجون': u'الْحُجُونِ', #5
u'الحجونين': u'الْحَجُونَيْنِ', #4
u'الحجى': u'الْحِجَى', #6
u'الحجين': u'الْحَجَّيْنِ', #1
u'الحدآت': u'الْحِدَآتِ', #3
u'الحداقة': u'الْحَدَّاقَةُ', #1
u'الحدانى': u'الْحُدَّانِىَّ', #1
u'الحدانى': u'الْحُدَّانِىِّ', #2
u'الحدانى': u'الْحُدَّانِىُّ', #6
u'الحدثات': u'الْحَدَثَاتِ', #1
u'الحدثانى': u'الْحُدَثَانِىِّ', #1
u'الحدثمن': u'الْحَدَثُمِنْ', #1
u'الحدثى': u'الحدثى', #1
u'الحدثى،': u'الْحُدْثَى،', #1
u'الحدثى': u'الْحُدْثَى', #6
u'الحدجة': u'الْحَدَجَةُ', #2
u'الحدجة': u'الْحَدَجَةَ', #3
u'الحدجة': u'الْحَدَجَةِ', #3
u'الحددباب': u'الْحِددبَابِ', #1
u'الحدوبة': u'الحدوبة', #1
u'الحدوبة': u'الْحُدُوبَةُ', #5
u'الحدوة': u'الْحَدْوَةُ', #2
u'الحدوج': u'الْحُدُوجَ', #1
u'الحديا': u'الْحُدَيَّا', #2
u'الحديببة': u'الْحُدَيْبِبّةِ', #1
u'الحديبيين': u'الْحُدَيْبِيِّينَ', #1
u'الحديثبسم': u'الحديثبسم', #1
u'الحديثتقريب': u'الحديثتقريب', #1
u'الحديثمن': u'الْحَدِيثِمِنْ', #1
u'الحديثوعن': u'الْحديثوَعَنِ', #1
u'الحديدا': u'الْحَدِيدَا', #5
u'الحذامي': u'الْحِذَامِيَّ', #1
u'الحذامي،': u'الْحِذَامِيُّ،', #1
u'الحذف': u'الْحُذُفً', #1
u'الحذفة': u'الْحَذْفَةِ', #1
u'الحذفي': u'الْحَذْفِيُّ', #1
u'الحذفي': u'الْحَذْفِيِّ', #1
u'الحذم': u'الْحَذْمُ', #1
u'الحذوة': u'الْحَذْوَةَ', #1
u'الحذيا': u'الْحَذْيَا', #1
u'الحذية': u'الْحِذْيَة', #1
u'الحذية،': u'الْحِذْيَةَ،', #1
u'الحراء': u'الْحَرَّاءِ', #1
u'الحراثون': u'الْحَرَّاثُونَ', #7
u'الحراثين': u'الْحَرَّاثِينَ', #4
u'الحراجيج': u'الْحَرَاجِيجَ', #1
u'الحرادي': u'الحرادي', #1
u'الحرادي': u'الْحَرَادِيُّ', #1
u'الحرادي': u'الْحَرَادِيّ', #2
u'الحرازي،': u'الحَرَازيّ،', #1
u'الحرازي،': u'الْحَرَّازِيُّ،', #1
u'الحرازي': u'الْحَرَازِيُّ', #2
u'الحرازي،': u'الْحَرَازِيُّ،', #2
u'الحرازي': u'الْحَرَازِيِّ', #3
u'الحراسين': u'الْحَرَّاسِينَ', #2
u'الحرافيش': u'الْحَرَافِيشِ', #1
u'الحرافيش': u'الْحَرَافِيشُ', #5
u'الحراق': u'الْحُرَاقُ', #1
u'الحراق': u'الْحِرَاقَ', #1
u'الحرامى': u'الْحَرَامِىِّ', #2
u'الحراني': u'الْحَرَّانِي', #1
u'الحراني،': u'الْحَرَّانِيَّ،', #1
u'الحرانى': u'الْحَرَّانِىِّ', #1
u'الحراني': u'الْحَرَّانِيُّ', #118
u'الحراني،': u'الْحَرَّانِيِّ،', #174
u'الحراني': u'الحراني', #2
u'الحرانى': u'الْحَرَّانِىَّ', #2
u'الحراني،': u'الحراني،', #34
u'الحراني': u'الْحَرَّانِيِّ', #41
u'الحراني': u'الْحَرَّانِيَّ', #5
u'الحراني،': u'الْحَرَّانِيُّ،', #598
u'الحرانى': u'الْحَرَّانِىُّ', #81
u'الحرانيان': u'الْحَرَّانِيَّانِ', #1
u'الحرانيان،': u'الْحَرَّانِيَّانِ،', #1
u'الحراوي': u'الْحِرَّاوِيِّ', #1
u'الحرائب': u'الْحَرَائِبِ', #1
u'الحرائم': u'الْحَرَائِمِ', #1
u'الحربث': u'الْحُرْبُثَ', #1
u'الحرثات': u'الْحَرْثَاتِ', #1
u'الحرثين': u'الْحَرْثَيْنِ', #2
u'الحرجد': u'الْحَرْجَدَ', #1
u'الحرح': u'الْحَرَحُ', #1
u'الحردي': u'الْحُرْدِيَّ', #1
u'الحردي': u'الْحَرْدِيُّ', #2
u'الحردي': u'الْحُرْدِيُّ', #2
u'الحرر': u'الْحَرَرَ', #1
u'الحرسات': u'الْحِرْسَات', #1
u'الحرستاني': u'الحَرَسْتاني', #1
u'الحرشى': u'الْحَرَشِىِّ', #1
u'الحرشى': u'الْحَرَشِىُّ', #59
u'الحرصات': u'الْحَرَصَاتُ', #1
u'الحرصات': u'الْحُرُصَاتِ', #1
u'الحرصة': u'الْحَرْصَةَ', #2
u'الحرضى': u'الْحُرْضىِ', #1
u'الحرضى': u'الْحَرَضِىُّ', #1
u'الحرضى': u'الْحُرْضِىُّ', #4
u'الحرفات': u'الْحِرْفَاتِ', #2
u'الحرفى': u'الْحُرْفِىِّ', #2
u'الحرفى': u'الْحُرْفِىُّ', #44
u'الحرفى': u'الْحِرَفِىُّ', #5
u'الحرقانية': u'الْحَرْقَانِيَّةِ', #2
u'الحرقد': u'الْحَرْقَدَ', #3
u'الحرقدة': u'الْحَرْقَدَةَ', #2
u'الحرقدة': u'الْحَرْقَدَةِ', #2
u'الحرقوص': u'الْحُرْقُوصُ', #1
u'الحرما': u'الْحَرَمَا', #3
u'الحرمازي': u'الْحَرْمَازِيّ', #1
u'الحرمازي': u'الْحِرْمَازِيِّ', #1
u'الحرمازي،': u'الْحِرْمَازِيُّ،', #1
u'الحرمازى': u'الحرمازى', #1
u'الحرمازي': u'الْحِرْمَازِيُّ', #2
u'الحرمد؟': u'الحرمد؟', #1
u'الحرمد': u'الْحَرْمَدُ', #2
u'الحرميني': u'الحرميني', #1
u'الحره': u'الْحُرَّهْ', #1
u'الحرو': u'الْحُرُو', #2
u'الحروراء': u'الْحَرُورَاء', #1
u'الحرورة': u'الْحَرُورَةِ', #1
u'الحرورى': u'الْحَرُورِىَّ', #2
u'الحرورى': u'الْحَرُورِىُّ', #2
u'الحروز': u'الْحُرُوزَ', #2
u'الحروز': u'الْحُرُوزُ', #2
u'الحروز': u'الْحُرُوزِ', #5
u'الحرى': u'الْحَرَّى', #1
u'الحرى': u'الْحَرَى', #2
u'الحريب': u'الْحَرِيبَ', #2
u'الحريب': u'الْحَرِيبِ', #2
u'الحريبة': u'الْحَرِيبَةُ', #1
u'الحريث': u'الْحُرَيْثِ', #5
u'الحريرى': u'الْحَرِيرِىِّ', #1
u'الحريرى': u'الْحَرِيرِىُّ', #8
u'الحريس': u'الْحَرِيسُ', #4
u'الحريسات': u'الْحَرِيسَات', #1
u'الحريسة': u'الْحَرِيسَةُ', #1
u'الحريسة': u'الْحَرِيسَة', #2
u'الحريسة': u'الْحَرِيسَةَ', #2
u'الحريسة': u'الْحَرِيسَةِ', #4
u'الحريش،': u'الْحُرَيْشِ،', #1
u'الحريش': u'الْحَرِيشِ', #13
u'الحريش': u'الْحَرِيشُ', #2
u'الحريش،': u'الْحَرِيشِ،', #2
u'الحريش': u'الحريش', #3
u'الحزابة': u'الْحُزَابَةُ', #1
u'الحزار': u'الْحَزّارِ', #1
u'الحزامى': u'الْحِزَامِىِّ', #1
u'الحزامى': u'الحزامى', #2
u'الحزامى': u'الْحِزَامِىَّ', #21
u'الحزامى': u'الْحِزَامِىُّ', #22
u'الحزان': u'الحِزَّانُ', #1
u'الحزان': u'الْحِزّانُ', #2
u'الحزة': u'الْحَزَّةِ', #1
u'الحزة': u'الْحَزَّةُ', #2
u'الحزة': u'الْحُزَّةَ', #2
u'الحزرات': u'الْحَزَرَاتُ', #2
u'الحزفى': u'الْحُزَفِىُّ', #1
u'الحزقان': u'الحزقان', #1
u'الحزمى': u'الْحَزْمِىِّ', #1
u'الحزورة': u'الْحَزْوَرَةُ', #3
u'الحزورة': u'الْحَزْوَرَةِ', #9
u'الحزون': u'الْحُزُونِ', #1
u'الحزون': u'الْحُزُونَ', #2
u'الحزونة': u'الْحُزُونَةُ', #2
u'الحزونة': u'الْحُزُونَةِ', #3
u'الحزيم': u'الْحَزِيمَ', #1
u'الحزيم': u'الْحَزِيمُ', #1
u'الحسانى': u'الْحَسَّانِىُّ', #14
u'الحسحاس': u'الحسحاس', #1
u'الحسحاس': u'الحَسْحَاس', #1
u'الحسحاس': u'الْحَسْحَاسِ', #17
u'الحسحاس': u'الْحِسْحَاسِ', #5
u'الحسدين': u'الْحَسَدَيْنِ', #1
u'الحسل': u'الْحِسْلِ', #2
u'الحسلي،': u'الحِسْلِيُّ،', #1
u'الحسنأصحاب': u'الْحَسَنِأَصْحَابُ', #1
u'الحسنسمعت': u'الْحَسَنُسَمِعْتُ', #1
u'الحسنعن': u'الْحَسَنَعَنِ', #1
u'الحسنعن': u'الْحَسَنَعَنْ', #1
u'الحسنعن': u'الْحَسَنُعَنْ', #1
u'الحسنعن': u'الْحَسَنِعَنْ', #1
u'الحسنعوان': u'الْحَسَنِعَوَانٌ', #1
u'الحسنفي': u'الْحَسَنُفِي', #1
u'الحسنقوله': u'الْحَسَنِقَوْلُهُ', #1
u'الحسنهو': u'الْحَسَنُهُوَ', #1
u'الحسنوالله': u'الْحَسَنُوَاللَّهِ', #1
u'الحسنوكان': u'الْحَسَنِوَكَانَ', #1
u'الحسنومستودع،': u'الْحَسَنِوَمُسْتَوْدَعٌ،', #1
u'الحسنيون': u'الْحَسَنِيُّونَ', #1
u'الحسيل،': u'الْحُسَيْلُ،', #1
u'الحسينأن': u'الْحُسَيْنِأَنَّ', #1
u'الحسينى': u'الْحُسَيْنِىُّ', #6
u'الحشارون': u'الْحَشَّارُونَ', #1
u'الحشاوة': u'الْحَشَاوَةِ', #4
u'الحشاياه،': u'الْحَشَايَاه،', #1
u'الحشرالموت': u'الْحَشْرُالْمَوْتُ', #1
u'الحشرج': u'الْحَشْرَجِ', #1
u'الحشرج': u'الْحَشْرَجُ', #3
u'الحشفه': u'الْحَشَفَهْ', #2
u'الحشكفان': u'الْحَشْكَفَانِ', #1
u'الحشني': u'الحشني', #1
u'الحشوش': u'الْحُشُوش', #3
u'الحشوش': u'الْحُشُوشِ', #3
u'الحشوش': u'الْحُشُوشُ', #7
u'الحشوش': u'الْحُشُوشَ', #8
u'الحشى': u'الْحَشَى', #5
u'الحشيا': u'الحشيا', #1
u'الحصا': u'الحَصَا', #1
u'الحصا،': u'الْحَصَا،', #4
u'الحصا': u'الْحَصَا', #56
u'الحصاوي': u'الْحَصَاوِي', #1
u'الحصائري': u'الْحَصَائِرِيِّ', #2
u'الحصرا': u'الْحَصْرَا', #1
u'الحصفكي': u'الْحَصْفَكِيِّ', #1
u'الحصكفي': u'الْحَصْكَفِيُّ', #22
u'الحصكفي': u'الْحَصْكَفِيِّ', #6
u'الحصمات': u'الْحَصَمَاتِ', #1
u'الحصورة': u'الْحَصُورَةُ', #1
u'الحصوص': u'الحصوص', #1
u'الحصولي': u'الْحُصُولِيُّ', #1
u'الحصولي': u'الْحُصُولِيِّ', #2
u'الحصيب': u'الحصيب', #1
u'الحصيب': u'الحُصَيب', #1
u'الحصيب': u'الحُصَيْب', #1
u'الحصيب': u'الْحُصَيْبُ', #1
u'الحصيب،': u'الْحُصَيْبِ،', #17
u'الحصيب': u'الْحُصَيْبِ', #37
u'الحصيب': u'الْحَصِيبِ', #5
u'الحضاج': u'الْحِضَاجُ', #1
u'الحضارم': u'الْحَضَارِمِ', #3
u'الحضالي': u'الحضالي', #1
u'الحضانه': u'الْحَضَانَهْ', #1
u'الحضاية': u'الْحَضَايَةِ', #1
u'الحضرم': u'الْحَضْرَمِ', #1
u'الحضرمة': u'الْحَضْرَمَةَ', #1
u'الحضرمى': u'الْحَضْرَمِىَّ', #10
u'الحضرمى': u'الْحَضْرَمِىُّ', #101
u'الحضرمى': u'الْحَضْرَمِىِّ', #78
u'الحضير': u'الحُضَيْر', #1
u'الحضير': u'الْحَضِيرِ', #1
u'الحضير': u'الحُضَير', #2
u'الحضير': u'الْحُضَيْرِ', #24
u'الحضير،': u'الْحُضَيْرِ،', #3
u'الحضين': u'الْحُضَيْنِ', #1
u'الحضين،': u'الْحُضَيْنُ،', #1
u'الحطابي': u'الْحَطَّابِيِّ', #2
u'الحطاني': u'الْحِطَّانِيُّ', #1
u'الحطة': u'الحطة', #1
u'الحطة': u'الْحِطَّةُ', #1
u'الحطة': u'الْحِطَّةِ', #8
u'الحطيم': u'الْحَطِيم', #1
u'الحطيم،': u'الْحَطِيمِ،', #2
u'الحطيم': u'الْحَطِيمُ', #23
u'الحطيم': u'الْحَطِيمَ', #53
u'الحطيم': u'الْحَطِيمِ', #77
u'الحظارات': u'الْحَظَارَاتِ', #1
u'الحظرية': u'الْحَظْرِيَّةِ', #3
u'الحظو': u'الْحُظُوّ', #1
u'الحظوظات': u'الْحُظُوظَاتِ', #1
u'الحظير': u'الْحَظِيرِ', #1
u'الحفإ': u'الْحَفَإِ', #1
u'الحفاةالعراة': u'الْحُفَاةَالْعُرَاةَ', #1
u'الحفد': u'الْحَفْدُ', #1
u'الحفد': u'الْحَفْدِ', #3
u'الحفرا': u'الْحُفَرَا', #1
u'الحفرى': u'الْحَفَرِىَّ', #2
u'الحفرى': u'الْحَفَرِىِّ', #2
u'الحفرى': u'الْحَفَرِىُّ', #22
u'الحفش': u'الحفش', #1
u'الحفش': u'الْحَفْشَ', #1
u'الحفش': u'الْحِفْشُ', #2
u'الحفش': u'الْحَفْشُ', #3
u'الحفظين': u'الْحِفْظَيْنِ', #1
u'الحفناوي': u'الْحَفْنَاوِيُّ', #10
u'الحفى': u'الحفى', #2
u'الحفيا': u'الْحَفْيَا', #1
u'الحفياء': u'الْحَفْيَاءَ', #1
u'الحفياء': u'الْحَفْيَاءُ', #2
u'الحفياء،': u'الْحَفْيَاءِ،', #2
u'الحفياء': u'الْحَفْيَاءِ', #38
u'الحفيدة': u'الْحَفِيدَةِ', #1
u'الحفيدد': u'الْحَفَيْدَدِ', #1
u'الحفيفتين': u'الْحَفِيفَتَيْنِ', #1
u'الحقائبSحول': u'الْحَقَائِبِSحَوْلَ', #1
u'الحقبا': u'الْحَقَبَا', #4
u'ألحقتنى': u'أَلْحَقْتَنِى', #1
u'الحقحقة': u'الْحَقْحَقَةِ', #1
u'الحقحقة': u'الْحَقْحَقَةُ', #4
u'الحقراء': u'الْحُقَرَاءِ', #1
u'الحقرة': u'الْحُقْرَةِ', #2
u'ألحقنى': u'أَلْحَقَنِى', #1
u'الحكرة': u'الْحُكْرَة', #2
u'الحكرة': u'الْحُكْرَةَ', #4
u'الحكرة': u'الْحُكْرَةُ', #4
u'الحكرة': u'الْحُكْرَةِ', #7
u'الحكما': u'الْحُكْمَا', #2
u'الحكور': u'الْحُكُورِ', #1
u'الحكورة': u'الحكورة', #1
u'الحكورة': u'الْحُكُورَةُ', #1
u'الحكوم': u'الحكوم', #1
u'الحكوم': u'الْحُكُومِ', #1
u'الحكومه': u'الْحُكُومَهْ', #3
u'الحكيمى': u'الْحَكِيمِىُّ', #1
u'الحكيمى': u'الْحَكِيمِىِّ', #1
u'الحلاء': u'الحلاء', #1
u'الحلاحل': u'الْحُلَاحِلُ', #2
u'الحلالS': u'الْحَلَالِS', #1
u'الحلام': u'الْحُلَّامُ', #2
u'الحلائس': u'الْحَلَائِسِ', #1
u'الحلائق': u'الْحَلَائِقَ', #1
u'الحلائق': u'الْحَلَائِقِ', #1
u'الحلبس': u'الْحَلْبَسِ', #1
u'الحلبى': u'الْحَلَبِىَّ', #1
u'الحلبى': u'الْحَلَبِىُّ', #26
u'الحلبيون': u'الْحَلَبِيُّونَ', #1
u'الحلحي': u'الْحَلْحِيُّ', #1
u'الحلز': u'الْحِلّزُ', #1
u'الحلزة': u'الْحِلّزَةُ', #1
u'الحلفا': u'الْحَلِفَا', #1
u'الحلفا': u'الْحَلْفَا', #3
u'الحلقطيرات': u'الحلقطيرات', #1
u'الحلقوروي': u'الْحَلْقِوَرُوِيَ', #1
u'الحلما': u'الْحُلُمَا', #1
u'الحلنجبين': u'الْحَلَنْجَبِينَ', #1
u'الحلوانى': u'الْحُلَوانِىِّ', #1
u'الحلوانى': u'الْحُلَوَانِىُّ', #1
u'الحلوانى': u'الْحُلْوَانِىَّ', #1
u'الحلوانى': u'الْحُلْوَانِىُّ', #150
u'الحلوانى': u'الْحُلْوَانِىِّ', #28
u'الحلولا': u'الْحُلُولَا', #1
u'الحليس': u'الْحُلَيْسَ', #5
u'الحليس': u'الْحُلَيْسِ', #5
u'الحليس': u'الْحُلَيْسُ', #6
u'الحليمى': u'الْحُلَيْمِىُّ', #1
u'الحليمى': u'الْحَلِيمِىُّ', #4
u'الحماء': u'الْحَمّاءَ', #2
u'الحمادى': u'الْحَمَّادِىُّ', #2
u'الحمادية': u'الْحَمَّادِيَّةِ', #5
u'الحماط': u'الْحَمَاطُ', #1
u'الحماط': u'الْحُمَاطُ', #1
u'الحماطة': u'الْحَمَاطَةُ', #1
u'الحماطة': u'الْحَمَاطَةِ', #3
u'الحمامه': u'الْحَمَامَهْ', #6
u'الحمامى': u'الحَمَّامِىِّ', #1
u'الحمامى': u'الْحَمَامِىِّ', #1
u'الحمامى': u'الْحُمَّامِىِّ', #1
u'الحمامى': u'الْحَمَّامِىُّ', #3
u'الحمامى': u'الْحَمَّامِىِّ', #34
u'الحمانى': u'الْحِمَّانِىَّ', #1
u'الحمانى': u'الْحِمَّانِىُّ', #22
u'الحمانى': u'الْحِمَّانِىِّ', #3
u'الحمائليين': u'الْحَمَائِلِيِّينَ', #1
u'الحمايل': u'الْحَمَايِلُ', #1
u'الحمديسية': u'الحمديسية', #1
u'الحمديسية': u'الْحَمْدِيسِيَّةِ', #3
u'الحمدين': u'الْحَمْدَيْنِ', #5
u'الحمدين': u'الْحَمَدَيْنِ', #7
u'الحمرا': u'الْحَمْرَا', #1
u'الحمران': u'الْحُمْرَانَ', #1
u'الحمران': u'الْحُمْرَانُ', #4
u'الحمران': u'الْحُمْرَانِ', #4
u'الحمراني': u'الْحُمْرَانِيِّ', #1
u'الحمرانى': u'الْحُمْرَانِىِّ', #1
u'الحمرانى': u'الْحُمْرَانِىُّ', #3
u'الحمراني': u'الْحُمْرَانِيُّ', #4
u'الحمراوى': u'الْحَمْرَاوِىُّ', #1
u'الحمره': u'الْحُمْرَهْ', #1
u'الحمزة': u'الْحَمْزَةَ', #1
u'الحمزي': u'الْحَمْزِيّ', #1
u'الحمزية': u'الْحَمْزِيَّةُ', #2
u'الحمساء،': u'الْحَمْسَاءِ،', #1
u'الحمساء': u'الْحَمْسَاءِ', #7
u'الحمش': u'الْحَمْشُ', #2
u'الحمش': u'الْحَمْشِ', #3
u'الحمصانيين': u'الْحِمْصَانِيِّينَ', #1
u'الحمصى': u'الْحِمْصِىَّ', #2
u'الحمصى': u'الْحِمْصِىِّ', #3
u'الحمصى': u'الْحِمْصِىُّ', #49
u'الحمصيون': u'الحمصيون', #1
u'الحمصيون،': u'الْحِمْصِيُّونَ،', #1
u'الحمقا': u'الْحُمُقَا', #1
u'الحملا': u'الْحَمْلَا', #2
u'الحملاء': u'الْحُمَلَاءُ', #15
u'الحملاء': u'الْحُمَلَاءِ', #27
u'الحملاء': u'الْحُمَلَاءَ', #4
u'الحموسة': u'الْحُمُوسَةِ', #1
u'الحموقة': u'الْحُمُوقَةَ', #1
u'الحموقة': u'الْحَمُوقَةَ', #2
u'الحمئة': u'الحمئة', #1
u'الحمئة': u'الْحَمِئَةِ', #7
u'الحميت': u'الْحَمِيت', #1
u'الحميت': u'الْحَمِيتُ', #2
u'الحميت': u'الْحَمِيتَ', #3
u'الحميدي': u'الْحَمِيدِيّ', #1
u'الحميدي': u'الْحَمِيدِيُّ', #1
u'الحميدي،': u'الْحَمِيدِيِّ،', #1
u'الحميدي،': u'الْحُمَيْدِيَّ،', #1
u'الحميدى': u'الْحُمَيْدِى', #1
u'الحميدي': u'الحميدي', #2
u'الحميدى': u'الْحُمَيْدِىَّ', #2
u'الحميدي،': u'الْحُمَيْدِيِّ،', #22
u'الحميدي،': u'الْحُمَيْدِيُّ،', #235
u'الحميدى': u'الْحُمَيْدِىُّ', #252
u'الحميدي': u'الْحُمَيْدِيَّ', #3
u'الحميدي': u'الْحُمَيْدِيِّ', #31
u'الحميدى': u'الْحُمَيْدِىِّ', #45
u'الحميدي': u'الْحُمَيْدِيّ', #7
u'الحميدي،': u'الحميدي،', #8
u'الحميدي': u'الْحُمَيْدِيُّ', #96
u'الحميدية': u'الْحَمِيدِيَّة', #1
u'الحميدية': u'الْحُمَيْدِيَّةِ', #2
u'الحميدية': u'الْحَمِيدِيَّةِ', #5
u'الحميرات': u'الْحَمِيرَاتُ', #1
u'الحميرقال': u'الْحَمِيرِقَالَ', #1
u'الحميري': u'الحمْيَرِيّ', #1
u'الحميري،': u'الحِميرِيّ،', #1
u'الحميري،': u'الحِمْيرِيّ،', #1
u'الحميري': u'الحِمْيَري', #1
u'الحميري،': u'الحِمْيَري،', #1
u'الحميري،': u'الحِمْيَرِيّ،', #1
u'الحميري': u'الْحِمْيَريُّ', #1
u'الحميري': u'الْحُمَيْرِيُّ', #1
u'الحميرى': u'الْحِمْيَرِىَّ', #1
u'الحميري،': u'الْحِمْيَرِيِّ،', #13
u'الحميري،': u'الحميري،', #2
u'الحميري': u'الحِمْيَريّ', #2
u'الحميرى': u'الْحِمْيَرِىِّ', #20
u'الحميري': u'الْحِمْيَرِيّ', #28
u'الحميري': u'الْحِمْيَرِيُّ', #29
u'الحميري': u'الحميري', #3
u'الحميري': u'الْحِمْيَرِيَّ', #3
u'الحميري': u'الْحِمْيَرِيِّ', #30
u'الحميري،': u'الْحِمْيَرِيُّ،', #6
u'الحميرى': u'الْحِمْيَرِىُّ', #6
u'الحميرية': u'الْحِمْيَرِيّةُ', #1
u'الحميرية': u'الْحِمْيَرِيَّةَ', #1
u'الحميرية': u'الْحِمْيَرِيَّةُ', #1
u'الحميسي': u'الْحُمَيْسِيُّ', #1
u'الحميسى': u'الْحُمَيْسِىُّ', #1
u'الحميصي،': u'الحميصيّ،', #1
u'الحناتم،': u'الْحَنَاتِمَ،', #1
u'الحناتم': u'الحناتم', #2
u'الحناتم': u'الْحَنَاتِمِ', #3
u'الحناتم': u'الْحَنَاتِمَ', #4
u'الحنادس': u'الْحَنَادِسَ', #1
u'الحناكية': u'الْحِنَاكِيَّةِ', #7
u'الحناويين': u'الْحِنَّاوِيِّينَ', #1
u'الحنائى': u'الْحَنَّائِىُّ', #1
u'الحنائى': u'الْحِنَائِىُّ', #1
u'الحنائى': u'الْحِنَّائِىِّ', #1
u'الحنائى': u'الْحِنَّائِىُّ', #10
u'الحنتم': u'الْحَنَتَم', #1
u'الحنتم،': u'الْحَنْتَمَ،', #1
u'الحنتم،': u'الْحَنْتَمُ،', #1
u'الحنتم': u'الْحَنْتَمُ', #17
u'الحنتم': u'الحنتم', #19
u'الحنتم؟': u'الْحَنْتَمُ؟', #2
u'الحنتم': u'الْحَنْتَمِ', #32
u'الحنتم،': u'الْحَنْتَمِ،', #4
u'الحنتم': u'الْحَنْتَمَ', #5
u'الحنتمة؟': u'الْحَنْتَمَةُ؟', #1
u'الحنتمة': u'الْحَنْتَمَةِ', #12
u'الحنتمة': u'الحنتمة', #2
u'الحنتمة،': u'الْحَنْتَمَةِ،', #3
u'الحنتمة': u'الْحَنْتَمَةُ', #4
u'الحندريس': u'الْحَنْدَرِيسِ', #1
u'الحندس': u'الْحِنْدِسِ', #1
u'الحندقوق': u'الحندقوق', #1
u'الحنذ': u'الْحَنْذِ', #1
u'الحنظلقوله': u'الْحَنْظَلِقَوْلُهُ', #1
u'الحنظلى': u'الْحَنْظَلِىَّ', #14
u'الحنظلى': u'الْحَنْظَلِىُّ', #142
u'الحنظلى': u'الْحَنْظَلِىِّ', #17
u'الحنفيون': u'الْحَنَفِيُّونَ', #2
u'الحنيذ': u'الْحَنِيذَ', #1
u'الحنيذ': u'الْحَنِيذِ', #1
u'الحنيذ': u'الْحَنِيذُ', #2
u'الحنينى': u'الْحُنَيْنِىُّ', #5
u'الحوءب': u'الْحَوْءَبِ', #1
u'الحوءب،': u'الْحَوْءَبُ،', #1
u'الحوءب،': u'الْحَوْءَبِ،', #1
u'الحواء': u'الْحَوَّاءُ', #1
u'الحواء': u'الْحِوَاءَ', #1
u'الحواء': u'الْحِوَاءُ', #1
u'الحواء': u'الْحِوَاءِ', #1
u'الحواء': u'الْحِوَاء', #3
u'الحواب': u'الْحَوَابُّ', #1
u'الحوأب': u'الْحَوْأَبِ', #10
u'الحوأب': u'الْحَوْأَبُ', #3
u'الحوابي': u'الْحَوَابِي', #2
u'الحواجيب': u'الْحَوَاجِيبِ', #2
u'الحوادي،': u'الْحَوَادِيِّ،', #1
u'الحوارك': u'الْحَوَارِكِ', #3
u'الحوارى،': u'الحوارى،', #1
u'الحوارى': u'الْحَوَارِى', #2
u'الحوارى': u'الْحَوَارِىِّ', #5
u'الحوارى': u'الْحُوَّارَى', #5
u'الحواريونيا': u'الْحَوَارِيُّونَيَا', #1
u'الحوازة': u'الْحَوَازَةِ', #1
u'الحواشى': u'الْحَوَاشِى', #2
u'الحوافد': u'الْحَوَافِدُ', #1
u'الحوافد': u'الْحَوَافِدِ', #2
u'الحواكون': u'الْحَوَّاكُونَ', #1
u'الحوالك': u'الْحَوَالِكِ', #1
u'الحواله': u'الْحَوَالَهْ', #7
u'الحواميم': u'الْحَوَامِيمُ', #1
u'الحواميم': u'الْحَوَامِيمِ', #3
u'الحوائد': u'الْحَوَائِدُ', #1
u'الحوائم': u'الْحَوَائِمِ', #1
u'الحوايا': u'الْحَوَايَا', #28
u'الحوب': u'الْحُوبُ', #2
u'الحوبة': u'الْحَوْبَةَ', #1
u'الحوبي': u'الْحُوبِيُّ', #1
u'الحوبي': u'الْحُوبِيِّ', #3
u'الحوتكية': u'الْحَوْتَكِيَّةُ', #1
u'الحوتكية،': u'الْحَوْتَكِيَّةُ،', #3
u'الحوتكية': u'الْحَوْتَكِيَّةِ', #7
u'الحوجم': u'الْحَوْجَمُ', #1
u'الحوجم': u'الْحَوْجَمِ', #1
u'الحوذان': u'الْحَوْذَانِ', #2
u'الحوراني': u'الْحَوْرَانِيِّ', #2
u'الحوساء': u'الْحَوْسَاءِ', #2
u'الحوص': u'الْحَوَصُ', #2
u'الحوص،': u'الْحَوْصِ،', #3
u'الحوضى': u'الْحَوْضِىَّ', #1
u'الحوضى': u'الْحَوْضِى', #2
u'الحوضى': u'الْحَوْضِىُّ', #33
u'الحوضى': u'الْحَوْضِىِّ', #4
u'الحولا': u'الْحَوْلَا', #1
u'الحولة': u'الْحُولَةِ', #1
u'الحولة': u'الْحُوَلَةِ', #1
u'الحويرث،': u'الحُوَيْرِث،', #1
u'الحويرث': u'الْحُوَيْرِثَ', #1
u'الحويرث': u'الْحُوَيْرِثُ', #12
u'الحويرث': u'الْحُوَيْرِثِ', #198
u'الحويرث': u'الحويرث', #2
u'الحويرث': u'الحُوَيْرث', #2
u'الحويرث،': u'الْحُوَيْرِثِ،', #34
u'الحويرث': u'الْحُوَيْرِث', #6
u'الحويصرة': u'الْحُوَيْصِرَةِ', #1
u'الحويطات': u'الْحُوَيْطَاتِ', #2
u'الحويل': u'الْحَوِيلِ', #10
u'الحويل': u'الْحَوِيلَ', #3
u'الحويل': u'الْحَوِيلُ', #4
u'الحى': u'الحى', #1
u'الحى': u'الْحَىَّ', #11
u'الحى': u'الْحَىُّ', #13
u'الحى': u'الْحَىِّ', #48
u'الحياز': u'الْحِيَازِ', #1
u'الحياطة': u'الْحِيَاطَةِ', #2
u'الحيالى': u'الْحَيَالَى', #32
u'الحيداء': u'الْحَيْدَاءُ', #1
u'الحيدث': u'الحيدث', #1
u'الحيدرة': u'الحيدرة', #1
u'الحيدرة': u'الْحَيْدَرَةَ', #1
u'الحيدرة': u'الْحَيْدَرَةُ', #1
u'الحيس': u'الْحَيْسَ', #10
u'الحيس': u'الْحَيْسُ', #10
u'الحيس': u'الحيس', #6
u'الحيس': u'الْحَيْسِ', #8
u'الحيسر': u'الْحَيْسَرِ', #11
u'الحيسمان': u'الْحَيْسُمَانَ', #1
u'الحيسمان': u'الْحَيْسُمَانِ', #1
u'الحيسمان': u'الْحَيْسُمَانُ', #3
u'الحيسوب': u'الحيسوب', #1
u'الحيسوب': u'الْحَيْسُوبُ', #1
u'الحيشاني،': u'الْحَيْشَانِيُّ،', #1
u'الحيصتين': u'الْحَيْصَتَيْنِ', #1
u'الحيضان': u'الْحِيضَانِ', #1
u'الحيضلا': u'الْحَيْضَلَا', #1
u'الحيضين': u'الْحَيْضَيْنِ', #1
u'الحيط': u'الْحَيْطُ', #1
u'الحيفا': u'الْحَيْفَا', #1
u'الحيفاء': u'الحَيْفَاءِ', #2
u'الحيفاء': u'الْحَيْفَاءُ', #2
u'الحيفاء': u'الْحَيْفَاءِ', #3
u'الحيوة': u'الْحَيَوةُ', #1
u'الخاتمية': u'الْخَاتِمِيَّةِ', #1
u'الخاتون': u'الْخَاتُونَ', #2
u'الخاتون': u'الْخَاتُونِ', #4
u'الخاتيام': u'الْخَاتِيَامُ', #1
u'الخاذف،': u'الخاذف،', #1
u'الخارب': u'الْخَارِبُ', #3
u'الخاربة': u'الْخَارِبَةَ', #2
u'الخاربة': u'الْخَارِبَةِ', #2
u'الخارص': u'الْخَارِصَ', #19
u'الخارص': u'الْخَارِصُ', #43
u'الخارص': u'الْخَارِصِ', #80
u'الخارصة': u'الْخَارِصَةِ', #2
u'الخارصة': u'الْخَارِصَةَ', #3
u'الخارصة': u'الْخَارِصَةُ', #8
u'الخارصون': u'الْخَارِصُونَ', #1
u'الخارف': u'الْخَارِفِ', #1
u'الخارفي': u'الْخَارِفِيُّ', #1
u'الخارفي،': u'الْخَارِفِيِّ،', #2
u'الخارفي': u'الْخَارِفِيّ', #3
u'الخارفي': u'الْخَارِفِيِّ', #3
u'الخارم': u'الْخَارِمَ', #1
u'الخارم': u'الْخَارِمِ', #1
u'الخارم': u'الْخَارِمُ', #2
u'الخازباز': u'الْخَازَبَازِ', #2
u'الخازباز': u'الْخَازِبَازِ', #2
u'الخازق': u'الْخَازِقَ', #2
u'الخاسق': u'الْخَاسِقَ', #2
u'الخاسق': u'الْخَاسِقِ', #4
u'الخاطيينا': u'الْخَاطِيِينَا', #2
u'الخافور': u'الْخَافُورُ', #1
u'الخاقان': u'الْخَاقَانَ', #1
u'الخاقان': u'الْخَاقَانُ', #1
u'الخاقان': u'الْخَاقَانِ', #7
u'الخاقاني': u'الْخَاقَانَيَّ', #1
u'الخاقاني': u'الْخَاقَانِيِّ', #12
u'الخاقاني': u'الْخَاقَانِيُّ', #4
u'الخاقانية': u'الْخَاقَانِيَّةِ', #1
u'الخاقانية': u'الخاقانية', #2
u'الخالقية': u'الْخَالِقِيَّةِ', #1
u'الخالى': u'الخالى', #1
u'الخامسه': u'الخامسه', #1
u'الخامشات': u'الْخَامِشَاتُ', #1
u'الخامشة': u'الْخَامِشَة', #2
u'الخامشة': u'الْخَامِشَةَ', #2
u'الخامعة': u'الْخَامِعَةِ', #1
u'الخانقاه': u'الْخَانَقَاهَ', #1
u'الخانقاه': u'الْخَانِقَاهُ', #1
u'الخانقاه': u'الْخَانْقَاهْ', #10
u'الخانكا': u'الْخَانْكَا', #1
u'الخانكات': u'الْخَانَكَاتِ', #1
u'الخانكاه': u'الْخَانِكَاهْ', #1
u'الخانكاه': u'الْخَانْكَاه', #1
u'الخانكة': u'الْخَانْكَةِ', #2
u'الخانين': u'الْخَانَيْنِ', #3
u'الخبأ': u'الْخَبْأَ', #1
u'الخبا': u'الْخَبَا', #1
u'الخباثة': u'الْخَبَاثَةِ', #3
u'الخبائري': u'الخبائري', #1
u'الخبائري': u'الْخَبَائِرِيِّ', #1
u'الخبائري،': u'الْخَبَائِرِيُّ،', #1
u'الخبائرى': u'الْخَبَائِرِىَّ', #1
u'الخبائرى': u'الْخَبَائِرِىُّ', #1
u'الخبائري': u'الْخَبَائِرِيُّ', #6
u'الخبائص': u'الخبائص', #1
u'الخبائص': u'الْخَبَائِصَ', #1
u'الخبايري،': u'الخبايري،', #2
u'الخبة': u'الْخِبَّةِ', #1
u'الخبجبة': u'الْخَبْجَبَةِ', #1
u'الخبخبة': u'الْخَبْخَبَةِ', #1
u'الخبرا': u'الْخَبَرَا', #1
u'الخبزان': u'الْخُبْزَانِ', #7
u'الخبزة': u'الْخَبْزَةِ', #1
u'الخبزة،': u'الْخُبْزَةِ،', #1
u'الخبزة': u'الْخُبْزَةُ', #3
u'الخبزين': u'الخبزين', #1
u'الخبزين': u'الْخُبْزَيْنِ', #13
u'الخبستاني': u'الخبستاني', #1
u'الخبشاني': u'الْخُبْشَانِيُّ', #1
u'الخبن': u'الْخَبْنِ', #1
u'الخبن': u'الْخَبْنُ', #3
u'الخبنة': u'الْخُبْنَة', #1
u'الخبنة': u'الْخُبْنَةُ', #2
u'الخبيت': u'الْخُبَيْتِ', #1
u'الخبيزا': u'الْخُبَّيْزَا', #1
u'الخبيزى': u'الْخُبَّيْزَى', #2
u'الختانان': u'الْخِتَانَانِ', #57
u'الختانين': u'الْخِتَانَيْنِ', #144
u'الختلي،': u'الْخُتَّلِيَّ،', #1
u'الختلي،': u'الْخُتَّلِيِّ،', #1
u'الختلي،': u'الْخُتُّلِيِّ،', #1
u'الختلي،': u'الْخُتُّلِيُّ،', #12
u'الختلى': u'الْخُتَّلِىُّ', #5
u'الختمات': u'الْخِتْمَاتِ', #2
u'الختمات': u'الْخَتْمَاتِ', #3
u'الختمات': u'الْخَتَمَاتِ', #7
u'الختمة': u'الْخَتْمَةِ', #17
u'الختمة': u'الْخِتْمَةُ', #2
u'الختمة': u'الْخِتْمَةَ', #3
u'الختمة': u'الْخَتْمَةُ', #4
u'الختمة': u'الْخِتْمَةِ', #7
u'الختمة': u'الْخَتْمَةَ', #8
u'الختمين': u'الْخَتْمَيْنِ', #1
u'الختونة': u'الْخُتُونَةُ', #1
u'الختونة': u'الْخُتُونَةِ', #1
u'الختى': u'الْخَتِّىُّ', #1
u'الخثعمي،': u'الخثعمي،', #1
u'الخثعمي،': u'الْخَثْعَمِيَّ،', #1
u'الخثعمي': u'الْخَثْعَمِيّ', #10
u'الخثعمي': u'الْخَثْعَمِيِّ', #15
u'الخثعمي': u'الْخَثْعَمِيَّ', #2
u'الخثعمي': u'الخثعمي', #4
u'الخثعمي': u'الْخَثْعَمِيُّ', #4
u'الخثعمي،': u'الْخَثْعَمِيِّ،', #4
u'الخثعمي،': u'الْخَثْعَمِيُّ،', #6
u'الخثعمى': u'الْخَثْعَمِىُّ', #7
u'الخثعمى': u'الْخَثْعَمِىِّ', #7
u'الخثعمية': u'الْخَثْعَمِيّةِ', #1
u'الخثعمية': u'الخثعمية', #2
u'الخثعمية': u'الْخَثْعَمِيّة', #2
u'الخثعمية': u'الْخَثْعَمِيَّةِ', #33
u'الخثعمية': u'الْخَثْعَمِيّةُ', #4
u'الخثعمية': u'الْخَثْعَمِيَّةَ', #4
u'الخثعمية': u'الْخَثْعَمِيَّةُ', #8
u'الخثعميون': u'الْخَثْعَمِيّونَ', #1
u'الخثعميين': u'الْخَثْعَمِيِّينَ', #2
u'الخثى': u'الْخَثَى', #1
u'الخجالة': u'الْخَجَالَةِ', #1
u'الخجلا': u'الْخَجِلَا', #1
u'الخجندي': u'الْخُجَنْدِيُّ', #133
u'الخجندي': u'الْخُجَنْدِيِّ', #97
u'الخجوج،': u'الخجوج،', #1
u'الخجوج': u'الْخَجُوجِ', #1
u'الخجوج،': u'الْخُجُوجِ،', #1
u'الخداج': u'الْخِدَاج', #1
u'الخداج': u'الْخِدَاجُ', #1
u'الخداج': u'الْخِدَاجِ', #1
u'الخداج': u'الخداج', #2
u'الخداج': u'الْخِدَاجَ', #2
u'الخدب': u'الْخَدَبُ', #1
u'الخدرى': u'الْخُدْرِىُّ', #34
u'الخدرى': u'الْخُدْرِىِّ', #408
u'الخدرى': u'الخُدْرِىِّ', #5
u'الخدرى': u'الْخُدْرِىَّ', #91
u'الخدشة': u'الْخَدْشَةَ', #2
u'الخدشة': u'الْخَدْشَةُ', #2
u'الخدلج': u'الْخَدَلَّج', #1
u'الخديرية': u'الْخُدَيْرِيَّةِ', #2
u'الخذاف': u'الْخَذَّافِ', #1
u'الخذف': u'الخَذف', #1
u'الخذف؟': u'الْخَذْفِ؟', #1
u'الخذف': u'الخذف', #2
u'الخذف،': u'الْخَذْفَ،', #2
u'الخذف': u'الْخَذْفِ', #224
u'الخذف': u'الْخَذَفِ', #4
u'الخذف': u'الْخَذْفَ', #4
u'الخذف': u'الْخَذْفُ', #5
u'الخذف،': u'الْخَذْفِ،', #5
u'الخذف': u'الْخَذْف', #8
u'الخذفة': u'الْخَذَفَةَ', #1
u'الخذفة': u'الْخَذْفَةَ', #1
u'الخذفة': u'الْخَذْفَةِ', #1
u'الخذفة،': u'الْخَذَفَةِ،', #1
u'الخرء': u'الْخُرْءَ', #2
u'الخرء': u'الْخَرْءَ', #3
u'الخرء': u'الْخَرْءُ', #3
u'الخرء': u'الْخَرْءِ', #3
u'الخرء': u'الْخُرْءِ', #7
u'الخرء': u'الْخُرْءُ', #8
u'الخراء': u'الْخِرَاءَ', #1
u'الخراء،': u'الْخِرَاءَ،', #1
u'الخراءة': u'الْخَرَاءَةَ', #1
u'الخراءة،': u'الْخِرَاءَةَ،', #1
u'الخراءة': u'الْخِرَاءَةِ', #2
u'الخراءة': u'الْخِرَاءَة', #3
u'الخراءة': u'الْخِرَاءَةَ', #9
u'الخرابز': u'الخرابز', #1
u'الخرأة': u'الْخَرَأَةَ', #1
u'الخرأة': u'الْخَرْأَةَ', #1
u'الخراثاني': u'الْخُرَاثَانِيُّ', #1
u'الخراجات': u'الْخُرَاجَاتِ', #1
u'الخراجات': u'الْخَرَاجَاتِ', #2
u'الخرار': u'الْخَرَّارَ', #1
u'الخرار،': u'الْخَرَّارَ،', #1
u'الخرار،': u'الْخَرَّارِ،', #1
u'الخرار': u'الْخَرَّارُ', #2
u'الخرار': u'الْخَرَّارِ', #2
u'الخرار': u'الْخَرّارِ', #5
u'الخرار': u'الْخَرّارَ', #9
u'الخرارة': u'الخرَّارة', #1
u'الخراريب': u'الْخَرَارِيبُ', #2
u'الخراريب': u'الْخَرَارِيبِ', #2
u'الخراسانى': u'الخَرَاسَانِىُّ', #1
u'الخراسانى': u'الْخَرَاسَانِىُّ', #1
u'الخراسانى': u'الْخَرُاسَانِىِّ', #1
u'الخراسانى': u'الْخُرْاسَانِىِّ', #1
u'الخراسانى': u'الْخُرَاسَانِىُّ', #37
u'الخراسانى': u'الْخُرَاسَانِىِّ', #42
u'الخراسانى': u'الْخُرَاسَانِىَّ', #9
u'الخراسانيأما': u'الْخُرَاسَانِيّأَمَّا', #1
u'الخراسانيوأما': u'الْخُرَاسَانِيّوَأَمَّا', #1
u'الخراسانيوأما': u'الْخُرَاسَانِيِّوَأَمَّا', #1
u'الخراطى': u'الْخُرَاطَى', #1
u'الخرباق': u'الْخِرْبَاق', #1
u'الخرباق': u'الْخِرْبَاقُ', #26
u'الخرباق': u'الْخِرْبَاقِ', #4
u'الخربز': u'الْخِرْبِزُ', #1
u'الخربز': u'الخربز', #2
u'الخربز': u'الْخِرْبِزِ', #2
u'الخرتيت': u'الْخَرْتِيتَ', #1
u'الخرتيت': u'الْخَرْتِيتُ', #1
u'الخرثاني': u'الْخَرْثَانِيُّ', #1
u'الخرفع': u'الْخُرْفُعُ', #1
u'الخرك': u'الْخَرِكِ', #1
u'الخركاوات': u'الخركاوات', #1
u'الخركاوات': u'الْخَرْكَاوَاتِ', #1
u'الخرمات': u'الْخُرُمَاتِ', #1
u'الخرمانية': u'الْخَرْمَانِيَّةِ', #1
u'الخرمة': u'الْخَرْمَةُ', #1
u'الخرنوبة': u'الْخَرْنُوبَةُ', #1
u'الخرنوبة،': u'الْخَرْنُوبَةُ،', #1
u'الخرو': u'الْخَرُو', #1
u'الخروء': u'الْخُرُوءِ', #2
u'الخرياق': u'الْخِرْيَاقُ', #1
u'الخريبة': u'الْخُرَيْبَةِ', #1
u'الخريبي': u'الْخُرَيْبِيّ', #1
u'الخريبي': u'الْخُرَيْبِيَّ', #1
u'الخريبي،': u'الْخُرَيْبِيُّ،', #2
u'الخريبى': u'الْخُرَيْبِىُّ', #2
u'الخريبى': u'الْخُرَيْبِىِّ', #2
u'الخريبي': u'الْخُرَيْبِيُّ', #3
u'الخريت،': u'الخِريت،', #1
u'الخريت': u'الْخِرِّيتُ', #1
u'الخريت،': u'الْخِرِّيتِ،', #13
u'الخريت': u'الْخِرِّيتَ', #2
u'الخريت': u'الْخِرِّيتِ', #27
u'الخريزة': u'الْخُرَيْزَةِ', #9
u'الخريشي': u'الْخُرَيْشِيَّ', #1
u'الخريشي': u'الْخُرَيْشِيُّ', #1
u'الخريشي': u'الْخُرَيْشِيِّ', #2
u'الخريفغني': u'الخريفغني', #1
u'الخريق': u'الْخَرِيقِ', #1
u'الخريمى': u'الْخُرَيْمِىُّ', #1
u'الخزاخزي': u'الْخَزَاخَزِيُّ', #1
u'الخزار': u'الْخَزَّارَ', #1
u'الخزار،': u'الْخَزَّارِ،', #1
u'الخزار': u'الْخَزَّارِ', #2
u'الخزاز،': u'الخزاز،', #1
u'الخزاز': u'الْخَزَّازُّ', #1
u'الخزاز': u'الْخُزَّازُ', #1
u'الخزاز،': u'الْخَزَّازَ،', #1
u'الخزاز': u'الخزاز', #2
u'الخزاز': u'الْخَزَّازَ', #2
u'الخزاز': u'الْخَزَّازِ', #2
u'الخزاز،': u'الْخَزَّازِ،', #4
u'الخزاز،': u'الْخَزَّازُ،', #40
u'الخزاز': u'الْخَزَّازُ', #67
u'الخزازة': u'الْخَزَّازَةِ', #1
u'الخزاعى': u'الْخُزَاعِىِّ', #28
u'الخزاعى': u'الْخُزَاعِىُّ', #72
u'الخزاعى': u'الْخُزَاعِىَّ', #9
u'الخزاعيعلى': u'الْخُزَاعِيَّعَلَى', #1
u'الخزام': u'الْخِزَامُ', #1
u'الخزام': u'الْخِزَامِ', #2
u'الخزايا': u'الْخَزَايَا', #5
u'الخزرة': u'الْخَزْرَةُ', #1
u'الخزرجى': u'الْخَزْرَجِىَّ', #1
u'الخزرجى': u'الْخَزْرَجِىِّ', #1
u'الخزرجين': u'الْخَزْرَجِينَ', #1
u'الخزرجين': u'الْخَزْرَجَيْنِ', #1
u'الخزرنق': u'الْخَزَرْنَقِ', #1
u'الخزز': u'الْخُزَزَ', #1
u'الخزز': u'الْخُزَزُ', #1
u'الخزفة': u'الْخَزَفَةِ', #1
u'الخزم': u'الْخَزَمُ', #1
u'الخزم': u'الْخَزْمِ', #1
u'الخزم': u'الْخَزَمِ', #2
u'الخزم': u'الْخُزُمُ', #2
u'الخزنقلة': u'الْخَزَنْقَلَةِ', #1
u'الخزيمي': u'الْخُزَيْمِيِّ', #1
u'الخساره': u'الْخَسَارَهْ', #1
u'الخسرو': u'الْخُسْرَوْ', #6
u'الخسرواني': u'الْخُسْرَوَانِيَّ', #1
u'الخسرواني': u'الْخُسْرَوَانِيُّ', #1
u'الخسروجردى': u'الْخُسْرُوجَرْدِىُّ', #1
u'الخسروجردى': u'الْخَسْرَوْجِرْدِىُّ', #1
u'الخسروجردى': u'الْخُسْرَوْجِرْدِىُّ', #18
u'الخسروجردى': u'الْخَسْرُوجَرْدِىُّ', #2
u'الخسروجردى': u'الْخُسْرَوْجَرْدِىُّ', #2
u'الخسروجردى': u'الْخَسْرُوجِرْدِىُّ', #4
u'الخسروجردى': u'الْخُسْرَوجِرْدِىُّ', #4
u'الخسق': u'الْخَسْقَ', #3
u'الخسق': u'الْخَسْقُ', #5
u'الخسق': u'الْخَسْقِ', #5
u'الخسير': u'الْخَسِيرُ', #1
u'الخشابي،': u'الْخَشَّابِيُّ،', #1
u'الخشار': u'الْخُشَارُ', #1
u'الخشاف': u'الْخُشَافَ', #1
u'الخشاف': u'الْخُشَافُ', #1
u'الخشاف': u'الْخُشَّافَ', #1
u'الخشاف': u'الْخُشَّافُ', #1
u'الخشاف': u'الْخِشَافُ', #1
u'الخشخاشة': u'الْخَشْخَاشَةِ', #1
u'الخشخاشة': u'الْخَشْخَاشَةَ', #2
u'الخشخاشة': u'الْخَشْخَاشَةُ', #2
u'الخشكار': u'الْخَشْكَارَ', #1
u'الخشكان': u'الْخُشْكَانُ', #1
u'الخشكنابخ': u'الخشكنابخ', #1
u'الخشكنان': u'الْخَشْكُنَانِ', #1
u'الخشكنان': u'الْخُشْكَنَانُ', #1
u'الخشكنان': u'الخشكنان', #3
u'الخشكنان': u'الْخُشْكِنَانُ', #4
u'الخشكنان': u'الْخُشْكِنَانِ', #6
u'الخشكنانج': u'الخشكنانج', #1
u'الخشل': u'الْخَشْلَ', #1
u'الخشل': u'الْخَشْلُ', #1
u'الخشماء': u'الْخَشْمَاءُ', #2
u'الخشمراني': u'الْخَشْمَرَانِيِّ', #2
u'الخشني': u'الخُشنّي', #1
u'الخشني': u'الْخُشَنِيّ', #1
u'الخشني،': u'الْخَشْنِيِّ،', #1
u'الخشنى': u'الْخُشْنِىِّ', #1
u'الخشني،': u'الْخُشَنِيِّ،', #11
u'الخشني': u'الْخُشَنِيَّ', #13
u'الخشني': u'الْخُشَنِيُّ', #19
u'الخشنى': u'الْخُشَنِىُّ', #2
u'الخشنى': u'الْخُشَنِىِّ', #20
u'الخشني،': u'الْخُشَنِيَّ،', #3
u'الخشني': u'الخشني', #4
u'الخشني،': u'الْخُشَنِيُّ،', #5
u'الخشني': u'الْخُشَنِيِّ', #56
u'الخشنى': u'الْخُشَنِىَّ', #6
u'الخشى،': u'الْخَشَى،', #1
u'الخصا': u'الْخُصَا', #1
u'الخصا': u'الْخَصَا', #2
u'الخصا': u'الْخِصَا', #2
u'الخصباء': u'الْخَصْبَاءِ', #1
u'الخصكفي': u'الْخَصْكَفِيِّ', #1
u'الخصومةالوجه': u'الْخُصُومَةِالْوَجْهُ', #1
u'الخصيبي': u'الْخَصِيبِيّ', #2
u'الخصيصى': u'الْخِصِّيصَى', #1
u'الخضابا': u'الْخِضَابَا', #1
u'الخضارمة': u'الْخَضَارِمَةُ', #2
u'الخضخاض': u'الْخَضْخَاضَ', #1
u'الخضخاض': u'الْخِضْخَاضَ', #1
u'الخضخاض': u'الْخِضْخَاضُ', #1
u'الخضخاض': u'الْخَضْخَاضِ', #12
u'الخضخاض': u'الْخَضْخَاضُ', #2
u'الخضخاض': u'الْخِضْخَاضِ', #7
u'الخضخضة': u'الْخَضْخَضَةَ', #1
u'الخضخضة': u'الْخَضْخَضَةِ', #3
u'الخضد': u'الْخَضْد', #1
u'الخضرم': u'الْخَضْرَمِ', #1
u'الخضرم': u'الْخِضْرِمُ', #1
u'الخضرمي': u'الْخَضْرَمِيُّ', #1
u'الخضرمي': u'الْخَضْرَمِيِّ', #1
u'الخضرى': u'الْخُضْرِىِّ', #1
u'الخضمات': u'الْخَضَمَاتُ', #1
u'الخضمات': u'الْخَضِمَاتُ', #1
u'الخضمات،': u'الْخَضَمَاتِ،', #1
u'الخضمات': u'الْخَضَمَاتِ', #2
u'الخضمات': u'الْخَضِمَاتِ', #22
u'الخضمان': u'الْخَضِمَانِ', #1
u'الخضيري،': u'الخضيري،', #1
u'الخضيري': u'الْخُضَيْرِيِّ', #1
u'الخضيم': u'الْخَضِيمِ', #1
u'الخطا': u'الْخَطَا', #1
u'الخطا': u'الْخُطَّا', #1
u'الخطا': u'الْخَطَّا', #2
u'الخطا': u'الخطا', #4
u'الخطا': u'الْخُطَا', #55
u'الخطاءون': u'الْخَطَّاءُونَ', #1
u'الخطابالطاغوت': u'الْخَطَّابِالطَّاغُوتُ', #1
u'الخطابالمتقدم': u'الْخَطَّابِالْمُتَقَدِّمُ', #1
u'الخطابرضي': u'الْخَطَّابِرَضِيَ', #1
u'الخطابفوالذي': u'الْخَطَّابِفَوَاَلَّذِي', #1
u'الخطابنافعا': u'الْخَطَّابِنَافِعًا', #1
u'الخطابى': u'الْخَطَابِىُّ', #1
u'الخطابى': u'الْخِطَّابِىُّ', #1
u'الخطابى': u'الْخَطَّابِىُّ', #19
u'الخطابى': u'الْخَطَابِىِّ', #2
u'الخطابى': u'الْخَطَّابِىِّ', #3
u'الخطائين،': u'الْخَطَّائِينَ،', #1
u'الخطائين': u'الْخَطَّائِينَ', #20
u'الخطبى': u'الْخُطَبِىُّ', #10
u'الخطفى': u'الْخَطَفَى', #5
u'الخطمى': u'الْخِطْمِىِّ', #1
u'الخطمى': u'الْخَطْمِىُّ', #12
u'الخطمى': u'الْخَطْمِىَّ', #7
u'الخطمى': u'الْخَطْمِىِّ', #8
u'الخطميأخبره،': u'الْخَطْمِيَّأَخْبَرَهُ،', #1
u'الخطوبا': u'الْخُطُوبَا', #1
u'الخطيطة': u'الْخَطِيطَةِ', #2
u'الخطيم': u'الخطيم', #1
u'الخطيم': u'الخَطِيم', #1
u'الخطيم': u'الْخَطِيمَ', #1
u'الخطيم': u'الْخَطِيمُ', #1
u'الخطيم': u'الْخَطِيمِ', #11
u'الخطيم،': u'الْخَطِيمِ،', #2
u'الخظر': u'الْخَظْرِ', #1
u'الخفاجي': u'الخفاجي', #1
u'الخفاجي': u'الْخَفَاجِيُّ', #10
u'الخفاجي': u'الْخَفَاجِيِّ', #6
u'الخفتانات': u'الخفتانات', #2
u'الخفرات': u'الْخَفِرَاتِ', #1
u'الخفرة': u'الْخَفِرَةِ', #1
u'الخفرة': u'الْخَفْرَةُ', #1
u'الخفرة': u'الْخَفْرَةِ', #2
u'الخفضين': u'الْخَفْضَيْنِ', #1
u'الخفيدد': u'الخَفَيْدَدِ', #1
u'الخفيرة': u'الْخَفِيرَةِ', #1
u'الخلا': u'الْخَلَا', #28
u'الخلات': u'الْخَلَّاتِ', #4
u'الخلافةوالوجه': u'الْخِلافَةُوَالْوَجْهُ', #1
u'الخلافيون': u'الْخِلَافِيُّونَ', #3
u'الخلالى': u'الْخِلاَلِىُّ', #1
u'الخلالى': u'الْخَلاَّلِىُّ', #13
u'الخلاوي': u'الْخَلَاوِي', #3
u'الخلاوى': u'الْخَلَاوَى', #3
u'الخلبة': u'الْخُلْبَةُ', #1
u'الخلبة': u'الخلبة', #3
u'الخلجي،': u'الْخَلْجِيِّ،', #1
u'الخلجى': u'الْخُلْجِىِّ', #1
u'الخلدى': u'الْخَلَدِىُّ', #1
u'الخلدى': u'الْخَلْدِىُّ', #1
u'الخلدى': u'الْخُلْدِىُّ', #12
u'الخلر': u'الْخُلَّرُ', #1
u'الخلعين': u'الْخُلْعَيْنِ', #2
u'الخلفاني،': u'الْخَلْفانِيِّ،', #1
u'الخلقات': u'الْخَلِقَاتُ', #1
u'الخلقاني': u'الخلقاني', #1
u'الخلقاني': u'الْخَلْقَانِيُّ', #1
u'الخلقاني،': u'الْخَلْقَانِيُّ،', #1
u'الخلقاني،': u'الْخُلْقَانِيِّ،', #1
u'الخلقاني،': u'الْخُلْقَانِيُّ،', #3
u'الخللا': u'الْخَلَلَا', #1
u'الخلوتي': u'الْخَلْوَتِيُّ', #13
u'الخلوتي': u'الْخَلْوَتِيِّ', #2
u'الخلوتية': u'الْخَلْوَتِيَّةِ', #10
u'الخلوج': u'الْخَلُوجِ', #1
u'الخلوقة': u'الْخُلُوقَةُ', #1
u'الخلوقي': u'الخلوقي', #1
u'الخلول': u'الْخُلُولُ', #11
u'الخلول': u'الْخُلُولِ', #24
u'الخلول': u'الْخُلُولَ', #5
u'الخلى': u'الْخَلَى', #1
u'الخلى': u'الخلى', #2
u'الخليصة': u'الْخُلَيْصَةِ', #1
u'الخليطان': u'الْخَلِيطَانِ', #39
u'الخليطي': u'الْخَلِيطَيْ', #1
u'الخليطين': u'الْخَلِيطَيْنِ', #143
u'الخليطين': u'الْخَلِيطِينَ', #7
u'الخليفا': u'الْخِلِّيفَا', #4
u'الخليفتي': u'الْخَلِيفَتِيَّ', #1
u'الخليفتي': u'الْخَلِيفَتِيُّ', #3
u'الخليفى': u'الْخِلِّيفَى', #11
u'الخليلا': u'الْخَلِيلَا', #2
u'الخليلنجي': u'الْخَلِيلَنْجِيُّ', #1
u'الخليلنجي': u'الْخَلِيلَنْجِيِّ', #1
u'الخليلي': u'الْخَلِيلِيّ', #1
u'الخليلي': u'الْخَلِيلِيَّ', #1
u'الخليلى': u'الْخَلِيلِىُّ', #1
u'الخليلي': u'الْخَلِيلِيِّ', #10
u'الخليلي': u'الْخَلِيلِيُّ', #9
u'الخماس': u'الْخُمَاسُ', #1
u'الخماس': u'الْخُمَاسِ', #17
u'الخماسين': u'الْخَمَاسِينِ', #2
u'الخماص': u'الْخِمَاص', #1
u'الخمرالرحيق': u'الْخَمْرِالرّحِيقُ', #1
u'الخمسات': u'الْخَمْسَاتِ', #1
u'الخمساوية': u'الخمساوية', #1
u'الخمساوية': u'الْخَمْسَاوِيَّةِ', #1
u'الخمستان': u'الْخَمْسَتَانِ', #1
u'الخمستين': u'الْخَمْسَتَيْنِ', #3
u'الخمسمائتين': u'الخمسمائتين', #1
u'الخمسمائتين': u'الخَمْسِمِائَتَيْن', #1
u'الخمسه': u'الْخَمْسَهْ', #1
u'الخمسوروي': u'الْخَمْسُوَرُوِيَ', #1
u'الخمسينان': u'الْخَمْسِينَانِ', #1
u'الخمط': u'الْخَمْطُ', #4
u'الخميسي': u'الْخَمِيسِيِّ', #1
u'الخميصة': u'الخَميصة', #1
u'الخميصة': u'الْخَمِيصَةَ', #13
u'الخميصة': u'الْخَمِيصَةِ', #22
u'الخميصة': u'الْخَمِيصَة', #3
u'الخميصة': u'الْخَمِيصَةُ', #3
u'الخميصة': u'الخميصة', #6
u'الخناب': u'الْخِنّابُ', #2
u'الخناث': u'الْخِنَاثُ', #1
u'الخناثي': u'الْخَنَاثِي', #5
u'الخنادم': u'الْخَنَادِمُ', #1
u'الخنادم': u'الْخَنَادِمِ', #4
u'الخناقين': u'الْخَنَّاقِينَ', #1
u'الخنائم': u'الْخَنَائِمُ', #1
u'الخنبق': u'الْخُنْبُقِ', #1
u'الخنبق': u'الخنبق', #2
u'الخنبقات': u'الخنبقات', #2
u'الخنجي': u'الْخَنْجِيُّ', #3
u'الخندقفقلت': u'الْخَنْدَقَفَقُلْت', #1
u'الخندقوقريظة': u'الْخَنْدَقِوَقُرَيْظَةَ', #1
u'الخندمة،': u'الخَنْدَمَة،', #1
u'الخندمة': u'الْخَنْدَمَة', #1
u'الخندمة،': u'الْخَنْدَمَةِ،', #1
u'الخندمة': u'الْخَنْدَمَةُ', #2
u'الخندمة': u'الْخَنْدَمَةِ', #5
u'الخندمة': u'الْخَنْدَمَةَ', #6
u'الخندمه': u'الْخَنْدَمَهْ', #2
u'الخنذمي،': u'الخنذمي،', #1
u'الخنكارية': u'الْخَنْكَارِيَّةِ', #1
u'الخنكارية': u'الْخَنْكَارِيِّةِ', #1
u'الخنوة': u'الْخَنْوَةُ', #1
u'الخنيث': u'الْخِنِّيثَ', #1
u'الخوابى': u'الْخَوَابِى', #2
u'الخواتيمي': u'الْخَوَاتِيمِيِّ', #1
u'الخواتيمي': u'الْخَوَاتِيمِيُّ', #2
u'الخواجا': u'الْخَوَاجَا', #2
u'الخوارزمى': u'الْخَوَارَزْمِىُّ', #1
u'الخوارزمى': u'الْخَوَارِزِمِىُّ', #1
u'الخوارزمى': u'الْخَوَارِزِمِّىُّ', #1
u'الخوارزمى': u'الْخَوَارِزْمِىِّ', #1
u'الخوارزمى': u'الْخَوَارِزْمِىُّ', #27
u'الخوارزمى': u'الْخُوَارِزْمِىُّ', #4
u'الخوازق': u'الْخَوَازِقُ', #2
u'الخوازم': u'الْخَوَازِمُ', #1
u'الخوازي،': u'الْخَوَازِيِّ،', #1
u'الخواسق': u'الْخَوَاسِقَ', #2
u'الخواشني': u'الْخَوَاشِنِيُّ', #1
u'الخواشيم': u'الْخَوَاشِيمِ', #1
u'الخوال': u'الْخُوَّالِ', #1
u'الخوانق': u'الْخَوَانِقَ', #1
u'الخوانق': u'الْخَوَانِقُ', #2
u'الخوانق': u'الْخَوَانِقِ', #3
u'الخوانك': u'الْخَوَانِكُ', #1
u'الخوانك': u'الْخَوَانِكِ', #1
u'الخوانيق': u'الْخَوَانِيقِ', #3
u'الخوبي': u'الْخُوبِيُّ', #1
u'الخوبي': u'الْخُوبِيِّ', #1
u'الخوتع': u'الْخَوْتَعُ', #2
u'الخوداء': u'الْخَوْدَاءُ', #1
u'الخورنق': u'الْخَوَرْنَق', #1
u'الخورنق': u'الْخَوَرْنَقِ', #19
u'الخورنق': u'الْخَوَرْنَقَ', #3
u'الخورنق': u'الْخَوَرْنَقُ', #6
u'الخوز': u'الْخُوزِ', #1
u'الخوز': u'الْخَوْزِ', #1
u'الخوزلى': u'الْخَوْزَلَى', #1
u'الخوزي،': u'الْخُوزِيَّ،', #1
u'الخوزي': u'الْخُوزِيَّ', #2
u'الخوزى': u'الْخُوزِىُّ', #3
u'الخوزي': u'الْخُوزِيُّ', #5
u'الخوزي': u'الْخُوزِيِّ', #5
u'الخوزى': u'الْخُوزِىِّ', #6
u'الخوشخوان': u'الخوشخوان', #1
u'الخوصة': u'الْخُوصَةُ', #1
u'الخوصتان': u'الْخُوصَتَانِ', #1
u'الخوطين': u'الْخُوْطَيْنِ', #3
u'الخوع': u'الْخَوْعُ', #2
u'الخوفين': u'الخوفين', #1
u'الخوفين': u'الْخَوْفَيْنِ', #4
u'الخولان': u'الْخُولَانِ', #1
u'الخولاني،': u'الخُولانِيّ،', #1
u'الخولاني': u'الْخَوْلانِيّ', #1
u'الخولاني؟': u'الْخَوْلانِيَّ؟', #1
u'الخولاني': u'الْخَوْلَانيِّ', #1
u'الخولاني،': u'الْخَوْلَانِيَّ،', #1
u'الخولاني': u'الْخَوْلانِيَّ', #10
u'الخولاني': u'الخولاني', #11
u'الخولاني': u'الْخَوْلانِيِّ', #12
u'الخولانى': u'الْخَوْلاَنِىَّ', #13
u'الخولاني': u'الْخَوْلانِيُّ', #19
u'الخولاني،': u'الخولاني،', #2
u'الخولاني،': u'الخوْلاني،', #2
u'الخولاني،': u'الْخَوْلانِيَّ،', #2
u'الخولاني': u'الْخَوْلَانِيّ', #2
u'الخولاني،': u'الْخَوْلَانِيِّ،', #2
u'الخولاني': u'الخَوْلاني', #3
u'الخولاني': u'الخَوْلانيّ', #3
u'الخولاني،': u'الْخَوْلانِيِّ،', #32
u'الخولاني،': u'الْخَوْلَانِيُّ،', #4
u'الخولاني': u'الْخَوْلَانِيُّ', #50
u'الخولانى': u'الْخَوْلاَنِىِّ', #55
u'الخولانى': u'الْخَوْلاَنِىُّ', #58
u'الخولاني،': u'الخَوْلاني،', #6
u'الخولاني،': u'الخَوْلانيّ،', #6
u'الخولاني': u'الْخَوْلَانِيَّ', #6
u'الخولاني': u'الْخَوْلَانِيِّ', #69
u'الخولاني،': u'الْخَوْلانِيُّ،', #72
u'الخولاني،أنه': u'الْخَوْلانِيُّ،أَنَّهُ', #1
u'الخونجي': u'الْخُونَجِيُّ', #1
u'الخونجي': u'الْخُونَجِيِّ', #5
u'الخويصة': u'الْخُوَيِّصَة', #1
u'الخويصرة،': u'الْخُوَيْصِرَةِ،', #2
u'الخويصرة': u'الْخُوَيْصِرَةِ', #31
u'الخويي': u'الْخُويِيُّ', #1
u'الخويي': u'الْخُويِيِّ', #1
u'الخئولة': u'الْخَئُولَةُ', #1
u'الخئولة': u'الْخُئُولَةُ', #1
u'الخئولة': u'الْخُئُولَةِ', #1
u'الخئوله': u'الخئوله', #2
u'الخيا': u'الْخِيَا', #1
u'الخياب': u'الْخُيَّابِ', #1
u'الخياب': u'الْخُيّابِ', #2
u'الخيابرة': u'الْخَيَابِرَةُ', #1
u'الخياراااا': u'الْخِيَارِاااا', #1
u'الخيانه': u'الْخِيَانَهْ', #2
u'الخيبر': u'الْخَيْبَرِ', #1
u'الخيبري': u'الخَيْبَرِيِّ', #1
u'الخيبري': u'الْخَيْبَرِيُّ', #1
u'الخيبري': u'الخيبري', #2
u'الخيبري': u'الْخَيْبَرِيِّ', #3
u'الخيبري،': u'الْخَيْبَرِيِّ،', #4
u'الخيبرية': u'الْخَيْبَرِيّةُ', #1
u'الخيبرية': u'الْخَيْبَرِيَّةِ', #1
u'الخيبرية،': u'الْخَيْبَرِيَّةُ،', #1
u'الخيراخري': u'الْخَيْرَاخَرِيَّ', #1
u'الخيراخري': u'الْخَيْرَاخَرِيُّ', #1
u'الخيراني،': u'الخيراني،', #1
u'الخيرواني': u'الْخَيْرَوَانِيِّ', #2
u'الخيزاخزي': u'الْخَيْزَاخَزِيِّ', #1
u'الخيزاخزي': u'الْخَيْزَاخَزِيُّ', #6
u'الخيزاخيزي': u'الْخَيْزَاخِيزِيُّ', #3
u'الخيزوني': u'الْخَيْزُونِيِّ', #1
u'الخيشة': u'الْخَيْشَةُ', #1
u'الخيشة': u'الْخَيْشَةِ', #4
u'الخيضري': u'الْخَيْضَرِيِّ', #2
u'الخيضعه': u'الْخَيْضَعَهْ', #1
u'الخيفانة': u'الْخَيْفَانَةُ', #1
u'الخيلتاشي': u'الخيلتاشي', #1
u'الخيو': u'الخيو', #1
u'الخيو': u'الْخُيُو', #4
u'الخيواني،': u'الْخَيْوَانِيُّ،', #1
u'الخيواني': u'الْخَيْوَانِيُّ', #2
u'الخيوانى': u'الْخَيْوَانِىِّ', #2
u'الخيواني،': u'الْخَيْوَانِيِّ،', #4
u'الخيور': u'الْخُيُورَ', #1
u'الخيور': u'الْخُيُورِ', #2
u'الد': u'الد', #1
u'الد': u'الدُّ', #1
u'الدءوب': u'الدَّءُوبَ', #1
u'الدابس': u'الدَّابِسُ', #1
u'الدابوغة': u'الدَّابُوغَةِ', #3
u'الدابولي': u'الدَّابُولِيَّ', #1
u'الداتورة': u'الدَّاتُورَةَ', #2
u'الداخر،': u'الدَّاخِرُ،', #1
u'الداذي': u'الدَّاذِيِّ', #2
u'الدارا': u'الدَّارَا', #1
u'الدارابجردي،': u'الدَّارَابْجِرْدِيُّ،', #1
u'الدارابجردى': u'الدَّارَابَجَرْدِىُّ', #1
u'الدارابجردى': u'الدَّارَابَجِرْدِىُّ', #1
u'الدارابجردى': u'الدَّارَابُجَرْدِىُّ', #1
u'الدارابجردى': u'الدَّارَابِجَرْدِىُّ', #1
u'الدارابردي،': u'الدَّارَابِرْدِيُّ،', #1
u'الداراني،': u'الدَّارَانِيَّ،', #1
u'الداراني،': u'الدَّارَانِيِّ،', #1
u'الداراني': u'الدَّارَانِيُّ', #12
u'الداراني': u'الدَّارَانِيِّ', #13
u'الداراني': u'الدَّارَانِيَّ', #2
u'الداراوردي': u'الدَّارَاوَرْدِيُّ', #1
u'الداربجردى': u'الدَّارَبَجَرْدِىُّ', #1
u'الداربجردى': u'الدَّارَبْجِرْدِىُّ', #2
u'الداربردي،': u'الدَّاربردِيُّ،', #1
u'الداربردى': u'الدَارَبَرْدِىُّ', #1
u'الداربردى': u'الدَارَبُرْدِىُّ', #1
u'الداربردى': u'الدَّارَبَرْدِىَّ', #1
u'الداربردي،': u'الدَّارَبَرْدِيُّ،', #2
u'الداربردى': u'الدَّارَبُرْدِىُّ', #4
u'الداربردى': u'الدَّارَبَرْدِىُّ', #6
u'الداربزين': u'الدَّارَبْزِينِ', #1
u'الدارصين': u'الدَّارَصِينُ', #1
u'الدارصيني': u'الدَّارَصِينِيِّ', #1
u'الدارقطني': u'الدارَقُطْنيُّ', #1
u'الدارقطنى': u'الدَّارَقُطِنِىُّ', #1
u'الدارقطنى': u'الدَّارَقُطَّنِىُّ', #1
u'الدارقطنى': u'الدَّارَقُطْنِى', #1
u'الدارقطنى': u'الداَّرَقُطْنِىُّ', #1
u'الدارقطنى': u'الدَّارَقُطْنِىِّ', #12
u'الدارقطني': u'الدَّارَقُطْنِيُّ', #1517
u'الدارقطني،': u'الدَّارَقُطْنِيُّ،', #2
u'الدارقطني': u'الدَّارَقُطْنِيِّ', #214
u'الدارقطني': u'الدارقطني', #4
u'الدارقطني': u'الدَّارَقُطْنِيّ', #525
u'الدارقطنى': u'الدَّارَقُطْنِىُّ', #57
u'الدارقطني': u'الدّارَقُطْنِيّ', #70
u'الدارقهطني': u'الدَّارَقهطْنِيَّ', #1
u'الداركة': u'الدَّارِكَةِ', #1
u'الداركي': u'الدَّارَكِيَّ', #1
u'الداركي': u'الدَّارَكِيِّ', #19
u'الداركى': u'الدَّارِكِىُّ', #2
u'الداركي': u'الدَّارَكِيُّ', #21
u'الداركى': u'الدَّارَكِىُّ', #3
u'الدارمى': u'الدَارِمِىُّ', #1
u'الدارمى': u'الدَّارَمِىَّ', #1
u'الدارمى': u'الدُّارِمِىُّ', #1
u'الدارمى': u'الدَّارِمِىَّ', #14
u'الدارمى': u'الدَّارِمِىِّ', #20
u'الدارمى': u'الدَّارِمِىُّ', #360
u'الدارني': u'الدَّارَنِيِّ', #2
u'الداروإذا': u'الدَّارِوَإِذَا', #1
u'الداروم': u'الدَّارُومَ', #1
u'الداروم': u'الدَّارُومُ', #2
u'الدارى': u'الدَّارِىِّ', #22
u'الدارى': u'الدَّارِىُّ', #3
u'الدارى': u'الدَّارِىَّ', #7
u'الداع،': u'الداعِ،', #1
u'الداع': u'الدَّاعِّ', #1
u'الداع': u'الدَّاعِ', #18
u'الداعى': u'الداعى', #1
u'الداعى': u'الدَّاعِى', #12
u'الداعى': u'الدَّاعِىَ', #3
u'إلداغ': u'إلْدَاغِ', #1
u'الداغستاني': u'الدَّاغِسْتَانِيِّ', #3
u'الدافة': u'الدافة', #1
u'الدافة': u'الدّافَةَ', #1
u'الدافة': u'الدَّافَّة', #1
u'الدافة': u'الدَّافَّةُ', #12
u'الدافة': u'الدَّافَّةِ', #24
u'الدالاني،': u'الدالاني،', #1
u'الدالاني': u'الدَّالَانِيَّ', #1
u'الدالانى': u'الدَّالاَنِىِّ', #10
u'الدالاني،': u'الدَّالانِيُّ،', #2
u'الدالاني': u'الدَّالانِيُّ', #4
u'الدالاني': u'الدَّالانِيِّ', #4
u'الدالاني،': u'الدَّالانِيِّ،', #6
u'الدالاني': u'الدَّالَانِيُّ', #6
u'الدالانى': u'الدَّالاَنِىُّ', #6
u'الدالاني': u'الدَّالَانِيِّ', #9
u'الداله': u'الدَّالِهِ', #1
u'الداله': u'الدَّالَّهَ', #1
u'الداماء': u'الدّامّاءِ', #1
u'الداماء': u'الدّامّاءُ', #2
u'الدامرة': u'الدَّامِرَةِ', #1
u'الدامغاني': u'الدَّامِغَانِيُّ', #1
u'الدامغاني،': u'الدَّامَغَانِيِّ،', #1
u'الدامغاني،': u'الدَّامِغَانِيَّ،', #1
u'الدامغانى': u'الدَّامِغَانِىُّ', #1
u'الدامغانى': u'الدَّامَغَانِىُّ', #13
u'الدامغاني': u'الدَّامَغَانِيَّ', #3
u'الدامغاني،': u'الدَّامِغَانِيُّ،', #4
u'الدامغاني': u'الدَّامَغَانِيُّ', #7
u'الدان': u'الدّانِ', #2
u'الداناج': u'الدَّانَاجُ', #1
u'الداناج،': u'الدَّانَاجَ،', #1
u'الداناج': u'الدَّانَاجِ', #17
u'الداناج،': u'الدَّانَاجُ،', #4
u'الداناج،': u'الدَّانَاجِ،', #6
u'الدانق': u'الدَّانِقُ', #11
u'الدانق': u'الدَّانِقِ', #11
u'الدانق': u'الدَّانَقِ', #14
u'الدانق': u'الدَّانَقُ', #6
u'الدانق': u'الدَّانَقَ', #8
u'الدانق': u'الدَّانِقَ', #9
u'الدانقان': u'الدَّانَقَانِ', #1
u'الدانقان': u'الدَّانِقَانِ', #1
u'الدانقين': u'الدَّانِقَيْنِ', #1
u'الدانئ': u'الدَّانِئِ', #1
u'الداهري،': u'الدَّاهِرِيُّ،', #1
u'الداهرى': u'الدَّاهِرِىُّ', #1
u'الداهري': u'الدَّاهِرِيُّ', #3
u'الداودي،': u'الدَّاوُدِيُّ،', #1
u'الداودى': u'الدَاوُدِىُّ', #1
u'الداودي': u'الدَّاوُدِيُّ', #109
u'الداودي': u'الدَّاوُدِيِّ', #23
u'الداودى': u'الدَّاوُدِىُّ', #5
u'الداودي': u'الدَّاوُدِيّ', #7
u'الداودية': u'الدَّاوُدِيَّةَ', #1
u'الداودية': u'الدَّاوُدِيَّةِ', #1
u'الداورية': u'الدَّاوَرِيَّةِ', #1
u'الدائره': u'الدَّائِرَهْ', #1
u'الدائلي،': u'الدَّائِلِيِّ،', #1
u'الدائمي': u'الدَّائِمِيَّ', #1
u'الدائمي': u'الدَّائِمِيُّ', #2
u'الدائمي': u'الدَّائِمِيِّ', #2
u'الدبا': u'الدّبَا', #1
u'الدبا': u'الدَّبَا', #1
u'الدبا': u'الدُّبَا', #1
u'الدباء': u'الدباء', #16
u'الدباء': u'الدُّبَّاءُ', #20
u'الدباء': u'الدُّبَّاءِ', #208
u'الدباء،': u'الدُّبَّاءَ،', #3
u'الدباء،': u'الدُّبَّاءُ،', #3
u'الدباء،': u'الدُّبَّاءِ،', #41
u'الدباء': u'الدُّبَّاءَ', #49
u'الدباء': u'الدُّبَّاء', #7
u'الدبادب': u'الدَّبَادِبِ', #1
u'الدبداب': u'الدِّبْدَابِ', #1
u'الدبرى': u'الدَّبَرِىَّ', #1
u'الدبرى': u'الدُّبَرِىُّ', #1
u'الدبرى': u'الدَّبَرِىُّ', #24
u'الدبلة': u'الدُّبْلَةِ', #1
u'الدبورا': u'الدَّبُّورَا', #1
u'الدبوقة': u'الدَّبُّوقَةُ', #1
u'الدبى': u'الدَّبَى', #1
u'الدبى': u'الدُّبَى', #1
u'الدبيثي،': u'الدُّبَيْثِيِّ،', #1
u'الدبير': u'الدّبِيرَ', #2
u'الدبير': u'الدّبِيرُ', #3
u'الدبيقى': u'الدِّبَيْقَى', #1
u'الدبيلة': u'الدُّبَيْلَة', #1
u'الدبيلة؟': u'الدُّبَيْلَةُ؟', #1
u'الدبيلة': u'الدبيلة', #2
u'الدبيلة': u'الدّبَيْلَةُ', #2
u'الدبيلة': u'الدُّبَيْلَةُ', #6
u'الدبيلى': u'الدُّبَيْلِىُّ', #1
u'الدبيلي': u'الدَّبِيلِيُّ', #17
u'الدبيلي': u'الدَّبِيلِي', #2
u'الدبيلي': u'الدَّبِيلِيِّ', #6
u'الدثنة': u'الدّثِنّة', #13
u'الدثنة،': u'الدَّثِنَةِ،', #3
u'الدثنة': u'الدَّثِنَةِ', #6
u'الدثنة': u'الدّثِنّةِ', #8
u'الدثنية': u'الدَّثْنِيَّةِ', #1
u'الدثير،': u'الدَّثِيرِ،', #1
u'الدجاجين': u'الدَّجَّاجِينَ', #1
u'الدجلة': u'الدِّجْلَةِ', #31
u'الدجلة': u'الدِّجْلَةَ', #4
u'الدجلة': u'الدِّجْلَةُ', #7
u'الدجيلي': u'الدُّجَيْلِيّ', #1
u'الدحج': u'الدَّحْجَ', #1
u'الدحداح': u'الدَّحْدَاحُ', #1
u'الدحداح': u'الدَّحْدَاح', #4
u'الدحداح،': u'الدَّحْدَاحِ،', #6
u'الدحداح': u'الدَّحْدَاحِ', #70
u'الدحداحة': u'الدَّحْدَاحَة', #1
u'الدحداحة،': u'الدَّحْدَاحَةِ،', #1
u'الدحداحة': u'الدّحْدَاحَةِ', #11
u'الدحداحة': u'الدَّحْدَاحَةِ', #15
u'الدحرض': u'الدَّحْرَضُ', #1
u'الدحرضين': u'الدَّحْرَضَيْنِ', #3
u'الدحريج': u'الدَّحْرِيجَ', #1
u'الدحريج': u'الدَّحْرِيجُ', #1
u'الدحريج': u'الدَّحْرِيجِ', #1
u'الدحضة': u'الدَّحَضَةِ', #1
u'الدحى': u'الدّحَى', #1
u'الدحية': u'الدّحْيَةُ', #2
u'الدخ': u'الدُّخّ', #1
u'الدخ': u'الدُّخِّ', #1
u'الدخ': u'الدُّخُّ', #10
u'الدخ': u'الدّخّ', #2
u'الدخاخين': u'الدّخَاخِينِ', #1
u'الدخاريص': u'الدَّخَارِيصَ', #1
u'الدخاريص': u'الدَّخَارِيصُ', #1
u'الدخاريص': u'الدَّخَارِيصِ', #6
u'الدخرضين': u'الدّخُرُضَيْنِ', #1
u'الدخريص': u'الدِّخْرِيصَ', #2
u'الدخشم': u'الدّخْشُم', #1
u'الدخشم': u'الدُّخْشُمِ', #15
u'الدخشم': u'الدخشم', #2
u'الدخشم': u'الدّخْشَمِ', #2
u'الدخشم': u'الدَّخْشَمِ', #2
u'الدخشم': u'الدّخْشُمِ', #25
u'الدخشن': u'الدُّخْشُن', #1
u'الدخشن': u'الدِّخْشَنِ', #1
u'الدخشن': u'الدِّخْشِنُ', #1
u'الدخشن،': u'الدُّخْشُنِ،', #1
u'الدخشن': u'الدُّخْشُنِ', #9
u'الدخيش': u'الدّخَيْشُ', #1
u'الدخيش': u'الدّخَيْشِ', #1
u'الدخيشن': u'الدخيشن', #1
u'الدخيشن': u'الدُّخَيْشِنِ', #6
u'الدخين،': u'الدُّخَيْنِ،', #1
u'الدراءة': u'الدَّرَاءَةِ', #1
u'الدرابجردي،': u'الدَّرَابَجِرْدِيُّ،', #1
u'الدرابجردى': u'الدَرَابِجِرْدِىُّ', #1
u'الدرابجردى': u'الدَّرَابْجَرْدِىُّ', #1
u'الدرابجردى': u'الدَّرَابِجَرْدِىُّ', #2
u'الدرابجردي،': u'الدَّرَابِجِرْدِيُّ،', #3
u'الدرابجردى': u'الدَّرَابَجَرْدِىُّ', #3
u'الدرابجردى': u'الدَّرَابَجِرْدِىُّ', #3
u'الدرابجردى': u'الدَّرَابْجِرْدِىُّ', #4
u'الدرابزين': u'الدَّرَابْزِينِ', #2
u'الدراة': u'الدَّرَاةَ', #1
u'الدرأة': u'الدَّرْأَة', #2
u'الدراداء': u'الدَّرْادَاءِ', #1
u'الدراري': u'الدّرَارِيّ', #1
u'الدراري': u'الدَّرَارِي', #2
u'الدراري': u'الدَّرَارِيِّ', #2
u'الدراقطني': u'الدَّرَاقُطْنِيُّ', #4
u'الدراك': u'الدَّرَّاكِ', #1
u'الدراكة': u'الدَّرَّاكَةُ', #1
u'الدرانيق': u'الدَّرَانِيقِ', #1
u'الدراوردي': u'الدراوردي', #1
u'الدراوردي': u'الدّراوَرْديّ', #1
u'الدراوردي،': u'الدَّرَاوَرْدِيِّ،', #10
u'الدراوردي،': u'الدراوردي،', #2
u'الدراوردي،': u'الدَّرَاوَرْدِيَّ،', #2
u'الدراوردى': u'الدَّرَاوَرْدِىَّ', #31
u'الدراوردى': u'الدَّرَاوَرْدِىِّ', #35
u'الدراوردي،': u'الدَّرَاوَرْدِيُّ،', #42
u'الدراوردي': u'الدَّرَاوَرْدِيِّ', #47
u'الدراوردي': u'الدَّرَاوَرْدِيَّ', #7
u'الدراوردى': u'الدَّرَاوَرْدِىُّ', #73
u'الدراوردي': u'الدَّرَاوَرْدِيُّ', #78
u'الدراوردي': u'الدّرَاوَرْدِيّ', #8
u'الدرباب': u'الدَّرْبَابُ', #1
u'الدربكة': u'الدَّرَبُكَّةَ', #1
u'الدربكة': u'الدَّرَبُكَّةُ', #1
u'الدرد': u'الدَّرَدُ', #1
u'الدرداءإني': u'الدَّرْدَاءِإِنِّي', #1
u'الدردير': u'الدَّرْدِيرُ', #5
u'الدردير': u'الدَّرْدِيرِ', #6
u'الدرديري': u'الدَّرْدِيرِيِّ', #1
u'الدرزاي': u'الدَّرْزَايُ', #1
u'الدرشخوان': u'الدرشخوان', #1
u'الدرفس': u'الدِّرَفْسِ', #1
u'الدرمك': u'الدرمك', #1
u'الدرمك': u'الدَّرْمَكِ', #2
u'الدرمكة': u'الدرمكة', #2
u'الدرنوق': u'الدَّرْنُوقُ', #1
u'الدرنوك': u'الدرنوك', #1
u'الدرنوك': u'الدُّرْنَوَكِ', #1
u'الدرهما': u'الدِّرْهَمَا', #1
u'الدروازكي': u'الدَّرْوَازَكِيُّ', #1
u'الدروقي،': u'الدَّرُوقِيُّ،', #1
u'الدروقي': u'الدَّرْوَقِيُّ', #1
u'الدروند': u'الدروَنْد', #1
u'الدروى': u'الدُّرِوىُّ', #1
u'الدروية': u'الدَّرْوِيَّةُ', #1
u'الدرى': u'الدُّرِّىَّ', #2
u'الدرياق': u'الدِّرْيَاقُ', #2
u'الدريدي': u'الدُّرَيْدِيُّ', #1
u'الدريس': u'الدَّرِيسُ', #1
u'الدريسين': u'الدّرِيسَيْنِ', #5
u'الدريك': u'الدُّرَيْكِ', #2
u'الدزماري': u'الدِّزَّمَارِيُّ', #1
u'الدستجة': u'الدَّسْتَجَةُ', #1
u'الدستمان': u'الدِّسْتِمَانِ', #1
u'الدستوائي': u'الدستوائي', #1
u'الدستوائي،': u'الدسْتَوائي،', #1
u'الدستوائى': u'الدَّسْتُوَائِىَّ', #1
u'الدستوائي': u'الدَّسْتُوَائِيَّ', #14
u'الدستوائي،': u'الدَّسْتُوَائِيِّ،', #16
u'الدستوائي،': u'الدَّسْتُوَائِيَّ،', #2
u'الدستوائي': u'الدَّسْتُوَائِيِّ', #28
u'الدستوائي،': u'الدستوائي،', #3
u'الدستوائى': u'الدَّسْتَوَائِىَّ', #3
u'الدستوائى': u'الدَّسْتُوَائِىِّ', #4
u'الدستوائي': u'الدَّسْتَوَائِيُّ', #5
u'الدستوائى': u'الدَّسْتَوَائِىُّ', #51
u'الدستوائى': u'الدَّسْتَوَائِىِّ', #52
u'الدستوائي،': u'الدَّسْتُوَائِيُّ،', #59
u'الدستوائى': u'الدَّسْتُوَائِىُّ', #7
u'الدستوائي': u'الدَّسْتُوَائِيُّ', #76
u'الدستيمان': u'الدِّسْتِيمَانَ', #2
u'الدستيمان': u'الدِّسْتِيمَانِ', #4
u'الدستيمان': u'الدستيمان', #8
u'الدسكرة،': u'الدَّسْكَرَةِ،', #1
u'الدسكرة': u'الدَّسْكَرَةَ', #2
u'الدسكرة': u'الدَّسْكَرَةُ', #4
u'الدسكرة': u'الدَّسْكَرَةِ', #4
u'الدسوسة': u'الدَّسُوسَةِ', #1
u'الدسوقي': u'الدسوقي', #1
u'الدسوقي': u'الدُّسُوقِيُّ', #13
u'الدسوقي': u'الدُّسُوقِيِّ', #7
u'الدسومات': u'الدُّسُومَاتُ', #1
u'الدسومات': u'الدُّسُومَاتِ', #8
u'الدسومة': u'الدُّسُومَةُ', #1
u'الدسومة': u'الدُّسُومَةِ', #13
u'الدسومة': u'الدُّسُومَةَ', #2
u'الدشت': u'الدشت', #1
u'الدشت': u'الدَّشْتَ', #1
u'الدشت': u'الدَّشْتِ', #2
u'الدشت': u'الدَّشْتُ', #7
u'الدشتج': u'الدَّشْتَجُ', #1
u'الدشتكي،': u'الدَّشْتَكِيُّ،', #107
u'الدشتكي': u'الدَّشْتَكِيُّ', #12
u'الدشتكي،': u'الدَّشْتَكِيِّ،', #2
u'الدشتكى': u'الدَّشْتَكِىُّ', #4
u'الدشتكي،': u'الدشتكي،', #5
u'الدشتكي،': u'الدَّشْتَكِيَّ،', #6
u'الدشتكي،أنبأ': u'الدَّشْتَكِيُّ،أَنْبَأَ', #1
u'الدشناوي': u'الدِّشْنَاوِيُّ', #4
u'الدعا': u'الدُّعَا', #11
u'الدعارون': u'الدَّعَّارُونَ', #1
u'الدعاميص': u'الدَّعَامِيصُ', #1
u'الدعج': u'الدَّعَج', #1
u'الدعج': u'الدَّعَجُ', #2
u'الدعج': u'الدَّعَجِ', #4
u'الدعجة': u'الدّعْجَةُ', #1
u'الدعجي': u'الدَّعْجِيُّ', #1
u'الدعف': u'الدّعُفْ', #1
u'الدعموص': u'الدُّعْمُوصُ', #1
u'الدعموص': u'الدُّعْمُوصِ', #1
u'الدعموص': u'الدعموص', #2
u'الدعموص': u'الدّعْمُوصِ', #3
u'الدعه': u'الدَّعَهْ', #1
u'الدعوتيات': u'الدَّعْوَتِيَّاتِ', #1
u'الدعوتية': u'الدَّعْوَتِيَّةِ', #5
u'الدعى': u'الدُّعَى', #1
u'الدعيثة': u'الدُّعَيْثَةِ', #1
u'الدعيني': u'الدُّعَيْنِيُّ', #1
u'الدغشى': u'الدَّغْشِىُّ', #1
u'الدغفقة': u'الدغفقة', #1
u'الدغنة': u'الدُّغُنَّةُ', #1
u'الدغنة،': u'الدُّغُنَّة،', #1
u'الدغنة،': u'الدُّغُنَّةِ،', #1
u'الدغنة': u'الدَّغِنَةِ', #13
u'الدغنة': u'الدُّغُنَّةِ', #2
u'الدغنة،': u'الدَّغِنَةَ،', #2
u'الدغنة': u'الدّغُنّةِ', #21
u'الدغنة': u'الدَّغِنَةَ', #3
u'الدغنية': u'الدّغُنّيّةِ', #1
u'الدغولي': u'الدَّغُولِيِّ', #1
u'الدغولي،': u'الدَّغُولِيَّ،', #1
u'الدغولى': u'الدَّغُولِىِّ', #1
u'الدغولي،': u'الدَّغُولِيِّ،', #2
u'الدغولى': u'الدَّغُولِىُّ', #3
u'الدغولي،': u'الدغولي،', #4
u'الدغولي،': u'الدَّغُولِيُّ،', #5
u'الدغينة': u'الدغينة', #1
u'الدغينة': u'الدّغَيْنَةِ', #1
u'الدفاف': u'الدّفَافَ', #1
u'الدفاف': u'الدّفَافُ', #1
u'الدفاف': u'الدّفَافِ', #1
u'الدفاف': u'الدِّفَافُ', #2
u'الدفاف': u'الدِّفَافَ', #3
u'الدفاف': u'الدِّفَافِ', #4
u'الدفر': u'الدّفْرُ', #1
u'الدفر': u'الدَّفْرِ', #1
u'الدفر': u'الدَّفَرُ', #3
u'الدفر': u'الدَّفْرُ', #3
u'الدفري': u'الدَّفَرِيَّ', #1
u'الدفري': u'الدَّفَرِيِّ', #2
u'الدفري': u'الدَّفَرِيُّ', #7
u'الدفعان': u'الدَّفْعَانِ', #3
u'الدفيترات': u'الدُّفَيْتِرَاتِ', #1
u'الدقاع': u'الدُّقَاع', #1
u'الدقاقين': u'الدَّقَّاقِينَ', #5
u'الدقرى': u'الدّقَرَى', #1
u'الدقسة': u'الدُّقْسَةَ', #2
u'الدقعاء': u'الدّقْعَاءِ', #2
u'الدقعاء': u'الدَّقْعَاءِ', #3
u'الدقل': u'الدّقَلُ', #1
u'الدقل': u'الدَّقَل', #1
u'الدقل': u'الدَّقْلِ', #1
u'الدقل': u'الدقل', #3
u'الدقل': u'الدَّقَلِ', #34
u'الدقل': u'الدَّقَلُ', #5
u'الدقل': u'الدَّقَلَ', #8
u'الدقلتين': u'الدَّقَلَتَيْنِ', #1
u'الدقن': u'الدّقْنِ', #1
u'الدقيقا': u'الدَّقِيقَا', #1
u'الدقيقه': u'الدَّقِيقَهْ', #1
u'الدقيقى': u'الدِّقِيقِىُّ', #1
u'الدقيقى': u'الدَّقِيقِىُّ', #15
u'الدكك': u'الدِّكَكُ', #2
u'الدلا': u'الدَّلَّا', #1
u'الدلاصي': u'الدَّلَاصِيِّ', #1
u'الدلافة': u'الدّلّافَةَ', #3
u'الدلاني،': u'الدَّلانِيِّ،', #1
u'الدلجة': u'الدُّلْجَةِ', #15
u'الدلجة': u'الدُّلْجَة', #2
u'الدلجي': u'الدُّلَجِيِّ', #1
u'الدلجي': u'الدُّلَجِيُّ', #4
u'الدلجية': u'الدُّلَجِيَّةِ', #3
u'الدلدل': u'الدّلْدُلَ', #1
u'الدلدل': u'الدَّلْدَلُ', #1
u'الدلدل': u'الدُّلْدُلَ', #1
u'الدلدل': u'الدُّلْدُل', #2
u'الدلدل': u'الدُّلْدُلُ', #3
u'الدلسة': u'الدُّلْسَةَ', #2
u'الدلسة': u'الدُّلْسَةِ', #7
u'الدلم': u'الدُّلَمِ', #1
u'الدلوح': u'الدّلُوحُ', #1
u'الدليمي': u'الدليمي', #1
u'الدما': u'الدَّما', #1
u'الدما': u'الدِّمَا', #1
u'الدما': u'الْدِمَا', #1
u'الدما': u'الدَّمَا', #3
u'الدما': u'الدّمَا', #4
u'الدماءوالوجه': u'الدِّمَاءِوَالْوَجْهُ', #1
u'الدماسي': u'الدَّمَاسِيِّ', #1
u'الدماميني': u'الدَّمَامِينِيّ', #1
u'الدماميني': u'الدَّمَامِينِيِّ', #12
u'الدماميني': u'الدَّمَامِينِيَّ', #2
u'الدماميني': u'الدَّمَامِينِيُّ', #49
u'الدمائث': u'الدّمَائِثِ', #2
u'الدمرداش': u'الدِّمِرْدَاشُ', #1
u'الدمرداش': u'الدِّمِرْدَاشِ', #1
u'الدمشقى': u'الدِّمَشْقِىَّ', #11
u'الدمشقى': u'الدِّمَشْقِىُّ', #121
u'الدمشقى': u'الدِّمَشْقِىِّ', #20
u'الدمنهوري': u'الدَّمَنْهُورِيُّ', #2
u'الدمنهوري': u'الدَّمَنْهُورِيِّ', #2
u'الدمهوجي': u'الدَّمْهُوجِيُّ', #4
u'الدمهوجي': u'الدَّمْهُوجِيِّ', #6
u'الدموك': u'الدّمُوكِ', #3
u'الدمون': u'الدّمُونَ', #1
u'الدمون': u'الدّمُونُ', #1
u'الدمون': u'الدّمّونَ', #1
u'الدمياطى': u'الدِّمْيَاطِىُّ', #5
u'الدميري': u'الدَّمِيرِيُ', #1
u'الدميري': u'الدَّمِيرِيِ', #1
u'الدميري،': u'الدُّمَيْرِيُّ،', #1
u'الدميري،': u'الدَّمِيرِيِّ،', #2
u'الدميري': u'الدَّمِيرِيّ', #22
u'الدميري': u'الدَّمِيرِيُّ', #224
u'الدميري': u'الدَّمِيرِيِّ', #470
u'الدميري': u'الدَّمِيرِيَّ', #7
u'الدميك،': u'الدُّمَيْكِ،', #3
u'الدميك': u'الدُّمَيْكِ', #7
u'الدناكل': u'الدّنَاكِلِ', #1
u'الدنداني،': u'الدنداني،', #1
u'الدنداني': u'الدَّنْدَانِيِّ', #1
u'الدنداني،': u'الدَّنْدَانِيِّ،', #13
u'الدنداني': u'الدَّنْدَانِيُّ', #3
u'الدنداني،': u'الدَّنْدَانِيُّ،', #32
u'الدندن': u'الدِّنْدِنِ', #1
u'الدنن': u'الدّنَنَ', #1
u'الدنوشري': u'الدَّنَوْشَرِيِّ', #1
u'الدنوشري': u'الدَّنَوْشَرِيُّ', #9
u'الدنياحتى': u'الدُّنْيَاحَتَّى', #1
u'الدنياوالوجه': u'الدُّنْيَاوَالْوَجْهُ', #2
u'الدنيلس': u'الدَّنِيلِسَ', #1
u'الدنيلس': u'الدَّنِيلَسُ', #3
u'الدنيلس': u'الدَّنِيلِسُ', #3
u'الدنيلس': u'الدَّنِيلَسِ', #4
u'الدنيلس': u'الدَّنِيلِسِ', #5
u'الدنيلس': u'الدنيلس', #6
u'الده': u'الده', #9
u'الدهاس': u'الدّهَاسِ', #1
u'الدهاس': u'الدَّهَاسَ', #1
u'الدهاقون': u'الدَّهَّاقُونَ', #1
u'الدهانة': u'الدِّهَانَةِ', #2
u'الدهانون': u'الدَّهَّانُونَ', #1
u'الدهب': u'الدَّهْبِ', #1
u'الدهكى': u'الدَّهَكِىَّ', #1
u'الدهلوي': u'الدَّهْلَوِيِّ', #1
u'الدهلي': u'الدِّهْلِيُّ', #1
u'الدهنى': u'الدُّهْنِىَّ', #1
u'الدهنى': u'الدُّهْنِىِّ', #11
u'الدهنى': u'الدُّهْنِىُّ', #7
u'الدهيماء': u'الدُّهَيْمَاءِ', #1
u'الدوا': u'الدَّوَا', #3
u'الدواخلي': u'الدَّوَاخِلِيُّ', #1
u'الدواخلي': u'الدَّوَاخِلِيِّ', #1
u'الدوادمي': u'الدوادمي', #1
u'الدوادمي': u'الدَّوَادِمِيِّ', #1
u'الدوادي': u'الدوادي', #1
u'الدوارون': u'الدَّوَّارُونَ', #1
u'الدواس': u'الدِّوَاسُ', #4
u'الدوال': u'الدَّوَالُّ', #1
u'الدوال': u'الدَّوَالِّ', #1
u'الدوالح': u'الدّوَالِحُ', #1
u'الدوالح': u'الدّوَالِحِ', #1
u'الدوالح': u'الدّوَالِحْ', #2
u'الدوالقي': u'الدَّوَالِقِيِّ', #1
u'الدوانق': u'الدَّوَانِقَ', #1
u'الدوانق': u'الدَّوَانِقِ', #2
u'الدوانقي': u'الدَّوَانِقِيِّ', #4
u'الدوانيق': u'الدَّوَانِيقِ', #3
u'الدوانيقي': u'الدوانيقي', #1
u'الدوانيقي': u'الدَّوَانِيقِيَّ', #1
u'الدوانيقي': u'الدَّوَانِيقِيِّ', #5
u'الدواي': u'الدَّوَايَ', #1
u'الدوحات': u'الدَّوْحَاتِ', #1
u'الدودان': u'الدُّودَانِ', #1
u'الدودوية': u'الدَّوْدَوِيَّةُ', #1
u'الدورا': u'الدُّورَا', #1
u'الدورا': u'الدَّوْرَا', #1
u'الدورقى': u'الدَّوْرَقِىِّ', #14
u'الدورقى': u'الدَّوْرَقِىُّ', #66
u'الدورى': u'الدُّورِىَّ', #12
u'الدورى': u'الدُّورِىُّ', #293
u'الدورى': u'الدُّورِىِّ', #5
u'الدوسي': u'الدوْسي', #1
u'الدوسي،': u'الدَّوْسيْ،', #1
u'الدوسي،': u'الدَّوْسِيِّ،', #1
u'الدوسى': u'الدَّوْسِىِّ', #1
u'الدوسي': u'الدَّوْسِيِّ', #11
u'الدوسي': u'الدَّوْسِيُّ', #14
u'الدوسي': u'الدَّوْسِيّ', #2
u'الدوسي،': u'الدَّوْسِيُّ،', #2
u'الدوسى': u'الدَّوْسِىَّ', #2
u'الدوسي': u'الدّوْسِيّ', #20
u'الدوسي': u'الدوسي', #3
u'الدوسي': u'الدَّوْسيّ', #3
u'الدوسى': u'الدَّوْسِىُّ', #3
u'الدوسي': u'الدَّوْسِيَّ', #5
u'الدوسيان،': u'الدَّوْسِيَّانِ،', #1
u'الدوسية': u'الدوسية', #1
u'الدوسية': u'الدّوْسِيّةِ', #1
u'الدوسية': u'الدَّوْسِيَّةَ', #1
u'الدوسية': u'الدَّوْسِيَّةِ', #5
u'الدوسيون': u'الدّوْسِيّونَ', #1
u'الدوفتين': u'الدَّوْفَتَيْنِ', #1
u'الدوكاء': u'الدَّوْكَاءِ', #1
u'الدؤل': u'الدُّؤْلِ', #1
u'الدؤل': u'الدُّؤَلِ', #2
u'الدولأبي،': u'الدُّولأبِيُّ،', #1
u'الدولابى': u'الدُّولاَبِىَّ', #1
u'الدولابى': u'الدُّولاَبِىِّ', #1
u'الدولابى': u'الدَّوْلاَبِىُّ', #1
u'الدولابى': u'الدُّولاَبِىُّ', #6
u'الدولات': u'الدَّوْلَاتُ', #3
u'الدولج': u'الدَّوْلَجَ', #3
u'الدولعي': u'الدَّوْلَعِيُّ', #3
u'الدؤلي': u'الدؤلي', #1
u'الدؤلي،': u'الدُّؤليّ،', #1
u'الدؤلي،': u'الدُّؤَليِّ،', #1
u'الدؤلي': u'الدُؤَلِيِّ', #1
u'الدؤلي': u'الدُّؤَلِيّ', #1
u'الدؤلى': u'الدُّؤَلِىَّ', #1
u'الدؤلي': u'الدُّؤَلِيُّ', #13
u'الدؤلي': u'الدُّؤَلِيِّ', #14
u'الدؤلي': u'الدُّؤَلِيَّ', #5
u'الدؤلي': u'الدّؤَلِيّ', #6
u'الدؤلى': u'الدُّؤَلِىُّ', #6
u'الدؤلي،': u'الدُّؤَلِيُّ،', #7
u'الدؤلي،': u'الدُّؤَلِيِّ،', #7
u'الدؤلى': u'الدُّؤَلِىِّ', #7
u'الدومة': u'الدَّوْمَةِ', #1
u'الدومة': u'الدّوْمَةِ', #2
u'الدونمات': u'الدُّونَمَاتُ', #2
u'الدونمات': u'الدُّونَمَاتِ', #4
u'الدونمين': u'الدُّونَمَيْنِ', #1
u'الدونين': u'الدُّونَيْنِ', #1
u'الدويرات': u'الدُّوَيْرَاتِ', #2
u'الدويرة': u'الدُّوَيْرَةَ', #1
u'الدويرة': u'الدُّوَيْرَةُ', #1
u'الدويرة': u'الدُّوَيْرَةِ', #2
u'الدويرى': u'الدُّوَيْرِىُّ', #1
u'الدوين': u'الدَّوِينَ', #1
u'الدئل': u'الدئل', #1
u'الدئل': u'الدّئل', #1
u'الدئل': u'الدّئَلِ', #1
u'الدئل': u'الدّئِلَ', #1
u'الدئل': u'الدّئِلِ', #1
u'الدئل': u'الدّئْلِ', #1
u'الدئل': u'الدُّئَلِ', #1
u'الدئل': u'الدُّئِلِ', #1
u'الدئل،': u'الدُّئِلِ،', #1
u'الدئل': u'الدّئِلُ', #2
u'الدئل': u'الدِّئْلِ', #2
u'الدئلي': u'الدّئليّ', #1
u'الدئلي': u'الدِّئْلِيَّ', #1
u'الدئلي': u'الدِّئْلِيُّ', #1
u'الدئلي،': u'الدِّئْلِيُّ،', #1
u'الدئلى': u'الدِّئَلِىِّ', #1
u'الدئلي': u'الدِّئْلِيِّ', #4
u'الدئلي': u'الدئلي', #6
u'الديارا': u'الدِّيَارَا', #1
u'الدياس': u'الدَّيَّاسِ', #1
u'الدياس': u'الدِّيَاسُ', #1
u'الدياس': u'الدِّيَاسَ', #3
u'الدياس': u'الدِّيَاسِ', #35
u'الدياسة': u'الدِّيَاسَةَ', #1
u'الدياسة': u'الدِّيَاسَةُ', #2
u'الدياسة': u'الدِّيَاسَةِ', #22
u'الديافي': u'الدّيَافِي', #1
u'الديافي': u'الدّيَافِيّ', #3
u'الديالمة': u'الدَّيَالِمَةِ', #1
u'الديباجى': u'الدِّيبَاجِىُّ', #2
u'الديبع': u'الدَّيْبَعِ', #4
u'الديبقي': u'الدَّيِبقِيُّ', #2
u'الديبل': u'الدَّيْبُلَ', #1
u'الديبلي': u'الدَّيْبُلِيُّ', #1
u'الديبلى': u'الدَّيْبُلِىُّ', #8
u'الديربي': u'الدَّيْرَبِيُّ', #6
u'الديرعاقولي': u'الدَّيْرُعَاقُولِيُّ', #1
u'الديرعاقولي،': u'الدَّيْرَعَاقُولِيِّ،', #1
u'الديرعاقولى': u'الدَّيْرَعَاقُولِى', #1
u'الديرعاقولى': u'الدَّيْرَعَاقُولِىُّ', #5
u'الديرعاقولي،': u'الدَّيْرُعَاقُولِيُّ،', #7
u'الديريني': u'الدِّيرِينِيُّ', #1
u'الديريني': u'الدِّيرِينِيِّ', #3
u'الديزج': u'الدَّيْزَجُ', #1
u'الديزج،': u'الدَّيْزَجُ،', #1
u'الديل': u'الدِّيلُ', #1
u'الديل': u'الدّيلَ', #1
u'الديل': u'الدِّيَلِ', #1
u'الديل': u'الدّيْلِ', #1
u'الديل،': u'الدّيْل،', #1
u'الديل': u'الدّيلِ', #16
u'الديل': u'الديل', #2
u'الديل،': u'الدِّيلِ،', #2
u'الديل': u'الدِّيلِ', #28
u'الديل': u'الدّيلُ', #5
u'الديلمى': u'الدَّيْلَمِىُّ', #1
u'الديلمى': u'الدَّيْلَمِىِّ', #11
u'الديلي': u'الدِّيليّ', #1
u'الديلي،': u'الدّيليّ،', #1
u'الديلي،': u'الدِيلِيِّ،', #1
u'الديلي': u'الدِّيَلِيِّ', #1
u'الديلي': u'الدِّيْلِيّ', #1
u'الديلي': u'الدّيْلِيّ', #1
u'الديلى': u'الدِّيلىِّ', #1
u'الديلي': u'الدِّيلِيُّ', #14
u'الديلي': u'الدِّيْلِيِّ', #16
u'الديلي': u'الديلي', #2
u'الديلي،': u'الدِّيلِيُّ،', #2
u'الديلي،': u'الدِّيلِيِّ،', #2
u'الديلي': u'الدَّيْلِيِّ', #2
u'الديلي': u'الدِّيْلِيَّ', #2
u'الديلي': u'الدِّيْلِيُّ', #2
u'الديلى': u'الدِّيلِىَّ', #2
u'الديلى': u'الدِّيلِىِّ', #31
u'الديلي': u'الدّيلِيّ', #36
u'الديلى': u'الدِّيلِىُّ', #4
u'الديلي': u'الدِّيلِيِّ', #48
u'الديلي': u'الدِّيلِيَّ', #7
u'الديما': u'الدِّيَمَا', #1
u'الدينا': u'الدِّينَا', #3
u'الدينباذ': u'الدَّيْنَبَاذِ', #4
u'الدينحدثنا': u'الدِّينُحَدَّثَنَا', #1
u'الدينقوله': u'الدِّينِقَولُهُ', #1
u'الدينلات': u'الدينلات', #1
u'الدينور': u'الدِّينور', #1
u'الدينور': u'الدِّينَوَرُ', #1
u'الدينوروي': u'الدِّينُوَرُوِيَ', #1
u'الدينوروي': u'الدِّينِوَرُوِيَ', #1
u'الدينوري': u'الدّينَوَرِيّ', #1
u'الدينوري،': u'الدِّينَوَرِيِّ،', #1
u'الدينورى': u'الدَّيْنُورِىُّ', #1
u'الدينورى': u'الدِّينَوَرِىَّ', #1
u'الدينوري': u'الدِّينَوَرِيَّ', #2
u'الدينورى': u'الدِّينَوَرِىُّ', #21
u'الدينوري': u'الدِّينَوَرِيُّ', #25
u'الدينوري': u'الدِّينَوَرِيِّ', #5
u'الديه،': u'الديه،', #1
u'الديه': u'الدِّيَهْ', #6
u'الديوي': u'الدَّيْوِيُّ', #2
u'الذ': u'الذّ', #2
u'الذ': u'الَّذِ', #3
u'الذاب': u'الذاب', #1
u'الذاب': u'الذَّابُّ', #1
u'الذابون': u'الذَّابُّونَ', #1
u'الذابين': u'الذَّابِّينَ', #3
u'إلذاذ': u'إِلْذَاذٌ', #1
u'الذاري': u'الذَّارِيُّ', #1
u'الذاهبSغزوة': u'الذّاهِبِSغَزْوَةُ', #1
u'الذباذب': u'الذباذب', #1
u'الذبياني': u'الذّبْيَانِي', #1
u'الذبياني': u'الذبياني', #2
u'الذبياني': u'الذّبْيَانِيّ', #6
u'الذبياني': u'الذُّبْيَانِيُّ', #6
u'الذحول': u'الذّحُولَ', #1
u'الذحول': u'الذُّحُولَ', #1
u'الذحول': u'الذُّحُولُ', #1
u'الذخيرية': u'الذَّخِيرِيَّةِ', #2
u'الذرا': u'الذُّرَا', #1
u'الذرا': u'الذّرَا', #4
u'الذرارى': u'الذَّرَارِىُّ', #1
u'الذرارى': u'الذَّرَارِىِّ', #1
u'الذرارى': u'الذَّرَارِىَّ', #4
u'الذراعللخبر': u'الذِّرَاعِلِلْخَبَرِ', #1
u'الذردج': u'الذَّرْدَجِ', #1
u'الذرقة': u'الذَّرِقَةَ', #1
u'الذره': u'الذُّرَهْ', #1
u'الذريرة': u'الذريرة', #1
u'الذريرة': u'الذَّرِيرَةَ', #1
u'الذريرة': u'الذَّرِيرَةِ', #16
u'الذشي': u'الذِّشِي', #1
u'الذعت': u'الذّعْتِ', #1
u'الذعلب': u'الذِّعْلِبُ', #1
u'الذفر': u'الذَّفَرِ', #2
u'الذفر': u'الذَّفَرُ', #4
u'الذكارة': u'الذِّكَارَة', #1
u'الذكرمن': u'الذِّكْرُمِنْ', #1
u'الذكواني': u'الذَّكوانّي', #1
u'الذكواني': u'الذّكُوَانِيّ', #1
u'الذكواني': u'الذّكْوَانِيّ', #1
u'الذكوانى': u'الذَّكْوَانِىُّ', #1
u'الذكواني': u'الذَّكْوَانِيُّ', #6
u'الذليلا': u'الذّلِيلَا', #2
u'الذمارى': u'الذِّمَّارِىِّ', #1
u'الذمارى': u'الذِّمَارِىُّ', #6
u'الذمةقال': u'الذِّمَّةِقَالَ', #1
u'الذمه': u'الذمه', #1
u'الذمه': u'الذِّمَّهْ', #9
u'الذناب': u'الذِّنَابِ', #1
u'الذنبا': u'الذَّنْبَا', #1
u'الذنن': u'الذّنَنُ', #1
u'الذنوبا': u'الذُّنُوبَا', #2
u'الذنوبالوجه': u'الذُّنُوبِالْوَجْهُ', #1
u'الذنين': u'الذَّنِينَ', #1
u'الذهبيي': u'الذهبيي', #1
u'الذهلى': u'الذَّهْلِىَّ', #1
u'الذهلى': u'الذُّهْلِىَّ', #2
u'الذهلى': u'الذُّهْلِىِّ', #5
u'الذهلى': u'الذُّهْلِىُّ', #97
u'الذواء': u'الذّوَاءُ', #2
u'الذواري': u'الذَّوَارِي', #1
u'الذى': u'الذى', #136
u'الذى': u'الَّذِى', #2441
u'الذياب': u'الذِّيَابِ', #1
u'الذيال': u'الذيال', #1
u'الذيال': u'الذَّيَّالُ', #1
u'الذيال': u'الذَّيَّالِ', #12
u'الذيال': u'الذّيّالُ', #2
u'الذيال،': u'الذَّيَّالِ،', #2
u'الذيب': u'الذِّيبُ', #1
u'الذيب': u'الذّيْبُ', #1
u'الذيخ': u'الذَّيْخِ', #1
u'الذيهو': u'الّذِيهُوَ', #1
u'الر': u'الرَّ', #1
u'الر': u'الرّ', #2
u'الر': u'الر', #49
u'الرءوس': u'الرّءُوس', #1
u'الرءوس': u'الرّءُوسَ', #1
u'الرءوس': u'الرّءُوسُ', #1
u'الرءوس،': u'الرُّءُوسَ،', #1
u'الرءوس': u'الرُّءُوس', #12
u'الرءوس،': u'الرُّءُوسِ،', #3
u'الرءوس': u'الرُّءُوسُ', #43
u'الرءوس': u'الرُّءُوسَ', #73
u'الرءوس': u'الرُّءُوسِ', #762
u'الرءوس': u'الرّءُوسِ', #9
u'الرءوسا': u'الرُّءُوسَا', #1
u'الرءوف': u'الرَّءُوف', #1
u'الرءوف': u'الرَّءُوفَ', #1
u'الرءوف': u'الرَّءُوفُ', #25
u'الرءوف': u'الرَّءُوفِ', #48
u'الرأ': u'الرّأ', #1
u'الرأ': u'الرّأْ', #1
u'الرا': u'الرا', #1
u'الراءات': u'الرَّاءَاتِ', #5
u'الراءة': u'الرّاءَةَ', #1
u'الراءة': u'الرّاءَةُ', #1
u'الراءون': u'الرَّاءُونَ', #5
u'الراب': u'الرَّابُّ', #1
u'الراب': u'الرَّابِّ', #14
u'الراب': u'الرَّابَّ', #3
u'الرابسي': u'الرَّابِسِيِّ', #1
u'الرابعه': u'الرَّابِعَهْ', #3
u'الراتج': u'الرَّاتِجُ', #1
u'الراتجي': u'الرّاتِجِيّ', #1
u'الراجحية': u'الرَّاجِحِيَّةُ', #2
u'الراجحية': u'الرَّاجِحِيَّةِ', #3
u'الراجعا': u'الرَّاجِعَا', #2
u'الراجعه': u'الرَّاجِعَهْ', #1
u'الراحله': u'الرَّاحِلَهْ', #1
u'الرأد': u'الرَّأْدَ', #1
u'الرازي': u'الرازيّ', #1
u'الرازي': u'الرَّازِيَُّ', #1
u'الرازي': u'الرَّازِّي', #1
u'الرازى،': u'الرازى،', #1
u'الرازى': u'الرَّازِى', #1
u'الرازي': u'الرَّازِيُّ', #110
u'الرازي': u'الرازي', #12
u'الرازى': u'الرَّازِىِّ', #12
u'الرازي': u'الرَّازِيِّ', #137
u'الرازي،': u'الرَّازِيَّ،', #15
u'الرازي،': u'الرازي،', #20
u'الرازى': u'الرَّازِىُّ', #255
u'الرازي': u'الرَّازِيَّ', #308
u'الرازي،': u'الرَّازِيُّ،', #368
u'الرازي،': u'الرَّازِيِّ،', #61
u'الرازى': u'الرَّازِىَّ', #8
u'الرازي': u'الرَّازِيّ', #994
u'الرازيان': u'الرَّازِيَّانُ', #1
u'الرازيان،': u'الرَّازِيَّانِ،', #1
u'الرازيان': u'الرَّازِيَّانِ', #2
u'الرازيانج': u'الرَّازِيَانجِ', #1
u'الرازيانج': u'الرازيانج', #4
u'الرازيبلغني': u'الرَّازِيُّبَلَغَنِي', #1
u'الرازية': u'الرَّازِيَّةَ', #1
u'الرازيون،': u'الرَّازِيُّونَ،', #1
u'الرازيين': u'الرَّازِيَّيْنِ', #1
u'الرازيين،': u'الرَّازِيَّيْنِ،', #1
u'الرازيين،': u'الرَّازِيِّينَ،', #3
u'الراس': u'الرَّاسِّ', #1
u'الراس': u'الرَّاسِ', #5
u'الراسبي': u'الرَّاسِبِيَّ', #1
u'الراسبى': u'الرَّاسِبِىَّ', #1
u'الراسبي،': u'الرَّاسِبِيُّ،', #11
u'الراسبى': u'الرَّاسِبِىُّ', #11
u'الراسبي': u'الراسبي', #2
u'الراسبى': u'الرَّاسِبِىِّ', #2
u'الراسبي': u'الرَّاسِبِيُّ', #24
u'الراسبي،': u'الرَّاسِبِيِّ،', #4
u'الراسبي': u'الرَّاسِبِيِّ', #6
u'الراسبية': u'الرَّاسِبِيَّةِ', #1
u'الراسبية': u'الرَّاسِبِيَّةُ', #3
u'الراش': u'الرَّاشُّ', #19
u'الراش': u'الرَّاشِّ', #6
u'الراشدي،': u'الرَّاشِدِيُّ،', #1
u'الراشدي': u'الرَّاشِدِيُّ', #2
u'الراشى': u'الرَّاشِىَ', #1
u'الراع': u'الرَّاعِ', #2
u'الراعن': u'الرَّاعِنُ', #2
u'الراعى': u'الرَّاعِى', #12
u'الراعى': u'الرَّاعِىَ', #4
u'الرافقى': u'الرَّافِقِىُّ', #3
u'الرافلة': u'الرَّافِلَةُ', #1
u'الراقم': u'الرَّاقِمُ', #2
u'الرال': u'الرَّالُ', #1
u'الرامخ': u'الرَّامِخُ', #4
u'الرامخ': u'الرَّامِخِ', #9
u'الرامهرمزي': u'الرامَهُرْمُزِيّ', #1
u'الرامهرمزي': u'الرامهرمزي', #2
u'الرامهرمزي': u'الرَّامَهُرْمُزِيُّ', #2
u'الراموز': u'الرَّامُوزِ', #1
u'الرامى': u'الرامى', #1
u'الرامى': u'الرَّامِى', #2
u'الراميني': u'الرَّامِينِيِّ', #1
u'الرانج': u'الرَّانِجِ', #4
u'الرانجاوي': u'الرَّانْجَاوِيُّ', #1
u'الراهطاء': u'الرّاهِطَاءِ', #1
u'الراهنه': u'الرَّاهِنَهْ', #1
u'الراهويه،': u'الرَّاهَوَيْهِ،', #1
u'الراودي': u'الرَّاوِدِيّ', #2
u'الراوسانى': u'الرَّاوَسَانِىُّ', #1
u'الراوند': u'الراوند', #6
u'الراوى': u'الراوى', #2
u'الراوى': u'الرَّاوِى', #22
u'الراوى': u'الرَّاوِىَ', #4
u'الراويه': u'الرَّاوِيَهْ', #1
u'الرأى': u'الرأى', #1
u'الرأى؟': u'الرَّأْىِ؟', #1
u'الرأى': u'الرَّأْىُ', #2
u'الرأى': u'الرَّأْىِ', #21
u'الرأى': u'الرَّأْى', #3
u'الرأى': u'الرَّأْىَ', #5
u'الرائض': u'الرَّائِضَ', #2
u'الرائض': u'الرَّائِضُ', #3
u'الرائض': u'الرَّائِضِ', #8
u'الرائين': u'الرَّائَيْنِ', #1
u'الرائين': u'الرَّائِينَ', #14
u'الرايس': u'الرايس', #1
u'الرايعة': u'الرَّايِعَةِ', #2
u'الرأيي': u'الرَّأْيِيُّ', #1
u'الرأيي': u'الرَّأْيِيِّ', #1
u'الرباطى': u'الرِّبَاطِىَّ', #1
u'الرباطى': u'الرِّبَاطِىُّ', #1
u'الرباطى': u'الرِّبَاطِىِّ', #1
u'الربالوجه': u'الرَّبُّالْوَجْهُ', #1
u'الربالي': u'الربالي', #1
u'الربالي': u'الرَّبَالِيّ', #1
u'الربالي،': u'الرَّبَالِيُّ،', #1
u'الربالي،': u'الرَّبَالِيِّ،', #2
u'الربالى': u'الرَّبَالِىُّ', #2
u'الربحلة': u'الرَّبْحَلَةِ', #1
u'الربداء': u'الرَّبْدَاءَ', #1
u'الربذى': u'الرَّبَذِىِّ', #1
u'الربذى': u'الرَّبَذِىُّ', #5
u'الربطاء': u'الرُّبَطَاءُ', #1
u'الربعى': u'الرَّبْعِىِّ', #1
u'الربعى': u'الرَّبَعِىُّ', #2
u'الربوعات': u'الرَّبُوعَاتِ', #1
u'الربيث': u'الرِّبِّيثُ', #1
u'الربيثا': u'الرِّبِّيثَا', #1
u'الربيح': u'الرَّبِيحِ', #1
u'الربيس': u'الرّبّيسُ', #1
u'الربيس': u'الرُّبَيْسُ', #1
u'الربيس': u'الرّبَيّسُ', #2
u'الربيضين': u'الرَّبِيضَيْنِ', #2
u'الرتاعا': u'الرِّتَاعَا', #1
u'الرتائم': u'الرَّتَائِمِ', #6
u'الرتقاء': u'الرَّتْقَاءَ', #15
u'الرتقاء': u'الرَّتْقَاءُ', #29
u'الرتقاء': u'الرَّتْقَاءِ', #50
u'الرتم': u'الرَّتَمْ', #1
u'الرتم': u'الرَّتْمَ', #1
u'الرتم': u'الرَّتَمَ', #2
u'الرتم': u'الرَّتْمُ', #2
u'الرتم': u'الرَّتَمِ', #3
u'الرتم': u'الرَّتَمُ', #6
u'الرتيلا': u'الرتيلا', #1
u'الرتيلا': u'الرَّتِيلَا', #1
u'الرتيلى': u'الرُّتَيْلَى', #1
u'الرتيمة': u'الرَّتِيمَةِ', #3
u'الرتيمة': u'الرَّتِيمَةُ', #7
u'الرثائث': u'الرّثَائِثِ', #3
u'الرجالوروي': u'الرِّجَالِوَرُوِيَ', #1
u'الرجامين': u'الرّجَامَيْنِ', #1
u'الرجح': u'الرَّجْحُ', #2
u'الرجحي': u'الرَّجَحِيِّ', #1
u'الرجراجي': u'الرَّجْرَاجِيَّ', #3
u'الرجراجي': u'الرَّجْرَاجِيِّ', #35
u'الرجراجي': u'الرَّجْرَاجِيُّ', #71
u'الرجزاء': u'الرّجْزَاءِ', #1
u'الرجعيه': u'الرَّجْعِيَّهْ', #2
u'الرجلاء': u'الرَّجْلَاءُ', #1
u'الرجلاء': u'الرَّجْلَاءَ', #2
u'الرجلاء': u'الرّجْلَاءِ', #4
u'الرجلاء': u'الرَّجْلَاءِ', #6
u'الرجلالحسن': u'الرَّجُلُالْحَسَنُ', #1
u'الرجلفي': u'الرَّجُلَفِي', #1
u'الرجليشرع': u'الرَّجُلِيَشْرَعُ', #1
u'الرجو': u'الرَّجْوُ', #1
u'الرجوعا': u'الرُّجُوعَا', #1
u'الرجيح': u'الرَّجِيحِ', #1
u'الرحا': u'الرَّحَا', #160
u'الرحا': u'الرّحَا', #3
u'الرحاء': u'الرَّحَّاءَ', #1
u'الرحاء': u'الرَّحَّاءِ', #1
u'الرحاء': u'الرَّحَاءِ', #2
u'الرحايل': u'الرَّحَايِلِ', #1
u'الرحبى': u'الرَّحَبِىَّ', #1
u'الرحبى': u'الرَّحَبِىُّ', #11
u'الرحبى': u'الرَّحَبِىِّ', #6
u'الرحراح': u'الرحراح', #1
u'الرحض': u'الرَّحْضِ', #5
u'الرحضاء': u'الرحضاء', #1
u'الرحضاء': u'الرّحَضَاءُ', #2
u'الرحضاء': u'الرُّحَضَاء', #2
u'الرحضاء': u'الرُّحَضَاءَ', #4
u'الرحمتي': u'الرَّحْمَتَيَّ', #1
u'الرحمتي': u'الرَّحْمَتَيْ', #1
u'الرحمتي': u'الرَّحْمَتِيَّ', #11
u'الرحمتي': u'الرَّحْمَتِيُّ', #182
u'الرحمتي': u'الرَّحْمَتِيِّ', #9
u'الرحمه': u'الرَّحْمَهْ', #1
u'الرحي': u'الرُّحِيِّ', #1
u'الرحي': u'الرُّحِيْ', #1
u'الرحيمية': u'الرَّحِيمِيَّةِ', #20
u'الرخاني،': u'الرخاني،', #1
u'الرخج': u'الرُّخَّجَ', #1
u'الرخج': u'الرُّخَّجِ', #2
u'الرخجى': u'الرُّخَجِىُّ', #1
u'الرخى': u'الرُّخِّىُّ', #3
u'الردء': u'الرَّدْءِ', #1
u'الردء': u'الرِّدْءَ', #13
u'الردء': u'الرِّدْءُ', #15
u'الردء': u'الرِّدْءِ', #16
u'الرداح': u'الرداح', #1
u'الرداح': u'الرّدّاحُ', #1
u'الرداح': u'الرّدَاحِ', #2
u'الرداد،': u'الرداد،', #1
u'الرداد': u'الرَّدَّادَ', #1
u'الرداد': u'الرِّدَادَ', #1
u'الرداد': u'الرَّدَّادُ', #20
u'الرداد': u'الرَّدَّادِ', #20
u'الرداد': u'الرداد', #3
u'الرداعي': u'الرَّدَاعِي', #1
u'الردعات': u'الرَّدَعَاتُ', #1
u'الردغ': u'الردغ', #1
u'الردغ': u'الرَّدْغُ', #2
u'الردغة': u'الردغة', #1
u'الردغة': u'الرَّدْغَةَ', #1
u'الردغة': u'الرَّدْغَةِ', #2
u'الردغة': u'الرَّدْغَةُ', #4
u'الردن': u'الرّدَنِ', #1
u'الردئ': u'الرَّدِئ', #1
u'الرديني': u'الرّدَيْنِيّ', #1
u'الرديني': u'الرُّدَيْنِيِّ', #3
u'الردينية': u'الرّدَيْنِيّةُ', #1
u'الردينية': u'الرّدَيْنِيّةِ', #2
u'الرذلة': u'الرَّذِلَةِ', #1
u'الرذلة': u'الرَّذِلَةُ', #2
u'الرزاز': u'الرَّزَّاز', #1
u'الرزاز،': u'الرَّزَّازِ،', #2
u'الرزاز': u'الرَّزَّازُ', #281
u'الرزاز': u'الرَّزَازُ', #3
u'الرزاز': u'الرَّزَّازِ', #3
u'الرزاز': u'الرَّزْازُ', #4
u'الرزازون': u'الرَّزَّازُونَ', #1
u'الرزازين': u'الرَّزَّازِينَ', #1
u'الرزاق،': u'الرَّزًّاقِ،', #1
u'الرزاي،': u'الرَّزِايُّ،', #1
u'الرزجاهى': u'الرُّزْجَاهِىُّ', #1
u'الرزجاهى': u'الرَّزْجَاهِىُّ', #11
u'الرزداق': u'الرُّزْدَاقِ', #1
u'الرزقات': u'الرَّزَقَاتُ', #1
u'الرزقة': u'الرِّزْقَةُ', #1
u'الرزقة': u'الرَّزْقَةِ', #2
u'الرزقة': u'الرَّزْقَةُ', #3
u'الرزى': u'الرُّزْىِّ', #1
u'الرزى': u'الرُّزِّىُّ', #8
u'الرزيقي': u'الرُّزَيْقِيُّ', #1
u'الرزيقي،': u'الرُّزَيْقِيُّ،', #2
u'الرزيم': u'الرّزِيمِ', #1
u'الرساتيق': u'الرساتيق', #1
u'الرساتيق': u'الرَّساتيق', #1
u'الرساتيق': u'الرَّسَاتِيقِ', #28
u'الرساله': u'الرِسَالَهْ', #1
u'الرساله': u'الرِّسَالَهْ', #1
u'الرسبي،': u'الرَّسَبِيَّ،', #1
u'الرستاق': u'الرُّسْتَاقُ', #1
u'الرستاق': u'الرِّسْتَاقِ', #1
u'الرستاق،': u'الرِّسْتَاقِ،', #1
u'الرستاق': u'الرُّسْتَاقَ', #2
u'الرستاق': u'الرُّسْتَاقِ', #86
u'الرستاقي': u'الرستاقي', #2
u'الرستاقي': u'الرُّسْتَاقِيِّ', #2
u'الرستاقي': u'الرُّسْتَاقِيُّ', #3
u'الرستاقيون': u'الرُّسْتَاقِيُّونَ', #4
u'الرستغفني': u'الرُّسْتُغَفْنِيُّ', #1
u'الرستغفني': u'الرُّسْتُغْفَنِيِّ', #12
u'الرستغفني': u'الرُّسْتُغْفَنِيُّ', #18
u'الرستغفني': u'الرُّسْتُغْفَنِيَّ', #2
u'الرستفغني': u'الرستفغني', #1
u'الرستفغني': u'الرُّسْتُفْغَنِيِّ', #2
u'الرستن': u'الرستن', #1
u'الرستني': u'الرُّسْتَنِيُّ', #1
u'الرسحاء': u'الرَّسْحَاءُ', #2
u'الرسع': u'الرَّسَعُ', #1
u'الرسعني،': u'الرسعني،', #1
u'الرسعني': u'الرَّسْعَنِيُّ', #1
u'الرسعني': u'الرَّسْعَنِيِّ', #1
u'الرسعني،': u'الرَّسْعَنِيُّ،', #3
u'الرسعنى': u'الرَّسْعَنِىُّ', #4
u'الرسلا': u'الرسلا', #1
u'الرسلا': u'الرُّسُلاَ', #1
u'الرسلا': u'الرّسُلَا', #1
u'الرسلا': u'الرُّسُلَا', #3
u'الرسولا': u'الرَّسُولَا', #1
u'الرسيلان': u'الرَّسِيلَانِ', #2
u'الرسيم': u'الرسيم', #1
u'الرسيم': u'الرُّسَيْمِ', #1
u'الرسيم،': u'الرُّسَيْمِ،', #1
u'الرسيم': u'الرّسِيمِ', #2
u'الرسيم': u'الرَّسِيمِ', #3
u'الرشتة': u'الرَّشْتَةِ', #1
u'الرشتة': u'الرِّشْتَة', #1
u'الرشدا': u'الرَّشَدَا', #1
u'الرشداء': u'الرُّشَدَاءَ', #2
u'الرشداء': u'الرُّشَدَاءُ', #3
u'الرشداء': u'الرُّشَدَاءِ', #8
u'الرشداني': u'الرِّشْدَانِيِّ', #1
u'الرشك': u'الرِّشْكِ', #25
u'الرشك': u'الرِّشْكُ', #5
u'الرشك،': u'الرِّشْكُ،', #5
u'الرشك': u'الرِّشْكَ', #6
u'الرشك،': u'الرِّشْكِ،', #6
u'الرشيدي': u'الرَّشِيدِيّ', #3
u'الرشيدي': u'الرَّشِيدِيِّ', #537
u'الرشيدي': u'الرَّشِيدِيُّ', #688
u'الرشيدي': u'الرَّشِيدِيَّ', #7
u'الرشيدية': u'الرَّشِيدِيَّةَ', #1
u'الرشيدية': u'الرَّشِيدِيَّةِ', #17
u'الرصاصى': u'الرَّصَاصِىُّ', #1
u'الرصاع': u'الرَّصَّاعِ', #19
u'الرصاع': u'الرَّصَّاعَ', #3
u'الرصاع': u'الرَّصَّاعُ', #50
u'الرصاع': u'الرَّصَّاع', #7
u'الرصافى': u'الرُّصَافِىُّ', #5
u'الرصدا': u'الرَّصَدَا', #1
u'الرصدات': u'الرَّصَدَاتِ', #1
u'الرصديون': u'الرَّصَدِيُّونَ', #1
u'الرصوف': u'الرُّصُوفِ', #2
u'الرضح': u'الرّضْحُ', #1
u'الرضح': u'الرَّضْحِ', #1
u'الرضخة': u'الرَّضْخَةَ', #1
u'الرضراض،': u'الرضراض،', #1
u'الرضراض': u'الرَّضْرَاضُ', #2
u'الرضراض': u'الرَّضْرَاضِ', #2
u'الرضعات': u'الرَّضَعَاتُ', #1
u'الرضعات': u'الرَّضْعَاتِ', #1
u'الرضعات': u'الرَّضَعَاتِ', #22
u'الرضعتان': u'الرَّضْعَتَانِ', #20
u'الرضم': u'الرّضْمُ', #1
u'الرضمة': u'الرضمة', #1
u'الرضوانوروي': u'الرِّضْوَانِوَرُوِيَ', #1
u'الرضوانية': u'الرِّضْوَانِيَّةُ', #1
u'الرضوانية': u'الرِّضْوَانِيَّةِ', #1
u'الرضيخة': u'الرَّضِيخَةَ', #1
u'الرضيم': u'الرّضِيمَ', #1
u'الرطيل': u'الرُّطَيْلُ', #1
u'الرطيل': u'الرُّطَيْلِ', #1
u'الرعاث': u'الرّعَاثَ', #1
u'الرعاث': u'الرِّعَاثِ', #1
u'الرعام': u'الرُّعَامُ', #1
u'الرعام': u'الرُّعَامَ', #2
u'الرعة': u'الرِّعَةُ', #1
u'الرعى': u'الرعى', #1
u'الرعى': u'الرَّعْىِ', #1
u'الرعيني': u'الرعيني', #1
u'الرعيني،': u'الرُّعَيْنِيُّ،', #1
u'الرعينى': u'الرُّعَيْنِىَّ', #1
u'الرعيني': u'الرُّعَيْنِيِّ', #13
u'الرعيني،': u'الرعيني،', #2
u'الرعينى': u'الرُّعَيْنِىِّ', #2
u'الرعينى': u'الرُّعَيْنِىُّ', #3
u'الرعيني': u'الرُّعَيْنِيُّ', #34
u'الرعيني': u'الرُّعَيْنِيَّ', #6
u'الرعيني،': u'الرُّعَيْنِيِّ،', #7
u'الرغامه': u'الرّغَامَهْ', #1
u'الرغائف': u'الرَّغَائِفَ', #1
u'الرغبا': u'الرُّغْبَا', #1
u'الرغباء': u'الرَّغْبَاءُ', #1
u'الرغباء': u'الرَّغْبَاءِ', #1
u'الرغفان': u'الرُّغْفَانُ', #1
u'الرغفان': u'الرُّغْفَانِ', #2
u'الرفا': u'الرَّفَا', #2
u'الرفا': u'الرَّفَّا', #2
u'الرفاعى': u'الرِّفَاعِىِّ', #1
u'الرفاعى': u'الرِّفَاعِىُّ', #11
u'الرفاف': u'الرّفَافِ', #1
u'الرفاف': u'الرِّفَافَ', #1
u'الرفاف': u'الرِّفَافُ', #1
u'الرفاف': u'الرِّفَافِ', #2
u'الرفائين': u'الرَّفَّائِينَ', #2
u'الرفدا': u'الرّفُدَا', #3
u'الرفعاء': u'الرُّفَعَاءُ', #1
u'الرفعاء': u'الرُّفَعَاءِ', #3
u'الرفغ': u'الرُّفْغُ', #1
u'الرفغ': u'الرُّفْغِ', #2
u'الرفوع': u'الرُّفُوعَ', #1
u'الرفيل': u'الرُّفَيْلُ', #1
u'الرفيل': u'الرُّفَيْلِ', #2
u'الرقابا': u'الرّقَابَا', #2
u'الرقاشي،': u'الرّقاشيّ،', #1
u'الرقاشي،': u'الرَّقَاشِيَّ،', #1
u'الرقاشي': u'الرَّقَاشِيّ', #12
u'الرقاشي': u'الرَّقَاشِيُّ', #21
u'الرقاشى': u'الرَّقَاشِىِّ', #25
u'الرقاشي،': u'الرَّقَاشِيِّ،', #27
u'الرقاشى': u'الرَّقَاشِىَّ', #3
u'الرقاشي': u'الرَّقَاشِيِّ', #47
u'الرقاشي،': u'الرَّقَاشِيُّ،', #48
u'الرقاشي': u'الرقاشي', #5
u'الرقاشي': u'الرَّقَاشِيَّ', #5
u'الرقاشى': u'الرَّقَاشِىُّ', #61
u'الرقاشي،': u'الرقاشي،', #9
u'الرقاشي،أنه': u'الرقاشي،أنه', #1
u'الرقاعة': u'الرَّقَاعَةِ', #1
u'الرقبات': u'الرَّقَبَاتِ', #2
u'الرقبه': u'الرّقَبَهْ', #2
u'الرقبه': u'الرَّقَبَهْ', #7
u'الرقبى،': u'الرُّقْبَى،', #1
u'الرقبى': u'الرُّقْبَى', #107
u'الرقل': u'الرّقْلُ', #2
u'الرقمة': u'الرَّقْمَةُ', #1
u'الرقمة': u'الرَّقْمَةِ', #1
u'الرقمة': u'الرقمة', #3
u'الرقمتين': u'الرَّقْمَتَيْنِ', #3
u'الرقوم': u'الرُّقُومُ', #2
u'الرقوم': u'الرُّقُومِ', #2
u'الرقيا': u'الرُّقْيَا', #4
u'الرقيبا': u'الرَّقِيبَا', #1
u'الرقيش': u'الرّقَيْشِ', #1
u'الرقيع': u'الرّقِيعَ', #1
u'الرقيع': u'الرَّقِيعُ', #1
u'الركاز': u'الرِّكَازُ', #105
u'الركاز': u'الرِّكَازَ', #109
u'الركاز': u'الرِّكَاز', #4
u'الركاز': u'الرِّكَازِ', #423
u'الركايا': u'الرّكَايَا', #2
u'الركدا': u'الرُّكَّدَا', #1
u'الركراكي': u'الرَّكْرَاكِيَّ', #1
u'الركراكي': u'الرَّكْرَاكِيُّ', #4
u'الركرب': u'الركرب', #1
u'الركزة': u'الرِّكْزَةَ', #1
u'الركس': u'الرِّكْس', #5
u'الركضة': u'الرَّكْضَةِ', #1
u'الركعيتن': u'الركعيتن', #1
u'الركنن': u'الرُّكْنَنِ', #1
u'الركوز': u'الرُّكُوزِ', #2
u'الركوسية': u'الرَّكُوسِيَّةَ', #1
u'الركوسية': u'الرَّكُوسِيَّةِ', #1
u'الركي': u'الرّكِيّ', #1
u'الركي،': u'الرَّكِيِّ،', #1
u'الركى': u'الركى', #1
u'الركي': u'الرَّكِيِّ', #4
u'الركيات': u'الرّكِيّاتِ', #2
u'الركية': u'الرّكِيّةِ', #1
u'الركية': u'الرَّكِيَّةَ', #1
u'الركية': u'الركية', #2
u'الركية': u'الرَّكِيَّةُ', #2
u'الركية': u'الرَّكْيَةِ', #2
u'الركية': u'الرَّكِيَّةِ', #7
u'الركيعات': u'الرُّكَيْعَاتُ', #1
u'الرما': u'الرِّمَا', #2
u'الرمادى': u'الرَّمَادِىَّ', #1
u'الرمادى': u'الرَّمَادِىِّ', #1
u'الرمادى': u'الرَّمَّادِىُّ', #1
u'الرمادى': u'الرَّمَادِىُّ', #130
u'الرماس،': u'الرَّمَّاسِ،', #1
u'الرماصي': u'الرَّمَاصِيِّ', #13
u'الرماصي': u'الرَّمَاصِيَّ', #3
u'الرماصي': u'الرَّمَاصِيُّ', #78
u'الرماع': u'الرُّمَاعِ', #1
u'الرماك': u'الرّمّاكِ', #1
u'الرماك': u'الرِّمَاكِ', #40
u'الرماك': u'الرِّمَاكُ', #8
u'الرمام': u'الرَّمَّامِ', #1
u'الرمانى': u'الرُّمَّانِىُّ', #1
u'الرمث': u'الرّمَثِ', #1
u'الرمث': u'الرّمْثِ', #1
u'الرمث': u'الرَّمْثِ', #1
u'الرمثاء': u'الرَّمْثَاءِ', #1
u'الرمجارى': u'الرَّمْجَارِىُّ', #2
u'الرمدانة': u'الرَّمْدَانَةُ', #1
u'الرمص': u'الرَّمَصُ', #4
u'الرمص': u'الرَّمَصِ', #6
u'الرمضان': u'الرَّمَضَانِ', #16
u'الرمضان': u'الرَّمَضَانُ', #5
u'الرمضان': u'الرَّمَضَانَ', #6
u'الرمضانين': u'الرَّمَضَانَيْنِ', #11
u'الرمضة': u'الرَّمَضَةُ', #1
u'الرمضة': u'الرَّمِضَةُ', #1
u'الرمك': u'الرَّمَكَ', #1
u'الرمك': u'الرَّمَكُ', #1
u'الرمك': u'الرَّمَكِ', #2
u'الرمكة': u'الرَّمَكَةَ', #10
u'الرمكة': u'الرُّمْكَةِ', #2
u'الرمكة': u'الرَّمَكَةُ', #22
u'الرمكة': u'الرَّمَكَةِ', #24
u'الرملى': u'الرَّمْلِىَّ', #1
u'الرملى': u'الرَّمْلِىُّ', #49
u'الرملى': u'الرَّمْلِىِّ', #7
u'الرموح': u'الرَّمُوحُ', #2
u'الرمى': u'الرمى', #1
u'الرمى': u'الرَّمْىَ', #11
u'الرمى': u'الرَّمْىِ', #13
u'الرمى': u'الرَّمْىُ', #8
u'الرميا': u'الرّمّيا', #1
u'الرميا': u'الرِّمِيَّا', #1
u'الرميا': u'الرّمْيَا', #3
u'الرميصاء': u'الرميصاء', #1
u'الرميصاء': u'الرُّمَيْصَاءَ', #1
u'الرميصاء': u'الرُّمَيْصَاءِ', #1
u'الرميصاء': u'الرّمَيْصَاءُ', #2
u'الرميصاء': u'الرُّمَيْصَاء', #3
u'الرميصاء': u'الرُّمَيْصَاءُ', #6
u'الرميل': u'الرُّمَيْلِ', #1
u'الرميلة': u'الرُّمَيْلَةِ', #4
u'الرميه': u'الرميه', #1
u'الرند': u'الرَّنْدِ', #1
u'الرنه': u'الرّنّهْ', #2
u'الرنه': u'الرَّنَّهْ', #2
u'الرها': u'الرَّها', #1
u'الرها': u'الرُّها', #1
u'الرهاوي،': u'الرَهاوي،', #1
u'الرهاوي،': u'الرّهاوي،', #1
u'الرهاوي': u'الرَّهاوِيّ', #1
u'الرهاوي': u'الرَّهَاوِيّ', #1
u'الرهاوي': u'الرُّهَاوِيّ', #1
u'الرهاوي': u'الرُّهَاوِيِّ', #1
u'الرهاوي،': u'الرَّهَاوِيُّ،', #1
u'الرهاوي،': u'الرُّهَاوِيُّ،', #13
u'الرهاوي': u'الرَّهَاوِيُّ', #19
u'الرهاوي': u'الرهاوي', #2
u'الرهاوي،': u'الرهاوي،', #2
u'الرهاوي': u'الرَهاوي', #2
u'الرهاوي،': u'الرَّهَاوِيَّ،', #2
u'الرهاوي،': u'الرَّهَاوِيِّ،', #2
u'الرهاوي': u'الرَّهَاوِيَّ', #3
u'الرهاوي': u'الرُّهَاوِيُّ', #3
u'الرهاوي': u'الرّهَاوِيّ', #4
u'الرهاوي': u'الرَّهَاوِيِّ', #4
u'الرهاوي،': u'الرُّهَاوِيِّ،', #4
u'الرهاوى': u'الرُّهَاوِىُّ', #4
u'الرهاويون': u'الرّهَاوِيّونَ', #1
u'الرهج': u'الرّهَجُ', #1
u'الرهج': u'الرّهَجِ', #1
u'الرهج': u'الرّهْجِ', #2
u'الرهنيه': u'الرَّهْنِيَّهْ', #1
u'الرهونات': u'الرُّهُونَاتِ', #1
u'الرهوني': u'الرَّهُونِيّ', #1
u'الرهوني': u'الرَّهُونِيَّ', #1
u'الرهوني': u'الرَّهُونِيِّ', #23
u'الرهوني': u'الرَّهُونِيُّ', #41
u'الرهيد': u'الرّهِيدِ', #1
u'الرهيص': u'الرَّهِيصُ', #1
u'الرهيص': u'الرَّهِيصَ', #2
u'الرهيص': u'الرَّهِيصِ', #7
u'الرهيط': u'الرُّهَيْطُ', #1
u'الرهيم': u'الرَّهِيمِ', #1
u'الرهيني': u'الرَّهِينِيُّ', #1
u'الرواتك': u'الرَّوَاتِك', #1
u'الرواتك': u'الرّوَاتِك', #2
u'الرواتك': u'الرّوَاتِكِ', #3
u'الروادى': u'الرَّوَّادِىُّ', #1
u'الروازن': u'الرَّوَازِنَ', #1
u'الروازن': u'الرَّوَازِنُ', #1
u'الروازن': u'الرَّوَازِنِ', #2
u'الرواس': u'الرواس', #1
u'الرواس': u'الرَّوَّاسِ', #2
u'الرؤاسى': u'الرُّؤَاسِىِّ', #1
u'الرؤاسي': u'الرُّؤَاسِيُّ', #11
u'الرؤاسى': u'الرُّؤَاسِىُّ', #12
u'الرؤاسي،': u'الرُّؤَاسِيُّ،', #16
u'الرؤاسي،': u'الرؤاسي،', #2
u'الرؤاسي،': u'الرُّؤَاسِيِّ،', #2
u'الرؤاسى': u'الرُّؤَّاسِىُّ', #2
u'الرؤاسي': u'الرؤاسي', #3
u'الرؤاسي': u'الرُّؤَاسِيِّ', #3
u'الرواسين': u'الرواسين', #1
u'الرواسين': u'الرَّوَّاسِينَ', #1
u'الرواشن': u'الرَّوَاشِنِ', #8
u'الرواع': u'الرّوَاعُ', #1
u'الروايم': u'الرّوَايِمَ', #1
u'الروايم': u'الرّوَايِمُ', #1
u'الروباص': u'الرُّوبَاصِ', #2
u'الروباص': u'الروباص', #4
u'الروباض': u'الرُّوبَاضِ', #1
u'الروتيلا': u'الرُّوتِيلَا', #1
u'الروثة': u'الرَّوْثَةُ', #1
u'الروثة': u'الرَّوْثَة', #3
u'الروثة': u'الرَّوْثَةَ', #38
u'الروثة': u'الرَّوْثَةِ', #7
u'الروحاء': u'الروحاء', #1
u'الروحاء،': u'الرَّوْحاء،', #1
u'الروحاء': u'الرَّوْحَاء', #1
u'الروحاء،': u'الرَّوْحَاءَ،', #1
u'الروحاء،': u'الرَّوْحَاءِ،', #2
u'الروحاء': u'الرّوْحَاءِ', #22
u'الروحاء': u'الرَّوْحَاءُ', #4
u'الروحاء': u'الرَّوْحَاءِ', #48
u'الروحاء': u'الرّوْحَاءَ', #6
u'الروحاء': u'الرَّوْحَاءَ', #7
u'الروذ،': u'الرُّوذِ،', #3
u'الروذ': u'الرُّوذِ', #5
u'الروذباري': u'الرُّوذَبَارِيّ', #1
u'الروذباري': u'الرُّوذَبَارِيِّ', #1
u'الروذباري': u'الرُّوذْبَارِيُّ', #1
u'الروذباري،': u'الرُّوذَبَارِيُّ،', #1
u'الروذباري،': u'الرُّوذْبَارِيُّ،', #1
u'الروذبارى': u'الرُّوذْبَارىُّ', #1
u'الروذبارى': u'الرُّوذْبَارِىُّ', #1640
u'الروذباري': u'الرُّوذَبَارِيُّ', #2
u'الروذبارى': u'الرُّوذَبَارِىُّ', #2
u'الروذبارى': u'الرُّوذْبَارِىِّ', #20
u'الروذبارى': u'الرُّوذْبَارَىُّ', #6
u'الروذي،': u'الرُّوذِيُّ،', #1
u'الروزقي،': u'الرَّوْزَقِيُّ،', #1
u'الروزنة': u'الرَّوْزَنَةُ', #1
u'الروزنة': u'الرَّوْزَنَةِ', #2
u'الروشن': u'الرَّوْشَنَ', #10
u'الروشن': u'الرَّوْشَنُ', #22
u'الروشن': u'الرَّوْشَنِ', #32
u'الروعات': u'الرَّوْعَاتِ', #2
u'الرومSإسلام': u'الرّومِSإسْلَامُ', #1
u'الرومللي': u'الرومللي', #3
u'الرومى': u'الرُّوْمِىُّ', #1
u'الرومى': u'الرُّومِىُّ', #3
u'الرومى': u'الرُّومِىِّ', #4
u'الرؤووس': u'الرّؤُووسِ', #1
u'الروى': u'الرّوَى', #1
u'الرويا': u'الرّوَيَا', #1
u'الروياني': u'الرُويَانِيّ', #1
u'الروياني': u'الرُّويَانِيُّ', #1437
u'الرويانى': u'الرُّويَانِىُّ', #4
u'الروياني': u'الرُّويَانِيَّ', #43
u'الروياني': u'الرُّويَانِيِّ', #575
u'الروياني': u'الرُّويَانِيّ', #9
u'الرؤيائي': u'الرُّؤْيَائِيِّ', #1
u'الرويبضة': u'الرُّوَيْبِضَة', #1
u'الرويبضة': u'الرُّوَيْبِضَةُ', #12
u'الرويبضة': u'الرُّوَيْبِضَةِ', #3
u'الرويثة': u'الرويثة', #1
u'الرويثة': u'الرّوَيْثَةِ', #1
u'الرويثة': u'الرُّوَيْثَة', #1
u'الرويثة': u'الرُّوَيْثَةِ', #4
u'الرويجل': u'الرُّوَيْجِلِ', #1
u'الرويجل': u'الرُّوَيْجِلُ', #2
u'الرويحة': u'الرُّوَيْحَةُ', #1
u'الرويحة؟': u'الرُّوَيْحَةُ؟', #1
u'الرى': u'الرِّىَّ', #2
u'الرئبال': u'الرِّئْبَالَ', #1
u'الرئم': u'الرِّئْمِ', #1
u'الرئمان': u'الرّئْمَانُ', #1
u'الريا': u'الرَّيَّا', #1
u'الريا': u'الرِّيَا', #2
u'الرياب': u'الرياب', #1
u'الرياحي،': u'الرِّياحيّ،', #1
u'الرياحي': u'الرَّيَاحِيَّ', #1
u'الرياحي،': u'الرَّيَاحِيَّ،', #1
u'الرياحى': u'الرِّيَاحَىِّ', #1
u'الرياحى': u'الرِّيَاحِىَّ', #1
u'الرياحي': u'الرِّيَاحِيِّ', #12
u'الرياحي،': u'الرِّيَاحِيَّ،', #2
u'الرياحي': u'الرياحي', #3
u'الرياحى': u'الرَّيَاحِىُّ', #3
u'الرياحى': u'الرِّيَاحِىُّ', #6
u'الرياحي': u'الرِّيَاحِيُّ', #8
u'الرياحي،': u'الرِّيَاحِيُّ،', #8
u'الرياسات': u'الرِّيَاسَاتِ', #1
u'الرياشى': u'الرَّيَاشِىِّ', #1
u'الرياشى': u'الرِّيَاشِىُّ', #1
u'الرياط': u'الرِّيَاطَ', #1
u'الريالات': u'الرِّيَالَاتِ', #18
u'الريالات': u'الرِّيَالَاتُ', #4
u'الريالين': u'الرِّيَالَيْنِ', #1
u'الريباس': u'الرِّيبَاسَ', #1
u'الريباس': u'الرِّيبَاسِ', #2
u'الريبع': u'الريبع', #1
u'الريبع': u'الرِّيبِعِ', #1
u'الرية': u'الرَّيَّةَ', #1
u'الريس': u'الرَّيسُ', #1
u'الريس': u'الرَّيِّسُ', #1
u'الريس': u'الرّيْس', #1
u'الريس': u'الرّيّسُ', #2
u'الريسين': u'الرَّيِّسَيْنِ', #1
u'الريطة': u'الريطة', #1
u'الريطة': u'الرَّيْطَةِ', #1
u'الريطة': u'الرَّيْطَة', #2
u'الريطة': u'الرَّيْطَةَ', #2
u'الريطة': u'الرَّيْطَةُ', #8
u'الريطتين': u'الرَّيْطَتَيْنِ', #1
u'الريطتين،': u'الرَّيْطَتَيْنِ،', #1
u'الريه': u'الرِّيَهْ', #1
u'الريوب': u'الرُّيُوبِ', #1
u'الزاء': u'الزَّاءِ', #2
u'الزاب': u'الزَّابُ', #1
u'الزاب': u'الزَّابِّ', #1
u'الزاجري': u'الزّاجِرِي', #1
u'الزارة،': u'الزارة،', #1
u'الزارة': u'الزَّارَةَ', #1
u'الزارة': u'الزَّارَةِ', #6
u'الزاز': u'الزَّاز', #1
u'الزاز': u'الزَّازَ', #2
u'الزاز': u'الزَّازِ', #24
u'الزاز': u'الزَّازُ', #27
u'الزازان': u'الزَّازَانِ', #1
u'الزازي': u'الزازي', #1
u'الزاغوني': u'الزَّاغُونِيُّ', #13
u'الزاغوني': u'الزاغوني', #27
u'الزاغوني': u'الزَّاغُونِيِّ', #355
u'الزال': u'الزَّالُّ', #1
u'الزالة': u'الزَّالَّةِ', #1
u'الزالق': u'الزَّالِقُ', #1
u'الزالق': u'الزَّالِقَ', #2
u'الزالق': u'الزَّالِقِ', #4
u'الزالين': u'الزَّالِّينَ', #1
u'الزان': u'الزَّانِ', #1
u'الزانى': u'الزانى', #1
u'الزانى': u'الزَّانِىَ', #2
u'الزانى': u'الزَّانِى', #35
u'الزاهدي': u'الزَّاهْدِيِّ', #1
u'الزاهدى': u'الزَّاهِدِىُّ', #1
u'الزاهدي': u'الزَّاهِدِي', #11
u'الزاهدي': u'الزَّاهِدِيُّ', #143
u'الزاهدي': u'الزَّاهِدِيِّ', #387
u'الزاهدي': u'الزَّاهِدَيَّ', #4
u'الزاهدي': u'الزَّاهِدِيَّ', #7
u'الزاهرى': u'الزَّاهِرِىُّ', #1
u'الزاهرية،': u'الزَّاهرية،', #1
u'الزاهرية': u'الزَّاهِرِيَّةَ', #1
u'الزاهرية': u'الزَّاهْرَيَّةِ', #1
u'الزاهرية،': u'الزَّاهِرِيَّةَ،', #1
u'الزاهرية،': u'الزَّاهْرِيّة،', #1
u'الزاهرية،': u'الزَّاهِرِيَّةِ،', #13
u'الزاهرية،': u'الزاهرية،', #3
u'الزاهرية': u'الزَّاهِرِيَّةِ', #41
u'الزاهرية': u'الزاهرية', #6
u'الزاويا': u'الزَّاوِيَا', #1
u'الزائي': u'الزّائِيّ', #1
u'الزائية': u'الزّائِيّةُ', #1
u'الزباء': u'الزّبّاءَ', #1
u'الزباء': u'الزّبّاءِ', #2
u'الزباء': u'الزَّبَّاءِ', #2
u'الزباء': u'الزَّبَّاءُ', #3
u'الزبادان': u'الزَّبَادَانِ', #2
u'الزبادة': u'الزَّبَادَةِ', #1
u'الزبدا': u'الزّبَدا', #1
u'الزبدا': u'الزَّبَدَا', #1
u'الزبدا': u'الزّبَدَا', #2
u'الزبداني': u'الزبداني', #2
u'الزبداني': u'الزَّبَدَانِيِّ', #2
u'الزبرة': u'الزَّبْرَةَ', #1
u'الزبرة': u'الزُّبْرَةَ', #2
u'الزبرة': u'الزُّبْرَةُ', #3
u'الزبرة': u'الزُّبْرَةِ', #3
u'الزبرقان': u'الزِّبْرقان', #1
u'الزبرقان': u'الزِّبْرِقان', #1
u'الزبرقان': u'الزِّبْرِقانُ', #1
u'الزبرقان،': u'الزِّبْرقَان،', #1
u'الزبرقان،': u'الزِّبْرِقَانَ،', #1
u'الزبرقان،': u'الزِّبْرِقَانُ،', #1
u'الزبرقان': u'الزّبْرِقَانُ', #11
u'الزبرقان': u'الزِّبْرِقَانَ', #12
u'الزبرقان': u'الزِّبْرِقَانُ', #14
u'الزبرقان': u'الزّبْرِقَانِ', #16
u'الزبرقان': u'الزبرقان', #2
u'الزبرقان،': u'الزِّبْرِقَانِ،', #43
u'الزبرقان': u'الزّبْرِقَانَ', #5
u'الزبرقان': u'الزِّبْرِقَانِ', #66
u'الزبريراني': u'الزبريراني', #1
u'الزبعري': u'الزِّبَعْرِي', #1
u'الزبعرى': u'الزّبْعَرَى', #1
u'الزبعرى،': u'الزِّبَعْرَى،', #1
u'الزبعرى': u'الزّبَعْرَى', #105
u'الزبعرى': u'الزِّبَعْرَى', #13
u'الزبيد': u'الزبيد', #1
u'الزبيد': u'الزُّبَيْدُ', #1
u'الزبيد': u'الزُّبَيْدِ', #1
u'الزبيدى': u'الزَّبِيدِىِّ', #1
u'الزبيدى': u'الزَّبَيْدِىُّ', #1
u'الزبيدى': u'الزُّبَيْدِىَّ', #1
u'الزبيدي': u'الزُّبَيْدِيَّ', #10
u'الزبيدي': u'الزبيدي', #11
u'الزبيدي': u'الزّبَيْدِيّ', #14
u'الزبيدي،': u'الزبيدي،', #3
u'الزبيدي': u'الزُّبَيْدِيّ', #3
u'الزبيدي،': u'الزُّبَيْدِيِّ،', #35
u'الزبيدي': u'الزَّبِيدِيُّ', #4
u'الزبيدي،': u'الزُّبَيْدِيُّ،', #40
u'الزبيدى': u'الزُّبَيْدِىُّ', #44
u'الزبيدى': u'الزُّبَيْدِىِّ', #45
u'الزبيدي': u'الزَّبِيدِيِّ', #6
u'الزبيدي': u'الزُّبَيْدِيِّ', #69
u'الزبيدي': u'الزُّبَيْدِيُّ', #77
u'الزبيديين': u'الزُّبَيْدِيِّينَ', #1
u'الزبيرإن': u'الزُّبَيْرِإِنَّ', #2
u'الزبيرأنه': u'الزُّبَيْرِأَنَّهُ', #1
u'الزبيرفى': u'الزُّبَيْرِفِى', #1
u'الزبيرى': u'الزُّبَيْرِىَّ', #1
u'الزبيرى': u'الزُّبَيْرِىُّ', #75
u'الزبيرى': u'الزُّبَيْرِىِّ', #9
u'الزبيقي': u'الزَّبْيَقِيِّ', #1
u'الزبيل': u'الزَّبِيلُ', #1
u'الزبيل': u'الزَّبِيلِ', #1
u'الزبيلي': u'الزَّبِيلَيْ', #1
u'الزبيلي': u'الزَّبِيلِيِّ', #24
u'الزبيلي': u'الزَّبِيلِيُّ', #27
u'الزبيلي': u'الزَّبِيلِيَّ', #3
u'الزبين': u'الزّبَيْنِ', #1
u'الزجيج': u'الزُّجَيْجَ', #1
u'الزجيج': u'الزُّجَيْجُ', #1
u'الزخاريف': u'الزَّخَارِيفِ', #1
u'الزخيرة': u'الزَّخِيرَةِ', #1
u'الزراب': u'الزّرَابِ', #3
u'الزراتيتي': u'الزَّرَاتِيِتيِّ', #1
u'الزراتيتي': u'الزَّرَاتِيتِيِّ', #2
u'الزراتيني': u'الزراتيني', #1
u'الزراجين': u'الزَّرَاجِينُ', #1
u'الزراجين': u'الزَّرَاجِينِ', #8
u'الزراد': u'الزَّرَّادَ', #1
u'الزراد': u'الزَّرَّادُ', #2
u'الزراد،': u'الزَّرَّادُ،', #2
u'الزراد': u'الزَّرَّادِ', #4
u'الزراد،': u'الزَّرَّادِ،', #4
u'الزراريع': u'الزَّرَارِيعَ', #2
u'الزراريع': u'الزَّرَارِيعُ', #2
u'الزراريع': u'الزَّرَارِيعِ', #4
u'الزراق،': u'الزراق،', #1
u'الزراقة': u'الزَّرَّاقَةُ', #1
u'الزراقة': u'الزَّرَّاقَةِ', #5
u'الزرانيق': u'الزرانيق', #2
u'الزرايتي': u'الزَّرَايَتِيِّ', #1
u'الزرباني': u'الزرباني', #1
u'الزربخري': u'الزربخري', #1
u'الزربور': u'الزُّرْبُورِ', #1
u'الزربول': u'الزُّرْبُولُ', #1
u'الزربول': u'الزُّرْبُولِ', #3
u'الزرة': u'الزِّرَةَ', #1
u'الزرة': u'الزِّرَةُ', #1
u'الزرجون': u'الزَّرَجُونُ', #1
u'الزرجون': u'الزَّرْجُونِ', #7
u'الزردة': u'الزَّرْدَةِ', #1
u'الزردج': u'الزَّرْدَجِ', #8
u'الزرفي': u'الزّرَفِيّ', #1
u'الزرقا': u'الزُّرْقَا', #1
u'الزرقا،': u'الزَّرْقَا،', #1
u'الزرقاني': u'الزَّرْقَانِيِّ', #153
u'الزرقاني': u'الزَّرْقَانِيَّ', #16
u'الزرقاني': u'الزَّرْقَانِيُّ', #215
u'الزرقى': u'الزُّرَقِىِّ', #32
u'الزرقى': u'الزُّرَقِىُّ', #6
u'الزرقى': u'الزُّرَقِىَّ', #7
u'الزرموجة': u'الزُّرْمُوجَةُ', #1
u'الزرموزة': u'الزُّرْمُوزَةُ', #1
u'الزرموزة': u'الزُّرْمُوزَةِ', #3
u'الزرنب': u'الزرنب', #1
u'الزرنجري': u'الزرنجري', #1
u'الزرنجري': u'الزَّرَنْجَرِيِّ', #2
u'الزرنجري': u'الزَّرَنْجَرِيُّ', #5
u'الزرنوجي': u'الزَّرْنُوجِيُّ', #1
u'الزرنوجي': u'الزَّرْنُوجِيِّ', #1
u'الزرنوق': u'الزرنوق', #2
u'الزرور': u'الزُّرُورِ', #1
u'الزروعات': u'الزُّرُوعَاتِ', #2
u'الزريراني': u'الزَّرِيرَانِيُّ', #1
u'الزريراني': u'الزَّرِيرَانِيِّ', #4
u'الزريرانية': u'الزِّرْيَرانِيَّةِ', #3
u'الزريزاني': u'الزَّرَيْزَانِيِّ', #1
u'الزريون': u'الزَّرْيُونُ', #1
u'الزط': u'الزُّطَّ', #1
u'الزط': u'الزُّطُّ', #1
u'الزط،': u'الزُّطُّ،', #1
u'الزط': u'الزُّطِّ', #6
u'الزطي': u'الزُّطِّيَ', #1
u'الزطي': u'الزُّطِّيَّ', #2
u'الزطي': u'الزُّطِّيُّ', #2
u'الزطي': u'الزُّطِّيِّ', #9
u'الزطية': u'الزُّطِّيَّةَ', #1
u'الزطية': u'الزُّطِّيَّةِ', #1
u'الزطية': u'الزُّطِّيَّةُ', #3
u'الزعارة': u'الزِّعَارَةُ', #1
u'الزعازيع': u'الزَّعَازِيعِ', #1
u'الزعافرى': u'الزَّعَافِرِىُّ', #1
u'الزعافرى': u'الزَّعَافِرِىِّ', #2
u'الزعافري': u'الزَّعَافِرِيُّ', #3
u'الزعبري': u'الزِّعْبَرِي', #1
u'الزعبي': u'الزَّعْبِيِّ', #1
u'الزعفرانى': u'الزَّعْفَرَانِىِّ', #16
u'الزعفرانى': u'الزَّعْفَرَانِىُّ', #214
u'الزعقوق': u'الزُّعْقُوقُ', #3
u'الزعقوق': u'الزُّعْقُوقَ', #5
u'الزعور': u'الزُّعُورِ', #1
u'الزعيزعة': u'الزُّعَيْزِعَةِ', #1
u'الزغابة': u'الزّغَابَةَ', #1
u'الزغابة': u'الزّغَابَةِ', #1
u'الزغاريت': u'الزَّغَارِيتُ', #3
u'الزغبر': u'الزّغْبُرُ', #1
u'الزغد': u'الزّغْدَ', #1
u'الزغرتة،': u'الزِّغْرِتَةُ،', #1
u'الزغروتة': u'الزَّغْرُوتَةِ', #1
u'الزغرية،': u'الزَّغْرِيَّةُ،', #1
u'الزغريت': u'الزَّغْرِيتِ', #1
u'الزغل': u'الزَّغَلِ', #3
u'الزغياء': u'الزّغْيَاءِ', #1
u'الزفاتين': u'الزَّفَّاتِينَ', #1
u'الزفف': u'الزَّفَفِ', #2
u'الزفن': u'الزّفْنَ', #1
u'الزفن': u'الزّفْنِ', #1
u'الزفن': u'الزَّفْنُ', #1
u'الزفيزف': u'الزفيزف', #1
u'الزقيقات': u'الزُّقَيْقَاتِ', #1
u'الزقيقات': u'الزُّقَيْقَاتُ', #2
u'الزقيقة': u'الزُّقَيْقَةِ', #1
u'الزقيقتين': u'الزَّقِيقَتَيْنِ', #1
u'الزكاتي': u'الزَّكَاتِيَّ', #1
u'الزكاوات': u'الزكاوات', #1
u'الزكائية': u'الزَّكَائِيَّةِ', #1
u'الزكمة،': u'الزُّكْمَةِ،', #1
u'الزكمة': u'الزُّكْمَةَ', #2
u'الزكى': u'الزَّكِىُّ', #3
u'الزلاء': u'الزَّلَّاءُ', #2
u'الزلالا': u'الزُّلَالَا', #1
u'الزلاني': u'الزَّلَّانِيُّ', #1
u'الزلخة': u'الزّلَخَةُ', #1
u'الزلزل': u'الزُّلْزُلُ', #1
u'الزلط': u'الزَّلَطَ', #1
u'الزلط': u'الزَّلَطُ', #2
u'الزلوق': u'الزَّلُوقُ', #1
u'الزليق': u'الزّلِيق', #1
u'الزليق': u'الزّلِيقُ', #1
u'الزليق': u'الزّلِيقِ', #1
u'الزمانى': u'الزِّمَّانِىَّ', #1
u'الزمانى': u'الزِّمَّانِىُّ', #1
u'الزمانى': u'الزِّمَّانِىِّ', #7
u'الزماورد': u'الزماورد', #1
u'الزماورد': u'الزَّمَاوَرْدَ', #1
u'ألزمتهموه': u'أَلْزَمَتْهُمُوهُ', #1
u'الزمخشري': u'الزَّمَخْشَرِيّ', #120
u'الزمخشري': u'الزَّمَخْشَرِيُّ', #204
u'الزمخشري': u'الزَّمَخْشَرِي', #5
u'الزمخشري': u'الزَّمَخْشَرِيُ', #5
u'الزمخشري': u'الزَّمَخْشَرِيِّ', #70
u'الزمخشري': u'الزَّمَخْشَرِيَّ', #9
u'الزمعي': u'الزّمَعِيّ', #1
u'الزمعي': u'الزَّمَعِيُّ', #1
u'الزمعي': u'الزَّمْعِيِّ', #1
u'الزمعي،': u'الزَّمْعِيِّ،', #1
u'الزمعى': u'الزَّمَعِىُّ', #1
u'الزمعي،': u'الزَّمْعِيُّ،', #4
u'الزمعى': u'الزَّمْعِىُّ', #6
u'الزمعي': u'الزَّمْعِيُّ', #8
u'الزمق': u'الزمق', #1
u'الزملق': u'الزُّمَّلِقُ', #1
u'الزملكاني': u'الزَّمْلَكَانِيِّ', #17
u'الزملكاني': u'الزَّمْلَكَانِيُّ', #4
u'الزمناء': u'الزُّمَنَاءُ', #1
u'الزمناء': u'الزُّمَنَاءِ', #1
u'الزمناء': u'الزُّمَنَاءَ', #2
u'الزمنة': u'الزَّمِنَةَ', #1
u'الزمنة': u'الزَّمِنَةُ', #3
u'الزمنة': u'الزَّمِنَةِ', #3
u'الزمنى': u'الزّمْنَى', #1
u'الزمنى': u'الزَّمْنَى', #50
u'الزمهرانى': u'الزَّمْهَرَانِىُّ', #1
u'الزمى': u'الزِّمِّىُّ', #1
u'الزمى': u'الزَّمِّىُّ', #2
u'الزمين': u'الزَّمِينِ', #1
u'الزنء': u'الزَّنْءَ', #3
u'الزنابا': u'الزّنَابَا', #2
u'الزناتي': u'الزَّنَاتِيَّ', #1
u'الزناتي': u'الزَّنَاتِيُّ', #31
u'الزناتي': u'الزَّنَاتِيِّ', #9
u'الزناق': u'الزَّنَّاقُ', #1
u'الزنباع': u'الزنباع', #1
u'الزنباع،': u'الزِّنْبَاعِ،', #11
u'الزنباع': u'الزِّنْبَاعِ', #15
u'الزنبري': u'الزَّنْبَرِيُّ', #1
u'الزنبرى': u'الزَّنْبَرِىِّ', #1
u'الزنجاني': u'الزَّنْجَانِيَّ', #1
u'الزنجاني': u'الزَّنْجَانِيُّ', #28
u'الزنجاني': u'الزنجاني', #3
u'الزنجاني': u'الزَّنْجَانِيّ', #3
u'الزنجاني': u'الزَّنْجَانِيِّ', #7
u'الزنجرلي': u'الزنجرلي', #1
u'الزنجرلي': u'الزِّنْجِرْلِي', #1
u'الزنجري': u'الزنجري', #1
u'الزنجفر': u'الزُّنْجُفْرِ', #1
u'الزنجى': u'الزِّنَجِىِّ', #1
u'الزنجى': u'الزَّنْجِىُّ', #12
u'الزنجى': u'الزِّنْجِىُّ', #2
u'الزنجى': u'الزَّنْجِىِّ', #5
u'الزنجير': u'الزِّنْجِيرِ', #1
u'الزندبيجي': u'الزَّنْدَبِيجِيِّ', #3
u'الزندنجي': u'الزَّنْدَنْجِيُّ', #1
u'الزندنيجي': u'الزَّنْدَنِيجِيَّ', #1
u'الزندنيجي': u'الزَّنْدَنِيجِيِّ', #1
u'الزندوستي': u'الزندوستي', #1
u'الزندوستي': u'الزَّنْدَوَسْتِيّ', #1
u'الزندوستي': u'الزَّنْدَوَسْتِيِّ', #21
u'الزندوستي': u'الزَّنْدَوَسْتِيُّ', #9
u'الزندوسني': u'الزَّنْدُوسَنِيِّ', #1
u'الزندوسي': u'الزَّنْدُوسِيُّ', #1
u'الزندوسي': u'الزَّنْدُوسِيِّ', #2
u'الزندويستي': u'الزندويستي', #14
u'الزندويسي': u'الزَّنْدَوِيسِيُّ', #1
u'الزندويسي': u'الزَّنْدَوِيسِيِّ', #1
u'الزنديجي': u'الزِّنْدِيجِيِّ', #2
u'الزنط': u'الزُّنْطَ', #2
u'الزنكلوني': u'الزَّنْكَلُونِيِّ', #4
u'الزنكلوني': u'الزَّنْكَلُونِيُّ', #9
u'الزنوط': u'الزُّنُوطِ', #4
u'الزنيات': u'الزَّنَيَاتُ', #1
u'الزنيات': u'الزَّنْيَاتِ', #1
u'الزنيات': u'الزِّنْيَاتُ', #1
u'الزنيات': u'الزَّنَيَاتِ', #2
u'الزنيات': u'الزِّنْيَاتِ', #3
u'الزنية': u'الزَّنْيَةُ', #1
u'الزنية': u'الزِّنْيَةِ', #4
u'الزنية': u'الزَّنْيَةِ', #7
u'الزنيتين': u'الزَّنْيَتَيْنِ', #1
u'الزنيرة،': u'الزِّنِّيرَةَ،', #1
u'الزنيم': u'الزنيم', #1
u'الزنيم؟،': u'الزنيم؟،', #1
u'الزنيم': u'الزّنِيمَ', #1
u'الزنيم': u'الزَّنِيمِ', #1
u'الزنيم،': u'الزَّنِيمِ،', #1
u'الزنيم؟': u'الزَّنِيمُ؟', #1
u'الزنيم': u'الزّنِيمُ', #2
u'الزنيم': u'الزَّنِيمُ', #2
u'الزنيم،': u'الزَّنِيمُ،', #2
u'الزنيين': u'الزَّنْيَيْنِ', #3
u'الزهاوة': u'الزَّهَاوَةِ', #2
u'الزهاوي،': u'الزَّهَاوِيِّ،', #1
u'الزهراني': u'الزهراني', #1
u'الزهرانى': u'الزَّهْرَانِىُّ', #102
u'الزهراني': u'الزَّهْرَانِيِّ', #15
u'الزهرانى': u'الزَّهْرَانِىِّ', #16
u'الزهراني،': u'الزَّهْرَانِيِّ،', #2
u'الزهراني،': u'الزهراني،', #3
u'الزهراني،': u'الزَّهْرَانِيُّ،', #34
u'الزهراني': u'الزَّهْرَانِيُّ', #51
u'الزهراني': u'الزَّهْرَانِيَّ', #6
u'الزهره': u'الزّهَرَهْ', #3
u'الزهري،': u'الزُّهْرِيًّ،', #1
u'الزهرى': u'الزُهْرِىِّ', #1
u'الزهرى': u'الزُّهْرِىِّ', #1954
u'الزهرى': u'الزهرى', #2
u'الزهرى': u'الزُّهْرِىُّ', #356
u'الزهرى': u'الزُّهْرِىَّ', #60
u'الزهريعن': u'الزُّهْرِيَّعَنْ', #1
u'الزهم': u'الزهم', #1
u'الزهم': u'الزُّهْم', #1
u'الزهمة': u'الزهمة', #1
u'الزهومة': u'الزُّهُومُةِ', #1
u'الزهومة': u'الزُّهُومَةَ', #13
u'الزهومة': u'الزُّهُومَةِ', #20
u'الزهومة': u'الزُّهُومَةُ', #4
u'الزهير': u'الزُّهَيْرِ', #2
u'الزهيرى': u'الزُّهَيْرِىُّ', #1
u'الزوابون': u'الزَّوَابُونَ', #1
u'الزوان': u'الزُّوَانِ', #1
u'الزوان': u'الزُّوَانُ', #2
u'الزواوي': u'الزَّوَاوِيَّ', #1
u'الزواوي': u'الزَّوَاوِيُّ', #15
u'الزواوي': u'الزَّوَاوِيِّ', #7
u'الزوجيه': u'الزَّوْجِيَّهْ', #2
u'الزوراء': u'الزوراء', #1
u'الزوراء': u'الزَّوْرَاءَ', #1
u'الزوراء': u'الزّوْرَاءُ', #2
u'الزوراء': u'الزَّوْرَاء', #2
u'الزوراء': u'الزَّوْرَاءُ', #2
u'الزوراء': u'الزَّوْرَاءِ', #35
u'الزوراي': u'الزُّورِايّ', #1
u'الزورة': u'الزّوْرَةِ', #1
u'الزوزنى': u'الزَّوْزَنِىُّ', #12
u'الزوزني': u'الزَّوْزَنِيُّ', #5
u'الزوعي': u'الزَّوْعِيُّ', #1
u'الزوعي': u'الزَّوْعِيِّ', #1
u'الزوفي': u'الزَّوْفِيّ', #1
u'الزوفي': u'الزَّوْفِيِّ', #1
u'الزوفي،': u'الزَّوْفِيِّ،', #2
u'الزوفى': u'الزَّوْفِىِّ', #2
u'الزوم': u'الزَّوْمِ', #1
u'الزياب،': u'الزَّيَّابِ،', #1
u'الزياتي': u'الزَّيَّاتِيُّ', #1
u'الزياد': u'الزَّيَّادِ', #1
u'الزياد': u'الزِّيَادُ', #1
u'الزياد': u'الزِّيَادِ', #3
u'الزياده': u'الزِّيَادَهْ', #1
u'الزيادى': u'الزِّيَادِىُّ', #5
u'الزيادى': u'الزِّيَادِىِّ', #7
u'الزيافة': u'الزِّيَافَةُ', #16
u'الزيافة': u'الزِّيَافَةَ', #18
u'الزيافة': u'الزِّيَافَةِ', #47
u'الزيال': u'الزّيّالُ', #1
u'الزيانب؟': u'الزَّيَانِبِ؟', #3
u'الزيانب': u'الزَّيَانِبِ', #7
u'الزيبق': u'الزّيبَقِ', #1
u'الزيبق': u'الزِّيْبَقُ', #1
u'الزيدان': u'الزّيْدَانِ', #1
u'الزيدان': u'الزَّيْدَان', #5
u'الزيدان': u'الزَّيْدَانِ', #7
u'الزيداني': u'الزَّيْدَانِيِّ', #2
u'الزيدون': u'الزَّيْدُونِ', #1
u'الزيدون': u'الزّيْدُون', #1
u'الزيدون': u'الزَّيْدُون', #2
u'الزيدون': u'الزَّيْدُونَ', #2
u'الزيدين': u'الزّيْدَيْنِ', #1
u'الزيدين': u'الزَّيْدِينَ', #3
u'الزيدين': u'الزَّيْدَيْنِ', #5
u'الزيرباج': u'الزِّيرَبَاجَ', #1
u'الزيرياج': u'الزيرياج', #1
u'الزيزاني': u'الزَّيْزَانِيِّ', #1
u'الزيغد': u'الزيغد', #1
u'الزيفة': u'الزَّيْفَةِ', #1
u'الزيقات': u'الزِّيقَاتُ', #3
u'الزيقة': u'الزِّيقَةِ', #2
u'الزيقة': u'الزِّيَقَةِ', #3
u'الزيقى': u'الزِّيقِىُّ', #2
u'الزيلعي': u'الزيلعي', #1
u'الزيلعي': u'الزَّيْلَعِيِّ', #1155
u'الزيلعي': u'الزَّيْلَعِيُّ', #2152
u'الزيلعي': u'الزَّيْلَعِيّ', #374
u'الزيلعي': u'الزَّيْلَعِيَّ', #88
u'الزينبى': u'الزَّيْنَبِىُّ', #1
u'الزيوفة': u'الزُّيُوفَةِ', #1
u'الس': u'الس', #1
u'ألس': u'أَلْسَ', #2
u'الساباط': u'السَّابَاطُ', #25
u'الساباط': u'السَّابَاطِ', #35
u'الساباط': u'السَّابَاطَ', #4
u'السابري،': u'السابري،', #1
u'السابري،': u'السَّابِرِيُّ،', #18
u'السابري': u'السَّابِرِيِّ', #4
u'السابري': u'السَّابِرِيُّ', #6
u'السابري،': u'السَّابِرِيِّ،', #6
u'السابرية': u'السّابِرِيّةُ', #1
u'السابرية': u'السَّابِرِيَّةِ', #2
u'السابعه': u'السَّابِعَهْ', #1
u'السابقتي': u'السَّابِقَتَيْ', #1
u'الساج': u'السَّاجَ', #1
u'الساج': u'السَّاجُ', #11
u'الساج': u'السَّاجِ', #29
u'الساجة': u'الساجة', #1
u'الساجة': u'السَّاجَة', #1
u'الساجة': u'السَّاجَةَ', #13
u'الساجة': u'السَّاجَةُ', #2
u'الساجة': u'السَّاجَةِ', #72
u'الساجى': u'السَّاجِىَّ', #2
u'الساجى': u'السَّاجِىِّ', #2
u'الساجى': u'السَّاجِىُّ', #26
u'الساحروالوجه': u'السَّاحِرُوَالْوَجْهُ', #1
u'السادا': u'السّادَا', #2
u'الساس': u'السَّاسِ', #1
u'الساسان': u'السَّاسَانِ', #2
u'السآسم': u'السَّآسِمُ', #1
u'الساسم': u'الساسم', #1
u'الساسم': u'السَّاسَمُ', #1
u'الساسم': u'السَّاسَمِ', #1
u'الساعةوالوجه': u'السَّاعَةِوَالْوَجْهُ', #1
u'الساعدى': u'السَّاعِدِىَّ', #19
u'الساعدى': u'السَّاعِدِىُّ', #20
u'الساعدى': u'السَّاعِدِىِّ', #76
u'الساعه': u'الساعه', #1
u'الساعى': u'السَّاعِىُ', #1
u'الساعى': u'السَّاعِى', #13
u'السافي': u'السّافِي', #1
u'السافي': u'السَّافِي', #1
u'الساقاة': u'السَّاقَاةِ', #1
u'الساقبة': u'السَّاقِبَة', #2
u'الساقى': u'السَّاقِى', #1
u'الساقياني': u'السَّاقِيَانِيُّ', #1
u'السالحانى': u'السَّالَحَانِىُّ', #1
u'السالحين': u'السَّالِحِينَ', #4
u'السالحيني': u'السَّالَحِينِيَّ', #1
u'السالحيني': u'السَّالَحِينِيِّ', #1
u'السالحينى': u'السَّالِحِينِىَّ', #1
u'السالحينى': u'السَّالِحِينِىِّ', #1
u'السالحيني': u'السَّالَحِينِيُّ', #2
u'السالحينى': u'السَّالِحِينِىُّ', #2
u'السالحينى': u'السَّالَحِينِىُّ', #3
u'السالحيني،': u'السَّالَحِينِيُّ،', #5
u'السالغ': u'السَّالِغُ', #1
u'السالفةSغزوة': u'السّالِفَةُSغَزْوَةُ', #1
u'السالمي': u'السالمي', #1
u'السالمي': u'السَّالِمِيُّ', #1
u'السالمي،': u'السَّالِمِيُّ،', #1
u'السالمي': u'السَّالِمِيِّ', #2
u'السالمي': u'السّالِمِيّ', #3
u'الساماني': u'الساماني', #1
u'الساماني': u'السَّامَانِيِّ', #1
u'السامرى': u'السَّامَرِّىُّ', #1
u'السامرى': u'السَّامِرِىُّ', #2
u'السامى': u'السَّامِىُّ', #11
u'الساهلية': u'السَّاهِلِيَّةِ', #1
u'السائبمولى': u'السَّائِبِمَوْلَى', #1
u'السائحاني': u'السائحاني', #1
u'السائحاني': u'السَّائِحَانِيُّ', #109
u'السائحاني': u'السَّائِحَانِيَّ', #2
u'السائحاني': u'السَّائِحَانِيِّ', #38
u'السائع': u'السَّائِعَ', #1
u'السائف': u'السَّائِفُ', #2
u'السائم': u'السَّائِمُ', #2
u'السائم': u'السَّائِمِ', #6
u'السايب،': u'السَّايبِ،', #2
u'السايب،': u'السَّايِبِ،', #6
u'السايحاني': u'السَّايَحَانِيِّ', #1
u'السبا': u'السّبَا', #1
u'السباء': u'السِّبَاءِ', #2
u'السباء': u'السّبَاءَ', #3
u'السباء': u'السِّبَاءَ', #4
u'السباء': u'السِّبَاءُ', #7
u'السبابا': u'السِّبَابَا', #1
u'السباط': u'السِّبَاطَ', #1
u'السباط': u'السِّبَاطُ', #1
u'السباطريين': u'السباطريين', #1
u'السباك،': u'السباك،', #1
u'السباك': u'السَّبَّاكُ', #4
u'السباك،': u'السَّبَّاكُ،', #4
u'السباكون': u'السَّبَّاكُونَ', #1
u'السبالان': u'السِّبَالَانِ', #3
u'السبالين': u'السَّبَّالِينَ', #1
u'السبالين': u'السَّبَّالَيْنِ', #1
u'السبالين': u'السِّبَالَيْنِ', #2
u'السباهي': u'السَّبَاهِيَّ', #1
u'السباهي': u'السَّبَاهِي', #2
u'السباهي': u'السَّبَاهِيُ', #3
u'السباهي': u'السَّبَاهِيُّ', #3
u'السباهي': u'السَّبَاهِيِّ', #4
u'السباهية': u'السَّبَاهِيَةِ', #1
u'السباهية': u'السَّبَاهِيَّةِ', #2
u'السبأي،': u'السّبأي،', #1
u'السبأي': u'السَّبَأِيِّ', #1
u'السبأي،': u'السَّبَأِيٍّ،', #1
u'السبإى': u'السَّبَإِىِّ', #1
u'السبائب': u'السّبَائِبُ', #1
u'السبائب': u'السَّبَائِبُ', #1
u'السبائب': u'السّبَائِبِ', #2
u'السبائي،': u'السبائي،', #1
u'السبائي،': u'السَبائي،', #1
u'السبائي': u'السَّبَائِيّ', #1
u'السبائي': u'السَّبَّائِيَّ', #1
u'السبائي،': u'السَّبَائِيِّ،', #1
u'السبائي': u'السَّبَّائِيِّ', #2
u'السبائي،': u'السَّبَائِيُّ،', #2
u'السبائى': u'السَّبَائِىُّ', #2
u'السبائي': u'السّبَائِيّ', #3
u'السبائي': u'السَّبَائِيُّ', #4
u'السبائى': u'السَّبَائِىِّ', #5
u'السبائي': u'السَّبَائِيِّ', #7
u'السبائية': u'السبائية', #1
u'السبائية': u'السَّبَائِيَّةُ', #1
u'السبائية،': u'السَّبَائِيَّةُ،', #1
u'السبتاني': u'السَّبْتَانِيُّ', #1
u'السبتي': u'السَّبْتِي', #1
u'السبتي': u'السَّبْتِيَّ', #1
u'السبتي': u'السِّبْتِيُّ', #1
u'السبتي': u'السِّبْتِيِّ', #1
u'السبتي': u'السِّبْتِيَّ', #2
u'السبتي': u'السَّبْتِيِّ', #3
u'السبتي': u'السَّبْتِيُّ', #5
u'السبتية': u'السبتية', #1
u'السبتية': u'السَّبْتِيَّةَ', #1
u'السبتية': u'السَّبْتِيَّةِ', #1
u'السبتية': u'السِّبْتِيَّةُ', #10
u'السبتية': u'السِّبْتِيَّة', #2
u'السبتية': u'السِّبْتِيَّةِ', #3
u'السبتية': u'السِّبْتِيَّةَ', #30
u'السبتية،': u'السِّبْتِيَّةَ،', #4
u'السبتيتين': u'السَّبْتِيَّتَيْنِ', #1
u'السبتيتين': u'السِّبْتِيَّتَيْنِ', #16
u'السبحانية': u'السُّبْحَانِيَّةِ', #1
u'السبخى': u'السَّبَخِىُّ', #1
u'السبخى': u'السَّبَخِىِّ', #1
u'السبد': u'السَّبَدِ', #1
u'السبرات': u'السَّبَرَاتِ', #2
u'السبطا': u'السِّبْطَا', #1
u'السبعات': u'السَّبْعَاتُ', #1
u'السبعات': u'السَّبْعَاتِ', #6
u'السبعاوية': u'السَّبْعَاوِيَّةُ', #1
u'السبعتين': u'السَّبْعَتَيْنِ', #1
u'السبعه': u'السَّبْعَهْ', #1
u'السبعى': u'السَّبْعِىِّ', #1
u'السبعى': u'السَّبْعِىُّ', #3
u'السبعى': u'السُّبْعِىُّ', #5
u'السبغة': u'السَّبْغَةَ', #1
u'السبكين': u'السَّبْكَيْنِ', #1
u'السبلان': u'السَّبَلَانِ', #1
u'السبلان': u'السُّبْلَانُ', #1
u'السبلين': u'السَّبَلَيْنِ', #1
u'السبني': u'السَّبَنِيَّ', #2
u'السبنية': u'السّبَنِيّةُ', #1
u'السبنية': u'السَّبَنِيَّةِ', #2
u'السبوح': u'السُّبُوحِ', #1
u'السبوح': u'السُّبُّوحُ', #1
u'السبوحية': u'السُّبُّوحِيَّةِ', #2
u'السبور': u'السَّبُورُ', #1
u'السبوطة': u'السُّبُوطَةَ', #1
u'السبوطة': u'السُّبُوطَةِ', #2
u'السبوطة': u'السبوطة', #3
u'السبوعين': u'السُّبُوعَيْنِ', #1
u'السبى': u'السَّبْىِ', #18
u'السبى': u'السَّبْىُ', #2
u'السبى': u'السَّبْىَ', #4
u'السبىء': u'السَّبِىءُ', #1
u'السبئى': u'السَّبَئِىُّ', #2
u'السبئى': u'السَّبَئِىِّ', #2
u'السبيبة': u'السَّبِيبَةُ', #1
u'السبيع': u'السَّبِيعِ', #2
u'السبيعي،': u'السبيعيّ،', #1
u'السبيعي،': u'السّبيعيّ،', #1
u'السبيعي،': u'السَّبيعيُّ،', #1
u'السبيعي': u'السّبيْعيُّ', #1
u'السبيعي': u'السَّبِيعيُّ', #1
u'السبيعي،': u'السَّبِيعيُّ،', #1
u'السبيعي،': u'السَّبَيْعي،', #1
u'السبيعي': u'السُّبَيْعِيّ', #1
u'السبيعي': u'السُّبَيْعِيَّ', #1
u'السبيعي': u'السُّبَيْعِيِّ', #1
u'السبيعي،': u'السُّبَيْعِيُّ،', #1
u'السبيعى': u'السَّبِيعِىَّ', #1
u'السبيعى': u'السَّبِيعِىُّ', #11
u'السبيعى': u'السَّبِيعِىِّ', #11
u'السبيعي،': u'السبيعي،', #17
u'السبيعي،': u'السَّبيعيّ،', #2
u'السبيعي،': u'السَّبِيعِيَّ،', #2
u'السبيعي': u'السَّبِيعِيِّ', #21
u'السبيعي': u'السَّبِيعِيُّ', #25
u'السبيعي': u'السّبِيعِيّ', #3
u'السبيعي': u'السَّبِيعِيَّ', #3
u'السبيعي': u'السبيعي', #5
u'السبيعي،': u'السَّبِيعِيُّ،', #55
u'السبيعي،': u'السَّبِيعِيِّ،', #9
u'السبيلا': u'السَّبِيلا', #1
u'السبيلا': u'السَّبِيلَا', #2
u'السترةبالخط': u'السُّتْرَةُبِالْخَطِّ', #1
u'الستره': u'السُّتْرَهْ', #1
u'السته': u'السَّتَهِ', #2
u'السته': u'السِّتَّهْ', #2
u'الستوق': u'السَّتُّوقِ', #12
u'الستوق': u'السَّتُّوقُ', #4
u'الستوق': u'السَّتُّوقَ', #8
u'الستوقة': u'السَّتُّوقَةُ', #18
u'الستوقة': u'السَّتُّوقَةَ', #20
u'الستوقة': u'السَّتُّوقَةِ', #37
u'الستير': u'السِّتِّيرَ', #2
u'الستيرين': u'السِّتِّيرِينَ', #1
u'الستينا': u'السِّتِّينَا', #1
u'الستينين': u'السِّتِّينَيْنِ', #3
u'السجاج': u'السّجَاجِ', #1
u'السجاعي': u'السِّجَاعِيَّ', #1
u'السجاعي': u'السِّجَاعِيُّ', #2
u'السجاعي': u'السِّجَاعِيِّ', #2
u'السجاوندي': u'السَّجَاوَنْدِيِّ', #4
u'السجح': u'السَّجْحِ', #1
u'السجده': u'السَّجْدَهْ', #2
u'السجزي': u'السِّجْزِيَّ', #1
u'السجزي،': u'السِّجْزِيَّ،', #1
u'السجزى': u'السجزى', #1
u'السجزى': u'السَّجَزِىُّ', #1
u'السجزى': u'السِّجْزِىُّ', #13
u'السجزي،': u'السجزي،', #2
u'السجزي': u'السِّجْزِيُّ', #23
u'السجزي،': u'السِّجْزِيُّ،', #247
u'السجزي': u'السِّجْزِيِّ', #5
u'السجزى': u'السَّجْزِىُّ', #5
u'السجزي،': u'السِّجْزِيِّ،', #55
u'السجستاني،': u'السجستاني،', #1
u'السجستاني': u'السِّجِّسْتَانِيّ', #1
u'السجستانى': u'السِّجَسْتَانِىُّ', #1
u'السجستاني،': u'السِّجِسْتَانِيِّ،', #18
u'السجستانى': u'السَّجِسْتَانِىُّ', #2
u'السجستانى': u'السِّجْسْتَانِىُّ', #2
u'السجستاني': u'السِّجِسْتَانِيُّ', #21
u'السجستاني': u'السِّجِسْتَانِيّ', #3
u'السجستاني': u'السِّجِسْتَانِيِّ', #4
u'السجستانى': u'السِّجِسْتَانِىُّ', #68
u'السجستاني،': u'السِّجِسْتَانِيُّ،', #73
u'السجيني': u'السَّجِينِي', #1
u'السجيني': u'السِّجِّينِيٌّ', #1
u'السجيني': u'السِّجِّينِيِّ', #1
u'السجيني': u'السِّجِّينِيُّ', #3
u'السحابا': u'السّحَابَا', #3
u'السحابات': u'السَّحَابَاتُ', #1
u'السحاتيت': u'السَّحَاتِيتِ', #3
u'السحامي': u'السُّحَامِيُّ', #1
u'السحف': u'السَّحْفِ', #1
u'السحل': u'السّحْلِ', #1
u'السحل': u'السَّحْلِ', #1
u'السحل': u'السُّحَّل', #1
u'السحل': u'السّحْلُ', #2
u'السحل': u'السَّحْلُ', #3
u'السحلية': u'السِّحْلِيَّةِ', #1
u'السحلية': u'السِّحْلِيَّةُ', #2
u'السحول': u'السُّحُولَ', #1
u'السحول': u'السُّحُولُ', #1
u'السحول': u'السَّحُولِ', #6
u'السحولية': u'السحولية', #2
u'السحولية': u'السَّحُولِيَّةُ', #2
u'السحيح': u'السَحِيحْ', #1
u'السحيمي': u'السُّحَيْمِيِّ', #1
u'السحيمي،': u'السُّحَيْمِيَّ،', #1
u'السحيمى': u'السُّحَيْمِىُّ', #1
u'السحيمي': u'السُّحَيْمِيُّ', #10
u'السحيمي،': u'السُّحَيْمِيِّ،', #2
u'السحيمى': u'السُّحَيْمِىِّ', #2
u'السحيمي،': u'السُّحَيْمِيُّ،', #3
u'السحيمية': u'السّحَيْمِيّةُ', #1
u'السحين': u'السُّحَيْنُ', #1
u'السخا': u'السَّخَا', #1
u'السخاب': u'السِّخَابَ', #1
u'السخاب': u'السخاب', #2
u'السخال': u'السُّخَالُ', #1
u'السخال': u'السِّخَالِ', #17
u'السخال': u'السِّخَالَ', #4
u'السخال': u'السِّخَالُ', #9
u'السخاوندي': u'السَّخَاوَنْدِيِّ', #1
u'السخاوي،': u'السَّخَاوِيُّ،', #1
u'السخاوي': u'السَّخَاوِيِّ', #12
u'السخاوي': u'السَّخَاوِيَّ', #3
u'السخاوي': u'السَّخَاوِيُّ', #44
u'السخاوي': u'السَّخَاوِيّ', #5
u'السخائم': u'السَّخَائِمُ', #1
u'السخب': u'السَّخَب', #1
u'السخب': u'السَّخَبِ', #2
u'السختيان': u'السِّخْتِيَانُ', #2
u'السختيان': u'السِّخْتِيَانِ', #5
u'السختياني،': u'السختياني،', #1
u'السختياني': u'السّخْتِيَانِيّ', #1
u'السختياني': u'السِّخْتِيَانِيّ', #1
u'السختياني': u'السِّخْتِيَانِّيُّ', #1
u'السختياني،': u'السِّخْتِيَانِيِّ،', #1
u'السختيانى': u'الْسَّخْتَيَانِىُّ', #1
u'السختياني': u'السِّخْتِيَانِيُّ', #100
u'السختياني': u'السَّخْتِيَانِيِّ', #15
u'السختياني': u'السِّخْتِيَانِيِّ', #15
u'السختياني،': u'السَّخْتِيَانِيِّ،', #16
u'السختياني': u'السَّخْتِيَانِيَّ', #2
u'السختياني،': u'السَّخْتِيَانِيَّ،', #2
u'السختياني،': u'السَّخْتِيَانِيُّ،', #29
u'السختياني،': u'السِّخْتِيَانِيُّ،', #3
u'السختيانى': u'السَّخْتِيَانِىَّ', #3
u'السختيانى': u'السَّخْتِيَانِىُّ', #31
u'السختيانى': u'السَّخْتِيَانِىِّ', #67
u'السختياني': u'السَّخْتِيَانِيُّ', #7
u'السخل': u'السَّخْلَ', #4
u'السخل': u'السَّخْلِ', #4
u'السخل': u'السَّخْلُ', #5
u'السخلة': u'السِّخْلَةُ', #1
u'السخلة': u'السَّخْلَةَ', #19
u'السخلة': u'السَّخْلَةُ', #37
u'السخلة': u'السَّخْلَةِ', #71
u'السخيمة': u'السَّخِيمَةَ', #3
u'السدا': u'السَّدَا', #4
u'السداء': u'السَّدَاءَ', #2
u'السداء': u'السَّدَاءِ', #2
u'السدارين': u'السدارين', #1
u'السددي': u'السددي', #1
u'السدوسي،': u'السَّدُوسيّ،', #1
u'السدوسي،': u'السَّدُوسِيُّ،', #18
u'السدوسي،': u'السدوسي،', #2
u'السدوسي،': u'السَّدُوسِيَّ،', #2
u'السدوسى': u'السُّدُوسِىُّ', #2
u'السدوسي': u'السَّدُوسِيِّ', #20
u'السدوسي': u'السَّدُوسِيُّ', #28
u'السدوسى': u'السَّدُوسِىُّ', #29
u'السدوسي': u'السَّدُوسِيَّ', #3
u'السدوسي': u'السدوسي', #4
u'السدوسى': u'السَّدُوسِىِّ', #4
u'السدوسي،': u'السَّدُوسِيِّ،', #6
u'السدوسي': u'السّدُوسِيّ', #7
u'السديالتي': u'السُّدِّيِّالَّتِي', #1
u'السديأما': u'السُّدِّيِّأَمَّا', #9
u'السديأن': u'السُّدِّيِّأَنَّ', #1
u'السديثم': u'السُّدِّيِّثُمَّ', #1
u'السديرة': u'السَّدِيرَةُ', #1
u'السديرى': u'السُّدَيْرِىُّ', #1
u'السديرى': u'السَّدِيرِىُّ', #2
u'السديف': u'السّدِيفِ', #1
u'السديف': u'السَّدِيفِ', #1
u'السديف': u'السّدِيفَ', #2
u'السديفأبى': u'السُّدِّيِّفَأَبَى', #1
u'السديفأنزل': u'السُّدِّيِّفَأَنْزَلَ', #1
u'السديوأما': u'السُّدِّيِّوَأَمَّا', #4
u'السدييقول': u'السُّدِّيِّيَقُولُ', #1
u'السرابا': u'السّرَابَا', #2
u'السرابات': u'السَّرَابَاتُ', #1
u'السرابات': u'السَّرَابَاتِ', #2
u'السراباتي': u'السِّرَابَاتِيِّ', #1
u'السراباتية': u'السَّرَابَاتِيَّةِ', #1
u'السرادة': u'السرادة', #1
u'السرادة': u'السَّرَّادَةُ', #1
u'السراديح': u'السّرادِيح', #1
u'السراديح': u'السّرَادِيحِ', #1
u'السرارا': u'السِّرَارَا', #1
u'السرارى': u'السَّرَارِىَّ', #1
u'السراطمة': u'السّرَاطِمَةِ', #2
u'السرايجة': u'السرايجة', #1
u'السرباتية': u'السَّرَبَاتِيَّةِ', #1
u'السربام': u'السربام', #1
u'السرحان': u'السّرْحَانَ', #1
u'السرحان': u'السّرْحَانِ', #1
u'السرحان': u'السَّرْحَانِ', #2
u'السرحان': u'السِّرْحَانُ', #4
u'السرحان': u'السِّرْحَانِ', #40
u'السرحي،': u'السَّرَحِيُّ،', #1
u'السرحى': u'السَّرْحِىُّ', #3
u'السرخسى': u'السَّرْخَسِىَّ', #1
u'السرخسى': u'السَّرَخْسِىَّ', #2
u'السرخسى': u'السَّرَخْسِىُّ', #3
u'السرخسى': u'السَّرْخَسِىُّ', #5
u'السرخكتي': u'السُّرْخَكَتِيِّ', #1
u'السرخكتي': u'السُّرْخَكَتِيُّ', #3
u'السرف': u'السَّرِفِ', #1
u'السرف': u'السَّرْفَ', #1
u'السرف؟': u'السَّرَفُ؟', #1
u'السرف': u'السَّرَفِ', #163
u'السرف': u'السَّرَفَ', #19
u'السرف': u'السرف', #2
u'السرف': u'السَّرَف', #4
u'السرف': u'السَّرَفُ', #53
u'السرقنة': u'السَّرْقَنَةِ', #2
u'السرقه': u'السرقه', #1
u'السرقوج': u'السَّرْقُوجَ', #1
u'السرقين': u'السَّرْقِينِ', #1
u'السرقين': u'السِّرْقِين', #1
u'السرقين': u'السِّرْقِينُ', #18
u'السرقين': u'السِّرْقِينَ', #31
u'السرقين': u'السِّرْقِينِ', #75
u'السركار': u'السركار', #2
u'السرما': u'السِّرُّمَا', #2
u'السرموجة': u'السُّرْمُوجَةِ', #1
u'السرموزة': u'السَّرْمُوزَةَ', #2
u'السرموزة': u'السَّرْمُوزَةِ', #4
u'السرموزة': u'السَّرْمُوزَةُ', #6
u'السروجي': u'السَّرُوجِيِّ', #1
u'السروجي': u'السُّرُوجِيُّ', #123
u'السروجي': u'السُّرُوجِيِّ', #160
u'السروجي': u'السُّرُوجِيَّ', #4
u'السروجية': u'السُّرُوجِيَّةِ', #2
u'السريةالوجه': u'السَّرِيَّةَالْوَجْهُ', #1
u'السريجة': u'السريجة', #1
u'السريجي': u'السُّرَيْجِيُّ', #1
u'السريجية': u'السُّرَيْجِيَّةُ', #11
u'السريجية': u'السُّرَيْجِيَّةَ', #2
u'السريجية': u'السُّرَيْجِيَّةِ', #28
u'السريجية': u'السُّرَيْجِيَّة', #3
u'السريح': u'السّرِيحَ', #1
u'السريح': u'السّرِيحِ', #2
u'السريحا': u'السّرِيحَا', #1
u'السريحا': u'السَّرِيحَا', #1
u'السريروالدكان': u'السَّرِيرِوَالدُّكَّانِ', #1
u'السريه': u'السَّرِيَّهْ', #1
u'السطا': u'السَّطَا', #2
u'السطاح': u'السُّطَّاحَ', #1
u'السطوحات': u'السُّطُوحَاتِ', #2
u'السطي': u'السَّطِّيَّ', #1
u'السطي': u'السَّطِّيِّ', #2
u'السطي': u'السَّطِّيُّ', #5
u'السعدان': u'السَّعْدَانًًًًًًًًِ', #1
u'السعدانة': u'السَّعْدَانَةُ', #1
u'السعدني،': u'السَّعْدَنِيِّ،', #1
u'السعدى': u'السّعْدَى', #1
u'السعدى': u'السَّعْدِىُّ', #106
u'السعدى': u'السَّعْدِىِّ', #19
u'السعدى': u'السَّعْدِىَّ', #3
u'السعلاة': u'السِّعْلَاةُ', #1
u'السعور': u'السُّعُورُ', #1
u'السعوط': u'السُّعُوط', #1
u'السعوط': u'السُّعُوطُ', #1
u'السعوط': u'السَّعُوطِ', #18
u'السعوط': u'السَّعُوطُ', #24
u'السعوط': u'السعوط', #3
u'السعوط': u'السُّعُوطِ', #3
u'السعوط': u'السَّعُوطَ', #9
u'السعى': u'السَّعْىُ', #2
u'السعى': u'السَّعْىِ', #6
u'السعى': u'السَّعْىَ', #8
u'السعيدي': u'السَّعِيدِيُّ', #1
u'السعيدى': u'السَّعِيدِىِّ', #1
u'السعيدي': u'السَّعِيدِيِّ', #2
u'السعيدى': u'السَّعِيدِىُّ', #4
u'السعيدية': u'السَّعِيدِيَّةِ', #1
u'السغباء': u'السَّغْبَاءِ', #1
u'السغد': u'السُّغْدُ', #1
u'السغد': u'السُّغْدِ', #1
u'السغد،': u'السُّغْدِ،', #1
u'السغدي': u'السُّغْدِيَّ', #2
u'السغدي': u'السُّغْدِيِّ', #28
u'السغدي': u'السُّغْدِيُّ', #98
u'السغدية': u'السُّغْدِيَّةِ', #1
u'السغدية': u'السُّغْدِيَّةُ', #3
u'السغسغة': u'السَّغْسَغَةُ', #1
u'السغناقي': u'السِّغْنَاقِيُّ', #25
u'السغناقي': u'السِّغْنَاقِيِّ', #41
u'السفاتج': u'السَّفَاتِجُ', #10
u'السفاتج': u'السَّفَاتِجِ', #10
u'السفاتج': u'السَّفَاتِجَ', #3
u'السفارون': u'السفارون', #1
u'السفارون': u'السَّفَّارُونَ', #2
u'السفاريني': u'السَّفَارِينِيُّ', #1
u'السفاق': u'السِّفَاقِ', #1
u'السفاقسي': u'السَّفَاقِسِيَّ', #1
u'السفاقسي': u'السَّفَاقِسِيِّ', #1
u'السفاقسي': u'السَّفَاقِسِيُّ', #11
u'السفائح': u'السّفائح', #1
u'السفائح': u'السّفَائِحُ', #1
u'السفائح': u'السّفَائِحْ', #2
u'السفتج': u'السُّفْتَجُ', #1
u'السفتج': u'السَّفْتَجُ', #3
u'السفتجات': u'السَّفْتَجَاتُ', #1
u'السفتجات': u'السُّفْتَجَاتُ', #1
u'السفتجة': u'السُّفْتَجَةَ', #1
u'السفتجة': u'السَّفْتَجَةُ', #11
u'السفتجة': u'السَّفْتَجَةِ', #15
u'السفتجة': u'السَّفْتَجَةَ', #8
u'السفرجلا': u'السَّفَرْجَلَا', #10
u'السفرهل': u'السَّفَرِهَلْ', #1
u'السفروالوجه': u'السَّفَرِوَالْوَجْهُ', #2
u'السفعاء': u'السفعاء', #1
u'السفكردري': u'السَّفْكَرْدَرِيِّ', #1
u'السفكردري': u'السفكردري', #3
u'السفلاء': u'السفلاء', #1
u'السفلاني': u'السُّفْلَانِي', #1
u'السفلاني': u'السُّفْلَانِيُّ', #1
u'السفلاني': u'السُّفْلَانِيِّ', #3
u'السفها': u'السُّفَهَا', #1
u'السفواء': u'السَّفْوَاءُ', #1
u'السفوف': u'السَّفُوفُ', #1
u'السفوف': u'السَّفُوفِ', #2
u'السفوف': u'السَّفُوفَ', #3
u'السفوق': u'السُّفُوقِ', #1
u'السفى': u'السّفَى', #2
u'السفيانان': u'السُّفْيَانَانِ', #1
u'السفيانان،': u'السُّفْيَانَانُ،', #1
u'السفياني': u'السُّفْيَانِيِّ', #1
u'السفياني،': u'السُّفْيَانِيِّ،', #1
u'السفيانين': u'السُّفْيَانَيْنِ', #1
u'السفيق': u'السَّفِيقُ', #1
u'السفيقة': u'السَّفِيقَةِ', #1
u'السفينةوجدا': u'السَّفِينَةِوَجَدَا', #1
u'السفينت': u'السَّفِينَتَ', #1
u'السقا': u'السِّقَا', #3
u'السقا': u'السَّقَّا', #9
u'السقاءون': u'السَّقَّاءُونَ', #6
u'السقارون': u'السَّقَّارُونَ', #3
u'السقاما': u'السِّقَامَا', #2
u'السقاميني': u'السَّقَامِينِيِّ', #1
u'السقايا': u'السَّقَايَا', #1
u'السقايين': u'السَّقَّايِينَ', #3
u'السقب': u'السّقَبِ', #1
u'السقب': u'السَّقَب', #2
u'السقب': u'السَّقَبُ', #2
u'السقب': u'السّقْبِ', #4
u'السقراط': u'السقراط', #2
u'السقرق': u'السقرق', #2
u'السقطى': u'السَّقْطِىُّ', #1
u'السقطى': u'السَّقَطِىُّ', #8
u'السقلاب': u'السقلاب', #1
u'السقلي': u'السَّقَلِّيِّ', #1
u'السقمقوله': u'السُّقْمُقَوْلُهُ', #1
u'السقمونيا': u'السَّقَمُونْيَا', #13
u'السقى': u'السقى', #1
u'السقى': u'السَقْىِ', #1
u'السقى': u'السَّقْى', #1
u'السقى': u'السُّقَى', #1
u'السقى': u'السَّقْىِ', #3
u'السقيات': u'السَّقْيَات', #1
u'السقيات': u'السَّقْيَاتِ', #21
u'السقيات': u'السَّقِيَّاتِ', #5
u'السقيب': u'السَّقِيبَ', #1
u'السقية': u'السُّقْيَةِ', #1
u'السقية': u'السَّقِيَّة', #10
u'السقية': u'السَّقِيَّةُ', #16
u'السقية': u'السُّقْيَةَ', #2
u'السقية': u'السَّقِيَّةِ', #27
u'السقية': u'السَّقِيَّةَ', #3
u'السقية': u'السَّقْيَةَ', #3
u'السكاء': u'السَّكَّاءُ', #9
u'السكاسك': u'السَّكَاسِكُ', #1
u'السكاف': u'السَّكَّافِ', #1
u'السكاكي': u'السَّكَّاكِيّ', #1
u'السكاكي': u'السَّكَّاكِيَّ', #1
u'السكاكي': u'السَّكَّاكِيِّ', #16
u'السكاكي': u'السَّكَّاكِيُّ', #30
u'السكباج': u'السِّكْبَاجُ', #1
u'السكباج': u'السِّكْبَاجَ', #3
u'السكباجة': u'السِّكْبَاجَةِ', #1
u'السكتاني': u'السُّكْتَانِيُّ', #2
u'السكرجة': u'السُّكْرُجَةُ', #1
u'السكركة': u'السُّكْرُكَةَ', #1
u'السكركة': u'السُّكُرْكَةُ', #2
u'السكركة': u'السُّكْرُكَةُ', #2
u'السكسك': u'السَّكْسَكِ', #1
u'السكسكي': u'السكسكي', #1
u'السكسكي': u'السّكْسَكِيُّ', #1
u'السكسكي،': u'السَّكْسَكِيَّ،', #1
u'السكسكي': u'السَّكْسَكِيُّ', #10
u'السكسكي': u'السَّكْسَكِيِّ', #12
u'السكسكي،': u'السكسكي،', #2
u'السكسكى': u'السَّكْسَكِىُّ', #2
u'السكسكي،': u'السَّكْسَكِيِّ،', #4
u'السكسكي،': u'السَّكْسَكِيُّ،', #6
u'السكسكى': u'السَّكْسَكِىِّ', #6
u'السكفين': u'السَّكْفِينِ', #1
u'السكنجبيل': u'السّكَنْجَبِيلِ', #1
u'السكنجبيل': u'السَّكَنْجَبيلِ', #2
u'السكنجبين': u'السكنجبين', #1
u'السكنجبين': u'السَّكَنْجَبِين', #1
u'السكنجبين': u'السَّكَنْجَبِينُ', #3
u'السكنجبين': u'السَّكَنْجَبِينِ', #5
u'السكنجبين': u'السَّكَنْجَبِينَ', #7
u'السكندري': u'السَّكَنْدَرِيَّ', #1
u'السكندري': u'السَّكَنْدَرِيُّ', #4
u'السكندرية': u'السَّكَنْدَرِيَّةَ', #1
u'السكندرية': u'السَّكَنْدَرِيَّةِ', #3
u'السكونى': u'السَّكُونِىَّ', #1
u'السكونى': u'السَّكُونِىُّ', #12
u'السكونى': u'السَّكُونِىِّ', #2
u'السكيت': u'السّكّيتِ', #1
u'السكيت': u'السُّكَّيْتِ', #1
u'السكيت': u'السِّكِّيت', #2
u'السكيت': u'السُّكَيْتُ', #7
u'السكيت': u'السِّكِّيتِ', #93
u'السلا': u'السَّلا', #1
u'السلا': u'السَّلَا', #1
u'السلا': u'السُّلَّا', #1
u'السلاء': u'السِّلَاءُ', #1
u'السلابة': u'السَّلَّابَةُ', #4
u'السلابة': u'السَّلَّابَةِ', #7
u'السلار': u'السَّلَّارَ', #1
u'السلاطح': u'السّلَاطِحْ', #2
u'السلاق': u'السّلّاقُ', #2
u'السلالقة': u'السَّلَالِقَةُ', #2
u'السلالقة': u'السَّلَالِقَةِ', #2
u'السلالى': u'السَّلاَلِى', #1
u'السلاليم': u'السَّلَالِيمُ', #2
u'السلامSأسطورة': u'السّلَامُSأُسْطُورَةُ', #1
u'السلامSحديث': u'السّلَامSحَدِيثُ', #1
u'السلامSمن': u'السّلَامُSمِنْ', #1
u'السلاما': u'السَّلَامَا', #1
u'السلامانى': u'السَّلاَمَانِىُّ', #1
u'السلامقوما': u'السَّلامُقُومَا', #1
u'السلامه': u'السَّلَامَهْ', #4
u'السلاميا': u'السَّلامُيَا', #1
u'السلاميون': u'السَّلَامِيُّونَ', #1
u'السلتاء': u'السَّلْتَاءِ', #1
u'السلتاء': u'السَّلْتَاءَ', #6
u'السلجج': u'السّلْجَجَ', #1
u'السلجم': u'السَّلْجَمِ', #17
u'السلجم': u'السَّلْجَمُ', #2
u'السلحاني،': u'السَّلْحَانِيُّ،', #1
u'السلسل': u'السَّلْسَلُ', #1
u'السلسل': u'السّلْسَلُ', #2
u'السلعه': u'السِّلْعَهْ', #1
u'السلمات': u'السّلَمَاتُ', #1
u'السلماني،': u'السَّلْمَانيّ،', #1
u'السلمانى': u'السَّلْمَانِىَّ', #1
u'السلمانى': u'السَّلْمَانِىِّ', #10
u'السلماني': u'السُّلْمَانِيِّ', #2
u'السلماني،': u'السَّلْمَانِيَّ،', #2
u'السلماني': u'السَّلْمَانِيُّ', #24
u'السلماني': u'السّلْمَانِيّ', #3
u'السلماني': u'السَّلْمَانِيَّ', #3
u'السلمانى': u'السَّلْمَانِىُّ', #3
u'السلماني': u'السَّلْمَانِيِّ', #34
u'السلماني،': u'السَّلْمَانِيُّ،', #5
u'السلماني،': u'السَّلْمَانِيِّ،', #8
u'السلماني،': u'السلماني،', #9
u'السلمانية': u'السَّلْمَانِيَّةِ', #1
u'السلمى': u'السُلَمِىُّ', #1
u'السلمى': u'السُّلَمِى', #1
u'السلمى': u'السُّلَمْىُّ', #1
u'السلمى': u'السُّلَمِىَّ', #13
u'السلمى': u'السَّلَمِىُّ', #2
u'السلمى': u'السَّلَمِىِّ', #2
u'السلمى': u'السُّلَمِىُّ', #723
u'السلمى': u'السُّلَمِىِّ', #78
u'السله': u'السّلّهْ', #3
u'السلهب': u'السّلْهَبُ', #1
u'السلول': u'السّلُولُ', #1
u'السلول': u'السّلُولِ', #1
u'السلول': u'السَّلُولِ', #4
u'السلولي،': u'السلولي،', #1
u'السلولي،': u'السَّلُولِيِّ،', #11
u'السلولى': u'السَّلُولِىُّ', #14
u'السلولي،': u'السَّلُولِيُّ،', #16
u'السلولي': u'السَّلُولِيِّ', #22
u'السلولي': u'السَّلُولِيُّ', #24
u'السلولي': u'السلولي', #3
u'السلولي': u'السَّلُولِيَّ', #5
u'السلولى': u'السَّلُولِىِّ', #8
u'السليحي': u'السَّلِيحِيُّ', #1
u'السليحي': u'السَّلِيحِيِّ', #1
u'السليحي،': u'السُّلَيْحِيُّ،', #1
u'السليحى': u'السَّلِيحِىُّ', #1
u'السليطى': u'السُّلَيْطِىُّ', #4
u'السليطى': u'السَّلِيطِىُّ', #9
u'السليك': u'السُّلَيْكِ', #2
u'السليمانى': u'السُّلَيْمَانِىُّ', #2
u'السليمي': u'السُّلَيْمِيِّ', #1
u'السليمي،': u'السُّلَيْمِيُّ،', #1
u'السليمية': u'السُّلَيْمِيَّةِ', #2
u'السليميين': u'السُّلَيْمِيِّينَ', #1
u'السما': u'السّمَا', #1
u'السما': u'السَّمَا', #2
u'السمآء': u'السَّمَآءِ', #1
u'السماءقوله': u'السَّمَاءِقَوْلُهُ', #1
u'السماخ': u'السماخ', #1
u'السمارة': u'السَّمَارَةِ', #1
u'السماسم': u'السماسم', #1
u'السماسم': u'السَّمَاسِمُ', #1
u'السماسم': u'السَّمَاسِمِ', #6
u'السماطين،': u'السِّمَاطَيْنِ،', #1
u'السماطين': u'السِّمَاطَيْنِ', #4
u'السماعى': u'السَّمَاعِىِّ', #1
u'السماما': u'السمَامَا', #1
u'السماوة': u'السّمَاوَةِ', #1
u'السماوة،': u'السَّمَاوَةِ،', #1
u'السماوة': u'السَّمَاوَةِ', #7
u'السمتى': u'السَّمْتِىُّ', #3
u'السمحاق': u'السِّمْحَاقَ', #13
u'السمحاق': u'السِّمْحَاقُ', #36
u'السمحاق': u'السِّمْحَاقِ', #37
u'السمديسي': u'السَّمَدِيسِيِّ', #1
u'السمديسي': u'السَّمْدِيسِيُّ', #1
u'السمديسي': u'السَّمْدِيسِيِّ', #1
u'السمديسي': u'السَّمَدِيسِيُّ', #2
u'السمذى': u'السِّمِّذِىَّ', #1
u'السمرا': u'السَّمْرَا', #1
u'السمراسي': u'السَّمْرَاسِيُّ', #1
u'السمرقندى': u'السَّمَرْقَنْدِىُّ', #11
u'السمرى': u'السِّمَّرِىُّ', #11
u'السمرى': u'السِّمَرِىُّ', #3
u'السمسق': u'السمسق', #1
u'السمسق': u'السَّمْسَقُ', #2
u'السمسمة': u'السِّمْسِمَة', #2
u'السمسمة': u'السِّمْسِمَةَ', #4
u'السمسمة': u'السِّمْسِمَةِ', #5
u'السمعا': u'السَّمْعَا', #1
u'السمعاني،': u'السَّمْعاني،', #1
u'السمعاني': u'السَّمْعَانِيّ', #1
u'السمعاني': u'السمعاني', #2
u'السمعاني': u'السَّمْعَانِيُّ', #37
u'السمعاني': u'السَّمْعَانِيِّ', #481
u'السمعانية': u'السَّمْعَانِيَّةِ', #1
u'السمكري': u'السَّمْكَرِيُّ', #1
u'السمكه': u'السَّمَكَهْ', #1
u'السملاوي': u'السِّمِلَّاوِيُّ', #1
u'السمنا': u'السَّمْنَا', #1
u'السمنانى': u'السَّمْنَانِىُّ', #1
u'السمناني': u'السمناني', #2
u'السمناني': u'السَّمْنَانِيُّ', #3
u'السمناني،': u'السِّمْنَانِيُّ،', #3
u'السمناني': u'السَّمْنَانِيِّ', #4
u'السمنانى': u'السِّمْنَانِىُّ', #5
u'السمنودي': u'السَّمَنُّودِيِّ', #1
u'السمهري': u'السّمْهَرِيّ', #2
u'السمهري': u'السَّمْهَرِيِّ', #2
u'السمهرية': u'السّمْهَرِيّةُ', #1
u'السمهرية': u'السّمْهَرِيّةِ', #1
u'السمهودي': u'السَّمْهُودِيَّ', #10
u'السمهودي': u'السَّمْهُودِيِّ', #44
u'السمهودي': u'السَّمْهُودِيّ', #6
u'السمهودي': u'السَّمْهُودِيُّ', #72
u'السمهوري': u'السَّمْهُورِيُّ', #1
u'السميدع': u'السُّمَيْدِعِ', #1
u'السميدع': u'السّمَيْدَعُ', #12
u'السميدع': u'السَّمَيْدَعِ', #2
u'السميدع': u'السَّمَيْدَعُ', #4
u'السميدع': u'السّمَيْدَعِ', #8
u'السميذ': u'السَّمِيذَ', #1
u'السميذ': u'السَّمِيذُ', #1
u'السميذ': u'السَّمِيذِ', #1
u'السميراء': u'السّمَيْرَاءُ', #1
u'السميراء': u'السّمَيْرَاءِ', #1
u'السميساطية': u'السَّمِيسَاطِيَّةُ', #1
u'السميساطية،': u'السُّمَيْسَاطِيَّةُ،', #1
u'السميفع': u'السْمَيْفَعَ', #1
u'السميفع،': u'السَّمَيْفَع،', #1
u'السناسن': u'السّنَاسِنِ', #2
u'السناف': u'السّنَافُ', #2
u'السنامين': u'السنامين', #3
u'السنامين': u'السَّنَامَيْنِ', #4
u'السنباطي': u'السَّنْبَاطِيِّ', #15
u'السنباطي': u'السَّنْبَاطِيَّ', #2
u'السنباطي': u'السَّنْبَاطِيُّ', #41
u'السنبلةوالوجه': u'السُّنْبُلَةِوَالْوَجْهُ', #1
u'السنةوالوجه': u'السُّنَّةَوَالْوَجْهُ', #1
u'السنةوالوجه': u'السُّنَّةُوَالْوَجْهُ', #1
u'السنجاري': u'السِّنْجَارِيُّ', #1
u'السنجاري': u'السِّنْجَارِيِّ', #1
u'السنجاري،': u'السِّنْجَارِيُّ،', #2
u'السنجري': u'السّنْجَرِيّ', #1
u'السنجري': u'السَّنْجَرِيُّ', #1
u'السنجى': u'السَّنْجِىُّ', #2
u'السنحي': u'السُّنْحِيُّ', #1
u'السنداس': u'السُّنْدَاسُ', #1
u'السنداس': u'السُّنْدَاسِ', #2
u'السندره': u'السّنْدَرَهْ', #1
u'السندره': u'السِّنْدَرَهْ', #1
u'السندره': u'السَّنْدَرَهْ', #7
u'السندفي': u'السَّنْدَفِيُّ', #1
u'السندى': u'السِّنْدِىِّ', #11
u'السندى': u'السِّنْدِىُّ', #5
u'السنديد': u'السنديد', #1
u'السنقري': u'السُّنْقُرِيِّ', #2
u'السنكلوني': u'السَّنْكَلُونِيِّ', #2
u'السنهوري': u'السَّنْهُوريِّ', #1
u'السنهوري': u'السَّنْهُورِيِّ', #24
u'السنهوري': u'السَّنْهُورِيُّ', #55
u'السنهوري': u'السَّنْهُورِيَّ', #7
u'السنهوريان': u'السَّنْهُورِيَّانِ', #1
u'السنوت': u'السَّنُّوتَ', #1
u'السنوت': u'السَّنُّوتُ', #1
u'السنوت': u'السَّنُّوتِ', #1
u'السنوت؟': u'السَّنُّوتُ؟', #1
u'السنوسي': u'السُّنُوسِيُّ', #1
u'السنوسي،': u'السُّنُوسِيُّ،', #1
u'السنوسي': u'السُّنُوسِيِّ', #2
u'السنوسي': u'السَّنُوسِيُّ', #46
u'السنوسي': u'السَّنُوسِيِّ', #8
u'السنوسية': u'السَّنُوسِيَّةِ', #1
u'السنوسية': u'السُّنُوسِيَّةِ', #2
u'السنى': u'السَّنَى', #3
u'السنى': u'السُّنِّىُّ', #4
u'السه': u'السَّهْ', #1
u'السه': u'السَّهَ', #2
u'السه': u'السَّهِ', #35
u'السه': u'السَّهُ', #5
u'السهاما': u'السِّهَامَا', #1
u'السهروردي': u'السُّهْرَوَرْدِي', #1
u'السهروردي': u'السُّهْرَوَرْدِيّ', #17
u'السهروردي': u'السُّهْرَوَرْدِيَّ', #2
u'السهروردي': u'السُّهْرَوَرْدِيِّ', #4
u'السهروردي': u'السُّهْرَوَرْدِيُّ', #9
u'السهمى': u'السَّهْمِىِّ', #15
u'السهمى': u'السَّهْمِىَّ', #2
u'السهمى': u'السَّهْمِىُّ', #33
u'السهود': u'السّهُودُ', #3
u'السهوكة': u'السَّهُوكَةَ', #2
u'السهوكة': u'السَّهْوَكَةَ', #2
u'السهولا': u'السَّهُولَا', #1
u'السهيمي': u'السُّهَيْمِيُّ', #1
u'السؤ': u'السؤ', #1
u'السوءى': u'السّوءَى', #1
u'السوابغ': u'السّوَابِغِ', #2
u'السوابغ': u'السَّوَابِغَ', #2
u'السوابغ': u'السَّوَابِغِ', #2
u'السوادة': u'السَّوَادَةُ', #1
u'السوادة': u'السِّوَادَةُ', #1
u'السوادة': u'السَّوَادَةَ', #2
u'السوادة': u'السَّوَادَةِ', #30
u'السوادة': u'السِّوَادَةَ', #5
u'السوادة': u'السِّوَادَةِ', #53
u'السوادني': u'السُّوادَنِيِّ', #1
u'السوادي': u'السَّوَادِيُّ', #1
u'السوادين': u'السَّوَادَيْنِ', #4
u'السوارقية': u'السوارقية', #2
u'السوارى': u'السَّوَارِىَ', #4
u'السوارى': u'السَّوَارِى', #6
u'السواف': u'السّوّافِ', #1
u'السوافي': u'السَّوَافِي', #1
u'السوال': u'السُّوَالَ', #2
u'السوال': u'السُّوَالُ', #3
u'السؤالاتي': u'السُّؤَالَاتِيّ', #1
u'السؤالاتي': u'السُّؤَالَاتِيِّ', #1
u'السواما': u'السِّوَامَا', #1
u'السوائمة': u'السَّوَائِمَة', #1
u'السوائي': u'السّوائيّ', #1
u'السوائي': u'السُّوائيّ', #1
u'السوائي': u'السّوَائِيّ', #1
u'السوائي': u'السُّوَائِي', #1
u'السوائي': u'السُّوَائِيّ', #1
u'السوائي،': u'السُّوَائِيِّ،', #1
u'السوائى': u'السُّوائِىُّ', #1
u'السوائى': u'السُّوَائِىِّ', #1
u'السوائي': u'السُّوَائِيِّ', #12
u'السوائي': u'السوائي', #3
u'السوائي': u'السُّوَائِيَّ', #3
u'السوائى': u'السُّوَائِىُّ', #3
u'السوائي': u'السُّوَائِيُّ', #5
u'السوائي،': u'السُّوَائِيُّ،', #5
u'السوبيا': u'السُّوبْيَا', #2
u'السوبية': u'السُّوبِيَةِ', #1
u'السودة': u'السَّوْدَة', #1
u'السودد': u'السُّوْدُدِ', #1
u'السودد': u'السُّوْدُدَ', #2
u'السودد': u'السّودَدُ', #4
u'السودزيان': u'السودزيان', #1
u'السودواني': u'السَّوْدَوَانِيُّ', #1
u'السوذرجاني': u'السُّوذَرْجَانِيُّ', #1
u'السورج': u'السّوْرَجْ', #1
u'السورج': u'السّوْرَجُ', #2
u'السوريانى': u'السُّورْيَانِىُّ', #1
u'السوريني': u'السُّورِينِيِّ', #1
u'السوسى': u'السُّوسِىُّ', #143
u'السوسى': u'الُّسوسِىُّ', #2
u'السوسى': u'السُّوسِىِّ', #4
u'السوسيقالوا': u'السوسيقَالُوا', #1
u'السوطى': u'السُّوطِىُّ', #1
u'السوطى': u'السَّوْطِىُّ', #1
u'السوقة': u'السُّوقَةِ', #28
u'السوقة': u'السُّوقَةَ', #5
u'السوقة': u'السُّوقَةُ', #9
u'السوكرة': u'السَّوْكَرَةِ', #6
u'السول': u'السُّولِ', #2
u'السومين': u'السَّوْمَيْنِ', #1
u'السويفي': u'السُّوَيْفِيِّ', #1
u'السويق': u'السُّوَيْقُ', #1
u'السويق': u'السَّوِيقَ', #100
u'السويق': u'السّوِيق', #2
u'السويق،': u'السَّوِيقِ،', #2
u'السويق': u'السَّوِيقِ', #210
u'السويق': u'السّوِيقِ', #23
u'السويق': u'السّوِيقُ', #3
u'السويق': u'السَّوِيقُ', #36
u'السويق': u'السّوِيقَ', #4
u'السويقين': u'السَّوِيقَيْنِ', #1
u'السويه': u'السَّوِيَّهْ', #1
u'السيء': u'السِّيءِ', #1
u'السيء': u'السَّيْء', #1
u'السيء': u'السّيّءَ', #1
u'السيء': u'السّيْءِ', #1
u'السىء': u'السىء', #1
u'السيء': u'السَّيِّءِ', #2
u'السيء': u'السَّيْءِ', #2
u'السياري،': u'السياري،', #1
u'السياري': u'السَّيَّارِيَّ', #1
u'السيارى': u'السِّيَارِىُّ', #1
u'السياري،': u'السَّيَّارِيُّ،', #13
u'السياري': u'السَّيَّارِيُّ', #3
u'السيارى': u'السِّيَّارِىُّ', #3
u'السيارى': u'السَّيَّارِىُّ', #32
u'السياري،': u'السَّيَّارِيِّ،', #7
u'السياعري': u'السَّيَاعِرِيُّ', #1
u'السيالكوتي': u'السَّيَالَكُوتِيَّ', #1
u'السيالكوتي': u'السَّيَالَكُوتِيِّ', #1
u'السيالكوتي': u'السَّيَالَكُوتِيُّ', #5
u'السيب': u'السَّيِّبُ', #1
u'السيب': u'السُّيَّبَ', #1
u'السيب': u'السَّيْبُ', #2
u'السيباني،': u'السَّيْبَانِيُّ،', #2
u'السيبانى': u'السَّيْبَانِىُّ', #2
u'السيباني،': u'السَّيْبَانِيِّ،', #3
u'السيباني': u'السَّيْبَانِيُّ', #4
u'السيبانى': u'السَّيْبَانِىِّ', #4
u'السيباني': u'السيباني', #5
u'السيباني': u'السَّيْبَانِيِّ', #9
u'السية': u'السية', #1
u'السيجان': u'السيجان', #1
u'السيجان': u'السِّيجَانُ', #3
u'السيدالكريم': u'السَّيِّدَالْكَرِيمَ', #1
u'السيدي': u'السِّيدِيُّ', #1
u'السيدي': u'السِّيدِيِّ', #1
u'السيدية': u'السَّيِّدِيَّةَ', #2
u'السيدية': u'السَّيِّدِيَّةِ', #4
u'السيراء': u'السِّيرَاءِ', #1
u'السيراء': u'السِّيَرَاء', #1
u'السيراء': u'السِّيَرَاءَ', #3
u'السيراء': u'السِّيَرَاءِ', #3
u'السيراء': u'السيراء', #4
u'السيراء': u'السِّيَرَاءُ', #7
u'السيرافي': u'السِّيرَافِيَّ', #1
u'السيرافي': u'السَّيْرَافِيِّ', #1
u'السيرافي،': u'السَّيْرَافِيِّ،', #1
u'السيرافي': u'السِّيرَافِيُّ', #19
u'السيرافي': u'السّيْرَافِيّ', #2
u'السيرافي': u'السّيرَافِيّ', #3
u'السيرافي،': u'السِّيرَافِيُّ،', #3
u'السيرافى': u'السِّيرَافِىُّ', #5
u'السيرافي': u'السِّيرَافِيِّ', #6
u'السيرامي': u'السِّيرَامِيِّ', #4
u'السيرامي': u'السِّيرَامِيُّ', #6
u'السيرجي': u'السَّيْرَجِيُّ', #1
u'السيرجي': u'السَّيْرَجِيِّ', #1
u'السيرين': u'السَّيْرَيْنِ', #1
u'السيريني': u'السِّيرِينِيُّ', #1
u'السيسبان': u'السَّيْسَبَانِ', #2
u'السيقل،': u'السَّيْقَلُ،', #1
u'السيكران': u'السَّيْكَرَانُ', #1
u'السيكران': u'السَّيْكُرَانِ', #1
u'السيكران': u'السَّيْكَرَانِ', #11
u'السيكران': u'السَّيْكُرَانَ', #2
u'السيكران': u'السُّيْكَرَانِ', #2
u'السيكران': u'السَّيْكَرَانَ', #8
u'السيلحون': u'السَّيْلَحُونَ', #1
u'السيلحين': u'السَّيْلحين', #1
u'السيلحيني،': u'السِّيلِحِينِيُّ،', #1
u'السيلحيني': u'السِّيْلَحِينِيُّ', #1
u'السيلحيني،': u'السَّيْلَحِينِيِّ،', #1
u'السيلحينى': u'السَّيْلَحِينِىَّ', #1
u'السيلحينى': u'السَّيْلَحِينِىِّ', #1
u'السيلحيني': u'السِّيلَحِينِيُّ', #2
u'السيلحيني،': u'السَّيْلَحِينِيُّ،', #2
u'السيلحينى': u'السَّيْلَحِينِىُّ', #5
u'السيلي': u'السِّيليَّ', #1
u'السيلي': u'السِّيليُّ', #1
u'السيلي': u'السِّيليِّ', #1
u'السيميا': u'السِّيمَيَا', #1
u'السينابي': u'السِّينَابِيِّ', #1
u'السينانى': u'السِّينَانِىِّ', #1
u'السينانى': u'السِّيْنَانِىُّ', #1
u'السيناني': u'السِّينَانِيُّ', #5
u'السينانى': u'السِّينَانِىُّ', #9
u'السينوبي': u'السَّيْنُوبِيِّ', #1
u'السيواسي': u'السِّيوَاسِيِّ', #1
u'السيواسي': u'السِّيوَاسِيُّ', #3
u'السيوب': u'السُّيُوبَ', #1
u'السيوب': u'السُّيُوبُ', #3
u'السيوب': u'السُّيُوبِ', #5
u'السيور': u'السُّيُورُ', #2
u'السيور': u'السُّيُورَ', #5
u'السيور': u'السُّيُورِ', #5
u'السيوري': u'السُّيُورِيُّ', #29
u'السيوري': u'السُّيُورِيِّ', #31
u'السيوري': u'السُّيُورِيَّ', #5
u'السيوطية': u'السُّيُوطِيَّةِ', #2
u'السيوفا': u'السُّيُوفَا', #1
u'السيوفا': u'السّيُوفَا', #3
u'السيىء': u'السَّيِّىءِ', #1
u'الشاء': u'الشّاءَ', #1
u'الشاء،': u'الشَّاءُ،', #1
u'الشاء؟': u'الشَّاءِ؟', #1
u'الشاء': u'الشّاءِ', #10
u'الشاء': u'الشّاءُ', #2
u'الشاء،': u'الشَّاءِ،', #3
u'الشاء': u'الشَّاءُ', #4
u'الشاء': u'الشَّاءِ', #43
u'الشاء': u'الشَّاء', #6
u'الشاء': u'الشَّاءَ', #7
u'الشاباط': u'الشَّابَاطِ', #1
u'الشابرقان': u'الشَّابِرْقَانَ', #1
u'الشابوري،': u'الشابوري،', #1
u'الشات': u'الشَّاتِ', #1
u'الشادخة': u'الشّادِخَةُ', #1
u'الشادوران': u'الشادوران', #1
u'الشادوف': u'الشَّادُوفُ', #1
u'الشاذروان': u'الشَّاذَرْوَانَ', #12
u'الشاذروان': u'الشاذروان', #3
u'الشاذروان': u'الشَّاذَرْوَانِ', #75
u'الشاذروان': u'الشَّاذَرْوَانُ', #8
u'الشاذكونة': u'الشَّاذَكُونَةِ', #1
u'الشاذكوني': u'الشَّاذَكُونِيَّ', #1
u'الشاذكوني،': u'الشَّاذَكُونِيُّ،', #1
u'الشاذكوني': u'الشَّاذَكُونِيُّ', #2
u'الشاذكوني': u'الشَّاذَكُونِيِّ', #3
u'الشاذكونى': u'الشَّاذَكُونِىُّ', #4
u'الشاذي': u'الشَّاذِيِّ', #9
u'الشاذياخى': u'الشَّاذْيَاخِى', #1
u'الشاذياخى': u'الشَّاذَيَاخِىُّ', #3
u'الشاذياخى': u'الشَّاذْيَاخِىُّ', #9
u'الشارقي': u'الشَّارِقِيُّ', #2
u'الشاركي': u'الشَّارِكِيُّ', #2
u'الشارمساحي': u'الشَّارْمَسَاحِيُّ', #7
u'الشاس': u'الشَّاسِ', #1
u'الشاسي': u'الشَّاسِيَّ', #1
u'الشاسي': u'الشَّاسِيُّ', #1
u'الشاسي': u'الشَّاسِيِّ', #1
u'الشاشى': u'الشَّاشِىُّ', #2
u'الشاط': u'الشَّاطِ', #1
u'الشاط': u'الشَّاطّ', #1
u'الشاط': u'الشَّاطِّ', #395
u'الشاطبي': u'الشاطبي', #1
u'الشاطبي': u'الشَّاطِبِيَّ', #1
u'الشاطبي': u'الشَّاطِبِيِّ', #27
u'الشاطبي': u'الشَّاطِبِيُّ', #31
u'الشاطبية': u'الشَّاطِبِيَّةِ', #8
u'الشاعبة': u'الشَّاعِبَةِ', #2
u'الشاغبينا': u'الشّاغِبِينَا', #2
u'الشاغور': u'الشَّاغُورِ', #3
u'الشاغية': u'الشَّاغِيَةُ', #7
u'الشاغية': u'الشَّاغِيَةِ', #8
u'الشاف': u'الشَّافَّ', #3
u'الشاف': u'الشَّافِّ', #3
u'الشاف': u'الشَّافُّ', #4
u'الشافعى': u'الشَّافِعِىِّ', #172
u'الشافعى': u'الشُّافِعِىُّ', #2
u'الشافعى': u'الشَّافِعِىُّ', #2539
u'الشافعى': u'الشَّافِعِىَّ', #45
u'الشافعىأخبرنا': u'الشَّافِعِىُّأَخْبَرَنَا', #1
u'الشافعيوالدليل': u'الشَّافِعِيُّوَالدَّلِيلُ', #1
u'الشافعييعتد': u'الشَّافِعِيُّيَعْتَدُّ', #1
u'الشافعييقف': u'الشَّافِعِيُّيَقِفُ', #1
u'الشافى': u'الشَّافِى', #6
u'الشالنجي': u'الشالنجي', #1
u'الشالنجي': u'الشَّالَنْجِيِّ', #11
u'الشالنجي': u'الشَّالَنْجِيُّ', #54
u'الشالوسي': u'الشَّالُوسِيُّ', #3
u'الشالوسي': u'الشَّالُوسِيِّ', #4
u'الشآم': u'الشّآمَ', #1
u'الشآم': u'الشَّآمِ', #1
u'الشآم': u'الشّآمُ', #2
u'الشاماتي،': u'الشاماتي،', #1
u'الشاماتي': u'الشَّامَاتِيُّ', #1
u'الشاماتي،': u'الشَّامَاتِيُّ،', #1
u'الشاماتى': u'الشَّامَاتِىُّ', #10
u'الشامى': u'الشَّامِىِّ', #14
u'الشامى': u'الشَّامِىُّ', #22
u'الشاميأن': u'الشَّامِيُّأَنَّ', #1
u'الشاني': u'الشَّانِي', #1
u'الشانية': u'الشَّانِيَةِ', #1
u'الشاهسفرم': u'الشاهسفرم', #1
u'الشاهنبرى': u'الشَّاهَنْبَرِىُّ', #1
u'الشاوي': u'الشَّاوِيُّ', #11
u'الشاوي': u'الشَّاوِي', #3
u'الشاوي': u'الشَّاوِيِّ', #8
u'الشبابة': u'الشَّبَّابَةِ', #11
u'الشبابة': u'الشَّبَّابَةُ', #17
u'الشبابة': u'الشَّبَّابَةَ', #3
u'الشباة': u'الشّبَاةِ', #4
u'الشبامى': u'الشِّبَامِىُّ', #1
u'الشبة': u'الشَّبَّةُ', #1
u'الشبة': u'الشَّبَّةِ', #1
u'الشبت': u'الشَّبِتُّ', #1
u'الشبث': u'الشَّبَثَ', #1
u'الشبراخيتي': u'الشَّبْرَاخِيتِيُّ', #3
u'الشبراملسي': u'الشبراملسي', #38
u'الشبرخيتي': u'الشَّبْرَخِيتِيُّ', #10
u'الشبرخيتي': u'الشَّبْرَخِيتِيِّ', #14
u'الشبرق': u'الشّبْرِقُ', #1
u'الشبرق،': u'الشِّبْرَقُ،', #2
u'الشبرق': u'الشِّبْرَقُ', #3
u'الشبرم': u'الشُّبْرُمَ', #1
u'الشبشيري': u'الشَّبْشِيرِيُّ', #4
u'الشبشيري': u'الشَّبْشِيرِيِّ', #4
u'الشبشيني': u'الشَّبْشِينِيُّ', #1
u'الشبكه': u'الشَّبَكَهْ', #1
u'الشبوبة': u'الشُّبُوبَةِ', #1
u'الشبوبة': u'الشَّبُوبَةِ', #2
u'الشبوبة': u'الشَّبُوبَةَ', #3
u'الشبوبية': u'الشُّبُوبِيَّةُ', #1
u'الشبوبية': u'الشُّبُوبِيَّةِ', #5
u'الشبور': u'الشّبّورَ', #1
u'الشبور': u'الشّبّورِ', #1
u'الشبور': u'الشَّبُّورِ', #1
u'الشبور': u'الشَّبُّورَ', #2
u'الشبور': u'الشَّبُّورُ', #2
u'الشبيني': u'الشَّبِينِيُّ', #1
u'الشتا': u'الشِّتَا', #1
u'الشتر': u'الشَّتَرَ', #1
u'الشتر': u'الشَّتْرُ', #1
u'الشتر': u'الشَّتْرِ', #1
u'الشتراء': u'الشّتْرَاءِ', #1
u'الشتل': u'الشَّتْلُ', #4
u'الشتل': u'الشَّتْلِ', #5
u'الشتل': u'الشَّتْلَ', #6
u'الشتمة': u'الشَّتْمَةِ', #1
u'الشتمة': u'الشِّتْمَةِ', #1
u'الشتمة': u'الشَّتْمَةُ', #2
u'الشتمة': u'الشَّتْمَةَ', #8
u'الشتيم': u'الشّتِيمَ', #1
u'الشجاعى': u'الشُّجَاعِىُّ', #1
u'الشجرSوذكر': u'الشّجَرِSوَذَكَرَ', #1
u'الشجره': u'الشَّجَرَهْ', #1
u'الشجز': u'الشّجْزِ', #1
u'الشجعما': u'الشّجْعَمَا', #1
u'الشجه': u'الشَّجَّهْ', #1
u'الشحات': u'الشَّحَّاتِ', #1
u'الشحامي': u'الشَّحَّامِيُّ', #1
u'الشحامى': u'الشَّحَامِىُّ', #1
u'الشحامى': u'الشَّحَّامِىِّ', #1
u'الشحبة': u'الشَّحِبَةُ', #1
u'الشحبة': u'الشُّحْبَةُ', #1
u'الشحر،': u'الشِّحْرِ،', #1
u'الشحشح': u'الشَّحْشَحُ', #1
u'الشحطبي': u'الشَّحْطَبِيِّ', #1
u'الشحنا': u'الشِّحْنَا', #1
u'الشخاتير': u'الشَّخَاتِيرِ', #1
u'الشخت': u'الشّخْتُ', #1
u'الشخيص': u'الشّخَيْصَ', #1
u'الشخيص': u'الشّخَيْصِ', #1
u'الشداخ': u'الشّدَاخُ', #1
u'الشداخ': u'الشَّدَّاخِ', #1
u'الشداخ': u'الشّدّاخِ', #3
u'الشداخ': u'الشّدّاخَ', #4
u'الشداخ': u'الشّدّاخُ', #4
u'الشدادات': u'الشَّدَّادَاتِ', #1
u'الشدادي': u'الشَّدَّادِيُّ', #1
u'الشدايد': u'الشَّدَايِدَ', #1
u'الشدخ': u'الشّدْخِ', #1
u'الشدخة': u'الشّدْخَةُ', #2
u'الشدخة': u'الشّدْخَةِ', #4
u'الشدخية': u'الشَّدْخِيَّةُ', #1
u'الشدف': u'الشّدَفُ', #1
u'الشدف': u'الشّدُفُ', #1
u'الشدن': u'الشّدُنِ', #2
u'الشديق': u'الشّدِيقِ', #2
u'الشذي': u'الشَّذِي', #1
u'الشرا': u'الشَّرَّا', #1
u'الشرا': u'الشِّرَا', #17
u'الشرابا': u'الشّرَابَا', #1
u'الشراباتي': u'الشَّرَابَاتِيُّ', #1
u'الشرابة': u'الشَّرَابَةِ', #1
u'الشرابة': u'الشُّرَّابَةِ', #1
u'الشرابة': u'الشُّرَّابَةَ', #2
u'الشرابة': u'الشَّرَابَةُ', #3
u'الشرات': u'الشَّرَّاتِ', #1
u'الشراج': u'الشراج', #1
u'الشراج': u'الشّرَاج', #1
u'الشراج': u'الشّرَاجُ', #1
u'الشراج': u'الشَّرَاَجِ', #1
u'الشراج': u'الشّرَاجِ', #2
u'الشراج': u'الشِّرَاجُ', #3
u'الشراج': u'الشِّرَاجِ', #4
u'الشراريب': u'الشَّرَارِيبِ', #5
u'الشراسيف': u'الشَّرَاسِيفِ', #1
u'الشراسيف': u'الشَّرَاسِيفُ', #2
u'الشراط': u'الشُّرَّاطِ', #1
u'الشرائج': u'الشَّرَائِجِ', #2
u'الشرائحي': u'الشَّرَائِحِيَّ', #2
u'الشرائحي': u'الشَّرَائِحِيِّ', #7
u'الشرائحيين': u'الشُّرائِحيِّينَ', #2
u'الشرائر': u'الشَّرَائِرِ', #1
u'الشربة': u'الشَّرْبَةً', #1
u'الشربيني': u'الشِّرْبِينِيُّ', #39
u'الشربيني': u'الشِّرْبِينِيِّ', #6
u'الشرة': u'الشِّرَّةِ', #2
u'الشرجة': u'الشرجة', #1
u'الشرحا': u'الشَّرْحَا', #1
u'الشرخلتي': u'الشرخلتي', #1
u'الشرشير': u'الشَّرْشِيرِ', #1
u'الشرشير': u'الشَّرْشِيرُ', #2
u'الشرطى': u'الشَّرَطَىُّ', #1
u'الشرطى': u'الشُّرْطَى', #1
u'الشرعان': u'الشَّرْعَانِ', #1
u'الشرعب': u'الشّرْعَبُ', #1
u'الشرعبة': u'الشَّرْعَبَةِ', #1
u'الشرعبي،': u'الشَّرْعَبِيُّ،', #1
u'الشرعبي،': u'الشَّرْعَبِيِّ،', #1
u'الشرعبى': u'الشَّرْعَبِىِّ', #1
u'الشرعبي': u'الشَّرْعَبِيُّ', #3
u'الشرعبى': u'الشَّرْعَبِىُّ', #4
u'الشرعين': u'الشِّرْعَيْنِ', #1
u'الشرغي': u'الشَّرْغِيُّ', #1
u'الشرغي': u'الشَّرَغِيُّ', #3
u'الشرفا': u'الشَّرَفَا', #1
u'الشرفا': u'الشُّرَفَا', #1
u'الشرقاء': u'الشَّرْقَاءُ', #11
u'الشرقاء': u'الشَّرْقَاءِ', #5
u'الشرقاوي': u'الشَّرْقَاوِيُّ', #16
u'الشرقاوي': u'الشَّرْقَاوِيَّ', #3
u'الشرقاوي': u'الشَّرْقَاوِيِّ', #41
u'الشرقة': u'الشَّرَقَة', #1
u'الشرقة': u'الشَّرْقَةَ', #1
u'الشرقة': u'الشَّرْقَةُ', #1
u'الشرقى': u'الشَّرْقِىُّ', #16
u'الشرقى': u'الشَّرْقِىِّ', #91
u'الشركا': u'الشِّرْكَا', #1
u'الشركا': u'الشُّرَكَا', #2
u'الشركه': u'الشَّرِكَهْ', #2
u'الشرمان': u'الشّرْمَانُ', #1
u'الشرمان': u'الشِّرْمَانُ', #1
u'الشرمان': u'الشَّرْمَانُ', #2
u'الشرمان': u'الشّرْمَان', #3
u'الشرنبلالي': u'الشُّرُنْبُلَالِيّ', #2
u'الشرنبلالي': u'الشُّرُنْبُلَالِيَّ', #2
u'الشرنبلالي': u'الشُّرُنْبُلَالِيِّ', #35
u'الشرنبلالي': u'الشُّرُنْبُلَالِيُّ', #488
u'الشرنبلالي': u'الشرنبلالي', #5
u'الشرنبلالية': u'الشُّرُنْبُلَالِيَّةَ', #1
u'الشرنبلالية': u'الشرنبلالية', #131
u'الشرنبلالية': u'الشُّرُنْبُلَالِيَّةُ', #3
u'الشرنبلالية': u'الشُّرُنْبُلَالِيَّةِ', #527
u'الشرنبلالية': u'الشُّرُنْبُلَالِيَّة', #71
u'الشرواني': u'الشِّرْوَانِيَّ', #1
u'الشرواني': u'الشِّرْوَانِيُّ', #2
u'الشرواني': u'الشِّرْوَانِيِّ', #4
u'الشروحات': u'الشّرُوحَاتِ', #1
u'الشروحات': u'الشُّرُوحَاتِ', #3
u'الشروطي': u'الشُّرُوطِيَّ', #1
u'الشروطي': u'الشُّرُوطِيُّ', #17
u'الشروطي': u'الشُّرُوطِيِّ', #2
u'الشروطيون': u'الشُّرُوطِيُّونَ', #1
u'الشريب': u'الشَّرِيب', #1
u'الشريب': u'الشِّرِّيبُ', #2
u'الشريب': u'الشّرِيبُ', #3
u'الشريجة': u'الشَّرِيجَةِ', #1
u'الشريجة': u'الشَّرِيجَةُ', #2
u'الشريحي': u'الشُّرَيْحِيِّ', #1
u'الشريحى': u'الشُرَيْحِىُّ', #1
u'الشريحى': u'الشُّرَيْحِىُّ', #19
u'الشريحية': u'الشَّرِيحِيَّةَ', #2
u'الشريحية': u'الشَّرِيحِيَّةِ', #3
u'الشريحية': u'الشُّرَيْحِيَّةُ', #3
u'الشريحية': u'الشُّرَيْحِيَّةَ', #5
u'الشريشي': u'الشَّرِيشِيُّ', #2
u'الشريشي': u'الشَّرِيشِيِّ', #4
u'الشريفية': u'الشَّرِيفِيَّةِ', #2
u'الشريكا': u'الشَّرِيكَا', #2
u'الشسع': u'الشِّسْع', #1
u'الشسع': u'الشسع', #2
u'الشسع': u'الشِّسْعِ', #2
u'الشسع': u'الشِّسْعُ', #3
u'الشسع': u'الشِّسْعَ', #5
u'الشطء': u'الشَّطْءِ', #1
u'الشطاة': u'الشَّطَاةِ', #1
u'الشطاة': u'الشّطاة', #2
u'الشطح': u'الشَّطْحُ', #1
u'الشطن': u'الشطن', #1
u'الشطوي': u'الشَّطَوِيَّ', #2
u'الشطوي': u'الشَّطَوِيُّ', #2
u'الشطوى': u'الشَّطَوِىُّ', #2
u'الشطوي': u'الشَّطَوِيِّ', #9
u'الشطوية': u'الشطوية', #1
u'الشظاة': u'الشَّظَاةَ', #1
u'الشظاة': u'الشَّظَاةُ', #2
u'الشظاة': u'الشَّظَاةِ', #5
u'الشظاظ': u'الشِّظَاظُ', #1
u'الشظفاء': u'الشَّظْفَاءِ', #1
u'الشعبا': u'الشّعْبَا', #4
u'الشعبانى': u'الشَّعْبَانِىُّ', #1
u'الشعبانى': u'الشَّعْبَانِىِّ', #1
u'الشعبذة': u'الشَّعْبَذَةَ', #2
u'الشعبذة': u'الشَّعْبَذَةُ', #3
u'الشعبذة': u'الشَّعْبَذَةِ', #8
u'الشعبى': u'الشَّعْبِى', #1
u'الشعبى': u'الشَّعْبِىَّ', #46
u'الشعبى': u'الشَّعْبِىِّ', #590
u'الشعبى': u'الشَّعْبِىُّ', #65
u'الشعبيأنه': u'الشَّعْبِيِّأَنَّهُ', #1
u'الشعبيفي': u'الشَّعْبِيِّفِي', #1
u'الشعبينزلت': u'الشَّعْبِيُّنَزَلَتِ', #1
u'الشعرانى': u'الشَّعَرَانِىُّ', #1
u'الشعرانى': u'الشَّعْرَانِىَّ', #1
u'الشعرانى': u'الشَّعْرَانِىِّ', #2
u'الشعرانى': u'الشَّعْرَانِىُّ', #49
u'الشعوثة': u'الشُّعُوثَةَ', #1
u'الشعئر': u'الشعئر', #1
u'الشعيبة': u'الشّعيبةِ', #1
u'الشعيبة': u'الشّعَيْبَةَ', #1
u'الشعيبة،': u'الشُّعَيْبَةِ،', #1
u'الشعيبة': u'الشّعَيْبَةِ', #5
u'الشعيبي': u'الشُّعَيْبِيُّ', #1
u'الشعيبى': u'الشُّعَيْبِىُّ', #4
u'الشعيثي': u'الشُّعَيْثِيِّ', #1
u'الشعيثي،': u'الشُّعَيْثِيِّ،', #1
u'الشعيثى': u'الشَّعُيْثِىِّ', #1
u'الشعيثى': u'الشُّعَيْثِىَّ', #1
u'الشعيثي': u'الشُّعَيْثِيُّ', #11
u'الشعيثي،': u'الشُّعَيْثِيُّ،', #4
u'الشعيرى': u'الشُّعَيْرِىُّ', #3
u'الشعيرى': u'الشَّعِيرِىُّ', #6
u'الشعيرين': u'الشَّعِيرَيْنِ', #1
u'الشغارة': u'الشِّغَارَةِ', #1
u'الشغوش': u'الشّغُوشَ', #2
u'الشغوش': u'الشّغُوشِ', #3
u'الشفاعه': u'الشَّفَاعَهْ', #2
u'الشفافير': u'الشَّفَافِيرِ', #1
u'الشفش': u'الشفش', #1
u'الشفش': u'الشَّفْشُ', #1
u'الشفعه': u'الشُّفْعَهْ', #1
u'الشفعوي': u'الشَّفْعَوِيِّ', #10
u'الشفعوي': u'الشَّفْعَوِيُّ', #6
u'الشفعوية': u'الشَّفْعَوِيَّةُ', #1
u'الشفعوية': u'الشَّفْعَوِيَّةِ', #2
u'الشفقين': u'الشَّفَقَيْنِ', #4
u'الشفوع': u'الشَّفُوعِ', #3
u'الشفيف': u'الشّفِيفَ', #1
u'الشفيف': u'الشّفِيفُ', #2
u'الشقارير': u'الشّقَارِيرُ', #1
u'الشقايق': u'الشَّقَايِقَ', #1
u'الشقدف': u'الشُّقْدُفِ', #1
u'الشقرى': u'الشَّقَرِىُّ', #4
u'الشقص': u'الشقص', #1
u'الشقص': u'الشِّقْص', #2
u'الشقص': u'الشِّقْصُ', #266
u'الشقص': u'الشِّقْصَ', #610
u'الشقص': u'الشِّقْصِ', #901
u'الشقصان': u'الشِّقْصَانِ', #2
u'الشقصية': u'الشِّقْصِيَّةَ', #1
u'الشقصين': u'الشِّقْصَيْنِ', #8
u'الشقه': u'الشُّقَّهْ', #1
u'الشقوص': u'الشُّقُوصُ', #1
u'الشقى': u'الشَّقِىُّ', #2
u'الشقيري': u'الشقيري', #1
u'الشقيريالكتاب': u'الشقيريالكتاب', #1
u'الشقيص': u'الشَّقِيصُ', #1
u'الشقيص': u'الشَّقِيصِ', #1
u'الشقيص': u'الشقيص', #2
u'الشقيص': u'الشَّقِيص', #2
u'الشقيقي،': u'الشَّقِيقِيُّ،', #2
u'الشقيقية': u'الشَّقِيقِيَّةَ', #1
u'الشكاز': u'الشَّكَّازُ', #3
u'الشكران': u'الشُّكْرَانُ', #1
u'الشكرين': u'الشُّكْرَيْنِ', #2
u'الشكولي': u'الشَّكُولِيِّ', #1
u'الشكير': u'الشّكِيرِ', #1
u'الشكير': u'الشَّكِيرِ', #1
u'الشكير': u'الشكير', #2
u'الشلبة': u'الشَّلَبَةِ', #1
u'الشلبي': u'الشَّلَبِيِّ', #148
u'الشلبي': u'الشَّلَبِيَّ', #3
u'الشلبي': u'الشَّلَبِيُّ', #72
u'الشلجم': u'الشَّلْجَمُ', #2
u'الشلق': u'الشَّلْقِ', #1
u'الشلوبين': u'الشَّلَوْبِينِ', #1
u'الشلوبين': u'الشَّلَوْبِينَ', #4
u'الشلوبين': u'الشَّلَوْبِينُ', #5
u'الشلوبيني': u'الشَّلَوْبِينِيُّ', #1
u'الشلوح': u'الشُّلُوحُ', #1
u'الشلوفين': u'الشَّلُوفِينَ', #1
u'الشلي': u'الشَّلِّيِّ', #1
u'الشلي': u'الشَّلِّيُّ', #3
u'الشليل': u'الشّلَيْلُ', #1
u'الشما': u'الشّمَا', #2
u'الشماريخ': u'الشماريخ', #1
u'الشماريخ': u'الشَّمَارِيخ', #1
u'الشماريخ': u'الشَّمَارِيخُ', #10
u'الشماريخ': u'الشَّمَارِيخِ', #13
u'الشماريخ': u'الشَّمَارِيخَ', #4
u'الشماسة': u'الشّمّاسَةِ', #1
u'الشماطيط': u'الشّمَاطِيطُ', #1
u'الشمأل': u'الشَّمْأَلُ', #1
u'الشمامسة': u'الشَّمَامِسَةُ', #1
u'الشمامسة': u'الشَّمَامِسَةِ', #1
u'الشمامسة': u'الشّمَامِسَةِ', #3
u'الشمامسة': u'الشَّمَامِسَةَ', #3
u'الشمت': u'الشَّمْتِ', #1
u'الشمت': u'الشُّمُتْ', #1
u'الشمردل': u'الشَّمَرْدَلِ', #6
u'الشمرلسي': u'الشَّمَرْلِسِيُّ', #1
u'الشمساااا': u'الشَّمْسُاااا', #1
u'الشمشك': u'الشمشك', #1
u'الشمط': u'الشّمَطُ', #1
u'الشمط': u'الشَّمَطَ', #1
u'الشمط': u'الشُّمْطُ', #1
u'الشمط': u'الشّمْطِ', #2
u'الشمط': u'الشَّمَط', #2
u'الشمط': u'الشَّمَطِ', #2
u'الشمط': u'الشَّمْطُ', #2
u'الشمط': u'الشَّمَطُ', #8
u'الشمطات': u'الشمطات', #1
u'الشمعونية': u'الشَّمْعُونِيَّةُ', #1
u'الشمني': u'الشُّمُنِّيّ', #1
u'الشمني': u'الشُّمُنِّيِّ', #106
u'الشمني': u'الشُّمُنِّيَّ', #3
u'الشمني': u'الشُّمُنِّيُّ', #90
u'الشميط': u'الشّمِيطِ', #1
u'الشميط': u'الشُّمَيْطِ', #1
u'الشناتر': u'الشّنَاتِرُ', #1
u'الشنار': u'الشَّنَارُ', #3
u'الشناوي': u'الشِّنَّاوِيِّ', #1
u'الشناوي': u'الشِّنَّاوِيُّ', #2
u'الشنائى': u'الشَّنَائِىُّ', #1
u'الشنبر': u'الشِّنْبَرِ', #1
u'الشنبر': u'الشَّنْبَرَ', #2
u'الشنبر': u'الشَّنْبَرِ', #3
u'الشنة': u'الشنة', #1
u'الشندخي': u'الشَّنْدَخِيِّ', #1
u'الشندخية': u'الشُّنْدُخِيَّةُ', #1
u'الشنذة': u'الشّنَذَةِ', #1
u'الشنشوري': u'الشَّنْشَوْرِيِّ', #5
u'الشنشوري': u'الشِّنْشَوْرِيُّ', #5
u'الشنشوري': u'الشِّنْشَوْرِيِّ', #7
u'الشنظير': u'الشنظير', #1
u'الشنظير': u'الشَّنْظِيرُ', #1
u'الشنفرى': u'الشَّنْفَرَى', #1
u'الشنقيطي': u'الشنقيطي', #1
u'الشنقيطي': u'الشِّنْقِيطِيُّ', #1
u'الشنواني': u'الشَّنَوَانِيِّ', #13
u'الشنواني': u'الشَّنَوَانِيُّ', #16
u'الشنوي': u'الشَّنَوِيِّ', #1
u'الشنوئي': u'الشَّنُوئِيّ', #2
u'الشني': u'الشَّنِّيَّ', #1
u'الشني،': u'الشَّنِّيُّ،', #1
u'الشني': u'الشّنّيّ', #2
u'الشني': u'الشَّنِّيُّ', #3
u'الشنئى': u'الشَّنَئِىُّ', #1
u'الشنئين': u'الشَّنِئِينَ', #1
u'الشهاده': u'الشَّهَادَهْ', #3
u'الشهاردة': u'الشَّهَارْدَةِ', #1
u'الشهاوي': u'الشَّهَاوِيِّ', #3
u'الشهاوي': u'الشَّهَاوِيُّ', #6
u'الشهبرة': u'الشَّهْبَرَةُ', #1
u'الشهبرة': u'الشَّهْبَرَةِ', #2
u'الشهة': u'الشهة', #1
u'الشهدا': u'الشُّهْدَا', #1
u'الشهدا': u'الشُّهَدَا', #2
u'الشهدانج': u'الشَّهْدَانِجُ', #1
u'الشهرزوري': u'الشَّهْرَزُورِيِّ', #1
u'الشهرزورى': u'الشَّهْرُزُورِىُّ', #1
u'الشهرستاني': u'الشِّهْرِسْتَانِيُّ', #1
u'الشهرستاني': u'الشِّهْرِسْتَانِيّ', #10
u'الشهزاده': u'الشهزاده', #1
u'الشهوري': u'الشُّهُورِيُّ', #2
u'الشهولة': u'الشُّهُولَةَ', #1
u'الشهيدي': u'الشَّهِيدِيُّ', #1
u'الشهيدى': u'الشَّهِيدِىِّ', #1
u'الشواءة': u'الشَّوَّاءَةَ', #1
u'الشواب': u'الشَّوَابَّ', #10
u'الشواب': u'الشَّوَابِّ', #10
u'الشواب': u'الشّوَابّ', #2
u'الشواب': u'الشَّوَابُّ', #9
u'الشوابإليه': u'الشَّوَابِّإِلَيْهِ', #1
u'الشوازب': u'الشّوَازِبُ', #1
u'الشوازب': u'الشّوَازِبِ', #3
u'الشوام': u'الشَّوَامِ', #1
u'الشوائين': u'الشَّوَّائِينَ', #2
u'الشوبري': u'الشَّوْبَرِيَّ', #2
u'الشوبري': u'الشَّوْبَرِيِّ', #206
u'الشوبري': u'الشَّوْبَرِيُّ', #257
u'الشوحط': u'الشّوْحَطِ', #1
u'الشوراب،': u'الشوراب،', #1
u'الشورة': u'الشَّوْرَةَ', #1
u'الشورة': u'الشُّورَةَ', #2
u'الشورة': u'الشَّوْرَةُ', #3
u'الشورة': u'الشُّورَةُ', #5
u'الشورة': u'الشَّوْرَةِ', #7
u'الشورة': u'الشُّورَةِ', #8
u'الشوشة': u'الشُّوشَةِ', #1
u'الشوشة': u'الشُّوشَةُ', #3
u'الشوصة': u'الشَّوْصَةَ', #1
u'الشوصة': u'الشَّوْصَةُ', #1
u'الشوصة': u'الشَّوْصَةِ', #2
u'الشوم': u'الشُّومُ', #12
u'الشوم': u'الشُّومِ', #5
u'الشوم': u'الشُّومَ', #6
u'الشوماء': u'الشَّوْمَاءُ', #1
u'الشون': u'الشُّوَنُ', #4
u'الشون': u'الشُّوَنِ', #4
u'الشونيز،': u'الشُّونِيزُ،', #1
u'الشونيز': u'الشُّونِيزِ', #10
u'الشونيز': u'الشُّونِيزُ', #22
u'الشونيز': u'الشُّونِيزَ', #3
u'الشونيزي،': u'الشُّونِيزِيُّ،', #1
u'الشويكي': u'الشُّوَيْكِيُّ', #2
u'الشىء': u'الشَّىْءُ', #16
u'الشىء': u'الشَّىْءَ', #21
u'الشىء': u'الشىء', #23
u'الشىء': u'الشَّىْءِ', #36
u'الشياب': u'الشياب', #1
u'الشياب': u'الشَّيَّابِ', #1
u'الشياع': u'الشِّيَاع', #1
u'الشياع': u'الشّيَاعِ', #1
u'الشياع؟': u'الشِّيَاعُ؟', #1
u'الشياع': u'الشِّيَاعُ', #10
u'الشياع': u'الشِّيَاعِ', #21
u'الشياع': u'الشِّيَاعَ', #6
u'الشيبانى': u'الشَّيْبَانِىَّ', #11
u'الشيبانى': u'الشَّيْبَانِىِّ', #161
u'الشيبانى': u'الشَّيْبَانِىُّ', #256
u'الشيخونية': u'الشَّيْخُونِيَّةِ', #11
u'الشيدن': u'الشِّيدنِ', #1
u'الشير': u'الشَّيِّرَ', #1
u'الشيرازة': u'الشِّيرَازَةِ', #1
u'الشيرازة': u'الشِّيرَازِةِ', #1
u'الشيرازي،': u'الشيرازي،', #1
u'الشيرازى': u'الشِّيرَازِىِّ', #1
u'الشيرازى': u'الشَّيِرَازِىُّ', #1
u'الشيرازي،': u'الشِّيرَازِيُّ،', #2
u'الشيرازي': u'الشِّيرَازِيُّ', #243
u'الشيرازى': u'الشِّيرَازِىُّ', #39
u'الشيرازي': u'الشِّيرَازِيّ', #4
u'الشيرازي': u'الشِّيرَازِيَّ', #8
u'الشيرازي': u'الشِّيرَازِيِّ', #90
u'الشيرازيات': u'الشِّيرَازِيَّاتِ', #4
u'الشيرازية': u'الشّيرَازِيّةِ', #1
u'الشيراماذي': u'الشِّيرَامَاذِيُّ', #1
u'الشيرخ': u'الشيرخ', #1
u'الشيرخشك': u'الشيرخشك', #2
u'الشيرزي': u'الشَّيْرَزِيَّ', #1
u'الشيرزي': u'الشَّيْرَزِيُّ', #11
u'الشيرق': u'الشيرق', #1
u'الشيزات': u'الشِّيزَاتُ', #1
u'الشيزري': u'الشَّيْزَرِيُّ', #1
u'الشيزري': u'الشَّيْزَرِيِّ', #4
u'الشيزي': u'الشّيزَي', #1
u'الشيزى': u'الشِّيزَى', #1
u'الشيزى': u'الشّيزَى', #4
u'الشيشني': u'الشِّيشْنِيُّ', #5
u'الشيص': u'الشيص', #1
u'الشيص': u'الشِّيص', #1
u'الشيص': u'الشِّيصَ', #1
u'الشيص': u'الشِّيصِ', #1
u'الشيص': u'الشّيصِ', #1
u'الشيطان': u'الشَّيْطَانًًًًِ', #1
u'الشيطانة': u'الشَّيْطَانَةُ', #1
u'الشيطانة': u'الشّيْطَانَةَ', #2
u'الشيطانوروي': u'الشَّيْطَانِوَرُوِيَ', #1
u'الشيعى': u'الشَّيْعِىُّ', #1
u'الشيلم': u'الشَّيْلَمَ', #2
u'الشيلمانى': u'الشَّيْلَمَانِىُّ', #1
u'الشيماء': u'الشَّيْمَاءُ', #2
u'الشيماء': u'الشّيْمَاءِ', #2
u'الشيماء': u'الشّيْمَاءَ', #5
u'الشيماء': u'الشّيْمَاءُ', #5
u'الشينم': u'الشَّيْنَمَ', #1
u'الشينيز': u'الشَّيْنِيزُ', #1
u'الشيهم': u'الشّيْهَمِ', #1
u'الشيوخة': u'الشُّيُوخَة', #1
u'الشيوخة': u'الشُّيُوخَةَ', #1
u'الشيوخة': u'الشُّيُوخَةِ', #3
u'الشيوم': u'الشّيُومَ', #1
u'الشيىء': u'الشيىء', #3
u'الشيئة': u'الشّيئَةَ', #1
u'الشيئة': u'الشّيئَةُ', #1
u'الص': u'الص', #1
u'الص': u'الصّ', #1
u'الصا': u'الصَّا', #1
u'الصاء': u'الصَّاءِ', #1
u'الصابونى': u'الصَّابُونِىِّ', #1
u'الصابونى': u'الصَّابُونِىُّ', #3
u'الصابونين': u'الصَّابُونَيْنِ', #2
u'الصابىء': u'الصابىء', #1
u'الصابئي': u'الصَّابِئِيَّ', #1
u'الصابئي': u'الصَّابِئِي', #2
u'الصابئيات': u'الصَّابِئِيَّاتُ', #1
u'الصابئية': u'الصَّابِئِيَّةَ', #1
u'الصابئية': u'الصَّابِئِيَّةُ', #3
u'الصابئية': u'الصَّابِئِيَّةِ', #3
u'الصاج': u'الصَّاجِ', #2
u'الصاحبية': u'الصَّاحِبِيَّةِ', #1
u'الصاحبينا': u'الصَّاحِبِينَا', #1
u'الصاروج': u'الصَّارُوجَ', #1
u'الصاروج': u'الصَّارُوجِ', #1
u'الصاروج': u'الصَّارُوجُ', #4
u'الصاعدى': u'الصَّاعِدِىِّ', #1
u'الصاغاني،': u'الصاغاني،', #1
u'الصاغاني': u'الصَّاغَانِي', #1
u'الصاغاني،': u'الصَّاغَانِيُّ،', #117
u'الصاغانى': u'الصَّاغَانِىُّ', #2
u'الصاغاني': u'الصَّاغَانِيُّ', #44
u'الصاغاني': u'الصَّاغَانِيِّ', #7
u'الصاغاني،': u'الصَّاغَانِيِّ،', #8
u'الصافر': u'الصَّافِرِ', #1
u'الصافنات': u'الصَّافِنَاتُ', #5
u'الصافى': u'الصَّافِى', #1
u'الصأك': u'الصَّأَك', #1
u'الصألة': u'الصَّأْلَةِ', #1
u'الصالحه': u'الصَّالِحَهْ', #1
u'الصالحي': u'الصَّالِحِيِّ', #3
u'الصالحي': u'الصَّالِحِيُّ', #7
u'الصالحية': u'الصَّالِحِيَّةِ', #10
u'الصالغ': u'الصَّالِغُ', #1
u'الصالغ': u'الصَّالِغِ', #1
u'الصالقة': u'الصالقة', #1
u'الصالقة': u'الصَّالِقَةِ', #10
u'الصالقة': u'الصَّالِقَةَ', #4
u'الصامتي،': u'الصامتي،', #1
u'الصاني': u'الصَّانِيِّ', #1
u'الصائدى': u'الصَّائِدِىِّ', #1
u'الصائمونوروي': u'الصَّائِمُونَوَرُوِيَ', #1
u'الصايغ': u'الصَّايِغِ', #1
u'الصايغ،': u'الصَّايِغَ،', #1
u'الصايغ،': u'الصَّايِغِ،', #11
u'الصايغ،': u'الصَّايِغُ،', #2
u'الصبات': u'الصَّبَّاتِ', #1
u'الصباج': u'الصَّبَّاجِ', #1
u'الصباحى': u'الصَّبَّاحِىُّ', #1
u'الصباع': u'الصَّبَّاعِ', #1
u'الصباوة': u'الصَّبَاوَةِ', #1
u'الصبب': u'الصَّبَبِ', #2
u'الصبة': u'الصَّبَّةَ', #1
u'الصبة': u'الصُّبَّة', #1
u'الصبحا': u'الصُّبْحَا', #1
u'الصبحوالوجه': u'الصُّبْحِوَالْوَجْهُ', #1
u'الصبحى': u'الصَّبْحَى', #1
u'الصبرا': u'الصَّبِرَا', #1
u'الصبغاء': u'الصَّبْغَاءَ', #2
u'الصبغاني': u'الصَّبْغَانِيِّ', #1
u'الصبغى': u'الصِّبغِىُّ', #1
u'الصبغى': u'الصِّبْغِىُّ', #18
u'الصبغى': u'الصَّبَغِىُّ', #2
u'الصبغى': u'الصَّبْغِىُّ', #3
u'الصبهاء': u'الصّبْهَاءِ', #1
u'الصبوب': u'الصبوب', #1
u'الصبى': u'الصُّبَىُّ', #1
u'الصبى؟': u'الصَّبِىُّ؟', #1
u'الصبى': u'الصَّبِىَّ', #19
u'الصبى': u'الصَّبِىُّ', #29
u'الصبى': u'الصبى', #4
u'الصبى': u'الصُّبَىِّ', #4
u'الصبى': u'الصَّبِىِّ', #64
u'الصبيحه': u'الصَّبِيحَهْ', #1
u'الصبيحي': u'الصَّبِيحِيُّ', #1
u'الصبيحي،': u'الصُّبَيْحِيُّ،', #1
u'الصبيحي،': u'الصُّبَيْحِيِّ،', #1
u'الصبيحي،': u'الصَّبِيحِيُّ،', #3
u'الصح': u'الصِّحِ', #1
u'الصحا': u'الصَّحَا', #1
u'الصحابةوكثر': u'الصَّحَابَةِوَكَثَّرَ', #1
u'الصحابى': u'الصَّحَابِىَّ', #2
u'الصحاصح': u'الصّحَاصِحُ', #1
u'الصحافين': u'الصَّحَّافِينَ', #2
u'الصحرا': u'الصَّحْرَا', #1
u'الصحناء': u'الصَّحْنَاءُ', #1
u'الصحناء': u'الصَّحْنَاءِ', #1
u'الصحناة': u'الصِّحْنَاةُ', #1
u'الصحناة': u'الصِّحْنَاةِ', #1
u'الصحناة': u'الصَّحْنَاةُ', #2
u'الصحيحا': u'الصَّحِيحَا', #1
u'الصحيحه': u'الصَّحِيحَهْ', #2
u'الصحيحي': u'الصَّحِيحَيْ', #1
u'الصخار': u'الصِّخَارِ', #2
u'الصخره': u'الصخره', #1
u'الصخيرات': u'الصُّخَيْرَاتِ', #1
u'الصداء': u'الصِّدَاءَ', #1
u'الصداء': u'الصِّدَاءُ', #3
u'الصداء': u'الصِّدَاءِ', #4
u'الصداقوالوجه': u'الصَّدَاقِوَالْوَجْهُ', #1
u'الصدائي': u'الصدائي', #1
u'الصدائي': u'الصَّدَائِيُّ', #1
u'الصدائي،': u'الصُّدَائِيِّ،', #1
u'الصدائي': u'الصُّدَائِيِّ', #16
u'الصدائي،': u'الصُّدَائِيَّ،', #2
u'الصدائي،': u'الصُّدَائِيُّ،', #2
u'الصدائي': u'الصُّدَائِيَّ', #3
u'الصدائي': u'الصُّدَائِيُّ', #3
u'الصدائى': u'الصُّدَائِىُّ', #3
u'الصدائى': u'الصُّدَائِىِّ', #3
u'الصدائى': u'الصُّدَائِىَّ', #5
u'الصدعين': u'الصَّدْعَيْنِ', #1
u'الصدفى': u'الصَّدَفِىُّ', #16
u'الصدفى': u'الصَّدَفِىِّ', #4
u'الصدفين': u'الصَّدَفَيْنِ', #4
u'الصدقاتوالوجه': u'الصَّدَقَاتِوَالْوَجْهُ', #1
u'الصدقة': u'الصَدَقَةً', #1
u'الصدقه': u'الصَّدَقَهْ', #2
u'الصدورS': u'الصّدُورُS', #1
u'الصدوع': u'الصُّدُوعِ', #1
u'الصديء': u'الصَّدِيءِ', #1
u'الصديري': u'الصَّدِيرِيّ', #1
u'الصديع': u'الصّدِيعُ', #1
u'الصراة': u'الصَّراة', #1
u'الصراة': u'الصَّرَاةُ', #1
u'الصراة،': u'الصَّرَاةَ،', #1
u'الصراة': u'الصَّرَاةِ', #8
u'الصراصر': u'الصَّرَاصِرُ', #1
u'الصراصر': u'الصَّرَاصِرِ', #2
u'الصرائح': u'الصَّرَائِح', #1
u'الصرائح': u'الصَّرَائِحَ', #1
u'الصرائح': u'الصَّرَائِحُ', #5
u'الصرائح': u'الصَّرَائِحِ', #58
u'الصرحة': u'الصَّرْحَة', #2
u'الصرخدي': u'الصّرْخَدِيّ', #1
u'الصرخدية': u'الصّرْخَدِيّةُ', #1
u'الصرصار': u'الصِّرْصَارُ', #4
u'الصرغتمشية': u'الصرغتمشية', #5
u'الصرفا': u'الصَّرْفَا', #1
u'الصرناي': u'الصُّرْنَايَ', #1
u'الصرناي': u'الصُّرْنَايِ', #1
u'الصرورة': u'الصَّرُورَةُ', #16
u'الصرورة': u'الصَّرُورَةَ', #23
u'الصرورة': u'الصَّرُورَةِ', #85
u'الصرورية': u'الصَّرُورِيَّةُ', #1
u'الصروفات': u'الصُّرُوفَاتِ', #1
u'الصرى': u'الصّرَى', #1
u'الصريرة': u'الصّرَيّرَةُ', #1
u'الصريرة': u'الصّرَيّرَةِ', #1
u'الصريفني': u'الصَّرِيفِنِيُّ', #1
u'الصريفيني': u'الصَّرِيفِينِيُّ', #1
u'الصريفيني،': u'الصَّرِيفِينِيُّ،', #1
u'الصريفيني': u'الصُّرَيْفِينِيُّ', #1
u'الصريفينى': u'الصَّرِيفِينِىُّ', #1
u'الصريقة': u'الصَّرِيقَةِ', #1
u'الصريمي': u'الصَّرِيمِيُّ', #1
u'الصريمي،': u'الصُّرَيْمِيُّ،', #1
u'الصريمي،': u'الصَّرِيمِيُّ،', #3
u'الصريمية': u'الصريمية', #1
u'الصريمية': u'الصُّرَيْمِيَّةُ', #1
u'الصريمية': u'الصُّرَيْمِيَّةِ', #1
u'الصعالك': u'الصّعَالِكِ', #3
u'الصعائدة': u'الصَّعَائِدَةِ', #1
u'الصعدات': u'الصعدات', #1
u'الصعدات': u'الصُّعُدَات', #1
u'الصعدات': u'الصّعَدَاتِ', #2
u'الصعدات': u'الصُّعُدَاتِ', #20
u'الصعر': u'الصَّعَرُ', #1
u'الصعر': u'الصَّعْرِ', #1
u'الصعر': u'الصَّعَرِ', #6
u'الصعلوكى': u'الصَّعْلُوكِىُّ', #1
u'الصعو': u'الصَّعْوُ', #1
u'الصغارا': u'الصِّغَارَا', #1
u'الصغاني': u'الصَّغَانِي', #1
u'الصغاني': u'الصَّغَانِيَّ', #1
u'الصغاني،': u'الصَّغَانِيّ،', #1
u'الصغانى': u'الصَّغَانِىَّ', #1
u'الصغانى': u'الصَّغْانِىُّ', #1
u'الصغانى': u'الصُّغَانِىُّ', #1
u'الصغانى': u'الصَّغَانِىِّ', #17
u'الصغانى': u'الصَّغَانِىُّ', #382
u'الصغاني،': u'الصَّغَانِيِّ،', #388
u'الصغاني': u'الصغاني', #4
u'الصغاني': u'الصَّغَانِيّ', #4
u'الصغانى': u'الصَّغَّانِىُّ', #4
u'الصغاني': u'الصَّغَانِيِّ', #49
u'الصغاني،': u'الصغاني،', #64
u'الصغاني': u'الصَّغَانِيُّ', #73
u'الصغاني،': u'الصَّغَانِيُّ،', #944
u'الصغد': u'الصُغد', #1
u'الصغد': u'الصُّغْدُ', #1
u'الصغدي': u'الصغدي', #1
u'الصغدى': u'الصُّغْدِىُّ', #1
u'الصغدي،': u'الصُّغْدِيُّ،', #2
u'الصغدية': u'الصّغْدِيّةُ', #1
u'الصغيراء': u'الصَّغِيرَاءِ', #1
u'الصغيرورحمة': u'الصَّغِيرِوَرَحْمَةً', #1
u'الصفاة': u'الصفاة', #1
u'الصفاة': u'الصّفَاةُ', #1
u'الصفاة': u'الصَّفَاةِ', #2
u'الصفاة': u'الصّفَاةَ', #3
u'الصفاتية': u'الصِّفَاتِيَّةِ', #1
u'الصفاف': u'الصِّفَافِ', #3
u'الصفافة': u'الصَّفَّافَةُ', #1
u'الصفاقسي': u'الصَّفَاقُسِيُّ', #2
u'الصفاقصي': u'الصَّفَاقُصِيُّ', #1
u'الصفاني،': u'الصفََّانِيُّ،', #1
u'الصفاني': u'الصَّفَّانِيُّ', #1
u'الصفائق': u'الصَّفَائِقِ', #1
u'الصفائق': u'الصّفَائِقِ', #2
u'الصفتي': u'الصَّفْتِيِّ', #1
u'الصفتي': u'الصَّفْتِيُّ', #3
u'الصفحتى': u'الصَّفِّحَتَّى', #1
u'الصفر،': u'الصُّفًّر،', #1
u'الصفره': u'الصُّفْرَهْ', #1
u'الصفقوله': u'الصَّفَّقَوْلُهُ', #1
u'الصفه': u'الصِّفَهْ', #3
u'الصفوري': u'الصَّفُّورِيُّ', #1
u'الصفون': u'الصُّفُونَ', #2
u'الصفوين': u'الصَّفَوَيْنِ', #1
u'الصفى': u'الصَّفِىِّ', #6
u'الصفيرا': u'الصَّفِيرَا', #1
u'الصفيرا': u'الصُّفَيْرَا', #2
u'الصفيراء': u'الصفيراء', #1
u'الصفيراء': u'الصُّفَيْرَاءِ', #2
u'الصقالبة': u'الصَّقَالِبَةَ', #1
u'الصقالبة،': u'الصَّقَالِبَةِ،', #1
u'الصقالبة': u'الصَّقَالِبَةُ', #2
u'الصقالبة': u'الصَّقَالِبَةِ', #21
u'الصقب': u'الصَّقَبَ', #3
u'الصقراط': u'الصِّقْرَاطُ', #1
u'الصقعب،': u'الصَّقْعَبِ،', #1
u'الصقعب؟': u'الصَّقْعَبِ؟', #1
u'الصقعب': u'الصَّقْعَبَ', #2
u'الصقعب': u'الصَّقْعَبِ', #2
u'الصقعب': u'الصَّقْعَبُ', #3
u'الصقفي،': u'الصَّقَفِيُّ،', #1
u'الصقلاوون': u'الصَّقْلَاوُونَ', #1
u'الصقلبية': u'الصَّقْلَبِيَّةَ', #1
u'الصقليون': u'الصِّقِلِّيُونَ', #1
u'الصكاء': u'الصَّكَّاءُ', #2
u'الصكاك': u'الصَّكَّاكَ', #1
u'الصكاك': u'الصَّكَّاكُ', #2
u'الصكاك': u'الصِّكَاكَ', #3
u'الصكاك': u'الصَّكَّاكِ', #7
u'الصكاك': u'الصِّكَاكِ', #8
u'الصكاكين': u'الصَّكَّاكِينَ', #8
u'الصكك': u'الصَّكَكُ', #1
u'الصلا': u'الصّلَا', #3
u'الصلا': u'الصَّلَا', #3
u'الصلاب': u'الصِّلَابُ', #1
u'الصلاة': u'الصَّلَاةًًًًِ', #1
u'الصلاةإذا': u'الصَّلَاةِإِذَا', #1
u'الصلاةإلى': u'الصَّلَاةَإِلَى', #1
u'الصلاةأن': u'الصَّلَاةَأَنَّ', #1
u'الصلاةفلأنها': u'الصَّلَاةِفَلِأَنَّهَا', #1
u'الصلاةفي': u'الصَّلَاةُفِي', #1
u'الصلاةفي': u'الصَّلَاةِفِي', #2
u'الصلاةفيتعلق': u'الصَّلَاةِفَيَتَعَلَّقُ', #1
u'الصلاةقبل': u'الصَّلَاةِقَبْلَ', #1
u'الصلاةكصلاة': u'الصَّلَاةِكَصَلَاةِ', #1
u'الصلاةلإزالة': u'الصَّلَاةِلِإِزَالَةِ', #1
u'الصلاةلأنه': u'الصَّلَاةِلِأَنَّهُ', #1
u'الصلاةوالثاني': u'الصَّلَاةُوَالثَّانِي', #1
u'الصلاةوبعدها': u'الصَّلَاةِوَبَعْدَهَا', #1
u'الصلاةوكان': u'الصَّلَاةَوَكَانَ', #1
u'الصلاةويعجله': u'الصَّلَاةِوَيُعْجِلُهُ', #1
u'الصلاتية': u'الصَّلَاتِيَّةَ', #17
u'الصلاتية': u'الصَّلَاتِيَّةُ', #18
u'الصلاتية': u'الصَّلَاتِيَّةِ', #32
u'الصلاصل': u'الصّلَاصِلِ', #5
u'الصلاق': u'الصَّلَّاقَ', #1
u'الصلال': u'الصّلَالِ', #1
u'الصلاه،': u'الصلاه،', #1
u'الصلاه': u'الصلاه', #4
u'الصلبيون': u'الصُّلْبِيُّونَ', #3
u'الصلحان': u'الصُّلْحَانِ', #2
u'الصلصل': u'الصّلْصُلِ', #1
u'الصلصل': u'الصَّلْصَلُ', #1
u'الصلصل،': u'الصُلْصُل،', #1
u'الصلق': u'الصّلْقِ', #1
u'الصلق': u'الصَّلْقَ', #2
u'الصلق': u'الصَّلْقِ', #4
u'الصلق': u'الصَّلْقُ', #5
u'الصلهام': u'الصِّلْهَامِ', #2
u'الصلوان': u'الصَّلَوَانِ', #1
u'الصلوة': u'الصَّلَوةَ', #1
u'الصلوة': u'الصِّلْوَةَ', #1
u'الصلوحي': u'الصُّلُوحِيُّ', #4
u'الصلوين': u'الصَّلَوَيْنِ', #16
u'الصمادحي': u'الصمادحي', #1
u'الصمادحي': u'الصُّمَادِحِيِّ', #3
u'الصمان': u'الصَّمَّانِ', #1
u'الصمان': u'الصُّمَّانُ', #1
u'الصمان': u'الصَّمَّانُ', #2
u'الصمان': u'الصّمّانُ', #3
u'الصمداني': u'الصَّمَدَانِيِّ', #2
u'الصمداني': u'الصَّمَدَانِيُّ', #4
u'الصمدانية': u'الصَّمَدَانِيَّةُ', #1
u'الصمصامة': u'الصَّمْصَامَةُ', #1
u'الصمصامة': u'الصَّمْصَامَةَ', #2
u'الصمعاء': u'الصَّمْعَاءَ', #1
u'الصمعاء': u'الصَّمْعَاءُ', #5
u'الصمه': u'الصّمّهْ', #2
u'الصميتة': u'الصميتة', #1
u'الصميتة': u'الصُّمَيْتَةِ', #1
u'الصمير': u'الصَّمِيرَ', #1
u'الصميري': u'الصَّمْيَرِيُّ', #1
u'الصناب': u'الصِّنَابِ', #1
u'الصنابح': u'الصنابح', #1
u'الصنابح': u'الصُّنَابِحَ', #1
u'الصنابح': u'الصُّنَابِحُ', #6
u'الصنابح': u'الصُّنَابِحِ', #6
u'الصنابحي': u'الصَّنَابِحِيِّ', #1
u'الصنابحي،': u'الصَّنَابِحِيِّ،', #1
u'الصنابحي': u'الصُّنَابِحِيُّ', #10
u'الصنابحي،': u'الصُّنَابِحِيِّ،', #12
u'الصنابحى': u'الصُّنَابِحِىِّ', #12
u'الصنابحي،': u'الصنابحي،', #2
u'الصنابحي': u'الصّنَابِحِيّ', #2
u'الصنابحي،': u'الصُّنَابِحِيُّ،', #3
u'الصنابحي': u'الصنابحي', #4
u'الصنابحى': u'الصُّنَابِحِىُّ', #4
u'الصنابحي': u'الصُّنَابِحِيِّ', #41
u'الصنابحي': u'الصُّنَابِحِيَّ', #5
u'الصنابحيون': u'الصُّنَابِحِيُّونَ', #1
u'الصناف': u'الصِّنَافِ', #1
u'الصنبرة': u'الصنبرة', #1
u'الصنبرة': u'الصِّنَّبْرَةَ', #1
u'الصنجات': u'الصَّنَجَاتِ', #2
u'الصنجات': u'الصَّنَجَاتُ', #4
u'الصنجة': u'الصَّنْجَةُ', #11
u'الصنجة': u'الصَّنْجَةِ', #34
u'الصنجة': u'الصَّنْجَةَ', #5
u'الصنجتين': u'الصَّنْجَتَيْنِ', #1
u'الصنعاني،': u'الصَّنعانِيُّ،', #1
u'الصنعاني،': u'الصَّنْعانيّ،', #1
u'الصنعانى': u'الصَّنَعَانِىُّ', #1
u'الصنعاني،': u'الصنعاني،', #14
u'الصنعاني،': u'الصَّنْعَانِيُّ،', #158
u'الصنعانى': u'الصَّنْعَانِىِّ', #19
u'الصنعاني،': u'الصَّنْعاني،', #2
u'الصنعاني': u'الصنعاني', #4
u'الصنعانى': u'الصَّنْعَانِىَّ', #4
u'الصنعانى': u'الصَّنْعَانِىُّ', #43
u'الصنعاني': u'الصَّنْعَانِيِّ', #50
u'الصنعاني،': u'الصَّنْعَانِيِّ،', #55
u'الصنعاني': u'الصّنْعَانِيّ', #6
u'الصنعاني': u'الصَّنْعَانِيُّ', #63
u'الصنعاني': u'الصَّنْعَانِيَّ', #9
u'الصنعانيان،': u'الصَّنْعَانِيَّانِ،', #1
u'الصنعانيون،': u'الصنعانيون،', #1
u'الصنعانيون،': u'الصَّنْعَانِيُّونَ،', #3
u'الصنعانيين،': u'الصَّنْعَانِيِّينَ،', #1
u'الصنعانيين،': u'الصَّنْعَانِيَّيْنِ،', #1
u'الصنفة': u'الصنفة', #1
u'الصنهاجي': u'الصِّنْهَاجِيِّ', #1
u'الصنهاجي': u'الصَّنْهَاجِيُّ', #2
u'الصنهاجي': u'الصَّنْهَاجِيِّ', #2
u'الصهاريخ': u'الصَّهَارِيخِ', #1
u'الصهباني': u'الصَّهْبَانِيُّ', #1
u'الصهباني،': u'الصَّهْبَانِيُّ،', #1
u'الصهرة': u'الصَّهْرَةُ', #1
u'الصهرة': u'الصَّهْرَةِ', #1
u'الصهرة': u'الصِّهْرَةِ', #1
u'الصهرة': u'الصِّهْرَةُ', #2
u'الصهوبة': u'الصُّهُوبَةَ', #1
u'الصهوبة': u'الصُّهُوبَةُ', #2
u'الصهوبة': u'الصُّهُوبَةِ', #3
u'الصهيبى': u'الصُّهَيْبِىِّ', #2
u'الصهيلا': u'الصّهِيلَا', #2
u'الصوابا': u'الصَّوَابَا', #1
u'الصوات': u'الصُّوَاتُ', #1
u'الصوار': u'الصُّوَارِ', #1
u'الصوارف': u'الصَّوَارِفَ', #1
u'الصوارف': u'الصَّوَارِفِ', #3
u'الصواع': u'الصُّوَاعُ', #1
u'الصواع،': u'الصُّوَاعَ،', #1
u'الصواع،': u'الصُّوَاعُ،', #1
u'الصواع': u'الصُّوَاعِ', #2
u'الصواع': u'الصُّوَاعَ', #3
u'الصواغون': u'الصَّوَّاغُونَ', #3
u'الصواغين،': u'الصَّوَّاغِينَ،', #1
u'الصواغين': u'الصَّوَّاغِينَ', #34
u'الصوالج': u'الصّوَالِجُ', #1
u'الصوائف': u'الصَّوَائِفَ', #1
u'الصوائف': u'الصوائف', #2
u'الصوائف': u'الصَّوَائِفِ', #5
u'الصوباشي': u'الصُّوبَاشِيَّ', #1
u'الصوباشي': u'الصُّوبَاشِيِّ', #1
u'الصوبين': u'الصَّوْبَيْنِ', #3
u'الصوره': u'الصُّورَهْ', #1
u'الصورى': u'الصُّورِىُّ', #6
u'الصوفى': u'الصُّوفُىُّ', #1
u'الصوفى': u'الصُّوفِىُّ', #70
u'الصول': u'الصُّولَ', #1
u'الصول': u'الصُّوَلُ', #1
u'الصول': u'الصَّوْلُ', #2
u'الصول': u'الصَّوْلَ', #3
u'الصول': u'الصَّوْلِ', #4
u'الصولى': u'الصُّولِىُّ', #1
u'الصوما': u'الصَّوْمَا', #1
u'الصومين': u'الصَّوْمَيْنِ', #33
u'الصونان': u'الصَّوْنَانِ', #1
u'الصونين': u'الصَّوْنَيْنِ', #1
u'الصويت': u'الصُّوَيْتُ', #1
u'الصويدرة': u'الصُّوَيْدِرَةِ', #2
u'الصوير': u'الصُّوَيْرِ', #1
u'الصوير': u'الصُّوَيْرُ', #2
u'الصئبان': u'الصِّئْبَانَ', #1
u'الصئبان': u'الصِّئْبَانُ', #3
u'الصئبان': u'الصِّئْبَانِ', #5
u'الصئول': u'الصّئُولِ', #1
u'الصئول': u'الصَّئُول', #1
u'الصئول': u'الصَّئُولَ', #1
u'الصئول': u'الصَّئُولُ', #2
u'الصئول': u'الصَّئُولِ', #7
u'الصيا': u'الصّيَا', #2
u'الصيادي': u'الصَّيَّادِيُّ', #1
u'الصياريف': u'الصّيَارِيفَ', #1
u'الصياصيا': u'الصّيَاصِيَا', #4
u'الصياقل': u'الصّيَاقِلَ', #1
u'الصياقل': u'الصَّيَاقِلُ', #2
u'الصياقل': u'الصّيَاقِلُ', #2
u'الصياقل': u'الصّيَاقِلِ', #2
u'الصياقلة': u'الصَّيَاقِلَةِ', #1
u'الصيال': u'الصِّيَالَ', #5
u'الصيال': u'الصِّيَالِ', #74
u'الصيال': u'الصِّيَالُ', #8
u'الصيالة': u'الصَّيَّالَةِ', #1
u'الصيان': u'الصِّيَانُ', #1
u'الصيبات': u'الصَّيْبَات', #1
u'الصيبان': u'الصِّيبَانُ', #1
u'الصيبان': u'الصّيْبَانُ', #1
u'الصيحاني': u'الصَّيْحَانِيَّ', #1
u'الصيحاني': u'الصّيْحَانِيّ', #1
u'الصيحاني': u'الصَّيْحَانِيِّ', #12
u'الصيحاني': u'الصَّيْحَانِيّ', #2
u'الصيداوى': u'الصَّيْدَاوِىُّ', #1
u'الصيداوي': u'الصَّيْدَاوِيُّ', #2
u'الصيدفاني': u'الصَّيْدَفَانِيُّ', #1
u'الصيدلانى': u'الصيَّدْلاَنِىُّ', #1
u'الصيدلانى': u'الصَّيْدَلاَنِىِّ', #1
u'الصيدلانى': u'الصَّيْدَلاِنِىُّ', #1
u'الصيدلانى': u'الصِّيْدَلاَنِىُّ', #1
u'الصيدلانى': u'الصَّيْدَلاَنِىَّ', #2
u'الصيدلانى': u'الصَّيْدَلاَنِىُّ', #79
u'الصيدين': u'الصَّيْدَيْنِ', #1
u'الصيرفى': u'الصِّيرَفِىُّ', #1
u'الصيرفى': u'الصَّيْرَفِى', #1
u'الصيرفى': u'الصَّيْرَفِىَّ', #1
u'الصيرفى': u'الصَّيْرَفُِّى', #1
u'الصيرفى': u'الصِّيْرَفِىُّ', #1
u'الصيرفى': u'الصَّيْرَفِىِّ', #4
u'الصيرفى': u'الصَّيْرَفِىُّ', #85
u'الصيرفيني': u'الصَّيْرَفِينِيُّ', #1
u'الصيعلون': u'الصّيْعَلُونَ', #1
u'الصيغين': u'الصَّيِّغَيْنِ', #1
u'الصيق': u'الصِّيق', #1
u'الصيقل،': u'الصَّيْقل،', #1
u'الصيقل': u'الصَّيْقَلَ', #1
u'الصيقل': u'الصُّيَقْلِ', #1
u'الصيقل': u'الصّيْقَلَ', #1
u'الصيقل،': u'الصَّيْقَلُ،', #1
u'الصيقل،': u'الصَّيْقَلِ،', #1
u'الصيقل': u'الصَّيْقَلِ', #10
u'الصيقل': u'الصّيْقَلُ', #3
u'الصيقل': u'الصَّيْقَلُ', #8
u'الصيقلاني': u'الصَّيْقَلَانِيُّ', #1
u'الصيقلي': u'الصَّيْقَلِيُّ', #1
u'الصيلم': u'الصَّيْلَمُ', #1
u'الصيمران': u'الصَّيْمَرَانِ', #1
u'الصيمري،': u'الصَّيْمَرِيُّ،', #1
u'الصيمري': u'الصَّيْمَرِيُّ', #260
u'الصيمري': u'الصَّيْمَرِيَّ', #7
u'الصيمري': u'الصَّيْمَرِيِّ', #98
u'الصينى': u'الصِّينِىُّ', #2
u'الصيود': u'الصُّيُودُ', #14
u'الصيود': u'الصُّيُودِ', #29
u'الصيود': u'الصَّيُودَ', #3
u'الصيود': u'الصَّيُودِ', #35
u'الصيود': u'الصَّيُودُ', #6
u'الصيود': u'الصُّيُودَ', #6
u'الصيودية': u'الصُّيُودِيَّةِ', #2
u'الض': u'الضّ', #1
u'الضابث': u'الضّابِثِ', #2
u'الضاربك': u'الضَّارِبُكَ', #1
u'الضاربية': u'الضَّارِبِيَّةَ', #1
u'الضاربية': u'الضَّارِبِيَّةِ', #1
u'الضاربية': u'الضَّارِبِيَّةُ', #2
u'الضارورة': u'الضَّارُورَةِ', #1
u'الضارى': u'الضارى', #1
u'الضافطة': u'الضّافِطَةِ', #1
u'الضآلون': u'الضَّآلُّونَ', #1
u'الضآلين': u'الضَّآلِّينَ', #1
u'الضألين': u'الضَّأْلِينَ', #1
u'الضان': u'الضّانِ', #1
u'الضان': u'الضَّانّ', #1
u'الضائر': u'الضَّائِرِ', #1
u'الضائر': u'الضَّائِرُ', #2
u'الضائف': u'الضّائِفِ', #1
u'الضبابة': u'الضَّبَابَةَ', #2
u'الضبابة': u'الضَّبَابَةِ', #4
u'الضبابى': u'الضَّبَابِىِّ', #2
u'الضبابى': u'الضِّبَابِىِّ', #3
u'الضبات': u'الضَّبَّاتِ', #1
u'الضبرة': u'الضّبْرَةِ', #1
u'الضبطين': u'الضّبْطَيْنِ', #1
u'الضبطين': u'الضَّبْطَيْنِ', #8
u'الضبعى': u'الضُّبَعِىَّ', #1
u'الضبعى': u'الضُّبَعِىِّ', #12
u'الضبعى': u'الضُّبَعِىُّ', #28
u'الضبنة': u'الضُّبْنَةِ', #3
u'الضبوعة': u'الضّبُوعَةَ', #1
u'الضبوعة': u'الضَّبُوعَةَ', #1
u'الضبوعة': u'الضَّبُوعَةُ', #2
u'الضبوعة': u'الضَّبُوعَةِ', #2
u'الضبوعة': u'الضّبُوعَةِ', #3
u'الضبى': u'الضَّبِىُّ', #1
u'الضبى': u'الضَّبِّىِّ', #13
u'الضبى': u'الضَّبِّىُّ', #149
u'الضبى': u'الضَّبِّىَّ', #3
u'الضبيب': u'الضَّبِيبِ', #1
u'الضبيب': u'الضّبَيْبُ', #1
u'الضبيب': u'الضّبَيْبِ', #15
u'الضبيب': u'الضُّبَيْبِ', #3
u'الضبيبي': u'الضّبَيْبِيّ', #5
u'الضبيس': u'الضّبِيسُ', #1
u'الضبيعي': u'الضُّبَيْعِيِّ', #1
u'الضبيني': u'الضّبِينِيّ', #2
u'الضجاج': u'الضّجَاجَ', #1
u'الضجن': u'الضَّجَنِ', #1
u'الضجور': u'الضَّجُورَ', #1
u'الضجيع': u'الضّجِيعَ', #2
u'الضجيع': u'الضَّجِيع', #2
u'الضجيع': u'الضَّجِيعَ', #2
u'الضجيع': u'الضَّجِيعُ', #6
u'الضح': u'الضَّحُّ', #1
u'الضح': u'الضَّحِّ', #1
u'الضح': u'الضّحّ', #4
u'الضح': u'الضِّحِّ', #5
u'الضحا': u'الضّحَا', #1
u'الضحاكا': u'الضّحّاكَا', #3
u'الضحاكوالفسوق': u'الضَّحَّاكِوَالْفُسُوقُ', #1
u'الضحضاح': u'الضّحْضَاحُ', #1
u'الضحضاح': u'الضّحْضَاحِ', #1
u'الضحضاح': u'الضحضاح', #3
u'الضحي': u'الضُّحِي', #1
u'الضحي،': u'الضُّحَي،', #1
u'الضحيان': u'الضّحْيَانُ', #2
u'الضرا': u'الضَّرَّا', #1
u'الضرا': u'الضُّرَّا', #2
u'الضراءالسقم': u'الضَّرَّاءُالسَّقَمُ', #1
u'الضرابا': u'الضّرَابَا', #2
u'الضرات': u'الضَّرَّات', #1
u'الضرات': u'الضَّرَّاتِ', #10
u'الضراثيت': u'الضَّرَاثِيتِ', #1
u'الضرارية': u'الضِّرَارِيَّةِ', #1
u'الضراطة': u'الضّرّاطَةَ', #1
u'الضربا': u'الضّرْبَا', #2
u'الضرباء': u'الضُّرْبَاءُ', #1
u'الضرباء،': u'الضُّرَبَاءُ،', #1
u'الضرباء': u'الضُّرَبَاءُ', #2
u'الضربه': u'الضربه', #1
u'الضربوب': u'الضَّرْبُوبُ', #1
u'الضرطة': u'الضَّرْطَةَ', #1
u'الضرطة': u'الضَّرْطَةِ', #5
u'الضرغامين': u'الضِّرْغَامَيْنِ', #2
u'الضرفتان': u'الضَّرْفَتَانِ', #1
u'الضرو': u'الضِّرْوُ', #1
u'الضرو': u'الضِّرْوِ', #1
u'الضروة': u'الضِّرْوَةُ', #1
u'الضريري': u'الضَّرِيرِيِّ', #10
u'الضريك': u'الضّرِيكِ', #2
u'الضريك': u'الضّرِيكُ', #6
u'الضعبي،': u'الضُّعَبِيُّ،', #1
u'الضعفا': u'الضَّعْفَا', #1
u'الضعفى': u'الضَّعْفَى', #1
u'الضعفى': u'الضُّعْفَى', #1
u'الضغابيث': u'الضَّغَابِيثُ', #2
u'الضغابيس': u'الضَّغَابِيسَ', #1
u'الضغابيس': u'الضّغَابِيسِ', #1
u'الضغابيس': u'الضَّغَابِيسُ', #5
u'الضفاري': u'الضّفَارِيّ', #2
u'الضفاوي': u'الضّفَاوِيّ', #1
u'الضل': u'الضُّلُّ', #1
u'الضل': u'الضُّلِّ', #1
u'الضمامة': u'الضمامة', #1
u'الضمائم': u'الضَّمَائِمِ', #1
u'الضمرى': u'الضَّمْرِىِّ', #21
u'الضمرى': u'الضَّمْرِىُّ', #4
u'الضمرى': u'الضَّمْرِىَّ', #5
u'الضنا': u'الضَّنَّا', #1
u'الضنا': u'الضَّنَا', #8
u'الضناوي': u'الضّنَاوِيّ', #1
u'الضنة': u'الضِّنَةَ', #1
u'الضنة': u'الضِّنَّةَ', #1
u'الضنة': u'الضِّنَّةِ', #1
u'الضنة': u'الضِّنَّةُ', #2
u'الضنة': u'الضِّنَةُ', #3
u'الضنة': u'الضِّنَةِ', #6
u'الضومران': u'الضَّوْمَرَانُ', #2
u'الضئبان': u'الضِّئْبَانِ', #1
u'الضئر': u'الضِّئْرَ', #1
u'الضئر': u'الضِّئْرِ', #1
u'الضئضئ': u'الضئضئ', #5
u'الضيا': u'الضِّيَا', #1
u'الضياح': u'الضَّيَّاح', #1
u'الضياح': u'الضّيَاحِ', #1
u'الضياح': u'الضّيّاحِ', #2
u'الضياعة': u'الضِّيَاعَةِ', #1
u'الضيائع': u'الضَّيَائِعِ', #1
u'الضيحان': u'الضّيْحَانِ', #1
u'الضيرا': u'الضَّيْرَا', #1
u'الضيروطي': u'الضَّيْرُوطِيِّ', #1
u'الضيزن': u'الضَّيْزَنُ', #1
u'الضيزن': u'الضَّيْزَنِ', #1
u'الضيزن': u'الضّيْزَنُ', #3
u'الضيزن': u'الضّيْزَنِ', #3
u'الضيمران': u'الضَّيْمَرَانِ', #1
u'الضيمران': u'الضَّيْمَرَانُ', #2
u'الضيون': u'الضَّيْوَنَ', #1
u'الط': u'الط', #1
u'الط': u'الطَّ', #1
u'الطاءة': u'الطّاءَةِ', #1
u'الطاب': u'الطَّابَ', #1
u'الطاب': u'الطَّابِ', #12
u'الطاب': u'الطَّابُ', #9
u'الطابة': u'الطَّابَةَ', #1
u'الطابرانى': u'الطَّابَرَانِىُّ', #10
u'الطابرانى': u'الطَّابِرَانِىُّ', #9
u'الطابقات': u'الطَّابِقَاتِ', #2
u'الطابو': u'الطَّابُو', #31
u'الطاحي': u'الطَّاحِيَّ', #1
u'الطاحى': u'الطَّاحِىُّ', #1
u'الطاحي': u'الطَّاحِيُّ', #3
u'الطاحي،': u'الطَّاحِيُّ،', #4
u'الطارم': u'الطارم', #1
u'الطارمات': u'الطَّارِمَاتُ', #1
u'الطارئية': u'الطَّارِئِيَّةَ', #1
u'الطارئية': u'الطَّارِئِيَّةِ', #2
u'الطاطري': u'الطاطري', #1
u'الطاطري،': u'الطاطري،', #1
u'الطاطري،': u'الطَّاطَرِيَّ،', #1
u'الطاطري': u'الطَّاطَرِيُّ', #3
u'الطاطري،': u'الطَّاطَرِيُّ،', #5
u'الطاعةوالوجه': u'الطَّاعَةُوَالْوَجْهُ', #1
u'الطاعونالوجه': u'الطَّاعُونِالْوَجْهُ', #1
u'الطافى': u'الطَّافِى', #1
u'الطافى': u'الطَّافِىَ', #1
u'الطافئة': u'الطَّافِئَةِ', #1
u'الطالباني': u'الطَّالِبَانِيُّ', #2
u'الطالباني': u'الطَّالِبَانِيِّ', #3
u'الطالبيين،': u'الطَّالِبِيِّينَ،', #1
u'الطالبيين': u'الطّالِبِيّيْنِ', #1
u'الطالبيين': u'الطَّالِبِيِّينَ', #3
u'الطالقاني،': u'الطالقاني،', #1
u'الطالقاني': u'الطَّالَقَانِيَّ', #1
u'الطالقانى': u'الطَّالْقَانِىِّ', #1
u'الطالقانى': u'الْطَالَقَانِىُّ', #1
u'الطالقاني،': u'الطَّالْقَانِيُّ،', #14
u'الطالقاني': u'الطَّالَقَانِيُّ', #16
u'الطالقاني': u'الطَّالَقَانِيِّ', #2
u'الطالقانى': u'الطَّالَقَانِىَّ', #2
u'الطالقانى': u'الطَّالَقَانِىِّ', #2
u'الطالقانى': u'الطَّالْقَانِىَّ', #2
u'الطالقاني،': u'الطَّالْقَانِيِّ،', #3
u'الطالقانى': u'الطَّالْقَانِىُّ', #5
u'الطالقانى': u'الطَّالَقَانِىُّ', #6
u'الطالقاني': u'الطَّالْقَانِيُّ', #9
u'الطاهري': u'الطَّاهِرِيُّ', #1
u'الطاهرية': u'الطَّاهِرِيَّةِ', #18
u'الطاهرية': u'الطَّاهِرِيَّةَ', #6
u'الطاهرية': u'الطَّاهِرِيَّةُ', #7
u'الطاوس': u'الطَّاوُسُ', #2
u'الطاوس': u'الطَّاوُسِ', #2
u'الطاوسي': u'الطَّاوُسِيُّ', #23
u'الطاوسي': u'الطَّاوُسِيِّ', #9
u'الطائفى': u'الطَّائِفِىَّ', #2
u'الطائفى': u'الطَّائِفِىُّ', #21
u'الطائفى': u'الطَّائِفِىِّ', #7
u'الطائكانى': u'الطَّائِكَانِىُّ', #1
u'الطائى': u'الطَائِىُّ', #1
u'الطائى': u'الطَّائِى', #1
u'الطائى': u'الطَّائِىَّ', #2
u'الطائى': u'الطَّائِىِّ', #28
u'الطائى': u'الطَّائِىُّ', #34
u'الطائيون': u'الطّائِيّونَ', #1
u'الطايفي،': u'الطَّايِفِيِّ،', #1
u'الطايكاني': u'الطَّايَكَانِيِّ', #1
u'الطايكانى': u'الطَّايِكَانِىُّ', #1
u'الطباب': u'الطّبَابُ', #3
u'الطباقاء': u'الطباقاء', #2
u'الطباهج': u'الطباهج', #1
u'الطباهج': u'الطَّبَاهِجُ', #1
u'الطباهجات': u'الطباهجات', #1
u'الطباهجة': u'الطباهجة', #1
u'الطباهجة': u'الطَّبَاهِجَةِ', #1
u'الطبائخ': u'الطَّبَائِخِ', #1
u'الطبائعيون': u'الطَّبَائِعِيُّونَ', #2
u'الطبايعي': u'الطَّبَايِعِيَّ', #2
u'الطبر': u'الطَّبَرَ', #1
u'الطبر': u'الطَّبَرُ', #1
u'الطبر': u'الطَّبْرُ', #1
u'الطبراني،': u'الطَّبَرَانِيِّ،', #1
u'الطبراني': u'الطَّبَرَانِيَّ', #11
u'الطبراني': u'الطَّبَرَانِيُّ', #1188
u'الطبراني': u'الطبراني', #12
u'الطبراني': u'الطَّبَرَانِيّ', #3
u'الطبراني': u'الطَّبَرَانِيِّ', #320
u'الطبرانى': u'الطَّبَرَانِىُّ', #55
u'الطبراني،': u'الطَّبَرَانِيُّ،', #9
u'الطبرانيين': u'الطَّبَرَانِيِّينَ', #1
u'الطبرزد': u'الطبرزد', #1
u'الطبرزد': u'الطَّبَرْزَدُ', #1
u'الطبرس': u'الطِّبْرِسِ', #2
u'الطبرسية': u'الطَّبَرَسِيَّةِ', #5
u'الطبري': u'الطبريُّ', #1
u'الطبري': u'الطَّبْرِيُّ', #1
u'الطبري،': u'الطَّبَرِيِّ،', #1
u'الطبرى': u'الطَّبَرِىَّ', #1
u'الطبرى': u'الطَّبَرِىُّ', #18
u'الطبري': u'الطبريّ', #2
u'الطبري': u'الطَّبَرِيَّ', #21
u'الطبري': u'الطَّبَرِيِّ', #320
u'الطبري': u'الطَّبَرِيّ', #4
u'الطبري،': u'الطبري،', #6
u'الطبري،': u'الطَّبَرِيُّ،', #6
u'الطبري': u'الطبري', #7
u'الطبري': u'الطَّبَرِيُّ', #739
u'الطبري': u'الطّبَرِيّ', #94
u'الطبرية': u'الطَّبَرِيَّةَ', #1
u'الطبرية': u'الطَّبَرِيَّةُ', #2
u'الطبرية': u'الطَّبَرِيَّةِ', #5
u'الطبسي': u'الطَّبَسِيُّ', #1
u'الطبسي،': u'الطَّبْسِيُّ،', #1
u'الطبسين،': u'الطَّبَسَيْنِ،', #1
u'الطبلاوي': u'الطَّبَلَاوِيُّ', #103
u'الطبلاوي': u'الطَّبَلَاوِيَّ', #3
u'الطبلاوي': u'الطَّبَلَاوِيِّ', #46
u'الطبلخانا': u'الطَّبْلَخَانَا', #1
u'الطبوع': u'الطُّبُوعُ', #2
u'الطبوع': u'الطُّبُوعِ', #4
u'الطبولية': u'الطُّبُولِيَّةِ', #1
u'الطبيبا': u'الطَّبِيبَا', #1
u'الطبيخين': u'الطَّبِيخَيْنِ', #1
u'الطبيق': u'الطُّبَيْقِ', #2
u'الطثرية': u'الطّثَرِيّةِ', #1
u'الطحارية': u'الطَّحَارِيَّةِ', #1
u'الطحاوي': u'الطحاوي', #1
u'الطحاوي': u'الطَّحَاوِيُّ', #1259
u'الطحاوي': u'الطَّحَاوِيِّ', #1859
u'الطحاوي،': u'الطَّحَاوِيُّ،', #2
u'الطحاوي': u'الطَّحَاوِيَّ', #54
u'الطحاوى': u'الطَّحَاوِىُّ', #7
u'الطحرور': u'الطُّحْرُورِ', #1
u'الطحطاوي': u'الطَّحْطَاوِيّ', #1
u'الطحطاوي': u'الطَّحْطَاوِيِّ', #11
u'الطحطاوي': u'الطَّحْطَاوِيَّ', #2
u'الطحطاوي': u'الطَّحْطَاوِيُّ', #481
u'الطحينة': u'الطَّحِينَةُ', #2
u'الطحينة': u'الطَّحِينَةِ', #2
u'الطحينين': u'الطَّحِينَيْنِ', #2
u'الطخاء': u'الطَّخَاءُ', #2
u'الطخرور': u'الطُّخْرُورِ', #1
u'الطخم': u'الطّخْمَ', #2
u'الطخمة': u'الطّخْمَة', #2
u'الطخيخي': u'الطِّخِّيخِيِّ', #18
u'الطخيخي': u'الطَّخِّيخِيِّ', #3
u'الطخيخي': u'الطَّخِّيخِيُّ', #4
u'الطخيخي': u'الطِّخِّيخِيُّ', #53
u'الطخيخي': u'الطِّخِّيخِيَّ', #7
u'الطراب': u'الطّرَابِ', #2
u'الطرابيشي': u'الطَّرَابِيشِيِّ', #1
u'الطراثيت': u'الطَّرَاثِيتُ', #1
u'الطراثيث': u'الطَّرَاثِيثِ', #2
u'الطراحة': u'الطَّرَّاحَةَ', #1
u'الطراحة': u'الطُّرَّاحَةِ', #1
u'الطراحة': u'الطَّرَّاحَةِ', #13
u'الطراحة': u'الطَّرَّاحَةُ', #2
u'الطراخم': u'الطّرَاخِمِ', #3
u'الطرار': u'الطُّرَّارِ', #1
u'الطرار': u'الطِّرَارَ', #1
u'الطرار': u'الطَّرَّارِ', #10
u'الطرار': u'الطَّرَّارُ', #15
u'الطرار': u'الطُّرَّارُ', #2
u'الطرار': u'الطِّرَارُ', #5
u'الطرار': u'الطَّرَّارَ', #9
u'الطراريح': u'الطَّرَارِيحِ', #2
u'الطرازدان': u'الطِّرَازْدَانُ', #2
u'الطرازى': u'الطِّرَازِىُّ', #1
u'الطراقين': u'الطَّرَّاقِينَ', #1
u'الطراني': u'الطَّرَّانِيُّ', #2
u'الطرائفي': u'الطَّرَائِفِيُّ', #1
u'الطرائفي،': u'الطَّرَائِفِيُّ،', #2
u'الطرائفى': u'الطَّرَائِفِىَّ', #2
u'الطرائفى': u'الطَّرَائِفِىُّ', #79
u'الطربة': u'الطَّرَبَةُ', #1
u'الطربة': u'الطَّرِبَةُ', #1
u'الطربة': u'الطَّرَبَةِ', #2
u'الطرثوث': u'الطُّرْثُوثَ', #1
u'الطرثوث': u'الطُّرْثُوثُ', #1
u'الطرثوث': u'الطُّرْثُوثِ', #2
u'الطرخان': u'الطَّرْخَانِ', #1
u'الطرخون': u'الطَّرْخُونِ', #1
u'الطرسوسي': u'الطَّرَسُوسِيٌّ', #1
u'الطرسوسي،': u'الطَّرْسٌوسِيُّ،', #1
u'الطرسوسى': u'الطَرْسُوسِىُّ', #1
u'الطرسوسى': u'الطَّرْسُوسِىَّ', #1
u'الطرسوسي': u'الطَّرَسُوسِيَّ', #12
u'الطرسوسي،': u'الطَّرَسُوسِيِّ،', #13
u'الطرسوسي': u'الطَّرَسُوسِيُّ', #177
u'الطرسوسي،': u'الطرسوسي،', #2
u'الطرسوسى': u'الطَّرْسُوسِىِّ', #2
u'الطرسوسى': u'الطَّرَسُوسِىُّ', #4
u'الطرسوسي': u'الطَّرَسُوسِيِّ', #41
u'الطرسوسي،': u'الطَّرَسُوسِيُّ،', #52
u'الطرسوسى': u'الطَّرْسُوسِىُّ', #9
u'الطرطر': u'الطَّرْطَرِ', #1
u'الطرطوسي': u'الطَّرْطُوسِيِّ', #3
u'الطرطوسي': u'الطَّرْطُوسِيُّ', #5
u'الطرطوشي': u'الطُّرْطُوشِيّ', #1
u'الطرطوشي': u'الطَّرْطُوشِيُّ', #13
u'الطرطوشي': u'الطُّرْطُوشِيُّ', #157
u'الطرطوشي': u'الطَّرْطُوشِيَّ', #2
u'الطرطوشي': u'الطَّرْطُوشِيِّ', #2
u'الطرطوشي': u'الطُّرْطُوشِيِّ', #46
u'الطرطوشي': u'الطُّرْطُوشِيَّ', #6
u'الطرطير': u'الطِّرْطِيرِ', #2
u'الطرفا': u'الطَّرَفَا', #3
u'الطرماح': u'الطّرِمّاحِ', #1
u'الطرماح': u'الطّرِمّاحُ', #6
u'الطرو': u'الطُّرُوُّ', #11
u'الطرو': u'الطُّرُوِّ', #17
u'الطرو': u'الطُّرُوَّ', #4
u'الطروحات': u'الطَّرُوحَاتِ', #1
u'الطروفا': u'الطُّرُوفَا', #1
u'الطروفا': u'الطّرُوفَا', #2
u'الطريثيثي': u'الطُّرَيْثِيثِيُّ', #1
u'الطريده': u'الطَّرِيدَهْ', #1
u'الطريقا': u'الطَّرِيقَا', #1
u'الطريقفقد': u'الطَّرِيقِفَقَدْ', #1
u'الطريئان': u'الطَّرِيئَانِ', #1
u'الطساس': u'الطّسَاسِ', #2
u'الطساس': u'الطِّسَاسُ', #2
u'الطستي،': u'الطَّسْتِيِّ،', #1
u'الطستى': u'الطَّسْتِىُّ', #2
u'الطسق': u'الطَّسْقُ', #1
u'الطسوج': u'الطَّسُّوجِ', #3
u'الطش': u'الطّشّ', #1
u'الطش': u'الطَّشَّ', #1
u'الطش': u'الطَّشُّ', #1
u'الطشت': u'الطَّشْتَ', #13
u'الطشت': u'الطَّشْتُ', #2
u'الطشت': u'الطَّشْتِ', #7
u'الطعاما': u'الطَّعَامَا', #3
u'الطعين': u'الطَّعِينُ', #1
u'الطغام': u'الطَّغَامُ', #3
u'الطغام': u'الطَّغَامِ', #3
u'الطغامجى': u'الطَّغَامِجِىُّ', #1
u'الطغرا': u'الطُّغْرَا', #1
u'الطغرائي': u'الطُّغْرَائِيِّ', #2
u'الطفاوى': u'الطُّفَاوِىِّ', #1
u'الطفاوى': u'الطُّفَاوِىُّ', #4
u'الطفشيل': u'الطَّفْشِيلَ', #1
u'الطفشيل': u'الطِّفْشِيلِ', #1
u'الطفى': u'الطُّفَى', #2
u'الطفية': u'الطُّفْيَةِ', #2
u'الطفية': u'الطُّفْيَةُ', #3
u'الطفيتان': u'الطُّفْيَتَانِ', #2
u'الطفيتين،': u'الطُّفْيَتَيْنِ،', #2
u'الطفيتين': u'الطُّفْيَتَيْنِ', #77
u'الطفيل': u'الطُّفيل', #1
u'الطفيل،': u'الطُّفَيْلٍ،', #1
u'الطفيل،': u'الطُّفَيْلَ،', #1
u'الطفيل': u'الطفيل', #14
u'الطفيل': u'الطّفِيلِ', #2
u'الطفيل': u'الطُّفَيْلٍ', #2
u'الطفيل،': u'الطُّفَيْل،', #2
u'الطفيل': u'الطّفَيْلُ', #20
u'الطفيل،': u'الطُّفيل،', #3
u'الطفيل،': u'الطُّفَيْلُ،', #3
u'الطفيل': u'الطُّفَيْلِ', #353
u'الطفيل': u'الطُّفَيْلُ', #38
u'الطفيل': u'الطّفَيْلَ', #4
u'الطفيل': u'الطُّفَيْل', #4
u'الطفيل': u'الطُّفَيْلَ', #5
u'الطفيل': u'الطّفَيْلِ', #55
u'الطفيل،': u'الطُّفَيْلِ،', #70
u'الطلا': u'الطَّلاَ', #1
u'الطلا': u'الطَّلَا', #1
u'الطلا': u'الطِّلَا', #3
u'الطلاس،': u'الطَّلاسُ،', #3
u'الطلاس': u'الطَّلاسُ', #5
u'الطلاطلة': u'الطّلَاطِلَةِ', #5
u'الطلاقا': u'الطَّلَاقَا', #2
u'الطلاقىىىى': u'الطَّلَاقَىىىى', #1
u'الطلباء': u'الطُّلَبَاءِ', #1
u'الطلبقة': u'الطَّلْبَقَةُ', #2
u'الطلحى': u'الطَّلْحِىُّ', #7
u'الطلف': u'الطَّلَفَ', #1
u'الطلقاءSعن': u'الطّلَقَاءُSعَنْ', #1
u'الطلقاني': u'الطَّلَقَانِيّ', #1
u'الطلقاني': u'الطَّلْقَانِيُّ', #3
u'الطلمنكي': u'الطّلَمَنْكِيّ', #2
u'الطليع': u'الطَّلِيعُ', #2
u'الطماسة': u'الطَّمَاسَةُ', #1
u'الطمأنينةوهي': u'الطُّمَأْنِينَةُوَهِيَ', #1
u'الطمستاني': u'الطَّمَسْتَانِيُّ', #1
u'الطمستاني': u'الطَّمَسْتَانِيِّ', #1
u'الطمطام': u'الطّمْطَامُ', #1
u'الطمطام': u'الطّمْطَامِ', #1
u'الطمعا': u'الطَّمَعَا', #1
u'الطمغاجى': u'الطمغاجى', #1
u'الطمل': u'الطّمْلُ', #2
u'الطنافسي': u'الطُّنَافِسِيّ', #1
u'الطنافسي،': u'الطَّنَافِسِيَّ،', #1
u'الطنافسى': u'الطَّنَافِسِىَّ', #1
u'الطنافسي': u'الطَّنَافِسِيُّ', #13
u'الطنافسي': u'الطَّنَافِسِيِّ', #2
u'الطنافسى': u'الطَّنَافِسِىِّ', #2
u'الطنافسي،': u'الطَّنَافِسِيِّ،', #3
u'الطنافسى': u'الطَّنَافِسِىُّ', #30
u'الطنافسي،': u'الطَّنَافِسِيُّ،', #37
u'الطنافسي،': u'الطنافسي،', #5
u'الطنبا': u'الطُّنُبَا', #4
u'الطنباء': u'الطَّنْبَاءِ', #3
u'الطنبار': u'الطِّنْبَارُ', #1
u'الطنبداوي': u'الطَّنْبَدَاوِيّ', #2
u'الطنبداوي': u'الطَّنْبَدَاوِيُّ', #2
u'الطنبداوي': u'الطَّنْبَدَاوِيِّ', #4
u'الطنبذي': u'الطُّنْبُذِيُّ', #1
u'الطنبذي': u'الطُّنْبُذِيِّ', #1
u'الطنبذي،': u'الطُّنْبُذِيُّ،', #1
u'الطنبو': u'الطنبو', #1
u'الطندتائي': u'الطَّنْدَتَائِيُّ', #10
u'الطندتائي': u'الطَّنْدَتَائِيِّ', #7
u'الطنوب؟،': u'الطَّنُوبُ؟،', #1
u'الطنيزي': u'الطُّنَيْزِيِّ', #1
u'الطنيزي': u'الطُّنَيْزِيُّ', #3
u'الطهران': u'الطّهْرَانِ', #1
u'الطهرانى': u'الطِّهْرَانِىُّ', #4
u'الطهرين': u'الطُّهْرَيْنِ', #28
u'الطهماني': u'الطَّهْمَانِيِّ', #1
u'الطهمانى': u'الطَّهْمَانِىُّ', #1
u'الطهيان': u'الطَّهَيَانِ', #1
u'الطوابقي': u'الطَّوَابِقِيَّ', #1
u'الطوابيق': u'الطَّوَابِيقِ', #3
u'الطوابيقى': u'الطَّوَابِيقِىُّ', #2
u'الطواحم': u'الطَّوَاحِمِ', #1
u'الطواسين': u'الطَّوَاسِينُ', #1
u'الطواشي': u'الطَّوَاشِيِّ', #1
u'الطواشي': u'الطَّوَاشِي', #2
u'الطواشي': u'الطَّوَاشِيُ', #2
u'الطواشية': u'الطُّوَاشِيَةِ', #1
u'الطواشية': u'الطَّوَّاشِيَّةِ', #2
u'الطواغى': u'الطواغى', #1
u'الطواقي': u'الطَّوَاقِي', #1
u'الطواقي': u'الطَّوَّاقِيُّ', #1
u'الطوالات': u'الطَّوَالاتِ', #1
u'الطوالات': u'الطُّوَالَاتِ', #1
u'الطوالات': u'الطِّوَالَاتِ', #1
u'الطوانيت': u'الطَّوَانِيتِ', #1
u'الطواويسي': u'الطَّوَاوِيسِيَّ', #1
u'الطواويسى': u'الطَّوَاوِيسِىُّ', #1
u'الطواويسي': u'الطَّوَاوِيسِيِّ', #11
u'الطواويسي': u'الطَّوَاوِيسِيُّ', #25
u'الطوخي': u'الطُّوخِي', #1
u'الطوخي': u'الطُّوخِيَّ', #1
u'الطوخي': u'الطُّوخِيُّ', #18
u'الطوخي': u'الطُّوخِيِّ', #5
u'الطوسى': u'الطُّوسِىُّ', #129
u'الطوسى': u'الطُّوسِىَّ', #2
u'الطوسى': u'الطُّوسِىِّ', #2
u'الطوطي': u'الطُّوطِيِّ', #2
u'الطوفات': u'الطَّوَفَاتِ', #2
u'الطوفات': u'الطَّوْفَاتِ', #4
u'الطوفة': u'الطَّوْفَةُ', #1
u'الطوفة': u'الطَّوْفَةِ', #13
u'الطولوني': u'الطُّولُونِيِّ', #1
u'الطولين': u'الطُّولَيْنِ', #3
u'الطونجة': u'الطونجة', #1
u'الطونس': u'الطَّوَنْسِ', #1
u'الطويلإن': u'الطويلإِنَّ', #1
u'الطياب': u'الطِّيَابِ', #1
u'الطياش': u'الطَّيَّاشُ', #1
u'الطيال': u'الطَّيَّالُ', #1
u'الطيالسي،': u'الطيَّالِسيِّ،', #1
u'الطيالسي': u'الطّيَالِسِيّ', #1
u'الطيالسي،': u'الطَّيَالِسِيَّ،', #1
u'الطيالسي،': u'الطيالسي،', #10
u'الطيالسي': u'الطَّيَالِسِيَّ', #10
u'الطيالسي،': u'الطَّيَالِسِيِّ،', #16
u'الطيالسي': u'الطَّيَالِسِيُّ', #199
u'الطيالسى': u'الطَيَالِسِىُّ', #2
u'الطيالسى': u'الطَّيَالِسِىُّ', #244
u'الطيالسى': u'الطَّيَالِسِىِّ', #25
u'الطيالسي': u'الطَّيَالِسِيِّ', #29
u'الطيالسي': u'الطَّيَالِسِيّ', #3
u'الطيالسى': u'الطَّيَالِسِىَّ', #4
u'الطيالسي': u'الطيالسي', #5
u'الطيالسي،': u'الطَّيَالِسِيُّ،', #87
u'الطيبرسية': u'الطَّيْبَرِسِيَّةِ', #8
u'الطيل': u'الطِّيَلِ', #2
u'الطيلس': u'الطَّيْلَسُ', #1
u'الطيلوني': u'الطِّيلُونِيِّ', #1
u'الطيماوي': u'الطيماوي', #5
u'الطيوري': u'الطُّيُورِيُّ', #1
u'الطيوري': u'الطُّيُورِيِّ', #1
u'الطيوريات': u'الطُّيُورِيَّاتِ', #2
u'الطيئ': u'الطيئ', #1
u'الظبا': u'الظِّبَا', #3
u'الظباة': u'الظّبَاةِ', #1
u'الظبى': u'الظَّبْىُ', #1
u'الظبى': u'الظَّبْىِ', #9
u'الظبينا': u'الظّبِينَا', #2
u'الظة': u'الظة', #1
u'الظريب': u'الظَّرِيب', #1
u'الظريب': u'الظّرَيْبَ', #1
u'الظريب': u'الظّرَيْبِ', #4
u'الظريبة': u'الظُّرَيْبَةُ', #2
u'الظفرى': u'الظَّفَرِىُّ', #2
u'الظفيرة': u'الظفيرة', #2
u'الظلمانية': u'الظُّلْمَانِيَّةِ', #4
u'الظما': u'الظَّمَا', #5
u'الظمأين': u'الظَّمَأَيْنِ', #1
u'الظنبه': u'الظَّنِّبِهِ', #1
u'الظنونا': u'الظَّنُونَا', #1
u'الظنونا': u'الظّنُونَا', #2
u'الظنونا': u'الظُّنُونَا', #2
u'الظه': u'الظّهْ', #1
u'الظهاران': u'الظِّهَارَانِ', #1
u'الظهارين': u'الظِّهَارَيْنِ', #18
u'الظهرا': u'الظَّهْرَا', #1
u'الظهراني،': u'الظهْرَانِيُّ،', #1
u'الظهرانى': u'الظَّهْرَانِىِّ', #1
u'الظهرانى': u'الظِّهْرَانِىُّ', #1
u'الظهراني،': u'الظِّهْرَانِيُّ،', #2
u'الظئارة': u'الظِّئَارَةِ', #1
u'الظئر': u'الظِّئْرُ', #102
u'الظئر': u'الظئر', #2
u'الظئر': u'الظِّئْرِ', #235
u'الظئر': u'الظِّئْر', #4
u'الظئر': u'الظِّئْرَ', #60
u'الظئران': u'الظِّئْرَانِ', #1
u'الظئرة': u'الظِّئْرَةَ', #1
u'الظئرين': u'الظِّئْرَيْنِ', #5
u'الظئورة': u'الظُّئُورَةِ', #2
u'الظئورة': u'الظُّئُورَةَ', #3
u'الع': u'الْعِ', #1
u'الع،': u'الْعَ،', #1
u'العا': u'الْعَا', #1
u'العاب': u'الْعَابِ', #1
u'العاب': u'الْعَابُّ', #1
u'العابدى': u'الْعَابِدِىُّ', #5
u'العاتكة': u'الْعَاتِكَة', #1
u'العاتكة،': u'الْعَاتِكَةَ،', #1
u'العاتكة؟': u'الْعَاتِكَةِ؟', #1
u'العاتكة،': u'الْعَاتِكَةِ،', #10
u'العاتكة': u'الْعَاتِكَةَ', #3
u'العاتكة': u'الْعَاتِكَةِ', #6
u'العادلي': u'الْعَادِلِي', #2
u'العادلية': u'الْعَادِلِيَّةِ', #2
u'العاده': u'الْعَادَهْ', #1
u'العادى': u'الْعَادِى', #1
u'العادى': u'الْعَادِىَ', #1
u'العادى': u'الْعَادِىُّ', #1
u'العادى': u'الْعَادِىِّ', #1
u'العاديهS': u'الْعَادِيَهْS', #1
u'العاديه': u'الْعَادِيَهْ', #1
u'العارضية': u'الْعَارِضِيَّةُ', #1
u'العارضية': u'الْعَارِضِيَّةِ', #7
u'العارى': u'العارى', #1
u'العارى': u'الْعَارِى', #1
u'العاريه': u'الْعَارِيَّهْ', #1
u'العاشرية': u'الْعَاشِرِيَّةِ', #1
u'العاص': u'الْعاصِ', #1
u'العاص،': u'الْعَاصٍ،', #1
u'العاص': u'الْعَاصَ', #10
u'العاص،': u'الْعَاصِ،', #110
u'العاص': u'العاص', #141
u'العاص': u'الْعَاصِ', #2169
u'العاص': u'الْعَاصُ', #29
u'العاص،': u'الْعَاصُ،', #3
u'العاص،': u'العاص،', #39
u'العاص': u'الْعَاص', #7
u'العاصأن': u'الْعَاصِأَنَّ', #1
u'العاص،إن': u'العاص،إِنَّ', #1
u'العاصمى': u'الْعَاصِمِىَّ', #1
u'العاصمى': u'الْعَاصِمِىِّ', #1
u'العاصى': u'الْعَاصِى', #6
u'العاضه': u'الْعَاضِهِ', #3
u'العاضهات': u'الْعَاضِهَاتِ', #1
u'العاضهة': u'الْعَاضِهَةُ', #1
u'العاطب': u'الْعَاطِبَ', #1
u'العاطب': u'الْعَاطِبُ', #2
u'العاطب': u'الْعَاطِبِ', #8
u'العاطش': u'الْعَاطِشِ', #1
u'العاطي': u'الْعَاطِي', #3
u'ألعاع': u'أَلْعَاعٍ', #1
u'العافيا': u'الْعَافِيَا', #1
u'العاقدية': u'الْعَاقِدِيَّةِ', #2
u'العاقله': u'العاقله', #1
u'العاقله': u'الْعَاقِلَهْ', #4
u'العاقول': u'الْعَاقُولِ', #4
u'العاقولى': u'الْعَاقُولِىُّ', #1
u'العاقولي': u'الْعَاقُولِيُّ', #2
u'العاقولي': u'الْعَاقُولِيِّ', #4
u'العالف': u'الْعَالِفِ', #4
u'العالمونا': u'الْعَالِمُونَا', #1
u'العالمينا': u'الْعَالَمِينَا', #3
u'العالى': u'الْعَالِى', #1
u'العاليةكلمة': u'الْعَالِيَةِكَلِمَةُ', #1
u'العاليةوإنما': u'الْعَالِيَةِوَإِنَّمَا', #1
u'العاليةيعني': u'الْعَالِيَةِيَعْنِي', #1
u'العاليه': u'الْعَالِيَهْ', #1
u'العاما': u'الْعَامَا', #3
u'العامرى': u'الْعَامِرِىِّ', #18
u'العامرى': u'الْعَامِرِىُّ', #84
u'العامرية': u'العامرية', #1
u'العامرية،': u'العامرية،', #1
u'العامرية': u'العامريّة', #1
u'العامرية': u'الْعَامِرِيّةُ', #1
u'العامرية،': u'الْعَامِرِيَّةِ،', #1
u'العامرية،': u'الْعَامِرِيَّةُ،', #2
u'العامرية': u'الْعَامِرِيَّةِ', #4
u'العامرية': u'الْعَامِرِيَّةُ', #5
u'العامريين': u'الْعَامِرِيّينَ', #1
u'العامريين،': u'الْعَامِرِيَّيْنِ،', #1
u'العامريين': u'الْعَامِرِيِّينَ', #2
u'العامريين': u'الْعَامِرِيَّيْنِ', #2
u'العامريين': u'الْعَامِرِيّيْنِ', #9
u'العاملونا': u'الْعَامِلُونَا', #1
u'العامود': u'الْعَامُودِ', #1
u'العان': u'الْعَانِ', #1
u'العانقاء': u'الْعَانُقَاءِ', #1
u'العانى': u'الْعَانِىَ', #4
u'العائذي': u'الْعَائِذِيَّ', #1
u'العائذي،': u'الْعَائِذِيَّ،', #1
u'العائذي،': u'الْعَائِذِيِّ،', #1
u'العائذي': u'الْعَائِذِيِّ', #2
u'العائذي': u'الْعَائِذِيُّ', #4
u'العائذي،': u'الْعَائِذِيُّ،', #4
u'العائذى': u'الْعَائِذِىِّ', #4
u'العائر': u'الْعَائِرَ', #1
u'العائر': u'الْعَائِرُ', #1
u'العائر': u'الْعَائِرِ', #6
u'العائرة': u'العائرة', #1
u'العائرة': u'الْعَائِرَة', #2
u'العائرة': u'الْعَائِرَةِ', #7
u'العائشي': u'الْعَائِشِيُّ', #1
u'العائف': u'الْعَائِفُ', #1
u'العائف': u'الْعَائِفِ', #2
u'العائن': u'الْعَائِنَ', #17
u'العائن': u'الْعَائِنُ', #31
u'العائن': u'الْعَائِنِ', #62
u'العبابيب': u'الْعَبَابِيبَ', #2
u'العبابيب': u'الْعَبَابِيبُ', #4
u'العبابيد': u'الْعَبَابِيدَ', #1
u'العبابيد': u'الْعَبَابِيدُ', #1
u'العبابيد': u'الْعَبَابِيدِ', #2
u'العباداني': u'الْعَبَّادَانِيِّ', #1
u'العبادانى': u'الْعَبَادَانِىُّ', #1
u'العباداني': u'الْعَبَّادَانِيُّ', #3
u'العباداني،': u'الْعَبَّادَانِيُّ،', #5
u'العبادلة': u'الْعَبَادِلَةُ', #10
u'العبادلة': u'الْعَبَادِلَةِ', #31
u'العبادلة': u'الْعَبَادِلَةَ', #4
u'العباديد': u'الْعَبَادِيدِ', #1
u'العباره': u'الْعِبَارَهْ', #2
u'العباسى': u'الْعَبَّاسِىُّ', #2
u'العبالة': u'الْعَبَالَةَ', #1
u'العبالة': u'الْعَبَالَةِ', #2
u'العبدا': u'الْعَبْدَا', #1
u'العبدالصلاة': u'الْعَبْدِالصَّلَاةُ', #1
u'العبداني': u'العبداني', #2
u'العبدانية': u'الْعَبْدَانِيَّةُ', #2
u'العبدري،': u'العبدري،', #1
u'العبدري': u'العَبْدري', #1
u'العبدري،': u'العَبْدري،', #1
u'العبدري،': u'العَبْدَريّ،', #1
u'العبدري': u'العَبْدَرِيّ', #1
u'العبدري': u'الْعَبْدَرِيَّ', #1
u'العبدرى': u'الْعَبْدَرِىَّ', #1
u'العبدري': u'الْعَبْدَرِيِّ', #10
u'العبدري،': u'الْعَبْدَرِيَّ،', #2
u'العبدري،': u'الْعَبْدَرِيِّ،', #2
u'العبدري': u'الْعَبْدَرِيّ', #26
u'العبدري': u'الْعَبْدَرِيُّ', #58
u'العبدري،': u'الْعَبْدَرِيُّ،', #7
u'العبدرية،': u'العَبْدَرية،', #1
u'العبدرية': u'الْعَبْدَرِيَّةُ', #1
u'العبدرية،': u'الْعَبْدَرِيَّةُ،', #1
u'العبدلي': u'الْعَبْدَلِيِّ', #1
u'العبدلي': u'الْعَبْدَلِيُّ', #2
u'العبدوسي': u'الْعَبْدُوسِيِّ', #16
u'العبدوسي': u'الْعَبْدُوسِيُّ', #34
u'العبدوى': u'الْعَبْدَوِىَّ', #1
u'العبدوى': u'الْعَبْدُوِىُّ', #2
u'العبدوى': u'الْعَبْدَوِىُّ', #40
u'العبدى': u'الْعَبْدىُّ', #1
u'العبدى': u'الْعُبْدَى', #1
u'العبدى؟': u'الْعَبْدِىُّ؟', #1
u'العبدى': u'الْعَبْدِىِّ', #22
u'العبدى': u'الْعَبَدِىُّ', #23
u'العبدى': u'الْعَبْدِىُّ', #232
u'العبدى': u'الْعَبَدِىِّ', #3
u'العبدى': u'الْعَبْدِىَّ', #3
u'العبرى': u'العَبْرَى', #1
u'العبرى': u'الْعَبْرَى', #1
u'العبسى': u'الْعَبْسِىِّ', #13
u'العبسى': u'الْعَبْسِىَّ', #2
u'العبسى': u'الْعَبْسِىُّ', #31
u'العبشي،': u'الْعَبْشيُّ،', #1
u'العبعب': u'الْعَبْعَبُ', #1
u'العبقسى': u'الْعَبْقَسِىُّ', #1
u'العبل': u'الْعَبْلِ', #1
u'العبلاء': u'الْعَبْلَاءُ', #2
u'العبلات': u'الْعَبَلَاتُ', #1
u'العبلات': u'الْعَبَلَاتِ', #1
u'العبلات': u'الْعَبَلاَتِ', #1
u'العبلات،': u'الْعَبَلَاتِ،', #1
u'العبلات': u'الْعَبَلاتِ', #2
u'العبلة': u'الْعَبْلَةُ', #1
u'العبلي': u'الْعَبْلِيُّ', #1
u'العبهر': u'الْعَبْهَرِ', #1
u'العبيدي': u'الْعُبَيْدَيَّ', #1
u'العبيدي': u'الْعُبَيْدِيِّ', #1
u'العبيدي،': u'الْعُبَيْدِيُّ،', #1
u'العبيدية': u'الْعُبَيْدِيَةِ', #1
u'العبيدية': u'الْعُبَيْدِيَّةُ', #2
u'العبيدين،': u'الْعُبَيْدَيْنِ،', #2
u'العبيدين': u'الْعُبَيْدَيْنِ', #4
u'العبيديون': u'الْعَبِيدِيُّونَ', #1
u'العبيديون': u'الْعُبَيْدِيُّونَ', #3
u'العبيس': u'الْعُبَيْسُ', #1
u'العت': u'الْعَتَّ', #2
u'العتائر': u'الْعَتَائِرُ', #2
u'العتبى': u'الْعُتْبِىُّ', #1
u'العتبى': u'الْعُتْبَى', #6
u'العتبيةأنه': u'الْعُتْبِيَّةِأَنَّهُ', #1
u'العتبيةأو': u'الْعُتْبِيَّةِأَوْ', #1
u'العتبيةعن': u'الْعُتْبِيَّةِعَنْ', #1
u'العتر': u'الْعِتْرُ', #1
u'العتقا': u'الْعِتْقَا', #1
u'العتقاء': u'الْعُتَقَاءِ', #120
u'العتقاء': u'الْعُتَقَاءُ', #21
u'العتقاء': u'الْعُتَقَاءَ', #7
u'العتقى': u'الْعُتَقِىُّ', #1
u'العتقين': u'الْعِتْقَيْنِ', #6
u'العتكي،': u'العتكي،', #1
u'العتكي': u'الْعَتَكِيّ', #1
u'العتكي': u'الْعَتَكِيَّ', #1
u'العتكي،': u'الْعَتَكِيِّ،', #1
u'العتكي،': u'الْعَتَكِيُّ،', #14
u'العتكى': u'الْعَتَكِىَّ', #2
u'العتكي': u'الْعَتَكِيُّ', #21
u'العتكى': u'الْعَتَكِىُّ', #72
u'العتكى': u'الْعَتَكِىِّ', #8
u'العتكي': u'الْعَتَكِيِّ', #9
u'العتكية': u'الْعَتَكِيَّةَ', #1
u'العتكية': u'الْعَتَكِيَّةُ', #2
u'العتواري': u'العتواري', #1
u'العتواري': u'العُتْواري', #1
u'العتواري،': u'الْعُتْوَارِيَّ،', #1
u'العتواري،': u'الْعُتْوَارِيُّ،', #1
u'العتوارى': u'الْعَتَوَارِىَّ', #1
u'العتواري': u'الْعُتْوَارِيُّ', #3
u'العتواري': u'الْعُتْوَارِيِّ', #3
u'العتواريين': u'الْعَتْوَارِيِّينَ', #1
u'العتواريين': u'الْعُتْوَارِيِّينَ', #1
u'العتود': u'العتود', #1
u'العتود': u'الْعَتُودَ', #2
u'العتود': u'الْعَتُودُ', #3
u'العتودة': u'الْعَتْوَدَةَ', #1
u'العتى': u'العتى', #1
u'العتيبة': u'الْعُتَيْبَة', #1
u'العتيبة': u'الْعُتَيْبَةُ', #1
u'العتيبي': u'الْعُتَيْبِيُّ', #1
u'العتيبية': u'الْعَتِيبِيَّةِ', #1
u'العتير': u'الْعَتِيرِ', #1
u'العتير': u'الْعُتَيْرِ', #1
u'العتيرة': u'الْعَتِيرَة', #1
u'العتيرة': u'الْعَتِيرَةَ', #11
u'العتيرة': u'العتيرة', #2
u'العتيرة': u'الْعَتِيرَةِ', #20
u'العتيرة؟': u'الْعَتِيرَةُ؟', #3
u'العتيرة': u'الْعَتِيرَةُ', #37
u'العتيقه': u'الْعَتِيقَهْ', #1
u'العث': u'الْعَثِّ', #1
u'العث': u'الْعُثَّ', #1
u'العث': u'الْعُثِّ', #1
u'العث': u'الْعُثُّ', #5
u'العثاعث': u'الْعَثَاعَثَ', #1
u'العثاعث': u'الْعَثَاعِثَ', #1
u'العثاعث': u'الْعَثَاعِثُ', #1
u'العثامنة': u'الْعَثَامِنَةِ', #2
u'العثان': u'الْعُثَانُ', #1
u'العثاية': u'الْعِثَايَةِ', #1
u'العثة': u'الْعُثَّةُ', #4
u'العثرى': u'الْعَثَرِىُّ', #2
u'العثعث': u'الْعُثْعُثُ', #1
u'العثكال': u'الْعِثْكَالِ', #13
u'العثكال': u'الْعِثْكَالَ', #5
u'العثكال': u'الْعِثْكَالُ', #9
u'العثل': u'الْعَثْلِ', #1
u'العثل': u'الْعَثَلُ', #2
u'العثلون': u'الْعُثْلُونِ', #1
u'العثم': u'الْعَثْمُ', #1
u'العثمانى': u'الَعُثْمَانِىُّ', #1
u'العثمانى': u'الْعُثْمَانِىَّ', #1
u'العثمانى': u'الْعُثْمَانِىُّ', #5
u'العثمة': u'الْعَثْمَةِ', #1
u'العثنون': u'الْعُثْنُونُ', #1
u'العثى': u'الْعُثَى', #1
u'العثيانة': u'الْعِثْيَانَةَ', #1
u'العثيانة': u'الْعِثْيَانَةُ', #2
u'العجاجيل': u'الْعَجَاجِيلُ', #7
u'العجاجيل': u'الْعَجَاجِيلِ', #7
u'العجاردة': u'الْعَجَارِدَةُ', #1
u'العجايات': u'الْعُجَايَاتِ', #2
u'العجاية': u'الْعُجَايَةِ', #1
u'العجدواني': u'الْعَجْدَوَانِيِّ', #1
u'العجرة': u'الْعُجْرَةُ', #3
u'العجلاني': u'الْعَجْلانِيُّ', #1
u'العجلاني': u'العَجْلَانّي', #1
u'العجلاني،': u'الْعَجْلانِيَّ،', #1
u'العجلاني،': u'الْعَجْلانِيُّ،', #1
u'العجلاني،': u'الْعَجْلانِيِّ،', #1
u'العجلاني': u'الْعَجْلَانَيَّ', #1
u'العجلاني': u'الْعَجْلاَنِيُّ', #1
u'العجلاني،': u'الْعَجْلَانِيِّ،', #1
u'العجلاني': u'الْعَجْلَانِيّ', #11
u'العجلانى': u'الْعَجْلاَنِىِّ', #17
u'العجلاني': u'الْعَجْلَانِيَّ', #19
u'العجلاني': u'العجلاني', #2
u'العجلاني': u'الْعَجْلَانَيْ', #2
u'العجلاني': u'الْعَجْلَانِيِّ', #20
u'العجلاني': u'الْعَجْلانِيَّ', #3
u'العجلانى': u'الْعَجْلاَنِىَّ', #4
u'العجلانى': u'الْعَجْلاَنِىُّ', #4
u'العجلاني': u'الْعَجْلَانِيُّ', #40
u'العجلاني': u'الْعَجْلانِيِّ', #6
u'العجلوني': u'الْعَجْلُونِيِّ', #1
u'العجمان': u'الْعَجْمَانِ', #1
u'العجمان': u'الْعُجْمَانِ', #1
u'العجورة': u'الْعَجُّورَةَ', #2
u'العجورة': u'الْعَجُّورَةُ', #2
u'العجورة': u'الْعَجُّورَةِ', #3
u'العجيف': u'الْعَجِيفُ', #1
u'العجيف': u'الْعَجِيفَ', #2
u'العجيفى': u'الْعُجَيْفِىُّ', #1
u'العجيل': u'الْعُجَيْلِ', #1
u'العجيل': u'الْعَجِيلُ', #2
u'العجيلي': u'الْعُجَيْلِيُّ', #1
u'العجيمي': u'الْعَجِيمِيِّ', #3
u'العدا': u'الْعِدَا', #13
u'العدات': u'الْعِدَّاتِ', #1
u'العدات': u'الْعِدَاتِ', #4
u'العداسة': u'الْعَدَاسَةَ', #1
u'العداله': u'الْعَدَالَهْ', #1
u'العدالى': u'الْعَدَالَى', #7
u'العدبس،': u'الْعَدَبَّسِ،', #1
u'العدبس': u'الْعَدَبَّسِ', #5
u'العددا': u'الْعَدَدَا', #2
u'العدلات': u'الْعِدْلَاتِ', #2
u'العدلتان': u'الْعَدْلَتَانِ', #1
u'العدلتين': u'الْعَدْلَتَيْنِ', #1
u'العدلقوله': u'العدلقَوْلُهُ', #1
u'العدلوروي': u'الْعَدْلُوَرُوِيَ', #1
u'العدمان': u'الْعَدَمانِ', #1
u'العدملي': u'الْعُدْمِلِيّ', #1
u'العدمين': u'الْعَدِمِينَ', #1
u'العدمين': u'الْعَدَمَيْنِ', #2
u'العدنى،': u'العدنى،', #1
u'العدنى': u'الْعَدَنِى', #1
u'العدنى': u'الْعَدَنِىُّ', #36
u'العدنى': u'الْعَدَنِىِّ', #5
u'العده': u'الْعِدَّهْ', #6
u'العدواة': u'العدواة', #1
u'العدواة': u'الْعَدَوَاةُ', #1
u'العدواة': u'الْعَدَوَاةِ', #2
u'العدوعليكم': u'الْعَدُوِّعَلَيْكُمْ', #1
u'العدوم': u'العدوم', #1
u'العديس': u'الْعُدَيْسُ', #1
u'العذارة': u'الْعِذَارَةَ', #1
u'العذارة': u'الْعَذَارَةَ', #2
u'العذاق': u'العذاق', #1
u'العذبطة': u'الْعِذْبَطَةُ', #1
u'العذرا': u'الْعُذْرَا', #1
u'العذره': u'الْعَذِرَهْ', #1
u'العذرى': u'الْعَذَرِىِّ', #1
u'العذرى': u'الْعُذْرِىُّ', #1
u'العذرى': u'الْعُذْرِىِّ', #3
u'العذي': u'الْعَذْيَ', #1
u'العذي': u'الْعِذْيُ', #1
u'العذى': u'الْعِذْىُّ', #1
u'العذيب،': u'العّذَيب،', #1
u'العذيب': u'الْعُذَيْب', #1
u'العذيب،': u'الْعُذَيْبِ،', #1
u'العذيب': u'الْعُذَيْبَ', #2
u'العذيب': u'الْعُذَيْبِ', #26
u'العذيب': u'الْعُذَيْبُ', #4
u'العذيبة': u'الْعُذَيْبَةِ', #1
u'العذير': u'الْعَذِيرُ', #1
u'العذيرة': u'الْعَذِيرَةُ', #2
u'العذيطة': u'الْعَذْيَطَةَ', #2
u'العذيطة': u'الْعَذْيَطَةُ', #3
u'العرابنين': u'العَرَابنِين', #1
u'العرادات': u'الْعَرّادَاتِ', #1
u'العرادات': u'الْعَرَّادَاتِ', #3
u'العراضون': u'الْعَرَّاضُونَ', #1
u'العرامطة': u'الْعَرَامِطَةِ', #1
u'العراميس': u'العَرامِيس', #1
u'العراميس': u'الْعَرَامِيسُ', #2
u'العرباض': u'الْعِرْباضُ', #1
u'العرباض،': u'الْعِرْبَاضَ،', #2
u'العرباض': u'الْعِربَاضُ', #3
u'العرباض': u'العرباض', #4
u'العرباض': u'الْعِرْبَاضَ', #4
u'العرباض': u'الْعِرْبَاضِ', #46
u'العرباض،': u'الْعِرْبَاضِ،', #5
u'العرباض': u'الْعِرْبَاضُ', #8
u'العربد': u'الْعِرْبَدُّ', #1
u'العربى': u'الْعَرَبِىِّ', #1
u'العربى': u'الْعَرَبِىَّ', #7
u'العرجة': u'الْعُرْجَةِ', #1
u'العرجيقال': u'الْعَرْجِيُقَالُ', #1
u'العرزال': u'الْعِرْزَالِ', #3
u'العرزمي،': u'العرزمي،', #1
u'العرزمي': u'الْعَرْزَمِيَّ', #1
u'العرزمى': u'الْعَرْزَمِىَّ', #1
u'العرزمى': u'الْعَرْزَمِىُّ', #10
u'العرزمي': u'الْعَرْزَمِيِّ', #11
u'العرزمي،': u'الْعَرْزَمِيُّ،', #21
u'العرزمي،': u'الْعَرْزَمِيِّ،', #5
u'العرزمى': u'الْعَرْزَمِىِّ', #7
u'العرزمي': u'الْعَرْزَمِيُّ', #8
u'العرسا': u'الْعِرْسَا', #2
u'العرسات': u'الْعُرْسَاتِ', #1
u'العرسات': u'الْعُرُسَاتِ', #2
u'العرسة': u'الْعُرَسَةُ', #1
u'العرشالوجه': u'الْعَرْشِالْوَجْهُ', #1
u'العرفج': u'العرفج', #2
u'العرفج': u'الْعَرْفَجَ', #2
u'العرفط': u'العرفط', #1
u'العرفط': u'الْعُرْفُط', #1
u'العرفط': u'الْعُرْفُطُ', #1
u'العرفط': u'الْعُرْفُطِ', #3
u'العرفط': u'الْعُرْفُطَ', #9
u'العرفى': u'الْعُرْفِىِّ', #1
u'العرقبة': u'الْعَرْقَبَةُ', #1
u'العرقبة': u'الْعَرْقَبَةِ', #6
u'العركي': u'الْعَرَكِيُّ', #3
u'العرما': u'الْعَرِمَا', #3
u'العرمس': u'الْعِرْمِسُ', #1
u'العرنجج': u'العَرَنجَج', #2
u'العرنجج': u'الْعَرَنْجَجُ', #2
u'العرنجح': u'الْعَرَنْجَحِ', #1
u'العرني': u'العرني', #1
u'العرنى': u'الْعُرَنِىَّ', #1
u'العرنى': u'الْعُرَنِىِّ', #12
u'العرني': u'الْعُرَنِيِّ', #19
u'العرني،': u'العرني،', #2
u'العرني': u'الْعُرَنِيَّ', #2
u'العرني،': u'الْعُرَنِيَّ،', #2
u'العرني،': u'الْعُرَنِيُّ،', #4
u'العرنى': u'الْعُرَنِىُّ', #4
u'العرني': u'الْعُرَنِيُّ', #7
u'العرني،': u'الْعُرَنِيِّ،', #8
u'العرنيون': u'الْعَرْنِيُّونَ', #1
u'العرنيون': u'الْعُرَنِيّونَ', #2
u'العرنيون': u'الْعُرَنِيُّونَ', #4
u'العرنيين': u'العُرَنيّين', #1
u'العرنيين': u'العُرَنِيّين', #1
u'العرنيين': u'الْعُرَنِيِّينِ', #1
u'العرنيين': u'الْعُرَنِيّينَ', #1
u'العرنيين؟': u'الْعُرَنِيِّينَ؟', #2
u'العرنيين': u'الْعُرَنِيِّينَ', #97
u'العرواء،': u'الْعَرْوَاءُ،', #1
u'العرواء': u'الْعُرَوَاءُ', #4
u'العروضى': u'الْعَرُوضِىُّ', #1
u'العريب': u'الْعَرِيبِ', #1
u'العريب': u'الْعُرَيْبِ', #1
u'العريب': u'الْعَرِيبُ', #2
u'العريضيون': u'الْعُرَيْضِيُّونَ', #1
u'العرينا': u'الْعَرِينَا', #4
u'العزا': u'الْعَزَا', #1
u'العزاق': u'الْعِزَاقِ', #2
u'العزالى': u'الْعَزَالَى', #1
u'العزالى': u'الْعَزَالِى', #1
u'العزالي': u'الْعَزَالِي', #2
u'العزالى': u'الْعَزَالِىَ', #2
u'العزائمى': u'الْعَزَائِمِىُّ', #2
u'العزرمي': u'الْعَزْرَمِيّ', #1
u'العزرمي': u'الْعَزْرَمِيَّ', #1
u'العزرمي': u'الْعَزْرَمِيِّ', #2
u'العزرمي': u'الْعَزْرَمِيُّ', #3
u'العزرمي،': u'الْعَزْرَمِيُّ،', #3
u'العزفج': u'الْعَزْفَجَ', #1
u'العزلين': u'الْعَزْلَيْنِ', #1
u'العزمين': u'الْعَزْمَيْنِ', #3
u'العزور': u'الْعَزَوَّرُ', #1
u'العزوز؟،': u'الْعَزُوزُ؟،', #1
u'العزوين': u'الْعَزْوَيْنِ', #1
u'العزير': u'الْعَزِيرِ', #1
u'العزير': u'الْعُزَيْرَ', #3
u'العزير': u'الْعُزَيْرُ', #8
u'العزير': u'الْعُزَيْرِ', #8
u'العزيزي': u'الْعَزِيزِيُّ', #113
u'العزيزي': u'الْعَزِيزِيِّ', #25
u'العزيزيا': u'الْعَزِيزِيَا', #1
u'العزيزية': u'الْعَزِيزِيَّةِ', #2
u'العزين': u'العزين', #1
u'العسار': u'الْعَسَارَ', #1
u'العسار': u'الْعَسَارِ', #1
u'العسار': u'الْعِسَارَ', #1
u'العسار': u'الْعِسَارُ', #2
u'العسار': u'الْعِسَارِ', #7
u'العساليج': u'الْعَسَالِيجِ', #1
u'العسب': u'الْعَسْبُ', #1
u'العسب': u'الْعَسْبَ', #3
u'العسب': u'الْعُسُبِ', #3
u'العسب': u'الْعَسْبِ', #7
u'العسفا': u'الْعُسْفَا', #1
u'العسفاء': u'الْعُسَفَاءَ', #1
u'العسفاء': u'الْعُسَفَاءِ', #2
u'العسفاء': u'الْعُسَفَاءُ', #3
u'العسقلاني': u'الْعَسْقَلانِيِّ', #1
u'العسقلاني،': u'الْعَسْقُلانِيُّ،', #1
u'العسقلاني،': u'الْعَسْقَلانِيُّ،', #113
u'العسقلانى': u'الْعَسْقَلاَنِىُّ', #18
u'العسقلاني': u'الْعَسْقَلانِيُّ', #19
u'العسقلاني،': u'الْعَسْقَلانِيِّ،', #19
u'العسقلاني،': u'العسقلاني،', #2
u'العسقلاني،': u'الْعَسْقَلانِيَّ،', #2
u'العسقلاني': u'الْعَسْقَلَانِيِّ', #20
u'العسقلاني': u'الْعَسْقَلَانِيَّ', #3
u'العسقلاني': u'العسقلاني', #4
u'العسقلاني': u'الْعَسْقَلَانِيُّ', #47
u'العسكرى': u'الْعَسْكَرِىِّ', #1
u'العسكرى': u'الْعَسْكَرِىُّ', #84
u'العسم': u'الْعَسْمُ', #1
u'العسم': u'الْعَسَمُ', #2
u'العسيب': u'العَسيبَ', #1
u'العسيب': u'الْعَسِيبَ', #2
u'العسيب': u'الْعَسِيبِ', #20
u'العسيب': u'العسيب', #3
u'العسيب': u'الْعَسِيبُ', #8
u'العسيف': u'الْعَسِيفِ', #25
u'العسيف': u'الْعَسِيفُ', #5
u'العسيلة': u'الْعَسِيلَةِ', #1
u'العسيلة': u'الْعُسَيْلَةُ', #14
u'العسيلة': u'العسيلة', #2
u'العسيلة': u'الْعُسَيْلَةَ', #23
u'العسيلة': u'الْعُسَيْلَةِ', #40
u'العشاءوروي': u'الْعِشَاءِوَرُوِيَ', #1
u'العشائين': u'الْعِشَائِينِ', #1
u'العشائين،': u'الْعِشَائَيْنِ،', #1
u'العشائين': u'الْعِشَائَيْنِ', #3
u'العشبة': u'الْعُشْبَةَ', #1
u'العشبة': u'الْعُشْبَةُ', #1
u'العشبة': u'الْعُشْبَةِ', #4
u'العشرينا': u'الْعِشْرِينَا', #2
u'العشرينين': u'الْعِشْرِينَيْنِ', #2
u'العشماوي': u'الْعَشْمَاوِيُّ', #209
u'العشماوي': u'الْعَشْمَاوِيِّ', #9
u'العشماوية': u'الْعَشْمَاوِيَّةِ', #5
u'العشنزر': u'الْعَشَنْزَرُ', #2
u'العشنق': u'العشنق', #1
u'العشنق': u'الْعَشَنَّقُ', #1
u'العشى': u'الْعَشِىِّ', #17
u'العشى': u'الْعَشِىُّ', #4
u'العشيرا': u'العَشِيرَا', #1
u'العشيرأي': u'الْعَشِيرُأَيْ', #1
u'العشيره': u'الْعَشِيرَهْ', #3
u'العشيشية': u'العشيشية', #1
u'العصافة': u'الْعُصَافَةُ', #2
u'العصافر': u'الْعَصَافِرُ', #5
u'العصاية': u'الْعَصَايَةِ', #1
u'العصباء': u'الْعَصْبَاءِ', #1
u'العصبه': u'الْعَصَبَهْ', #1
u'العصركاملة': u'العصركاملة', #1
u'العصرى': u'الْعَصَرِىُّ', #2
u'العصفة': u'الْعَصْفَةَ', #1
u'العصفر،': u'الْعُصْفُرِ،', #1
u'العصفر': u'الْعُصْفُرَ', #20
u'العصفر': u'الْعُصْفُرُ', #32
u'العصفر': u'الْعُصْفُرِ', #84
u'العصفري': u'الْعُصْفُرِيّ', #1
u'العصفري': u'الْعُصْفُرِيَّ', #1
u'العصفري': u'الْعُصْفُرِيِّ', #1
u'العصفرى': u'الْعُصْفُرِىِّ', #1
u'العصفرى': u'الْعُصْفُرِىُّ', #2
u'العصفري': u'الْعُصْفُرِيُّ', #3
u'العصفري،': u'الْعُصْفُرِيُّ،', #6
u'العصل': u'الْعَصَلِ', #2
u'العصل': u'الْعَصَلْ', #3
u'العصلاء': u'الْعَصْلَاءِ', #2
u'العصلبي': u'الْعَصْلَبِيُّ', #1
u'العصمور': u'الْعُصْمُورُ', #1
u'العصنوتي': u'الْعَصَنُوتِيِّ', #1
u'العصنوني': u'العصنوني', #3
u'العصنوني': u'الْعَصْنُونِيِّ', #4
u'العصنوني': u'الْعَصْنُونِيُّ', #6
u'العصوبة': u'الْعُصُوبَةَ', #26
u'العصوبة': u'الْعُصُوبَةِ', #289
u'العصوبة': u'الْعُصُوبَةُ', #54
u'العصوبة': u'الْعُصُوبَة', #9
u'العصى': u'الْعُصِىِّ', #1
u'العصى': u'الْعِصِىِّ', #1
u'العصيرة': u'الْعَصِيرَةِ', #1
u'العصيم': u'الْعَصِيمِ', #1
u'العضاريط': u'الْعَضَارِيطِ', #2
u'العضاه': u'الْعِضَاهَ', #1
u'العضاه': u'الْعِضَاهِ', #19
u'العضاه': u'العضاه', #3
u'العضاه': u'الْعِضَاهُ', #3
u'العضاه': u'الْعِضَاه', #4
u'العضائد': u'الْعَضَائِدَ', #1
u'العضائد': u'الْعَضَائِدِ', #1
u'العضائد': u'الْعَضَائِدُ', #2
u'العضب': u'الْعَضْب', #1
u'العضب،': u'الْعَضْبُ،', #1
u'العضب': u'الْعَضْبَ', #18
u'العضب': u'الْعَضَبَ', #2
u'العضب': u'الْعَضْبِ', #24
u'العضب': u'الْعَضَبِ', #4
u'العضب': u'الْعَضْبُ', #6
u'العضب': u'الْعَضَبُ', #8
u'العضباء': u'العضباء', #1
u'العضباء،': u'العَضْباء،', #1
u'العضباء،': u'الْعَضْبَاءُ،', #1
u'العضباء': u'الْعَضْبَاءَ', #20
u'العضباء': u'الْعَضْبَاءِ', #27
u'العضباء،': u'الْعَضْبَاءِ،', #3
u'العضباء': u'الْعَضْبَاءُ', #48
u'العضرط': u'الْعَضْرَطَ', #1
u'العضه': u'العضه', #1
u'العضه': u'الْعِضَه', #1
u'العضه': u'الْعِضَهَ', #1
u'العضه': u'الْعِضَهُ', #1
u'العضه؟': u'الْعَضْهُ؟', #2
u'العضه': u'الْعَضْهُ', #7
u'العضهة': u'الْعَضْهَةُ', #1
u'العضيد': u'الْعَضِيدُ', #1
u'العضين': u'الْعِضِينَ', #2
u'العضيهة': u'الْعَضِيهَةِ', #1
u'العطا': u'الْعَطَا', #2
u'العطارد': u'الْعُطَارِدُ', #1
u'العطاردى': u'الْعُطَارِدِىِّ', #17
u'العطاردى': u'الْعُطَارِدِىَّ', #2
u'العطاردى': u'الْعُطَارِدِىُّ', #42
u'العطاردي،والأحمسي': u'الْعُطَارِدِيُّ،وَالأَحْمَسِيُّ', #1
u'العطارون': u'الْعَطَّارُونَ', #10
u'العطارين': u'الْعَطَّارِينَ', #45
u'العطاسا': u'الْعُطَاسَا', #1
u'العطان،': u'الْعَطَّانُ،', #1
u'العطايات': u'الْعَطَايَاتِ', #1
u'العطشين': u'الْعَطَشَيْنِ', #1
u'العطن،': u'العَطَن،', #1
u'العطن': u'العطن', #2
u'العطن': u'الْعَطَنَ', #2
u'العطن': u'الْعَطَنُ', #2
u'العطن': u'الْعَطَنِ', #65
u'العطوفي': u'الْعَطُوفِيُّ', #1
u'العطيات': u'الْعَطِيَّاتُ', #1
u'العطيات': u'الْعَطِيّاتِ', #2
u'العطيات': u'الْعَطِيَّاتِ', #2
u'العطيفي': u'الْعُطَيْفِيُّ', #1
u'العطيمة': u'الْعَطِيمَةِ', #1
u'العظا': u'الْعِظَا', #4
u'العظلم': u'الْعِظْلِمُ', #2
u'العظما': u'الْعُظَمَا', #1
u'العظيمالوجه': u'الْعَظِيمِالْوَجْهُ', #1
u'العظيوط': u'الْعِظْيَوْطُ', #1
u'العغو': u'الْعَغْوِ', #1
u'العفا': u'الْعَفَا', #1
u'العفاص': u'الْعِفَاصُ', #14
u'العفاص': u'الْعِفَاصِ', #44
u'العفاص': u'العفاص', #6
u'العفاص': u'الْعِفَاصَ', #89
u'العفص': u'الْعَفْصَ', #1
u'العفص': u'الْعَفْصُ', #4
u'العفص': u'الْعَفْصِ', #5
u'العفصى': u'الْعَفْصِىُّ', #1
u'العفل': u'الْعَفْلِ', #1
u'العفل': u'الْعَفَلِ', #4
u'العفل': u'الْعَفَلُ', #6
u'العفلة': u'الْعَفْلَةِ', #1
u'العفلة': u'الْعَفَلَةِ', #2
u'العفلة': u'الْعَفَلَةُ', #7
u'العفوصة': u'الْعُفُوصَةِ', #1
u'العفيفية': u'الْعَفِيفِيَّةِ', #4
u'العقابا': u'الْعِقَابَا', #2
u'العقاص': u'العقاص', #1
u'العقاص': u'الْعِقَاصُ', #1
u'العقاص': u'الْعِقَاصِ', #6
u'العقباني': u'الْعُقْبَانِيّ', #1
u'العقباني': u'الْعُقْبَانِيُّ', #12
u'العقباني': u'الْعُقْبَانِيِّ', #9
u'العقباوي': u'الْعُقْبَاوِيُّ', #2
u'العقبيون': u'الْعُقْبِيُّونَ', #1
u'العقدى': u'العَقَدِىُّ', #1
u'العقدى': u'الْعَقَدِىِّ', #10
u'العقدى': u'الْعَقَدِىَّ', #5
u'العقدى': u'الْعَقَدِىُّ', #50
u'العقصاء': u'الْعَقْصَاءُ', #1
u'العقصاء': u'العقصاء', #2
u'العقنقل': u'الْعَقَنْقَلُ', #3
u'العقنقل': u'الْعَقَنْقَلِ', #9
u'العقو': u'الْعُقُو', #2
u'العقودات': u'الْعُقُودَاتِ', #1
u'العقولا': u'الْعَقُولَا', #1
u'العقولة': u'العقولة', #1
u'العقيبة': u'الْعُقَيْبَةَ', #1
u'العقيبة': u'الْعُقَيْبَةِ', #1
u'العقيصة': u'الْعَقِيصَةُ', #1
u'العقيصة': u'الْعَقِيصَةِ', #2
u'العقيصتين': u'الْعَقِيصَتَيْنِ', #5
u'العقيقه': u'الْعَقِيقَهْ', #1
u'العقيقى': u'الْعَقِيقِىُّ', #1
u'العقيلى': u'الْعَقِيلِىُّ', #1
u'العقيلى': u'الْعُقَيْلِىُّ', #10
u'العقيلى': u'الْعُقَيْلِىِّ', #10
u'العكارون': u'الْعَكّارُونَ', #1
u'العكارون': u'الْعَكَّارُونَ', #11
u'العكاكين': u'الْعَكَّاكِينَ', #1
u'العكام': u'الْعَكَّامُ', #1
u'العكام': u'الْعَكَّامِ', #1
u'العكام': u'الْعِكَامُ', #1
u'العكام': u'الْعِكَامِ', #1
u'العكامين': u'الْعِكَامَيْنِ', #1
u'العكامين': u'الْعَكَّامِينَ', #6
u'العكاوي': u'الْعَكَّاوِيُّ', #1
u'العكبري': u'العكبري', #2
u'العكبرى': u'الْعُكْبُرِىُّ', #2
u'العكبري': u'الْعُكْبَرِيِّ', #21
u'العكبرى': u'الْعُكْبَرِىُّ', #7
u'العكبري': u'الْعُكْبَرِيُّ', #86
u'العكبريان': u'الْعُكْبَرِيَّانِ', #1
u'العكبريين': u'الْعُكْبَرِيِّينَ', #1
u'العكة': u'العكة', #3
u'العكلي': u'العكلي', #1
u'العكلى': u'الْعُكَلِىُّ', #1
u'العكلي': u'الْعُكْلِيِّ', #10
u'العكلى': u'الْعُكْلِىَّ', #2
u'العكلى': u'الْعُكْلِىِّ', #3
u'العكلي،': u'الْعُكْلِيُّ،', #4
u'العكلي،': u'الْعُكْلِيِّ،', #4
u'العكلي': u'الْعُكْلِيُّ', #6
u'العكلى': u'الْعُكْلِىُّ', #6
u'العكلي،في': u'الْعُكْلِيِّ،فِي', #1
u'العكليين،': u'العُكْلِيِّينَ،', #1
u'العكم': u'الْعَكْمُ', #1
u'العكم': u'الْعِكْمِ', #1
u'العكم': u'الْعَكْمِ', #2
u'العكن': u'الْعُكَنَ', #1
u'العكن': u'الْعُكَنُ', #1
u'العكنة': u'الْعُكْنَة', #1
u'العكوس': u'الْعُكُوسِ', #1
u'العكوس': u'الْعَكُوسُ', #2
u'العكوس': u'الْعُكُوسُ', #3
u'العكوسات': u'الْعُكُوسَاتِ', #1
u'العكوم': u'العكوم', #1
u'العكوم': u'الْعُكُومُ', #4
u'العكى': u'الْعَكِّىُّ', #1
u'العكى': u'الْعَكِّىِّ', #1
u'العكير': u'العكير', #1
u'العكير': u'الْعُكَيْرِ', #5
u'العكيشية': u'الْعُكَيْشِيَّةِ', #1
u'العكيم': u'الْعُكَيْمِ', #1
u'العلابى': u'الْعَلاَبِىَّ', #1
u'العلاتي': u'الْعَلَّاتِيِّ', #1
u'العلاط': u'الْعِلَاطُ', #1
u'العلافية': u'الْعِلَافِيّةُ', #1
u'العلافيين،': u'الْعِلافِيِّينَ،', #1
u'العلاق': u'الْعِلاقِ', #1
u'العلاق': u'الْعَلَاق', #1
u'العلاق': u'الْعَلَاقُ', #1
u'العلاق': u'الْعِلاَقِ', #3
u'العلاق': u'الْعِلَاقِ', #5
u'العلاقه': u'الْعَلّاقَه', #1
u'العلاقه': u'الْعَلّاقَهْ', #1
u'العلاقه': u'الْعِلَاقَهْ', #1
u'العلالة': u'الْعُلَالَةُ', #1
u'العلامي': u'الْعَلَامِيّ', #1
u'العلامي': u'الْعَلَامِيُّ', #1
u'العلامي': u'الْعَلَّامِيُّ', #1
u'العلامي': u'الْعَلَامِيِّ', #11
u'العلامي': u'الْعَلَّامِيِّ', #6
u'العلامية': u'الْعَلَامِيَّةِ', #2
u'العلامية': u'الْعَلَّامِيَّةِ', #3
u'العلث': u'الْعَلَثِ', #1
u'العلث': u'الْعَلْثُ', #2
u'العلث': u'الْعَلْثِ', #8
u'العلجة': u'الْعِلْجَةُ', #2
u'العلس': u'الْعَلْس', #1
u'العلس': u'الْعَلَسِ', #13
u'العلس': u'الْعَلْسَ', #2
u'العلس': u'الْعَلْسُ', #2
u'العلس': u'الْعَلَسُ', #28
u'العلس': u'الْعَلْسِ', #4
u'العلس': u'الْعَلَسَ', #7
u'العلطة': u'الْعُلْطَةُ', #1
u'العلقآية': u'العلقآية', #1
u'العلقى': u'الْعَلَقِىَّ', #1
u'العلقى': u'الْعَلَقِىِّ', #1
u'العللا': u'الْعِلَلَا', #1
u'العلما': u'الْعِلْمَا', #1
u'العلما': u'الْعُلَمَا', #11
u'العلماءأنه': u'الْعُلَمَاءِأَنَّهُ', #1
u'العلمالوجه': u'الْعِلْمُالْوَجْهُ', #1
u'العلمالوجه': u'الْعِلْمِالْوَجْهُ', #1
u'العلمس': u'الْعَلْمَسُ', #1
u'العلملأن': u'الْعِلْمِلِأَنَّ', #1
u'العلميه': u'الْعِلْمِيَّهْ', #1
u'العله،': u'العله،', #1
u'العلهز': u'الْعِلْهِزَ', #8
u'العلواني': u'الْعَلْوَانِيُّ', #1
u'العلوة': u'الْعُلْوَةِ', #1
u'العلوص': u'الْعِلَّوْصُ', #1
u'العلوص': u'الْعِلَّوْصِ', #2
u'العلوفات': u'الْعَلُوفَاتِ', #3
u'العلوفة': u'الْعُلُوفَةَ', #1
u'العلوفة': u'الْعَلُوفَةِ', #16
u'العلوفة': u'الْعُلُوفَةُ', #2
u'العلوفة': u'الْعَلُوفَةَ', #4
u'العلوفة': u'الْعُلُوفَةِ', #4
u'العلوفة': u'الْعَلُوفَةُ', #8
u'العلوى': u'العَلَوِىُّ', #1
u'العلوى': u'الْعَلَوِىُّ', #375
u'العلوى': u'الْعَلَوِىِّ', #5
u'العلياوين،': u'الْعُلْيَاوَيْنِ،', #1
u'العلياوين': u'الْعُلْيَاوَيْنِ', #3
u'العليمي': u'الْعُلَيْمِيُّ', #1
u'العليمي': u'الْعُلَيْمِيِّ', #4
u'العليه': u'الْعَلِيّه', #1
u'العليه': u'الْعَلِيّهْ', #1
u'العمالون': u'الْعَمَّالُونَ', #1
u'العماليق': u'الْعَمَالِيقِ', #10
u'العماليق': u'الْعَمَالِيقُ', #5
u'العمردة': u'الْعَمَرَّدَةَ', #2
u'العمرو،': u'الْعمرو،', #1
u'العمروسي': u'الْعَمْرُوسِيِّ', #1
u'العمرى': u'الْعَمْرِىُّ', #1
u'العمرى': u'الْعُمَرِى', #1
u'العمرى،': u'الْعُمْرَى،', #1
u'العمرى؟': u'الْعُمْرَى؟', #1
u'العمرى': u'الْعُمَرِىِّ', #21
u'العمرى': u'الْعُمَرِىَّ', #3
u'العمرى': u'الْعُمْرَى', #379
u'العمرى': u'العمرى', #7
u'العمرى': u'الْعُمَرِىُّ', #89
u'العمريطي': u'الْعِمْرِيطِيُّ', #2
u'العمطريني': u'الْعَمْطَرِينِيِّ', #1
u'العملا': u'الْعَمَلَا', #4
u'العمومه': u'الْعُمُومَهْ', #1
u'العميا': u'الْعِمِّيَّا', #1
u'العميدي': u'الْعَمِيدِيُّ', #1
u'العميس،': u'الْعُمَيْسِ،', #11
u'العميس': u'الْعُمَيْسِ', #32
u'العميصاء': u'الْعَمِيصَاءِ', #1
u'العميصاء': u'الْعُمَيْصَاءَ', #1
u'العنابس': u'الْعَنَابِسَ', #1
u'العناة،': u'الْعُنَاةَ،', #2
u'العناج': u'الْعِنَاجَ', #1
u'العناجة': u'الْعَنَاجَةِ', #2
u'العناجيج': u'الْعَنَاجِيجُ', #3
u'العناجيح': u'الْعَنَاجِيحَ', #1
u'العناص': u'العناص', #1
u'العنانة': u'الْعَنَانَةِ', #1
u'العنائم،': u'العنائم،', #1
u'العنبج': u'العنبج', #1
u'العنبرى': u'الْعَنْبَرِىِّ', #17
u'العنبرى': u'الْعَنْبَرِىُّ', #269
u'العنبرى': u'الْعَنْبَرِىَّ', #6
u'العنبس': u'العنبس', #1
u'العنبس': u'الْعنبس', #1
u'العنبس': u'الْعَنْبَس', #1
u'العنبس': u'الْعَنْبَسِ', #32
u'العنبس،': u'الْعَنْبَسِ،', #8
u'العنبسي': u'الْعَنْبَسِيِّ', #1
u'العنة': u'الْعُنَّة', #1
u'العنة': u'الْعِنَّةِ', #1
u'العنة': u'الْعُنَّةِ', #215
u'العنة': u'الْعُنَّةَ', #46
u'العنة': u'الْعُنَّةُ', #49
u'العنتا': u'الْعَنَتَا', #1
u'العنجد': u'الْعَنْجَدُ', #1
u'العندية': u'الْعِنْدِيَّةَ', #2
u'العندية': u'الْعِنْدِيَّةِ', #2
u'العندية': u'الْعِنْدِيَّةُ', #6
u'العنزى': u'الْعَنْزِىِّ', #1
u'العنزى': u'الْعَنَزِىَّ', #2
u'العنزى': u'الْعَنْزِىُّ', #4
u'العنزى': u'الْعَنَزِىِّ', #8
u'العنزى': u'الْعَنَزِىُّ', #83
u'العنسي،': u'العنسي،', #1
u'العنسي': u'العنْسي', #1
u'العنسي': u'العَنْسي', #1
u'العنسي،': u'العَنْسيّ،', #1
u'العنسي': u'العَنْسِيّ', #1
u'العنسي': u'الْعَنَسِيُّ', #1
u'العنسي،': u'الْعَنْسِيَّ،', #1
u'العنسي': u'الْعَنْسِيّ', #12
u'العنسي': u'الْعَنْسِيِّ', #16
u'العنسي،': u'العَنْسِيّ،', #2
u'العنسي': u'الْعَنْسِيُّ', #24
u'العنسى': u'الْعَنْسِىَّ', #3
u'العنسى': u'الْعَنْسِىِّ', #3
u'العنسي': u'الْعَنْسِيَّ', #4
u'العنسى': u'الْعَنْسِىُّ', #4
u'العنسي': u'العنسي', #5
u'العنسي،': u'الْعَنْسِيُّ،', #6
u'العنصل': u'الْعُنْصُلِ', #1
u'العنطنطة': u'العنطنطة', #1
u'العنطنطة': u'الْعَنَطْنَطَةُ', #1
u'العنطنطة': u'الْعَنَطْنَطَةِ', #2
u'العنقا': u'الْعُنُقَا', #1
u'العنقري': u'الْعَنْقَرِيُّ', #1
u'العنقري،': u'الْعَنْقَرِيُّ،', #8
u'العنقزي': u'الْعَنْقَزِيِّ', #1
u'العنقزي،': u'الْعَنْقَزِيَّ،', #1
u'العنقزى،': u'العنقزى،', #1
u'العنقزي،': u'العنقزي،', #2
u'العنقزي': u'الْعَنْقَزِيَّ', #2
u'العنقزى': u'الْعَنْقَزِىُّ', #2
u'العنقزي،': u'الْعَنْقَزِيُّ،', #32
u'العنقزي،': u'الْعَنْقَزِيِّ،', #5
u'العنقزي': u'الْعَنْقَزِيُّ', #8
u'العنم': u'الْعَنَمُ', #1
u'العنوي': u'الْعَنْوِيَّ', #13
u'العنوي': u'الْعَنْوِيِّ', #20
u'العنوي': u'الْعَنْوِيُّ', #7
u'العنوية': u'الْعَنْوِيَّة', #1
u'العنوية': u'الْعَنْوِيَّةُ', #10
u'العنوية': u'الْعَنْوِيَّةِ', #12
u'العنوية': u'الْعَنْوِيَّةَ', #3
u'العنيق': u'الْعُنَيْقَ', #1
u'العنين': u'العِنِّين', #1
u'العنين': u'الْعَنِينِ', #1
u'العنين': u'العنين', #2
u'العنين': u'الْعِنِّينِ', #308
u'العنين': u'الْعِنِّينَ', #42
u'العنين': u'الْعِنِّينُ', #82
u'العهدآيها': u'الْعَهْدِآيُهَا', #1
u'العهده': u'الْعُهْدَهْ', #1
u'العهدوروي': u'الْعَهْدُوَرُوِيَ', #1
u'العواتك': u'الْعَوَاتِكُ', #1
u'العواتك': u'الْعَوَاتِكِ', #10
u'العوار': u'الْعُوَارُ', #1
u'العوار': u'الْعَوَارِ', #19
u'العوار': u'الْعُوَارِ', #2
u'العوار': u'الْعَوَارُ', #6
u'العوارت': u'الْعَوْارَتِ', #1
u'العوارك،': u'الْعَوَارِكِ،', #1
u'العوارك': u'الْعَوَارِكِ', #3
u'العوارى': u'العوارى', #1
u'العوارى': u'الْعَوَارِىِّ', #1
u'العوازان': u'الْعَوَازَانِ', #1
u'العواطي': u'الْعَوَاطِي', #1
u'العوافى': u'الْعَوَافِى', #2
u'العوال': u'الْعَوَالِ', #1
u'العوالى': u'العَوَالِى', #1
u'العوالى': u'الْعَوَالِى', #15
u'العوالى': u'الْعَوَالِىَ', #2
u'العواليا': u'الْعَوَالِيَا', #1
u'العوامأنه': u'الْعَوَّامِأَنَّهُ', #1
u'العوامد': u'الْعَوَامِدِ', #2
u'العواميد': u'الْعَوَامِيدِ', #5
u'العوانة': u'الْعَوَانَةُ', #1
u'العواني': u'الْعَوَانِي', #2
u'العوائث': u'الْعَوَائِثِ', #2
u'العوائر': u'الْعَوَائِرَ', #1
u'العوة': u'الْعَوّةِ', #1
u'العوجري،': u'الْعَوْجَرِيُّ،', #1
u'العوذى': u'الْعَوْذِىُّ', #2
u'العورا': u'الْعَوْرَا', #1
u'العوضات': u'الْعِوَضَاتِ', #1
u'العوفي،': u'العَوْفي،', #1
u'العوفي': u'الْعَوْفِيّ', #10
u'العوفي': u'الْعَوْفِيُّ', #173
u'العوفى': u'الْعَوْفِىُّ', #19
u'العوفى': u'الْعَوَفِىُّ', #2
u'العوفي،': u'الْعَوْفِيِّ،', #29
u'العوفي،': u'العوفي،', #3
u'العوفى': u'الْعَوْفِىَّ', #3
u'العوفي': u'العوفي', #5
u'العوفي': u'العَوْفِيّ', #5
u'العوفى': u'الْعَوْفِىِّ', #5
u'العوفي': u'الْعَوْفِيَّ', #7
u'العوفي': u'الْعَوْفِيِّ', #88
u'العوفي،': u'الْعَوْفِيُّ،', #95
u'العوفي،و': u'الْعَوْفِيِّ،وَ', #1
u'العوفي،وجعل': u'الْعَوْفِيِّ،وَجَعَلَ', #1
u'العوقة': u'الْعُوقَةِ', #1
u'العوقي': u'الْعَوَقِيُّ', #1
u'العوقي': u'الْعَوْقِيّ', #1
u'العوقى': u'الْعَوَقِىُّ', #2
u'العوهي': u'الْعَوْهِيُّ', #1
u'العوهي،': u'الْعَوَهِيُّ،', #1
u'العوهي،': u'الْعَوَهِيِّ،', #1
u'العوهي،': u'الْعَوْهِيِّ،', #2
u'العوهي،': u'الْعَوْهِيُّ،', #7
u'العويد': u'الْعُوَيْدَ', #1
u'العويس': u'الْعُوَيْسِ', #1
u'العوين': u'الْعَوِينُ', #3
u'العوين': u'الْعَوِينِ', #4
u'العوينتين': u'الْعُوَيْنَتَيْنِ', #2
u'العى': u'الْعَىِّ', #1
u'العى': u'الْعِىِّ', #3
u'العياب': u'الْعُيَّابِ', #1
u'العياب': u'الْعِيَابِ', #2
u'العياش': u'الْعَيَّاشِ', #2
u'العياشي': u'الْعَيَّاشِيِّ', #2
u'العياض': u'العياض', #1
u'العياض': u'الْعِيَاضِ', #1
u'العياضي': u'الْعِيَاضِي', #1
u'العياضي': u'الْعِيَاضِيَّ', #2
u'العياضي': u'الْعِيَاضِيُّ', #5
u'العياضي': u'الْعِيَاضِيِّ', #7
u'العياطلة': u'الْعَيَاطِلَةَ', #1
u'العيافة': u'الْعَيَّافَةُ', #1
u'العيافة': u'الْعِيَافَةُ', #19
u'العيافة': u'الْعِيَافَةَ', #4
u'العيافة': u'الْعِيَافَةِ', #6
u'العيالا': u'الْعِيَالَا', #2
u'العيالان': u'الْعَيَّالَانِ', #1
u'العيالان': u'الْعِيَالَانِ', #2
u'العياياء': u'العياياء', #1
u'العيبة': u'الْعَيْبَةَ', #2
u'العيبة': u'الْعَيْبَةِ', #9
u'العيتاوي': u'الْعِيتَاوِيِّ', #1
u'العيثمي': u'الْعَيْثَمِيّ', #1
u'العيدإذا': u'الْعِيدِإِذَا', #1
u'العيدروس': u'الْعَيْدَرُوس', #1
u'العيدروس': u'الْعَيْدَرُوسِ', #1
u'العيرتين': u'الْعَيْرَتَيْنِ', #1
u'العيزار': u'الْعِيزَارُ', #1
u'العيزار': u'الْعِيزَارِ', #1
u'العيزار': u'الْعَيْزَارُ', #1
u'العيزار،': u'الْعَيْزَارَ،', #1
u'العيزار': u'الْعَيْزَارَ', #2
u'العيزار،': u'العيزار،', #3
u'العيزار': u'العيزار', #4
u'العيزار،': u'الْعَيْزَارِ،', #5
u'العيزار': u'الْعَيْزَارِ', #52
u'العيزار،،أنه': u'الْعَيْزَارِ،،أَنَّهُ', #1
u'العيس': u'الْعِيسَ', #12
u'العيس': u'الْعِيسِ', #5
u'العيس': u'الْعِيسُ', #7
u'العيسوي': u'الْعِيسَوِيِّ', #20
u'العيسوية': u'الْعِيسَوِيَّةِ', #12
u'العيسوية': u'الْعِيسَوِيَّةُ', #7
u'العيسي': u'الْعِيسِيُّ', #1
u'العيسي': u'الْعِيسِيِّ', #1
u'العيسىأنه': u'الْعِيسَىأَنَّهُ', #1
u'العيشى': u'الْعَيْشِىُّ', #16
u'العيص،': u'العيص،', #1
u'العيص،': u'الْعِيصِ،', #2
u'العيص،': u'الْعَيْصِ،', #2
u'العيص': u'العيص', #3
u'العيص': u'العِيص', #3
u'العيص': u'الْعِيصَ', #3
u'العيص': u'الْعَيْصِ', #3
u'العيص': u'الْعِيصِ', #31
u'العيص': u'الْعِيصُ', #4
u'العيطاء': u'العيطاء', #2
u'العيلم': u'الْعَيْلَمِ', #1
u'العيمان': u'الْعَيْمَانَ', #1
u'العيمة': u'الْعَيْمَةِ', #1
u'العيناء': u'الْعَيْنَاءِ', #4
u'العينوالوجه': u'الْعَيْنِوَالْوَجْهُ', #1
u'العينواني': u'الْعَيْنَوَانِيِّ', #1
u'العيهب': u'الْعَيْهَبُ', #3
u'العيهم': u'الْعَيْهَمَ', #2
u'العيوبا': u'الْعُيُوبَا', #1
u'العيوق': u'الْعَيّوقِ', #1
u'العيوق': u'الْعَيُّوقِ', #4
u'العيي': u'الْعَيِيَّ', #1
u'العيي': u'الْعَيِيُّ', #1
u'العيي': u'الْعَيِيِّ', #3
u'الغابن': u'الْغَابِنِ', #1
u'الغاذية': u'الْغَاذِيَّةَ', #1
u'الغاذية': u'الْغَاذِيَةُ', #2
u'الغاريقون': u'الْغَارِيقُونُ', #1
u'الغاريقون': u'الْغَارِيقُونَ', #2
u'ألغاز': u'أَلْغَازً', #1
u'الغازى': u'الْغَازِىُّ', #1
u'الغازى': u'الْغَازِى', #12
u'الغاضرة': u'الْغَاضِرَةُ', #1
u'الغاضري': u'الْغَاضِرِيَّ', #1
u'الغاضري': u'الْغَاضِرِيِّ', #1
u'الغاضرى': u'الْغَاضِرِىَّ', #1
u'الغاضرى': u'الْغَاضِرِىِّ', #1
u'الغافري': u'الْغَافِرِي', #1
u'الغافقي': u'الغافقيّ', #1
u'الغافقي،': u'الغافقي،', #1
u'الغافقي': u'الْغَافِقِيِّ', #14
u'الغافقي': u'الْغَافِقِيّ', #2
u'الغافقي': u'الْغَافِقِيَّ', #2
u'الغافقي': u'الْغَافِقِيُّ', #20
u'الغافقي': u'الغافقي', #4
u'الغافقي،': u'الْغَافِقِيِّ،', #6
u'الغافقى': u'الْغَافِقِىُّ', #6
u'الغافقي،': u'الْغَافِقِيُّ،', #7
u'الغافقى': u'الْغَافِقِىِّ', #7
u'الغالط': u'الْغَالِطُ', #10
u'الغالط': u'الْغَالِطِ', #37
u'الغالط': u'الْغَالِطَ', #7
u'الغالطون': u'الْغَالِطُونَ', #1
u'الغالطين': u'الْغَالِطِينَ', #2
u'الغالى': u'الْغَالِى', #1
u'الغامدي': u'الغامدّي', #1
u'الغامدي': u'الغامِديّ', #1
u'الغامدي،': u'الغامِديّ،', #1
u'الغامدي،': u'الْغَامِدِيُّ،', #1
u'الغامدي': u'الْغَامِدِيِّ', #17
u'الغامدي': u'الْغَامِدِيَّ', #2
u'الغامدى': u'الْغَامِدِىِّ', #2
u'الغامدي': u'الغامدي', #5
u'الغامدي': u'الْغَامِدِيُّ', #5
u'الغامدية،': u'الْغَامِدِيَّةُ،', #1
u'الغامدية': u'الْغَامِدِيَّةُ', #14
u'الغامدية': u'الْغَامِدِيَّةَ', #23
u'الغامدية': u'الْغَامِدِيَّةِ', #60
u'الغآئط': u'الْغَآئِطِ', #1
u'الغايص': u'الْغَايِصُ', #1
u'الغايص': u'الْغَايِصِ', #1
u'الغباب': u'الْغُبَابُ', #1
u'الغباش': u'الْغَبّاشَ', #1
u'الغبرى': u'الْغُبَرِىُّ', #22
u'الغبريني': u'الْغُبْرِينِيَّ', #1
u'الغبريني': u'الْغُبْرِينِيُّ', #22
u'الغبريني': u'الْغُبْرِينِيِّ', #5
u'الغبشاني': u'الْغُبْشَانِيّ', #4
u'الغبط': u'الْغَبْطُ', #1
u'الغبغب': u'الْغَبْغَبِ', #2
u'الغبوق': u'الغبوق', #1
u'الغبوق': u'الْغَبُوقُ', #2
u'الغبيراء': u'الْغُبَيْرَاءَ', #1
u'الغبيراء؟': u'الْغُبَيْرَاءِ؟', #1
u'الغبيراء؟': u'الْغُبَيْرَاءُ؟', #2
u'الغبيراء': u'الْغُبَيْرَاءِ', #3
u'الغبيراء': u'الْغُبَيْرَاءُ', #7
u'الغبيط': u'الْغَبِيطُ', #2
u'الغتمة': u'الْغُتْمَةُ', #1
u'الغثامة': u'الغثامة', #1
u'الغثريانة': u'الْغِثْرَيَانَةُ', #1
u'الغثم': u'الْغُثْمِ', #1
u'الغجدواني': u'الْغَجْدَوَانِيُّ', #1
u'الغجدوانى': u'الْغُجْدَوَانِىُّ', #1
u'الغداف': u'الْغُدَافِ', #3
u'الغداف': u'الْغُدَافُ', #34
u'الغداف': u'الْغُدَافَ', #6
u'الغدانى': u'الْغُدَّانِىُّ', #1
u'الغدانى': u'الْغُدَّانِىِّ', #2
u'الغدانى': u'الْغُدَانِىُّ', #3
u'الغدوإلى': u'الْغُدُوِّإِلَى', #1
u'الغذا': u'الْغِذَا', #2
u'الغذي': u'الْغَذِيّ', #2
u'الغرابليين': u'الْغَرَابِلِيِّينَ', #1
u'الغراسين': u'الْغِرَاسَيْنِ', #1
u'الغراض': u'الْغِرَاضِ', #1
u'الغرافي': u'الْغَرَّافِيِّ', #1
u'الغرامه': u'الْغَرَامَهْ', #4
u'الغرانق': u'الْغُرَانِقَ', #1
u'الغرانق': u'الْغَرَانِقُ', #2
u'الغرانقة': u'الْغَرَانِقَة', #1
u'الغرانقة': u'الْغَرَانِقَةُ', #3
u'الغربا': u'الْغَرْبَا', #1
u'الغربى': u'الْغَرْبِىِّ', #1
u'الغرث': u'الْغَرَثِ', #1
u'الغرث': u'الْغَرْثَ', #1
u'الغرثى': u'الغرثى', #2
u'الغررا': u'الْغَرَرَا', #1
u'الغرطم': u'الغرطم', #1
u'الغرغره': u'الغَرْغَرَه', #1
u'الغرقاوي': u'الْغَرْقَاوِيَّ', #1
u'الغرقاوي': u'الْغَرْقَاوِيُّ', #1
u'الغرقد': u'الغرقد', #1
u'الغرقد': u'الغَرْقَدِ', #1
u'الغرقد': u'الْغَرْقَدُ', #1
u'الغرقد': u'الْغَرْقَد', #2
u'الغرقد': u'الْغَرْقَدَ', #2
u'الغرقد،': u'الْغَرْقَدِ،', #3
u'الغرقد': u'الْغَرْقَدِ', #56
u'الغرقدة': u'الْغَرْقَدَة', #1
u'الغرقدة': u'الْغَرْقَدَةَ', #1
u'الغرقي': u'الْغَرْقِيُّ', #1
u'الغرل': u'الغرل', #3
u'الغرلة': u'الْغُرْلَةِ', #5
u'الغرما': u'الْغُرَمَا', #4
u'الغروان': u'الْغَرَوَانِ', #1
u'الغرود': u'الْغُرُودُ', #1
u'الغرود': u'الْغُرُودِ', #2
u'الغروزة': u'الْغَرُوزَةِ', #1
u'الغروس': u'الْغُرُوسُ', #3
u'الغروس': u'الْغُرُوسَ', #4
u'الغرى': u'الغرى', #1
u'الغرياني': u'الْغِرْيَانِيِّ', #11
u'الغرياني': u'الْغِرْيَانِيُّ', #6
u'الغريف': u'الغُرَيْف', #1
u'الغريف': u'الْغَرِيفِ', #18
u'الغريف': u'الْغَرِيفُ', #3
u'الغريف،': u'الْغَرِيفِ،', #3
u'الغزاء،': u'الغُزَّاء،', #1
u'الغزاوي': u'الْغَزَّاوِيُّ', #1
u'الغزاوية': u'الْغَزَّاوِيَّةِ', #1
u'الغزائر': u'الْغَزَائِرِ', #1
u'الغزة': u'الْغَزَّةُ', #1
u'الغزر': u'الْغَزْرُ', #1
u'الغزنوي': u'الْغَزْنَوِيَّ', #1
u'الغزنوي': u'الْغَزْنَوِيِّ', #11
u'الغزنوي': u'الْغَزْنَوِيُّ', #12
u'الغزنوية': u'الْغَزْنَوِيَّة', #1
u'الغزنوية': u'الْغَزْنَوِيَّةِ', #26
u'الغزوب': u'الْغُزُوبِ', #1
u'الغزول': u'الْغُزُولُ', #1
u'الغزوين': u'الغزوين', #1
u'الغزى': u'الْغَزِىُّ', #1
u'الغزى': u'الْغُزْىُّ', #1
u'الغزى': u'الْغَزِّىُّ', #9
u'الغزية': u'الَغَزِيَّةِ', #1
u'الغس': u'الْغَسّ', #1
u'الغسانى': u'الْغَسَّانِىِّ', #6
u'الغسانى': u'الْغَسَّانِىُّ', #7
u'الغسلا': u'الْغُسْلَا', #4
u'الغسيلي،': u'الْغَسِيلِيُّ،', #1
u'الغسيلى': u'الْغَسِيلِىُّ', #1
u'الغسيلي': u'الْغَسِيلِيِّ', #2
u'الغشام': u'الْغِشَامِ', #1
u'الغشش': u'الْغَشَش', #1
u'الغشمرة': u'الْغَشْمَرَةُ', #1
u'الغشوة': u'الْغَشْوَةِ', #1
u'الغشوش': u'الْغُشُوشُ', #1
u'الغشوش': u'الْغُشُوشِ', #1
u'الغص': u'الْغَصِّ', #2
u'الغصبين': u'الْغَصْبَيْنِ', #3
u'الغصوب': u'الْغُصُوبُ', #10
u'الغصوب': u'الْغُصُوبِ', #38
u'الغصوب': u'الْغُصُوبَ', #6
u'الغصوبات': u'الْغُصُوبَاتِ', #4
u'الغضارين': u'الغَضّارِينَ', #1
u'الغضائرى': u'الْغَضَائِرِىُّ', #17
u'الغضة': u'الغضة', #1
u'الغضة': u'الْغَضَّةَ', #1
u'الغضة': u'الْغَضَّةُ', #4
u'الغضوين': u'الْغَضَوَيْن', #1
u'الغضوين': u'الْغَضْوَيْنِ', #1
u'الغضوين': u'الْغَضَوَيْنِ', #4
u'الغضيضي،': u'الْغَضِيضِيِّ،', #1
u'الغطات': u'الْغَطّات', #1
u'الغطات': u'الْغَطّاتِ', #1
u'الغطات': u'الْغَطَّاتِ', #1
u'الغطارف': u'الْغَطَارِفَ', #1
u'الغطارف': u'الْغَطَارِفُ', #3
u'الغطارف': u'الْغَطَارِفِ', #6
u'الغطريفي': u'الْغِطْرِيفِيُّ', #1
u'الغطريفي': u'الْغِطْرِيفِيِّ', #1
u'الغطريفى': u'الْغِطْرِيفِىُّ', #2
u'الغطريفي': u'الْغِطْرِيفِيَّ', #3
u'الغطريفية': u'الْغِطْرِيفِيَّةِ', #3
u'الغطريفية': u'الْغِطْرِيفِيَّةُ', #4
u'الغطفاني': u'الغَطفاني', #1
u'الغطفاني': u'الغَطَفَاني', #1
u'الغطفاني،': u'الْغَطْفَانِيُّ،', #1
u'الغطفانى': u'الْغَطَفَانِىَّ', #1
u'الغطفاني': u'الْغَطَفَانِيّ', #2
u'الغطفانى': u'الْغَطَفَانِىِّ', #2
u'الغطفاني': u'الْغَطَفَانِيِّ', #25
u'الغطفاني،': u'الْغَطَفَانِيُّ،', #3
u'الغطفاني،': u'الْغَطَفَانِيِّ،', #3
u'الغطفاني': u'الْغَطَفَانِيُّ', #33
u'الغطفاني': u'الغطفاني', #4
u'الغطفاني': u'الْغَطَفَانِيَّ', #5
u'الغطفانى': u'الْغَطَفَانِىُّ', #7
u'الغطفانية': u'الْغَطَفَانِيَّةُ', #1
u'الغطفانيون': u'الْغَطَفَانِيّونَ', #1
u'الغطفانيون': u'الْغَطَفَانِيُّونَ', #2
u'الغطفانيين': u'الْغَطَفَانِيِّينَ', #1
u'الغطمة': u'الغطمة', #1
u'الغطيفي': u'الْغُطَيْفِيِّ', #1
u'الغطيفي': u'الْغُطَيْفِيُّ', #2
u'الغفارى': u'الْغِفَارِىُّ', #22
u'الغفارى': u'الْغِفَارِىِّ', #38
u'الغفارى': u'الْغِفَارِىَّ', #5
u'الغلا': u'الْغَلَا', #3
u'الغلابي': u'الغلابيّ', #1
u'الغلابي': u'الغُلابيّ', #1
u'الغلابي،': u'الْغَلابِيُّ،', #1
u'الغلابي،': u'الْغِلابِيُّ،', #1
u'الغلابي': u'الْغَلَّابِيّ', #1
u'الغلابي': u'الْغِلَابِيُّ', #1
u'الغلابى': u'الْغِلاَبِىُّ', #1
u'الغلابي': u'الغلابي', #2
u'الغلابي': u'الْغِلابِيُّ', #2
u'الغلابي': u'الْغَلَابِيُّ', #2
u'الغلابي': u'الْغَلَّابِيَّ', #2
u'الغلابي': u'الْغَلابِيُّ', #3
u'الغلابي': u'الْغَلَّابِيُّ', #4
u'الغلابى': u'الْغَلاَّبِىُّ', #5
u'الغلابي': u'الْغَلَّابِيِّ', #6
u'الغلابى': u'الْغَلاَبِىُّ', #6
u'الغلاس': u'الْغَلاسُ', #1
u'الغلاصم': u'الْغَلَاصِمِ', #2
u'الغلت': u'الْغَلَتَ', #1
u'الغلت': u'الْغَلَتِ', #1
u'الغلث': u'الْغَلِثُ', #1
u'الغلث': u'الْغَلْثَ', #2
u'الغلث': u'الْغَلْثِ', #2
u'الغلث': u'الْغَلِثَ', #4
u'الغلث': u'الْغَلَثَ', #5
u'الغلث': u'الْغَلَثُ', #5
u'الغلث': u'الْغَلِثِ', #5
u'الغلث': u'الْغَلَثِ', #7
u'الغلث': u'الْغَلْثُ', #8
u'الغلصمة': u'الْغَلْصَمَة', #1
u'الغلصمة': u'الْغَلْصَمَةِ', #14
u'الغلصمة': u'الْغَلْصَمَةَ', #2
u'الغلصمة': u'الْغَلْصَمَةُ', #8
u'الغلوة': u'الْغَلْوَةِ', #12
u'الغلوة': u'الْغَلْوَةُ', #2
u'الغلوة': u'الْغَلْوَةَ', #3
u'الغلوج': u'الْغُلُوجُ', #1
u'الغلوطات': u'الْغُلُوطَاتِ', #5
u'الغليث': u'الْغَلِيثِ', #1
u'الغليلا': u'الْغَلِيلَا', #2
u'الغليم؟': u'الْغُلَيِّمُ؟', #1
u'الغليم؟': u'الْغُلَيْمُ؟', #1
u'الغليم': u'الْغُلَيِّمُ', #2
u'الغماد،': u'الْغِمَادِ،', #1
u'الغماد': u'الْغِمَادِ', #21
u'الغماد': u'الْغُمَادِ', #4
u'الغمراوي': u'الْغَمْرَاوِيُّ', #1
u'الغمسة': u'الْغَمْسَةِ', #1
u'الغموس': u'الْغَمُوس', #1
u'الغموس،': u'الْغَمُوسُ،', #1
u'الغموس؟': u'الْغَمُوسُ؟', #1
u'الغموس': u'الْغَمُوسُ', #147
u'الغموس': u'الْغَمُوسِ', #190
u'الغموس': u'الْغَمُوسَ', #40
u'الغموسة': u'الْغَمُوسَةِ', #1
u'الغمى': u'الْغَمّى', #1
u'الغمى': u'الْغُمّى', #3
u'الغميس': u'الْغَمِيسِ', #1
u'الغميصاء،': u'الغميصاء،', #1
u'الغميصاء': u'الْغُمَيْصَاء', #2
u'الغميصاء': u'الْغُمَيْصَاءَ', #2
u'الغميصاء': u'الْغُمَيْصَاءُ', #7
u'الغميصاء': u'الْغُمَيْصَاءِ', #9
u'الغميط': u'الْغَميْطِ', #1
u'الغميم،': u'الغَمِيم،', #1
u'الغميم': u'الْغَمِيمُ', #1
u'الغميم،': u'الْغَمِيمَ،', #1
u'الغميم،': u'الْغَمِيمِ،', #1
u'الغميم': u'الْغَمِيم', #2
u'الغميم': u'الْغَمِيمَ', #3
u'الغميم': u'الْغَمِيمِ', #37
u'الغنامي': u'الْغَنَّامِيِّ', #1
u'الغنثر': u'الغنثر', #2
u'الغنوى': u'الْغَنَوِىُّ', #10
u'الغنوى': u'الْغَنَوِىَّ', #2
u'الغنوى': u'الْغَنَوِىِّ', #7
u'الغنيمه': u'الْغَنِيمَهْ', #1
u'الغنيمي': u'الْغُنَيْمِيَّ', #1
u'الغنيمي': u'الْغُنَيْمِيُّ', #14
u'الغنيمي': u'الْغُنَيْمِيِّ', #5
u'الغنىوروي': u'الْغِنَىوَرُوِيَ', #1
u'الغوراء': u'الْغَوْرَاءِ', #20
u'الغوراء': u'الْغَوْرَاءَ', #4
u'الغوراء': u'الْغَوْرَاءُ', #5
u'الغورة': u'الْغَوْرَةِ', #1
u'الغورة': u'الْغَوْرَةَ', #2
u'الغورجي': u'الْغُورَجِيُّ', #1
u'الغوصة': u'الْغَوْصَةِ', #1
u'الغوطة،': u'الْغُوطَةِ،', #1
u'الغوطة': u'الْغَوْطَةِ', #4
u'الغوطة': u'الْغُوطَةُ', #5
u'الغوطة': u'الْغُوطَةِ', #9
u'الغوير': u'الْغُوَيْرِ', #1
u'الغوير': u'الْغُوَيْرُ', #13
u'الغوير': u'الْغُوَيْرَ', #2
u'الغويص': u'الْغَوِيصُ', #1
u'الغويصات': u'الْغَوِيصَاتِ', #1
u'الغيات': u'الْغَيّاتِ', #1
u'الغيات': u'الْغِيّاتِ', #1
u'الغياطل': u'الْغَيَاطِل', #1
u'الغياطل': u'الْغَيَاطِلُ', #1
u'الغياطل': u'الْغَيَاطِلِ', #3
u'الغيال': u'الْغِيَال', #1
u'الغيال': u'الْغِيَالِ', #1
u'الغيال،': u'الْغِيَالِ،', #1
u'الغياني': u'الْغِيَانِيِّ', #1
u'الغياياء': u'الغياياء', #1
u'الغيايتان': u'الغيايتان', #1
u'الغيداق': u'الْغَيْدَاقَ', #1
u'الغيداق': u'الْغَيْدَاقِ', #2
u'الغيداق': u'الْغَيْدَاقُ', #3
u'الغيراء': u'الْغَيْرَاءُ', #1
u'الغيطان': u'الْغِيطَانِ', #2
u'الغيطلة': u'الْغَيْطَلَةَ', #1
u'الغيطلة': u'الْغَيْطَلَةِ', #4
u'الغيطلة': u'الْغَيْطَلَةُ', #6
u'الغيل،': u'الْغَيْلُ،', #1
u'الغيل': u'الْغِيلُ', #2
u'الغيل': u'الْغَيْلُ', #3
u'الغيل': u'الْغَيْل', #4
u'الغيل': u'الْغَيْلَ', #6
u'الغيل': u'الْغَيْلِ', #6
u'الغيل': u'الْغِيلِ', #8
u'الغيلاني': u'الْغَيْلانِيُّ', #1
u'الغيلاني': u'الْغَيْلَانِيُّ', #1
u'الغيلانى': u'الْغَيْلاَنِىُّ', #8
u'الغيلانيات': u'الْغَيْلانِيَّاتِ', #1
u'الغيلانيات': u'الْغَيْلَانِيَّاتِ', #7
u'الغينمي': u'الْغَيْنَمِيُّ', #1
u'ألف': u'أَلْفً', #1
u'الف': u'الف', #1
u'الف': u'الْف', #1
u'الف': u'الْفٍ', #1
u'الفا': u'الفاً', #1
u'الفا': u'الْفاَ', #1
u'الفا': u'الْفَا', #2
u'إلفاء': u'إلْفَاءٍ', #1
u'إلفاء': u'إلْفَاءِ', #2
u'الفاتخة': u'الْفَاتِخَةَ', #1
u'إلفاتها': u'إِلْفَاتهَا', #1
u'الفاثور': u'الْفَاثُور', #1
u'الفاثور': u'الْفَاثُورُ', #1
u'الفاجة': u'الْفَاجَّةُ', #1
u'الفاجة': u'الْفَاجَّةِ', #1
u'الفاجة': u'الْفَاجّةَ', #3
u'الفاخت': u'الْفَاخِتِ', #1
u'الفاختة': u'الْفَاخِتَةِ', #3
u'الفاختي': u'الْفَاخَّتِي', #1
u'الفاختي': u'الْفَاخِتِيُّ', #2
u'الفاختي': u'الْفَاخِتِيِّ', #2
u'الفاخرانيين': u'الْفاخَرانِيّينَ', #1
u'الفاخره': u'الْفَاخِرَهْ', #2
u'الفاخور': u'الْفَاخُورِ', #1
u'الفادر': u'الْفَادِرُ', #1
u'الفاذ': u'الْفَاذَّ', #1
u'الفارابي': u'الْفَارَابِيِّ', #10
u'الفارابي': u'الْفَارَابِيُّ', #19
u'الفارسى': u'الْفَارِسِىُّ', #167
u'الفارسى': u'الْفَارِسِىِّ', #18
u'الفارسى': u'الْفَارِسِىَّ', #2
u'الفارضية': u'الْفَارِضِيَّةِ', #1
u'الفارضينا': u'الْفَارِضِينَا', #1
u'الفارقي': u'الفَارِقِيِّ', #1
u'الفارقي': u'الْفَارِقِيُّ', #148
u'الفارقي': u'الْفَارِقِيّ', #3
u'الفارقي': u'الْفَارِقِيِّ', #55
u'الفارقي': u'الْفَارِقِيَّ', #7
u'الفاروني': u'الْفَارُونِيُّ', #1
u'الفارياب،': u'الْفَارِيَابَ،', #1
u'الفاريابى': u'الْفَارْيَابِىُّ', #10
u'الفاريابى': u'الْفَارَيَابِىُّ', #13
u'الفاريابى': u'الْفَارِيَابِىُّ', #3
u'الفازازي': u'الْفَازَازِيَّ', #1
u'الفاس': u'الْفَاسَ', #2
u'الفاس': u'الْفَاسُ', #2
u'الفاس': u'الْفَاسِ', #3
u'الفاسده': u'الْفَاسِدَهْ', #1
u'الفاسقية': u'الْفَاسِقِيَّةَ', #1
u'الفاضلية': u'الْفَاضِلِيَّةِ', #1
u'ألفاظ': u'أَلْفَاظً', #1
u'الفاغية': u'الْفَاغِيَةَ', #1
u'الفاغية،': u'الْفَاغِيَةُ،', #1
u'الفاغية': u'الْفَاغِيَةُ', #11
u'الفأفاء': u'الْفَأْفَاءُ', #3
u'الفأفاء': u'الْفَأْفَاءِ', #9
u'الفأفأة': u'الْفَأْفَأَةِ', #3
u'الفاقئ': u'الْفَاقِئَ', #17
u'الفاقئ': u'الْفَاقِئُ', #21
u'الفاقئ': u'الْفَاقِئِ', #69
u'الفاكهى': u'الْفَاكِهِىَّ', #1
u'الفاكهى': u'الْفَاكِهِىُّ', #43
u'الفالوجي': u'الْفَالُوجِيِّ', #4
u'الفاليري': u'الْفَالَيْرِيُّ', #1
u'الفاليز': u'الفاليز', #4
u'الفاليزي': u'الْفَالِيزِيُّ', #1
u'الفاليزى': u'الفاليزى', #1
u'الفالين': u'الْفَالِينَ', #1
u'الفامى': u'الْفْامِىُّ', #1
u'الفامي': u'الْفَامِيِّ', #11
u'الفامي': u'الفامي', #2
u'الفامي': u'الْفَامِيَّ', #3
u'الفامى': u'الْفَامِىُّ', #49
u'الفامى': u'الْفَامِى', #6
u'الفامي': u'الْفَامِيُّ', #9
u'الفاميون': u'الْفَامِيُّونَ', #1
u'الفانيد': u'الفانيد', #1
u'الفانيد': u'الْفَانِيدَ', #4
u'الفانيد': u'الْفَانِيدُ', #6
u'الفانيد': u'الْفَانِيدِ', #8
u'الفانيذ': u'الفانيذ', #1
u'الفانيذ': u'الْفَانِيذَ', #1
u'الفانيذ': u'الْفَانِيذُ', #1
u'الفانيذ': u'الْفَانِيذِ', #3
u'الفانيذي': u'الْفَانِيذِيُّ', #1
u'الفاواذق': u'الفاواذق', #6
u'ألفاوالوجه': u'أَلْفًاوَالْوَجْهُ', #1
u'ألفاوروي': u'أَلْفًاوَرُوِي', #1
u'الفاوي': u'الْفَاوِيّ', #4
u'الفاوية': u'الْفَاوِيّةِ', #1
u'الفائته': u'الْفَائِتَهْ', #1
u'الفائد': u'الْفَائِدَ', #1
u'الفائد': u'الْفَائِدُ', #2
u'الفائشي': u'الفائشي', #1
u'الفائشى': u'الْفَائِشِىِّ', #1
u'الفائشي': u'الْفَائِشِيِّ', #2
u'الفائل': u'الْفَائِلِ', #1
u'الفائل': u'الْفَائِلُ', #4
u'الفائنة': u'الْفَائِنَةَ', #1
u'الفائنة': u'الْفَائِنَةِ', #1
u'الفتال': u'الْفَتَّالِ', #17
u'الفتال': u'الْفَتَّالُ', #5
u'الفتايا': u'الْفَتَايَا', #1
u'الفتخ': u'الْفَتَخ', #1
u'الفتخ': u'الْفَتَخِ', #1
u'الفتخ': u'الْفَتْخ', #1
u'الفتخ': u'الْفَتْخِ', #1
u'الفتخ،': u'الْفَتَخُ،', #1
u'الفتخ': u'الفتخ', #2
u'الفتخ': u'الْفَتَخُ', #2
u'الفتخ': u'الْفَتَخَ', #5
u'الفتخات': u'الْفَتَخَاتِ', #1
u'الفتخة': u'الفتخة', #2
u'الفتوج': u'الْفُتُوجُ', #1
u'الفتوحي': u'الْفَتُوحِيُّ', #15
u'الفتوحي': u'الْفَتُوحِيِّ', #3
u'الفتيا': u'الفتيا', #1
u'الفتيا،': u'الْفُتْيَا،', #1
u'الفتيا؟': u'الْفُتْيَا؟', #1
u'الفتيا': u'الْفُتْيَا', #437
u'الفتياني،': u'الْفِتْيَانِيِّ،', #1
u'الفجاء': u'الْفَجَّاءِ', #1
u'الفجاء': u'الْفِجَاءُ', #2
u'الفجدواني': u'الْفَجْدَوَانِيِّ', #1
u'الفجران': u'الْفَجْرَانِ', #2
u'الفجرين': u'الْفَجْرَيْنِ', #13
u'الفجورة': u'الْفُجُورَةَ', #1
u'الفجيع': u'الفجيع', #2
u'الفجيع': u'الْفُجَيْعِ', #3
u'الفحال': u'الْفِحَالِ', #4
u'الفحال': u'الْفُحَّالِ', #5
u'الفحج': u'الْفَحَجُ', #1
u'الفحشا': u'الْفَحْشَا', #3
u'الفخام': u'الْفِخَامِ', #2
u'الفخيمة': u'الْفَخِيمَةَ', #1
u'الفخيمة': u'الْفَخِيمَةِ', #2
u'الفدا': u'الْفِدَا', #4
u'الفداد': u'الْفَدَّادُ', #1
u'الفداد': u'الْفِدَادُ', #1
u'الفداد': u'الفداد', #5
u'الفدادون': u'الْفَدَّادُونَ', #2
u'الفدادون': u'الفدادون', #5
u'الفدافد': u'الْفَدَافِدِ', #1
u'الفدر': u'الفدر', #1
u'الفدر': u'الْفَدَرَ', #1
u'الفدر': u'الْفِدَرَ', #5
u'الفدرة': u'الفدرة', #1
u'الفدفد': u'الفدفد', #1
u'الفدفد': u'الْفَدْفَدُ', #2
u'الفدكي': u'الْفَدَكِيِّ', #1
u'الفدكي،': u'الْفَدَكِيُّ،', #1
u'الفدكى': u'الْفَدَكِىِّ', #1
u'الفديد': u'الْفَدِيدِ', #1
u'الفديك': u'الْفُدَيْكِ', #2
u'الفرا': u'الْفُرَا', #2
u'الفرا': u'الْفَرَا', #5
u'الفرا': u'الْفِرَا', #5
u'الفراة': u'الْفُرَاةِ', #1
u'الفراديسي': u'الْفَرَادِيسِيُّ', #2
u'الفراديسي،': u'الْفَرَادِيسِيُّ،', #2
u'الفرارة': u'الْفَرَّارَةَ', #1
u'الفرارون': u'الْفَرَّارُونَ', #10
u'الفرارون': u'الْفَرّارُونَ', #3
u'الفرازنة': u'الفرازنة', #1
u'الفرازنة': u'الْفَرَازِنَةِ', #1
u'الفراسى': u'الْفِرَاسِىَّ', #2
u'الفراسى': u'الْفِرَاسِىِّ', #3
u'الفرافر': u'الْفَرَافِرُ', #1
u'الفرافر': u'الْفُرَافِرَ', #1
u'الفرافر': u'الْفُرَافِرُ', #1
u'الفرافر': u'الْفُرَافِرِ', #2
u'الفرافصة،': u'الفرافصة،', #1
u'الفرافصة': u'الفَرافصة', #1
u'الفرافصة': u'الْفَرَافِصَةَ', #1
u'الفرافصة': u'الْفَرَافِصَةِ', #5
u'الفرافصة': u'الْفُرَافِصَةِ', #5
u'الفرافصة': u'الْفُرَافِصَةَ', #7
u'الفرافصة': u'الْفُرَافِصَةُ', #7
u'الفرانق': u'الْفُرَانِقَ', #2
u'الفرانق': u'الْفُرَانِقُ', #4
u'الفرانين': u'الْفَرَّانِينَ', #3
u'الفراهيد': u'الْفَرَاهِيدِ', #1
u'الفراهيدي': u'الْفَرَاهِيدِيُّ', #1
u'الفراوى': u'الْفُرَاوِىِّ', #1
u'الفراوي': u'الْفَرَاوِيِّ', #11
u'الفراوي': u'الْفَرَاوِيّ', #4
u'الفراوى': u'الْفَرَاوِىُّ', #4
u'الفراوي': u'الْفَرَاوِيُّ', #9
u'الفرائضقوله': u'الْفَرَائِضِقَوْلُهُ', #1
u'الفرائضوالوجه': u'الْفَرَائِضِوَالْوَجْهُ', #1
u'الفرائضي،': u'الْفَرَائِضِيُّ،', #1
u'الفرائضي،': u'الْفَرَائِضِيِّ،', #2
u'الفرائضي': u'الْفَرَائِضِيِّ', #4
u'الفرائضى': u'الْفَرَائِضِىُّ', #4
u'الفرائضي': u'الْفَرَائِضِيُّ', #7
u'الفرائع': u'الْفَرَائِعُ', #2
u'الفربري،': u'الْفَرَبْرِيُّ،', #1
u'الفربرى': u'الْفِرَبْرِىُّ', #1
u'الفربري': u'الْفَرَبْرِيُّ', #10
u'الفرجات': u'الْفُرُجَات', #1
u'الفرجات': u'الْفُرُجَاتِ', #4
u'الفرجالوجه': u'الْفَرْجِالْوَجْهُ', #1
u'الفرجى': u'الْفَرَجِىِّ', #1
u'الفردا': u'الْفَرْدَا', #1
u'الفرديسي،': u'الْفَرْدِيسِيُّ،', #1
u'الفرسا': u'الْفَرَسَا', #2
u'الفرسك': u'الْفِرْسِكَ', #3
u'الفرسك': u'الْفِرْسِكِ', #4
u'الفرسن': u'الْفِرْسِنَ', #1
u'الفرسن': u'الْفِرْسِنِ', #1
u'الفرسن': u'الفرسن', #2
u'الفرسن': u'الْفِرْسِنُ', #3
u'الفرصاد': u'الْفِرْصَادُ', #10
u'الفرصاد': u'الْفِرْصَادَ', #3
u'الفرصاد': u'الْفِرْصَادِ', #38
u'الفرصد': u'الْفِرْصِدُ', #2
u'الفرصيد': u'الْفِرْصِيدُ', #1
u'الفرطات': u'الْفُرُطَاتِ', #2
u'الفرعاني': u'الْفِرْعَانِيُّ', #1
u'الفرعل': u'الْفُرْعُلُ', #7
u'الفرعيون': u'الْفَرْعِيُّونَ', #1
u'الفرغاني': u'الْفَرْغَانِيِّ', #1
u'الفرغاني،': u'الْفَرْغَانِيِّ،', #1
u'الفرغانى': u'الْفَرْغَانِىُّ', #1
u'الفرغاني،': u'الْفَرْغَانِيُّ،', #2
u'الفرغاني': u'الْفَرْغَانِيُّ', #4
u'الفرغانية': u'الْفَرْغَانِيَّةُ', #3
u'الفرفة': u'الْفُرْفَةِ', #1
u'الفرفحين': u'الفرفحين', #2
u'الفرفصة': u'الفَرَفِصَة', #1
u'الفرقانا': u'الْفُرْقَانَا', #1
u'الفرقبي': u'الْفُرْقُبِيِّ', #1
u'الفرقبية': u'الفرقبية', #1
u'الفرقه': u'الْفُرْقَهْ', #2
u'الفركاح': u'الْفِرْكَاحُ', #1
u'الفركاح': u'الْفِرْكَاحِ', #49
u'الفرما': u'الفَرَما', #3
u'الفرما': u'الْفَرْمَا', #4
u'الفرما': u'الْفَرَمَا', #5
u'الفرمان': u'الْفَرَمَانَ', #1
u'الفرمان': u'الْفَرَمَانِ', #2
u'الفرنساوي': u'الْفَرَنْسَاوِيِّ', #2
u'الفرنساوية': u'الفرنساوية', #3
u'الفرنقاني': u'الْفُرُنْقَانِيِّ', #1
u'الفرهاذاني،': u'الْفَرْهَاذَانِيُّ،', #1
u'الفروجة': u'الْفَرُّوجَةِ', #1
u'الفروزاد': u'الْفَرْوَزَادِ', #1
u'الفروسة': u'الْفُرُوسَةَ', #1
u'الفروسة': u'الْفُرُوسَةِ', #1
u'الفروعي': u'الْفُرُوعِي', #1
u'الفروعي': u'الْفُرُوعِيِّ', #1
u'الفروعية': u'الْفُرُوعِيَّةُ', #4
u'الفروعية': u'الْفُرُوعِيَّةِ', #7
u'الفروغ': u'الْفُرُوغُ', #1
u'الفروك': u'الْفَرُوكُ', #1
u'الفروى': u'الْفَرَوِىِّ', #1
u'الفروى': u'الْفَرْوِىُّ', #16
u'الفروى': u'الْفَرْوِىِّ', #2
u'الفروى': u'الْفَرَوِىُّ', #4
u'الفريابي،': u'الفريابي،', #12
u'الفريابى': u'الْفِرْيَابِىُّ', #121
u'الفريابي': u'الْفِرْيَابِيُّ', #156
u'الفريابي،': u'الْفِرْيَابيُّ،', #2
u'الفريابي،': u'الْفِرْيَابِيَّ،', #2
u'الفريابي،': u'الْفِرْيَابِيُّ،', #201
u'الفريابي': u'الْفِرْيَابِيِّ', #23
u'الفريابى': u'الْفِرْيَابِىِّ', #25
u'الفريابي،': u'الْفِرْيَابِيِّ،', #28
u'الفريابي': u'الْفِرْيَابِيّ', #3
u'الفريابي': u'الْفِرْيَابِيَّ', #3
u'الفريابى': u'الْفَرْيَابِىُّ', #3
u'الفريابى': u'الْفِرَيَابِىُّ', #3
u'الفريابي': u'الفريابي', #7
u'الفرياني،': u'الْفِرْيَانِيُّ،', #1
u'الفريعة': u'الفريعة', #1
u'الفريعة': u'الْفُرَيْعَةِ', #10
u'الفريعة': u'الْفُرَيْعَة', #2
u'الفريعة': u'الْفُرَيْعَةَ', #6
u'الفريعة': u'الْفُرَيْعَةُ', #7
u'الفريقة': u'الْفَرِيقَةِ', #1
u'الفزار': u'الْفَزَّار', #1
u'الفزارة': u'الفَزَارَةِ', #1
u'الفزاري': u'الفَزَاري', #1
u'الفزاري،': u'الفَزَاري،', #1
u'الفزاري': u'الفَزَارِيّ', #1
u'الفزارى': u'الْفَزَارِىَّ', #14
u'الفزاري': u'الْفَزَارِيّ', #158
u'الفزاري': u'الْفَزَارِيَّ', #19
u'الفزاري': u'الفزاري', #2
u'الفزاري،': u'الْفَزَارِيِّ،', #26
u'الفزارى': u'الْفَزَارِىِّ', #33
u'الفزاري،': u'الْفَزَارِيَّ،', #6
u'الفزاري': u'الْفَزَارِيِّ', #63
u'الفزاري': u'الْفَزَارِيُّ', #65
u'الفزاري،': u'الفزاري،', #7
u'الفزارى': u'الْفَزَارِىُّ', #83
u'الفزاري،': u'الْفَزَارِيُّ،', #99
u'الفزارية': u'الْفَزَارِيَّةُ', #1
u'الفزازنة': u'الْفَزَازِنَةِ', #2
u'الفزازي،': u'الْفَزَازِيُّ،', #1
u'الفزازى': u'الْفَزَازِىُّ', #1
u'الفزاوي،': u'الْفَزَاوِيَّ،', #1
u'الفزز': u'الْفِزْزِ', #1
u'الفساطيطي': u'الْفَسَاطِيطِيُّ', #1
u'الفساقير': u'الْفَسَاقِيرِ', #1
u'الفسطاس': u'الْفَسْطَاسِ', #1
u'الفسفس': u'الْفُسْفُسُ', #3
u'الفسقاء': u'الْفُسَقَاءَ', #1
u'الفسقار': u'الْفِسْقَارِ', #1
u'الفسقين': u'الْفِسْقَيْنِ', #1
u'الفسكل': u'الْفُسْكُلُ', #1
u'الفسكل': u'الْفِسْكِلِ', #4
u'الفسكل': u'الْفِسْكِلُ', #7
u'الفسلا': u'الْفَسْلَا', #1
u'الفسوة': u'الْفَسْوَةَ', #1
u'الفسوة': u'الْفَسْوَةِ', #1
u'الفسوخ': u'الْفُسُوخ', #1
u'الفسوخ': u'الْفُسُوخَ', #11
u'الفسوخ': u'الْفُسُوخُ', #22
u'الفسوخ': u'الْفُسُوخِ', #93
u'الفسوري': u'الفسوري', #1
u'الفسوي': u'الفسوي', #1
u'الفسوي،': u'الفَسَوِيّ،', #1
u'الفسوي،': u'الْفِسَوِيُّ،', #1
u'الفسوي': u'الْفَسَوِيُّ', #17
u'الفسوي': u'الْفَسَوِيّ', #2
u'الفسوي': u'الْفَسَوِيِّ', #2
u'الفسوي،': u'الْفَسَوِيُّ،', #4
u'الفسوى': u'الْفَسَوِىُّ', #54
u'الفسيخ': u'الْفَسِيخَ', #1
u'الفسيل': u'الْفَسِيلِ', #2
u'الفسيل': u'الْفَسِيلُ', #5
u'الفسيل': u'الْفَسِيلَ', #6
u'الفسيلات': u'الْفَسِيلاَت', #1
u'الفسيلات': u'الْفَسِيلاَتِ', #2
u'الفشاتيل': u'الْفَشَاتِيلِ', #1
u'الفشج': u'الْفَشْج', #1
u'الفشني': u'الْفَشْنِيِّ', #1
u'الفشني': u'الْفَشْنِيُّ', #2
u'الفصا': u'الْفَصَا', #1
u'الفصادة': u'الْفِصَادَةُ', #1
u'الفصادة': u'الْفِصَادَةِ', #4
u'الفصادة': u'الْفَصَادَةُ', #5
u'الفصادة': u'الْفَصَادَةِ', #7
u'الفصام': u'الْفِصَامَ', #1
u'الفصولية': u'الفصولية', #1
u'الفصولين': u'الْفُصُولَيْنِ', #2133
u'الفضا': u'الْفَضَا', #1
u'الفضاة': u'الْفَضَاةُ', #1
u'الفضاض': u'الْفِضَاضِ', #1
u'الفضتين': u'الْفِضَّتَيْنِ', #12
u'الفضخ': u'الْفَضْخِ', #3
u'الفضع': u'الْفَضَعْ', #1
u'الفضلا': u'الفُضَلا', #1
u'الفضلا': u'الْفُضَلَا', #1
u'الفضوح': u'الْفَضُوحِ', #1
u'الفضوح': u'الْفَضُوحُ', #3
u'الفضوخ': u'الْفَضُوخُ', #1
u'الفضولا': u'الْفُضُولَا', #1
u'الفضيح': u'الْفَضِيحُ', #1
u'الفضيخ،': u'الْفَضِيخَ،', #1
u'الفضيخ': u'الْفَضِيخُ', #11
u'الفضيخ': u'الْفَضِيخِ', #11
u'الفضيخ': u'الْفَضِيخ', #2
u'الفضيخ،': u'الْفَضِيخُ،', #3
u'الفضيخ': u'الفضيخ', #5
u'الفضيخ': u'الْفَضِيخَ', #7
u'الفضيلي': u'الْفُضَيْلِيِّ', #2
u'الفضيلي': u'الْفُضَيْلِيُّ', #3
u'الفضيلية': u'الْفَضِيلِيَّةُ', #1
u'الفطرقبل': u'الْفِطْرِقَبْلَ', #1
u'الفطروقال': u'الْفِطْرٌٌٌٌٌٌٌٌِوَقَالَ', #1
u'الفطيون': u'الفِطْيَوْن', #1
u'الفطيون،': u'الْفِطْيَوْنِ،', #1
u'الفطيون': u'الْفِطْيُونِ', #2
u'الفطيون': u'الْفِطْيَوْنِ', #2
u'الفطيوني': u'الْفَطْيُونِيّ', #2
u'الفطيوني': u'الْفِطْيَوْنِيّ', #2
u'الفعلاء': u'الْفُعَلَاءِ', #1
u'الفعلى': u'الْفَعَلَى', #2
u'الفعلى': u'الْفُعْلَى', #2
u'الفعول': u'الْفُعُولُ', #1
u'الفعول': u'الْفَعُولُ', #2
u'الفعول': u'الْفَعُولِ', #2
u'الفعول': u'الْفُعُولِ', #4
u'الفعيل': u'الْفَعِيلَ', #1
u'الفعيل': u'الْفَعِيلُ', #1
u'الفعيل': u'الْفَعِيلِ', #3
u'الفعيلة': u'الْفَعِيلَةِ', #5
u'الفغا': u'الْفَغَا', #5
u'الفغواء': u'الْفَغْوَاءِ', #4
u'الفقء': u'الْفَقْءِ', #10
u'الفقء': u'الْفَقْءَ', #2
u'الفقء': u'الْفَقْءُ', #4
u'الفقاح': u'الْفُقّاحِ', #1
u'الفقاح': u'الْفِقَاحُ', #1
u'الفقة': u'الفقة', #1
u'الفقعسي': u'الفقعسي', #1
u'الفقهين': u'الْفِقْهَيْنِ', #1
u'الفقيدا': u'الْفَقِيدَا', #2
u'الفقيرا': u'الْفَقِيرَا', #1
u'الفقيمي': u'الفقيمي', #1
u'الفقيمي،': u'الفقيمي،', #2
u'الفقيمي،': u'الْفُقَيْمِيِّ،', #3
u'الفقيمى': u'الْفُقَيْمِىِّ', #4
u'الفقيمي': u'الْفُقَيْمِيُّ', #5
u'الفقيمي': u'الْفُقَيْمِيِّ', #5
u'الفقيمي،': u'الْفُقَيْمِيُّ،', #5
u'الفقيمى': u'الْفُقَيْمِىُّ', #5
u'الفكون': u'الْفَكُّونُ', #1
u'الفلاتج': u'الْفَلَاتِجَ', #2
u'الفلاس،': u'الفلاس،', #1
u'الفلاس': u'الفلّاس', #1
u'الفلاس': u'الْفَلاسُ', #11
u'الفلاس،': u'الْفَلاسُ،', #11
u'الفلاس': u'الْفَلَّاسُ', #16
u'الفلاس': u'الفلاس', #2
u'الفلاس': u'الفلَّاس', #2
u'الفلاس': u'الْفَلاسِ', #2
u'الفلاس': u'الْفَلَّاسِ', #2
u'الفلاس': u'الْفَلاَّسُ', #2
u'الفلاس،': u'الْفَلاسِ،', #5
u'الفلاليس': u'الْفَلَالِيسِ', #1
u'الفلانى': u'الفلانى', #1
u'الفلنة': u'الْفَلْنَةِ', #1
u'الفلو': u'الفلو', #2
u'الفلو': u'الْفَلُوَّ', #2
u'الفلو': u'الْفُلُوِّ', #2
u'الفلو': u'الْفِلْوِ', #2
u'الفلو': u'الْفَلُوّ', #3
u'الفلو': u'الْفِلْوَ', #3
u'الفلو': u'الْفَلُوِّ', #6
u'الفلو': u'الْفُلُوُّ', #6
u'الفلو': u'الْفَلُوُّ', #9
u'الفليح': u'الْفُلَيْحِ', #1
u'الفنا': u'الْفَنَا', #7
u'الفنبكين': u'الْفَنْبَكَيْنِ', #1
u'الفنتان': u'الْفَنَّتَانِ', #1
u'الفنجانات': u'الْفِنْجَانَاتُ', #1
u'الفنجانات': u'الْفِنْجَانَاتِ', #1
u'الفنجانة': u'الْفِنْجَانَةَ', #1
u'الفنجانة': u'الْفِنْجَانَةِ', #1
u'الفندقلي': u'الْفُنْدُقْلِيَّ', #1
u'الفندقلي': u'الْفُنْدُقْلِيُّ', #1
u'الفندقلي': u'الْفُنْدُقْلِيِّ', #1
u'الفنري': u'الْفَنَرِيُّ', #1
u'الفنري': u'الْفَنَرِيِّ', #1
u'الفنليات': u'الفنليات', #1
u'الفنيني': u'الْفَنِّينِيَّ', #1
u'الفهادة': u'الْفَهَادَةَ', #1
u'الفهادة': u'الْفَهَّادَةِ', #1
u'الفهر': u'الْفِهْر', #1
u'الفهر': u'الْفِهْرَ', #1
u'الفهر': u'الْفِهْرِ', #5
u'الفهري': u'الفهرِي', #1
u'الفهري': u'الفِهري', #1
u'الفهري': u'الفِهْرِي', #1
u'الفهري،': u'الفِهْرِيّ،', #1
u'الفهري': u'الْفِهَرِيِّ', #1
u'الفهري': u'الْفِهْرَيَّ', #1
u'الفهري': u'الْفِهْرِيَّ', #1
u'الفهري': u'الفهري', #10
u'الفهرى': u'الْفِهْرِىُّ', #14
u'الفهرى': u'الْفِهْرِىَّ', #2
u'الفهري': u'الْفِهْرِيِّ', #20
u'الفهري': u'الْفِهْرِيّ', #27
u'الفهري': u'الفِهْري', #3
u'الفهري،': u'الفِهْري،', #3
u'الفهري،': u'الفِهْريّ،', #3
u'الفهري': u'الفِهْرِيّ', #3
u'الفهري': u'الْفِهْرِي', #3
u'الفهري،': u'الْفِهْرِيَّ،', #3
u'الفهري،': u'الْفِهْرِيِّ،', #3
u'الفهري،': u'الْفِهْرِيُّ،', #30
u'الفهري': u'الْفِهْرِيُّ', #34
u'الفهري': u'الفِهْريّ', #5
u'الفهرى': u'الْفِهْرِىِّ', #5
u'الفهرية': u'الفهرية', #1
u'الفهرية': u'الفِهْريّة', #1
u'الفهرية': u'الْفِهْرِيَّةَ', #1
u'الفهرية': u'الْفِهْرِيَّةِ', #1
u'الفهق': u'الْفَهَقِ', #1
u'الفهق': u'الْفَهْقِ', #2
u'الفهموالوجه': u'الْفَهْمُوَالْوَجْهُ', #1
u'الفهوم': u'الْفُهُومِ', #6
u'الفؤا': u'الْفُؤَا', #1
u'الفواتا': u'الْفَوَاتَا', #1
u'الفواخت': u'الْفَوَاخِتُ', #1
u'الفواخت': u'الْفَوَاخِتَ', #3
u'الفواخت': u'الْفَوَاخِتِ', #9
u'الفواشى': u'الفواشى', #1
u'الفواطم': u'الْفَوَاطِم', #1
u'الفواطم': u'الْفَوَاطِمِ', #17
u'الفوائت': u'الْفَوَائِتُ', #130
u'الفوائت': u'الْفَوَائِتِ', #473
u'الفوائت': u'الْفَوَائِتَ', #54
u'الفوائج': u'الْفَوَائِجِ', #2
u'الفوائح': u'الْفَوَائِحِ', #2
u'الفوائظ': u'الْفَوَائِظِ', #1
u'الفوتنج': u'الفوتنج', #2
u'الفورجي': u'الْفُورَّجِيُّ', #1
u'الفوزة': u'الْفَوْزَةِ', #1
u'الفوض': u'الْفَوْضِ', #3
u'الفوفلة': u'الفوفلة', #1
u'الفوقى': u'الْفَوقَى', #2
u'الفولة': u'الفولة', #1
u'الفولة': u'الْفُولَةِ', #4
u'الفوندج': u'الفوندج', #1
u'الفويرة': u'الْفُوَيْرَةَ', #1
u'الفويسق': u'الْفُوَيْسِق', #2
u'الفويسق': u'الْفُوَيْسِقُ', #4
u'الفويسقة': u'الْفُوَيْسِقَةِ', #1
u'الفويسقة،': u'الْفُوَيْسِقَةَ،', #1
u'الفويسقة،': u'الْفُوَيْسِقَةُ،', #1
u'الفويسقة': u'الْفُوَيْسِقَة', #2
u'الفويسقة': u'الْفُوَيْسِقَةَ', #25
u'الفويسقة': u'الْفُوَيْسِقَةُ', #7
u'الفىء': u'الْفَىْءُ', #16
u'الفئ': u'الْفَئُ', #2
u'الفىء': u'الفىء', #3
u'الفىء': u'الْفَىْءِ', #46
u'الفىء': u'الْفَىْءَ', #6
u'الفئام': u'الْفِئَام', #1
u'الفئام': u'الْفِئَامُ', #1
u'الفئام': u'الفئام', #2
u'الفئام': u'الْفِئَامَ', #2
u'الفئام': u'الْفِئَامِ', #4
u'الفياح': u'الْفَيَّاحُ', #1
u'الفيت': u'الْفَيْتُ', #1
u'الفيت': u'الْفَيْتِ', #1
u'ألفيتمونى': u'أَلْفَيْتُمُونِى', #1
u'الفيج': u'الْفَيْجَ', #1
u'الفيج': u'الْفَيْجُ', #4
u'الفيد': u'الْفَيْدِ', #1
u'الفيدي': u'الْفَيْدِيُّ', #1
u'الفيدي،': u'الْفَيْدِيُّ،', #2
u'الفيران': u'الْفِيرَانُ', #2
u'الفيرزان': u'الفيْرُزان', #1
u'الفيرزان': u'الفّيْرُزان', #1
u'الفيرزان،': u'الفَيْرُزان،', #1
u'الفيروزآبادي': u'الْفَيْرُوزْآبادِي', #1
u'الفيروزآباذي،': u'الفيروزآباذي،', #1
u'الفيروزج': u'الْفَيْرُوزَجَ', #2
u'الفيروزج': u'الْفَيْرُوزَجُ', #3
u'الفيروزج': u'الْفَيْرُوزَجِ', #6
u'الفيشاوي': u'الْفِيشَاوِيُّ', #2
u'الفيشة': u'الْفَيْشَةَ', #3
u'الفيشلة': u'الْفَيْشَلَةُ', #2
u'الفيصولة': u'الْفَيْصُولَةُ', #1
u'الفيعاء': u'الْفَيْعَاءِ', #1
u'الفيف': u'الْفَيْفُ', #3
u'الفيفا': u'الْفَيْفَا', #3
u'الفيل12382id': u'الفيل12382id', #1
u'الفيلج': u'الْفَيْلَجُ', #1
u'الفيلج': u'الْفَيْلَجِ', #1
u'الفين': u'الفين', #1
u'الفيول': u'الْفُيُولِ', #1
u'الفيوم': u'الْفَيُّومِ', #9
u'الفيومي': u'الْفَيُّومِيُّ', #2
u'الفيئ': u'الفيئ', #1
u'الفيئ': u'الْفَيْئُ', #1
u'القاآني': u'الْقَاآنِيِّ', #1
u'القاآني': u'الْقَاآنِيُّ', #5
u'القاآني': u'الْقَاآنِي', #7
u'القابسي': u'الْقَابِسِيُّ', #125
u'القابسي': u'الْقَابِسِيّ', #4
u'القابسي': u'الْقَابِسِيَّ', #7
u'القابسي': u'الْقَابِسِيِّ', #85
u'القابوسي': u'الْقَابُوسِيُّ', #1
u'القاتلية': u'الْقَاتِلِيَّةُ', #1
u'القاتليه': u'الْقَاتِلِيهِ', #2
u'القاتول': u'الْقَاتُولُ', #1
u'القاتول': u'الْقَاتُولِ', #1
u'القاحة': u'الْقَاحَةَ', #1
u'القاحة': u'الْقَاحَةُ', #1
u'القاحة': u'الْقَاحّةَ', #1
u'القاحة': u'الْقَاحَّةِ', #1
u'القاحة،': u'الْقَاحَةَ،', #1
u'القاحة': u'الْقَاحَة', #2
u'القاحة': u'الْقَاحّةُ', #2
u'القاحة': u'الْقَاحَةِ', #5
u'القاد': u'الْقَادَّ', #1
u'القاد': u'الْقَادِّ', #5
u'القاد': u'الْقَادُّ', #8
u'القادات': u'الْقَادَاتِ', #1
u'القادرينا': u'الْقَادِرِينَا', #2
u'القادس': u'الْقَادِسُ', #1
u'القادس': u'الْقَادِسِ', #1
u'القادف': u'الْقَادِفُ', #1
u'القادفات': u'الْقَادِفَاتِ', #1
u'القادوم،': u'الْقَادُومَ،', #1
u'القاذوره': u'الْقَاذُورَهْ', #1
u'القارظي': u'القارظي', #1
u'القارظي،': u'القارظي،', #1
u'القارظي': u'الْقَارِظِيّ', #1
u'القارظى': u'الْقَارِظِىِّ', #1
u'القارظي': u'الْقَارِظِيِّ', #3
u'القارورات': u'الْقَارُورَاتُ', #1
u'القارورات': u'الْقَارُورَاتِ', #1
u'القارى': u'الْقَارِىُّ', #13
u'القارى': u'الْقَارِى', #2
u'القارى': u'الْقَارِىَّ', #23
u'القارى': u'الْقَارِىِّ', #33
u'القاريء،': u'القاريء،', #1
u'القاريء': u'القاريء', #4
u'القارىء': u'القارىء', #8
u'القاسارية': u'الْقَاسَارِيَّةِ', #1
u'القاساني،': u'الْقَاسَانِيُّ،', #1
u'القاسمأن': u'الْقَاسِمِأَنَّ', #2
u'القاسمأو': u'الْقَاسِمِأَوْ', #1
u'القاسمعنه': u'الْقَاسِمِعَنْهُ', #1
u'القاسمفإن': u'الْقَاسِمِفَإِنَّ', #1
u'القاسمفي': u'الْقَاسِمِفِي', #1
u'القاسمفيمن': u'الْقَاسِمِفِيمَنْ', #2
u'القاسممن': u'الْقَاسِمِمَنْ', #1
u'القاسموغيره': u'الْقَاسِمِوَغَيْرِهِ', #1
u'القاسمي': u'الْقَاسِمِيُّ', #1
u'القاسمية': u'الْقَاسِمِيَّة', #1
u'القاسمية': u'الْقَاسِمِيَّةِ', #10
u'القاشاني': u'الْقَاشَانِي', #1
u'القاشاني': u'الْقَاشَانِيّ', #1
u'القاشاني': u'الْقَاشَانِيِّ', #1
u'القاشاني': u'الْقَاشَانِيُّ', #4
u'القاشور': u'الْقَاشُورَ', #2
u'القاشور': u'الْقَاشُورُ', #2
u'القاشي': u'الْقَاشِي', #1
u'القاصدها': u'الْقَاصِدَهَا', #1
u'القاصرية': u'الْقَاصِرِيَّةِ', #5
u'القاصرية': u'الْقَاصِرِيَّةُ', #6
u'القاصعاء': u'الْقَاصِعَاءُ', #1
u'القاصعاء': u'الْقَاصِعَاءِ', #3
u'القاضى': u'القاضى', #1
u'القاضى': u'الْقَاضِى', #1962
u'القاضى': u'الْقَاضِىَ', #3
u'القاطبي': u'الْقَاطِبِيُّ', #1
u'القاعده': u'الْقَاعِدَهْ', #1
u'القافة': u'القافة', #1
u'القافة،': u'القافة،', #1
u'القافة': u'الْقَافَة', #1
u'القافة': u'الْقَافَّةِ', #1
u'القافة،': u'الْقَافَةَ،', #1
u'القافة،': u'الْقَافَةُ،', #1
u'القافة': u'الْقَافَةِ', #125
u'القافة': u'الْقَافَةُ', #204
u'القافة': u'الْقَافَّةُ', #6
u'القافة': u'الْقَافَةَ', #82
u'القافلائى': u'الْقَافُلاَئِىُّ', #1
u'القاقلى': u'الْقَاقُلَّى', #1
u'القالة': u'القالة', #1
u'القالة': u'الْقَالَةَ', #1
u'القالة،': u'الْقَالَةُ،', #1
u'القالة': u'الْقَالَةُ', #11
u'القالة': u'الْقَالَةِ', #2
u'القالم': u'الْقَالِمِ', #1
u'القامري': u'الْقَامِرِيِّ', #1
u'القامشلي': u'القامشلي', #2
u'القامصة': u'الْقَامِصَةِ', #3
u'القاه': u'الْقَاهُ', #2
u'القاوند': u'القاوند', #1
u'القائف': u'الْقَائِف', #12
u'القائف': u'الْقَائِفُ', #127
u'القائف': u'الْقَائِفَ', #21
u'القائف': u'الْقَائِفِ', #339
u'القائفين': u'الْقَائِفَيْنِ', #2
u'القائفين': u'الْقَائِفِينَ', #3
u'ألقائهم': u'أَلْقَائِهِمْ', #1
u'القاياتي': u'الْقَايَاتِيُّ', #16
u'القاياتي': u'الْقَايَاتِيِّ', #5
u'القايتبابي': u'الْقَايِتْبَابِيُّ', #2
u'القايتباي': u'الْقَايِتْبَاي', #4
u'القايس': u'الْقَايِسِ', #1
u'القايسين': u'الْقَايِسِينَ', #1
u'القبا': u'الْقَبَا', #1
u'القبارى': u'الْقُبَارَى', #1
u'القباطي': u'الْقَبَاطِيُّ', #1
u'القباطي': u'الْقَبَاطِيِّ', #1
u'القباطي': u'الْقُبَاطِيَّ', #1
u'القباطى': u'الْقَبَاطِىَّ', #1
u'القباطي': u'الْقَبَاطِيّ', #2
u'القباطي': u'الْقَبَاطِيَّ', #8
u'القباعي': u'الْقُبَاعِيِّ', #1
u'القبانى': u'الْقَبَّانِىُّ', #24
u'القبانين': u'الْقَبَّانِينَ', #1
u'القبتي': u'الْقَبْتِيُّ', #1
u'القبج': u'الْقَبَجِ', #2
u'القبج': u'الْقَبَجُ', #3
u'القبجة': u'الْقَبَجَةُ', #1
u'القبحة': u'الْقَبْحَةِ', #1
u'القبرسي': u'الْقُبْرُسِيُّ', #1
u'القبص': u'الْقَبْص', #1
u'القبص': u'الْقَبْصُ', #1
u'القبضان': u'الْقَبْضَانِ', #18
u'القبضان': u'الْقَبْضَانُ', #2
u'القبضه': u'القبضه', #1
u'القبضين': u'الْقَبْضَيْنِ', #18
u'القبطى': u'الْقِبْطِىُّ', #1
u'القبطى': u'الْقِبْطِىِّ', #1
u'القبقلار': u'الْقُبُقْلَارِ', #1
u'القبلا': u'الْقُبُلَا', #2
u'القبلةثم': u'الْقِبْلَةِثُمَّ', #1
u'القبلةلا': u'الْقِبْلَةِلَا', #1
u'القبلةوروي': u'الْقِبْلَةِوَرُوِيَ', #2
u'القبله': u'القبله', #1
u'القبوض': u'الْقُبُوضِ', #2
u'القبولة': u'الْقَبُولَةِ', #1
u'القبيسي': u'الْقَبِيسِيَّ', #1
u'القبيسي': u'الْقَبِيسِيُّ', #1
u'القبيسي': u'الْقَبِيسِيِّ', #2
u'القبيله': u'القبيلَهْ', #1
u'القبيله': u'الْقِبِيلَه', #1
u'القبيله': u'الْقَبِيلَهْ', #3
u'القبيلين': u'الْقَبِيلَيْنِ', #5
u'القتا': u'الْقِتَا', #4
u'القتادة': u'الْقَتَادَةَ', #1
u'القتالا': u'الْقِتَالا', #1
u'القتالا': u'الْقِتَالَا', #1
u'القتالة': u'الْقَتَّالَةِ', #7
u'القتان': u'الْقِتَانَ', #1
u'القتب': u'الْقَتَبَ', #1
u'القتب': u'الْقَتَبِ', #19
u'القتب': u'القتب', #2
u'القتب': u'الْقَتَبُ', #2
u'القتب': u'الْقَتَب', #4
u'القتباني،': u'القتباني،', #1
u'القتباني،': u'الْقَتَبَانِيَّ،', #1
u'القتباني،': u'الْقُتْبَانِيِّ،', #1
u'القتباني،': u'الْقِتْبَانِيِّ،', #1
u'القتبانى': u'الْقِتْبَانِىَّ', #1
u'القتباني': u'الْقِتْبَانِيّ', #2
u'القتباني': u'الْقِتْبَانِيَّ', #2
u'القتبانى': u'الْقِتْبَانِىُّ', #3
u'القتبانى': u'الْقِتْبَانِىِّ', #4
u'القتباني': u'الْقِتْبَانِيُّ', #7
u'القتباني': u'الْقِتْبَانِيِّ', #7
u'القتباني،': u'الْقِتْبَانِيُّ،', #8
u'القتبائي': u'القَتْبَائِيُّ', #1
u'القتبائي': u'القَتْبَائِيِّ', #2
u'القتبي': u'الْقُتَبِيِّ', #1
u'القتبى': u'الْقُتَبِىُّ', #1
u'القتبي': u'الْقُتَبِيُّ', #29
u'القتبي': u'الْقُتَبِيّ', #47
u'القتد': u'الْقَتَدُ', #1
u'القتلا': u'الْقَتْلَا', #4
u'القتلات': u'الْقِتْلَاتِ', #2
u'القتلقوله': u'الْقَتْلِقَوْلُهُ', #1
u'القتوبة': u'الْقَتُوبَةِ', #1
u'القتولا': u'الْقَتُولَا', #1
u'القتيبي': u'الْقُتَيْبِيّ', #1
u'القتيبي': u'الْقُتَيْبِيُّ', #5
u'القتيبى': u'الْقُتَيْبِىُّ', #9
u'القتير': u'الْقَتِيرِ', #1
u'القتير': u'الْقَتِيرَ', #3
u'القثاة': u'الْقَثَّاةُ', #1
u'القحذمي،': u'القَحْذَميّ،', #1
u'القحذمي': u'الْقَحْذَمِيُّ', #1
u'القحذمي،': u'الْقَحْذَمِيُّ،', #1
u'القحوط': u'الْقُحُوط', #1
u'القحوط': u'الْقُحُوطِ', #2
u'القدا': u'الْقَدَّا', #1
u'القدرS': u'الْقَدَرْS', #1
u'القدما': u'الْقَدَمَا', #1
u'القدوري': u'الْقُدُورِيِّ', #1007
u'القدوري': u'الْقُدُورِيُّ', #1070
u'القدوري': u'الْقُدُورِيَّ', #59
u'القدوسي': u'الْقُدُّوسِيِّ', #1
u'القدوسية': u'الْقُدُّوسِيَّةِ', #1
u'القديدة': u'الْقَدِيدَةَ', #1
u'القذاء': u'الْقَذَاءَ', #1
u'القذفات': u'الْقَذَفَاتُ', #1
u'القذفان': u'الْقَذْفَانِ', #4
u'القذفين': u'الْقَذْفَيْنِ', #20
u'القرءان': u'القرءان', #1
u'القرءان': u'الْقُرءانَ', #1
u'القرءان': u'الْقُرْءَانَ', #15
u'القرءان': u'الْقُرْءَانُ', #5
u'القرءان': u'الْقُرْءَانِ', #8
u'القرا': u'الْقُرَّا', #1
u'القراءة': u'الْقِرَاءَةً', #1
u'القراءةأكاد': u'القراءةأكاد', #1
u'القراءةسألت': u'الْقِرَاءَةِسَأَلَتْ', #1
u'القرابةوروي': u'الْقَرَابَةُوَرُوِيَ', #1
u'القرابه': u'الْقَرَابَهْ', #1
u'القراحصاري': u'القراحصاري', #1
u'القراحصاري': u'الْقَرَاحَصَارِيِّ', #1
u'القرارى': u'الْقَرَارِىُّ', #1
u'القراريدي،': u'الْقَرَارِيدِيُّ،', #1
u'القراطيسي': u'الْقَرَاطِيسِيُّ', #194
u'القراطيسي،': u'الْقَرَاطِيسِيُّ،', #196
u'القراطيسي': u'الْقَرَاطِيسِيِّ', #2
u'القراطيسى': u'الْقَرَاطِيسِىُّ', #2
u'القراطيسي،': u'الْقَرَاطِيسِيِّ،', #5
u'القراظ،': u'الْقَرَّاظ،', #1
u'القراظ،': u'الْقَرَّاظِ،', #3
u'القراظ': u'الْقَرَّاظَ', #5
u'القراظ': u'الْقَرَّاظُ', #5
u'القراظ': u'الْقَرَّاظِ', #6
u'القرافة': u'الْقَرَافَةُ', #1
u'القرافة': u'الْقَرَافَةِ', #15
u'القرافة': u'الْقَرَافَةَ', #5
u'القرافي': u'الْقِرَافِيُّ', #1
u'القرافي': u'الْقَرَافِيُّ', #1055
u'القرافي': u'الْقَرَافِيَّ', #20
u'القرافي': u'الْقَرَافِيِّ', #212
u'القرافي': u'الْقَرَافِيّ', #5
u'القرافية': u'الْقَرَافِيَّةِ', #1
u'القراقر': u'الْقُرَاقِرِ', #1
u'القراقيش': u'الْقَرَاقِيشِ', #1
u'القرام': u'الْقِرَامُ', #1
u'القرام': u'القرام', #3
u'القرام': u'الْقِرَامِ', #4
u'القرام': u'الْقِرَامَ', #5
u'القرامد': u'الْقَرَامِدِ', #1
u'القرامز': u'الْقَرَامِزُ', #1
u'القرامز': u'الْقَرَامِزَ', #3
u'القرامل': u'الْقَرَامِلِ', #1
u'القراميل': u'الْقَرَامِيلَ', #1
u'القراميل': u'الْقَرَامِيلِ', #2
u'القرآنالوجه': u'الْقُرْآنِالْوَجْهُ', #1
u'القرآنفلا': u'الْقُرْآنِفَلَا', #1
u'القرآنقال': u'الْقُرْآنُقَالَ', #1
u'القرآنوالوجه': u'الْقُرْآنُوَالْوَجْهُ', #1
u'القرآنوالوجه': u'الْقُرْآنِوَالْوَجْهُ', #1
u'القرآنوروي': u'الْقُرْآنُوَرُوِيَ', #2
u'القرآنوليس': u'الْقُرْآنَوَلَيْسَ', #1
u'القرآنومن': u'الْقُرْآنَوَمَنْ', #1
u'القراوي': u'الْقَرَاوِيُّ', #1
u'القرأين': u'الْقُرْأَيْنِ', #16
u'القرايين': u'الْقَرَّايِينَ', #1
u'القربا': u'الْقُرْبَا', #1
u'القرباء': u'الْقُرَبَاءِ', #1
u'القرباء': u'الْقُرَبَاءُ', #2
u'القربز': u'الْقُرْبُزُ', #1
u'القربناء': u'الْقَرْبُنَاءِ', #1
u'القربه': u'الْقُرْبَهْ', #1
u'القربوس': u'القربوس', #1
u'القربوس،': u'القربوس،', #1
u'القربوس،': u'القَرَبُوسَ،', #1
u'القربوس،': u'القُرْبُوس،', #1
u'القرثع': u'الْقَرْثَعِ', #10
u'القرحا': u'الْقَرْحَا', #2
u'القردواني': u'الْقَرْدُوَانِيُّ', #1
u'القردواني': u'الْقَرْدُوَانِيِّ', #1
u'القردواني،': u'الْقَرْدُوَانِيِّ،', #1
u'القردواني،': u'الْقَرْدُوَانِيُّ،', #2
u'القردوسي': u'الْقُرْدُوسِيِّ', #1
u'القردوسي،': u'الْقُرْدُوسِيُّ،', #1
u'القردوسى': u'الْقُرْدُوسِىِّ', #1
u'القردوسي،': u'الْقُرْدُوسِيِّ،', #2
u'القردوسى': u'الْقُرْدُوسِىُّ', #3
u'القردوسي': u'الْقُرْدُوسِيُّ', #8
u'القرسطون': u'القرسطون', #1
u'القرشى': u'الْقُرَشِىُّ', #114
u'القرشى': u'الْقُرَشِىِّ', #32
u'القرشى': u'الْقُرَشِىَّ', #5
u'القرطا': u'القُرْطَا', #1
u'القرطاء': u'القرُطَاء', #1
u'القرطاء،': u'القرَطَاء،', #1
u'القرطاء': u'القُرَطَاء', #1
u'القرطاء': u'الْقُرَطَاءُ', #1
u'القرطاء': u'الْقُرَطُاءُ', #1
u'القرطاء،': u'الْقَرْطَاءِ،', #1
u'القرطاء': u'الْقُرْطَاءِ', #2
u'القرطاء': u'الْقُرَطَاءَ', #3
u'القرطاء': u'الْقُرَطَاءِ', #3
u'القرطاء': u'القُرطاء', #5
u'القرطالة': u'الْقِرْطَالَةَ', #1
u'القرطالة': u'الْقِرْطَالَةِ', #1
u'القرطالة': u'الْقِرْطَالَةُ', #3
u'القرطبان': u'الْقَرْطَبَانَ', #1
u'القرطبان': u'الْقَرْطُبَانُ', #2
u'القرطبان': u'الْقَرْطَبَانُ', #4
u'القرطبان': u'الْقَرْطَبَانِ', #6
u'القرطة': u'الْقِرَطَةَ', #1
u'القرطف': u'الْقَرْطَفُ', #3
u'القرطق': u'القرطق', #1
u'القرطق': u'الْقُرْطَقَ', #1
u'القرطق': u'الْقُرْطَقِ', #1
u'القرطق': u'الْقُرْطُقُ', #1
u'القرطم': u'الْقُرْطُمُ', #12
u'القرطم': u'الْقُرْطُمَ', #2
u'القرطم': u'الْقُرْطُمِ', #36
u'القرطيسي': u'الْقَرَطِيسِيُّ', #2
u'القرظ': u'الْقُرَظَ', #1
u'القرظ': u'الْقُرَظُ', #1
u'القرظ،': u'الْقُرَظُ،', #1
u'القرظ': u'الْقَرَظَ', #2
u'القرظ': u'الْقَرْظَ', #2
u'القرظ': u'الْقَرْظِ', #3
u'القرظ': u'القرظ', #4
u'القرظ': u'الْقَرَظِ', #41
u'القرظ': u'الْقَرَظُ', #7
u'القرظي،': u'القرظي،', #1
u'القرظي،': u'القرظِيّ،', #1
u'القرظي': u'القُرظي', #1
u'القرظي': u'القُرَظي', #1
u'القرظي': u'القُرَظيُ', #1
u'القرظي': u'القُرَظيّ', #1
u'القرظي،': u'القُرَظي،', #1
u'القرظي،': u'القَرَظِي،', #1
u'القرظي،': u'القُرَظِيّ،', #1
u'القرظي': u'الْقَرَظِيُ', #1
u'القرظي،': u'الْقُرْظِيِّ،', #1
u'القرظى': u'الْقَرَظِىَّ', #1
u'القرظي،': u'الْقُرَظِيُّ،', #10
u'القرظى': u'الْقُرَظِىُّ', #10
u'القرظي': u'الْقُرَظِيِّ', #113
u'القرظي': u'الْقُرَظِيُّ', #13
u'القرظي': u'القرظي', #2
u'القرظي،': u'الْقَرَظِيُّ،', #2
u'القرظى': u'الْقُرَظِىِّ', #21
u'القرظي': u'الْقُرَظِيَّ', #26
u'القرظي': u'القُرَظِيِّ', #3
u'القرظى': u'القرظى', #3
u'القرظى،': u'القرظى،', #3
u'القرظي': u'القُرظِيّ', #5
u'القرظي،': u'القُرَظِيِّ،', #5
u'القرظى': u'الْقُرَظِىَّ', #6
u'القرظي،': u'الْقُرَظِيِّ،', #65
u'القرظي': u'الْقُرَظِيّ', #66
u'القرظي،': u'الْقُرَظِيَّ،', #9
u'القرظيان': u'الْقُرَظِيَّانِ', #1
u'القرظي،أنه': u'الْقُرَظِيِّ،أَنَّهُ', #4
u'القرظية': u'الْقُرَظِيَّةُ', #1
u'القرظي،في': u'الْقُرَظِيِّ،فِي', #1
u'القرعوني': u'الْقَرْعُونِيُّ', #1
u'القرعى': u'الْقَرْعَى', #1
u'القرقبي': u'الْقُرْقُبِيُّ', #1
u'القرقر': u'القرقر', #1
u'القرقر': u'الْقَرْقَرَ', #1
u'القرقر': u'الْقَرْقَرُ', #1
u'القرقساني': u'القرقساني', #1
u'القرقساني،': u'القرقساني،', #1
u'القرقساني': u'الْقَرْقَسَانِيِّ', #1
u'القرقساني،': u'الْقَرْقَسَانِيُّ،', #1
u'القرقساني،': u'الْقَرْقَسَانِيِّ،', #1
u'القرقسانى': u'الْقُرْقُسَانِىُّ', #1
u'القرقسانى': u'الْقَرْقَسَانِىُّ', #2
u'القرقساني': u'الْقُرْقُسَانِيُّ', #3
u'القرقسائي': u'الْقُرْقُسَائِيُّ', #1
u'القرقسائي،': u'الْقَرْقَسَائِيُّ،', #2
u'القرقسائى': u'الْقَرْقَسَائِىُّ', #2
u'القرقشاني': u'الْقَرْقَشَانِيُّ', #1
u'القرقشندي': u'الْقَرْقَشَنْدِيِّ', #1
u'القرقل': u'الْقَرْقَلُ', #1
u'القرقوبى': u'الْقُرْقُوبِىُّ', #1
u'القرقور': u'القرقور', #1
u'القرقوس': u'الْقَرَقوُسِ', #1
u'القرم': u'القرم', #1
u'القرم': u'الْقُرَمِ', #1
u'القرم': u'الْقُرُمِ', #1
u'القرم،': u'الْقَرْمِ،', #1
u'القرم': u'الْقَرْمِ', #2
u'القرم': u'الْقَرْمُ', #5
u'القرماني': u'الْقَرْمَانِيَّ', #1
u'القرماني': u'الْقَرْمَانِيُّ', #4
u'القرماني': u'الْقَرْمَانِيِّ', #5
u'القرمة': u'الْقَرْمَةِ', #3
u'القرمز': u'الْقِرْمِزُ', #2
u'القرمز': u'الْقِرْمِزِ', #5
u'القرمود': u'الْقَرْمُودِ', #3
u'القرمونية': u'الْقَرَمُونِيَّةِ', #1
u'القرمية': u'الْقِرْمِيَّةِ', #1
u'القرميسي': u'الْقَرَمِيسِيُّ', #2
u'القرميسيني': u'الْقِرْمِيسِينِيُّ', #1
u'القرميسيني،': u'الْقِرْمِيسِينِيِّ،', #1
u'القرميسيني،': u'الْقِرْمِيسِينِيُّ،', #2
u'القرميسينى': u'الْقِرْمِيسِينِىُّ', #5
u'القرنباذ': u'الْقَرْنَبَاذُ', #1
u'القرنى': u'الْقَرَنِىِّ', #1
u'القروم': u'الْقُرُومَ', #2
u'القروم': u'الْقُرُومِ', #2
u'القرونا': u'الْقُرُونَا', #1
u'القروى': u'الْقَرَوِىُّ', #1
u'القروى': u'الْقَرَوِىِّ', #1
u'القرئين': u'الْقَرْئَيْنِ', #1
u'القرئين': u'الْقُرْئَيْنِ', #1
u'القريبه': u'الْقَرِيبَهْ', #2
u'القريس': u'الْقَرِيس', #1
u'القريس': u'الْقَرِيسِ', #1
u'القريش': u'الْقَرِيش', #1
u'القريشة': u'الْقَرِيشَةُ', #1
u'القريشة': u'الْقَرِيشَةِ', #1
u'القريشي': u'الْقُرَيْشِيُّ', #1
u'القريشي': u'الْقُرَيْشِيِّ', #3
u'القريشية': u'القرَيْشية', #1
u'القريشية': u'الْقُرَيْشِيَّةَ', #1
u'القريشية': u'الْقُرَيْشِيَّةُ', #1
u'القريص': u'الْقَرِيصِ', #1
u'القريظيون': u'الْقُرَيْظِيّونَ', #1
u'القريعي': u'الْقَرِيعِيَّ', #1
u'القريعي': u'الْقُرَيْعِيُّ', #4
u'القرىمكة': u'الْقُرَىمَكَّةَ', #1
u'القريناء': u'الْقُرَيْنَاءِ', #1
u'القزاز،': u'القزاز،', #1
u'القزاز': u'الْقَزَازَ', #1
u'القزاز': u'الْقَزَازِ', #1
u'القزاز': u'الْقَزّازِ', #1
u'القزاز،': u'الْقَزَّازَ،', #1
u'القزاز': u'الْقَزَّازِ', #13
u'القزاز،': u'الْقَزَّازِ،', #16
u'القزاز': u'القزاز', #2
u'القزاز': u'الْقَزَّازَ', #2
u'القزاز،': u'الْقَزَّازُ،', #22
u'القزاز': u'الْقَزَّاز', #4
u'القزاز': u'الْقَزَّازُ', #61
u'القزازون': u'الْقَزَّازُونَ', #1
u'القزازين': u'الْقَزَّازِينَ', #2
u'القزع': u'القزع', #1
u'القزع': u'القَزَع', #1
u'القزع': u'الْقَزَعِِِِِ', #1
u'القزع': u'الْقَزْعُ', #1
u'القزع،': u'الْقَزَعِ،', #1
u'القزع': u'الْقَزْعِ', #2
u'القزع': u'الْقَزَعُ', #29
u'القزع': u'الْقَزَعَ', #3
u'القزع': u'الْقَزَع', #4
u'القزع': u'الْقَزَعِ', #46
u'القزعة': u'الْقَزَعَةُ', #1
u'القزعة': u'القزعة', #2
u'القزوينى': u'الْقَزْوِينِىُّ', #2
u'القساسية': u'الْقُسَاسِيّة', #1
u'القساقس': u'الْقَسَاقِسِ', #1
u'القسامه': u'الْقَسَامَهْ', #3
u'القسامين': u'الْقَسَّامِينَ', #2
u'القسب': u'الْقَسْبَ', #1
u'القسب': u'الْقَسْبُ', #1
u'القسب': u'الْقَسْبِ', #2
u'القسرى': u'الْقَسْرِىِّ', #1
u'القسرى': u'الْقَسْرِىَّ', #2
u'القسطاسالعدل': u'الْقِسْطَاسُالْعَدْلُ', #1
u'القسطلاني': u'الْقَسْطَلَانِيّ', #1
u'القسطلاني': u'الْقَسْطَلَّانِيِّ', #31
u'القسطلاني': u'الْقَسْطَلَّانِيّ', #4
u'القسطلاني': u'الْقَسْطَلَّانِيُّ', #74
u'القسطلانية': u'الْقَسْطَلَّانِيَّة', #2
u'القسطنطينة': u'القسطنطينة', #1
u'القسطنطينة': u'الْقُسْطَنْطِينَةَ', #1
u'القسما': u'الْقَسَمَا', #1
u'القسملي': u'القسملي', #1
u'القسملي': u'الْقَسْمَلِيُّ', #12
u'القسملي،': u'القسملي،', #2
u'القسملي': u'الْقَسْمَلِيَّ', #2
u'القسملى': u'الْقَسْمَلِىُّ', #2
u'القسملى': u'الْقَسْمَلِىِّ', #2
u'القسملي': u'الْقَسْمَلِيِّ', #4
u'القسملي،': u'الْقَسْمَلِيُّ،', #5
u'القسى': u'القِسى', #1
u'القسى': u'الْقَسِّىَّ', #1
u'القسى': u'الْقِسِىَّ', #1
u'القسى': u'الْقَسِّىِّ', #10
u'القسى': u'الْقَسِّىُّ', #2
u'القسى': u'الْقِسِّىِّ', #2
u'القسى': u'القسى', #4
u'القشاشية': u'القشاشية', #1
u'القشطة': u'الْقِشْطَةِ', #3
u'القشطة': u'الْقِشْطَةُ', #5
u'القشعر': u'الْقُشْعُرُ', #1
u'القشيري': u'القُشَيْرِيّ', #1
u'القشيري': u'الْقَشِيرِي', #1
u'القشيري،': u'الْقُشَيْريُّ،', #1
u'القشيري،': u'الْقُشَيْرِيَّ،', #1
u'القشيرى': u'الْقُشَيْرِىَّ', #1
u'القشيري': u'الْقُشَيْرِيُّ', #101
u'القشيري': u'القشيري', #2
u'القشيري': u'الْقُشَيْرِيّ', #214
u'القشيرى': u'الْقُشَيْرِىُّ', #38
u'القشيرى': u'الْقُشَيْرِىِّ', #5
u'القشيري،': u'الْقُشَيْرِيُّ،', #6
u'القشيري': u'الْقُشَيْرِيَّ', #7
u'القشيري': u'الْقُشَيْرِيِّ', #91
u'القشيرية': u'الْقُشَيْرِيَّة', #1
u'القشيرية': u'الْقُشَيْرِيَّةِ', #68
u'القصارون': u'الْقَصَّارُونَ', #2
u'القصارين': u'الْقَصَّارَيْنِ', #2
u'القصارين': u'الْقَصَّارِينَ', #28
u'القصائر': u'الْقَصَائِرُ', #1
u'القصباء': u'الْقَصْبَاءِ', #1
u'القصباني': u'الْقَصَبَانِيُّ', #1
u'القصباني،': u'الْقَصَبَانِيُّ،', #1
u'القصبى': u'الْقَصَبِىُّ', #2
u'القصدان': u'الْقَصْدَانِ', #10
u'القصدين': u'الْقَصْدِينَ', #3
u'القصدين': u'الْقَصْدَيْنِ', #4
u'القصرا': u'الْقَصْرَا', #1
u'القصرات': u'الْقَصَرَاتُ', #1
u'القصرمل': u'الْقُصْرُمِلُّ', #1
u'القصمى': u'الْقُصْمَى', #1
u'القصواء': u'القصواء', #1
u'القصواء': u'القصْواء', #1
u'القصواء': u'القَصْواء', #1
u'القصواء،': u'الْقَصْوَاءِ،', #1
u'القصواء': u'الْقَصْوَاءُ', #15
u'القصواء': u'الْقَصْوَاء', #2
u'القصواء،': u'الْقَصْوَاءَ،', #2
u'القصواء': u'الْقَصْوَاءَ', #26
u'القصواء': u'الْقَصْوَاءِ', #32
u'القصود': u'الْقُصُودُ', #1
u'القصود': u'الْقُصُودَ', #2
u'القصود': u'الْقُصُودِ', #4
u'القصيده': u'الْقَصِيدَهْ', #1
u'القصيرى': u'الْقُصَيْرَى', #1
u'القصيم': u'الْقَصِيمُ', #1
u'القصيم': u'الْقَصِيمِ', #15
u'القصيم': u'الْقَصِيمَ', #2
u'القضا': u'الْقَضَّا', #1
u'القضا': u'الْقَضَا', #36
u'القضافة': u'الْقَضَافَةِ', #2
u'القضاه': u'القضاه', #1
u'القضبة': u'الْقَضْبَةُ', #2
u'القضقاض': u'الْقَضْقَاضِ', #1
u'القضوية': u'الْقَضَوِيَّةِ', #1
u'القضىء': u'القضىء', #1
u'القضيمة': u'الْقَضِيمَةِ', #1
u'القطاط': u'الْقِطَاطُ', #5
u'القطام': u'الْقَطَامِ', #1
u'القطامى': u'الْقُطَامِىِّ', #1
u'القطانون': u'الْقَطَّانُونَ', #2
u'القطانين': u'القطانين', #1
u'القطانين': u'الْقَطَّانِينَ', #4
u'القطائي': u'الْقَطَائِيِّ', #1
u'القطبانية': u'الْقُطْبَانِيَّةَ', #1
u'القطرانى': u'الْقَطِرَانِىُّ', #2
u'القطربلي،': u'القطربليّ،', #1
u'القطربلي': u'الْقُطْرُبُلِّيُّ', #1
u'القطرى': u'الْقَطْرِىُّ', #1
u'القطرى': u'الْقِطْرِىِّ', #1
u'القطرى': u'الْقِطْرِىُّ', #2
u'القطعى،': u'القطعى،', #1
u'القطعى': u'الْقَطِعِىُّ', #1
u'القطعى': u'الْقُطَعِىُّ', #5
u'القطعين': u'الْقِطْعَيْنِ', #2
u'القطعين': u'الْقَطْعَيْنِ', #30
u'القطقاط': u'الْقَطْقَاطُ', #1
u'القطواني،': u'القطواني،', #1
u'القطواني': u'الْقَطْوَانِيُّ', #1
u'القطواني،': u'الْقَطَوَانِيِّ،', #1
u'القطوانى': u'الْقَطْوَانِىُّ', #1
u'القطواني': u'الْقَطَوَانِيُّ', #13
u'القطواني': u'القطواني', #2
u'القطواني': u'الْقَطَوَانِيِّ', #2
u'القطواني،': u'الْقَطْوَانِيُّ،', #2
u'القطواني،': u'الْقَطَوَانِيُّ،', #24
u'القطوانى': u'الْقَطَوَانِىُّ', #3
u'القطيعاء،': u'الْقُطَيْعَاءِ،', #1
u'القطيعاء': u'القطيعاء', #2
u'القطيعاء': u'الْقُطَيْعَاءِ', #3
u'القطيعي': u'القطيعي', #1
u'القطيعي': u'الْقَطِيعِيَّ', #1
u'القطيعي': u'الْقُطَيعِيُّ', #1
u'القطيعي،': u'الْقَطِيعِيَّ،', #1
u'القطيعى': u'الْقَطِيْعِىُّ', #1
u'القطيعي': u'الْقَطِيعِيُّ', #16
u'القطيعي،': u'الْقَطِيعِيِّ،', #19
u'القطيعي': u'الْقَطِيعِيِّ', #3
u'القطيعي': u'الْقُطَيْعِيُّ', #3
u'القطيعي': u'الْقُطَيْعِيِّ', #3
u'القطيعى': u'الْقُطَيْعِىُّ', #3
u'القطيعي،': u'الْقَطِيعِيُّ،', #39
u'القطيعي،': u'القطيعي،', #6
u'القطيعى': u'الْقَطِيعِىُّ', #75
u'القطيعيات': u'الْقَطِيعِيَّاتِ', #1
u'القطيفي': u'الْقَطِيفِيُّ', #1
u'القعاب': u'الْقِعَابَ', #1
u'القعب،': u'الْقَعْبِ،', #1
u'القعب': u'الْقَعْبُ', #2
u'القعب': u'الْقَعْبَ', #3
u'القعب': u'الْقَعْبِ', #4
u'القعبري': u'الْقَعْبَرِيُّ', #1
u'القعد': u'الْقَعَد', #1
u'القعد': u'الْقَعَدِ', #1
u'القعدان': u'الْقَعْدَانَ', #1
u'القعدان': u'الْقُعْدَانَ', #1
u'القعدد': u'الْقُعْدَدِ', #4
u'القعدد': u'الْقُعْدُدِ', #9
u'القعقاع،': u'القعقاع،', #1
u'القعقاع': u'القعْقاع', #1
u'القعقاع': u'الْقَعْقَاعُ', #13
u'القعقاع': u'الْقَعْقَاعِ', #170
u'القعقاع،': u'الْقَعْقَاعِ،', #18
u'القعقاع': u'القَعْقَاع', #2
u'القعقاع،': u'الْقَعْقَاعُ،', #2
u'القعقاع': u'القعقاع', #5
u'القعقاع': u'الْقَعْقَاعَ', #8
u'القعقاعي': u'الْقَعْقَاعِيُّ', #1
u'القعقع': u'الْقَعْقَعُ', #1
u'القعقع': u'الْقُعْقُعُ', #4
u'القعنبي،': u'القعنبي،', #1
u'القعنبي،': u'الْقَعْنَبيِّ،', #1
u'القعنبى': u'القَعْنَبِىَّ', #1
u'القعنبي،': u'الْقَعْنَبِيُّ،', #160
u'القعنبى': u'الْقَعْنَبِىِّ', #170
u'القعنبى': u'القَعْنَبِىِّ', #2
u'القعنبى': u'الْقَعْنَبِى', #2
u'القعنبى': u'الْقَعْنَبِىُّ', #263
u'القعنبي': u'الْقَعْنَبِيِّ', #27
u'القعنبي': u'الْقَعْنَبِيّ', #4
u'القعنبي': u'الْقَعْنَبِيَّ', #4
u'القعنبي،': u'الْقَعْنَبِيِّ،', #42
u'القعنبى': u'القَعْنَبِىُّ', #5
u'القعنبى': u'الْقَعْنَبِىَّ', #8
u'القعنبي': u'الْقَعْنَبِيُّ', #96
u'القعنبيوغيره': u'الْقَعْنَبِيُّوَغَيْرُهُ', #1
u'القعو': u'الْقَعْوِ', #3
u'القعيس،': u'الْقُعَيْسِ،', #1
u'القعيس': u'الْقُعَيْسِ', #55
u'القفاء': u'الْقَفَاءِ', #6
u'القفاص': u'الْقَفَّاصِ', #1
u'القفاف': u'الْقِفَافَ', #1
u'القفاف': u'الْقِفَافُ', #1
u'القفاف': u'الْقِفَافِ', #3
u'القفزان': u'الْقُفْزَانُ', #2
u'القفزان': u'الْقُفْزَانِ', #33
u'القفزان': u'الْقُفْزَانَ', #7
u'القفطي': u'الْقِفْطِيَّ', #1
u'القفطي': u'الْقِفْطِيُّ', #1
u'القفعاء': u'الْقَفْعَاءِ', #2
u'القفعة': u'الْقَفْعَةُ', #1
u'القفيز': u'الْقَفِيزِ', #119
u'القفيز': u'القفيز', #2
u'القفيز': u'الْقَفِيزَ', #54
u'القفيز': u'الْقَفِيزُ', #62
u'القفيزان': u'الْقَفِيزَانِ', #3
u'القفيزين': u'الْقَفِيزَيْنِ', #6
u'القفينة': u'الْقَفِينَةَ', #1
u'الققل': u'القِقْلَ', #1
u'القلاخ': u'الْقَلَّاخُ', #1
u'القلاخ': u'الْقَلَّاخِ', #1
u'القلاخ': u'الْقُلَاخُ', #1
u'القلاس': u'الْقَلَّاسِ', #1
u'القلاص': u'القلاص', #1
u'القلاص': u'الْقِلاصَ', #1
u'القلاص': u'الْقِلَاصَ', #1
u'القلاص': u'الْقِلَاصِ', #1
u'القلاص': u'الْقِلاَصُ', #1
u'القلاص': u'الْقِلَاصُ', #2
u'القلاقة': u'الْقَلَاقَةُ', #1
u'القلاقة': u'الْقَلَاقَةِ', #10
u'القلام': u'القلام', #1
u'القلانسا': u'الْقَلانِسَا', #1
u'القلانسي،': u'القلانسي،', #1
u'القلانسي': u'الْقَلاَنِسِيُّ', #1
u'القلانسي': u'القلانسي', #2
u'القلانسي،': u'الْقَلانِسِيِّ،', #2
u'القلانسي': u'الْقَلَانِسِيُّ', #24
u'القلانسي،': u'الْقَلانِسِيُّ،', #3
u'القلانسي': u'الْقَلَانِسِيَّ', #3
u'القلانسي': u'الْقَلانِسِيُّ', #4
u'القلانسي': u'الْقَلَانِسِيِّ', #51
u'القلانسى': u'الْقَلاَنِسِىُّ', #71
u'القلائص،': u'الْقَلائِصَ،', #1
u'القلائص': u'الْقَلَائِصُ', #1
u'القلائص': u'الْقَلَائِصَ', #3
u'القلبا': u'الْقَلْبَا', #1
u'القلح': u'الْقَلَحُ', #1
u'القلح': u'الْقَلَحِ', #1
u'القلح': u'الْقُلْحِ', #2
u'القلح': u'الْقُلْحَ', #3
u'القلح': u'الْقَلَحَ', #6
u'القلخ': u'الْقَلْخُ', #1
u'القلزم': u'الْقُلْزُم', #1
u'القلزم': u'الْقُلْزُمِ', #12
u'القلزم': u'الْقَلْزَمِ', #4
u'القلزمي': u'القَلْزَمِيُّ', #1
u'القلزمي': u'الْقُلْزُمِيَّ', #1
u'القلزمي،': u'الْقَلْزَمِيِّ،', #1
u'القلشاني': u'الْقَلْشَانِيِّ', #18
u'القلشاني': u'الْقَلْشَانِيَّ', #2
u'القلشاني': u'الْقَلْشَانِيُّ', #36
u'القلشاني': u'الْقَلْشَانِيّ', #5
u'القلشين': u'الْقَلْشِينَ', #1
u'القلفونية': u'القلفونية', #1
u'القلفونية': u'الْقَلفُونِيّةُ', #1
u'القلقشندي': u'الْقَلْقَشَنْدِي', #1
u'القلقشندي': u'الْقَلْقَشَنْدِيُّ', #2
u'القلقطار': u'القلقطار', #1
u'القلقلان': u'الْقُلْقُلَانِ', #1
u'القلقند': u'القلقند', #1
u'القلمس': u'القَلَمّس', #1
u'القلمس': u'الْقَلَمَّسِ', #1
u'القلمس': u'الْقَلَمَّسُ', #2
u'القلمس': u'الْقَلَمّسُ', #5
u'القلندرية': u'القلندرية', #1
u'القلندرية': u'الْقَلَنْدَرِيَّةُ', #2
u'القلندرية': u'الْقَلَنْدَرِيَّةِ', #2
u'القلنسية': u'الْقُلَنْسِيَةُ', #1
u'القلهذم': u'الْقَلَهْذَمِ', #2
u'القلوبا': u'الْقُلُوبَا', #1
u'القلوذي': u'الْقَلْوَذِيُّ', #1
u'القلورى': u'الْقَلَوَّرِىُّ', #1
u'القلوسي،': u'القَلُوسِيُّ،', #1
u'القلوسي،': u'الْقُلُوسِيِّ،', #1
u'القلوسي': u'الْقُلُوسِيِّ', #2
u'القلوسي،': u'الْقُلُوسِيُّ،', #2
u'القلوسي': u'الْقَلُوسِيُّ', #3
u'القلوسي،': u'الْقَلُوسِيُّ،', #7
u'القليب': u'الْقَلِيبَ', #1
u'القليب': u'الْقَلِيبِ', #112
u'القليب': u'القليب', #3
u'القليب،': u'الْقَلِيبِ،', #5
u'القليب': u'الْقَلِيبُ', #6
u'القليخ': u'الْقَلِيخُ', #1
u'القليس': u'الْقُلَيْسِ', #1
u'القليس': u'الْقُلَّيْسُ', #1
u'القليس': u'الْقُلَّيْسِ', #2
u'القليس': u'الْقُلّيْسِ', #2
u'القليس': u'الْقُلَّيْسَ', #3
u'القليس': u'الْقُلّيْسَ', #3
u'القليس': u'الْقُلّيْس', #4
u'القليعة': u'الْقُلَيْعَةِ', #1
u'القليقات': u'الْقَلِيقَاتُ', #1
u'القليلون': u'الْقَلِيلُونَ', #1
u'القليني': u'الْقَلِينِيُّ', #1
u'القليوبي': u'الْقَلْيُوبِيِّ', #110
u'القليوبي': u'الْقَلْيُوبِيَّ', #2
u'القليوبي': u'الْقَلْيُوبِيُّ', #90
u'القماقمة': u'الْقَمَاقِمَةِ', #1
u'القماقمة': u'الْقَمَاقِمَة', #2
u'القمائم': u'الْقَمَائِمِ', #1
u'القمحدوة': u'القمحدوة', #1
u'القمرا': u'الْقَمَرَا', #3
u'القمسة': u'الْقَمَسَةِ', #1
u'القمعه': u'الْقَمَعَهْ', #2
u'القموص،': u'القَمُوص،', #1
u'القموص': u'الْقَمُوصُ', #1
u'القموص': u'الْقُمُوصُ', #1
u'القموص،': u'الْقَمُوصَ،', #1
u'القموص': u'الْقَمُوص', #2
u'القموص': u'الْقَمُوصَ', #2
u'القموص': u'الْقَمُوصِ', #8
u'القموصي،': u'القموصي،', #1
u'القموع': u'الْقُمُوعُ', #1
u'القمولي': u'الْقَمُولِيَّ', #13
u'القمولي': u'الْقَمُولِيِّ', #135
u'القمولي': u'الْقَمُولِيّ', #3
u'القمولي': u'الْقَمُولِيُّ', #389
u'القمى': u'الْقُمِّىُّ', #1
u'القمى': u'الْقُمِّىِّ', #1
u'القمير': u'الْقُمَيْرُ', #1
u'القناء': u'الْقَنَاءِ', #1
u'القناد': u'الْقَنَّادَ', #1
u'القناد،': u'الْقَنَّادُ،', #13
u'القناد،': u'الْقَنَّادِ،', #2
u'القناد': u'الْقَنَّادِ', #3
u'القناد': u'الْقَنَّادُ', #8
u'القنازعي': u'الْقَنَازِعِيُّ', #4
u'القناعه': u'الْقَنَاعَهْ', #6
u'القناعيس': u'الْقَنَاعِيسِ', #1
u'القنال': u'الْقَنَالِ', #1
u'القنالي': u'الْقَنَالِيُّ', #1
u'القنبادى،': u'القنبادى،', #1
u'القنباري،': u'الْقَنْبَارِيُّ،', #1
u'القنبارى': u'الْقِنْبَارِىُّ', #1
u'القنباري،': u'الْقِنْبَارِيُّ،', #3
u'القنباري،': u'الْقِنْبَارِيِّ،', #3
u'القنبس،': u'الْقَنْبَسِ،', #1
u'القنبله': u'الْقُنْبُلَهْ', #1
u'القنبيل': u'القنبيل', #1
u'القند': u'الْقَنْدُ', #1
u'القند': u'الْقُنْدِ', #1
u'القند': u'الْقَنْدَ', #5
u'القند': u'الْقَنْدِ', #9
u'القنداس': u'القنداس', #1
u'القندهار': u'القنُدُهار', #1
u'القنسريني': u'الْقِنَّسْرِينِيُّ', #1
u'القنطرى': u'الْقَنْطَرِىُّ', #21
u'القنفد': u'الْقُنْفُدَ', #1
u'القنقل': u'القَنْقل', #1
u'القنقل': u'الْقَنْقَلُ', #1
u'القنقل': u'الْقَنْقَلِ', #1
u'القنيطرة': u'الْقُنَيْطِرَةِ', #1
u'القنين': u'الْقِنِّينَ', #1
u'القنين': u'الْقِنِّينِ', #1
u'القنين': u'الْقِنِّينُ', #2
u'القنين': u'الْقِنَّيْنِ', #30
u'القهاوي': u'الْقَهَاوِي', #5
u'القهرمان': u'القهرمان', #1
u'القهستاني،': u'الْقُهُسْتَانِيُّ،', #1
u'القهستاني،': u'الْقُهُسْتَانِيِّ،', #1
u'القهستاني': u'الْقُهُسْتَانِيِّ', #1070
u'القهستاني': u'الْقُهُسْتَانِيَّ', #17
u'القهستاني،': u'الْقُهِسْتَانِيُّ،', #2
u'القهستاني': u'الْقُهُسْتَانِيّ', #4
u'القهستانى': u'الْقُهُسْتَانِىُّ', #4
u'القهستاني': u'الْقُهُسْتَانِيُّ', #540
u'القهقري': u'الْقَهْقَرِيُّ', #1
u'القهقري،': u'الْقَهْقَرِيِّ،', #1
u'القهقري': u'الْقَهْقَرِيّ', #2
u'القهقري': u'الْقَهْقَرِيَّ', #2
u'القهندزي': u'الْقُهَنْدُزِيّ', #1
u'القهندزي': u'الْقَهَنْدَزِيُّ', #2
u'القهندزي،': u'الْقُهَنْدُزِيُّ،', #2
u'القهندزى': u'الْقُهُنْدُزِىُّ', #2
u'القهندزي،': u'الْقَهَنْدَزِيُّ،', #5
u'القهوات': u'الْقَهَوَاتِ', #2
u'القوابي': u'الْقَوَابِي', #2
u'القوابي': u'الْقَوَابِيَ', #2
u'القوادح': u'الْقَوَادِحِ', #44
u'القوادح': u'الْقَوَادِحُ', #5
u'القوادس': u'الْقَوَادِسِ', #1
u'القوارة': u'الْقُوَارَةَ', #1
u'القوارة': u'الْقُوَارَةِ', #2
u'القواريري': u'القواريري', #1
u'القواريري،': u'الْقُوَارِيرِيُّ،', #1
u'القواريرى': u'الْقَوَارِيرِىُ', #1
u'القواريرى': u'الْقْوَارِيرِىُّ', #1
u'القواريري،': u'الْقَوَارِيرِيَّ،', #2
u'القواريري،': u'الْقَوَارِيرِيِّ،', #2
u'القواريرى': u'الْقَوَارِيرِىَّ', #2
u'القواريرى': u'الْقَوَارِيرِىِّ', #25
u'القواريري': u'الْقَوَارِيرِيَّ', #4
u'القواريري': u'الْقَوَارِيرِيِّ', #5
u'القواريري': u'الْقَوَارِيرِيُّ', #67
u'القواريرى': u'الْقَوَارِيرِىُّ', #76
u'القواريري،': u'القواريري،', #9
u'القواريري،': u'الْقَوَارِيرِيُّ،', #91
u'القواس': u'الْقَوَّاسِ', #2
u'القواس،': u'الْقَوَّاسُ،', #26
u'القواس،': u'الْقَوَّاسِ،', #5
u'القواس': u'الْقَوَّاسُ', #6
u'القواسة': u'الْقَوَّاسَةُ', #1
u'القواصة': u'الْقَوَّاصَةُ', #1
u'القواضبSشعر': u'الْقَوَاضِبِSشِعْرُ', #1
u'القواقل': u'الْقَوَاقِلِ', #1
u'القواقل،': u'الْقَوَاقِلِ،', #1
u'القواقل': u'الْقَوَاقِلَ', #2
u'القواقل': u'الْقَوَاقِلُ', #8
u'القواقلة': u'الْقَوَاقِلَةِ', #1
u'القوامر': u'الْقَوَّامِرِ', #1
u'القوانس': u'الْقَوَانِسُ', #2
u'القوانس': u'الْقَوَانِسِ', #4
u'القوانص': u'الْقَوَانِصِ', #1
u'القوب': u'الْقُوبِ', #1
u'القوبا': u'الْقُوبَا', #2
u'القوجحصاري': u'القوجحصاري', #1
u'القوز': u'الْقَوْزُ', #1
u'القوز': u'الْقَوْزِ', #1
u'القوسجي': u'الْقَوْسَجِيُّ', #1
u'القوشجي': u'الْقَوْشَجِيُّ', #1
u'القوصرة': u'الْقَوْصَرَّةُ', #14
u'القوصرة': u'الْقَوْصَرَّةِ', #15
u'القوصرة': u'الْقَوْصَرَةَ', #2
u'القوصرة': u'الْقَوْصَرَةُ', #3
u'القوصرة': u'الْقَوْصَرَّةَ', #5
u'القوصرة': u'الْقَوْصَرَةِ', #7
u'القوصي': u'الْقُوصِيِّ', #1
u'القوقل': u'الْقَوْقَلَ', #1
u'القوقلة': u'الْقَوْقَلَةُ', #2
u'القوقلي': u'الْقَوْقَلِيّ', #4
u'القولا': u'الْقَوْلَا', #1
u'القولنج': u'الْقُولَنْج', #1
u'القولنج': u'الْقُولُنْجِ', #1
u'القولنج': u'الْقُولَنْجِ', #12
u'القولنج': u'الْقُولَنْجُ', #4
u'القولنج': u'الْقُولَنْجَ', #8
u'القولوالوجه': u'الْقَوْلِوَالْوَجْهُ', #1
u'القومسي،': u'الْقُومَسِيُّ،', #1
u'القومسي،': u'الْقُومِسِيُّ،', #1
u'القومسي': u'الْقُومِسِيُّ', #4
u'القومسى': u'الْقُومِسِىُّ', #5
u'القوميجتمعون': u'الْقَوْمُيَجْتَمِعُونَ', #1
u'القونوي': u'الْقُونَويُّ', #1
u'القونوي': u'الْقُوَنِويِّ', #1
u'القونوي': u'الْقُونَوِيِّ', #21
u'القونوي': u'الْقُونَوِيَّ', #5
u'القونوي': u'الْقُونَوِيُّ', #64
u'القوهستاني،': u'الْقُوهُسْتَانِيِّ،', #1
u'القوهستاني،': u'الْقُوهُسْتَانِيُّ،', #2
u'القوهي': u'الْقُوهِيُّ', #1
u'القوهي': u'الْقُوهِيِّ', #16
u'القوهية': u'الْقُوهِيَّةِ', #2
u'القويسني': u'الْقُوَيْسِنِيَّ', #1
u'القويسني': u'الْقُوَيْسِنِيُّ', #14
u'القويسني': u'الْقُوَيْسَنِيُّ', #2
u'القويسني': u'الْقُوَيْسَنِيِّ', #2
u'القويسني': u'الْقُوَيْسِنِيِّ', #6
u'القويلة': u'الْقُوَيْلَةِ', #1
u'القىء': u'الْقَىْءَ', #1
u'القىء': u'الْقَىْءِ', #2
u'القىء': u'الْقَىْءُ', #9
u'القئول': u'القئول', #1
u'القياتة': u'الْقَيَاتَةِ', #1
u'القياتي': u'الْقَيَاتِيُّ', #1
u'القياسات': u'الْقِيَاسَاتُ', #2
u'القياسات': u'الْقِيَاسَاتِ', #3
u'القياسالذي': u'الْقِيَاسُالَّذِي', #1
u'القياسون': u'الْقَيَّاسُونَ', #3
u'القياطين': u'القياطين', #1
u'القياما': u'الْقِيَامَا', #1
u'القيامةقوله': u'الْقِيَامَةِقَوْلُهُ', #1
u'القيامةوالوجه': u'الْقِيَامَةِوَالْوَجْهُ', #2
u'القيامةوروي': u'الْقِيَامَةِوَرُوِيَ', #2
u'القيامه،': u'القيامه،', #1
u'القيامه': u'الْقِيَامَهْ', #1
u'القيت': u'القيت', #1
u'القيجاطي': u'الْقَيْجَاطِيُّ', #1
u'القير': u'الْقَيْرِ', #1
u'القير': u'الْقِيرِ', #21
u'القير': u'الْقِيرَ', #4
u'القير': u'الْقِيرُ', #9
u'القيرا': u'الْقِيرَا', #1
u'القيساري': u'الْقِيسَارِيُّ', #1
u'القيساري،': u'الْقَيسَارِيُّ،', #1
u'القيساري،': u'الْقِيسَارِيُّ،', #1
u'القيساري': u'الْقَيْسَارِيُّ', #13
u'القيساري،': u'الْقَيْسَارِيُّ،', #8
u'القيسراني،': u'الْقَيْسَرَانِيِّ،', #2
u'القيسراني،': u'الْقَيْسَرَانِيُّ،', #4
u'القيسري': u'الْقَيْسَرِيَّ', #1
u'القيسي،': u'القَيْسي،', #1
u'القيسي': u'الْقَيْسِيَّ', #1
u'القيسى': u'القيسى', #1
u'القيسى': u'الْقَيْسِىَّ', #1
u'القيسي،': u'الْقَيْسِيُّ،', #10
u'القيسي': u'الْقَيْسِيِّ', #15
u'القيسي': u'الْقَيْسِيّ', #2
u'القيسى': u'الْقَيْسِىُّ', #22
u'القيسي': u'القيسي', #3
u'القيسي،': u'القيسي،', #3
u'القيسي': u'الْقَيْسِيُّ', #31
u'القيسي،': u'الْقَيْسِيِّ،', #4
u'القيسى': u'الْقَيْسِىِّ', #5
u'القيسية': u'القيسية', #1
u'القيسية': u'القَيْسيّة', #1
u'القيسية': u'الْقَيْسِيَّةُ', #1
u'القيسية': u'الْقَيْسِيَّةِ', #1
u'القيسين': u'الْقَيْسَيْنِ', #1
u'القيسيين': u'الْقَيْسِيِّينَ', #2
u'القيشة': u'الْقِيشَةِ', #1
u'القيصرى': u'الْقَيْصَرَى', #1
u'القيصوم': u'الْقَيْصُوم', #1
u'القيطون': u'الْقَيْطُونِ', #1
u'القيعة': u'الْقِيعَةِ', #1
u'القيفال': u'الْقِيفَالِ', #2
u'القيفال': u'الْقِيفَالُ', #4
u'القيقاء': u'الْقِيقَاءُ', #1
u'القيقان،': u'القيِقان،', #1
u'القيقان': u'الْقَيْقَانَ', #2
u'القيقان،': u'الْقَيْقَانَ،', #2
u'القيقب': u'الْقَيْقَبِ', #1
u'القيلة': u'الْقَيْلَةَ', #1
u'القيمه': u'الْقِيمَهْ', #3
u'القينقاعي': u'الْقَيْنُقَاعِيِّ', #1
u'القينقاعي،': u'الْقَيْنُقَاعِيِّ،', #1
u'القينقاعي': u'الْقَيْنُقَاعِيّ', #2
u'القينى': u'الْقَينِىُّ', #1
u'القيولة': u'الْقُيُولَةِ', #1
u'آلكا': u'آلِكَا', #1
u'الكابلي،': u'الكَابِلِيُّ،', #1
u'الكابلي،': u'الْكَابِلِيِّ،', #1
u'الكابلي،': u'الْكَابُلِيِّ،', #2
u'الكابلي': u'الْكَابِلِي', #3
u'الكاتبونوروي': u'الْكَاتِبُونَوَرُوِيَ', #1
u'الكاتبينا': u'الْكَاتِبِينَا', #2
u'الكاتي': u'الْكَاتِي', #2
u'الكاتية': u'الْكَاتِيَّةِ', #1
u'الكادى': u'الْكَادِىُّ', #1
u'الكاذي': u'الْكَاذِي', #10
u'الكاذي': u'الْكَاذِيَ', #3
u'الكارزى': u'الَكَارِزِىُّ', #1
u'الكارزى': u'الْكَارِزِىُّ', #104
u'الكازروني': u'الْكَازَرُونِي', #1
u'الكازروني': u'الْكَازَرُونِيّ', #1
u'الكازروني': u'الْكَازَرُونِيُّ', #22
u'الكازروني': u'الْكَازَرُونِيِّ', #24
u'الكازري،': u'الْكَازِرِيُّ،', #1
u'الكازونية': u'الْكَازُونِيَّة', #1
u'الكاس': u'الْكَاسِّ', #1
u'الكاس': u'الْكَاسِ', #2
u'الكاساني': u'الْكَاسَانِيِّ', #1
u'الكاشانة': u'الْكَاشَانَةُ', #1
u'الكاشاني': u'الْكَاشَانِيِّ', #1
u'الكاشاني': u'الْكَاشَانِيُّ', #3
u'الكاشحينا': u'الْكَاشِحِينَا', #1
u'الكاغدة': u'الْكَاغَدَةِ', #1
u'الكاغدة': u'الْكَاغَدَةَ', #2
u'الكاغدة': u'الْكَاغِدَةُ', #2
u'الكاغضة': u'الْكَاغِضَةِ', #1
u'الكافره': u'الْكَافِرَهْ', #1
u'الكافرينا': u'الْكَافِرِينَا', #2
u'الكافيجي': u'الْكَافِيجِيَّ', #2
u'الكافيجي': u'الْكَافِيجِيِّ', #2
u'الكافيجي': u'الْكَافِيجِيُّ', #6
u'الكاكي': u'الْكَاكِيُّ', #144
u'الكاكي': u'الْكَاكِيِّ', #16
u'الكاكي': u'الْكَاكِيَّ', #7
u'الكالئ': u'الْكَالِئِ', #132
u'الكالئ': u'الْكَالِئُ', #22
u'الكالئ': u'الْكَالِئ', #4
u'الكالئ': u'الْكَالِئَ', #7
u'الكاملي،': u'الْكَامِلِيُّ،', #1
u'الكاملي': u'الْكَامِلِيُّ', #2
u'الكأنية': u'الْكَأَنِيَّةِ', #1
u'الكاهلى': u'الْكَاهِلِىُّ', #3
u'الكاهلى': u'الْكَاهِلِىِّ', #3
u'الكاهي': u'الكاهي', #1
u'الكائب': u'الْكَائِبُ', #1
u'الكائنية': u'الْكَائِنِيَّةِ', #1
u'الكبا': u'الْكِبَا', #1
u'الكباء': u'الْكِبَاءُ', #1
u'الكباث': u'الكباث', #1
u'الكباث،': u'الْكَبَاثِ،', #1
u'الكباث': u'الْكَبَاثُ', #2
u'الكباث': u'الْكَبَاثِ', #2
u'الكباث': u'الْكَبَاثَ', #3
u'الكباث،': u'الْكَبَاثَ،', #4
u'الكبارا': u'الْكِبَارَا', #1
u'الكباسة': u'الْكِبَاسَةَ', #1
u'الكباسة': u'الْكِبَاسَةُ', #5
u'الكباسة': u'الْكِبَاسَةِ', #6
u'الكباشية': u'الْكِبَاشِيَّةُ', #1
u'الكبائس': u'الْكَبَائِسُ', #1
u'الكبدة': u'الْكِبْدَةَ', #1
u'الكبرا': u'الْكِبَرَا', #1
u'الكبرتك': u'الْكَبَرْتَكَ', #1
u'الكبكادي': u'الْكَبْكَادِيُّ', #1
u'الكبلا': u'الْكَبْلَا', #2
u'الكبيرةشك': u'الْكَبِيرَةَشَكَّ', #1
u'الكبيس': u'الْكَبِيسَ', #1
u'الكبيس': u'الْكَبِيسُ', #1
u'الكبيس': u'الْكَبِيسِ', #10
u'الكتا': u'الْكِتَا', #1
u'الكتابالخط': u'الْكِتَابُالْخَطُّ', #1
u'الكتابالقرآن': u'الْكِتَابُالْقُرْآنُ', #1
u'الكتابالوجه': u'الْكِتَابِالْوَجْهُ', #1
u'الكتابأنها': u'الْكِتَابَأَنَّهَا', #1
u'الكتابةفي': u'الْكِتَابَةُفِي', #1
u'الكتابه': u'الْكِتَابَهْ', #2
u'الكتانين': u'الْكَتَّانِينَ', #1
u'الكتبا': u'الْكُتُبَا', #2
u'الكتبالوجه': u'الْكُتُبِالْوَجْهُ', #1
u'الكتبتين': u'الْكِتْبَتَيْنِ', #1
u'الكتبخانات': u'الْكُتُبْخَانَاتِ', #1
u'الكتخدائية': u'الكتخدائية', #1
u'الكتد،': u'الْكَتَدِ،', #1
u'الكتد': u'الْكَتَدُ', #4
u'الكتد': u'الْكَتَدِ', #4
u'الكتناني': u'الْكَتْنَانِيِّ', #1
u'الكتناني': u'الْكَتْنَانِيُّ', #4
u'الكتي': u'الْكَتِي', #1
u'الكتيـ': u'الْكَتِيـ', #1
u'الكتيفة': u'الْكَتِيفَةِ', #3
u'الكثبة': u'الْكُثْبَةِ', #1
u'الكثبة،': u'الْكُثْبَةُ،', #1
u'الكثبة،': u'الْكُثْبَةَ،', #2
u'الكثبة': u'الْكُثْبَةُ', #3
u'الكثبة': u'الكثبة', #5
u'الكثبة': u'الْكُثْبَةَ', #8
u'الكثكث': u'الْكَثْكَثُ', #3
u'الكثيبة': u'الكثيبة', #1
u'الكثيره': u'الْكَثِيرَهْ', #1
u'الكثيروروي': u'الْكَثِيرُوَرُوِيَ', #1
u'الكجى': u'الْكَجِّىُّ', #13
u'الكجي': u'الْكَجِّيُّ', #3
u'الكجي': u'الْكَجِّيِّ', #3
u'الكجي،': u'الْكَجِّيُّ،', #5
u'الكحال': u'الْكَحَّالَ', #2
u'الكحال': u'الْكَحَّالُ', #39
u'الكحال': u'الْكَحَّالِ', #45
u'الكحالة': u'الْكَحَّالَةِ', #3
u'الكحالون': u'الْكَحَّالُونَ', #2
u'الكحالين': u'الْكَحَّالِينَ', #1
u'الكحجاني': u'الكحجاني', #1
u'الكداء': u'الْكَدَاءُ', #1
u'الكداء': u'الْكَدَاءَ', #3
u'الكدان،': u'الكُدَانَ،', #1
u'الكدش': u'الْكَدْشِ', #1
u'الكدك': u'الْكَدَكِ', #5
u'الكدوح': u'الْكُدُوح', #1
u'الكدورات': u'الْكُدُورَاتِ', #7
u'الكدورة': u'الْكُدُورَةَ', #1
u'الكدورة': u'الْكُدُورَةِ', #8
u'الكدوف': u'الْكَدُوفُ', #1
u'الكدوف': u'الْكَدُوفِ', #2
u'الكديد': u'الْكَدِيد', #1
u'الكديد': u'الْكَدِيدُ', #1
u'الكديد': u'الْكُدَيْدَ', #1
u'الكديد،': u'الْكُدَيْدِ،', #1
u'الكديد': u'الْكَدِيدَ', #27
u'الكديد': u'الْكَدِيدِ', #5
u'الكديس': u'الْكَدِيسِ', #2
u'الكديمي،': u'الْكُدَيْمِيُّ،', #1
u'الكديمي': u'الْكُدَيْمِيِّ', #2
u'الكديمى': u'الْكُدَيْمِىِّ', #3
u'الكديمى': u'الْكُدَيْمِىُّ', #8
u'الكدين': u'الْكَدّيْنِ', #1
u'الكديور': u'الكديور', #1
u'الكديورين': u'الكديورين', #1
u'ألكذا': u'أَلِكَذَا', #1
u'الكذا': u'الْكَذَا', #5
u'الكذان': u'الكَذَّان', #1
u'الكذان': u'الْكَذَّانُ', #2
u'الكذان': u'الْكَذَّانِ', #2
u'الكذبوروى': u'الْكَذِبَوَرُوِِىِ', #1
u'الكذيبة': u'الْكُذَيْبَةُ', #2
u'الكرا': u'الْكِرَا', #18
u'الكرابة': u'الْكُرَابَةِ', #1
u'الكرابيس': u'الْكَرَابِيسَ', #13
u'الكرابيس': u'الْكَرَابِيسُ', #2
u'الكرابيس': u'الْكَرَابِيسِ', #21
u'الكرابيسى': u'الْكَرَابِيسِىَّ', #1
u'الكرابيسى': u'الْكَرَابِيسِىِّ', #1
u'الكرابيسى': u'الْكَرَابِيسِىُّ', #18
u'الكرابيسي،': u'الْكَرَابِيسِيُّ،', #3
u'الكرابيسي': u'الْكَرَابِيسِيُّ', #40
u'الكرابيسي': u'الْكَرَابِيسِيِّ', #65
u'الكراديس،': u'الكراديس،', #1
u'الكراديس': u'الْكَرَادِيسِ', #10
u'الكراديس،': u'الْكَرَادِيسِ،', #2
u'الكراديس': u'الكراديس', #4
u'الكرازين': u'الْكَرَازِينَ', #1
u'الكرازين': u'الْكَرَازِينِ', #1
u'الكراسم': u'الْكَرَاسِمُ', #1
u'الكراما': u'الْكِرَامَا', #1
u'الكران': u'الْكُرَّانِ', #9
u'الكراويا': u'الْكَرَاوْيَا', #2
u'الكراويا': u'الكراويا', #3
u'الكراييس': u'الكراييس', #1
u'الكراييس': u'الْكَرَايِيس', #3
u'الكربا': u'الْكَرَبَا', #1
u'الكربات': u'الْكُرُبَاتِ', #2
u'الكرباس': u'الْكِرْبَاسِ', #120
u'الكرباس': u'الْكِرْبَاسَ', #14
u'الكرباس': u'الْكِرْبَاسُ', #18
u'الكربزاني،': u'الْكُرْبُزَانِيُّ،', #1
u'الكربزاني،': u'الْكُرْبُزَانِيِّ،', #2
u'الكرج': u'الْكَرَجُ', #1
u'الكرجة': u'الْكِرْجَةَ', #1
u'الكرجي': u'الْكَرَجِيُّ', #1
u'الكرخ': u'الْكَرْخِ', #1
u'الكرخانة': u'الْكَرْخَانَةِ', #1
u'الكرخي': u'الكرخي', #1
u'الكرخي،': u'الْكَرْخِيُّ،', #1
u'الكرخى': u'الْكَرْخِىُّ', #1
u'الكرخي': u'الْكَرْخِيُّ', #1202
u'الكرخي': u'الْكَرْخِيَّ', #24
u'الكرخي': u'الْكَرْخِيّ', #28
u'الكرخي': u'الْكَرْخِيِّ', #986
u'الكرد': u'الْكُرْدِ', #2
u'الكردار': u'الْكِرْدَارُ', #1
u'الكردار': u'الْكِرْدَارِ', #10
u'الكردار': u'الكردار', #9
u'الكردارات': u'الكردارات', #1
u'الكردارات': u'الْكِرْدَارَاتِ', #1
u'الكردة': u'الكردة', #1
u'الكردة': u'الْكُرْدَةَ', #1
u'الكردة': u'الْكُرْدَةِ', #1
u'الكردجين': u'الكردجين', #1
u'الكردري': u'الْكَرْدَرِيُّ', #12
u'الكردري': u'الْكَرْدَرِيِّ', #42
u'الكردوس': u'الْكُرْدُوسِ', #1
u'الكردى': u'الْكُرْدِىُّ', #1
u'الكرزن': u'الْكَرْزَنَ', #2
u'الكرس': u'الْكِرْسِ', #1
u'الكرستون': u'الْكُرُسْتُونُ', #2
u'الكرسف': u'الكرسف', #1
u'الكرسف': u'الْكُرْسُفُ', #21
u'الكرسف': u'الْكُرْسُفَ', #23
u'الكرسف': u'الْكُرْسُفِ', #25
u'الكرسفة': u'الْكُرْسُفَةَ', #1
u'الكرسنة': u'الْكِرْسِنَّةَ', #2
u'الكرسنة': u'الْكِرْسِنَّةُ', #5
u'الكرسنة': u'الْكِرْسِنَّةِ', #5
u'الكرسوع': u'الْكُرْسُوعُ', #10
u'الكرسوع': u'الْكُرْسُوعَ', #2
u'الكرسوع': u'الْكُرْسُوعِ', #2
u'الكرسى': u'الْكُرْسِىِّ', #2
u'الكرشة': u'الْكَرِشَةُ', #1
u'الكرشة': u'الْكِرْشَةُ', #1
u'الكركة': u'الْكُرْكَةُ', #1
u'الكركم': u'الْكُرْكُمَ', #2
u'الكركم': u'الْكُرْكُمُ', #5
u'الكركم': u'الْكُرْكُمِ', #6
u'الكركور،': u'الْكُرْكُورَ،', #1
u'الكركى': u'الْكُرْكِىِّ', #1
u'الكرماني،': u'الْكَرْمَانِيُّ،', #1
u'الكرماني،': u'الْكِرْمَانِيِّ،', #1
u'الكرمانى': u'الْكِرْمَانِىُّ', #11
u'الكرماني': u'الْكَرْمَانِيِّ', #155
u'الكرمانى': u'الْكِرْمَانِىِّ', #2
u'الكرماني': u'الْكَرْمَانِيُّ', #253
u'الكرماني': u'الْكِرْمَانِيُّ', #3
u'الكرماني': u'الْكَرْمَانِيّ', #5
u'الكرماني،': u'الْكِرْمَانِيُّ،', #6
u'الكرماني': u'الْكَرْمَانِيَّ', #9
u'الكرمسوت': u'الْكَرْمَسُوتِ', #1
u'الكرميد': u'الكرميد', #1
u'الكرميني': u'الْكَرْمِينِيُّ', #1
u'الكرميني،': u'الْكَرْمِينِيِّ،', #1
u'الكرميني': u'الْكَرْمِينِيِّ', #2
u'الكرناس': u'الْكِرْنَاس', #1
u'الكرناف': u'الْكُرْنَافُ', #1
u'الكرناف': u'الْكِرْنَافِ', #1
u'الكرنيشي': u'الْكَرْنِيشِيِّ', #1
u'الكروبا': u'الْكُرُوبَا', #1
u'الكروبيون': u'الكروبيون', #1
u'الكروبيون': u'الْكَرُوبِيُّونَ', #1
u'الكروبيين': u'الْكَرُوبِيِّينَ', #2
u'الكروبيين': u'الْكُرُوبِيِّينَ', #2
u'الكروخي': u'الْكَرُوخِيُّ', #3
u'الكروس،': u'الكَرَوَّسِ،', #1
u'الكروس،': u'الْكَرَوَّسِ،', #1
u'الكروس،': u'الْكَرْوَسِ،', #1
u'الكروس': u'الكَرَوَّسِ', #2
u'الكروس': u'الْكَرَوَّسِ', #3
u'الكرياس': u'الْكِرْيَاسُ', #1
u'الكرياس': u'الْكِرْيَاسِ', #1
u'الكريز': u'الْكَرِيزِ', #1
u'الكريزي': u'الْكُرَيْزِيُّ', #3
u'الكرين': u'الْكُرَّيْنِ', #15
u'الكريون': u'الْكِرْيَوْن', #1
u'الكزبر': u'الْكُزْبَرَ', #1
u'الكزبر': u'الكزبر', #2
u'الكزبر': u'الْكُزْبَرُ', #2
u'الكزبراني،': u'الْكُزْبُرَانِيِّ،', #1
u'الكزبرانى': u'الْكُزْبُرَانِىُّ', #1
u'الكزبراني': u'الْكُزْبُرَانِيُّ', #2
u'الكزبراني،': u'الْكُزْبُرَانِيُّ،', #9
u'الكسالة': u'الكسالة', #1
u'الكسالة': u'الْكَسَالَةِ', #1
u'الكساوي': u'الْكَسَاوِي', #3
u'الكسائى': u'الْكَسَّائِىُّ', #1
u'الكسائى': u'الْكِسَائِىِّ', #2
u'الكسائى': u'الْكِسَائِىُّ', #7
u'الكسبان': u'الْكَسْبَانِ', #7
u'الكسبين': u'الْكَسْبَيْنِ', #39
u'الكست': u'الكست', #1
u'الكست': u'الْكُسْت', #1
u'الكست': u'الْكُسْتُ', #2
u'الكست': u'الْكُسْتَ', #4
u'الكستلي': u'الْكَسْتَلِيِّ', #1
u'الكستلي': u'الْكَسْتَلِيُّ', #4
u'الكستيج': u'الْكُسْتِيجِ', #1
u'الكستيج': u'الْكُسْتِيجُ', #2
u'الكستيج': u'الْكُسْتِيجَ', #5
u'الكستيجات': u'الْكُسْتِيجَاتِ', #2
u'الكسدانيين': u'الْكَسَدَانِيِّينَ', #1
u'الكسع': u'الْكَسْعِ', #1
u'الكسعة': u'الْكَسْعَةَ', #1
u'الكسعة': u'الْكَسْعَةِ', #1
u'الكسعة': u'الْكُسْعَةُ', #4
u'الكسعة': u'الْكُسْعَةِ', #6
u'الكسفرة': u'الْكُسْفُرَةِ', #2
u'الكسفرة': u'الْكُسْفُرَةُ', #3
u'الكسكري': u'الْكَسْكَرِيَّ', #1
u'الكسكري': u'الْكَسْكَرِيُّ', #3
u'الكسكري': u'الْكَسْكَرِيِّ', #3
u'الكسوب': u'الْكُسُوبُ', #1
u'الكسوب': u'الْكَسُوبِ', #19
u'الكسوب': u'الْكُسُوبِ', #4
u'الكسوب': u'الْكَسُوبُ', #5
u'الكسوب': u'الْكَسُوبَ', #7
u'الكش': u'الْكُشِّ', #2
u'الكشاني': u'الْكَشَانِيُّ', #1
u'الكشانى': u'الْكُشَانِىُّ', #1
u'الكشاني': u'الْكَشَانِيِّ', #3
u'الكشخان': u'الْكَشْخَانُ', #2
u'الكشخان': u'الْكَشْخَانِ', #2
u'الكشفين': u'الْكَشْفَيْنِ', #2
u'الكشكاك': u'الكشكاك', #2
u'الكشميهنى': u'الْكُشْمِيهَنِىُّ', #2
u'الكشميهني': u'الْكُشْمِيهَنِيُّ', #3
u'الكشوثا': u'الكشوثا', #1
u'الكشوثاء': u'الْكَشُوثَاءُ', #1
u'الكشوري،': u'الكَشْوَرِيُّ،', #1
u'الكشي': u'الْكَشِيّ', #1
u'الكشي': u'الْكَشِّيِّ', #2
u'الكشي': u'الْكَشّيّ', #7
u'الكشي': u'الْكَشِّيُّ', #8
u'الكظة': u'الْكِظَّةِ', #1
u'الكظيظ': u'الكظيظ', #1
u'الكعام': u'الْكِعَامِ', #1
u'الكعبةحتى': u'الْكَعْبَةِحَتَّى', #1
u'الكعبةفيقتضي': u'الْكَعْبَةِفَيَقْتَضِي', #1
u'الكعبةقال': u'الْكَعْبَةِقَالَ', #1
u'الكعبةوروي': u'الْكَعْبَةِوَرُوِيَ', #1
u'الكعبةيييي': u'الْكَعْبَةِيييي', #1
u'الكعبه': u'الْكَعْبَهْ', #3
u'الكعبى': u'الْكَعْبِىَّ', #1
u'الكعبى': u'الْكَعْبِىُّ', #68
u'الكعبى': u'الْكَعْبِىِّ', #7
u'الكعس': u'الْكَعْسِ', #1
u'الكعنبي': u'الْكَعْنَبِيِّ', #1
u'الكفات': u'الْكِفَاتُ', #1
u'الكفاله': u'الْكَفَالَهْ', #3
u'الكفائف': u'الْكَفَائِفُ', #1
u'الكفايه': u'الْكِفَايَهْ', #1
u'الكفت': u'الْكَفْتُ', #1
u'الكفت': u'الْكَفْتِ', #1
u'الكفرتاثي': u'الْكَفْرِتَاثِيُّ', #1
u'الكفرثي،': u'الْكَفْرَثِيُّ،', #1
u'الكفرقوله': u'الْكُفْرِقَوْلُهُ', #1
u'الكفره': u'الْكَفَرَهْ', #2
u'الكفروروي': u'الْكُفْرُوَرُوِيَ', #1
u'الكفرى': u'الْكُفَرَّى', #1
u'الكفرى': u'الْكُفُرَّى', #32
u'الكفريي،': u'الْكَفَرْيِيُّ،', #1
u'الكفوري': u'الْكَفُورِيُّ', #1
u'الكفوري': u'الْكَفُورِيِّ', #1
u'الكفوف': u'الْكُفُوفِ', #1
u'الكفوف': u'الْكُفُوفُ', #2
u'الكفوي': u'الْكَفَوِيُّ', #21
u'الكفيء': u'الْكَفِيءُ', #1
u'الكفيني': u'الْكُفِينِيُّ', #2
u'الكلا': u'الْكُلَّا', #1
u'الكلا': u'الْكَلاَ', #3
u'الكلا': u'الْكَلَا', #4
u'الكلاءة': u'الْكِلَاءَةُ', #1
u'الكلاءة': u'الْكِلَاءَةِ', #10
u'الكلاءة': u'الْكِلَاءَةَ', #5
u'الكلاباذى': u'الْكَلاَبَاذِىَّ', #1
u'الكلاباذي': u'الْكَلَابَاذِيِّ', #5
u'الكلاباذي': u'الْكَلَابَاذِيُّ', #7
u'الكلابى': u'الْكِلاَبِىُّ', #17
u'الكلابى': u'الْكِلاَبِىَّ', #4
u'الكلابى': u'الْكِلاَبِىِّ', #4
u'الكلاع': u'الكلاعِ', #1
u'الكلاع،': u'الكلاع،', #1
u'الكلاع،': u'الكَلاع،', #1
u'الكلاع': u'الْكَلاَعِ', #1
u'الكلاع': u'الكَلاع', #2
u'الكلاع': u'الكلاع', #3
u'الكلاع،': u'الْكَلاعِ،', #3
u'الكلاع': u'الْكُلَاعِ', #5
u'الكلاع،': u'الْكَلَاعِ،', #6
u'الكلاع': u'الْكَلَاعِ', #7
u'الكلاع': u'الْكَلاعِ', #8
u'الكلاعي،': u'الكلاعي،', #1
u'الكلاعي': u'الكَلَاعِيُّ', #1
u'الكلاعي': u'الْكَلَاعِيّ', #1
u'الكلاعي': u'الْكُلَاعِيِّ', #1
u'الكلاعي،': u'الْكَلَاعِيَّ،', #1
u'الكلاعي،': u'الْكَلَاعِيُّ،', #1
u'الكلاعى': u'الْكُلاَعِىُّ', #1
u'الكلاعى': u'الْكِلاَعِىُّ', #1
u'الكلاعي': u'الْكَلَاعِيُّ', #10
u'الكلاعي،': u'الْكَلاعِيُّ،', #13
u'الكلاعي،': u'الْكُلاعِيِّ،', #2
u'الكلاعي': u'الْكَلَاعِيَّ', #2
u'الكلاعي': u'الْكُلَاعِيُّ', #2
u'الكلاعى': u'الْكَلاَعِىَّ', #2
u'الكلاعى': u'الْكُلاَعِىِّ', #2
u'الكلاعي': u'الْكَلَاعِيِّ', #20
u'الكلاعي': u'الْكُلَاعِيّ', #3
u'الكلاعى': u'الْكَلاَعِىُّ', #3
u'الكلاعى': u'الْكَلاَعِىِّ', #4
u'الكلاعي': u'الْكَلاعِيِّ', #6
u'الكلاعي،': u'الْكَلاعِيِّ،', #8
u'الكلاعي': u'الْكَلاعِيُّ', #9
u'الكلاعيين': u'الْكُلَاعِيِّينَ', #1
u'الكلاعيين': u'الْكَلَاعِيِّينَ', #2
u'الكلاف': u'الْكُلَاف', #1
u'الكلاله': u'الْكَلَالَهْ', #1
u'الكلاما': u'الْكَلامَا', #1
u'الكلاما': u'الْكَلَامَا', #2
u'الكلامات': u'الْكَلَامَاتُ', #1
u'الكلامان': u'الْكَلَامَانِ', #87
u'الكلاموروى': u'الْكَلامِوَرُوِِىِ', #2
u'الكلامين': u'الْكَلَامَيْنِ', #272
u'الكلائي،': u'الْكَلائِيُّ،', #1
u'الكلائي': u'الْكَلَّائِيِّ', #1
u'الكلائي': u'الْكِلَائِيّ', #1
u'الكلبى': u'الْكَلْبِىَّ', #1
u'الكلبى': u'الْكَلْبِىِّ', #18
u'الكلبى': u'الْكَلْبِىُّ', #25
u'الكلتة': u'الْكَلْتَة', #1
u'الكلح': u'الْكَلَحَ', #1
u'الكلفى': u'الكُلَفِىِّ', #1
u'الكلكال': u'الْكَلْكَالَ', #1
u'الكلكال': u'الْكَلْكَالِ', #1
u'الكلكل': u'الْكَلْكَلَ', #1
u'الكلكل': u'الْكَلْكَلِ', #2
u'الكلمه': u'الْكَلِمَهْ', #3
u'الكلنبوي': u'الْكَلَنْبَوِيُّ', #1
u'الكلنبوي': u'الْكَلَنْبَوِيِّ', #3
u'الكلنة': u'الكلنة', #1
u'الكلوب': u'الْكَلُّوبُ', #1
u'الكلوتة': u'الكلوتة', #1
u'الكلوثات': u'الْكُلُوثَاتُ', #1
u'الكلوثات': u'الْكُلُوثَاتِ', #2
u'الكلوذاني': u'الْكَلْوَذَانِيُّ', #1
u'الكلوذاني،': u'الْكَلْوَذَانِيُّ،', #1
u'الكلوذاني': u'الْكَلْوَذَانِيِّ', #2
u'الكلونات': u'الْكُلُونَاتِ', #1
u'الكليبة': u'الْكُلَيْبَةِ', #2
u'الكليني،': u'الكليني،', #1
u'الكليني،': u'الْكُلِينِيُّ،', #1
u'الكليني،': u'الْكُلَيْنِيُّ،', #1
u'الكلينى': u'الْكُلِينِىُّ', #1
u'الكمآة': u'الْكَمَآةُ', #1
u'الكماة': u'الْكُمَاةِ', #20
u'الكماة': u'الْكُمَاةُ', #8
u'الكماة': u'الْكُمَاةَ', #9
u'الكماج': u'الكماج', #1
u'الكماج': u'الْكَمَاجُ', #2
u'الكماج': u'الْكَمَاجِ', #2
u'الكماري': u'الْكَمَارِيُّ', #3
u'الكمائن': u'الْكَمَائِنِ', #1
u'الكمر': u'الْكَمَرُ', #1
u'الكمران': u'الكمران', #1
u'الكمرة': u'الْكَمَرَةَ', #1
u'الكمرة': u'الْكَمَرَةِ', #10
u'الكمرة': u'الْكَمَرَةُ', #9
u'الكمرك': u'الكمرك', #3
u'الكمشة': u'الكمشة', #1
u'الكمشة؟،': u'الْكَمْشَةُ؟،', #1
u'الكمكام': u'الْكِمْكَامُ', #1
u'الكمل': u'الْكُمَّلِ', #13
u'الكمل': u'الْكُمَّلُ', #3
u'الكمى': u'الْكَمَى', #1
u'الكميد': u'الْكَمِيدُ', #1
u'الكميع': u'الْكَمِيعِ', #2
u'الكمينة': u'الْكَمِينَةِ', #1
u'الكناتين': u'الْكِنَاتَيْنِ', #1
u'الكنازون': u'الْكَنَّازُونَ', #1
u'الكنازين': u'الْكَنَّازِينَ', #4
u'الكناشات': u'الْكُنَّاشَاتِ', #1
u'الكناف': u'الْكَنَّافُ', #2
u'الكناف': u'الْكَنَّافِ', #2
u'الكنانى': u'الْكِنَانِىَّ', #1
u'الكنانى': u'الْكِنَانِىُّ', #15
u'الكنانى': u'الْكِنَانِىِّ', #4
u'الكنائي': u'الْكِنَائِيَّ', #1
u'الكنائي': u'الْكِنَائِيُّ', #2
u'الكنائي': u'الْكِنَائِيِّ', #4
u'الكنائية': u'الْكِنَائِيَّةَ', #2
u'الكنائية': u'الْكِنَائِيَّةِ', #2
u'الكنباني': u'الْكَنْبَانِيِّ', #1
u'الكنتي': u'الْكَنَّتَيْ', #1
u'الكنجفة': u'الْكَنْجَفَةُ', #1
u'الكنجفة': u'الكنجفة', #3
u'الكنح': u'الكنح', #2
u'الكنحفة': u'الْكُنْحُفَةُ', #1
u'الكندعي': u'الكندعي', #2
u'الكندوج': u'الْكُنْدُوجَ', #1
u'الكندوح': u'الْكَنْدُوحِ', #1
u'الكندى': u'الْكِنْدِىَّ', #11
u'الكندى': u'الْكِنْدِىِّ', #31
u'الكندى': u'الْكِنْدِىُّ', #39
u'الكنود': u'الكَنُود', #1
u'الكنود': u'الْكَنُودُ', #1
u'الكنود': u'الكنود', #2
u'الكنود،': u'الْكَنُودِ،', #7
u'الكنود': u'الْكَنُودِ', #8
u'الكنيفة': u'الْكَنِيفَةِ', #1
u'الكهبة': u'الْكُهْبَةِ', #1
u'الكهتلة': u'الكهتلة', #1
u'الكهتلة': u'الْكَهْتَلَةِ', #1
u'الكهتله،': u'الْكَهْتَلَهْ،', #1
u'الكهدل': u'الْكَهْدَلُ', #2
u'الكهر': u'الْكَهْر', #2
u'الكهلا': u'الْكَهْلَا', #2
u'الكهيلى': u'الْكُهَيْلِىُّ', #2
u'الكوادح': u'الكَوَادِح', #1
u'الكوادح': u'الْكَوَادِحْ', #1
u'الكوادن': u'الْكَوَادِنُ', #1
u'الكوادن': u'الْكَوَادِنِ', #6
u'الكوار': u'الْكِوَارُ', #1
u'الكوارات': u'الْكُوَّارَاتُ', #1
u'الكوارات': u'الْكِوَارَاتِ', #2
u'الكوارات': u'الْكُوَّارَاتِ', #3
u'الكوارة': u'الْكُوَّارَةَ', #1
u'الكوارة': u'الْكِوَارَةِ', #17
u'الكوارة': u'الْكُوَارَةِ', #2
u'الكوارة': u'الْكُوَّارَةُ', #2
u'الكوارة': u'الْكُوَّارَةِ', #30
u'الكوارع': u'الْكَوَارِعَ', #1
u'الكوارع': u'الْكَوَارِعِ', #3
u'الكواز': u'الْكَوَّازُ', #1
u'الكواز': u'الْكَوَّازِ', #1
u'الكواشي': u'الكواشي', #1
u'الكواشي': u'الْكَوَاشِيَّ', #1
u'الكواشي': u'الْكَوَاشِيُّ', #1
u'الكواشي': u'الْكَوَاشِيِّ', #2
u'الكوافح': u'الكَوافِح', #1
u'الكوافح': u'الْكَوَافِحُ', #1
u'الكواكبي': u'الْكَوَاكِبِيَّ', #1
u'الكواكبي': u'الْكَوَاكِبِيِّ', #2
u'الكواكبي': u'الْكَوَاكِبِيُّ', #4
u'الكوالئ': u'الْكَوَالِئِ', #3
u'الكوبة؟': u'الْكُوبَةُ؟', #1
u'الكوبة': u'الْكُوبَةَ', #12
u'الكوبة': u'الْكُوبَةُ', #15
u'الكوبة': u'الْكُوبَةِ', #22
u'الكوت': u'الْكُوتِ', #1
u'الكوثات': u'الْكَوْثَاتِ', #1
u'الكودان': u'الكودان', #1
u'الكودن': u'الْكَوْدَنَ', #1
u'الكودين': u'الكودين', #1
u'الكوراني': u'الْكُورَانِيِّ', #17
u'الكوراني': u'الْكُورَانِيُّ', #29
u'الكوراني': u'الْكُورَانِيَّ', #5
u'الكورجة': u'الْكَوْرَجَةَ', #3
u'الكوسج،': u'الْكَوْسَجُ،', #1
u'الكوسج': u'الْكَوْسَجِ', #23
u'الكوسج': u'الْكَوْسَجَ', #3
u'الكوسج': u'الْكَوْسَجُ', #9
u'الكوش': u'الْكَوْشَ', #1
u'الكوشت': u'الكوشت', #1
u'الكوفه،': u'الكوفه،', #1
u'الكوفى،': u'الكوفى،', #1
u'الكوفى': u'الْكُوفِىَّ', #3
u'الكوفى': u'الْكُوفِىُّ', #79
u'الكوفى': u'الْكُوفِىِّ', #9
u'الكوكبى': u'الْكَوْكَبِىُّ', #1
u'الكوكيلوني': u'الْكُوكِيلُونِيُّ', #1
u'الكولان': u'الْكَوْلَانِ', #1
u'الكوم': u'الْكُومِ', #1
u'الكوم': u'الْكَوْم', #1
u'الكوم': u'الْكُوَمَ', #1
u'الكوم': u'الْكَوْمَ', #3
u'الكوم': u'الْكُومَ', #4
u'الكوم': u'الْكَوْمُ', #4
u'الكوم': u'الْكَوْمِ', #4
u'الكوماء': u'الْكَوْمَاءَ', #1
u'الكوماء': u'الْكَوْمَاءِ', #1
u'الكوماء': u'الْكَوْمَاءُ', #2
u'الكوماء،': u'الْكَوْمَاءَ،', #3
u'الكوهكيلوني': u'الكوهكيلوني', #36
u'الكوهيكلوني': u'الكوهيكلوني', #3
u'الكوهيكيلوني': u'الكوهيكيلوني', #2
u'الكويفر': u'الْكُوَيْفِرُ', #1
u'الكى': u'الْكَىَّ', #1
u'الكى': u'الْكَىُّ', #1
u'الكى': u'الْكَىِّ', #2
u'الكئود': u'الْكَئُودُ', #1
u'إلكيا': u'إِلْكِيَا', #18
u'إلكيا': u'إلْكِيَا', #292
u'الكياد': u'الْكِيَادَ', #2
u'الكياظم': u'الْكَيَاظِمِ', #1
u'الكيالون': u'الْكَيَّالُونَ', #1
u'الكيالين': u'الْكَيَّالِينَ', #6
u'الكيتلاني': u'الكيتلاني', #1
u'الكيخاراني،': u'الْكَيْخَارَانِيُّ،', #1
u'الكيخاراني': u'الْكَيْخَارَانِيِّ', #3
u'الكيدانية': u'الْكَيْدَانِيَّةِ', #11
u'الكيرج': u'الْكَيْرَجَ', #1
u'الكيزان': u'الْكِيزَانُ', #10
u'الكيزان': u'الْكِيزَانَ', #3
u'الكيزان': u'الْكِيزَانِ', #39
u'الكيساني،': u'الكيساني،', #1
u'الكيساني': u'الْكَيْسَانِيَّ', #3
u'الكيساني،': u'الْكَيْسَانِيِّ،', #3
u'الكيساني': u'الْكَيْسَانِيُّ', #41
u'الكيساني،': u'الْكَيْسَانِيُّ،', #7
u'الكيسانى': u'الْكَيْسَانِىُّ', #8
u'الكيسانيات': u'الْكَيْسَانِيَّاتِ', #28
u'الكيسانية': u'الْكَيْسَانِيَّةِ', #1
u'الكيفتي': u'الْكَيْفَتِيُّ', #1
u'الكيفيه': u'الْكَيْفِيَّهْ', #1
u'الكيكيلوني': u'الكيكيلوني', #1
u'الكيلاني': u'الْكِيلَانِيَّ', #1
u'الكيلاني': u'الْكِيلَانِيُّ', #2
u'الكيلاني': u'الْكِيلَانِيِّ', #4
u'الكيلانية': u'الْكِيلَانِيَّةُ', #1
u'الكيلجة': u'الْكِيلَجَةِ', #1
u'الكيلون': u'الْكِيلُونِ', #1
u'الكيلون': u'الْكَيْلُونِ', #1
u'الكيلينى': u'الْكِيلِينِىُّ', #1
u'الكيمان': u'الْكِيمَانَ', #1
u'الكيمان': u'الْكِيمَانِ', #4
u'الكيمخت': u'الْكِيمَخْتِ', #30
u'الكيمخت': u'الْكِيمَخْتَ', #4
u'الكيمخت': u'الْكِيمَخْتُ', #5
u'الكيميا': u'الْكِيمِيَا', #1
u'الكيميا': u'الْكِيمْيَا', #1
u'الكيناني': u'الْكَيْنَانِيُّ', #1
u'الكيول': u'الْكَيُولِ', #1
u'الكيول': u'الْكَيّولُ', #1
u'الكيول': u'الْكَيُّولِ', #1
u'الكيول': u'الْكَيُّولُ', #2
u'الكيول': u'الْكُيُولِ', #2
u'الكيول': u'الْكَيّولِ', #3
u'الل': u'اللَّ', #2
u'الل': u'الل', #3
u'اللا': u'اللَّا', #14
u'اللاء': u'اللّاءِ', #2
u'اللاء': u'اللَّاءِ', #3
u'اللاءات': u'اللاءات', #1
u'اللاءات': u'اللَّاءَاتِ', #2
u'اللاتى': u'اللاَّتِى', #38
u'اللاتى': u'الَّلاتِى', #4
u'اللاجواز': u'اللَّاجَوَازُ', #1
u'اللاحجة': u'اللَّاحِجَةَ', #1
u'اللاحقى': u'اللاَّحِقِىُّ', #3
u'اللاحوني،': u'اللاحوني،', #1
u'اللاحوني،': u'اللاحُونِيُّ،', #3
u'اللادن': u'اللادن', #1
u'اللادن': u'اللَّادِنُ', #1
u'اللاذن': u'اللَّاذِنِ', #1
u'اللاذن': u'اللَّاذَنِ', #13
u'اللاذن': u'اللَّاذَنُ', #3
u'اللاري': u'اللَّارِيُّ', #1
u'اللازبي': u'اللازِبِيُّ', #1
u'اللازق': u'اللازِقُ', #1
u'اللازق': u'اللَّازِقُ', #1
u'اللازق': u'اللَّازِقِ', #1
u'اللازقة': u'اللَّازِقَةُ', #1
u'اللازقة': u'اللَّازِقَةَ', #4
u'اللازمي': u'اللَّازِمِيَّ', #1
u'اللازمية': u'اللَّازِمِيَّةَ', #1
u'اللازمية': u'اللَّازِمِيَّةُ', #2
u'اللاسكى': u'اللاَّسَكِىِّ', #1
u'اللأشتر،': u'اللأشتر،', #1
u'اللاطئة،': u'اللَّاطِئَةَ،', #1
u'اللاطئة': u'اللَّاطِئَةِ', #2
u'اللاقبلية': u'اللَّاقَبْلِيَّةِ', #1
u'اللالك': u'اللَّالَكَ', #1
u'اللالك': u'اللَّالَكُ', #1
u'اللالكائي': u'اللَّالَكَائِيِّ', #1
u'اللالكائي': u'اللَّالَكَائِيُّ', #3
u'اللالكة': u'اللَّالَكَةِ', #3
u'اللآلي': u'اللآلي', #1
u'اللآلي': u'اللَّآلِي', #1
u'اللأمة': u'اللأمة', #1
u'اللأمة': u'اللأّمة', #1
u'اللأمة؟': u'اللأْمَةَ؟', #1
u'اللأمة': u'اللّأْمَةَ', #1
u'اللأمة': u'اللَّأْمَةُ', #1
u'اللأمة': u'اللَّأْمَةِ', #1
u'اللأمة': u'الّلأمَةِ', #1
u'اللأمة،': u'الَّلأَمَةَ،', #1
u'اللأمة': u'اللّأْمَةِ', #2
u'اللأمة': u'اللَّأْمَةَ', #3
u'اللأمة': u'اللأْمَةَ', #4
u'اللامتي': u'اللامتي', #1
u'اللامشتي': u'اللَّامِشْتِيُّ', #1
u'اللامشي': u'اللَّامِشِيَّ', #1
u'اللامشي': u'اللَّامِشِيُّ', #13
u'اللامشي': u'اللَّامِشِيِّ', #7
u'اللان': u'الّلان', #1
u'اللان،': u'الّلان،', #1
u'اللاني': u'اللَّانِيّ', #1
u'اللاه': u'الِلَاهٌ', #1
u'اللاه': u'الِلَاهَ', #1
u'اللاهوري': u'اللَّاهُورِيِّ', #1
u'اللأواء': u'اللّأْوَاءِ', #1
u'اللأواء': u'اللْأَوَاءِ', #1
u'اللأواء': u'الّلأْوَاءِ', #1
u'اللأواء': u'اللَّأْوَاءِ', #12
u'اللأواء': u'اللأْوَاءُ', #2
u'اللأواء': u'اللَّأْوَاءَ', #2
u'اللأواء': u'اللّأْوَاءُ', #3
u'اللأواء': u'اللَّأْوَاءُ', #5
u'اللأواء': u'اللأواء', #7
u'اللأوثان': u'اللأوثان', #1
u'اللأي': u'اللَّأْيَ', #1
u'اللأي': u'اللّأْيُ', #2
u'اللأي': u'اللّأْيِ', #2
u'اللاي': u'اللاي', #2
u'اللآئي': u'اللّآئِي', #1
u'اللائى': u'اللاَّئِى', #1
u'اللبأ': u'اللَّبَأُ', #1
u'اللبإ': u'اللَّبَإِ', #1
u'اللبأ': u'اللِّبَأ', #3
u'اللبا': u'اللِّبَا', #3
u'اللبأ': u'اللِّبَأِ', #30
u'اللبأ': u'اللَّبَأَ', #4
u'اللبإ': u'اللِّبَإِ', #5
u'اللبأ': u'اللِّبَأَ', #58
u'اللبأ': u'اللِّبَأُ', #7
u'اللبا': u'اللُّبَا', #7
u'اللبادي': u'اللَّبَّادِي', #1
u'اللبثا': u'اللَّبَثَا', #1
u'اللبجة': u'اللّبْجَةُ', #1
u'اللبخ': u'اللّبْخُ', #1
u'اللبقى': u'اللَّبَقِىَّ', #1
u'اللبقى': u'اللَّبَقِىُّ', #3
u'اللبوديين': u'اللُّبُودِيِّينَ', #1
u'اللبيبا': u'اللَّبِيبَا', #2
u'اللبيدي': u'اللَّبِيدِيُّ', #1
u'اللبيدي': u'اللَّبِيدِيِّ', #2
u'اللة': u'اللة', #2
u'اللتات': u'اللَّتَّاتُ', #1
u'اللتات': u'اللِّتَاتُ', #1
u'اللتات': u'اللِّتَاتِ', #1
u'اللتات': u'اللُّتَاتُ', #2
u'اللتات': u'اللَّتَّاتِ', #5
u'اللتات': u'اللُّتَاتِ', #5
u'اللتبية': u'اللتبية', #1
u'اللتبية': u'اللّتْبِيّةِ', #1
u'اللتبية': u'اللُّتْبِيَّةَ', #1
u'اللتبية': u'اللُّتْبِيَّةِ', #27
u'اللتي': u'اللَّتِّيِّ', #1
u'اللثق': u'اللّثَق', #1
u'اللثق': u'اللّثَقُ', #1
u'اللثق': u'اللّثِقِ', #1
u'اللثق': u'اللّثَقِ', #2
u'اللثق': u'اللّثِقُ', #2
u'اللجء': u'اللَّجْءِ', #1
u'اللجأ': u'اللَّجَأُ', #1
u'اللجأ': u'اللُّجْأِ', #1
u'اللجأ': u'اللَّجَأِ', #8
u'اللجاءة': u'اللَّجَاءَةِ', #1
u'اللجاب': u'اللّجَابِ', #2
u'اللجاة': u'اللَّجَاةِ', #1
u'اللجاة': u'اللَّجَاةُ', #4
u'اللجما': u'اللُّجُمَا', #10
u'اللحاظان': u'اللِّحَاظَانِ', #1
u'اللحب': u'اللَّحْبِ', #1
u'اللحدا': u'اللَّحْدَا', #1
u'اللحط': u'اللَّحْطُ', #1
u'اللحون': u'اللُّحُونُ', #1
u'اللحون': u'اللُّحُونِ', #5
u'اللحيف': u'اللّحَيْفُ', #1
u'اللحيف': u'اللُّحَيْفُ', #1
u'اللحيف،': u'اللُّحَيْفُ،', #1
u'اللحيف': u'اللَّحِيفُ', #3
u'اللخص': u'اللَّخَصَ', #1
u'اللخع': u'اللّخَعِ', #1
u'اللخم': u'اللّخْمُ', #1
u'اللخم': u'اللَّخَمُ', #4
u'اللخمي': u'اللخمي', #1
u'اللخمي،': u'اللخمي،', #1
u'اللخمى': u'اللَّخْمُِّى', #1
u'اللخمي،': u'اللَّخْمِيُّ،', #10
u'اللخمي': u'اللَّخْمِيَّ', #107
u'اللخمي': u'اللَّخْمِيّ', #17
u'اللخمي،': u'اللَّخْمِيَّ،', #2
u'اللخمي': u'اللَّخْمِيِّ', #2446
u'اللخمي': u'اللَّخْمِيُّ', #2646
u'اللخمي': u'اللّخْمِيّ', #4
u'اللخمي،': u'اللَّخْمِيِّ،', #5
u'اللخمى': u'اللَّخْمِىُّ', #52
u'اللخمى': u'اللَّخْمِىَّ', #6
u'اللخمى': u'اللَّخْمِىِّ', #6
u'اللخناء،': u'اللَّخْنَاءِ،', #1
u'اللخيف': u'اللّخِيفُ', #1
u'اللخيف': u'اللُّخَيْفُ', #2
u'اللدم': u'اللّدَمُ', #1
u'اللدم': u'اللّدْمَ', #1
u'اللدم': u'اللّدْمُ', #1
u'اللدم': u'اللّدْمِ', #1
u'اللدم': u'اللَّدْمَ', #1
u'اللدم': u'اللّدَمَ', #2
u'اللدني': u'اللَّدُنْيُّ', #1
u'اللدني': u'اللَّدُنِّي', #5
u'اللدنية': u'اللَّدُنِيَّةِ', #1
u'اللدنية': u'اللَّدُنِّيَّةُ', #1
u'اللدنية': u'اللَّدُنِّيَّةِ', #16
u'اللدنية': u'اللَّدُنْيَّةِ', #6
u'اللدوغ': u'اللَّدُوغُ', #1
u'اللديدان': u'اللَّدِيدَانِ', #1
u'اللديدين': u'اللّدِيدَيْنِ', #1
u'اللديغ': u'اللديغ', #1
u'اللديغ': u'اللَّدِيغ', #1
u'اللديغ': u'اللَّدِيغِ', #10
u'اللديغ': u'اللَّدِيغَ', #2
u'اللديغ،': u'اللَّدِيغِ،', #2
u'اللديغ': u'اللَّدِيغُ', #3
u'اللذاعة': u'اللَّذَّاعَةَ', #1
u'اللزيق': u'اللَّزِيقَ', #1
u'اللزيق': u'اللَّزِيقُ', #1
u'اللسانة': u'اللَّسَانَةِ', #1
u'اللصيت': u'اللّصَيت', #1
u'اللصيت': u'اللُّصَيْتِ', #1
u'اللصيت،': u'اللُّصَيْتِ،', #1
u'اللصيت': u'اللّصَيْتِ', #17
u'اللصيت': u'اللّصِيت', #2
u'اللصيت': u'اللّصِيتِ', #2
u'اللطح': u'اللَّطْح', #1
u'اللطح': u'اللَّطْحُ', #1
u'اللطح': u'اللَّطْحِ', #1
u'اللطخة': u'اللَّطْخَةِ', #1
u'اللطيم': u'اللَّطِيمُ', #5
u'اللطيمة': u'اللّطِيمَةُ', #2
u'اللطيمة': u'اللَّطِيمَةَ', #2
u'اللطيمة': u'اللّطِيمَةَ', #5
u'اللعاعة': u'اللّعَاعَةُ', #1
u'اللعانون': u'اللَّعَّانُونَ', #7
u'اللعباء': u'اللَّعْبَاءِ', #1
u'اللعساء': u'اللَّعْسَاءِ', #1
u'اللعل': u'اللعل', #1
u'اللغةإلى': u'اللُّغَةِإِلَى', #1
u'اللغوب': u'اللُّغُوبُ', #1
u'اللفاف': u'اللِّفَافِ', #1
u'اللفاف': u'اللَّفَّافُ', #2
u'اللفاف': u'اللَّفَّافِ', #2
u'اللفوت': u'اللّفُوتَ', #1
u'اللفوت': u'اللَّفُوتُ', #1
u'اللقا': u'اللِّقَا', #2
u'اللقاني': u'اللَّقَّانِيِّ', #1
u'اللقاني': u'اللَّقَانِيُّ', #273
u'اللقاني': u'اللَّقَانِيِّ', #462
u'اللقاني': u'اللَّقَانِيَّ', #9
u'اللقائح': u'اللّقَائِحُ', #2
u'اللقحة': u'اللّقْحَةَ', #1
u'اللقحة،': u'اللّقْحَة،', #1
u'اللقحة': u'اللَّقْحَةَ', #2
u'اللقحة': u'اللِّقْحَةِ', #2
u'اللقحة': u'اللقحة', #3
u'اللقحة': u'اللِّقْحَة', #4
u'اللقحة': u'اللِّقْحَةَ', #5
u'اللقحة': u'اللِّقْحَةُ', #6
u'اللقس': u'اللَّقِسِ', #1
u'اللقلق': u'اللَّقْلَقِ', #3
u'اللقلق': u'اللَّقْلَقَ', #6
u'اللقوح': u'اللَّقُوحُ', #1
u'اللقوح': u'اللَّقُوحِ', #1
u'اللقيطي': u'اللَّقِيطِيَّ', #1
u'اللقيطي': u'اللَّقِيطِيِّ', #1
u'اللقيقة': u'اللّقِيقَةِ', #1
u'اللقيمات': u'اللُّقَيْمَاتِ', #1
u'اللكاع': u'اللَّكَاعُ', #1
u'اللكائي': u'اللكائي', #1
u'اللكزة': u'اللَّكْزَةُ', #1
u'اللكزة': u'اللَّكْزَةِ', #3
u'اللكنوي': u'اللَّكْنَوِيِّ', #2
u'اللكنوي': u'اللَّكْنَوِيُّ', #5
u'اللكيعة': u'اللّكيعَة', #1
u'اللكيعة،': u'اللَّكِيعَةِ،', #1
u'اللكيعة': u'اللّكِيعَةِ', #2
u'اللكيعه': u'اللَّكِيعَهْ', #1
u'اللما': u'اللَّمَا', #1
u'اللمط': u'اللَّمْطِ', #1
u'اللمياء': u'اللَّمْيَاءُ', #1
u'اللهheck': u'اللهheck', #9
u'اللهlearmark': u'اللهlearmark', #10
u'اللهolorText': u'اللهolorText', #10
u'اللهOLOR': u'اللهOLOR', #1200
u'اللهonnectionRead': u'اللهonnectionRead', #9
u'اللهORصلى': u'اللهORصلى', #10
u'اللهount': u'اللهount', #10
u'آلله': u'آللّهِ', #1
u'آلله؟': u'آللَّهِ؟', #1
u'الله': u'اللَّهً', #1
u'الله': u'اللَّهًًًًِ', #1
u'آلله،': u'آللَّهِ،', #2
u'آلله': u'آللَّه', #6
u'آلله': u'آللَّهِ', #65
u'آلله': u'آللَّهُ', #76
u'آلله': u'آللّهُ', #9
u'اللها': u'اللَّهَا', #1
u'اللها': u'اللُّهَا', #2
u'اللهاء': u'اللّهَاءُ', #1
u'اللهات': u'اللَّهَاتِ', #1
u'اللهات': u'اللِّهَاتِ', #1
u'اللهازما': u'اللّهَازِمَا', #1
u'اللهاعتبروا': u'اللَّهِاعْتَبِرُوا', #1
u'اللهالصلاة': u'اللَّهِالصَّلاةَ', #1
u'اللهالوجه': u'اللَّهُالْوَجْهُ', #1
u'اللهأن': u'اللَّهُأَنَّ', #1
u'اللهإن': u'اللهإِنَّ', #1
u'اللهإن': u'اللَّهإنَّ', #1
u'اللهإن': u'اللَّهُإِنَّ', #1
u'اللهإن': u'اللَّهِإِنَّ', #1
u'اللهأن': u'اللَّهِأَنَّ', #2
u'اللهأنه': u'اللَّهُأَنَّهُ', #5
u'اللهأنهار': u'اللَّهِأَنْهَارُ', #1
u'اللهبة': u'اللُّهَبَةُ', #2
u'اللهبرة': u'اللَّهْبَرَةُ', #1
u'اللهبهذه': u'اللَّهُبِهَذِهِ', #1
u'اللهبى': u'اللَّهَبِىُّ', #1
u'اللهبى': u'اللَّهْبِىِّ', #1
u'اللهتعالى': u'اللَّهُتَعَالَى', #1
u'اللهتعالى': u'اللَّهُتعالى', #2
u'اللهجه': u'اللَّهْجَهْ', #1
u'اللهخلاف': u'اللَّهُخِلَافَ', #1
u'اللهد': u'اللَّهْد', #2
u'اللهدة': u'اللهدة', #1
u'اللهذلك': u'اللَّهُذَلِكَ', #1
u'اللهروح': u'اللَّهِرَوْحُ', #1
u'اللهس': u'اللَّهِس', #1
u'اللهقد': u'اللَّهِقَدْ', #1
u'اللهقوله': u'اللَّهِقَولُهُ', #1
u'اللهقوله': u'اللَّهَقَوْلُهُ', #1
u'اللهقوله': u'اللَّهُقَوْلُهُ', #1
u'اللهقوله': u'اللَّهِقَوْلُهُ', #4
u'اللهلا': u'اللَّهِلا', #1
u'اللهما': u'اللَّهِمَا', #1
u'اللهمن': u'اللَّهُمِنْ', #2
u'اللهمنا': u'اللَّهُمِنَّا', #1
u'اللهمولى': u'اللَّهِمَوْلَى', #1
u'اللهنزلت': u'اللَّهِنَزَلَتْ', #1
u'اللههذا': u'اللَّهُهَذَا', #1
u'اللهوأكثر': u'اللَّهُوَأَكْثَرُ', #1
u'اللهوالمستضعفين': u'اللَّهِوَالْمُسْتَضْعَفِينَ', #1
u'اللهوالوجه': u'اللَّهِوَالْوَجْهُ', #5
u'اللهوالوجه': u'اللَّهُوَالْوَجْهُ', #6
u'اللهوبه': u'اللَّهُوَبِهِ', #1
u'اللهوروي': u'اللَّهِوَرُوِيَ', #1
u'اللهوروي': u'اللَّهُوَرُوِيَ', #2
u'اللهوعندي': u'اللَّهُوَعِنْدِي', #1
u'اللهوفي': u'اللَّهُوَفِي', #1
u'اللهوكل': u'اللَّهُوَكُلُّ', #1
u'اللهوليس': u'اللَّهُوَلَيْسَ', #1
u'اللهوهذا': u'اللَّهُوَهَذَا', #1
u'اللهويحتمل': u'اللَّهُوَيُحْتَمَلُ', #1
u'اللهية': u'اللَّهْيَةَ', #1
u'اللو': u'اللَّوُّ', #1
u'اللو': u'اللَّوْ', #4
u'اللو': u'اللَّوَّ', #6
u'اللواتى': u'اللَّوَاتِى', #1
u'اللواذ': u'اللّوَاذُ', #2
u'اللواقح،': u'اللواقح،', #1
u'اللواقح': u'اللَّوَاقِحَ', #1
u'اللواقح': u'اللَّوَاقِحِ', #1
u'اللواقح': u'اللَّوَاقِحْ', #1
u'اللواقح': u'اللّوَاقِحْ', #4
u'اللؤام': u'اللّؤَامُ', #2
u'اللوان': u'اللّوّانِ', #1
u'اللواوين': u'اللَّوَاوِينُ', #1
u'اللوايا': u'اللَّوَايَا', #1
u'اللوب': u'اللّوْبِ', #1
u'اللوب': u'اللّوبُ', #2
u'اللوزنيج': u'اللَّوْزَنِيجِ', #1
u'اللوزنيق': u'اللَّوْزَنِيقُ', #2
u'اللوزينق': u'اللَّوْزَيْنَقُ', #1
u'اللوزينق': u'اللَّوْزَيْنَقِ', #1
u'اللوص': u'اللَّوْصِ', #4
u'اللوطى': u'اللُّوطِىُّ', #2
u'اللوطى': u'اللُّوطِىِّ', #4
u'اللوفر': u'اللُّوفَرِ', #1
u'اللوقة': u'اللُّوَقَةُ', #1
u'اللؤلؤة': u'اللّؤْلُؤَةُ', #1
u'اللؤلؤة': u'اللُّؤْلُؤَةَ', #31
u'اللؤلؤة': u'اللُّؤْلُؤَةِ', #39
u'اللؤلؤة': u'اللُّؤْلُؤَةُ', #7
u'اللؤلؤتين': u'اللُّؤْلُؤَتَيْنِ', #1
u'اللؤلؤتين،': u'اللُّؤْلُؤَتَيْنِ،', #1
u'اللؤلؤي،': u'اللُّؤْلُؤِيُّ،', #1
u'اللؤلؤى': u'اللَّؤْلُؤِىُّ', #1
u'اللؤلؤى': u'اللُّؤْلُؤْىُّ', #1
u'اللؤلؤى': u'اللُّؤْلُّؤِىُّ', #1
u'اللؤلؤي': u'اللُّؤْلُؤِيُّ', #23
u'اللؤلؤي': u'اللُّؤْلُؤِيَّ', #4
u'اللؤلؤى': u'اللُّؤْلُؤِىُّ', #58
u'اللؤلؤي': u'اللُّؤْلُؤِيِّ', #7
u'اللونكة': u'اللَّوْنَكَةِ', #3
u'اللياطة': u'اللِّيَاطَةَ', #1
u'اللياطة': u'اللِّيَاطَةِ', #9
u'الليال،': u'الْلَيَالِ،', #1
u'الليإلى': u'الليإلى', #1
u'الليالى': u'اللَّيَالِى', #16
u'الليالى': u'اللَّيَالِىَ', #5
u'اللياليا': u'اللَّيَالِيَا', #2
u'اللية': u'اللِّيَّةَ', #1
u'الليتي': u'اللَّيْتِيُّ', #1
u'الليثني': u'اللَّيْثَنِيَّ', #1
u'الليثى': u'اللَّيْثِىَّ', #21
u'الليثى': u'اللَّيْثِىُّ', #67
u'الليثى': u'اللَّيْثِىِّ', #73
u'الليثيأنه': u'اللَّيْثِيُّأَنَّهُ', #1
u'الليحاني': u'اللِّيحَانِيُّ', #1
u'الليس': u'اللّيسُ', #1
u'الليس': u'اللُّيَّسِ', #1
u'الليسية': u'اللَّيْسِيَّةَ', #1
u'الليسية': u'اللَّيْسِيَّةِ', #2
u'الليطة': u'اللِّيطَةَ', #1
u'الليطة': u'اللِّيطَةُ', #2
u'الليطة': u'اللِّيطَةِ', #2
u'الليله،': u'الليله،', #1
u'الليم': u'اللِّيمُ', #1
u'الليم': u'اللِّيمِ', #1
u'الليم': u'اللُّيَّمَ', #1
u'الليم': u'اللُّيَّمِ', #1
u'الليمونا': u'اللَّيْمُونَا', #1
u'اللينقوله': u'اللَّيِّنُقَوْلُهُ', #1
u'اللينوفر': u'اللينوفر', #2
u'اللينوفر': u'اللِّينُوفَرِ', #2
u'الما': u'الْمَا', #10
u'الماءات': u'الْمَاءَاتِ', #1
u'الماءمترع': u'الْمَاءِمُتْرَعُ', #1
u'الماءو': u'الْمَاءَوَ', #1
u'الماءوروي': u'الْمَاءُوَرُوِيَ', #1
u'الماءينبئكم': u'الْمَاءِيُنْبِئُكُمْ', #1
u'المآبة': u'الْمَآبَةِ', #1
u'المأبور': u'الْمَأْبُورَ', #2
u'المأبور': u'الْمَأْبُورِ', #9
u'المأبورة': u'الْمَأْبُورَةِ', #22
u'المأبورة': u'الْمَأْبُورَةَ', #7
u'المأبورة': u'الْمَأْبُورَةُ', #7
u'المأبورين': u'الْمَأْبُورَيْنِ', #1
u'المأبون،': u'الْمَأْبُونِ،', #1
u'المأبون': u'الْمَأْبُونَ', #2
u'المأبون': u'الْمَأْبُونُ', #4
u'المأبون': u'الْمَأْبُونِ', #6
u'الماتريدي': u'الْمَاتُرِيدِيَّ', #2
u'الماتريدي': u'الْمَاتُرِيدِيِّ', #38
u'الماتريدي': u'الْمَاتُرِيدِيُّ', #90
u'الماتريدية': u'الْمَاتُرِيدِيَّةِ', #28
u'الماتريدية': u'الْمَاتُرِيدِيَّةُ', #6
u'الماتمرغي': u'الْمَاتَمْرَغِيُّ', #1
u'المأتي': u'الْمَأْتِيَّ', #35
u'المأتي': u'الْمَأْتِيُّ', #55
u'المأتي': u'الْمَأْتِيِّ', #57
u'المأتية': u'الْمَأْتِيَّةِ', #2
u'المأتية': u'الْمَأْتِيَّةُ', #6
u'المأثوم': u'الْمَأْثُومُ', #1
u'المأثوم': u'الْمَأْثُومِ', #3
u'الماج': u'الْمَاجَّ', #1
u'الماجرى': u'الْمَاجَرَى', #1
u'الماجشون': u'الْمَاجَشَونِ', #1
u'الماجشون': u'الْمَاجُشُونَ', #1
u'الماجشون': u'الْمَاجِشُونْ', #1
u'الماجشون': u'الْمَاجِشُونَ', #128
u'الماجشون،': u'الْمَاجِشُونُ،', #18
u'الماجشون': u'الماجشون', #2
u'الماجشون،': u'الماجشون،', #2
u'الماجشون،': u'الْمَاجِشُونِ،', #22
u'الماجشون': u'الْمَاجِشُونِ', #2317
u'الماجشون': u'الْمَاجِشَونِ', #3
u'الماجشون': u'الْمَاجِشُونُ', #30
u'الماجشون،': u'الْمَاجِشُونَ،', #6
u'الماجشوني': u'الْمَاجِشُونِيَّ', #2
u'الماجل': u'الماجل', #1
u'المأجورية': u'الْمَأْجُورِيَّةُ', #1
u'المأجورية': u'الْمَأْجُورِيَّةِ', #1
u'الماحوز': u'الماحوز', #1
u'الماحوز': u'الْمَاحُوزِ', #1
u'الماحوز،': u'الْمَاحُوزِ،', #2
u'الماحى': u'الْمَاحِى', #2
u'المأخيذ': u'الْمَأْخُيذِ', #1
u'المأدوم': u'الْمَأْدُومِ', #1
u'المأدوم': u'الْمَأْدُومُ', #2
u'الماذي': u'الْمَاذِي', #1
u'الماذي': u'الْمَاذِيّ', #3
u'الماذيان': u'الْمَاذِيَانَ', #1
u'الماذيان': u'الْمَاذِيَانُ', #3
u'الماذيان': u'الْمَاذِيَانِ', #3
u'الماذيانات': u'الْمَاذِيَانَاتِ', #18
u'الماذيانات': u'الماذيانات', #2
u'الماذيانات': u'الْمَاذِيَانَات', #2
u'الماذيانات،': u'الْمَاذِيَانَاتِ،', #2
u'الماذيانات': u'الْمَاذِيَانَاتُ', #3
u'الماذيانة': u'الْمَاذَيانَةُ', #1
u'الماذيانة': u'الْمَاذَيَانَةِ', #1
u'الماذية': u'الْمَاذِيّةِ', #1
u'المارانية': u'الْمَارَانِيَّةِ', #1
u'المارانية': u'الْمَارَانِيَّةُ', #4
u'المأربى': u'الْمَأْرِبِىَّ', #1
u'المأربى': u'الْمَأْرِبِىُّ', #1
u'المأربى': u'الْمَأْرِبِىِّ', #1
u'المارديني': u'المارديني', #1
u'المارديني': u'الْمَارْدِينِيَّ', #1
u'المارديني': u'الْمَارْدِينِيِّ', #19
u'المارديني': u'الْمَارْدِينِيُّ', #7
u'المارماهي': u'الْمَارْمَاهِيَّ', #1
u'المارماهي': u'الْمَارْمَاهِيِّ', #1
u'المازري': u'الْمَازِرِي', #1
u'المازري': u'الْمَازِرِيُ', #1
u'المازري': u'الْمَازِرِيّ', #11
u'المازري': u'الْمَازِرِيُّ', #1299
u'المازري': u'الْمَازِرِيَّ', #38
u'المازري': u'الْمَازِرِيِّ', #382
u'المازن': u'الْمَازِنُ', #1
u'المازني': u'المازنّي', #1
u'المازني،': u'المازنّي،', #1
u'المازني،': u'المازِنّي،', #1
u'المازني،': u'الْمَازِنِيُّ،', #14
u'المازنى': u'الْمَازِنِىُّ', #14
u'المازني،': u'الْمَازِنِيِّ،', #16
u'المازني': u'الْمَازِنِيَّ', #17
u'المازني،': u'المازني،', #2
u'المازنى': u'الْمَازِنِىِّ', #24
u'المازني': u'المازنيّ', #3
u'المازني': u'الْمَازِنِيّ', #38
u'المازني،': u'الْمَازِنِيَّ،', #4
u'المازني': u'الْمَازِنِيُّ', #63
u'المازني': u'الْمَازِنِيِّ', #64
u'المازنى': u'الْمَازِنِىَّ', #7
u'المازني': u'المازني', #9
u'المازنية': u'الْمَازِنِيّة', #1
u'المازنية': u'الْمَازِنِيّةُ', #6
u'المازنيين': u'الْمَازِنِيّينَ', #1
u'الماسخي': u'الْمَاسِخِيّ', #2
u'الماسرجسي': u'الْمَاسَرْجِسِيَّ', #1
u'الماسرجسي،': u'الْمَاسَرْجَسِيُّ،', #1
u'الماسرجسي،': u'الْمَاسَرْجِسِيُّ،', #1
u'الماسرجسى': u'الْمَاسَرْجِسِىَّ', #1
u'الماسرجسى': u'الْمَاسَرْجِسِىُّ', #16
u'الماسرجسي': u'الْمَاسَرْجِسِيِّ', #3
u'الماسرجسى': u'الْمَاسَرْجَسِىُّ', #6
u'الماسرجسي': u'الْمَاسَرْجِسِيُّ', #7
u'الماسيا': u'الْمَاسِيًّا', #1
u'الماش': u'الْمَاشُ', #2
u'الماش': u'الْمَاشِ', #2
u'الماش': u'الْمَاشَّ', #2
u'الماش': u'الْمَاشِّ', #2
u'الماش': u'الْمَاشُّ', #5
u'الماشر': u'الْمَاشِرُ', #1
u'الماشعير': u'الْمَاشَعِيرُ', #1
u'الماشعير': u'الْمَاشَعِيرِ', #1
u'الماشى': u'الماشى', #1
u'الماشى': u'الْمَاشِى', #7
u'الماشيه': u'الْمَاشِيَهْ', #2
u'الماصادقات': u'الْمَاصَادَقَاتِ', #1
u'الماصدق': u'الْمَاصَدَقُ', #1
u'الماصدق': u'الْمَاصَدَقِ', #10
u'الماصدق': u'الْمَاصَدَقَ', #23
u'الماصدقات': u'الْمَاصَدَقَاتُ', #4
u'الماصدقات': u'الْمَاصَدَقَاتِ', #4
u'الماصر،': u'الماصر،', #1
u'الماصر': u'الْمَاصِرُ', #1
u'الماصر': u'الْمَاصِرِ', #1
u'المأصول': u'الْمَأْصُولُ', #1
u'الماصية': u'الْمَاصِيَةَ', #1
u'الماصية': u'الْمَاصِيَةِ', #2
u'الماضى': u'الماضى', #1
u'الماضى': u'الْمَاضِى', #2
u'الماضيا': u'الْمَاضِيَا', #1
u'الماضيه': u'الْمَاضِيَهْ', #1
u'الماعزه': u'الْمَاعِزَهْ', #1
u'الماعونقوله': u'الْمَاعُونُقَوْلُهُ', #1
u'الماغرة،': u'الماغرة،', #1
u'المآق': u'الْمَآقِ', #1
u'المأق': u'الْمَأَقِ', #1
u'الماق': u'الْمَاقُ', #1
u'الماق': u'الْمَاقِّ', #1
u'الماق': u'الْمَاقِ', #3
u'المأقط': u'الْمَأْقِطُ', #1
u'المآقى': u'المآقى', #1
u'المأقي': u'الْمَأَقِي', #1
u'المآقي': u'الْمَآقِيِ', #2
u'المآقي': u'الْمَآقِي', #8
u'الماقين': u'الْمَاقَيْنِ', #5
u'المأقين': u'الْمَأْقَيْنِ', #7
u'الماكين': u'الْمَاكِّينَ', #1
u'المالقي': u'الْمَالِقِيَّ', #1
u'المالقي': u'الْمَالِقِيِّ', #1
u'المالقي': u'الْمَالِقِيُّ', #2
u'المالكى': u'الْمَالِكِىُّ', #20
u'المالكى': u'الْمَالِكِىِّ', #4
u'المألوم': u'المألوم', #2
u'المألوم': u'الْمَأْلُومَ', #2
u'المألوم': u'الْمَأْلُومُ', #4
u'المألوم': u'الْمَأْلُومِ', #7
u'المألوه': u'الْمَأْلُوهُ', #1
u'الماليخوليا': u'الْمَالِيخُولْيَا', #1
u'الماليخوليا': u'الْمَالَيْخُولِيَا', #1
u'الماليني': u'الْمَالِينِيِّ', #2
u'المالينى': u'الْمَالِينِىُّ', #303
u'المالينى': u'الْمَالِينِىِّ', #6
u'الماليه': u'الْمَالِيَّهْ', #1
u'المأمولا': u'الْمَأْمُولَا', #1
u'المأمومه': u'الْمَأْمُومَهْ', #1
u'المأمومية': u'الْمَأْمُومِيَّةَ', #10
u'المأمومية': u'الْمَأْمُومِيَّةِ', #52
u'المأموني': u'الْمَأْمُونِيِّ', #1
u'المأموني': u'الْمَأْمُونِيُّ', #3
u'المأمونية': u'الْمَأْمُونِيَّةِ', #2
u'المأمونية': u'الْمَأْمُونِيَّةُ', #3
u'المأمونية': u'الْمَأْمُونِيَّةَ', #6
u'المانعية': u'الْمَانِعِيَّةِ', #16
u'المانعية': u'الْمَانِعِيَّةَ', #6
u'المانعية': u'الْمَانِعِيَّةُ', #7
u'المانوية': u'الْمَانَوِيَّةُ', #1
u'الماني': u'الْمَانِي', #2
u'المانية': u'الْمَانَيَةِ', #1
u'المانية': u'الْمَانِيَةِ', #1
u'المانية': u'الْمَانِّيَّةِ', #1
u'المانية': u'الْمَانِيَّةِ', #4
u'الماهلة': u'الْمَاهِلَةِ', #1
u'الماورد': u'الْمَاوَرْدَ', #1
u'الماورد': u'الْمَاوَرْدُ', #2
u'الماورد': u'الْمَاوَرْدِ', #6
u'الماوردي': u'الماوردي', #1
u'الماوردي': u'الْمَاوَرْدِيّ', #4
u'الماوردي': u'الْمَاوَرْدِيُّ', #4604
u'الماوردي': u'الْمَاوَرْدِيَّ', #67
u'الماوردي': u'الْمَاوَرْدِيِّ', #916
u'الماوسي': u'الْمَاوِسِيِّ', #1
u'المائتا': u'الْمِائَتَا', #6
u'المائتي': u'الْمِائَتَيْ', #39
u'المائح': u'الْمَائِحُ', #7
u'المائعية': u'الْمَائِعِيَّةِ', #1
u'المائين': u'الْمَائِينَ', #3
u'المائين': u'الْمَائَيْنِ', #5
u'المايمرغي': u'الْمَايَمُرْغِيُّ', #2
u'المايمرغي': u'الْمَايَمُرْغِيِّ', #2
u'المأيوس': u'الْمَأْيُوس', #1
u'المأيوس': u'الْمَأْيُوسِ', #10
u'المأيوس': u'الْمَأْيُوسُ', #16
u'المأيوس': u'الْمَأْيُوسَ', #5
u'المبات': u'الْمَبَاتِ', #1
u'المبادره': u'الْمُبَادَرَهْ', #1
u'المبادي': u'الْمُبَادِي', #5
u'المبادي': u'الْمَبَادِي', #6
u'المبارأة': u'الْمُبَارَأَةَ', #19
u'المبارأة': u'الْمُبَارَأَةُ', #24
u'المبارأة': u'الْمُبَارَأَةِ', #44
u'المبارآت': u'الْمُبَارَآتُ', #1
u'المبارآت': u'الْمُبَارَآتِ', #2
u'المبارة': u'الْمُبَارَةِ', #1
u'المبارق': u'الْمُبَارَقِ', #1
u'المبارق': u'الْمَبَارِقِ', #11
u'المبارق': u'الْمُبَارِقِ', #8
u'المباركي': u'الْمُبَارَكِيِّ', #1
u'المباركي،': u'الْمُبَارِكِيُّ،', #1
u'المباركي،': u'الْمُبَارَكِيُّ،', #4
u'المباركي': u'الْمُبَارَكِيُّ', #5
u'المباركى': u'الْمُبَارَكِىُّ', #5
u'المبارئة': u'الْمُبَارِئَةِ', #1
u'المبارئة': u'الْمُبَارِئَةَ', #3
u'المبارئة': u'الْمُبَارِئَةُ', #4
u'المباسيط': u'الْمَباسِيطِ', #1
u'المباسيط': u'الْمَبَاسِيطِ', #2
u'المباشره': u'الْمُبَاشَرَهْ', #1
u'المباضعات': u'الْمُبَاضَعَاتِ', #2
u'المباضعة': u'الْمُبَاضَعَةِ', #11
u'المباضعة': u'الْمُبَاضَعَةَ', #3
u'المباضعة': u'الْمُبَاضَعَةُ', #3
u'المباطخ': u'الْمَبَاطِخُ', #1
u'المباعر': u'الْمَبَاعِرَ', #1
u'المباعر': u'الْمَبَاعِرُ', #4
u'المبالات': u'الْمُبَالَاتِ', #1
u'المبان': u'الْمُبَانَ', #28
u'المبان': u'الْمُبَانُ', #76
u'المبان': u'الْمُبَانِ', #95
u'المبانات': u'الْمُبَانَاتِ', #2
u'المبانة': u'الْمُبَانَةَ', #31
u'المبانة': u'الْمُبَانَةُ', #41
u'المبانة': u'الْمُبَانَةِ', #57
u'المباهات': u'الْمُبَاهَاتِ', #1
u'المباهلة': u'الْمُبَاهِلَةَ', #1
u'المباهلة': u'الْمُبَاهَلَةَ', #15
u'المباهلة': u'الْمُبَاهَلَةِ', #20
u'المباهلة': u'الْمُبَاهَلَةُ', #8
u'المباهله': u'الْمُبَاهَلَهْ', #1
u'المباهي': u'الْمُبَاهِي', #1
u'المباين': u'الْمَبَايِنِ', #1
u'المباين': u'الْمُبَايَنُ', #1
u'المباين': u'الْمُبَايِنُ', #11
u'المباين': u'الْمُبَايَنِ', #2
u'المباين': u'الْمُبَايِنِ', #23
u'المباين': u'الْمُبَايِنَ', #5
u'المباينات': u'الْمُبَايِنَاتُ', #2
u'المباينة': u'الْمُبَايَنَةُ', #11
u'المباينة': u'الْمُبَايِنَةُ', #3
u'المباينة': u'الْمُبَايِنَةِ', #5
u'المباينة': u'الْمُبَايَنَةِ', #52
u'المباينة': u'الْمُبَايَنَةَ', #9
u'المبتاعا': u'الْمُبْتَاعَا', #1
u'المبتدا': u'المبتدا', #1
u'المبتدا': u'الْمُبْتَدَا', #3
u'المبتدلة': u'المبتدلة', #1
u'المبتدى': u'الْمُبْتَدَى', #1
u'المبتدي': u'الْمُبْتَدِيَ', #2
u'المبتدي': u'الْمُبْتَدِي', #40
u'المبتدين': u'الْمُبْتَدِينَ', #1
u'المبتديه': u'الْمُبْتَدِيَهْ', #1
u'المبترة': u'الْمُبَتَّرَة', #1
u'المبتعث': u'الْمُبْتَعَثِ', #1
u'المبتنى': u'الْمُبْتَنَى', #4
u'المبتوتات': u'الْمَبْتُوتَاتِ', #1
u'المبتوتات': u'الْمَبْتُوتَاتُ', #3
u'المبتوتة': u'الْمَبْتُوتَة', #1
u'المبتوتة': u'الْمَبْتُوتَةِ', #113
u'المبتوتة': u'الْمَبْتُوتَةَ', #52
u'المبتوتة': u'الْمَبْتُوتَةُ', #60
u'المبداة': u'الْمُبْدَاةِ', #1
u'المبدى': u'الْمُبْدَى', #4
u'المبرءون': u'الْمُبَرَّءُونَ', #1
u'المبرءون': u'الْمُبْرَءُونَ', #2
u'المبرأ': u'المبرأ', #1
u'المبرأ': u'الْمُبَرَّأ', #1
u'المبرا': u'الْمُبَرَّا', #1
u'المبرأ': u'الْمُبْرَأَ', #12
u'المبرأ': u'الْمُبَرَّأِ', #16
u'المبرأ': u'الْمُبْرَأُ', #20
u'المبرأ': u'الْمُبَرَّأُ', #21
u'المبرأ': u'الْمُبْرَأِ', #38
u'المبرأ': u'الْمُبَرَّأَ', #7
u'المبرإ': u'الْمُبْرَإِ', #7
u'المبرإ': u'الْمُبَرَّإِ', #9
u'المبرأة': u'المبرأة', #1
u'المبرأة': u'الْمُبَرَّأَة', #1
u'المبرأة': u'الْمُبَرَّأَةُ', #4
u'المبرسم': u'الْمُبَرْسَمُ', #12
u'المبرسم': u'الْمُبَرْسَمَ', #3
u'المبرسم': u'الْمُبَرْسَمِ', #8
u'المبرسمين': u'الْمُبَرْسَمِينَ', #2
u'المبرص': u'الْمُبَرَّصُ', #1
u'المبرص': u'الْمُبْرَصِ', #1
u'المبروص': u'الْمَبْرُوصُ', #1
u'المبزر': u'الْمُبَزَّرَ', #2
u'المبسور': u'الْمَبْسُورَ', #1
u'المبسور': u'الْمَبْسُورِ', #10
u'المبسور': u'الْمَبْسُورُ', #2
u'المبسوطمن': u'الْمَبْسُوطِمِنْ', #1
u'المبعدا': u'الْمُبْعَدَا', #2
u'المبعر': u'الْمَبْعَرُ', #1
u'المبعر،': u'الْمَبْعَرُ،', #1
u'المبعض': u'الْمُبَعَّض', #1
u'المبعض': u'الْمُبَعِّضُ', #1
u'المبعض': u'الْمُبَعِّضِ', #2
u'المبعض': u'الْمُبْعِضُ', #2
u'المبعض': u'الْمُبَعَّضُ', #231
u'المبعض': u'الْمُبَعَّضِ', #319
u'المبعض': u'الْمُبَعَّضَ', #84
u'المبعضة': u'الْمُبْعِضَةَ', #1
u'المبعضة': u'الْمُبْعِضَةِ', #1
u'المبعضة': u'الْمُبَعِّضَةِ', #2
u'المبعضة': u'الْمُبَعَّضَةَ', #23
u'المبعضة': u'الْمُبَعَّضَةُ', #60
u'المبعضة': u'الْمُبَعَّضَةِ', #90
u'المبعضون': u'الْمُبَعَّضُونَ', #3
u'المبعضين': u'الْمُبَعَّضَيْنِ', #1
u'المبعضين': u'الْمُبَعَّضِينَ', #5
u'المبعود': u'الْمَبْعُودِ', #1
u'المبقاة': u'الْمُبْقَاةَ', #5
u'المبقاة': u'الْمُبْقَاةُ', #7
u'المبقى': u'الْمُبْقَى', #11
u'المبقيها': u'الْمُبْقِيهَا', #2
u'المبكتين': u'الْمُبَكِّتِينَ', #1
u'المبلدة': u'الْمُبَلِّدَةِ', #1
u'المبلس': u'الْمُبْلِسُ', #1
u'المبيتفي': u'الْمَبِيتُفِي', #1
u'المبيحه': u'المبيحه', #1
u'المبير': u'المبير', #1
u'المبير': u'الْمُبِيرُ', #6
u'المبيعية': u'الْمَبِيعِيَّةُ', #1
u'المبيكر': u'الْمُبَيْكَرِ', #1
u'المبيوع': u'الْمَبْيُوعُ', #1
u'المتاب': u'الْمَتَابُ', #2
u'المتأبد': u'الْمُتَأَبِّدُ', #1
u'المتأبدة': u'الْمُتَأَبِّدَةِ', #4
u'المتأبر': u'الْمُتَأَبِّرَ', #1
u'المتأبر': u'الْمُتَأَبِّرِ', #1
u'المتأبر': u'الْمُتَأَبَّرِ', #2
u'المتأبر': u'الْمُتَأَبِّرُ', #2
u'المتأبرة': u'الْمُتَأَبِّرَةَ', #1
u'المتأثل': u'المتأثل', #1
u'المتأجر': u'الْمُتَأَجَّرِ', #1
u'المتآجران': u'الْمُتَآجِرَانِ', #4
u'المتآجرين': u'الْمُتَآجِرِينَ', #1
u'المتآجرين': u'الْمُتَآجِرَيْنِ', #14
u'المتآخذين': u'الْمُتَآخِذَيْنِ', #1
u'المتأدي': u'الْمُتَأَدِّي', #2
u'المتأدية': u'الْمُتَأَدِّيَةِ', #1
u'المتأذي': u'الْمُتَأَذِّيَ', #1
u'المتأذي': u'الْمُتَأَذِّي', #3
u'المتارك': u'الْمُتَارِكِ', #3
u'المتاركة': u'الْمُتَارَكَةَ', #21
u'المتاركة': u'الْمُتَارَكَةُ', #25
u'المتاركة': u'الْمُتَارَكَةِ', #73
u'المتاعا': u'الْمَتَاعَا', #1
u'المتأكل': u'الْمُتَأَكِّلُ', #3
u'المتأكل': u'الْمُتَأَكِّلِ', #6
u'المتأكلة': u'الْمُتَأَكِّلَةَ', #1
u'المتأكلة': u'الْمُتَأَكِّلَةُ', #2
u'المتأكلة': u'الْمُتَأَكِّلَةِ', #3
u'المتآكلون': u'الْمُتَآكِلُونَ', #1
u'المتألي': u'الْمُتَأَلِّي', #2
u'المتألى': u'الْمُتَأَلِّى', #2
u'المتألية': u'الْمُتَأَلِّيَةُ', #1
u'المتاومة': u'الْمُتَاوَمَةِ', #1
u'المتباذلين': u'الْمُتَبَاذِلِينَ', #1
u'المتبائعين': u'الْمُتَبَائِعِينَ', #1
u'المتبائعين': u'الْمُتَبَائِعَيْنِ', #2
u'المتبدي': u'الْمُتَبَدِّي', #1
u'المتبدين': u'الْمُتَبَدِّينَ', #1
u'المتبذل': u'الْمُتَبَذِّلِ', #1
u'المتبذل': u'الْمُتَبَذِّلَ', #2
u'المتبذلات': u'الْمُتَبَذِّلَاتِ', #1
u'المتبذلة': u'الْمُتَبَذِّلَةَ', #1
u'المتبر': u'الْمُتَبَّرَ', #1
u'المتبر': u'الْمُتَبَّرُ', #2
u'المتبرأ': u'الْمُتَبَرَّأَ', #1
u'المتبرحات': u'الْمُتَبَرِّحَاتِ', #1
u'المتبري': u'الْمُتَبَرِّي', #2
u'المتبعض': u'الْمُتَبَعِّضِ', #3
u'المتبعه': u'الْمُتَّبِعَهْ', #1
u'المتبقى': u'الْمُتَبَقَّى', #1
u'المتبن': u'الْمَتْبَنُ', #2
u'المتبن': u'الْمَتْبَنِ', #3
u'المتبوأ': u'المتبوأ', #1
u'المتبوعية': u'الْمَتْبُوعِيَّةِ', #4
u'المتبول': u'الْمَتْبُولَ', #1
u'المتبولي': u'الْمَتْبُولِيِّ', #1
u'المتترب': u'الْمُتَتَرِّبِ', #2
u'المتترس': u'الْمُتَتَرَّسُ', #2
u'المتترس': u'الْمُتَتَرَّسِ', #5
u'المتترسون': u'الْمُتَتَرِّسُونَ', #2
u'المتترسين': u'الْمُتَتَرِّسِينَ', #5
u'المتتقيم': u'الْمُتْتَقِيمَ', #1
u'المتثلم': u'الْمُتَثَلّمِ', #2
u'المتثلم': u'الْمُتَثَلِّمِ', #2
u'المتثلمة': u'الْمُتَثَلِّمَةِ', #1
u'المتجالات': u'الْمُتَجَالَّاتُ', #3
u'المتجالات': u'الْمُتَجَالَّاتِ', #3
u'المتجالة': u'الْمُتَجَالَّةُ', #23
u'المتجالة': u'الْمُتَجَالَّةِ', #31
u'المتجالة': u'الْمُتَجَالَّةَ', #8
u'المتجرنات': u'المتجرنات', #1
u'المتجشي': u'الْمُتَجَشِّي', #1
u'المتجود': u'الْمُتَجَوِّدِ', #1
u'المتجود': u'الْمُتَجَوَّدِ', #2
u'المتجودة': u'الْمُتَجَوِّدَةِ', #1
u'المتجوز': u'الْمُتَجَوَّزَ', #1
u'المتجوز': u'الْمُتَجَوَّزِ', #13
u'المتجوز': u'الْمُتَجَوِّزَ', #2
u'المتجوز': u'الْمُتَجَوِّزُ', #2
u'المتجوز': u'الْمُتَجَوَّزُ', #5
u'المتجوز': u'الْمُتَجَوِّزِ', #8
u'المتجوه': u'الْمُتَجَوَّهُ', #1
u'المتجوه': u'الْمُتَجَوَّهِ', #1
u'المتحجز': u'الْمُتَحَجِّزِ', #1
u'المتحدثينا': u'الْمُتَحَدِّثِينَا', #1
u'المتحدد': u'الْمُتَحَدِّدَ', #1
u'المتحدى': u'الْمُتَحَدَّى', #4
u'المتحرف': u'الْمُتَحَرِّفَ', #1
u'المتحرف': u'الْمُتَحَرِّفِ', #4
u'المتحرف': u'الْمُتَحَرِّفُ', #5
u'المتحركية': u'المتحركية', #1
u'المتحرى': u'الْمُتَحَرَّى', #3
u'المتحولم': u'الْمُتَحَوْلِمُ', #1
u'المتحيل': u'الْمُتَحَيِّلُ', #1
u'المتحيل': u'الْمُتَحَيَّلِ', #3
u'المتحيل': u'الْمُتَحَيَّلُ', #6
u'المتخالعان': u'الْمُتَخَالَعَانِ', #1
u'المتخالعان': u'الْمُتَخَالِعَانِ', #6
u'المتخالعين': u'الْمُتَخَالِعَيْنِ', #6
u'المتخايرين': u'الْمُتَخَايِرَيْنِ', #1
u'المتخرص': u'الْمُتَخَرِّصُ', #1
u'المتخرصين': u'الْمُتَخَرِّصِينَ', #4
u'المتخرق': u'الْمُتَخَرِّقَ', #2
u'المتخرق': u'الْمُتَخَرِّقِ', #4
u'المتخصر': u'الْمُتَخَصِّرِ', #2
u'المتخصرون': u'الْمُتَخَصّرُونَ', #2
u'المتخصرون': u'الْمُتَخَصِّرُونَ', #4
u'المتخصرين': u'الْمُتَخَصّرِينَ', #1
u'المتخصرين': u'الْمُتَخَصِّرِينَ', #2
u'المتخفف': u'الْمُتَخَفِّفِ', #2
u'المتخففين': u'الْمُتَخَفِّفَيْنِ', #1
u'المتخللون؟': u'الْمُتَخَلِّلُونَ؟', #1
u'المتخللون': u'الْمُتَخَلِّلُونَ', #9
u'المتخم': u'الْمُتْخِمُ', #1
u'المتخم': u'الْمُتْخِمِ', #1
u'المتداعى': u'الْمُتَدَاعَى', #12
u'المتداني': u'الْمُتَدَانِي', #1
u'المتدانية': u'الْمُتَدَانِيَةِ', #1
u'المتراءى': u'الْمُتَرَاءَى', #1
u'المتراد': u'الْمُتَرَادُّ', #1
u'المتراضعين': u'الْمُتَرَاضِعِينَ', #3
u'المتراضعين': u'الْمُتَرَاضِعَيْنِ', #6
u'المترتلة': u'الْمُتَرَتِّلَة', #1
u'المترجبين': u'الْمُتَرَجِّبِينَ', #2
u'المترجى': u'الْمُتَرَجَّى', #1
u'المترخص': u'الْمُتَرَخِّصَ', #2
u'المترخص': u'الْمُتَرَخِّصُ', #2
u'المترخص': u'الْمُتَرَخِّصِ', #2
u'المتردى': u'الْمُتَرَدِّى', #2
u'المترصات': u'الْمُتْرَصَاتُ', #1
u'المتزارعان': u'الْمُتَزَارِعَانِ', #7
u'المتزارعين': u'الْمُتَزَارِعِينَ', #3
u'المتزارعين': u'الْمُتَزَارِعَيْنِ', #6
u'المتزايلان': u'الْمُتَزَايِلَانِ', #1
u'المتزيون': u'الْمُتَزَيُّونَ', #1
u'المتزيي': u'الْمُتَزَيِّي', #1
u'المتزيين': u'المُتَزَيِّينَ', #1
u'المتساحقان': u'الْمُتَسَاحِقَانِ', #1
u'المتساحقتين': u'المتساحقتين', #3
u'المتساومان': u'الْمُتَسَاوِمَانِ', #4
u'المتساومين': u'الْمُتَسَاوِمِينَ', #1
u'المتساومين': u'الْمُتَسَاوِمَيْنِ', #15
u'المتسبت': u'الْمُتَسَبَّتُ', #1
u'المتسحب': u'الْمُتَسَحَّبُ', #1
u'المتسحر': u'الْمُتَسَحَّرِ', #1
u'المتسحر': u'الْمُتَسَحِّرَ', #1
u'المتسحر': u'الْمُتَسَحِّرِ', #1
u'المتسحرين،': u'الْمُتَسَحِّرِينَ،', #1
u'المتسحرين': u'الْمُتَسَحِّرِينَ', #8
u'المتسخط': u'الْمُتَسَخِّطُ', #1
u'المتسخن': u'الْمُتَسَخَّنِ', #1
u'المتسرعينا': u'الْمُتَسَرّعِينَا', #2
u'المتسري': u'الْمُتَسَرِّي', #1
u'المتسرى': u'الْمُتَسَرَّى', #1
u'المتسلم': u'الْمُتَسَلِّمُ', #1
u'المتسلم': u'الْمُتَسَلِّمِ', #11
u'المتسلم': u'الْمُتَسَلِّمَ', #2
u'المتسمى': u'الْمُتَسَمَّى', #2
u'المتسنن': u'الْمُتَسَنِّنِ', #1
u'المتسننة': u'الْمُتَسَنِّنَةُ', #1
u'المتسننة': u'الْمُتَسَنِّنَةِ', #2
u'المتسور': u'الْمُتَسَوِّرُ', #1
u'المتسورين': u'الْمُتَسَوِّرِينَ', #1
u'المتسوفون': u'الْمُتَسَوِّفُونَ', #1
u'المتسوك': u'الْمُتَسَوِّكُ', #1
u'المتسوك': u'الْمُتَسَوِّكَ', #2
u'المتشابهاتوالوجه': u'الْمُتَشَابِهَاتُوَالْوَجْهُ', #1
u'المتشاغرين،': u'الْمُتَشَاغِرِينَ،', #1
u'المتشاوس': u'الْمُتَشَاوِسِ', #2
u'المتشحط': u'الْمُتَشَحِّطِ', #1
u'المتشربة': u'الْمُتَشَرِّبَةِ', #1
u'المتشربة': u'الْمُتَشَرِّبَةُ', #2
u'المتشرع': u'الْمُتَشَرِّعُ', #7
u'المتشرعة': u'الْمُتَشَرِّعَةُ', #1
u'المتشرعة': u'الْمُتَشَرِّعَةِ', #2
u'المتشرعون': u'الْمُتَشَرِّعُونَ', #1
u'المتشرعين': u'الْمُتَشَرِّعِينَ', #6
u'المتشطط': u'الْمُتَشَطِّطِ', #1
u'المتشقشقة': u'الْمُتَشَقْشِقَةُ', #1
u'المتشوف': u'الْمُتَشَوَّفِ', #1
u'المتشوف': u'الْمُتَشَوِّفَ', #1
u'المتشوف': u'الْمُتَشَوِّفُ', #2
u'المتشوف': u'الْمُتَشَوِّفِ', #6
u'المتشوفة': u'الْمُتَشَوِّفَةِ', #1
u'المتشيخة': u'الْمُتَشَيِّخَةِ', #1
u'المتصارفان': u'المتصارفان', #1
u'المتصارفان': u'الْمُتَصَارِفَانِ', #9
u'المتصارفين': u'الْمُتَصَارِفَيْنِ', #34
u'المتصدقونا': u'الْمُتَصَدِّقُونَا', #2
u'المتصعد': u'الْمُتَصَعِّدُ', #1
u'المتصعد': u'الْمُتَصَعِّدِ', #2
u'المتصفه': u'الْمُتَّصِفَهْ', #2
u'المتصلفين': u'الْمُتَصَلِّفِينَ', #2
u'المتصلفين': u'الْمُتَصَلَّفِينَ', #3
u'المتصول': u'الْمُتَصَوِّلِ', #2
u'المتصيد': u'الْمُتَصَيِّدُ', #1
u'المتصيد': u'الْمُتَصَيِّدِ', #1
u'المتضايفان': u'الْمُتَضَايِفَانِ', #1
u'المتضايفة': u'الْمُتَضَايِفَةِ', #2
u'المتضايفة': u'الْمُتَضَايِفَةُ', #3
u'المتضايفين': u'الْمُتَضَايِفَيْنِ', #31
u'المتضمخ': u'الْمُتَضَمِّخِ', #1
u'المتضمخ': u'المتضمخ', #2
u'المتضمخ': u'الْمُتَضَمِّخَ', #3
u'المتضيف': u'الْمُتَضَيَّفُ', #1
u'المتضيف': u'الْمُتَضَيِّفُ', #1
u'المتطالبان': u'الْمُتَطَالِبَانِ', #1
u'المتطامنة': u'الْمُتَطَامِنَةِ', #1
u'المتظالمان': u'الْمُتَظَالِمَانِ', #1
u'المتظالمين': u'الْمُتَظَالِمَيْنِ', #1
u'المتعاشقان': u'الْمُتَعَاشِقَانِ', #4
u'المتعاصين': u'الْمُتَعَاصِينَ', #1
u'المتعاقل': u'الْمُتَعَاقِلُ', #1
u'المتعال': u'الْمُتَعَال', #1
u'المتعال': u'الْمُتَعَالّ', #1
u'المتعال': u'الْمُتَعَالِ', #22
u'المتعال': u'الْمُتَعَالُ', #6
u'المتعالنات': u'الْمُتَعَالِنَاتِ', #1
u'المتعالى': u'الْمُتَعَالِى', #1
u'المتعاور': u'الْمُتَعَاوِرِ', #2
u'المتعاوضان': u'الْمُتَعَاوَضَانِ', #1
u'المتعاوضين': u'الْمُتَعَاوَضِينَ', #1
u'المتعاوضين': u'الْمُتَعَاوَضَيْنِ', #2
u'المتعاوضين': u'الْمُتَعَاوِضَيْنِ', #24
u'المتعتبين': u'الْمُتَعَتِّبِينَ', #1
u'المتعزر': u'الْمُتَعَزِّرِ', #1
u'المتعضد': u'الْمُتَعَضَّدِ', #1
u'المتعمر،': u'الْمُتْعَمِرِ،', #1
u'المتعمم': u'الْمُتَعَمِّمِ', #3
u'المتعوضة': u'الْمُتَعَوَّضَةُ', #1
u'المتعوضة': u'الْمُتَعَوِّضَةِ', #2
u'المتعى': u'الْمُتْعِىِّ', #1
u'المتعيب': u'الْمُتَعَيَّبَ', #1
u'المتعيب': u'الْمُتَعَيِّبُ', #1
u'المتعيب': u'الْمُتَعَيَّبِ', #2
u'المتعيب': u'الْمُتَعَيِّبَ', #2
u'المتعيب': u'الْمُتَعَيَّبُ', #3
u'المتعيب': u'الْمُتَعَيِّبِ', #3
u'المتغارسين': u'الْمُتَغَارِسَيْنِ', #1
u'المتغاضب': u'الْمُتَغَاضِبُ', #1
u'المتغالبة': u'الْمُتَغَالِبَةُ', #1
u'المتغالبة': u'الْمُتَغَالِبَةِ', #1
u'المتغالين': u'الْمُتَغَالِينَ', #1
u'المتغبر': u'الْمُتَغَبّرِ', #2
u'المتغذى': u'الْمُتَغَذَّى', #1
u'المتغر': u'الْمُتَّغِرِ', #1
u'المتغزي': u'الْمُتَغَزِّي', #1
u'المتغطى': u'الْمُتَغَطَّى', #1
u'المتفاحش': u'الْمُتَفَاحَشِ', #1
u'المتفاحش': u'الْمُتَفَاحِشِ', #10
u'المتفاحش': u'الْمُتَفَاحِشَ', #2
u'المتفاحش': u'الْمُتَفَاحِشُ', #6
u'المتفاحشة': u'الْمُتَفَاحِشَةِ', #15
u'المتفاحشة': u'الْمُتَفَاحِشَةُ', #2
u'المتفاصحون': u'الْمُتَفَاصِحُونَ', #1
u'المتفعل': u'الْمُتَفَعّلُ', #1
u'المتفقا': u'الْمُتَّفِقَا', #1
u'المتفقي': u'الْمُتَّفِقَيْ', #4
u'المتفيهق': u'الْمُتَفَيْهِقُ', #1
u'المتفيهق': u'الْمُتَفَيْهِقِ', #2
u'المتفيهقون': u'الْمُتَفَيْهِقُونَ', #15
u'المتقارضان': u'الْمُتَقَارِضَانِ', #14
u'المتقارضين': u'الْمُتَقَارِضَيْنِ', #11
u'المتقاصرة': u'الْمُتَقَاصِرَةِ', #1
u'المتقاطر': u'الْمُتَقَاطَرِ', #1
u'المتقاطر': u'الْمُتَقَاطِرُ', #2
u'المتقاطر': u'الْمُتَقَاطِرِ', #4
u'المتقاومان': u'الْمُتَقَاوِمَانِ', #1
u'المتقاومين': u'الْمُتَقَاوِمَيْنِ', #1
u'المتقائلين': u'الْمُتَقَائِلَيْنِ', #1
u'المتقايلان': u'الْمُتَقَايِلَانِ', #1
u'المتقايلين': u'الْمُتَقَايِلَيْنِ', #7
u'المتقدما': u'الْمُتَقَدِّمَا', #1
u'المتقدمتي': u'الْمُتَقَدِّمَتَيْ', #1
u'المتقدمي': u'الْمُتَقَدِّمِي', #1
u'المتقدمي': u'الْمُتَقَدِّمَيْ', #2
u'المتقدي': u'الْمُتَّقِدِي', #1
u'المتقى': u'الْمُتَّقِى', #1
u'المتقى': u'الْمُتَّقَى', #5
u'المتقينوالوجه': u'الْمُتَّقِينَوَالْوَجْهُ', #1
u'المتكارى': u'الْمُتَكَارَى', #1
u'المتكاري': u'الْمُتَكَارِي', #122
u'المتكاري': u'الْمُتَكَارِيَ', #3
u'المتكاريان': u'الْمُتَكَارَيَانِ', #1
u'المتكاريان': u'الْمُتَكَارِيَانِ', #4
u'المتكارين': u'الْمُتَكَارِينَ', #1
u'المتكاريين': u'الْمُتَكَارَيَيْنِ', #2
u'المتكاريين': u'الْمُتَكَارِيَيْنِ', #30
u'المتكشفا': u'الْمُتَكَشّفَا', #2
u'المتكفرون': u'الْمُتَكَفِّرُونَ', #1
u'المتكفي': u'الْمُتَكَفِّي', #1
u'المتكمي': u'الْمُتَكَمِّي', #1
u'المتلازقة': u'الْمُتَلَازِقَةُ', #4
u'المتلازقة': u'الْمُتَلَازِقَةِ', #5
u'المتلازقتين': u'الْمُتَلَازِقَتَيْنِ', #1
u'المتلازقين': u'الْمُتَلَازِقَيْنِ', #1
u'المتلحيين': u'الْمُتَلَحِّيِينَ', #1
u'المتلفه': u'الْمُتْلِفَهْ', #1
u'المتلقاة': u'الْمُتَلَقّاةِ', #1
u'المتلقاة': u'الْمُتَلَقَّاةِ', #2
u'المتلقاة': u'الْمُتَلَقَّاةُ', #5
u'المتلقط': u'الْمُتَلَقِّطُ', #2
u'المتلقى': u'الْمُتَلَقَّى', #15
u'المتلمح': u'الْمُتَلَمَّحُ', #1
u'المتمالئة': u'الْمُتَمَالِئَةَ', #1
u'المتمالئة': u'الْمُتَمَالِئَةِ', #1
u'المتمالئون': u'الْمُتَمَالَئُونَ', #1
u'المتمالئون': u'الْمُتَمَالِئُونَ', #3
u'المتمانعان': u'الْمُتَمَانِعَانِ', #1
u'المتمحض': u'الْمُتَمَحَّضُ', #1
u'المتمحض': u'الْمُتَمَحَّضِ', #1
u'المتمحض': u'الْمُتَمَحِّضَ', #1
u'المتمحض': u'الْمُتَمَحِّضِ', #10
u'المتمحض': u'الْمُتَمَحِّضُ', #7
u'المتمحضات': u'الْمُتَمَحِّضَاتُ', #2
u'المتمحضات': u'الْمُتَمَحِّضَاتِ', #9
u'المتمحضة': u'الْمُتَمَحِّضَة', #1
u'المتمحضة': u'الْمُتَمَحِّضَةُ', #1
u'المتمحضة': u'الْمُتَمَحِّضَةِ', #8
u'المتمدحين': u'الْمُتَمَدِّحِينَ', #1
u'المتمسخرين': u'الْمُتَمَسْخِرِينَ', #1
u'المتمشيخة': u'الْمُتَمَشْيِخَةِ', #1
u'المتمعطة': u'الْمُتَمَعِّطَةُ', #1
u'المتمنى': u'الْمُتَمَنِّى', #1
u'المتمنى': u'الْمُتَمَنَّى', #2
u'المتناشد': u'الْمُتَنَاشَدُ', #1
u'المتناضلان': u'الْمُتَنَاضَلَانِ', #2
u'المتناضلان': u'الْمُتَنَاضِلَانِ', #4
u'المتناضلون': u'الْمُتَنَاضَلُونَ', #1
u'المتناضلون': u'الْمُتَنَاضِلُونَ', #4
u'المتناضلين': u'الْمُتَنَاضِلَيْنِ', #17
u'المتناضلين': u'الْمُتَنَاضَلَيْنِ', #8
u'المتنافدة': u'الْمُتَنَافِدَةُ', #1
u'المتنافذة': u'الْمُتَنَافِذَةُ', #7
u'المتناهدين': u'الْمُتَنَاهِدَيْنِ', #1
u'المتنخع': u'المتنخع', #1
u'المتنخل': u'الْمُتَنَخّلُ', #3
u'المتهاجرين': u'الْمُتَهَاجِرِينَ', #1
u'المتهاجرين': u'الْمُتَهَاجِرَيْنِ', #4
u'المتهايأ': u'الْمُتَهَايَأُ', #3
u'المتهايئون': u'الْمُتَهَايِئُونَ', #1
u'المتهايئين': u'الْمُتَهَايِئِينَ', #1
u'المتهب': u'الْمُتَّهَبْ', #1
u'المتهب': u'الْمُتَّهَبَ', #10
u'المتهب': u'الْمُتَّهَبُ', #54
u'المتهب': u'الْمُتَّهِبَ', #6
u'المتهب': u'الْمُتَّهِبُ', #70
u'المتهب': u'الْمُتَّهَبِ', #78
u'المتهب': u'الْمُتَّهِبِ', #88
u'المتهت': u'المُتَّهِتُ', #1
u'المتهوم': u'الْمَتْهُومَ', #1
u'المتهوم': u'الْمُتَهَوِّمِ', #1
u'المتهوم': u'الْمَتْهُومِ', #25
u'المتهوم': u'الْمَتْهُومُ', #3
u'المتهومين': u'الْمَتْهُومِينَ', #1
u'المتهونين': u'الْمُتَهَوِّنِينَ', #1
u'المتهيئ': u'الْمُتَهَيِّئُ', #5
u'المتهيئ': u'الْمُتَهَيِّئِ', #7
u'المتهيئة': u'الْمُتَهَيِّئَةِ', #1
u'المتواجرين': u'الْمُتَوَاجِرَيْنِ', #1
u'المتواصى': u'الْمُتَوَاصَى', #8
u'المتوب': u'الْمَتُوبَ', #1
u'المتوب': u'الْمَتُوبِ', #3
u'المتوثن': u'الْمُتَوَثِّنَ', #1
u'المتوثنين': u'الْمُتَوَثِّنِينَ', #3
u'المتوثي،': u'الْمَتُّوثِيُّ،', #2
u'المتوثى': u'الْمَتُّوثِىُّ', #2
u'المتوشمات': u'الْمُتَوَشِّمَاتِ', #2
u'المتوضي': u'الْمُتَوَضِّي', #1
u'المتوغرة': u'الْمُتَوَغِّرَةَ', #1
u'المتولى': u'الْمُتَوَلَّى', #11
u'المتوني،': u'الْمِتُونِيُّ،', #1
u'المتئد': u'الْمُتَّئِدِ', #1
u'المتيخة': u'الْمِتِّيخَةِ', #1
u'المتيطي': u'الْمُتَيْطِيَّ', #18
u'المتيطي': u'الْمُتَيْطِيِّ', #209
u'المتيطي': u'الْمُتَيْطِيّ', #25
u'المتيطي': u'الْمُتَيْطِيُّ', #761
u'المتيطية': u'الْمُتَيْطِيَّة', #1
u'المتيطية': u'الْمُتَيْطِيَّةِ', #280
u'المتيطية': u'الْمُتَيْطِيَّةَ', #5
u'المتيوي': u'الْمَتْيَوِيُّ', #1
u'المثاعب': u'الْمَثَاعِبُ', #1
u'المثاقلة': u'الْمُثَاقَلَةِ', #2
u'المثالثة': u'الْمُثَالَثَةُ', #1
u'المثالثة': u'الْمُثَالَثَةِ', #1
u'المثالم': u'الْمَثَالِمُ', #3
u'المثانى؟': u'الْمَثَانِى؟', #1
u'المثانى': u'الْمَثَانِى', #12
u'المثبج': u'الْمُثَبَّجِ', #1
u'المثبوتة': u'الْمَثْبُوتَةَ', #1
u'المثبوتة': u'الْمَثْبُوتَةِ', #1
u'المثتقيم': u'الْمُثْتَقِيمَ', #5
u'المثدون': u'المثدون', #1
u'المثدون': u'الْمَثْدُونُ', #1
u'المثعور': u'الْمَثْعُورِ', #1
u'المثغر': u'الْمُثْغِرُ', #1
u'المثغر': u'الْمُثْغِرِ', #2
u'المثغرة': u'الْمُثْغِرَةِ', #4
u'المثغور': u'الْمَثْغُورَ', #2
u'المثغور': u'الْمَثْغُورِ', #33
u'المثغور': u'الْمَثْغُورُ', #4
u'المثغورة': u'الْمَثْغُورَةِ', #5
u'المثفى': u'الْمُثَفَّى', #1
u'المثقالان': u'الْمِثْقَالَانِ', #2
u'المثقالي': u'الْمِثْقَالِيُّ', #2
u'المثقالين': u'الْمِثْقَالَيْنِ', #2
u'المثلا': u'الْمِثْلَا', #1
u'المثلةS': u'الْمُثْلَةِS', #1
u'المثلة': u'الْمَثُلَةَ', #1
u'المثلة': u'الْمُثْلَةِ', #195
u'المثلة': u'الْمَثُلَةُ', #2
u'المثلة': u'الْمُثْلَةُ', #29
u'المثلة': u'الْمُثْلَةَ', #38
u'المثلة': u'الْمَثُلَةِ', #4
u'المثلة': u'الْمُثْلَة', #5
u'المثلوث': u'الْمَثْلُوثِ', #1
u'المثليه': u'الْمِثْلِيَّهْ', #1
u'المثمون': u'الْمَثْمُون', #1
u'المثمون': u'الْمَثْمُونَ', #10
u'المثمون': u'الْمَثْمُونِ', #24
u'المثمون': u'الْمَثْمُونُ', #4
u'المثمونات': u'الْمَثْمُونَاتِ', #1
u'المثمونين': u'الْمَثْمُونَيْنِ', #4
u'المثناتين': u'الْمُثَنَّاتَيْنِ', #1
u'المثنوي': u'الْمَثْنَوِيِّ', #1
u'المثوب': u'الْمُثَوِّبِ', #1
u'المثوب': u'الْمُثَوِّبُ', #5
u'المثوي': u'الْمُثْوِي', #1
u'المثين': u'المثين', #1
u'المجاح': u'الْمُجَاحِ', #46
u'المجاح': u'الْمُجَاحُ', #51
u'المجاح': u'الْمُجَاحَ', #7
u'المجاحة': u'الْمُجَاحَةِ', #2
u'المجاحة': u'الْمُجَاحَةُ', #3
u'المجار': u'الْمُجَارُ', #2
u'المجارير': u'الْمَجَارِيرِ', #2
u'المجازى': u'الْمُجَازَى', #11
u'المجاشعي': u'المُجاشِعِي', #1
u'المجاشعي': u'المُجَاشِعِيّ', #1
u'المجاشعي': u'الْمُجَاشِعِيِّ', #10
u'المجاشعي،': u'المُجَاشِعِيّ،', #2
u'المجاشعي': u'الْمُجَاشِعِيَّ', #2
u'المجاشعي،': u'الْمُجَاشِعِيُّ،', #2
u'المجاشعي': u'الْمُجَاشِعِيُّ', #3
u'المجاشعي،': u'الْمُجَاشِعِيِّ،', #3
u'المجاشعي': u'المجاشعي', #4
u'المجاشعي': u'الْمُجَاشِعِيّ', #4
u'المجاشعى': u'الْمُجَاشِعِىُّ', #4
u'المجاشعى': u'الْمُجَاشِعِىِّ', #6
u'المجاشعية': u'الْمُجَاشِعِيَّةُ', #1
u'المجاشعية': u'الْمُجَاشِعِيَّةِ', #1
u'المجاعل': u'الْمُجَاعَلُ', #11
u'المجاعل': u'الْمُجَاعِلَ', #2
u'المجاعل': u'الْمُجَاعَلِ', #20
u'المجاعل': u'الْمُجَاعَلَ', #6
u'المجاعل': u'الْمُجَاعِلُ', #8
u'المجاعل': u'الْمُجَاعِلِ', #9
u'المجاعلة': u'الْمُجَاعَلَةَ', #1
u'المجاعلة': u'الْمُجَاعَلَةُ', #10
u'المجاعلة': u'الْمُجَاعَلَةِ', #13
u'المجاف': u'المجاف', #1
u'المجالد،': u'الْمُجَالِدُ،', #1
u'المجالد': u'الْمُجَالِدِ', #15
u'المجالد،': u'الْمُجَالِدِ،', #5
u'المجالد': u'الْمُجَالِدُ', #6
u'المجالدي': u'الْمُجَالِدِيُّ', #1
u'المجامد': u'الْمَجَامِدِ', #2
u'المجامعه': u'الْمُجَامَعَهْ', #1
u'المجاهز': u'الْمُجَاهِزِ', #1
u'المجاهزون': u'الْمُجَاهِزُونَ', #5
u'المجاهزين': u'الْمُجَاهِزِينَ', #5
u'المجاورية': u'الْمُجَاوِرِيَّةِ', #1
u'المجبوب': u'المجبوب', #1
u'المجبوب': u'الْمَجْبُوبُ', #100
u'المجبوب': u'الْمَجْبُوبِ', #174
u'المجبوب': u'الْمَجْبُوبَ', #38
u'المجبوبة': u'الْمَجْبُوبَةُ', #1
u'المجبوبة،': u'الْمَجْبُوبَةِ،', #1
u'المجبوبة': u'الْمَجْبُوبَة', #3
u'المجبوبة': u'الْمَجْبُوبَةِ', #3
u'المجبوبون': u'الْمَجْبُوبُونَ', #2
u'المجبى': u'الْمُجَبَّى', #1
u'المجبى': u'الْمُجْبَى', #3
u'المجة': u'المجة', #1
u'المجة،': u'المجة،', #1
u'المجة': u'الْمَجَّةَ', #1
u'المجة': u'الْمَجَّةِ', #9
u'المجتاب': u'المجتاب', #2
u'المجتدي': u'الْمُجْتَدِي', #1
u'المجتدي': u'الْمُجْتَدِيَ', #1
u'المجتزئة': u'الْمُجْتَزِئَةِ', #1
u'المجتن': u'الْمُجْتَنِّ', #10
u'المجتنى': u'الْمُجْتَنَى', #1
u'المجثمة': u'الْمُجْثَمَة', #1
u'المجثمة،': u'الْمُجَثَّمَةِ،', #1
u'المجثمة': u'الْمُجَثَّمَةِ', #14
u'المجثمة': u'الْمُجَثَّمَة', #2
u'المجثمة': u'الْمُجَثَّمَةَ', #4
u'المجثمة': u'الْمُجَثَّمَةُ', #7
u'المجح': u'المجح', #1
u'المجحرات': u'الْمُجْحَرَاتِ', #1
u'المجحود': u'الْمَجْحُود', #1
u'المجحود': u'الْمَجْحُودَ', #11
u'المجحود': u'الْمَجْحُودُ', #14
u'المجحود': u'الْمَجْحُودِ', #46
u'المجحودة': u'الْمَجْحُودَةِ', #10
u'المجحودة': u'الْمَجْحُودَةُ', #12
u'المجحودة': u'الْمَجْحُودَةَ', #5
u'المجحودتين': u'الْمَجْحُودَتَيْنِ', #3
u'المجحودين': u'الْمَجْحُودَيْنِ', #1
u'المجحور': u'الْمَجْحُورُ', #1
u'المجخى': u'المجخى', #2
u'المجدح': u'الْمِجْدَح', #2
u'المجدح': u'الْمِجْدَحُ', #3
u'المجدح': u'الْمِجْدَحِ', #3
u'المجدود': u'الْمَجْدُودِ', #2
u'المجدود': u'الْمَجْدُودُ', #3
u'المجدودة': u'الْمَجْدُودَةِ', #1
u'المجدولي': u'الْمَجْدُولِي', #1
u'المجدولي': u'الْمَجْدُولِيُّ', #1
u'المجذم': u'الْمُجَذَّمِ', #1
u'المجذم': u'الْمُجْذَمِ', #2
u'المجذمين': u'الْمُجَذَّمِينَ', #3
u'المجذوذ': u'الْمَجْذُوذِ', #11
u'المجذوذ': u'الْمَجْذُوذُ', #3
u'المجذوذة': u'الْمَجْذُوذَةَ', #2
u'المجذوذة': u'الْمَجْذُوذَةِ', #4
u'المجذية': u'المجذية', #2
u'المجذية': u'الْمُجْذِيَةِ', #4
u'المجراة': u'الْمُجْرَاةُ', #2
u'المجراة': u'الْمُجْرَاةِ', #4
u'المجروش': u'الْمَجْرُوشُ', #2
u'المجزء': u'الْمُجَزَّءَ', #1
u'المجزره': u'الْمَجْزَرَهْ', #1
u'المجزز': u'الْمُجَزِّزُ', #1
u'المجزع': u'الْمُجَزّعِ', #1
u'المجزف': u'الْمُجَزَّفِ', #1
u'المجزور': u'الْمَجْزُورُ', #1
u'المجزور': u'الْمَجْزُورِ', #1
u'المجزورتين': u'الْمَجْزُورَتَيْنِ', #1
u'المجزوز': u'الْمَجْزُوزَ', #2
u'المجزوز': u'الْمَجْزُوزُ', #5
u'المجزوز': u'الْمَجْزُوزِ', #6
u'المجزوزة': u'الْمَجْزُوزَةُ', #2
u'المجزى': u'الْمُجْزَى', #1
u'المجسار': u'الْمِجْسَارَ', #1
u'المجسطي': u'الْمَجِسْطِي', #1
u'المجشة': u'الْمَجِشّةِ', #1
u'المجشر': u'الْمُجَشِّرِ', #1
u'المجشر': u'الْمِجْشَرِ', #2
u'المجشي': u'الْمُجَشِّي', #1
u'المجعولية': u'الْمَجْعُولِيَّةُ', #1
u'المجعولية': u'الْمَجْعُولِيَّةِ', #2
u'المجفوف': u'الْمَجْفُوفِ', #1
u'المجلاة': u'الْمُجَلَّاةُ', #1
u'المجلل': u'المجلل', #1
u'المجلل': u'الْمُجَلَّلُ', #1
u'المجلل،': u'الْمُجَلَّلِ،', #1
u'المجلل': u'الْمُجَلِّلِ', #5
u'المجلل': u'الْمُجَلّلِ', #9
u'المجلوبة': u'الْمَجْلُوبَةِ', #10
u'المجلوبة': u'الْمَجْلُوبَة', #2
u'المجلوبة': u'الْمَجْلُوبَةَ', #2
u'المجلوبون': u'الْمَجْلُوبُونَ', #1
u'المجلوبين': u'الْمَجْلُوبِينَ', #21
u'المجلوة': u'الْمَجْلُوَّةِ', #2
u'المجمة': u'المجمة', #1
u'المجموعةمن': u'الْمَجْمُوعَةِمِنْ', #1
u'المجموعي': u'الْمَجْمُوعِيُّ', #16
u'المجموعي': u'الْمَجْمُوعِيِّ', #25
u'المجموعي': u'الْمَجْمُوعِيَّ', #3
u'المجموعي': u'الْمَجْمُوعِي', #5
u'المجنف': u'الْمُجْنِفِ', #1
u'المجهولية': u'الْمَجْهُولِيَّةَ', #1
u'المجهولية': u'الْمَجْهُولِيَّةُ', #1
u'المجوب': u'المجوب', #1
u'المجوب': u'الْمَجُوبُ', #1
u'المجوح': u'الْمَجُوحِ', #1
u'المجور': u'الْمُجوَّرُ', #1
u'المجوسوي': u'الْمَجُوسُوِي', #1
u'المجوسى': u'الْمَجُوسِىُّ', #1
u'المجوسى': u'الْمَجُوسِىِّ', #9
u'المجىء': u'الْمَجِىءَ', #1
u'المجىء': u'الْمَجِىءُ', #1
u'المجيدح': u'الْمُجَيْدِحُ', #1
u'المجيدية': u'الْمَجِيدِيَّةُ', #1
u'المجيدية': u'الْمُجَيْدِيَّةُ', #1
u'المجيدية': u'الْمَجِيدِيَّةِ', #2
u'المجيدية': u'الْمُجَيْدِيَّةِ', #2
u'المجيىء': u'المجيىء', #8
u'المحابأه': u'الْمُحَابَأَهْ', #1
u'المحابى': u'الْمُحَابَى', #9
u'المحابيب': u'الْمَحَابِيبِ', #7
u'المحاججة': u'الْمُحَاجَجَةَ', #1
u'المحاججة': u'الْمُحَاجَجَةُ', #1
u'المحاجزة': u'الْمُحَاجَزَةُ', #1
u'المحاجزة': u'الْمُحَاجَزَةِ', #1
u'المحاجن': u'الْمَحَاجِنُ', #1
u'المحاجير': u'الْمَحَاجِيرَ', #2
u'المحاجير': u'الْمَحَاجِيرِ', #22
u'المحاجير': u'الْمَحَاجِيرُ', #3
u'المحاذى': u'الْمُحَاذَى', #1
u'المحاربى،': u'المحاربى،', #1
u'المحاربى': u'الْمُحَارِبِىِّ', #12
u'المحاربى': u'الْمُحَارِبِىَّ', #2
u'المحاربى': u'الْمُحَارِبِىُّ', #57
u'المحارس': u'الْمَحَارِسِ', #1
u'المحارما': u'الْمَحَارِمَا', #5
u'المحاز': u'الْمُحَازِ', #36
u'المحاز': u'الْمُحَازَ', #4
u'المحاز': u'الْمُحَازُ', #6
u'المحازات': u'الْمُحَازَاتِ', #1
u'المحازقة': u'الْمُحَازَقَةِ', #1
u'المحاصات': u'الْمُحَاصَّاتُ', #1
u'المحاصة': u'الْمُحَاصَّةَ', #24
u'المحاصة': u'الْمُحَاصَّةُ', #47
u'المحاصة': u'الْمُحَاصَّةِ', #96
u'المحاصصة': u'الْمُحَاصَصَةُ', #1
u'المحاصصة': u'الْمُحَاصَصَةَ', #4
u'المحاططه': u'الْمُحَاطَطَهْ', #1
u'المحاققة': u'الْمُحَاقَقَةُ', #1
u'المحاقلة': u'المحاقلة', #1
u'المحاقلة؟': u'الْمُحَاقَلَةُ؟', #1
u'المحاقلة': u'الْمُحَاقَلَة', #2
u'المحاقلة،': u'الْمُحَاقَلَةِ،', #3
u'المحاقلة': u'الْمُحَاقَلَةُ', #30
u'المحاقلة': u'الْمُحَاقَلَةَ', #5
u'المحاقلة': u'الْمُحَاقَلَةِ', #98
u'المحاكرة': u'الْمُحَاكَرَةِ', #2
u'المحالا': u'الْمُحَالَا', #1
u'المحاللة': u'الْمُحَالَلَةَ', #1
u'المحاللة': u'الْمُحَالَلَةِ', #1
u'المحاملي،': u'المحاملي،', #1
u'المحاملى': u'الْمَحَامِلِىِّ', #1
u'المحاملى': u'الْمَحَامِلِىُّ', #10
u'المحاملي': u'الْمَحَامِلِيُّ', #192
u'المحاملي': u'الْمَحَامِلِيّ', #2
u'المحاملي': u'الْمَحَامِلِيَّ', #2
u'المحاملي،': u'الْمَحَامِلِيُّ،', #6
u'المحاملي،': u'الْمَحَامِلِيِّ،', #7
u'المحاملي': u'الْمَحَامِلِيِّ', #72
u'المحاويج': u'الْمَحَاوِيجُ', #1
u'المحاويج': u'الْمَحَاوِيجَ', #2
u'المحاويج': u'الْمَحَاوِيجِ', #21
u'المحائض': u'الْمَحَائِضُ', #2
u'المحاير': u'الْمَحَايِرُ', #1
u'المحايض': u'الْمَحَايِضِ', #1
u'المحايض': u'الْمَحَايِضُ', #2
u'المحبار': u'المحبار', #1
u'المحبق': u'المحبق', #1
u'المحبق': u'الْمُحَبِّق', #1
u'المحبق': u'الْمُحَبَّقِ', #11
u'المحبق': u'الْمُحَبِّقِ', #30
u'المحبنطئ': u'الْمُحْبَنْطِئُ', #1
u'المحبوبي': u'الْمَحْبُوبِيِّ', #103
u'المحبوبي،': u'المحبوبي،', #12
u'المحبوبي،': u'الْمَحْبُوبِيِّ،', #16
u'المحبوبي': u'الْمَحْبُوبِي', #4
u'المحبوبي': u'الْمَحْبُوبِيَّ', #5
u'المحبوبي،': u'الْمَحْبُوبِيُّ،', #68
u'المحبوبى': u'الْمَحْبُوبِىُّ', #87
u'المحبوبي': u'الْمَحْبُوبِيُّ', #95
u'المحبوبية': u'الْمَحْبُوبِيَّةِ', #4
u'المحتبى': u'الْمُحْتَبِى', #2
u'المحتبى': u'الْمُحْتَبَى', #3
u'المحتجر': u'الْمُحْتَجِرِ', #1
u'المحتجر': u'الْمُحْتَجِرُ', #3
u'المحتجم': u'الْمُحْتَجَمُ', #1
u'المحتجم': u'الْمُحْتَجِمِ', #5
u'المحتجم': u'الْمُحْتَجِمُ', #7
u'المحترث': u'الْمُحْتَرَثِ', #1
u'المحترث': u'الْمُحْتَرِثِ', #1
u'المحتشى': u'الْمُحْتَشَى', #3
u'المحتط': u'الْمُحْتَطِّ', #1
u'المحتظر': u'الْمُحْتَظِرِ', #2
u'المحتف': u'الْمُحْتَفِّ', #3
u'المحتفة': u'الْمُحْتَفَّةَ', #1
u'المحتفة': u'الْمُحْتَفَّةِ', #6
u'المحتفز': u'المحتفز', #1
u'المحتفز،': u'الْمُحْتَفِزِ،', #1
u'المحتفز': u'الْمُحْتَفِزِ', #2
u'المحتوش': u'الْمُحْتَوِشِ', #3
u'المحتوش': u'الْمُحْتَوَشِ', #4
u'المحتوش': u'الْمُحْتَوَشُ', #9
u'المحتوش': u'الْمُحْتَوِشُ', #9
u'المحتوشين': u'الْمُحْتَوَشَيْنِ', #1
u'المحتوشين': u'الْمُحْتَوِشَيْنِ', #4
u'المحجبا': u'الْمُحَجَّبَا', #2
u'المحجلون': u'الْمُحَجَّلُونَ', #14
u'المحجن،': u'الْمِحْجَنِ،', #1
u'المحجن': u'الْمِحْجَنِ', #11
u'المحجن': u'الْمِحْجَن', #3
u'المحجن': u'المحجن', #5
u'المحجن': u'الْمِحْجَنَ', #5
u'المحجن': u'الْمِحْجَنُ', #5
u'المحجوج': u'الْمَحْجُوجِ', #103
u'المحجوج': u'الْمَحْجُوجُ', #21
u'المحجوج': u'الْمَحْجُوجَ', #5
u'المحجوجين': u'الْمَحْجُوجِينَ', #1
u'المحجورية': u'الْمَحْجُورِيَّةَ', #1
u'المحجورية': u'الْمَحْجُورِيَّةُ', #1
u'المحجوم': u'الْمَحْجُومَ', #3
u'المحجوم': u'الْمَحْجُومُ', #6
u'المحجوم': u'الْمَحْجُومِ', #6
u'المحدة': u'الْمُحِدَّةِ', #17
u'المحدة': u'الْمُحِدَّةُ', #18
u'المحدة': u'الْمُحِدَّةَ', #2
u'المحدة': u'الْمُحَدَّةُ', #3
u'المحدة': u'الْمُحَدَّةِ', #5
u'المحدر': u'الْمُحَدَّرِ', #1
u'المحدل': u'الْمُحْدَلِ', #1
u'المحربا': u'الْمُحَرِّبَا', #1
u'المحرث': u'الْمُحَرّثِ', #1
u'المحرث': u'الْمَحْرَثِ', #3
u'المحرس': u'الْمُحْرِسِ', #2
u'المحرس': u'الْمَحْرَسِ', #6
u'المحرما': u'الْمَحْرَمَا', #1
u'المحرما': u'الْمُحَرَّمَا', #1
u'المحرمتي': u'الْمُحَرَّمَتَيْ', #1
u'المحروب': u'المحروب', #1
u'المحروب': u'الْمَحْرُوبُ', #2
u'المحروز': u'الْمَحْرُوزِ', #1
u'المحروزة': u'الْمَحْرُوزَةَ', #1
u'المحروص': u'الْمَحْرُوصِ', #1
u'المحزو': u'الْمَحْزُوّ', #2
u'المحسد': u'الْمُحَسّدَ', #1
u'المحسر': u'الْمُحَسّرِ', #1
u'المحسر': u'الْمُحَسِّرُ', #1
u'المحسر': u'الْمُحَسِّرِ', #2
u'المحسنية': u'المحسنية', #1
u'المحشرة': u'الْمَحْشَرَةِ', #1
u'المحصر': u'الْمَحْصَرَ', #1
u'المحصر': u'الْمُحَصَّرُ', #1
u'المحصر': u'الْمُحْصَر', #1
u'المحصر،': u'الْمُحْصَرُ،', #1
u'المحصر': u'الْمُحْصِرِ', #11
u'المحصر': u'الْمُحْصَرِ', #245
u'المحصر': u'الْمُحَصَّرِ', #3
u'المحصر': u'الْمُحْصِرُ', #4
u'المحصر': u'الْمُحْصَرَ', #65
u'المحصر': u'الْمُحْصَرُ', #83
u'المحصرة': u'الْمُحْصَرَةِ', #3
u'المحصرين': u'الْمُحْصَرِينَ', #1
u'المحصلا': u'الْمُحَصَّلَا', #1
u'المحصنها': u'الْمُحَصِّنُهَا', #1
u'المحصوب': u'الْمَحْصُوبَ', #1
u'المحصوليات': u'الْمَحْصُولِيَّاتِ', #3
u'المحقب': u'الْمُحْقِبُ', #1
u'المحقيين': u'الْمَحْقِيِّينَ', #1
u'المحكرة': u'الْمُحْكَرَةَ', #1
u'المحكرة': u'الْمُحْكَرَةِ', #1
u'المحكك': u'المَحَكَّك', #1
u'المحكك': u'الْمُحَكّكُ', #3
u'المحكك': u'الْمُحَكَّكُ', #5
u'المحكى': u'الْمَحْكِىُ', #1
u'المحكيه': u'الْمَحْكِيَّهْ', #1
u'المحلا': u'الْمَحَلَّا', #1
u'المحلاب': u'الْمِحْلَابِ', #1
u'المحلبة': u'الْمُحْلِبَةُ', #1
u'المحلمي': u'الْمُحَلِّمِيِّ', #1
u'المحلمي،': u'الْمُحَلِّمِيُّ،', #2
u'المحله': u'الْمَحَلّهْ', #1
u'المحله': u'الْمَحِلّهْ', #1
u'المحمدابادي،': u'الْمُحَمَّدَابَادِيُّ،', #1
u'المحمدآباذى': u'الْمُحَمَّدَآبَاذِىُّ', #1
u'المحمدآباذى': u'الْمُحَمَّدْآبْاذِىُّ', #1
u'المحمداباذى': u'الْمُحَمْدَابَاذِىُّ', #1
u'المحمداباذى': u'المُحَمَّدَابَاذِىُّ', #10
u'المحمدآباذى': u'الْمُحَمَّدْآبَاذِىُّ', #5
u'المحمداباذى': u'الْمُحَمَّدَابَاذِىُّ', #83
u'المحمدباذى': u'الْمُحَمَّدَبَاذِىُّ', #1
u'المحمودي': u'الْمَحْمُودِيُّ', #1
u'المحمودي': u'الْمَحْمُودِيِّ', #1
u'المحمودي': u'الْمَحْمُودِيّ', #2
u'المحمودى': u'الْمَحْمُودِىُّ', #2
u'المحمودية': u'الْمَحْمُودِيَّةُ', #2
u'المحمودية': u'الْمَحْمُودِيَّةِ', #6
u'المحنتم': u'الْمُحَنْتَمَ', #2
u'المحنق': u'الْمُحُنَقُ', #1
u'المحنق': u'الْمُحْنِقُ', #1
u'المحنق': u'الْمُحْنَقُ', #6
u'المحنوذ': u'المحنوذ', #2
u'المحنوني': u'الْمَحْنُونِيُّ', #1
u'المحوج': u'الْمُحْوَجُ', #1
u'المحوج': u'الْمُحْوِجِ', #28
u'المحوج': u'الْمُحْوِجُ', #29
u'المحوج': u'الْمُحَوِّجُ', #4
u'المحوج': u'الْمُحَوِّجِ', #4
u'المحوج': u'الْمُحْوِجَ', #4
u'المحوجات': u'الْمُحْوِجَاتِ', #1
u'المحوجة': u'الْمُحْوِجَةَ', #2
u'المحوجة': u'الْمُحْوِجَةُ', #2
u'المحوجة': u'الْمُحْوِجَةِ', #8
u'المحوجين': u'الْمُحْوِجَيْنِ', #2
u'المحوروالوجه': u'الْمِحْوَرُوَالْوَجْهُ', #1
u'المحومدة': u'الْمُحَوْمَدَةِ', #1
u'المحياة': u'المُحَيَّاةِ', #1
u'المحياة،': u'الْمُحَيَّاةِ،', #1
u'المحياة': u'الْمُحْيَاةُ', #12
u'المحياة': u'الْمُحْيَاةِ', #12
u'المحياة': u'الْمُحَيَّاةَ', #2
u'المحياة': u'الْمُحْيَاةَ', #2
u'المحياة': u'الْمُحَيَّاةُ', #3
u'المحياة': u'الْمُحَيَّاةِ', #8
u'المحيس': u'الْمُحَيَّسُ', #1
u'المحيصن': u'الْمُحَيْصِنِ', #1
u'المحيوي': u'الْمَحْيَوِيُّ', #2
u'المحيى': u'الْمُحْيِى', #1
u'المخا': u'الْمَخَا', #1
u'المخابأة': u'الْمُخَابَأَةِ', #1
u'المخاتيم': u'الْمَخَاتِيمُ', #1
u'المخاتيم': u'الْمَخَاتِيمَ', #6
u'المخاتيم': u'الْمَخَاتِيمِ', #7
u'المخادن': u'الْمُخَادِنُ', #1
u'المخارجة': u'الْمُخَارَجَةُ', #12
u'المخارجة': u'الْمُخَارَجَةَ', #2
u'المخارجة': u'الْمُخَارَجَةِ', #22
u'المخارجين': u'المخارجين', #1
u'المخارصة': u'المخارصة', #1
u'المخارف': u'الْمَخَارِفُ', #1
u'المخارف': u'الْمَخَارِفِ', #1
u'المخارق': u'المخارق', #1
u'المخارق،': u'المخارق،', #1
u'المخارق،': u'الْمُخَارِقِ،', #11
u'المخارق': u'الْمَخَارِقَ', #3
u'المخارق': u'الْمُخَارِقُ', #3
u'المخارق': u'الْمَخَارِقِ', #4
u'المخارق': u'الْمُخَارِقِ', #62
u'المخارم': u'الْمَخَارِمَ', #1
u'المخارم': u'الْمَخَارِمُ', #2
u'المخارم': u'الْمَخَارِمِ', #2
u'المخازيا': u'الْمَخَازِيَا', #2
u'المخاص': u'الْمُخَاصِّ', #1
u'المخاصب': u'الْمَخَاصِبَ', #1
u'المخاصيب': u'الْمَخَاصِيبُ', #1
u'المخاضة': u'الْمَخَاضَةِ', #1
u'المخاضرة': u'الْمُخَاضَرَة', #1
u'المخاضرة': u'الْمُخَاضَرَةُ', #1
u'المخاضرة': u'الْمُخَاضَرَةِ', #3
u'المخاطة': u'الْمُخَاطَةُ', #1
u'المخاطة': u'الْمُخَاطَةِ', #1
u'المخافت': u'الْمُخَافِتِ', #1
u'المخال': u'الْمُخَالِ', #1
u'المخالص': u'الْمَخَالِصِ', #1
u'المخالع': u'الْمُخَالِعِ', #20
u'المخالع': u'الْمُخَالَعُ', #28
u'المخالع': u'الْمُخَالِعُ', #31
u'المخالع': u'الْمُخَالَعِ', #34
u'المخالع': u'الْمُخَالِعَ', #4
u'المخالع': u'الْمُخَالَعَ', #9
u'المخالفه': u'الْمُخَالَفَهْ', #2
u'المخاللة': u'الْمُخَالَلَةِ', #1
u'المخاليق': u'الْمَخَالِيقَ', #2
u'المخامر': u'الْمُخَامِرِ', #1
u'المخائض': u'الْمَخَائِضِ', #4
u'المخايلين': u'الْمُخَايِلِينَ', #1
u'المخبت': u'الْمُخْبِتُ', #1
u'المخبتون،': u'المخبتون،', #1
u'المخبتون': u'الْمُخْبِتُونَ', #1
u'المخبتين': u'الْمُخْبِتِينَ', #15
u'المخبث': u'الْمُخَبَّثِ', #1
u'المخبث': u'الْمُخْبِث', #1
u'المخبث': u'الْمُخْبَثِ', #2
u'المخبث': u'الْمُخْبِثِ', #4
u'المخبثة': u'الْمُخَبِّثَةَ', #1
u'المخبل': u'المخبل', #1
u'المخبل': u'الْمُخَبَّلُ', #1
u'المخبل': u'الْمُخَبَّلِ', #1
u'المخبل': u'الْمُخْبَلُ', #1
u'المخبل': u'الْمُخَبّلُ', #2
u'المخبل': u'الْمُخَبّلِ', #2
u'المخبور': u'الْمَخْبُورِ', #1
u'المخبورة': u'الْمَخْبُورَةِ', #2
u'المخبيات': u'الْمُخَبَّيَاتِ', #1
u'المختال': u'الْمُخْتَال', #1
u'المختال': u'الْمُخْتَالُ', #17
u'المختال': u'الْمُخْتَالَ', #3
u'المختال': u'الْمُخْتَالِ', #3
u'المخترف': u'الْمُخْتَرَف', #1
u'المخترف': u'الْمُخْتَرِف', #1
u'المخترف': u'الْمُخْتَرِفُ', #1
u'المختشع': u'الْمُخْتَشِعَ', #1
u'المختصروالدليل': u'الْمُخْتَصَرِوَالدَّلِيلُ', #1
u'المختفى': u'الْمُخْتَفِى', #2
u'المختلج': u'الْمُخْتَلِجِ', #1
u'المختلج»': u'الْمُخْتَلِجِ»', #1
u'المختلج': u'الْمُخْتَلَجِ', #2
u'المختلع': u'الْمُخْتَلَعُ', #1
u'المختلع': u'الْمُخْتَلَعِ', #1
u'المختلع': u'الْمُخْتَلِعُ', #13
u'المختلع': u'الْمُخْتَلِعِ', #18
u'المختلع': u'الْمُخْتَلِعَ', #6
u'المختلعات': u'الْمُخْتَلِعَاتُ', #3
u'المختلعات': u'الْمُخْتَلِعَاتِ', #6
u'المختلعة': u'الْمُخْتَلِعَةَ', #31
u'المختلعة': u'الْمُخْتَلِعَةُ', #52
u'المختلعة': u'الْمُخْتَلِعَةِ', #55
u'المختلفا': u'الْمُخْتَلِفَا', #3
u'المختلفتي': u'الْمُخْتَلِفَتَيْ', #3
u'المختلفي': u'الْمُخْتَلِفَيْ', #10
u'المختلفي': u'الْمُخْتَلِفِي', #3
u'المختلفية': u'المختلفية', #1
u'المختلى': u'الْمُخْتَلَى', #7
u'المختم': u'الْمُخَتّمِ', #1
u'المخدات': u'الْمِخَدَّاتِ', #2
u'المخدج': u'المخدج', #2
u'المخدج': u'الْمُخْدَجُ', #2
u'المخدج،': u'الْمُخْدَجَ،', #2
u'المخدج': u'الْمُخْدَجِ', #3
u'المخدج': u'الْمُخْدَجَ', #7
u'المخدجي': u'الْمُخْدِجِيُّ', #1
u'المخدجي،': u'الْمُخْدَجِيَّ،', #1
u'المخدجى': u'الْمَخْدِجِىَّ', #1
u'المخدجى': u'الْمَخْدِجِىُّ', #1
u'المخدجي': u'الْمُخْدَجِيُّ', #11
u'المخدجى': u'الْمُخْدَجِىُّ', #2
u'المخدجي': u'الْمُخْدَجِيِّ', #3
u'المخدجى': u'الْمُخْدَجِىَّ', #3
u'المخدجي': u'الْمُخْدَجِيَّ', #5
u'المخدوش': u'الْمَخْدُوشَ', #1
u'المخدينة': u'المخدينة', #1
u'المخذل': u'الْمُخَذِّلِ', #1
u'المخذل': u'الْمُخْذِلِ', #1
u'المخذل': u'الْمُخَذِّلَ', #2
u'المخذل': u'الْمُخْذِلَ', #2
u'المخذل': u'الْمُخَذِّلُ', #7
u'المخذلين': u'الْمُخَذّلِينَ', #1
u'المخذم،': u'الْمِخْذَمُ،', #1
u'المخذم': u'الْمِخْذَمُ', #4
u'المخراف': u'المخراف', #1
u'المخراف': u'الْمِخْرَافَ', #1
u'المخراف': u'الْمِخْرَافِ', #2
u'المخراقي،': u'الْمِخْرَاقِيُّ،', #1
u'المخردل': u'الْمُخَرْدَلُ', #5
u'المخرف': u'المخرف', #1
u'المخرف': u'الْمَخْرَفَ', #1
u'المخرف': u'الْمَخْرَفِ', #1
u'المخرف': u'الْمَخْرِفُ', #1
u'المخرف': u'الْمَخْرَفُ', #4
u'المخرفة': u'المخرفة', #1
u'المخرفة': u'الْمُخْرَفَةُ', #2
u'المخرفجة': u'الْمُخَرْفَجَةِ', #1
u'المخرق': u'الْمُخْرَقِ', #1
u'المخرق': u'الْمُخْرِقِ', #1
u'المخرق': u'الْمُخَرَّقِ', #10
u'المخرق': u'المخرق', #2
u'المخرق': u'الْمُخْرِقُ', #2
u'المخرق': u'الْمُخَرَّقَ', #7
u'المخرقة': u'الْمَخْرَقَةِ', #1
u'المخرقة': u'الْمُخَرَّقَةِ', #2
u'المخرمي،': u'الْمخرمِيُّ،', #1
u'المخرمي': u'الْمُخَرِّمِيِّ', #1
u'المخرمي،': u'الْمُخَرِمِّيِّ،', #1
u'المخرمي،': u'الْمُخَرَّمِيُّ،', #1
u'المخرمي،': u'الْمُخَرَّمِيِّ،', #1
u'المخرمى': u'الْمَخْرَمِىِّ', #1
u'المخرمى': u'الْمَخْرِّمِىُّ', #1
u'المخرمى': u'الْمُخَرِّمِىِّ', #1
u'المخرمى': u'الْمَخْرَمِىُّ', #11
u'المخرمي،': u'المخرمي،', #2
u'المخرمي': u'الْمَخْرَمِيِّ', #2
u'المخرمى': u'الْمُخَرِّمِىُّ', #28
u'المخرمي': u'الْمَخْرَمِيَّ', #3
u'المخرمي،': u'الْمُخَرِّمِيُّ،', #31
u'المخرمي': u'الْمَخْرَمِيُّ', #4
u'المخرمي،': u'الْمَخْرَمِيِّ،', #4
u'المخرمى': u'الْمُخَرَّمِىُّ', #4
u'المخرمي،': u'الْمُخَرِّمِيِّ،', #6
u'المخرمي،': u'الْمَخْرَمِيُّ،', #7
u'المخرمي': u'الْمُخَرِّمِيُّ', #8
u'المخروز': u'الْمَخْرُوز', #1
u'المخروز': u'الْمَخْرُوزِ', #1
u'المخروزة': u'الْمَخْرُوزَةِ', #2
u'المخروص': u'الْمَخْرُوصُ', #13
u'المخروص': u'الْمَخْرُوصِ', #31
u'المخروص': u'الْمَخْرُوص', #4
u'المخزوم': u'الْمَخْزُومِ', #1
u'المخزومتين': u'الْمَخْزُومَتَيْنِ', #1
u'المخزومى': u'الْمَخْزُوِمِىُّ', #1
u'المخزومى': u'الْمَخْزُومِىِّ', #18
u'المخزومى': u'الْمَخْزُومِىُّ', #82
u'المخزومى': u'الْمَخْزُومِىَّ', #9
u'المخش': u'الْمُخَشّ', #1
u'المخشوش': u'المخشوش', #1
u'المخشوش': u'الْمَخْشُوشِ', #3
u'المخصر': u'الْمُخَصَّرُ', #1
u'المخصرا': u'الْمُخَصّرَا', #3
u'المخصمة': u'الْمُخْصَمَةِ', #1
u'المخصوصية': u'الْمَخْصُوصِيَّةِ', #2
u'المخصوف': u'الْمَخْصُوف', #2
u'المخصوف': u'الْمَخْصُوفَ', #2
u'المخصومة': u'الْمَخْصُومَةِ', #2
u'المخصومين': u'الْمَخْصُومِينَ', #1
u'المخضل': u'الْمُخْضَلُ', #1
u'المخضل': u'الْمُخْضِلُ', #2
u'المخضوب': u'المَخْضُوبُ', #1
u'المخضوب،': u'المَخْضُوبُ،', #1
u'المخضوب،': u'الْمَخْضُوبُ،', #1
u'المخضوب': u'الْمَخْضُوبَ', #2
u'المخضوب': u'الْمَخْضُوبُ', #3
u'المخضوب': u'الْمَخْضُوبِ', #3
u'المخضوب،': u'الْمَخْضُوبِ،', #4
u'المخضود': u'الْمَخْضُودُ', #1
u'المخضوف': u'المَخْضُوفُ', #1
u'المخطرة': u'الْمُخْطِرَةِ', #3
u'المخفوض': u'الْمَخْفُوضَ', #1
u'المخفوض': u'الْمَخْفُوضِ', #14
u'المخفوض': u'الْمَخْفُوضُ', #4
u'المخفوضة': u'الْمَخْفُوضَةِ', #2
u'المخلدى': u'الْمَخْلَدِىُّ', #1
u'المخلصيات': u'الْمُخَلَّصِيَّاتِ', #1
u'المخلفو': u'الْمُخْلِفُو', #2
u'المخلو': u'الْمَخْلُوُّ', #1
u'المخلو': u'الْمَخْلُوِّ', #1
u'المخلوقية': u'الْمَخْلُوقِيَّةُ', #1
u'المخلوقية': u'الْمَخْلُوقِيَّةِ', #2
u'المخمص': u'الْمُخَمَّصُ', #1
u'المخمصة': u'المخمصة', #1
u'المخمصة': u'الْمَخْمَصَةَ', #1
u'المخمصة': u'الْمَخْمَصَةُ', #11
u'المخمصة': u'الْمَخْمَصَةِ', #119
u'المخنف': u'الْمِخْنَفِ', #1
u'المخولا': u'الْمُخْوِلَا', #2
u'المخيس': u'الْمَخِيسِ', #1
u'المخيس': u'الْمُخَيَّسُ', #1
u'المخيس': u'الْمُخَيْسِ', #1
u'المخيس،': u'الْمُخَيِّسِ،', #1
u'المخيس': u'الْمُخَيّسُ', #2
u'المدا': u'الْمَدَا', #2
u'المدابغي': u'الْمَدَابِغِيَّ', #2
u'المدابغي': u'الْمُدَابِغِيِّ', #2
u'المدابغي': u'الْمَدَابِغِيُّ', #46
u'المدابغي': u'الْمَدَابِغِيِّ', #53
u'المداج': u'المداج', #1
u'المداحاة': u'الْمُدَاحَاةِ', #1
u'المداحاة': u'الْمُدَاحَاةَ', #2
u'المداخلSشعر': u'الْمَدَاخِلُSشِعْرُ', #1
u'المدارأة': u'الْمُدَارَأَةُ', #1
u'المداعس': u'الْمَدَاعِسِ', #2
u'المدامغ': u'الْمُدَامَغِ', #1
u'المداوى': u'الْمُدَاوِى', #2
u'المداوى': u'الْمُدَاوَى', #3
u'المداويا': u'الْمُدَاوِيَا', #2
u'المدائني،': u'المدائنّي،', #1
u'المدائني': u'الْمَدَائِنِيّ', #1
u'المدائني': u'الْمَدَائِنِيَّ', #1
u'المدائنى': u'الَمَدَائِنِىُّ', #1
u'المدائنى': u'الْمَدِائِنِىِّ', #1
u'المدائني': u'المدائني', #13
u'المدائني': u'المدائنيّ', #2
u'المدائني،': u'المدائنيّ،', #3
u'المدائنى': u'الْمَدَائِنِىِّ', #3
u'المدائنى': u'الْمَدَائِنِىُّ', #31
u'المدائني،': u'الْمَدَائِنِيُّ،', #38
u'المدائني،': u'المدائني،', #4
u'المدائني': u'الْمَدَائِنِيُّ', #54
u'المدائني': u'الْمَدَائِنِيِّ', #9
u'المدائني،': u'الْمَدَائِنِيِّ،', #9
u'المداين': u'الْمُدَايِنِ', #1
u'المدايني،': u'الْمَدَاينِيُّ،', #1
u'المدايني،': u'الْمَدَايِنِيُّ،', #1
u'المدايني': u'الْمَدَايِنِيُّ', #2
u'المداينى': u'الْمَدَايِنِىُّ', #3
u'المداينين': u'الْمُدَايِنِينَ', #2
u'المدبح': u'الْمَدْبَحِ', #1
u'المدثرآية': u'المدثرآية', #3
u'المدثورة': u'الْمَدْثُورَةِ', #1
u'المدجلي': u'الْمُدْجَلِيّ', #1
u'المدخوله': u'الْمَدْخُولَهْ', #1
u'المددى': u'الْمَدَدِىِّ', #1
u'المددى': u'الْمَدَدِىُّ', #2
u'المدرا': u'الْمَدَرَا', #2
u'المدراس،': u'الْمِدْرَاسِ،', #1
u'المدراس': u'الْمِدْرَاسِ', #16
u'المدركية': u'الْمُدْرَكِيَّةَ', #1
u'المدروز': u'الْمَدْرُوزِ', #1
u'المدرى': u'الْمِدْرَى', #1
u'المدرى': u'المدرى', #2
u'المدرى': u'الْمَدَرِىِّ', #2
u'المدرى': u'الْمُدْرَى', #3
u'المدشوش': u'الْمَدْشُوشَ', #1
u'المدشوش': u'الْمَدْشُوشُ', #1
u'المدشوش': u'الْمَدْشُوشِ', #4
u'المدشوشة': u'الْمَدْشُوشَةُ', #1
u'المدعدعه': u'الْمُدَعْدَعَهْ', #1
u'المدفف': u'الْمُدَفِّفِ', #1
u'المدفوق': u'الْمَدْفُوقَ', #1
u'المدفوق': u'الْمَدْفُوقُ', #1
u'المدفوق': u'الْمَدْفُوقِ', #7
u'المدلجي': u'المدلجي', #1
u'المدلجي،': u'المُدْلجيّ،', #1
u'المدلجي': u'المُدْلجِي', #1
u'المدلجي': u'المُدْلجِيّ', #1
u'المدلجي': u'المُدْلِجيّ', #1
u'المدلجي': u'المّدْلِجيّ', #1
u'المدلجي': u'المُدْلِجِيّ', #1
u'المدلجي': u'الْمُدْلِجِي', #1
u'المدلجي،': u'الْمُدْلِجِيُّ،', #1
u'المدلجي،': u'الْمُدْلِجِيِّ،', #1
u'المدلجي؟': u'الْمُدْلِجِيُّ؟', #1
u'المدلجي': u'الْمُدْلِجِيّ', #15
u'المدلجي': u'الْمُدْلِجِيَّ', #18
u'المدلجى': u'الْمُدْلِجِىَّ', #2
u'المدلجى': u'الْمُدْلِجِىُّ', #2
u'المدلجي': u'الْمُدْلِجِيُّ', #33
u'المدلجي': u'الْمُدْلِجِيِّ', #46
u'المدلجيين': u'الْمُدْلِجِيِّينَ', #1
u'المدلمق': u'الْمُدَلْمَقُ', #1
u'المدلوك': u'الْمُدْلُوك', #1
u'المدلولية': u'الْمُدْلَوْلِيَةِ', #1
u'المدلولية': u'الْمَدْلُولِيَّةِ', #2
u'المدنالتي': u'الْمُدُنِالَّتِي', #1
u'المدنف': u'الْمُدَنَّفُ', #1
u'المدنف': u'الْمُدْنَفُ', #2
u'المدنف': u'الْمُدْنِفُ', #2
u'المدنف': u'الْمُدْنِفِ', #3
u'المدنو': u'الْمَدْنُوِّ', #1
u'المدنى': u'الْمَدَنِىِّ', #20
u'المدنى': u'الْمَدَنِىُّ', #53
u'المدنى': u'الْمَدَنِىَّ', #7
u'المده': u'الْمُدَّهْ', #2
u'المدهب': u'الْمُدْهَبِ', #1
u'المدهب': u'الْمِدْهَبِ', #1
u'المدهثم': u'الْمُدَهْثَمُ', #1
u'المدهثما': u'الْمُدَهْثَمَا', #1
u'المدواة': u'الْمُدَوَّاةُ', #1
u'المدواة': u'الْمُدَوَّاةِ', #1
u'المدونةعن': u'الْمُدَوَّنَةِعَنْ', #1
u'المديانة': u'الْمِدْيَانَةُ', #1
u'المديحه': u'الْمَدِيحَهْ', #1
u'المدينةSقول': u'الْمَدِينَةَSقَوْلُ', #1
u'المدينةالذين': u'الْمَدِينَةِالّذِينَ', #1
u'المدينةله': u'الْمَدِينَةِلَهُ', #1
u'المدينةو': u'الْمَدِينَةَوَ', #1
u'المدينةوالوجه': u'الْمَدِينَةِوَالْوَجْهُ', #1
u'المدينةوكل': u'الْمَدِينَةِوَكَّلَ', #1
u'المدينى': u'الْمَدِينِى', #1
u'المدينى': u'الْمَدِينِىِّ', #212
u'المدينى': u'الْمَدِينِىُّ', #45
u'المدينى': u'الْمَدِينِىَّ', #9
u'المذاء': u'المذاء', #1
u'المذاء': u'الْمِذَاءَ', #1
u'المذاء': u'الْمِذَاءُ', #1
u'المذاد': u'الْمَذَاد', #1
u'المذاد': u'الْمَذَادَ', #3
u'المذاد': u'الْمَذَادِ', #6
u'المذارعة': u'الْمُذَارَعَةِ', #3
u'المذاكرين': u'الْمُذَاكِرِينَ', #7
u'المذام': u'الْمَذَامّ', #1
u'المذام': u'الْمَذَامَّ', #1
u'المذاهبا': u'الْمَذَاهِبَا', #2
u'المذبات': u'الْمِذَبَّاتِ', #1
u'المذبة': u'الْمِذَبَّةُ', #5
u'المذبوحية': u'الْمَذْبُوحِيَّةُ', #1
u'المذبوحية': u'الْمَذْبُوحِيَّةِ', #2
u'المذحجي': u'المّذْحِجيّ', #1
u'المذحجي': u'الْمُذْحِجِيّ', #1
u'المذحجي': u'الْمُذْحِجِيُّ', #1
u'المذحجى': u'الْمَذْحِجِىِّ', #1
u'المذحجي،': u'الْمَذْحِجِيُّ،', #5
u'المذحجي': u'الْمَذْحِجِيُّ', #7
u'المذحجية': u'الْمَذْحِجِيّةُ', #1
u'المذخ': u'الْمَذَخُ', #1
u'المذخور': u'الْمَذْخُورِ', #1
u'المذخور': u'الْمَذْخُور', #3
u'المذروع': u'الْمَذْرُوعُ', #12
u'المذروع': u'الْمَذْرُوعَ', #19
u'المذروع': u'الْمَذْرُوعِ', #68
u'المذروعات': u'الْمَذْرُوعَاتُ', #2
u'المذروعات': u'الْمَذْرُوعَاتِ', #61
u'المذفف': u'الْمُذَفَّفَ', #1
u'المذفف': u'الْمُذَفِّفَ', #1
u'المذفف': u'الْمُذَفِّفِ', #13
u'المذفف': u'الْمُذَفَّفُ', #2
u'المذفف': u'الْمُذَفَّفِ', #2
u'المذفف': u'الْمُذَفِّفُ', #7
u'المذففة': u'الْمُذَفِّفَةَ', #1
u'المذففة': u'الْمُذَفِّفَةُ', #1
u'المذففة': u'الْمُذَفِّفَةِ', #2
u'المذففين': u'الْمُذَفِّفَيْنِ', #8
u'المذكاة': u'الْمُذْكَاةِ', #1
u'المذكاة': u'الْمُذَكَّاةَ', #4
u'المذكاة': u'الْمُذَكَّاةِ', #63
u'المذكاة': u'الْمُذَكَّاةُ', #9
u'المذكوان': u'الْمَذْكُوَّانِ', #1
u'المذكوة': u'الْمَذْكُوَّةِ', #2
u'المذكوي': u'الْمَذْكَوِيِّ', #1
u'المذكى': u'الْمُذَكَّى', #127
u'المذكى': u'الْمُذَكّى', #2
u'المذكى': u'الْمُذْكَى', #2
u'المذمومية': u'الْمَذْمُومِيَّةُ', #2
u'المذي،': u'الْمَذْيِ،', #1
u'المذي؟': u'الْمَذْيِ؟', #1
u'المذى': u'المذى', #1
u'المذي': u'الْمَذْي', #14
u'المذى': u'الْمَذْىِ', #14
u'المذى': u'الْمَذْىُ', #2
u'المذي': u'الْمَذْيِ', #206
u'المذى': u'الْمَذْىَ', #3
u'المذي': u'الْمَذْيَ', #32
u'المذي': u'الْمَذْيُ', #83
u'المرءون': u'الْمَرْءُونُ', #3
u'المراءون': u'الْمُرَاءُونَ', #6
u'المرابح': u'الْمُرَابِحَ', #1
u'المرابح': u'الْمُرَابِحِ', #1
u'المرابطية': u'الْمُرَابِطِيَّةِ', #1
u'المراة': u'الْمُرَاةِ', #1
u'المراة': u'الْمِرَاةِ', #1
u'المراة': u'الْمَرَاةِ', #3
u'المراثى': u'الْمَرَاثِى', #1
u'المراجح': u'الْمَرَاجِحْ', #2
u'المراجيح': u'الْمَرَاجِيحِ', #2
u'المراحب': u'الْمَرَاحِبِ', #2
u'المراحلا': u'الْمَرَاحِلَا', #1
u'المرادن': u'الْمَرَادِنُ', #1
u'المرادن': u'الْمَرَادِنِ', #1
u'المرادنيين': u'المرادنيين', #1
u'المرادون': u'الْمُرَادُونَ', #11
u'المرادي': u'المُرادِي', #1
u'المرادي،': u'المُرادِيّ،', #1
u'المرادي': u'المُرَادي', #1
u'المرادي،': u'المُرَادي،', #1
u'المرادي،': u'المُرَاديّ،', #1
u'المرادي،': u'المُرَادِيّ،', #1
u'المرادي': u'الْمَرَادِيَّ', #1
u'المرادي': u'الْمَرَادِيُّ', #1
u'المرادي': u'الْمَرَادِيِّ', #1
u'المرادي': u'الْمُرَادّيّ', #1
u'المرادي،': u'الْمُرَادِيَّ،', #1
u'المرادى': u'الْمَرَادِىُّ', #1
u'المرادى': u'الْمُرَادَى', #1
u'المرادي،': u'الْمُرَادِيِّ،', #10
u'المرادى': u'الْمُرَادِىِّ', #12
u'المرادي،': u'الْمُرَادِيُّ،', #16
u'المرادي': u'الْمُرَادِيَّ', #17
u'المرادي': u'الْمُرَادِيُّ', #178
u'المرادي،': u'المرادي،', #2
u'المرادي': u'المُرادي', #2
u'المرادي،': u'المُراديّ،', #2
u'المرادي': u'الْمُرَادِي', #2
u'المرادي': u'المرادي', #3
u'المرادي': u'المُرَادِيّ', #3
u'المرادي': u'الْمُرَادِيِّ', #32
u'المرادى': u'الْمُرَادِىَّ', #4
u'المرادى': u'الْمُرَادِىُّ', #40
u'المرادي': u'الْمُرَادِيّ', #9
u'المرادية': u'الْمُرَادِيَةِ', #1
u'المرادية': u'الْمُرَادِيَّةِ', #1
u'المرادية،': u'الْمُرَادِيَّةُ،', #1
u'المرازب': u'المرَازِب', #1
u'المرازب': u'الْمَرَازِبِ', #1
u'المرازبة': u'الْمَرَازِبَةُ', #1
u'المرازقة': u'الْمَرَازِقَةِ', #1
u'المراشد': u'الْمَرَاشِدَ', #1
u'المراشد': u'الْمَرَاشِدُ', #2
u'المراصة': u'الْمُرَاصَّةُ', #1
u'المراصة': u'الْمُرَاصَّةِ', #1
u'المراضات': u'الْمُرَاضَاتُ', #1
u'المراضخ': u'الْمَرَاضِخِ', #1
u'المراضخة': u'الْمُرَاضَخَةُ', #1
u'المراطل': u'الْمُرَاطَلِ', #1
u'المراطلة': u'الْمُرَاطِلَةِ', #1
u'المراطلة': u'الْمُرَاطَلَةَ', #13
u'المراطلة': u'الْمُرَاطَلَةُ', #22
u'المراطلة': u'الْمُرَاطَلَةِ', #54
u'المراطله': u'الْمُرَاطَلَهْ', #1
u'المراعة': u'الْمُرَاعَةِ', #2
u'المراعة': u'الْمَرَاعَةِ', #3
u'المراعى': u'الْمُرَاعَى', #81
u'المراغة': u'الْمَرَاغَةِ', #2
u'المراغمة': u'الْمُرَاغَمَةِ', #11
u'المراغمة': u'الْمُرَاغَمَةَ', #5
u'المراغمة': u'الْمُرَاغَمَةُ', #7
u'المراغمين': u'الْمُرَاغِمِينَ', #1
u'المراغى': u'الْمَرَاغِىُّ', #1
u'المراغى': u'الْمَرَاغِىِّ', #1
u'المراغي': u'الْمَرَاغِيُّ', #18
u'المراغي،': u'الْمَرَاغِيُّ،', #2
u'المراغي': u'الْمَرَاغِيّ', #3
u'المراغي': u'الْمَرَاغِيَّ', #7
u'المراغي': u'الْمَرَاغِيِّ', #7
u'المراقة': u'الْمُرَاقَةِ', #2
u'المراقيا': u'المراقيا', #1
u'المراقيل': u'الْمَرَاقِيلَ', #3
u'المرآن': u'الْمَرْآنِ', #2
u'المرأه': u'المرأه', #1
u'المراوحيين': u'المَرَاوِحِيّينَ', #2
u'المراوذة': u'الْمَرَاوِذَةِ', #1
u'المراوزة': u'الْمَرَاوِزَةَ', #1
u'المراوزة': u'الْمُرَاوَزَةُ', #1
u'المراوزة': u'الْمَرَاوِزَةُ', #13
u'المراوزة': u'الْمُرَاوَزَةِ', #3
u'المراوزة': u'الْمَرَاوِزَةِ', #73
u'المراوضة': u'المراوضة', #1
u'المراوضة': u'الْمُرَاوَضَةَ', #2
u'المراوضة': u'الْمُرَاوَضَةُ', #2
u'المراوضة': u'الْمُرَاوَضَةِ', #4
u'المراويح': u'الْمَرَاوِيحُ', #1
u'المراي،': u'الْمُرَايُ،', #3
u'المرائم': u'المرائم', #1
u'المرائى': u'الْمُرَائِى', #1
u'المرائى': u'الْمُرَائِىِّ', #1
u'المرائى': u'الْمُرَائِىُّ', #2
u'المرائين': u'المرائين', #1
u'المرائين': u'الْمُرَائِينَ', #10
u'المرباد': u'المرباد', #1
u'المربوب': u'الْمَرْبُوبِ', #1
u'المرتاض': u'الْمُرْتَاضِ', #2
u'المرتاضين': u'الْمُرْتَاضِينَ', #1
u'المرتتق': u'الْمُرْتَتِقِ', #1
u'المرتث': u'الْمُرْتَثِّ', #2
u'المرتث': u'الْمُرْتَثَّ', #3
u'المرتث': u'الْمُرْتَثُّ', #4
u'المرتجSشعر': u'الْمُرْتَجْSشِعْرُ', #1
u'المرتجز': u'الْمُرْتَجِزَ', #1
u'المرتجز': u'الْمُرْتَجِزُ', #3
u'المرتجس': u'الْمُرْتَجِسِ', #1
u'المرتجي': u'الْمُرْتَجِي', #3
u'المرتدف': u'الْمُرْتَدَفِ', #1
u'المرتدف': u'الْمُرْتَدِفُ', #2
u'المرتدفين': u'الْمُرْتَدِفِينَ', #1
u'المرتدفين': u'الْمُرْتَدِفَيْنِ', #2
u'المرتزقه': u'الْمُرْتَزِقَهْ', #1
u'المرتضع': u'الْمُرْتَضَعَ', #1
u'المرتضع': u'الْمُرْتَضَعُ', #1
u'المرتضع': u'الْمُرْتَضِع', #1
u'المرتضع': u'الْمُرْتَضِعَ', #1
u'المرتضع': u'الْمُرْتَضِعُ', #14
u'المرتضع': u'الْمُرْتَضِعِ', #35
u'المرتضع': u'الْمُرْتَضَعِ', #4
u'المرتضعات': u'الْمُرْتَضِعَاتِ', #2
u'المرتضعة': u'الْمُرْتَضِعَةِ', #12
u'المرتضعة': u'الْمُرْتَضِعَةَ', #2
u'المرتضعة': u'الْمُرْتَضِعَةُ', #6
u'المرتضعين': u'الْمُرْتَضِعِينَ', #1
u'المرتضعين': u'الْمُرْتَضِعَيْنِ', #1
u'المرتضى': u'الْمُرْتَضَى', #76
u'المرتفق': u'الْمُرْتَفِق', #2
u'المرتفق': u'الْمُرْتَفِقُ', #3
u'المرتفق': u'الْمُرْتَفَقِ', #4
u'المرتفق': u'الْمُرْتَفِقِ', #4
u'المرتفقون': u'الْمُرْتَفِقُونَ', #2
u'المرتفقين': u'الْمُرْتَفِقِينَ', #2
u'المرتك': u'الْمُرْتَكَ', #1
u'المرتك': u'الْمُرْتَكِ', #1
u'المرتك': u'الْمَرْتَكُ', #3
u'المرتك': u'الْمَرْتَكِ', #4
u'المرتهنSإسلام': u'الْمُرْتَهِنْSإسْلَامُ', #1
u'المرثدى': u'الْمَرْثَدِىِّ', #2
u'المرثدى': u'الْمَرْثَدِىُّ', #7
u'المرثدي،': u'الْمَرْثَدِيُّ،', #8
u'المرجا': u'الْمُرَجَّا', #2
u'المرجة': u'الْمَرْجَةِ', #1
u'المرجة': u'الْمُرِجَّةِ', #1
u'المرجة': u'الْمُرْجَةَ', #1
u'المرجة': u'الْمُرْجَةُ', #1
u'المرجة': u'الْمُرْجَةِ', #2
u'المرجوحية': u'الْمَرْجُوحِيَّةِ', #10
u'المرجوحية': u'الْمَرْجُوحِيَّةُ', #3
u'المرجوحية': u'الْمَرْجُوحِيَّةَ', #4
u'المرجى': u'الْمُرَجَّى', #3
u'المرحومي': u'الْمَرْحُومِيَّ', #1
u'المرحومي': u'الْمَرْحُومِيُّ', #33
u'المرحومي': u'الْمَرْحُومِيِّ', #33
u'المرخاة': u'الْمُرْخَاةَ', #1
u'المرخى': u'الْمُرْخَى', #8
u'المردا': u'الْمَرَدَّا', #1
u'المردان': u'الْمُرْدَانَ', #1
u'المردان': u'الْمُرْدَانِ', #6
u'المردانية': u'الْمُرْدَانِيَّةِ', #2
u'المردقوش': u'الْمَرْدَقُوشَ', #1
u'المردقوش': u'الْمَرْدَقُوشُ', #2
u'المردى': u'الْمُرَدَّى', #1
u'المردى': u'الْمِرْدَى', #1
u'المرذوي': u'الْمَرُّذِويُّ', #1
u'المرروزى': u'الْمَرْرُّوزِىُّ', #1
u'المرزبان': u'المرزبان', #1
u'المرزبان،': u'المرزبان،', #1
u'المرزبان': u'الْمَرْزُبَان', #1
u'المرزبان': u'الْمَرْزُبَانْ', #1
u'المرزبان،': u'الْمَرْزَبَانِ،', #1
u'المرزبان،': u'الْمَرْزُبَانُ،', #1
u'المرزبان،': u'الْمُرْزُبَانِ،', #2
u'المرزبان': u'الْمَرْزُبَانُ', #4
u'المرزبان': u'الْمَرْزُبَانِ', #42
u'المرزبان،': u'الْمَرْزُبَانِ،', #6
u'المرزبان': u'الْمَرْزُبَانَ', #7
u'المرزبانة': u'الْمَرْزُبَانَةُ', #1
u'المرزباني': u'الْمَرْزُبَانِيُ', #1
u'المرزباني': u'الْمَرْزُبَانِيَّ', #1
u'المرزباني': u'الْمَرْزُبَانِيُّ', #1
u'المرزدي': u'الْمَرْزَدِيُّ', #1
u'المرزفي،': u'الْمَرْزَفِيُّ،', #1
u'المرزنجوش': u'المرزنجوش', #1
u'المرزنجوش': u'الْمَرْزَنْجُوشِ', #1
u'المرزوي': u'المَرزوي', #1
u'المرزى': u'الْمُرَزَّى', #1
u'المرسل491id': u'المرسل491id', #1
u'المرسلSحول': u'الْمُرْسَلُSحَوْلُ', #1
u'المرسول': u'الْمَرْسُولُ', #2
u'المرسول': u'الْمَرْسُولَ', #3
u'المرسول': u'الْمَرْسُولِ', #5
u'المرصفي': u'الْمَرْصَفِيُّ', #5
u'المرصفي': u'الْمَرْصَفِيِّ', #8
u'المرصودون': u'الْمَرْصُودُونَ', #1
u'المرضة': u'الْمَرْضَةَ', #1
u'المرضة،': u'الْمَرْضَةَ،', #1
u'المرضة': u'الْمِرْضَةَ', #3
u'المرضخ': u'الْمُرْضَخِ', #2
u'المرضخة': u'الْمُرْضَخَةُ', #1
u'المرضخة': u'الْمِرْضَخَةِ', #1
u'المرضوض': u'الْمَرْضُوضِ', #2
u'المرط،': u'المِرْط،', #1
u'المرط': u'الْمِرْط', #1
u'المرط': u'الْمِرْطَ', #1
u'المرط': u'الْمِرْطُ', #2
u'المرط': u'الْمِرْطِ', #5
u'المرط': u'المرط', #8
u'المرعز': u'الْمِرْعَزُ', #1
u'المرعزى': u'الْمِرْعِزَّى', #5
u'المرعزية': u'المرعزية', #1
u'المرعزية': u'الْمِرْعَزِيَّةِ', #1
u'المرعشي': u'الْمَرْعَشِيَّ', #1
u'المرعشي': u'الْمَرْعَشِيُّ', #23
u'المرعشي': u'الْمَرْعَشِيِّ', #4
u'المرعيه': u'الْمَرْعِيَّهْ', #1
u'المرغاب': u'الْمَرْغَابِ', #1
u'المرغام': u'الْمِرْغَامُ', #1
u'المرغيناني': u'المرغيناني', #1
u'المرغيناني': u'الْمَرْغِينَانِيُّ', #199
u'المرغيناني': u'الْمَرْغِينَانِيَّ', #2
u'المرغيناني': u'الْمَرْغِينَانِيِّ', #95
u'المرغينانية': u'المرغينانية', #1
u'المرغينانية': u'الْمَرْغِينَانِيَّةِ', #1
u'المرفل': u'الْمُرَفّلِ', #1
u'المرفل': u'الْمُرَفَّلِ', #2
u'المرفل': u'الْمُرْفَلُ', #2
u'المرفود': u'الْمَرْفُودُ', #4
u'المرقوع': u'الْمَرْقُوعِ', #1
u'المرقوق': u'الْمَرْقُوقِ', #17
u'المرقوق': u'الْمَرْقُوقَ', #5
u'المرقوق': u'الْمَرْقُوقُ', #7
u'المرقوقان': u'الْمَرْقُوقَانِ', #2
u'المرقوقة': u'الْمَرْقُوقَةَ', #4
u'المرقوقة': u'الْمَرْقُوقَةُ', #4
u'المرقوقة': u'الْمَرْقُوقَةِ', #8
u'المرقوقين': u'الْمَرْقُوقَيْنِ', #1
u'المركزا': u'الْمَرْكَزَا', #1
u'المركوش': u'الْمَرْكُوشُ', #1
u'المرماة': u'الْمَرْمَاةِ', #1
u'المرماة': u'الْمِرْمَاةَ', #1
u'المرماة': u'الْمِرْمَاة', #4
u'المرماة': u'الْمِرْمَاةُ', #4
u'المرماتان': u'الْمِرْمَاتَانِ', #3
u'المرماتين': u'الْمِرْمَاتَيْنِ', #2
u'المرموس': u'الْمَرْمُوسِ', #1
u'المرنج': u'المرنج', #2
u'المره': u'الْمَرَهْ', #12
u'المره': u'الْمَرَهِ', #2
u'المرهبي': u'الْمُرْهِبِيُّ', #1
u'المرهبي': u'الْمُرْهِبِيِّ', #1
u'المرهبى': u'الْمُرْهِبِىُّ', #1
u'المرهبى': u'الْمُرْهِبِىِّ', #1
u'المرهج': u'الْمُرْهَجِ', #1
u'المرهج': u'الْمُرْهَجْ', #1
u'المرهج': u'الْمُرْهِجِ', #1
u'المرهقا': u'الْمُرَهّقَا', #2
u'المرهلة': u'الْمُرْهِلَةِ', #1
u'المرهوق': u'الْمَرْهُوقِ', #1
u'المرهونية': u'الْمَرْهُونِيَّةِ', #1
u'المروآت': u'الْمُرُوآتِ', #34
u'المروآت': u'الْمُرُوآت', #6
u'المرواح': u'الْمِرْوَاحِ', #1
u'المرواني': u'الْمَرْوَانِيَّ', #1
u'المروانية': u'الْمَرْوَانِيَّةَ', #1
u'المروانية': u'الْمَرْوَانِيَّةِ', #2
u'المروانية': u'الْمَرْوَانِيَّةُ', #3
u'المروتينا': u'الْمَرْوَتَيْنَا', #1
u'المروذي،': u'الْمَرُّوذِيَّ،', #1
u'المروذي،': u'الْمَرْوَذِيّ،', #1
u'المروذي،': u'الْمَرْوَذِيِّ،', #1
u'المروذي': u'المروذي', #12
u'المروذي': u'الْمَرُّوذِيِّ', #133
u'المروذي': u'الْمَرُّوذِيَّ', #15
u'المروذى،': u'المروذى،', #2
u'المروذي': u'الْمَرُّوذِيّ', #27
u'المروذي،': u'المروذي،', #3
u'المروذي،': u'الْمَرْوَذِيُّ،', #3
u'المروذي': u'الْمَرُّوذِيُّ', #479
u'المروذي،': u'الْمَرُّوذِيُّ،', #53
u'المروراة': u'الْمَرُورَاةَ', #1
u'المروراة': u'الْمَرَوْرَاةُ', #5
u'المروربين': u'الْمُرُورُبَيْنَ', #1
u'المرورذي': u'الْمَرْوَرُذِيَّ', #1
u'المروروذي': u'الْمَرْوَرُوذِيَّ', #1
u'المروروذى': u'الْمَرْورُّوْذِىُّ', #1
u'المروروذى': u'الْمَرْوَرْوَذِىُّ', #1
u'المروروذي': u'الْمَرْوَرُوذِيُّ', #16
u'المروروذي': u'الْمَرْوَرُوذِيِّ', #3
u'المروروذي،': u'الْمَرْوَرُوذِيُّ،', #3
u'المروروذى': u'الْمَرْوَرُّوذِىُّ', #4
u'المروروذى': u'الْمَرْورُّوذِىُّ', #6
u'المروروزي': u'الْمَرْوَرُوزِيِّ', #1
u'المروزى،': u'المروزى،', #1
u'المروزى': u'الْمَرْوَزِىَّ', #2
u'المروزى': u'الْمَرْوَزِىُّ', #213
u'المروزى': u'الْمَرْوَزِىِّ', #4
u'المروط': u'الْمُرُوطَ', #1
u'المروط': u'الْمُرُوطُ', #1
u'المروط': u'المروط', #2
u'المروط': u'الْمُرُوطِ', #2
u'المرويا': u'الْمَرْوِيَّا', #1
u'المرئى': u'الْمَرَئِىُّ', #1
u'المرياع': u'الْمِرْيَاعِ', #1
u'المريج': u'الْمَرِيجِ', #1
u'المريدية': u'الْمُرِيدِيَّةِ', #2
u'المريسع': u'المُرَيْسِع', #1
u'المريسيع': u'المرَيْسيع', #1
u'المريسيع': u'المُرَيْسِيع', #2
u'المريسيع،': u'الْمُرَيْسِيعِ،', #3
u'المريسيع': u'الْمُرَيْسِيعَ', #4
u'المريسيع': u'الْمُرَيْسِيعِ', #45
u'المريسيع': u'الْمُرَيْسِيعُ', #9
u'المريسيعمع': u'الْمُرَيْسِيعَمَعَ', #1
u'المريصع': u'الْمُرَيْصِعُ', #1
u'المريون': u'الْمُرّيُونَ', #1
u'المزاء': u'الْمُزَّاءِ', #3
u'المزابنة': u'المزابنة', #1
u'المزابنة،': u'المزابنة،', #1
u'المزابنة،': u'الْمُزَابَنَةُ،', #1
u'المزابنة،': u'الْمُزَابَنَةِ،', #13
u'المزابنة': u'الْمُزَابَنَة', #2
u'المزابنة': u'الْمُزَابَنَةِ', #215
u'المزابنة': u'الْمُزَابَنَةَ', #33
u'المزابنة': u'الْمُزَابَنَةُ', #50
u'المزاة': u'الْمُزَّاةِ', #2
u'المزاجر': u'الْمَزَاجِرِ', #2
u'المزادات': u'الْمَزَادَاتُ', #1
u'المزارعه': u'الْمُزَارَعَهْ', #1
u'المزاريق': u'الْمَزَارِيقَ', #1
u'المزاريق': u'الْمَزَارِيقِ', #1
u'المزاريق': u'الْمَزَارِيقُ', #2
u'المزالف': u'الْمَزَالِفِ', #2
u'المزامل': u'الْمُزَامِلِ', #1
u'المزايل': u'الْمُزَايِلِ', #3
u'المزبل': u'الْمُزَبَّلَ', #1
u'المزبور': u'الْمَزْبُورُ', #189
u'المزبور': u'الْمَزْبُورِ', #422
u'المزبور': u'الْمَزْبُورَ', #87
u'المزبورات': u'الْمَزْبُورَاتِ', #1
u'المزبوران': u'الْمَزْبُورَانِ', #13
u'المزبورة': u'الْمَزْبُورَة', #1
u'المزبورة': u'الْمَزْبُورَةِ', #201
u'المزبورة': u'الْمَزْبُورَةَ', #37
u'المزبورة': u'الْمَزْبُورَةُ', #57
u'المزبورتين': u'الْمَزْبُورَتَيْنِ', #5
u'المزبورين': u'الْمَزْبُورِينَ', #12
u'المزبورين': u'الْمَزْبُورَيْنِ', #25
u'المزجاة': u'الْمُزْجَاةُ', #1
u'المزجاة': u'الْمُزْجَاةِ', #3
u'المزجادي': u'الْمِزْجَادِيُّ', #1
u'المزجد': u'الْمُزَجَّدُ', #17
u'المزجد': u'الْمُزَجَّدَ', #2
u'المزجد': u'الْمُزَجَّدِ', #53
u'المزجرة': u'الْمَزْجَرَةِ', #1
u'المزجور': u'الْمَزْجُورُ', #1
u'المزجور': u'الْمَزْجُورِ', #1
u'المزجورات': u'الْمَزْجُورَاتِ', #1
u'المزحور': u'الْمَزْحُورِ', #2
u'المزحوف': u'الْمَزْحُوفَ', #3
u'المزحوم': u'المزحوم', #1
u'المزحوم': u'الْمَزْحُومُ', #18
u'المزحوم': u'الْمَزْحُومِ', #19
u'المزحوم': u'الْمَزْحُومَ', #2
u'المزحوم': u'الْمَزْحُوم', #5
u'المزخرفا': u'الْمُزَخْرَفَا', #2
u'المزدجر': u'الْمُزْدَجِرُ', #1
u'المزدحصائي': u'المزدحصائي', #1
u'المزدرعات': u'الْمُزْدَرِعَاتِ', #1
u'المزدرعات': u'الْمُزْدَرَعَاتِ', #2
u'المزدرعة': u'الْمُزْدَرَعَةَ', #1
u'المزدغي': u'الْمَزْدَغِيُّ', #2
u'المزدلف': u'الْمُزْدَلِفِ', #1
u'المزر؟': u'الْمِزْرُ؟', #1
u'المزر': u'الْمِزْرُ', #13
u'المزر': u'الْمِزْرِ', #4
u'المزر': u'المزر', #5
u'المزر،': u'الْمِزْرُ،', #7
u'المزراعة': u'الْمُزَراَعَةِ', #1
u'المزراق': u'الْمِزْرَاقُ', #1
u'المزراق': u'الْمِزْرَاقَ', #2
u'المزراق': u'الْمِزْرَاقِ', #2
u'المزرد': u'الْمُزَرِّدِ', #1
u'المزرر': u'الْمُزَرَّرُ', #1
u'المزررة': u'الْمُزَرَّرَةِ', #1
u'المزرع': u'الْمُزْرَعُ', #1
u'المزرع': u'الْمُزْرِعِ', #2
u'المزرعه': u'الْمَزْرَعَهْ', #1
u'المزرفي،': u'المَزْرَفِيُّ،', #2
u'المزرور': u'الْمَزْرُورِ', #10
u'المزرور': u'الْمَزْرُورَ', #2
u'المزرورة': u'الْمَزْرُورَةِ', #1
u'المزعة': u'المزعة', #2
u'المزعفر': u'الْمُزَعْفَرَ', #10
u'المزعفر': u'الْمُزَعْفَرُ', #28
u'المزعفر': u'الْمُزَعْفَرِ', #56
u'المزعفرا': u'الْمُزَعْفَرَا', #8
u'المزعفرة': u'الْمُزَعْفَرَةِ', #3
u'المزعفرة': u'الْمُزَعْفَرَةَ', #5
u'المزغول': u'الْمَزْغُولِ', #1
u'المزفوف': u'الْمَزْفُوفِ', #1
u'المزفوفة': u'الْمَزْفُوفَةَ', #2
u'المزفوفة': u'الْمَزْفُوفَةُ', #2
u'المزفوفة': u'الْمَزْفُوفَةِ', #9
u'المزمزة': u'الْمَزْمَزَةُ', #1
u'المزمزما': u'الْمُزَمْزِمَا', #1
u'المزملاتي': u'الْمُزَمِّلَاتِيُّ', #1
u'المزنم': u'الْمُزَنّمِ', #5
u'المزنوق': u'الْمَزْنُوقُ', #1
u'المزنى': u'الْمَزنِىِّ', #1
u'المزنى': u'الْمُزَنِىُّ', #147
u'المزنى': u'الْمُزَنِىَّ', #18
u'المزنى': u'الْمُزْنَى', #3
u'المزنى': u'الْمُزَنِىِّ', #65
u'المزهق': u'الْمُزْهِقُ', #11
u'المزهق': u'الْمُزْهِقَ', #2
u'المزهق': u'الْمُزْهِقِ', #9
u'المزوار': u'الْمِزْوَارُ', #1
u'المزوجه': u'الْمُزَوَّجَهْ', #1
u'المزون': u'الْمُزَوَّنِ', #1
u'المزوية': u'الْمَزْوِيَّةِ', #1
u'المزيرية': u'الْمُزَيْرِيّة', #4
u'المزيقيا': u'الْمُزَيْقِيَا', #1
u'المزيقياء': u'الْمُزَيْقِيَاءِ', #2
u'المسابة': u'الْمُسَابَّةِ', #1
u'المسابرة': u'الْمُسَابَرَةِ', #1
u'المساتر': u'الْمُسَاتَرِ', #1
u'المساتق': u'الْمُسَاتَقِ', #1
u'المساجدا': u'الْمَسَاجِدَا', #2
u'المساجدإلا': u'الْمَسَاجِدِإِلَّا', #1
u'المساجدإليه': u'الْمَسَاجِدِإِلَيْهِ', #1
u'المساحقات': u'الْمُسَاحِقَاتِ', #1
u'المساحقتان': u'الْمُسَاحِقَتَانِ', #1
u'المساحقي': u'المساحقي', #1
u'المساحقي،': u'الْمُسَاحِقِي،', #1
u'المساحى': u'الْمَسَاحِى', #1
u'المساحى': u'المساحى', #3
u'المساسة': u'الْمَسَاسَةِ', #1
u'المساطير': u'الْمَسَاطِيرِ', #3
u'المساعط': u'الْمَسَاعِطُ', #1
u'المساعيد': u'الْمَسَاعِيدُ', #1
u'المساغ': u'الْمَسَاغُ', #1
u'المساغ': u'الْمَسَاغِ', #7
u'المسافرالآمن': u'الْمُسَافِرِالْآمَنِ', #1
u'المسافربن': u'المسافربن', #1
u'المسافروكان': u'الْمُسَافِرِوَكَانَ', #1
u'المسافه': u'الْمُسَافَه', #1
u'المساقة': u'الْمُسَاقَةِ', #1
u'المساقى': u'الْمُسَاقَى', #72
u'المساكتة': u'الْمُسَاكَتَةِ', #1
u'المسالفة': u'الْمُسَالَفَةَ', #1
u'المسالكا': u'الْمَسَالِكَا', #1
u'المسأله': u'الْمَسْأَلَهْ', #7
u'المسامة': u'الْمُسَامَةِ', #1
u'المسامت': u'الْمَسَامِتِ', #1
u'المسامت': u'الْمُسَامَتَ', #1
u'المسامت': u'الْمُسَامِت', #1
u'المسامت': u'الْمُسَامِتِ', #19
u'المسامت': u'الْمُسَامِتَ', #2
u'المسامت': u'الْمُسَامِتُ', #2
u'المسامت': u'الْمُسَامَتِ', #7
u'المسامتة': u'الْمُسَامِتَةُ', #1
u'المسامتة': u'الْمُسَامَتَةَ', #15
u'المسامتة': u'الْمُسَامَتَةُ', #27
u'المسامتة': u'الْمُسَامِتَةِ', #3
u'المسامتة': u'الْمُسَامَتَةِ', #41
u'المسامتين': u'الْمُسَامِتِينَ', #2
u'المساناة': u'الْمُسَانَاةِ', #1
u'المسانهة': u'الْمُسَانَهَةَ', #1
u'المسانهة': u'الْمُسَانَهَةُ', #1
u'المسانهة': u'الْمُسَانَهَةِ', #1
u'المسانية': u'الْمُسَانِيَةِ', #1
u'المساوقة': u'الْمُسَاوَقَةَ', #3
u'المساوقة': u'الْمُسَاوَقَةِ', #3
u'المساوقة': u'الْمُسَاوَقَةُ', #6
u'المساوى': u'الْمُسَاوَى', #2
u'المساويا': u'الْمُسَاوِيَا', #1
u'المساويا': u'الْمَسَاوِيَا', #6
u'المسائح': u'الْمَسَائِحُ', #2
u'المسائح': u'الْمَسَائِحِ', #2
u'المسائح': u'الْمَسَائِحْ', #2
u'المسائلوالوجه': u'الْمَسَائِلِوَالْوَجْهُ', #1
u'المسببية': u'الْمُسَبَّبِيَّةُ', #2
u'المسببية': u'الْمُسَبِّبِيَّةُ', #2
u'المسبحون': u'الْمُسَبِّحُونَ', #6
u'المسبل': u'الْمُسَبّلُ', #1
u'المسبل': u'الْمُسَبِّلُ', #1
u'المسبل': u'الْمُسْبَلُ', #1
u'المسبل': u'الْمُسْبِلُ', #24
u'المسبل': u'الْمُسَبَّلِ', #28
u'المسبل': u'الْمُسْبِل', #3
u'المسبل': u'الْمُسْبَلِ', #4
u'المسبل': u'الْمُسَبَّلَ', #5
u'المسبل': u'الْمُسْبِلِ', #6
u'المسبل': u'الْمُسَبَّلُ', #8
u'المسبلات': u'الْمُسَبَّلَاتِ', #1
u'المسبلة': u'الْمُسَبَّلَةِ', #109
u'المسبلة': u'الْمُسَبَّلَةُ', #13
u'المسبلة': u'الْمُسْبَلَةُ', #2
u'المسبلة': u'الْمُسْبَلَةِ', #21
u'المسبلة': u'الْمُسَبَّلَةَ', #3
u'المسبلين': u'الْمُسْبِلِينَ', #3
u'المسبوط': u'الْمَسْبُوطِ', #3
u'المسبوقية': u'الْمَسْبُوقِيَّةِ', #6
u'المسبول': u'الْمَسْبُولِ', #1
u'المسبيه': u'الْمَسْبِيَّهْ', #1
u'المسة': u'الْمَسَّةُ', #1
u'المسة': u'الْمَسَّةِ', #1
u'المستأخر': u'الْمُسْتَأْخِرِ', #1
u'المستأخر': u'الْمُسْتَأْخَرِ', #3
u'المستأخرة': u'الْمُسْتَأْخَرَةِ', #1
u'المستأخرين': u'الْمُسْتَأْخِرِينَ', #13
u'المستاك': u'الْمُسْتَاكَ', #1
u'المستاك': u'الْمُسْتَاكُ', #1
u'المستاك': u'الْمُسْتَاكِ', #1
u'المستأكلة': u'الْمُسْتَأْكَلَةِ', #2
u'المستأكلين': u'الْمُسْتَأْكِلِينَ', #2
u'المستام': u'الْمُسْتَامِ', #12
u'المستام،': u'الْمُسْتَامِ،', #2
u'المستام': u'الْمُسْتَامَ', #8
u'المستام': u'الْمُسْتَامُ', #8
u'المستامة': u'الْمُسْتَامَةُ', #1
u'المستامة': u'الْمُسْتَامَةِ', #8
u'المستأمر،': u'الْمُسْتَأْمَرُ،', #1
u'المستأمر': u'الْمُسْتَأْمَرِ', #2
u'المستأمر': u'الْمُسْتَأْمَرُ', #3
u'المستأمر': u'الْمُسْتَأْمِرُ', #3
u'المستأنى': u'الْمُسْتَأْنَى', #1
u'المستبان': u'الْمُسْتَبَّانِ', #15
u'المستبحر': u'الْمُسْتَبْحَرَ', #1
u'المستبحر': u'الْمُسْتَبْحَرُ', #1
u'المستبحر': u'الْمُسْتَبْحِرَ', #3
u'المستبحر': u'الْمُسْتَبْحَرِ', #6
u'المستبحر': u'الْمُسْتَبْحِرِ', #7
u'المستبذل': u'الْمُسْتَبْذَلِ', #1
u'المستبرأة': u'الْمُسْتَبْرَأَةَ', #14
u'المستبرأة': u'الْمُسْتَبْرَأَةُ', #24
u'المستبرأة': u'الْمُسْتَبْرَأَةِ', #26
u'المستبرئ': u'الْمُسْتَبْرِئُ', #1
u'المستبرئ': u'الْمُسْتَبْرِئِ', #6
u'المستبرئة': u'الْمُسْتَبْرِئَةُ', #1
u'المستبضع': u'الْمُسْتَبْضَعُ', #13
u'المستبضع': u'الْمُسْتَبْضِعَ', #19
u'المستبضع': u'الْمُسْتَبْضِعِ', #22
u'المستبضع': u'الْمُسْتَبْضَعَ', #4
u'المستبضع': u'الْمُسْتَبْضِعُ', #47
u'المستبضع': u'الْمُسْتَبْضَعِ', #6
u'المستتمة': u'الْمُسْتَتِمَّةِ', #4
u'المستجادات': u'الْمُسْتَجَادَاتِ', #13
u'المستجسد': u'الْمُسْتَجْسِدَ', #1
u'المستجسد': u'الْمُسْتَجْسِدُ', #1
u'المستجسد': u'الْمُسْتَجْسِدِ', #1
u'المستجسدة': u'الْمُسْتَجْسَدَةِ', #1
u'المستجسدة': u'الْمُسْتَجْسِدَةُ', #1
u'المستجمر': u'الْمُسْتَجْمَرُ', #1
u'المستجمر': u'الْمُسْتَجْمِرُ', #14
u'المستجمر': u'الْمُسْتَجْمِرَ', #2
u'المستجمر': u'الْمُسْتَجْمِرِ', #23
u'المستجمر': u'الْمُسْتَجْمَرِ', #4
u'المستجمرة': u'الْمُسْتَجْمِرَةِ', #1
u'المستجنة': u'الْمُسْتَجِنَّةِ', #1
u'المستجهل': u'الْمُسْتَجْهِلُ', #1
u'المستجيز': u'الْمُسْتَجِيزُ', #2
u'المستحاضات': u'الْمُسْتَحَاضَاتِ', #13
u'المستحاضة': u'الْمُسْتَحَاضَة', #1
u'المستحاضة': u'الْمُسْتَحَاضَةُ', #197
u'المستحاضة': u'المستحاضة', #2
u'المستحاضة': u'الْمُسْتَحَاضَةِ', #375
u'المستحاضة': u'الْمُسْتَحَاضَةَ', #70
u'المستحاضتين': u'الْمُسْتَحَاضَتَيْنِ', #1
u'المستحال': u'الْمُسْتَحَالِ', #1
u'المستحثة': u'الْمُسْتَحَثَّةِ', #1
u'المستحجم': u'الْمُسْتَحْجِمُ', #1
u'المستحشرات': u'الْمُسْتَحْشَرَاتِ', #1
u'المستحشف': u'الْمُسْتَحْشَفِ', #2
u'المستحشف': u'الْمُسْتَحْشِفِ', #7
u'المستحشفة': u'الْمُسْتَحْشِفَةِ', #5
u'المستحشفتي': u'الْمُسْتَحْشِفَتِي', #1
u'المستحصد': u'الْمُسْتَحْصَدِ', #1
u'المستحفظ': u'الْمُسْتَحْفَظِ', #1
u'المستحفظ': u'الْمُسْتَحْفِظَ', #1
u'المستحفظ': u'الْمُسْتَحْفِظِ', #1
u'المستحفظ': u'الْمُسْتَحْفِظُ', #2
u'المستحفظ': u'الْمُسْتَحْفَظُ', #3
u'المستحفظة': u'الْمُسْتَحْفَظَةِ', #1
u'المستحفظة': u'الْمُسْتَحْفَظَةُ', #2
u'المستحفي': u'الْمُسْتَحْفِي', #2
u'المستحقرة': u'الْمُسْتَحْقَرَةَ', #7
u'المستحكرة': u'المستحكرة', #1
u'المستحكرين': u'الْمُسْتَحْكِرِينَ', #1
u'المستحلاة': u'الْمُسْتَحْلَاة', #1
u'المستحوز': u'الْمُسْتَحْوِزُ', #1
u'المستخبث': u'الْمُسْتَخْبَثَ', #2
u'المستخبث': u'الْمُسْتَخْبَثِ', #4
u'المستخبثات': u'الْمُسْتَخْبَثَاتِ', #4
u'المستخشن': u'الْمُسْتَخْشَنِ', #1
u'المستخفى': u'الْمُسْتَخْفَى', #1
u'المستخل': u'الْمُسْتَخْل', #1
u'المستخلين': u'الْمُسْتَخْلِينَ', #1
u'المستخير': u'الْمُسْتَخِيرُ', #1
u'المستدانة': u'الْمُسْتَدَانَةِ', #12
u'المستدانة': u'الْمُسْتَدَانَةَ', #2
u'المستدانة': u'الْمُسْتَدَانَةُ', #5
u'المستدة': u'الْمُسْتَدَّةُ', #1
u'المستدة': u'الْمُسْتَدَّةِ', #1
u'المستدخلة': u'الْمُسْتَدْخِلَةَ', #1
u'المستدخلة': u'الْمُسْتَدْخِلَةُ', #1
u'المستدخلة': u'الْمُسْتَدْخِلَةِ', #1
u'المستدفعة': u'الْمُسْتَدْفَعَةِ', #1
u'المستدنين': u'الْمُسْتَدَنَينَ', #1
u'المستديملسفره': u'الْمُسْتَدِيمُلِسَفَرِهِ', #1
u'المسترابة': u'المسترابة', #1
u'المسترابة': u'الْمُسْتَرَابَةِ', #5
u'المسترحمين': u'الْمُسْتَرْحِمِينَ', #3
u'المسترذل': u'الْمُسْتَرْذَلِ', #1
u'المسترذلة': u'الْمُسْتَرْذَلَةِ', #1
u'المسترذلين': u'الْمُسْتَرْذَلِينَ', #1
u'المسترضع': u'الْمُسْتَرْضَعِ', #1
u'المسترضع': u'الْمُسْتَرْضِعِ', #6
u'المسترضع': u'الْمُسْتَرْضِعُ', #8
u'المسترضعة': u'الْمُسْتَرْضَعَةُ', #1
u'المسترعاة': u'الْمُسْتَرْعَاةُ', #1
u'المسترعاة': u'الْمُسْتَرْعَاةَ', #2
u'المسترعاة': u'الْمُسْتَرْعَاةِ', #5
u'المسترعى': u'الْمُسْتَرْعَى', #1
u'المسترم': u'الْمُسْتَرَمِّ', #1
u'المستريب': u'الْمُسْتَرِيبِ', #2
u'المستزاد': u'الْمُسْتَزَادِ', #3
u'المستسر': u'الْمُسْتَسِرَّ', #3
u'المستسر': u'الْمُسْتَسِرِّ', #3
u'المستسر': u'الْمُسْتَسِرُّ', #7
u'المستسعاة': u'الْمُسْتَسْعَاةِ', #3
u'المستسعاة': u'الْمُسْتَسْعَاةَ', #5
u'المستسعاة': u'الْمُسْتَسْعَاةُ', #7
u'المستسعي': u'الْمُسْتَسْعِيَ', #1
u'المستسعي': u'الْمُسْتَسْعِي', #3
u'المستسعى': u'الْمُسْتَسْعَى', #90
u'المستسقى': u'الْمُسْتَسْقِى', #1
u'المستسقى': u'الْمُسْتَسْقَى', #2
u'المستسلف': u'الْمُسْتَسْلِفَ', #2
u'المستسلف': u'الْمُسْتَسْلِفُ', #4
u'المستسلف': u'الْمُسْتَسْلِفِ', #4
u'المستشكل': u'الْمُسْتَشْكَلَ', #1
u'المستشكل': u'الْمُسْتَشْكَلُ', #1
u'المستشكل': u'الْمُسْتَشْكَلِ', #1
u'المستشكل': u'الْمُسْتَشْكِلِ', #12
u'المستشكل': u'الْمُسْتَشْكِلُ', #14
u'المستشكل': u'الْمُسْتَشْكِلَ', #7
u'المستشكلة': u'الْمُسْتَشْكِلَةِ', #2
u'المستشنعة': u'الْمُسْتَشْنَعَةَ', #1
u'المستشنعة': u'الْمُسْتَشْنَعَةِ', #1
u'المستصبح': u'الْمُسْتَصْبِحِ', #1
u'المستصحبه': u'الْمُسْتَصْحَبَهْ', #1
u'المستصفى': u'الْمُسْتَصْفَى', #442
u'المستصنع': u'الْمُسْتَصْنَعُ', #12
u'المستصنع': u'الْمُسْتَصْنَعِ', #2
u'المستصنع': u'الْمُسْتَصْنِعِ', #29
u'المستصنع': u'الْمُسْتَصْنَعَ', #4
u'المستصنع': u'الْمُسْتَصْنِعَ', #5
u'المستصنع': u'الْمُسْتَصْنِعُ', #58
u'المستصوب': u'الْمُسْتَصْوَبِ', #3
u'المستضر': u'الْمُسْتَضِرِّ', #2
u'المستطرف': u'الْمُسْتَطْرَفِ', #2
u'المستطرفة': u'الْمُسْتَطْرَفَةِ', #2
u'المستطرق': u'الْمُسْتَطْرَقِ', #1
u'المستظرف': u'الْمُسْتَظْرَفِ', #3
u'المستظرفة': u'الْمُسْتَظْرَفَةِ', #1
u'المستظهري': u'الْمُسْتَظْهِرِيِّ', #6
u'المستعدى': u'الْمُسْتَعْدَى', #12
u'المستعصب،': u'المستعصب،', #1
u'المستعظمه': u'الْمُسْتَعْظَمَهْ', #1
u'المستعفف': u'الْمُسْتَعْفِفُ', #1
u'المستعقب': u'الْمُسْتَعْقَبُ', #1
u'المستعقب': u'الْمُسْتَعْقَبِ', #1
u'المستعقب': u'الْمُسْتَعْقِبَ', #3
u'المستعقب': u'الْمُسْتَعْقِبُ', #5
u'المستعقب': u'الْمُسْتَعْقِبِ', #8
u'المستعلن': u'الْمُسْتَعْلِنُ', #1
u'المستعلى': u'الْمُسْتَعْلَى', #3
u'المستعور': u'الْمُسْتَعْوِرِ', #1
u'المستعينى': u'الْمُسْتَعِينِىُّ', #1
u'المستغرقي': u'الْمُسْتَغْرِقِي', #1
u'المستغزر': u'الْمُسْتَغْزِرُ', #1
u'المستفاض': u'الْمُسْتَفَاضِ', #2
u'المستفتى': u'الْمُسْتَفْتِى', #1
u'المستفتى': u'الْمُسْتَفْتَى', #18
u'المستفحش': u'الْمُسْتَفْحِشِ', #1
u'المستفرش': u'الْمُسْتَفْرِشِ', #2
u'المستفرش': u'الْمُسْتَفْرِشُ', #4
u'المستفرشة': u'الْمُسْتَفْرَشَةَ', #1
u'المستفرشة': u'الْمُسْتَفْرَشَةِ', #14
u'المستفرشة': u'الْمُسْتَفْرَشَةُ', #5
u'المستفرق': u'الْمُسْتَفْرَقُ', #1
u'المستفزز': u'الْمُسْتَفْزِزُ', #1
u'المستفل': u'الْمُسْتَفَلِ', #1
u'المستفل': u'الْمُسْتَفِلِ', #2
u'المستفلة': u'الْمُسْتَفِلَةَ', #2
u'المستقاء': u'الْمُسْتَقَاءِ', #1
u'المستقاد': u'الْمُسْتَقَادِ', #12
u'المستقاد': u'الْمُسْتَقَادَ', #2
u'المستقاد': u'الْمُسْتَقَادُ', #3
u'المستقال': u'الْمُسْتَقَالِ', #6
u'المستقة': u'الْمُسْتَقَةَ', #1
u'المستقذر': u'الْمُسْتَقْذِرِ', #1
u'المستقذر': u'الْمُسْتَقْذَر', #2
u'المستقذر': u'الْمُسْتَقْذَرِ', #26
u'المستقذر': u'الْمُسْتَقْذَرَ', #3
u'المستقذر': u'الْمُسْتَقْذَرُ', #8
u'المستقذرات': u'الْمُسْتَقْذِرَاتِ', #1
u'المستقذرات': u'الْمُسْتَقْذَرَاتِ', #16
u'المستقذرة': u'الْمُسْتَقْذَرَة', #1
u'المستقذرة': u'الْمُسْتَقْذَرَةُ', #1
u'المستقذرة': u'الْمُسْتَقْذَرَةَ', #2
u'المستقذرة': u'الْمُسْتَقْذَرَةِ', #22
u'المستقذرين': u'الْمُسْتَقْذِرَيْنِ', #1
u'المستقرب': u'الْمُسْتَقْرَبُ', #1
u'المستقرض': u'المستقرضِ', #1
u'المستقرض': u'الْمُسْتَقْرَضَ', #15
u'المستقرض': u'الْمُسْتَقْرَضِ', #16
u'المستقرض': u'الْمُسْتَقْرِضُ', #207
u'المستقرض': u'الْمُسْتَقْرِضِ', #277
u'المستقرض': u'الْمُسْتَقْرَضُ', #6
u'المستقرض': u'الْمُسْتَقْرِضَ', #70
u'المستقرضان': u'الْمُسْتَقْرِضَانِ', #2
u'المستقرضة': u'الْمُسْتَقْرَضَةَ', #1
u'المستقرضة': u'الْمُسْتَقْرَضَةُ', #4
u'المستقرضين': u'الْمُسْتَقْرِضِينَ', #2
u'المستقصى': u'الْمُسْتَقْصَى', #1
u'المستقضى': u'الْمُسْتَقْضَى', #4
u'المستقطر': u'الْمُسْتَقْطِرَ', #1
u'المستقطر': u'الْمُسْتَقْطَرِ', #2
u'المستقنع': u'الْمُسْتَقْنِعِ', #1
u'المستقيد': u'الْمُسْتَقِيدِ', #1
u'المستقيد': u'الْمُسْتَقِيدُ', #4
u'المستقيمه': u'الْمُسْتَقِيمَهْ', #1
u'المستقيئ': u'الْمُسْتَقْيِئِ', #1
u'المستكري': u'الْمُسْتَكْرِيَ', #3
u'المستكري': u'الْمُسْتَكْرِي', #63
u'المستكفي': u'الْمُسْتَكْفِي', #1
u'المستلحق': u'الْمُسْتَلْحِق', #1
u'المستلحق': u'الْمُسْتَلْحِقَ', #19
u'المستلحق': u'الْمُسْتَلْحَق', #3
u'المستلحق': u'الْمُسْتَلْحَقَ', #32
u'المستلحق': u'الْمُسْتَلْحِقِ', #43
u'المستلحق': u'الْمُسْتَلْحَقِ', #52
u'المستلحق': u'الْمُسْتَلْحِقُ', #62
u'المستلحق': u'الْمُسْتَلْحَقُ', #92
u'المستلحقة': u'الْمُسْتَلْحِقَةَ', #1
u'المستلحقة': u'الْمُسْتَلْحِقَةِ', #1
u'المستلحقة': u'الْمُسْتَلْحِقَةُ', #2
u'المستلحقين': u'الْمُسْتَلْحَقَيْنِ', #2
u'المستلحقين': u'الْمُسْتَلْحَقِينَ', #6
u'المستلئم': u'الْمُسْتَلْئِمِ', #1
u'المستمتعا': u'الْمُسْتَمْتَعَا', #1
u'المستمك': u'الْمُسْتَمِكِ', #1
u'المستملك': u'المستملك', #1
u'المستملكه': u'الْمُسْتَمْلَكَهْ', #1
u'المستملي': u'الْمُسْتَمْلِيَّ', #1
u'المستملي،': u'الْمُسْتَمْلِيُّ،', #1
u'المستملى': u'الْمُسْتَمْلِىَّ', #1
u'المستملي': u'الْمُسْتَمْلِي', #15
u'المستملى': u'الْمُسْتَمْلِى', #17
u'المستملى': u'الْمُسْتَمْلِىُّ', #36
u'المستملي،': u'الْمُسْتَمْلِي،', #4
u'المستناب': u'الْمُسْتَنَابِ', #4
u'المستناب': u'الْمُسْتَنَابُ', #6
u'المستناخ': u'الْمُسْتَنَاخَ', #1
u'المستنة': u'الْمُسْتَنَّةِ', #1
u'المستنجى': u'الْمُسْتَنْجَى', #7
u'المستنذر': u'الْمُسْتَنْذَرِ', #2
u'المستنزل': u'الْمُسْتَنْزِلَ', #1
u'المستنزلة': u'الْمُسْتَنْزِلَةَ', #1
u'المستنصح': u'الْمُسْتَنْصِحِ', #4
u'المستنصرية': u'المُسْتَنْصِرِيَّة', #2
u'المستنظر': u'الْمُسْتَنْظِرُ', #1
u'المستنقذ': u'الْمُسْتَنْقَذِ', #1
u'المستنكح': u'الْمُسْتَنْكِحُ', #11
u'المستنكح': u'الْمُسْتَنْكِحَ', #21
u'المستنكح': u'الْمُسْتَنْكَحِ', #25
u'المستنكح': u'الْمُسْتَنْكِحِ', #37
u'المستنكح': u'الْمُسْتَنْكَحُ', #6
u'المستنكح': u'الْمُسْتَنْكَحَ', #7
u'المستنكحان': u'الْمُسْتَنْكَحَانِ', #1
u'المستنكه': u'الْمُسْتَنْكِهُ', #1
u'المستنمى': u'الْمُسْتَنْمَى', #2
u'المستنيب': u'الْمُسْتَنِيب', #1
u'المستنيب': u'الْمُسْتَنِيبَ', #11
u'المستنيب': u'الْمُسْتَنِيبُ', #63
u'المستنيب': u'الْمُسْتَنِيبِ', #95
u'المستهدم': u'الْمُسْتَهْدَمُ', #1
u'المستهدي': u'الْمُسْتَهْدِي', #1
u'المستوره': u'الْمَسْتُورَهْ', #2
u'المستوزر': u'الْمُسْتَوْزِرِ', #1
u'المستوشرة': u'الْمُسْتَوْشِرَةَ', #1
u'المستوشمة': u'الْمُسْتَوْشِمَةَ', #1
u'المستوضحه': u'الْمُسْتَوْضَحَهْ', #1
u'المستوضحه': u'الْمُسْتَوْضِحَهْ', #1
u'المستوعيات': u'الُمسْتَوْعِيَاتِ', #1
u'المستوغر': u'الْمُسْتَوْغِرُ', #1
u'المستوغر': u'الْمُسْتَوْغِرِ', #2
u'المستوغر': u'الْمُسْتَوْغِرَ', #3
u'المستوغر': u'المُسْتَوْغِرُ', #6
u'المستوفاة': u'الْمُسْتَوْفَاة', #1
u'المستوفاة': u'الْمُسْتَوْفَاةِ', #16
u'المستوفاة': u'الْمُسْتَوْفَاةَ', #4
u'المستوفاة': u'الْمُسْتَوْفَاةُ', #9
u'المستوفز': u'المستوفز', #1
u'المستوفز': u'الْمُسْتَوْفِزُ', #1
u'المستوفز': u'الْمُسْتَوْفِزِ', #12
u'المستوفزا': u'الْمُسْتَوْفِزَا', #1
u'المستوفزين': u'الْمُسْتَوْفِزِينَ', #5
u'المستوفى': u'الْمُسْتَوْفَى', #311
u'المستولدتي': u'الْمُسْتَوْلَدَتِي', #1
u'المستولده': u'الْمُسْتَوْلَدَهْ', #1
u'المستويوالوجه': u'الْمُسْتَوِيوَالْوَجْهُ', #1
u'المستئيم': u'الْمُسْتَئِيمَ', #1
u'المستيسر': u'الْمُسْتَيْسَرَ', #2
u'المستيسر': u'الْمُسْتَيْسَرِ', #2
u'المسجدSقول': u'الْمَسْجِدِSقَوْلُ', #1
u'المسجدأو': u'الْمَسْجِدِأَوْ', #1
u'المسجدللبيع': u'الْمَسْجِدِلِلْبَيْعِ', #1
u'المسجدلما': u'الْمَسْجِدِلِمَا', #1
u'المسجع': u'الْمُسَجّعُ', #1
u'المسجع': u'الْمُسَجَّعُ', #1
u'المسجع': u'الْمُسْجَعِ', #2
u'المسجع': u'الْمُسَجَّعِ', #3
u'المسجى': u'المسجى', #4
u'المسجى': u'الْمُسَجَّى', #4
u'المسحين': u'الْمِسْحَيْنِ', #3
u'المسحين': u'الْمَسْحَيْنِ', #4
u'المسخور': u'الْمَسْخُورِ', #2
u'المسخوطة': u'الْمَسْخُوطَةَ', #1
u'المسخوطون': u'الْمَسْخُوطُونَ', #1
u'المسخوطين': u'الْمَسْخُوطِينَ', #1
u'المسخوطين': u'الْمَسْخُوطَيْنِ', #1
u'المسدن': u'المَسْدَنِ', #1
u'المسدن': u'الْمَسْدَنِ', #1
u'المسرحه': u'الْمُسَرَّحَهْ', #1
u'المسرقن': u'الْمُسَرْقَنِ', #1
u'المسرقن': u'الْمُسَرْقَنُ', #2
u'المسرمدات': u'الْمُسَرْمَدَاتُ', #1
u'المسروح': u'الْمَسْرُوحُ', #1
u'المسروحة': u'الْمَسْرُوحَةُ', #1
u'المسرود': u'الْمَسْرُودَ', #1
u'المسرود': u'الْمَسْرُودُ', #2
u'المسرود': u'الْمَسْرُودِ', #4
u'المسرودة': u'الْمَسْرُودَةِ', #7
u'المسروقي': u'الْمَسْرُوقِيِّ', #1
u'المسروقي،': u'الْمَسْرُوقِيُّ،', #10
u'المسروقي،': u'المسروقي،', #2
u'المسروقي،': u'الْمَسْرُوقِيِّ،', #3
u'المسروقي': u'الْمَسْرُوقِيُّ', #4
u'المسروقى': u'الْمَسْرُوقِىُّ', #4
u'المسرى': u'الْمُسَرّى', #1
u'المسطاح': u'الْمِسْطَاحُ', #1
u'المسطاح': u'الْمِسْطَاحِ', #1
u'المسعط': u'الْمُسْعُطُ', #1
u'المسعط': u'الْمِسْعَطُ', #1
u'المسعط': u'الْمِسْعَطِ', #1
u'المسعل': u'الْمَسْعَلِ', #1
u'المسعودي': u'المسعوديّ', #1
u'المسعودي': u'المَسْعُوديّ', #1
u'المسعودى': u'الْمَسْعُودِىِّ', #15
u'المسعودي': u'الْمَسْعُودِيُّ', #164
u'المسعودى': u'الْمَسْعُودِىَّ', #2
u'المسعودي،': u'الْمَسْعُودِيِّ،', #20
u'المسعودي،': u'الْمَسْعُودِيُّ،', #34
u'المسعودي،': u'المسعودي،', #35
u'المسعودي': u'الْمَسْعُودِيّ', #35
u'المسعودي': u'المسعودي', #4
u'المسعودي': u'الْمَسْعُودِيَّ', #4
u'المسعودى': u'الْمَسْعُودِىُّ', #57
u'المسعودي': u'الْمَسْعُودِيِّ', #65
u'المسعودية': u'الْمَسْعُودِيَّةِ', #11
u'المسعوديوحجابه': u'الْمَسْعُودِيُّوَحِجَابُهُ', #1
u'المسغبه': u'الْمَسْغَبَهْ', #2
u'المسغم': u'الْمُسَغَّمُ', #1
u'المسفور': u'الْمَسْفُورِ', #4
u'المسفوران': u'الْمَسْفُورَانِ', #1
u'المسقاوي': u'الْمَسْقَاوِيَّ', #2
u'المسقاوي': u'الْمَسْقَاوِيُّ', #3
u'المسقاوي': u'الْمَسْقَاوِيِّ', #4
u'المسقف': u'الْمُسَقَّفِ', #11
u'المسقف': u'الْمُسَقَّفُ', #4
u'المسقف': u'الْمُسْقَفُ', #7
u'المسقف': u'الْمُسْقَفِ', #9
u'المسقفات': u'الْمُسَقَّفَاتُ', #2
u'المسقفات': u'الْمُسَقَّفَاتِ', #4
u'المسقفات': u'الْمُسْقَفَاتِ', #5
u'المسقفان': u'الْمُسَقَّفَانِ', #1
u'المسقفان': u'الْمُسْقَفَانِ', #1
u'المسقفة': u'الْمُسْقَفَةُ', #1
u'المسقفة': u'المسقفة', #2
u'المسقفتان': u'الْمُسَقَّفَتَانِ', #1
u'المسقفتان': u'الْمُسْقَفَتَانِ', #1
u'المسقفتين': u'الْمُسْقَفَتَيْنِ', #1
u'المسقوف': u'الْمَسْقُوفَ', #1
u'المسقوف': u'الْمَسْقُوفِ', #1
u'المسكورة': u'الْمَسْكُورَةِ', #2
u'المسكى': u'الْمِسْكِىُّ', #1
u'المسلاتي': u'الْمُسْلَاتِيِّ', #1
u'المسلاتيين': u'المسلاتيين', #1
u'المسلاخ': u'المسلاخ', #1
u'المسلمانية': u'المسلمانية', #1
u'المسلمانية': u'الْمَسْلَمانِيَّةَ', #1
u'المسلمه': u'الْمُسلِمَهْ', #1
u'المسلمه': u'الْمِسْلِمَهْ', #1
u'المسلمه': u'الْمُسْلِمَهْ', #5
u'المسلمونا': u'الْمُسْلِمُونَا', #1
u'المسلمينا': u'الْمُسْلِمِينَا', #3
u'المسلمينالوجه': u'الْمُسْلِمِينَالْوَجْهُ', #1
u'المسلى': u'الْمَسْلَى', #1
u'المسلى': u'الْمُسْلِىُّ', #2
u'المسلى': u'الْمُسْلِىِّ', #2
u'المسمط': u'الْمُسَمَّطِ', #2
u'المسمط': u'الْمَسْمَطِ', #3
u'المسمعى': u'الْمَسْمَعِىُّ', #1
u'المسمعى': u'الْمِسْمَعِىِّ', #3
u'المسمعى': u'الْمِسْمَعِىُّ', #51
u'المسملين': u'الْمُسْمَلِينَ', #2
u'المسمور': u'الْمَسْمُورِ', #3
u'المسمورة': u'الْمَسْمُورَةُ', #1
u'المسموط': u'الْمَسْمُوطُ', #1
u'المسموط': u'الْمَسْمُوطِ', #8
u'المسموطة': u'الْمَسْمُوطَةِ', #1
u'المسمولي': u'المَسْمُولِيُّ', #1
u'المسنأة': u'الْمُسَنَّأَةُ', #1
u'المسناة': u'الْمُسَنّاةُ', #1
u'المسناة': u'الْمُسْنَاةُ', #1
u'المسناة': u'الْمُسْنَاةِ', #2
u'المسناة': u'الْمُسْنَاةَ', #3
u'المسناة': u'الْمُسَنَّاةَ', #32
u'المسناة': u'الْمُسَنَّاةُ', #38
u'المسناة': u'الْمُسَنَّاةِ', #70
u'المسناوي': u'الْمِسْنَاوِيِّ', #15
u'المسناوي': u'الْمِسْنَاوِيُّ', #162
u'المسناوي': u'المسناوي', #3
u'المسناوي': u'الْمِسَناوِيُّ', #3
u'المسناوي': u'الْمِسْنَاوِيّ', #8
u'المسنبل': u'الْمُسَنْبَلِ', #1
u'المسنجاني،': u'الْمسِنْجَانِيُّ،', #1
u'المسندى': u'الْمُسْنَدِىُّ', #2
u'المسندى': u'الْمُسْنَدِىِّ', #7
u'المسنم': u'الْمُسَنَّمُ', #4
u'المسنودة': u'الْمَسْنُودَةِ', #1
u'المسهول': u'الْمَسْهُولَ', #1
u'المسهومين': u'الْمَسْهُومِينَ', #1
u'المسوح': u'المسوح', #1
u'المسوح': u'الْمُسُوحِ', #1
u'المسوح؟': u'الْمُسُوحُ؟', #1
u'المسوح': u'الْمُسُوحَ', #13
u'المسوح': u'الْمُسُوحُ', #2
u'المسوحفيجلسون': u'الْمُسُوحُفَيَجْلِسُونَ', #1
u'المسوحي': u'المسوحي', #1
u'المسوحي': u'الْمُسُوحِيُّ', #1
u'المسورى': u'الْمِسْوَرِىُّ', #4
u'المسيبى': u'الْمُسَيَّبِىِّ', #1
u'المسيبى': u'الْمُسَيَّبِىُّ', #11
u'المسيبي،': u'المسيبي،', #2
u'المسيبي': u'الْمُسَيَّبِيُّ', #3
u'المسيبي': u'الْمُسَيِّبِيُّ', #3
u'المسيبى': u'الْمُسَيِّبِىُّ', #3
u'المسيبي،': u'الْمُسَيَّبِيُّ،', #4
u'المسيبي،': u'الْمُسَيِّبِيُّ،', #5
u'المسيجيد': u'الْمُسَيْجِيدِ', #3
u'المسيخ': u'الْمَسِيخِ', #2
u'المسيطة': u'الْمَسِيطَةِ', #1
u'المسيك': u'المسيك', #1
u'المسيك': u'الْمُسَيْكِ', #1
u'المسيم': u'الْمُسِيمُ', #1
u'المسيم': u'الْمُسِيمِ', #2
u'المسين': u'الْمَسَّيْنِ', #8
u'المسيئ': u'الْمُسَيِّئِ', #1
u'المسيئ': u'الْمُسِيئِ', #3
u'المشا': u'الْمَشَا', #2
u'المشاءون': u'الْمَشَّاءُونَ', #12
u'المشاححة': u'الْمُشَاحَحَةُ', #4
u'المشاححة': u'الْمُشَاحَحَةِ', #8
u'المشارع': u'الْمَشَارِع', #1
u'المشارع': u'الْمَشَارِعَ', #1
u'المشارع': u'الْمَشَارِعِ', #4
u'المشاش': u'الْمُشَاشُ', #1
u'المشاش': u'الْمُشَاشِ', #4
u'المشاش': u'الْمُشَاشَ', #5
u'المشاقص': u'المشاقص', #2
u'المشاققة': u'الْمُشَاقَقَةِ', #1
u'المشالة': u'الْمُشَالَةُ', #2
u'المشالة': u'الْمُشَالَةِ', #48
u'المشالقون': u'الْمُشَالِقُونَ', #1
u'المشاوذ': u'الْمَشَاوِذُ', #1
u'المشاوذ': u'الْمَشَاوِذِ', #2
u'المشاوره': u'الْمُشَاوَرَهْ', #1
u'المشائخ': u'الْمَشَائِخِ', #2
u'المشبة': u'الْمُشَبَّة', #1
u'المشت': u'الْمُشْتُ', #1
u'المشتات': u'الْمُشَتَّاتِ', #1
u'المشتراة': u'الْمُشْتَرَاة', #1
u'المشتراة': u'الْمُشْتَرَاةُ', #116
u'المشتراة': u'الْمُشْتَرَاةِ', #237
u'المشتراة': u'الْمُشْتَرَاةَ', #92
u'المشترب': u'الْمُشْتَرِبَ', #1
u'المشترب': u'الْمُشْتَرِبُ', #4
u'المشتركتي': u'الْمُشْتَرِكَتَيْ', #4
u'المشتركتي': u'الْمُشْتَرَكَتَيْ', #5
u'المشتركه': u'الْمُشْتَرَكَهْ', #4
u'المشترى': u'الْمُشْتَرِىَ', #1
u'المشترى': u'الْمْشْتَرِىَ', #1
u'المشترى،': u'الْمُشْتَرَى،', #1
u'المشترى': u'الْمُشْتَرِى', #12
u'المشترى': u'الْمُشْتَرَى', #1338
u'المشترى': u'الْمْشْتَرِى', #5
u'المشتولي': u'الْمَشْتُولِيُّ', #1
u'المشتئق': u'الْمُشْتَئِقِ', #1
u'المشد': u'الْمُشَدُّ', #1
u'المشد': u'الْمُشِدِّ', #1
u'المشد': u'الْمِشَدِّ', #15
u'المشد': u'الْمِشَدُّ', #24
u'المشد': u'الْمِشَدَّ', #8
u'المشداخ': u'الْمِشْدَاخُ', #1
u'المشدة': u'الْمَشَدَّةِ', #1
u'المشدة': u'الْمُشَدَّةِ', #1
u'المشدة': u'الْمُشِدَّةِ', #1
u'المشدخ': u'الْمُشَدَّخَ', #1
u'المشدخ': u'الْمُشَدَّخُ', #2
u'المشدخة': u'الْمُشَدَّخَةِ', #1
u'المشدوخ': u'الْمَشْدُوخ', #1
u'المشذالي': u'الْمَشَذَّالِيَّ', #1
u'المشذالي': u'الْمَشَذَّالِيُّ', #28
u'المشذالي': u'الْمَشَذَّالِيِّ', #4
u'المشرخ': u'الْمُشَرَّخَ', #2
u'المشرز': u'الْمُشْرَزِ', #2
u'المشرز': u'الْمُشْرِزِ', #3
u'المشرز': u'الْمُشَرَّزُ', #4
u'المشرز': u'الْمُشَرَّزِ', #5
u'المشرقى': u'الْمِشْرَقِىِّ', #2
u'المشركية': u'الْمُشْرِكِيَّةُ', #1
u'المشركينSالمقصرون': u'الْمُشْرِكِينَSالْمُقَصّرُونَ', #1
u'المشروطية': u'الْمَشْرُوطِيَّةَ', #1
u'المشروف': u'الْمَشْرُوفِ', #1
u'المشرى': u'الْمُشْرَى', #12
u'المشعار': u'الْمِشْعَارِ', #11
u'المشعوبة': u'الْمَشْعُوبَةِ', #1
u'المشعور': u'الْمَشْعُورَ', #1
u'المشعور': u'الْمَشْعُورِ', #1
u'المشعور': u'الْمَشْعُورُ', #4
u'المشعولة': u'الْمَشْعُولَةُ', #1
u'المشفة': u'الْمَشَفَّةُ', #1
u'المشفوعة': u'الْمَشْفُوعَةَ', #10
u'المشفوعة': u'الْمَشْفُوعَةُ', #11
u'المشفوعة': u'الْمَشْفُوعَةِ', #74
u'المشفوه': u'المشفوه', #1
u'المشقر': u'الْمُشَقّرِ', #1
u'المشقر': u'الْمُشَقَّرُ', #1
u'المشقر،': u'الْمُشَقِّرِ،', #1
u'المشقشق': u'الْمُشَقْشِقِ', #1
u'المشقص': u'الْمِشْقَصُ', #1
u'المشقص': u'الْمِشْقَصَ', #2
u'المشقص': u'المشقص', #4
u'المشقوحة': u'الْمَشْقُوحَةُ', #1
u'المشقوحة': u'الْمَشْقُوحَةَ', #2
u'المشكاتي': u'الْمِشْكَاتِيُّ', #1
u'المشكى': u'الْمُشْكَى', #1
u'المشلل': u'الْمَشْلَلِ', #1
u'المشلل': u'الْمُشَلَّل', #1
u'المشلل': u'الْمُشَلَّلِ', #16
u'المشلل': u'الْمُشَلَّلُ', #3
u'المشلل': u'الْمُشَلّلِ', #5
u'المشلل،': u'الْمُشَلَّلِ،', #5
u'المشمعل،': u'الْمُشْمَعِلُّ،', #1
u'المشمعل،': u'الْمُشْمَعِّلُ،', #1
u'المشمعل،': u'الْمُشْمَعِلِّ،', #3
u'المشمعل': u'الْمُشْمَعِلِّ', #7
u'المشمعل': u'الْمُشْمَعِلُّ', #8
u'المشهده': u'الْمُشْهِدَهْ', #1
u'المشهورية': u'الْمَشْهُورِيَّةُ', #1
u'المشهورية': u'الْمَشْهُورِيَّةِ', #3
u'المشوم': u'الْمَشُومُ', #1
u'المشى': u'المشى', #11
u'المشى': u'الْمَشْىَ', #13
u'المشى': u'الْمَشْىِ', #22
u'المشى': u'الْمَشْىُ', #8
u'المشيء': u'الْمَشِيءُ', #1
u'المشيء': u'الْمُشِيءِ', #2
u'المشئمة،': u'المشئمة،', #1
u'المشئوم': u'الْمَشْئُومُ', #10
u'المشئوم': u'الْمَشْئُومَ', #2
u'المشئوم': u'الْمَشْئُومِ', #3
u'المشيات': u'المشيات', #1
u'المشيات': u'الْمِشْيَاتُ', #2
u'المشيات': u'الْمِشْيَاتِ', #4
u'المشية،': u'الْمِشْيَةِ،', #1
u'المشية': u'الْمِشْيَةَ', #3
u'المشية': u'الْمِشْيَةُ', #3
u'المشية': u'الْمِشْيَةِ', #9
u'المشيتين': u'الْمِشْيَتَيْنِ', #1
u'المشيح': u'الْمُشِيح', #1
u'المشيح': u'الْمُشِيحَ', #1
u'المشيح': u'الْمُشِيحِ', #1
u'المشيرب': u'الْمُشَيْرِبُ', #1
u'المشيمه': u'الْمَشِيمَهْ', #1
u'المشيئية': u'الْمَشِيئِيَّةَ', #1
u'المصاحفى': u'الْمَصَاحِفِىُّ', #1
u'المصاروة': u'الْمَصَارِوَةِ', #1
u'المصاري': u'الْمَصَارِي', #2
u'المصاري': u'الْمَصَارِيُّ', #2
u'المصاري': u'الْمَصَارِيِّ', #2
u'المصاطب': u'الْمَصَاطِبِ', #2
u'المصاع': u'المِصَاع', #1
u'المصاع': u'الْمِصَاعْ', #1
u'المصاع': u'الْمِصَاعَ', #3
u'المصافع': u'الْمُصَافِعِ', #1
u'المصافيا': u'الْمُصَافِيَا', #2
u'المصال': u'الْمُصَالُ', #1
u'المصامح': u'الْمُصَامِحُ', #1
u'المصامح': u'الْمُصَامِحَ', #3
u'المصاهره': u'الْمُصَاهَرَهْ', #2
u'المصايب': u'الْمَصَايِبَ', #1
u'المصحونة': u'الْمَصْحُونَةِ', #2
u'المصدومين': u'الْمَصْدُومَيْنِ', #1
u'المصراة،': u'المصَراة،', #1
u'المصراة': u'الْمُصَرّاةَ', #1
u'المصراة': u'الْمُصَرّاةُ', #1
u'المصراة': u'الْمُصَرَّاة', #1
u'المصراة': u'الْمُصَرَّاةِ', #185
u'المصراة': u'الْمُصْرَاةَ', #2
u'المصراة،': u'الْمُصَرَّاةِ،', #2
u'المصراة': u'الْمُصَرَّاةُ', #21
u'المصراة': u'الْمُصَرَّاةَ', #22
u'المصراة': u'المصراة', #5
u'المصراة': u'الْمُصْرَاةِ', #6
u'المصرخية': u'الْمَصْرَخِيَّةُ', #1
u'المصرصر': u'الْمُصَرْصَرِ', #1
u'المصرصر': u'الْمُصَرْصِرِ', #1
u'المصرمة': u'الْمُصَرِّمَةُ', #1
u'المصرمة': u'الْمُصَرِّمَةِ', #1
u'المصرمة': u'الْمُصَرَّمَةُ', #4
u'المصرور': u'الْمَصْرُورِ', #1
u'المصرورة': u'الْمَصْرُورَةُ', #1
u'المصرورة': u'الْمَصْرُورَةِ', #1
u'المصرى': u'الْمُصَرَّى', #1
u'المصرى': u'الْمِصْرِىِّ', #16
u'المصرى': u'الْمِصْرِىُّ', #234
u'المصرى': u'الْمِصْرِىَّ', #5
u'المصطرف': u'الْمُصْطَرِفِ', #3
u'المصطرف': u'الْمُصْطَرِفَ', #4
u'المصطرف': u'الْمُصْطَرِفُ', #8
u'المصطرفين': u'الْمُصْطَرِفَيْنِ', #1
u'المصطفوية': u'الْمُصْطَفَوِيَّةُ', #2
u'المصطفوية': u'الْمُصْطَفَوِيَّةِ', #5
u'المصطقيم': u'الْمُصْطَقِيمَ', #1
u'المصطكا': u'الْمُصْطَكَا', #5
u'المصطلق،': u'المصْطَلِق،', #1
u'المصطلق': u'الْمُصْطَلِقَ', #1
u'المصطلق': u'الْمُصْطَلِقُ', #1
u'المصطلق': u'الْمُصْطَلِقٌٌٌٌِ', #1
u'المصطلق': u'الْمُصْطَلِقِِِِِ', #1
u'المصطلق،': u'الْمُصْطَلِقِ،', #10
u'المصطلق': u'المصطلق', #2
u'المصطلق': u'المُصْطَلق', #2
u'المصطلق،': u'المُصْطَلِق،', #2
u'المصطلق': u'الْمُصْطَلَق', #2
u'المصطلق': u'الْمُصْطَلَقِ', #2
u'المصطلق': u'الْمُصْطَلِقِ', #210
u'المصطلق': u'المُصْطَلِق', #3
u'المصطلق': u'الْمُصْطَلِق', #3
u'المصطلقي': u'الْمُصْطَلَقَيْ', #1
u'المصطلقي': u'الْمُصْطَلَقِيُّ', #1
u'المصطلقي': u'الْمُصْطَلِقِيَّ', #1
u'المصطلقي': u'الْمُصْطَلِقِيُّ', #1
u'المصطلقى': u'الْمُصْطَلَقِىُّ', #1
u'المصطلقي': u'المصطلقي', #2
u'المصطلقية،': u'المصْطَلقية،', #1
u'المصطلقية': u'الْمُصْطَلِقيّة', #1
u'المصطلقية': u'الْمُصْطَلِقِيّة', #1
u'المصطلقية': u'الْمُصْطَلِقِيَّةُ', #3
u'المصطلقيون': u'الْمُصْطَلَقِيُّونَ', #1
u'المصطلى': u'الْمُصْطَلَى', #1
u'المصلق': u'الْمُصْلَقُ', #1
u'المصلوفين': u'الْمَصْلُوفِينَ', #1
u'المصلوق': u'الْمَصْلُوقَ', #1
u'المصلوق': u'الْمَصْلُوقُ', #5
u'المصلوقة': u'الْمَصْلُوقَةَ', #1
u'المصلى': u'الْمُصَلًّى', #2
u'المصليأن': u'الْمُصَلِّيأَنَّ', #1
u'المصليعما': u'الْمُصَلِّيعَمَّا', #1
u'المصليلأنه': u'الْمُصَلِّيلِأَنَّهُ', #1
u'المصلين': u'الْمُصَلِّينً', #2
u'المصلينوالوجه': u'الْمُصَلِّينَوَالْوَجْهُ', #1
u'المصليوقوله': u'الْمُصَلِّيوَقَوْلُهُ', #1
u'المصمود': u'الْمَصْمُودُ', #1
u'المصمودي': u'الْمَصْمُودِيُّ', #1
u'المصنج': u'الْمُصَنَّجِ', #2
u'المصوية': u'الْمُصَوِّيَةُ', #1
u'المصيبها': u'الْمُصِيبُهَا', #1
u'المصيح': u'الْمَصِيحُ', #1
u'المصيح': u'الْمُصَيَّحُ', #2
u'المصيدات': u'الْمِصْيَدَاتِ', #1
u'المصيصى': u'الْمَصِيصِىُّ', #1
u'المصيصى': u'الْمَصِّيصِىُّ', #1
u'المصيصى': u'الْمِصِّيصِىُّ', #14
u'المصيطرون': u'الْمُصَيْطِرُونَ', #3
u'المصيود': u'الْمَصْيُودُ', #2
u'المضاربه': u'الْمُضَارَبَهْ', #2
u'المضاررة': u'الْمُضَارَرَةِ', #2
u'المضام': u'الْمُضَامُ', #1
u'المضائق': u'الْمَضَائِقِ', #1
u'المضبب': u'الْمُضَبَّبَ', #3
u'المضبب': u'الْمُضَبَّبُ', #30
u'المضبب': u'الْمُضَبَّبِ', #38
u'المضببة': u'الْمُضَبَّبَةُ', #1
u'المضببة': u'الْمُضَبَّبَةِ', #4
u'المضبور': u'المضبور', #1
u'المضجعة': u'الْمُضْجَعَةِ', #1
u'المضحى': u'الْمُضَحَّى', #16
u'المضحى': u'الْمُضَحِّى', #2
u'المضدراعي': u'المضدراعي', #1
u'المضرحي': u'المضرحي', #1
u'المضروبية': u'الْمَضْرُوبِيَّةِ', #1
u'المضرور': u'الْمَضْرُورِ', #3
u'المضرور': u'الْمَضْرُورُ', #5
u'المضرورة': u'الْمَضْرُورَةِ', #1
u'المضرى': u'الْمُضَرِىُّ', #1
u'المضطبع': u'الْمُضْطَبَعُ', #1
u'المضطرد': u'الْمُضْطَرِدِ', #1
u'المضفر': u'المضفر', #1
u'المضفر': u'الْمُضَفَّرُ', #1
u'المضلول': u'الْمَضْلُولِ', #1
u'المضمضمة': u'الْمُضَمْضِمَةُ', #1
u'المضنو': u'الْمَضْنُوِّ', #1
u'المضنوك': u'الْمَضْنُوكُ', #1
u'المضنونة': u'الْمَضْنُونَةُ', #2
u'المضنونة': u'الْمَضْنُونَةَ', #5
u'المضى': u'الْمُضِىِّ', #2
u'المضيرة': u'الْمَضِيرَةِ', #1
u'المضيرة': u'الْمَضِيرَةَ', #2
u'المضيقS': u'الْمَضِيقِS', #1
u'المضيئ،': u'الْمُضِيئُ،', #1
u'المطابقي': u'الْمُطَابِقِيِّ', #16
u'المطابقي': u'الْمُطَابِقِيَّ', #3
u'المطابقي': u'الْمُطَابِقِيُّ', #8
u'المطابقية': u'الْمُطَابِقَيَّةَ', #1
u'المطابقية': u'الْمُطَابِقِيِّةِ', #1
u'المطابقية': u'الْمُطَابِقِيَّةَ', #2
u'المطابقية': u'الْمُطَابِقِيَّةُ', #4
u'المطابقية': u'الْمُطَابِقِيَّةِ', #5
u'المطافلS': u'الْمَطَافِلِS', #1
u'المطافل': u'الْمَطَافِلِ', #1
u'المطافيل،': u'المطافيل،', #1
u'المطافيل': u'الْمَطَافِيلُ', #13
u'المطالبه': u'الْمُطَالَبَهْ', #2
u'المطبقى': u'الْمَطْبَقِىُّ', #1
u'المطبوب': u'المطبوب', #1
u'المطجنات': u'الْمُطَجَّنَاتِ', #1
u'المطجنة': u'الْمُطَجَّنَةُ', #1
u'المطرا': u'الْمَطَرَا', #3
u'المطراة': u'المطراة', #1
u'المطراة': u'الْمُطَرَّاة', #1
u'المطرخم': u'الْمُطَرَخِمّ', #1
u'المطرخم': u'الْمُطْرَخِمّ', #1
u'المطرو': u'الْمَطْرُوّ', #1
u'المطرو': u'الْمَطْرُوُّ', #11
u'المطرو': u'الْمَطْرُوَّ', #4
u'المطرو': u'الْمَطْرُوِّ', #8
u'المطروء': u'الْمَطْرُوءَ', #3
u'المطروء': u'الْمَطْرُوءُ', #6
u'المطروء': u'الْمَطْرُوءِ', #9
u'المطرور': u'الْمَطْرُورَ', #1
u'المطعومية': u'الْمَطْعُومِيَّةُ', #1
u'المطعومية': u'الْمَطْعُومِيَّةِ', #5
u'المطغي': u'الْمُطْغِي', #1
u'المطفي': u'الْمَطْفِيُّ', #1
u'المطلا': u'الْمَطْلَا', #1
u'المطلاء': u'الْمِطْلَاءَ', #1
u'المطلبSقصة': u'الْمُطّلِبِSقِصّةُ', #1
u'المطلبى': u'الْمُطَّلِبِىِّ', #2
u'المطلقه': u'الْمُطَلَّقَهْ', #2
u'المطلوبوالوجه': u'الْمَطْلُوبِوَالْوَجْهُ', #1
u'المطلوبوروي': u'الْمَطْلُوبَوَرُوِيَ', #1
u'المطلوبوروي': u'الْمَطْلُوبِوَرُوِيَ', #1
u'المطلوبية': u'الْمَطْلُوبِيَّةَ', #1
u'المطلوبية': u'الْمَطْلُوبِيَّةِ', #5
u'المطلوقين': u'الْمَطْلُوقِينَ', #1
u'المطلي': u'الْمَطْلِيّ', #1
u'المطلى': u'المطلى', #10
u'المطلي': u'الْمَطْلِيَّ', #2
u'المطلى': u'الْمُطْلَى', #2
u'المطلي': u'الْمَطْلِيُّ', #23
u'المطلي': u'الْمَطْلِيِّ', #3
u'المطليان': u'الْمَطْلِيَّانِ', #1
u'المطلية': u'الْمَطْلِيَّةِ', #2
u'المطلية': u'الْمَطْلِيَّةُ', #5
u'المطمس': u'الْمُطَمّسُ', #1
u'المطموع': u'الْمَطْمُوعُ', #3
u'المطمومة': u'الْمَطْمُومَةِ', #1
u'المطهرSمن': u'الْمُطَهّرُSمِنْ', #1
u'المطهره': u'الْمُطَهَّرَهْ', #3
u'المطهيا؟': u'المطهيا؟', #1
u'المطوس': u'الْمُطَوَّس', #2
u'المطوس': u'الْمُطَوِّسِ', #21
u'المطوعى': u'الْمُطَوَّعِىُّ', #1
u'المطوعى': u'الْمُطَوِّعِىُّ', #1
u'المطوعى': u'الْمُطَّوَعِىُّ', #1
u'المطوعى': u'الْمُطَّوِعِىُّ', #1
u'المطوعى': u'الْمُطَّوِّعِىُّ', #4
u'المطى': u'الْمَطِىِّ', #2
u'المطيا': u'الْمَطِيّا', #1
u'المطيات': u'الْمَطِيّاتِ', #2
u'المطيرى': u'الْمَطِيرىُّ', #1
u'المطيري': u'الْمَطِيرِيُّ', #2
u'المطيرى': u'الْمَطِيرِىُّ', #3
u'المطيري،': u'الْمَطِيرِيُّ،', #4
u'المطيطا': u'الْمُطَيْطَا', #6
u'المطيطاء': u'الْمُطَيْطَاءَ', #3
u'المطيطاء': u'الْمُطَيْطَاءُ', #3
u'المطيطاء': u'الْمُطَيْطَاءِ', #3
u'المطيفة': u'الْمُطِيفَةِ', #1
u'المطيم': u'الْمُطَيَّمِ', #2
u'المطين': u'الْمُطَيَّنِ', #2
u'المطينة': u'الْمُطَيَّنَةِ', #3
u'ألمظ': u'أَلْمُظُ', #1
u'المظ': u'الْمَظّ', #2
u'المظالما': u'الْمَظَالِمَا', #2
u'المظاهرون': u'الْمُظَاهِرُونَ', #1
u'المظاهرين': u'الْمُظَاهِرِينَ', #4
u'المظفري': u'الْمُظَفَّرِيِّ', #3
u'المظلومية': u'الْمَظْلُومِيَّةِ', #3
u'المظن': u'الْمَظِنَّ', #1
u'المظن': u'الْمُظَنِّ', #1
u'المظن': u'الْمُظَنُّ', #2
u'المظنات': u'الْمَظِنَّاتِ', #1
u'المعابدة': u'الْمُعَابَدَةَ', #1
u'المعابل': u'الْمَعَابِلُ', #3
u'المعاده': u'الْمُعَادَهْ', #2
u'المعادى': u'الْمُعَادَى', #2
u'المعاذى': u'الْمُعَاذِىِّ', #1
u'المعاذى': u'الْمُعَاذِىُّ', #3
u'المعاصى': u'الْمُعَاصَى', #1
u'المعاصى': u'الْمَعَاصِى', #5
u'المعاض': u'الْمُعَاضُ', #1
u'المعاضلة': u'الْمُعَاضَلَةِ', #1
u'المعاطاة': u'الْمُعَاطَاةِ', #143
u'المعاطاة': u'الْمُعَاطَاةَ', #24
u'المعاطاة': u'الْمُعَاطَاةُ', #45
u'المعاطش': u'الْمَعَاطِشِ', #2
u'المعاطيف': u'الْمَعَاطِيفِ', #11
u'المعاطيف': u'الْمَعَاطِيفُ', #3
u'المعاطيف': u'الْمَعَاطِيفَ', #8
u'المعافر': u'الْمَعَافِر', #1
u'المعافر': u'الْمَعَافِرُ', #1
u'المعافر،': u'الْمَعَافِرِ،', #1
u'المعافر': u'الْمَعَافِرَ', #2
u'المعافر': u'الْمُعَافِرِ', #2
u'المعافر': u'الْمَعَافِرِ', #22
u'المعافري،': u'المعَافِري،', #1
u'المعافري': u'الْمُعَافِرِيّ', #1
u'المعافري،': u'الْمَعَافِرِيَّ،', #1
u'المعافري،': u'الْمُعَافِرِيُّ،', #1
u'المعافري،': u'الْمُعَافِرِيِّ،', #1
u'المعافرى': u'المعافرى', #1
u'المعافرى': u'الْمَعَافِرِىُّ', #13
u'المعافري،': u'المعافري،', #2
u'المعافري،': u'الْمَعَافِرِيُّ،', #20
u'المعافري': u'الْمَعَافِرِيِّ', #28
u'المعافري': u'الْمَعَافِرِيّ', #3
u'المعافري': u'الْمَعَافِرِيُّ', #49
u'المعافرى': u'الْمَعَافِرِىِّ', #5
u'المعافري': u'المعافري', #6
u'المعافرى': u'الْمَعَافِرِىَّ', #6
u'المعافري،': u'الْمَعَافِرِيِّ،', #7
u'المعافري': u'الْمَعَافِرِيَّ', #8
u'المعافرية': u'الْمَعَافِرِيَّةِ', #1
u'المعافرية': u'الْمَعَافِرِيَّةُ', #3
u'المعافصة': u'الْمُعَافَصَةِ', #1
u'المعاقد': u'الْمُعَاقَدَ', #1
u'المعاقد': u'الْمُعَاقَدُ', #1
u'المعاقدان': u'الْمُعَاقِدَانِ', #1
u'المعاقدين': u'الْمُعَاقِدِينَ', #5
u'المعاقله': u'الْمُعَاقَلَهْ', #1
u'المعاكمة': u'الْمُعَاكَمَةِ', #1
u'المعالى': u'الْمَعَالِىِّ', #1
u'المعالى': u'الْمَعَالِى', #5
u'المعالية': u'الْمُعَالِيَّةِ', #1
u'المعاليم': u'الْمَعَالِيمِ', #7
u'المعامرين': u'الْمُعَامِرِينَ', #1
u'المعامله': u'الْمُعَامَلَهْ', #1
u'المعانتة': u'الْمُعَانَتَةِ', #1
u'المعانى': u'الْمُعَانَى', #2
u'المعانى': u'الْمَعَانِى', #7
u'المعاوض': u'الْمُعَاوَضُ', #1
u'المعاوض': u'الْمُعَاوَضَ', #2
u'المعاوض': u'الْمُعَاوَضِ', #2
u'المعاوض': u'الْمُعَاوِضِ', #2
u'المعاوض': u'الْمُعَاوِضُ', #3
u'المعاوق': u'الْمُعَاوِقِ', #5
u'المعاوي': u'المعاوي', #1
u'المعاوي': u'الْمُعَاوِيُّ', #1
u'المعاوي،': u'الْمُعَاوِيَّ،', #1
u'المعاوي،': u'الْمُعَاوِيُّ،', #1
u'المعاوي': u'الْمُعَاوِيّ', #3
u'المعاوى': u'الْمُعَاوِىِّ', #3
u'المعاوي،': u'الْمُعَاوِيِّ،', #4
u'المعاوي': u'الْمُعَاوِيِّ', #5
u'المعائب': u'الْمَعَائِبْ', #1
u'المعائب': u'الْمَعَائِبِ', #2
u'المعبس': u'الْمُعَبِّسُ', #1
u'المعبله': u'الْمَعْبَلَهْ', #1
u'المعبى': u'الْمُعَبَّى', #1
u'المعتاض': u'الْمُعْتَاضُ', #3
u'المعتده': u'الْمُعْتَدَّهْ', #1
u'المعتر': u'المعتر', #1
u'المعتر': u'الْمُعْتَرِّ', #1
u'المعتر': u'الْمُعْتَرَّ', #2
u'المعتر': u'الْمُعْتَرُّ', #3
u'المعتصبون': u'الْمُعْتَصِبُونَ', #2
u'المعتصبين': u'الْمُعْتَصِبِينَ', #1
u'المعتضد': u'الْمُعْتَضَد', #1
u'المعتضد': u'الْمُعْتَضَدْ', #1
u'المعتضد': u'الْمُعْتَضِدِ', #14
u'المعتضد': u'الْمُعْتَضِدُ', #19
u'المعتضد': u'الْمُعْتَضَدَ', #2
u'المعتضد': u'الْمُعْتَضِدَ', #2
u'المعتضد': u'الْمُعْتَضَدُ', #3
u'المعتضد': u'الْمُعْتَضَدِ', #6
u'المعتضدة': u'الْمُعْتَضَدَةَ', #1
u'المعتضدة': u'الْمُعْتَضِدَةِ', #1
u'المعتقه': u'الْمُعْتَقَهْ', #1
u'المعتلا': u'الْمُعْتَلَّا', #1
u'المعتلف': u'الْمُعْتَلَفِ', #2
u'المعتلفة': u'الْمُعْتَلِفَةِ', #1
u'المعتمل': u'الْمُعْتَمِلَ', #1
u'المعتمل': u'الْمُعْتَمِلُ', #11
u'المعتمل': u'الْمُعْتَمَلِ', #2
u'المعتمل': u'الْمُعْتَمِلِ', #27
u'المعتوق': u'الْمَعْتُوقَ', #10
u'المعتوق': u'الْمَعْتُوقُ', #12
u'المعتوق': u'الْمَعْتُوقِ', #12
u'المعتوقة': u'الْمَعْتُوقَةِ', #1
u'المعتوقة': u'الْمَعْتُوقَةُ', #5
u'المعتوقون': u'الْمَعْتُوقُونَ', #1
u'المعتوقين': u'الْمَعْتُوقِينَ', #1
u'المعثور': u'الْمَعْثُورِ', #13
u'المعثور': u'الْمَعْثُورُ', #2
u'المعجر': u'الْمِعْجَرُ', #1
u'المعجر': u'الْمِعْجَرِ', #1
u'المعجفة': u'الْمُعْجَفَةِ', #1
u'المعجوز': u'الْمَعْجُوزَ', #13
u'المعجوز': u'الْمَعْجُوزُ', #27
u'المعجوز': u'الْمَعْجُوزِ', #65
u'المعداني': u'الْمَعْدَانِيُّ', #1
u'المعدانى': u'الْمَعْدَانِىُّ', #1
u'المعداوي': u'الْمَعَدَّاوِيِّ', #2
u'المعدمه': u'الْمُعْدَمَهْ', #1
u'المعدمينا': u'الْمُعْدِمِينَا', #2
u'المعدودية': u'الْمَعْدُودِيَّةُ', #1
u'المعدومون': u'الْمَعْدُومُونَ', #2
u'المعدى': u'الْمُعَدَّى', #14
u'المعدى': u'الْمُعْدَى', #2
u'المعذل': u'الْمُعَذّلِ', #2
u'المعذل': u'الْمُعَذَّلِ', #9
u'المعر': u'الْمُعِرِّ', #1
u'المعراض': u'المعراض', #1
u'المعراض': u'الْمِعْرَاضَ', #1
u'المعراض؟': u'الْمِعْرَاضِ؟', #2
u'المعراض': u'الْمِعْرَاضُ', #27
u'المعراض': u'الْمِعْرَاض', #3
u'المعراض': u'الْمِعْرَاضِ', #37
u'المعراض،': u'الْمِعْرَاضِ،', #7
u'المعرج': u'الْمُعَرِّجَ', #1
u'المعرج': u'الْمُعَرِّجِ', #1
u'المعرص': u'الْمُعَرِّصُ', #1
u'المعرفا': u'الْمُعَرّفَا', #1
u'المعرفه': u'الْمَعْرِفَهْ', #4
u'المعرقب': u'المُعَرْقَب', #1
u'المعرقب': u'الْمُعَرْقِبُ', #1
u'المعرقب،': u'الْمُعَرْقَبُ،', #1
u'المعرقب': u'الْمُعَرْقَبُ', #3
u'المعرور،': u'الْمَعْرُورِ،', #1
u'المعرور': u'المعرور', #2
u'المعرور': u'الْمَعْرُورُ', #2
u'المعرور': u'الْمَعْرُورِ', #59
u'المعرور': u'الْمَعْرُورَ', #6
u'المعرورى': u'المعرورى', #1
u'المعروفالوجه': u'الْمَعْرُوفُالْوَجْهُ', #1
u'المعروفوروي': u'الْمَعْرُوفِوَرُوِيَ', #1
u'المعروفية': u'الْمَعْرُوفِيَّةُ', #1
u'المعزق': u'الْمِعْزَقُ', #1
u'المعزوم': u'الْمَعْزُوم', #1
u'المعزوم': u'الْمَعْزُومُ', #1
u'المعزوم': u'الْمَعْزُومِ', #8
u'المعسف': u'الْمُعَسَّفِ', #1
u'المعسور': u'الْمَعْسُورِ', #4
u'المعشور': u'الْمَعْشُورُ', #1
u'المعشور': u'الْمَعْشُورَ', #2
u'المعشور': u'الْمَعْشُورِ', #5
u'المعشورة': u'الْمَعْشُورَةَ', #1
u'المعصفر،': u'المعصفر،', #1
u'المعصفر': u'الْمُعَصْفَر', #1
u'المعصفر': u'الْمُعْصَفَرَ', #1
u'المعصفر،': u'الْمُعَصْفَرَ،', #1
u'المعصفر': u'الْمُعَصْفَرِ', #122
u'المعصفر': u'الْمُعَصْفَرُ', #38
u'المعصفر،': u'الْمُعَصْفَرِ،', #5
u'المعصفر': u'الْمُعَصْفَرَ', #51
u'المعصفر': u'المعصفر', #9
u'المعصفرات': u'الْمُعَصْفَرَاتُ', #2
u'المعصفرات،': u'الْمُعَصْفَرَاتُ،', #2
u'المعصفرات': u'الْمُعَصْفَرَاتِ', #6
u'المعصفرة،': u'الْمُعَصْفَرَةُ،', #1
u'المعصفرة،': u'الْمُعَصْفَرَةِ،', #1
u'المعصفرة': u'الْمُعَصْفَرَةِ', #3
u'المعصفرة': u'الْمُعَصْفَرَةَ', #4
u'المعصفرين': u'الْمُعَصْفَرَيْنِ', #3
u'المعصى': u'الْمُعْصَى', #1
u'المعض': u'الْمُعَضَّ', #1
u'المعض': u'الْمَعَضُّ', #2
u'المعض': u'الْمَعَضِّ', #2
u'المعضه': u'الْمُعْضِهِ', #3
u'المعضوب': u'الْمَعْضُوبَ', #10
u'المعضوب': u'الْمَعْضُوبُ', #47
u'المعضوب': u'الْمَعْضُوبِ', #93
u'المعضوبة': u'الْمَعْضُوبَةِ', #1
u'المعضولة': u'الْمَعْضُولَةَ', #1
u'المعضولة': u'الْمَعْضُولَةُ', #1
u'المعطن': u'الْمُعَطَّنِ', #1
u'المعطن': u'الْمَعْطِنِ', #2
u'المعطن': u'الْمُعَطّنِ', #4
u'المعطوس': u'الْمَعْطُوسِ', #1
u'المعطوش': u'الْمَعْطُوشِ', #4
u'المعفف': u'الْمُعَفَّفُ', #1
u'المعفوج': u'الْمَعْفُوجِ', #1
u'المعفوف': u'الْمَعْفُوفِ', #1
u'المعفول': u'الْمَعْفُول', #1
u'المعقبي': u'الْمُعَقِّبِيِّ', #1
u'المعقر': u'الْمُعْقِرَ', #1
u'المعقر': u'الْمُعْقِرِ', #2
u'المعقرى': u'الْمَعْقِرِىِّ', #3
u'المعقرى': u'الْمَعْقِرِىُّ', #5
u'المعقص': u'الْمُعَقَّصُ', #1
u'المعقص': u'الْمُعَقَّصِ', #1
u'المعقلى': u'الْمَعْقِلىُّ', #1
u'المعقلى': u'الْمَعْقِلِىُّ', #1
u'المعقوص': u'المعقوص', #1
u'المعقوص': u'الْمَعْقُوصَ', #1
u'المعقوص': u'الْمَعْقُوصِ', #2
u'المعل': u'الْمُعَلّ', #1
u'المعل': u'الْمُعَلَّ', #1
u'المعلا،': u'الْمُعَلا،', #1
u'المعلا': u'الْمُعَلَّا', #2
u'المعلمونوالوجه': u'الْمُعَلِّمُونَوَالْوَجْهُ', #1
u'المعلهج': u'الْمُعَلْهَجِ', #1
u'المعلهج': u'الْمُعَلْهَجُ', #3
u'المعلوق': u'الْمُعْلُوقِ', #1
u'المعلوك': u'الْمُعْلُوك', #1
u'المعلوك': u'الْمَعْلُوكِ', #2
u'المعلوك': u'الْمَعْلُوكُ', #4
u'المعلولية': u'الْمَعْلُولِيَّةِ', #1
u'المعلومون': u'الْمَعْلُومُونَ', #1
u'المعلومية': u'الْمَعْلُومِيَّةُ', #2
u'المعلومية': u'الْمَعْلُومِيَّةِ', #5
u'المعم': u'الْمُعَمّ', #2
u'المعمرى': u'الْمَعْمَرِىِّ', #1
u'المعمرى': u'الْمَعْمَرِىُّ', #21
u'المعملات': u'الْمُعْمِلَاتِ', #1
u'المعمولية': u'الْمَعْمُولِيَّةِ', #2
u'المعنس': u'الْمُعَنَّسَ', #1
u'المعنس': u'الْمُعَنَّسُ', #1
u'المعنس': u'الْمُعَنَّسِ', #1
u'المعنس': u'الْمُعْنِسِ', #1
u'المعنسة': u'الْمُعَنِّسَةَ', #1
u'المعنسة': u'الْمُعَنَّسَةَ', #2
u'المعنسة': u'الْمُعَنَّسَةُ', #2
u'المعنسة': u'الْمُعَنَّسَةِ', #3
u'المعنعن': u'الْمُعَنْعَنَ', #1
u'المعنعن': u'الْمُعَنْعَنُ', #1
u'المعنعن': u'الْمُعَنْعَنِ', #6
u'المعنعنات': u'الْمُعَنْعَنَاتُ', #1
u'المعنعنة': u'الْمُعَنْعَنَةَ', #1
u'المعنعنة': u'الْمُعَنْعَنَةُ', #1
u'المعنق': u'الْمُعَنَّقُ', #1
u'المعنق': u'الْمُعْنِقَ', #2
u'المعنق': u'الْمُعْنِقُ', #2
u'المعنىأن': u'الْمَعْنَىأَنَّ', #2
u'المعهودون': u'الْمَعْهُودُونَ', #1
u'المعهودية': u'الْمَعْهُودِيَّةِ', #1
u'المعوده': u'الْمُعَوَّدَهْ', #1
u'المعولى': u'الْمَعْوَلِىُّ', #2
u'ألمعيا': u'أَلْمَعِيًّا', #1
u'المعيا': u'الْمُعْيَا', #1
u'المعيديون': u'الْمُعَيْدِيُّونَ', #1
u'المعيصي': u'الْمَعِيصِيّ', #1
u'المعيطي': u'الْمُعَيّطِي', #1
u'المعيطى': u'الْمُعَيْطِىُّ', #1
u'المعيطي،': u'الْمُعَيْطِيُّ،', #2
u'المعيطي': u'الْمُعَيْطِيّ', #6
u'المعيطي': u'الْمُعَيْطِيُّ', #6
u'المعيقيب': u'الْمُعَيْقِيبُ', #1
u'المعيقيب': u'الْمُعَيْقِيبِ', #1
u'المعيم': u'الْمُعِيمَ', #1
u'المعيم': u'الْمُعِيمُ', #2
u'المعيمة': u'الْمُعِيمَةُ', #2
u'المعينه': u'الْمُعَيَّنَهْ', #1
u'المعيوب': u'الْمَعْيُوبَ', #1
u'المعيوب': u'الْمَعْيُوبُ', #1
u'المعيوب': u'الْمَعْيُوبِ', #2
u'المغابرة': u'الْمُغَابَرَةِ', #1
u'المغابن': u'الْمَغَابِنِ', #7
u'المغابنات': u'الْمُغَابَنَاتِ', #1
u'المغابنة': u'الْمُغَابَنَةِ', #20
u'المغابنة': u'الْمُغَابَنَةَ', #3
u'المغابنة': u'الْمُغَابَنَةُ', #6
u'المغارسة': u'الْمُغَارَسَةَ', #14
u'المغارسة': u'الْمُغَارَسَةِ', #42
u'المغارسة': u'الْمُغَارَسَةُ', #43
u'المغازاة': u'الْمُغَازَاةِ', #1
u'المغازلي': u'الْمَغَازِلِيُّ', #5
u'المغازى': u'الْمَغَازِىَ', #1
u'المغازى': u'الْمَغَازِى', #33
u'المغازين': u'الْمُغَازِينَ', #1
u'المغاصبة': u'الْمُغَاصَبَةُ', #1
u'المغافر،': u'الْمَغَافِرَ،', #2
u'المغافر': u'الْمَغَافِرِ', #3
u'المغافقي': u'الْمَغَافِقِيُّ', #1
u'المغافير': u'الْمَغَافِيرُ', #2
u'المغافير': u'المغافير', #3
u'المغالية': u'الْمَغَالِيَّةِ', #1
u'المغالية': u'الْمُغَالِيَةَ', #1
u'المغالية': u'الْمَغَالِيَّة', #3
u'المغالية': u'الْمُغَالِيَةِ', #9
u'المغاليط': u'الْمَغَالِيطَ', #2
u'المغائر': u'الْمَغَائِرِ', #1
u'المغائض': u'الْمَغَائِضِ', #1
u'المغائظ': u'الْمَغَائِظِ', #1
u'المغاياة': u'الْمُغَايَاةِ', #1
u'المغايبة': u'الْمُغَايِبَةِ', #1
u'المغايبة': u'الْمُغَايَبَةِ', #3
u'المغايظ': u'الْمُغَايِظِ', #1
u'المغايظة': u'الْمُغَايَظَةُ', #5
u'المغايظة': u'الْمُغَايَظَةَ', #7
u'المغايظة': u'الْمُغَايَظَةِ', #9
u'المغتدي': u'الْمُغْتَدِي', #2
u'المغتذي': u'الْمُغْتَذِي', #1
u'المغتذي': u'الْمُغْتَذِيَ', #2
u'المغتل': u'الْمُغْتَلِّ', #3
u'المغتلم': u'الْمُغْتَلَمُ', #1
u'المغتلم': u'الْمُغْتَلَمِ', #3
u'المغتلم': u'الْمُغْتَلِمِ', #3
u'المغتلم': u'الْمُغْتَلِمُ', #4
u'المغث': u'الْمَغْثُ', #1
u'المغدق': u'الْمُغْدِقُ', #2
u'المغر': u'الْمُغِرُّ', #1
u'المغر': u'الْمُغِرِّ', #1
u'المغر': u'الْمُغْرُ', #1
u'المغر': u'الْمُغَرُّ', #3
u'المغراء،': u'الْمَغْرَاءِ،', #7
u'المغراء': u'الْمَغْرَاءِ', #9
u'المغراني': u'الْمَغْرَانِيُّ', #1
u'المغراوي': u'الْمَغْرَاوِيُّ', #1
u'المغربالوجه': u'الْمَغْرِبُالْوَجْهُ', #1
u'المغربعلى': u'الْمَغْرِبِعَلَى', #1
u'المغرة': u'الْمَغَرَةُ', #1
u'المغرة': u'الْمَغْرَة', #1
u'المغرة': u'الْمَغْرَةُ', #13
u'المغرة': u'الْمَغْرَةَ', #3
u'المغرة': u'الْمَغْرَةِ', #4
u'المغرزة': u'الْمُغْرَزَةُ', #1
u'المغرسة': u'الْمُغْرَسَةِ', #1
u'المغرورية': u'الْمَغْرُورِيَّةِ', #1
u'المغروز': u'الْمَغْرُوزُ', #4
u'المغروز': u'الْمَغْرُوزِ', #4
u'المغروزة': u'الْمَغْرُوزَة', #1
u'المغروزة': u'الْمَغْرُوزَةُ', #3
u'المغروزة': u'الْمَغْرُوزَةَ', #4
u'المغروزة': u'الْمَغْرُوزَةِ', #5
u'المغروم': u'الْمَغْرُوم', #1
u'المغروم': u'الْمَغْرُومُ', #11
u'المغروم': u'الْمَغْرُومَ', #13
u'المغروم': u'الْمَغْرُومِ', #13
u'المغرومة': u'الْمَغْرُومَةُ', #3
u'المغرومة': u'الْمَغْرُومَةِ', #7
u'المغزلوالوجه': u'الْمِغْزَلَوَالْوَجْهُ', #1
u'المغزول': u'الْمَغْزُولِ', #13
u'المغزول': u'الْمَغْزُولَ', #2
u'المغزول': u'الْمَغْزُولُ', #5
u'المغزولة': u'الْمَغْزُولَةُ', #1
u'المغش': u'الْمُغَشِّ', #1
u'المغصوبية': u'الْمَغْصُوبِيَّةَ', #1
u'المغصوبية': u'الْمَغْصُوبِيَّةُ', #2
u'المغصوبية': u'الْمَغْصُوبِيَّةِ', #2
u'المغصوص': u'الْمَغْصُوصِ', #1
u'المغفر': u'المِغْفَر', #1
u'المغفر،': u'الْمِغْفَرَ،', #1
u'المغفر،': u'الْمِغْفَرِ،', #1
u'المغفر': u'المغفر', #2
u'المغفر': u'الْمِغْفَرِ', #25
u'المغفر،': u'الْمِغْفَرُ،', #4
u'المغفر': u'الْمِغْفَرُ', #40
u'المغفر': u'الْمِغْفَر', #6
u'المغفر': u'الْمِغْفَرَ', #9
u'المغفره،': u'المِغْفره،', #1
u'المغفلا': u'الْمُغَفَّلَا', #3
u'المغفول': u'الْمَغْفُولُ', #1
u'المغفول': u'الْمَغْفُولِ', #5
u'المغلبه': u'الْمَغْلَبَهْ', #1
u'المغلس': u'المغلس', #1
u'المغلس': u'الْمُغَلِّسُ', #1
u'المغلس': u'الْمُغَلِّسِ', #11
u'المغلس': u'الْمُغَلِّس', #2
u'المغلس،': u'الْمُغَلِّسِ،', #2
u'المغلصمة': u'الْمُغَلْصَمَةَ', #1
u'المغلصمة': u'الْمُغَلْصَمَةُ', #1
u'المغلصمة': u'الْمُغَلْصَمَةِ', #1
u'المغلصمة': u'الْمُغَلْصِمَةُ', #1
u'المغلوبية': u'الْمَغْلُوبِيَّة', #1
u'المغلوبية': u'الْمَغْلُوبِيَّةِ', #1
u'المغلوبية': u'الْمَغْلُوبِيَّةُ', #2
u'المغلوث': u'الْمَغْلُوثَ', #1
u'المغلوث': u'الْمَغْلُوثِ', #1
u'المغلى': u'الْمُغَلَّى', #1
u'المغلى': u'الْمُغْلَى', #1
u'المغمس': u'الْمُغَمّسُ', #1
u'المغمس': u'الْمُغَمَّسَ', #1
u'المغمس،': u'الْمِغْمَسَ،', #1
u'المغمس': u'الْمُغَمَّسِ', #10
u'المغمس': u'الْمُغَمّسِ', #2
u'المغمس': u'الْمُغَمَّسُ', #3
u'المغمس': u'الْمُغَمّسَ', #5
u'المغموس': u'الْمَغْمُوسَ', #1
u'المغموس': u'الْمَغْمُوسِ', #2
u'المغموسة': u'الْمَغْمُوسَةِ', #2
u'المغموص': u'المغموص', #1
u'المغمى': u'الْمُغْمًى', #2
u'المغنوم': u'الْمَغْنُومُ', #4
u'المغنوم': u'الْمَغْنُومَ', #5
u'المغنوم': u'الْمَغْنُومِ', #7
u'المغنومة': u'الْمَغْنُومَةُ', #1
u'المغنومة': u'الْمَغْنُومَةِ', #24
u'المغنونا': u'الْمُغَنُّونَا', #2
u'المغواة': u'الْمَغْوَاةِ', #1
u'المغوي': u'الْمُغْوِي', #2
u'المغيا': u'الْمُغَيَّا', #110
u'المغيا': u'الْمُغْيَا', #2
u'المغياة': u'الْمُغَيَّاةَ', #1
u'المغيبا': u'الْمَغِيبَا', #1
u'المغيرةبن': u'الْمُغِيرَةَبْنَ', #1
u'المغيره': u'المغيره', #2
u'المغيره': u'الْمُغِيرَهْ', #3
u'المغيزل': u'الْمُغَيْزِلِ', #1
u'المغيلة': u'الْمُغِيلَةُ', #1
u'المغيلي': u'الْمَغِيلِيُّ', #1
u'المغيلي': u'الْمَغِيلِيِّ', #1
u'المفاخذة': u'الْمُفَاخَذَةُ', #1
u'المفاخذة': u'الْمُفَاخَذَةِ', #1
u'المفاخذة': u'الْمُفَاخَذَةَ', #2
u'المفادان': u'الْمُفَادَانِ', #4
u'المفادة': u'الْمُفَادَةَ', #1
u'المفادة': u'الْمُفَادَةِ', #10
u'المفادة': u'الْمُفَادَةُ', #7
u'المفادين': u'الْمَفَادَيْنِ', #1
u'المفادين': u'الْمُفَادَيْنِ', #2
u'المفاضة': u'الْمُفَاضَةَ', #1
u'المفاضة': u'الْمُفَاضَةُ', #2
u'المفاضة': u'الْمُفَاضَةِ', #2
u'المفاعلة': u'الْمُفَاعِلَةِ', #2
u'المفاعلة': u'الْمُفَاعَلَةَ', #24
u'المفاعلة': u'الْمُفَاعَلَةُ', #25
u'المفاعلة': u'الْمُفَاعَلَة', #3
u'المفاعلة': u'الْمُفَاعَلَةِ', #96
u'المفاقيد': u'الْمَفَاقِيدِ', #4
u'المفاليس': u'الْمَفَالِيسِ', #38
u'المفاهمون': u'الْمُفَاهِمُونَ', #1
u'المفتات': u'الْمُفْتَاتَ', #1
u'المفتات': u'الْمُفْتَاتِ', #14
u'المفتات': u'الْمُفْتَاتُ', #5
u'المفترص': u'الْمُفْتَرِصِ', #1
u'المفتصد': u'الْمُفْتَصِدِ', #11
u'المفتصد': u'الْمُفْتَصَدِ', #3
u'المفتصد': u'الْمُفْتَصِدُ', #5
u'المفتض': u'الْمُفْتَضِّ', #1
u'المفتوت': u'الْمَفْتُوتُ', #1
u'المفتيون': u'الْمُفْتِيُونَ', #2
u'المفجور': u'الْمَفْجُورُ', #1
u'المفجوئين': u'الْمَفْجُوئِينَ', #1
u'المفحول': u'الْمَفْحُولِ', #1
u'المفدرة': u'الْمَفْدَرَةُ', #1
u'المفدم،': u'المفدم،', #1
u'المفدم': u'الْمُفَدَّمُ', #1
u'المفدم': u'الْمُفَدَّم', #3
u'المفدم': u'الْمُفَدَّمَ', #3
u'المفدم': u'الْمُفَدَّمِ', #3
u'المفدم': u'الْمُفْدَمَ', #3
u'المفدم': u'الْمُفْدَمُ', #3
u'المفدم،': u'الْمُفَدَّمِ،', #3
u'المفدم': u'الْمُفْدَمِ', #6
u'المفدمة،': u'الْمُفَدَّمَةِ،', #1
u'المفدمة': u'الْمُفَدَّمَة', #2
u'المفدى': u'الْمُفَدَّى', #1
u'المفدى': u'الْمُفْدَى', #19
u'المفرص': u'الْمِفْرَصَ', #1
u'المفروح': u'الْمَفْرُوحُ', #1
u'المفروح': u'الْمَفْرُوحِ', #2
u'المفروز': u'الْمَفْرُوزِ', #2
u'المفروزة': u'الْمَفْرُوزَةِ', #2
u'المفروزة': u'الْمَفْرُوزَةَ', #3
u'المفروضةوالوجه': u'الْمَفْرُوضَةَوَالْوَجْهُ', #1
u'المفروع': u'الْمَفْرُوعِ', #1
u'المفسره': u'الْمُفَسَّرَهْ', #2
u'المفسوح': u'الْمَفْسُوحَ', #1
u'المفسوح': u'الْمَفْسُوحُ', #1
u'المفسوح': u'الْمَفْسُوحِ', #2
u'المفسودة': u'الْمَفْسُودَةِ', #4
u'المفصد': u'الْمَفْصِدَ', #1
u'المفصد': u'الْمُفْصِدَ', #1
u'المفصود': u'الْمَفْصُود', #1
u'المفصود': u'الْمَفْصُودَ', #1
u'المفصود': u'الْمَفْصُودِ', #7
u'المفصودة': u'الْمَفْصُودَةُ', #1
u'المفصودة': u'الْمَفْصُودَةَ', #2
u'المفصودة': u'الْمَفْصُودَةِ', #2
u'المفضاة': u'الْمُفْضَاةِ', #13
u'المفضاة': u'الْمُفْضَاةَ', #3
u'المفضاة': u'الْمُفْضَاةُ', #4
u'المفضوخ': u'الْمَفْضُوخِ', #3
u'المفضولية': u'الْمَفْضُولِيَّةُ', #1
u'المفضولية': u'الْمَفْضُولِيَّةِ', #3
u'المفضى': u'المفضى', #1
u'المفطور': u'الْمَفْطُورِ', #2
u'المفظع': u'المُفْظِعُ', #1
u'المفظع': u'الْمُفْظِعُ', #2
u'المفقع،': u'الْمُفَقَّعُ،', #1
u'المفقوء': u'الْمَفْقُوءِ', #13
u'المفقوء': u'الْمَفْقُوءَ', #4
u'المفقوء': u'الْمَفْقُوءُ', #5
u'المفقوءة': u'الْمَفْقُوءَةُ', #10
u'المفقوءة': u'الْمَفْقُوءَةِ', #34
u'المفقوءة': u'الْمَفْقُوءَةَ', #4
u'المفقور': u'الْمَفْقُورِ', #3
u'المفلت': u'الْمُفْلِتِ', #1
u'المفنى': u'الْمُفْنَى', #8
u'المفهومون': u'الْمَفْهُومُونَ', #1
u'المفوز': u'الْمُفَوَّزِ', #1
u'المفئود': u'الْمَفْئُودَ', #1
u'المفئود': u'الْمَفْئُودُ', #1
u'المفيت': u'الْمُفِيتُ', #16
u'المفيت': u'الْمُفِيتِ', #17
u'المفيت': u'الْمُفِيتَ', #7
u'المفيتة': u'الْمُفِيتَةِ', #2
u'المفيتين': u'الْمُفِيتِينَ', #1
u'المفيتين': u'الْمُفِيتَيْنِ', #1
u'المقا': u'الْمَقَا', #1
u'المقا': u'اُلْمُقَا', #1
u'المقابحة': u'الْمُقَابَحَةَ', #1
u'المقابحة': u'الْمُقَابَحَةِ', #3
u'المقابري': u'الْمَقَابِرِيُّ', #1
u'المقابرى': u'الْمَقَابِرِىُّ', #2
u'المقابرى': u'الْمُقَابِرِىُّ', #2
u'المقابري،': u'الْمَقَابِرِيُّ،', #7
u'المقابيس': u'الْمَقَابِيسِ', #1
u'المقات': u'الْمِقَاتُ', #1
u'المقاتله': u'الْمُقَاتَلَهْ', #1
u'المقاتلية': u'الْمُقَاتِلِيَّةُ', #1
u'المقاثي': u'الْمَقَاثِيُّ', #1
u'المقاثي': u'الْمَقَاثِيَّ', #2
u'المقاثي': u'الْمَقَاثِي', #45
u'المقاثي': u'الْمَقَاثِيَ', #7
u'المقاثئ': u'المقاثئ', #1
u'المقاثئ': u'الْمَقَاثِئ', #1
u'المقاثئ': u'الْمَقَاثِئِ', #10
u'المقاثئ': u'الْمَقَاثِئُ', #2
u'المقاثئ': u'الْمَقَاثِئَ', #3
u'المقاد': u'الْمُقَادُ', #1
u'المقادة': u'الْمُقَادَةَ', #1
u'المقادة': u'الْمُقَادَةِ', #1
u'المقادة': u'الْمَقَادَةَ', #3
u'المقادر': u'الْمُقَادِرِ', #1
u'المقادر': u'الْمَقَادِرِ', #3
u'المقادر': u'الْمَقَادِرُ', #4
u'المقادسة': u'الْمَقَادِسَةُ', #2
u'المقارض': u'الْمُقَارَضَ', #13
u'المقارض': u'الْمُقَارَضُ', #24
u'المقارض': u'الْمُقَارِضُ', #26
u'المقارض': u'الْمُقَارِضِ', #31
u'المقارض': u'الْمُقَارِضَ', #5
u'المقارض': u'الْمُقَارَضِ', #52
u'المقارضين': u'الْمُقَارِضَيْنِ', #3
u'المقارف': u'الْمَقَارِفِ', #2
u'المقارف': u'الْمُقَارِفِ', #2
u'المقاسة': u'الْمَقَّاسَةِ', #1
u'المقاصب': u'الْمَقَاصِبُ', #1
u'المقاصرة': u'الْمُقَاصَرَةِ', #1
u'المقاصري': u'الْمُقَاصِرِيُّ', #1
u'المقاصص': u'الْمُقَاصَصِ', #1
u'المقاصصة': u'الْمُقَاصَصَةَ', #1
u'المقاصصة': u'الْمُقَاصَصَةِ', #1
u'المقاصصة': u'الْمُقَاصَصَةُ', #8
u'المقاصيص': u'الْمَقَاصِيصَ', #1
u'المقاصيص': u'الْمَقَاصِيصُ', #1
u'المقاصيص': u'الْمَقَاصِيصِ', #6
u'المقاعدة': u'الْمُقَاعَدَةِ', #2
u'المقاله': u'الْمَقَالَه', #1
u'المقاله': u'الْمَقَالَهْ', #4
u'المقاما': u'الْمُقَامَا', #1
u'المقانص': u'الْمَقَانِصِ', #2
u'المقاومه': u'الْمُقَاوَمَهْ', #1
u'المقائي': u'الْمَقَائِيُّ', #1
u'المقايس': u'الْمُقَايِسُ', #1
u'المقايل': u'الْمُقَايِلُ', #1
u'المقايلة': u'الْمُقَايَلَةَ', #2
u'المقايلة': u'الْمُقَايَلَةُ', #3
u'المقايلة': u'الْمُقَايَلَةِ', #6
u'المقبره': u'الْمَقْبَرَهْ', #2
u'المقبرى': u'الْمَقْبُرِىَّ', #10
u'المقبرى': u'الْمَقْبُرِىِّ', #140
u'المقبرى': u'الْمَقْبُرِىُّ', #29
u'المقبوحة': u'الْمَقْبُوحَةُ', #1
u'المقبوحة': u'الْمَقْبُوحَةَ', #2
u'المقبوحين': u'الْمَقْبُوحِينَ', #2
u'المقبورا': u'الْمَقْبُورَا', #2
u'المقبوص': u'الْمَقْبُوصُ', #1
u'المقبوص': u'الْمَقْبُوصِ', #1
u'المقبولي': u'الْمَقْبُولِي', #2
u'المقبولية': u'الْمَقْبُولِيَّةَ', #1
u'المقتاة': u'الْمَقْتَاةُ', #1
u'المقتاض': u'الْمُقْتَاضِ', #1
u'المقتب': u'الْمُقَتَّبُ', #2
u'المقتب': u'الْمُقَتَّبِ', #4
u'المقتت': u'الْمُقَتَّت', #1
u'المقتت': u'الْمُقَتَّتِ', #2
u'المقتص': u'الْمُقْتَصُّ', #116
u'المقتص': u'الْمُقْتَصِّ', #141
u'المقتص': u'الْمُقْتَصَّ', #18
u'المقتصين': u'الْمُقْتَصِّينَ', #2
u'المقتضيها': u'الْمُقْتَضِيهَا', #1
u'المقتفى': u'الْمُقْتَفَى', #3
u'المقتناة': u'الْمُقْتَنَاةِ', #3
u'المقتنى': u'الْمُقْتَنَى', #16
u'المقتوبة': u'الْمَقْتُوبَةُ', #1
u'المقثاة': u'الْمَقْثَاةَ', #1
u'المقثأة': u'الْمَقْثَأَةِ', #27
u'المقثأة': u'الْمَقْثَأَةَ', #4
u'المقثأة': u'الْمَقْثَأَةُ', #6
u'المقحط': u'المقحط', #1
u'المقحط': u'الْمُقْحَطُ', #1
u'المقحط': u'الْمِقْحَطُ', #1
u'المقحط': u'الْمُقْحِطُ', #2
u'المقداد،': u'المِقداد،', #1
u'المقداد،': u'الْمِقدَادُ،', #1
u'المقداد،': u'الْمِقْدَادُ،', #1
u'المقداد': u'المقداد', #10
u'المقداد': u'الْمِقْدَادُ', #122
u'المقداد': u'الْمِقْدَادِ', #127
u'المقداد': u'المِقْداد', #2
u'المقداد،': u'المِقْداد،', #2
u'المقداد': u'الْمِقْدَاد', #2
u'المقداد،': u'الْمِقْدَادِ،', #2
u'المقداد': u'الْمِقْدَادَ', #63
u'المقدره': u'الْمَقْدِرَهْ', #1
u'المقدرها': u'الْمُقَدِّرُهَا', #1
u'المقدسى': u'الْمَقْدِسِىُّ', #2
u'المقدمى': u'الْمُقَدَّمِىِّ', #18
u'المقدمى': u'الْمُقَدَّمِىُّ', #53
u'المقدوح': u'الْمَقْدُوحِ', #2
u'المقدورية': u'الْمَقْدُورِيَّةُ', #2
u'المقدورية': u'الْمَقْدُورِيَّةِ', #2
u'المقدوم': u'الْمَقْدُومِ', #8
u'المقذرات': u'الْمُقَذَّرَاتِ', #1
u'المقرأة': u'الْمَقْرَأَةُ', #1
u'المقراة': u'الْمَقْرَاةِ', #2
u'المقراة': u'الْمِقْرَاةِ', #2
u'المقراة،': u'الْمَقْرَاةِ،', #2
u'المقراي': u'الْمَقراي', #1
u'المقرائي': u'الْمَقْرَائِيُّ', #1
u'المقرائي': u'الْمُقْرَائِيِّ', #1
u'المقرائي،': u'الْمَقْرَائِيِّ،', #1
u'المقردح': u'الْمُقَرْدِحَ', #3
u'المقرره': u'الْمُقَرَّرَهْ', #1
u'المقرش': u'الْمُقَرّشُ', #1
u'المقرش': u'الْمُقَرِّشُ', #1
u'المقرفينا': u'الْمُقْرِفِينَا', #2
u'المقرقة': u'الْمُقَرِّقَةِ', #1
u'المقرم': u'الْمِقْرَمِ', #1
u'المقروضة': u'الْمَقْرُوضَةِ', #2
u'المقروظ': u'المقروظ', #1
u'المقروع': u'الْمَقْرُوعَ', #1
u'المقروع': u'الْمَقْرُوعُ', #1
u'المقروع': u'الْمَقْرُوعِ', #3
u'المقروعين': u'الْمَقْرُوعِينَ', #1
u'المقرى': u'الْمُقْرِىُّ', #1
u'المقرى،': u'الْمُقْرِى،', #1
u'المقرى': u'الْمَقْرَى', #2
u'المقريء': u'المقريء', #1
u'المقريء،': u'الْمُقْرِيءُ،', #1
u'المقرىء': u'المقرىء', #4
u'المقرئح': u'الْمُقْرِئُح', #1
u'المقريزي': u'الْمَقْرِيزِي', #1
u'المقريزي': u'الْمَقْرِيزِيِّ', #2
u'المقريزي': u'الْمَقْرِيزِيُّ', #4
u'المقشقشة': u'الْمُقَشْقِشَةَ', #1
u'المقشقشة': u'الْمُقَشْقِشَةُ', #2
u'المقشور': u'الْمَقْشُورُ', #1
u'المقشور': u'الْمَقْشُورِ', #7
u'المقصة': u'الْمَقَصَّةُ', #1
u'المقصص': u'الْمُقَصِّصِ', #1
u'المقصصات': u'الْمُقَصَّصَاتُ', #1
u'المقصصة': u'الْمُقَصَّصَةِ', #1
u'المقصودية': u'الْمَقْصُودِيَّةَ', #1
u'المقصودية': u'الْمَقْصُودِيَّةِ', #1
u'المقصوم': u'الْمَقْصُومُ', #1
u'المقضاب': u'الْمِقْضَابُ', #1
u'المقضاب': u'الْمِقْضَابِ', #3
u'المقضاة': u'الْمُقْضَاة', #1
u'المقضوب': u'الْمَقْضُوبُ', #2
u'المقضى': u'الْمَقْضِىِّ', #2
u'المقضى': u'الْمُقَضَّى', #3
u'المقضى': u'الْمُقْضَى', #45
u'المقضى': u'الْمَقْضِىُّ', #5
u'المقطة': u'الْمِقَطَّةِ', #1
u'المقطم': u'الْمُقَطَّمَ', #1
u'المقطم': u'الْمُقَطَّمُ', #1
u'المقطم': u'الْمُقَطَّمِ', #1
u'المقطوعون': u'الْمَقْطُوعُونَ', #2
u'المقطوعي': u'الْمَقْطُوعَيْ', #1
u'المقعطة': u'الْمُقْعَطَةُ', #1
u'المقعود': u'الْمَقْعُودَ', #1
u'المقعود': u'الْمَقْعُودِ', #1
u'المقعى': u'المقعى', #1
u'المقعي': u'الْمُقْعِي', #2
u'المقلبه': u'الْمَقْلَبَهْ', #1
u'المقلس': u'الْمُقَلِّس', #1
u'المقلش': u'المقلش', #1
u'المقلش': u'الْمُقَلِّشَ', #1
u'المقلش': u'الْمُقْلِشُ', #1
u'المقلش': u'الْمُقْلِشِ', #1
u'المقلش': u'الْمُقَلِّشُ', #4
u'المقلقلة': u'الْمُقَلْقَلَةِ', #2
u'المقلقلة': u'الْمُقَلْقَلَةُ', #3
u'المقلوة': u'الْمَقْلُوَّةَ', #1
u'المقلوة': u'الْمَقْلُوَّةِ', #12
u'المقلوة': u'الْمَقْلُوَّةُ', #2
u'المقلوم': u'الْمَقْلُومُ', #1
u'المقلوم': u'الْمَقْلُومِ', #2
u'المقمع': u'الْمِقْمَعُ', #1
u'المقنفين': u'الْمُقْنِفِينَ', #1
u'المقهقه': u'الْمُقَهْقِهُ', #1
u'المقهقه': u'الْمُقَهْقِهِ', #1
u'المقهورية': u'الْمَقْهُورِيَّةِ', #1
u'المقهورية': u'الْمَقْهُورِيَّةَ', #2
u'المقوقس': u'المقوقس', #1
u'المقوقس،': u'المقوقس،', #1
u'المقوقس': u'المُقَوْقس', #1
u'المقوقس': u'المُقَوْقِس', #1
u'المقوقس،': u'الْمُقَوْقِسِ،', #1
u'المقوقس': u'الْمُقَوْقِسِ', #21
u'المقوقس': u'الْمُقَوْقِسُ', #24
u'المقوقس،': u'الْمُقَوْقِسُ،', #3
u'المقوقس': u'الْمُقَوْقِسَ', #4
u'المقوقس': u'الْمُقَوْقَسِ', #7
u'المقوقس': u'الْمُقَوْقَسُ', #9
u'المقولا': u'الْمَقُولَا', #1
u'المقير': u'الْمُقِيرِ', #1
u'المقير،': u'الْمُقَيَّرُ،', #1
u'المقير': u'الْمُقَيَّرُ', #13
u'المقير': u'الْمُقِيرُ', #2
u'المقير': u'المقير', #3
u'المقير': u'الْمُقَيَّرَ', #3
u'المقير': u'الْمُقَيِّرِ', #3
u'المقير،': u'الْمُقَيَّرِ،', #3
u'المقير': u'الْمُقَيَّرِ', #8
u'المقيرة': u'الْمُقَيَّرَةُ', #1
u'المقيس': u'الْمَقِيس', #1
u'المقيس': u'الْمَقِيسِ', #317
u'المقيس': u'الْمَقِيسَ', #34
u'المقيس': u'الْمَقِيسُ', #56
u'المقيسة': u'الْمَقِيسَةَ', #1
u'المقيسة': u'الْمَقِيسَةِ', #12
u'المقيسة': u'الْمَقِيسَةُ', #4
u'المقيسي': u'الْمَقِيسِيِّ', #1
u'المكابلة': u'الْمُكَابَلَةُ', #1
u'المكاتبه': u'الْمُكَاتَبَهْ', #3
u'المكاتل': u'المكاتل', #1
u'المكاتل': u'الْمَكَاتِلَ', #1
u'المكاتل': u'الْمَكَاتِلُ', #2
u'المكاتل': u'الْمَكَاتِلِ', #2
u'المكارى': u'الْمُكَارَى', #6
u'المكاس': u'الْمُكَّاسَ', #1
u'المكاس': u'الْمُكَّاسُ', #10
u'المكاس': u'الْمَكَّاسُ', #13
u'المكاس': u'الْمُكَاسُ', #3
u'المكاس': u'الْمِكَاسِ', #4
u'المكاس': u'الْمُكَّاسِ', #5
u'المكاس': u'الْمَكَّاسِ', #6
u'المكاس': u'الْمَكَّاسَ', #7
u'المكاسبة': u'الْمُكَاسَبَةِ', #2
u'المكاسة': u'الْمِكَاسَة', #1
u'المكاسة': u'الْمِكَاسَةِ', #1
u'المكاسة': u'الْمَكَّاسَةِ', #2
u'المكاسون': u'الْمَكَّاسُونَ', #3
u'المكاسين': u'الْمَكَّاسِينَ', #13
u'المكاشح': u'الْمُكَاشِحْ', #2
u'المكاشفون': u'الْمُكَاشَفُونَ', #1
u'المكاشفين': u'الْمُكَاشَفِينَ', #2
u'المكاشفين': u'الْمُكَاشِفِينَ', #3
u'المكاعب': u'الْمَكَاعِبَ', #3
u'المكاعب': u'الْمَكَاعِبِ', #5
u'المكاعمة': u'الْمُكَاعَمَةِ', #9
u'المكاعي': u'الْمَكَّاعِيُّ', #1
u'المكاعي': u'الْمَكَّاعِيِّ', #2
u'المكاعيين': u'الْمَكَّاعِيِّينَ', #1
u'المكافي': u'الْمَكَافِي', #1
u'المكافئه': u'الْمُكَافِئَهْ', #1
u'المكال': u'الْمُكَالُ', #1
u'المكامعة': u'الْمُكَامَعَة', #1
u'المكامعة': u'الْمُكَامَعَةِ', #18
u'المكامعة': u'الْمُكَامَعَةُ', #3
u'المكامعة': u'الْمُكَامَعَةَ', #6
u'المكاويا': u'الْمَكَاوِيَا', #1
u'المكايرين': u'الْمُكَايِرِينَ', #1
u'المكايسة': u'الْمُكَايَسَة', #1
u'المكايسة': u'الْمُكَايَسَةُ', #11
u'المكايسة': u'الْمُكَايَسَةَ', #2
u'المكايسة': u'الْمُكَايَسَةِ', #61
u'المكايل': u'الْمُكَايِلِ', #2
u'المكبوب': u'الْمَكْبُوبُ', #3
u'المكبوبة': u'الْمَكْبُوبَةِ', #1
u'المكتراة': u'الْمُكْتَرَاة', #1
u'المكتراة': u'الْمُكْتَرَاةُ', #15
u'المكتراة': u'الْمُكْتَرَاةَ', #17
u'المكتراة': u'الْمُكْتَرَاةِ', #68
u'المكترى': u'الْمُكْتَرِى', #2
u'المكترى': u'الْمُكْتَرَى', #39
u'المكتفى': u'الْمُكْتَفَى', #9
u'المكتمن': u'الْمُكْتَمِنِ', #1
u'المكتين': u'الْمَكَّتَيْنِ', #1
u'المكتين': u'الْمُكَتّيْنِ', #1
u'المكتين': u'الْمَكّتَيْنِ', #8
u'المكثور': u'المكثور', #2
u'المكحولي': u'الْمَكْحُولِيُّ', #1
u'المكحولي،': u'الْمَكْحُولِيُّ،', #1
u'المكد': u'الْمُكْدَ', #1
u'المكدم،': u'المكدم،', #1
u'المكدم': u'الْمُكَدَّمِ', #2
u'المكدوس': u'المكدوس', #1
u'المكدوش': u'الْمَكْدُوشُ', #1
u'المكدي': u'الْمُكَدِّي', #1
u'المكدي': u'الْمُكْدِي', #3
u'المكدين': u'الْمُكِدِّينَ', #1
u'المكراة': u'الْمُكْرَاةِ', #4
u'المكربلون': u'الْمُكَرْبِلُونَ', #1
u'المكروهية': u'الْمَكْرُوهِيَّةِ', #1
u'المكرى': u'الْمُكْرَى', #20
u'المكسة': u'الْمَكَسَةُ', #1
u'المكسة': u'الْمَكَسَةِ', #1
u'المكسة': u'الْمَكْسَةِ', #1
u'المكسة': u'الْمَكَسَةَ', #3
u'المكسود': u'المكسود', #1
u'المكسود': u'الْمَكْسُودِ', #1
u'المكسود': u'الْمَكْسُودُ', #4
u'المكشوح': u'المكشوح', #1
u'المكعبر': u'الْمُكَعْبَرُ', #1
u'المكفف': u'الْمُكَفَّفِ', #1
u'المكفف': u'الْمُكَفَّفَ', #3
u'المكفف': u'الْمُكَفِّفِ', #4
u'المكفو': u'الْمَكْفُو', #1
u'المكفوء': u'الْمَكْفُوءِ', #2
u'المكفى': u'الْمُكْفَى', #2
u'المكلا': u'الْمُكِلَّا', #1
u'المكلب': u'الْمُكَلَّبِ', #1
u'المكلب،': u'الْمُكَلَّبُ،', #1
u'المكلب،': u'الْمُكَلَّبِ،', #1
u'المكلب': u'المكلب', #2
u'المكلب': u'الْمُكَلَّبُ', #2
u'المكلب': u'الْمُكَلَّبَ', #6
u'المكلبين': u'الْمُكَلِّبَيْنِ', #1
u'المكلبين': u'الْمُكَلِّبِينَ', #2
u'المكلثم،': u'الْمُكَلْثَمِ،', #1
u'المكلثم': u'الْمُكَلْثَمُ', #2
u'المكلثم': u'الْمُكَلْثَمِ', #2
u'المكلوء': u'الْمَكْلُوءُ', #2
u'المكلوء': u'الْمَكْلُوءِ', #2
u'المكلوم': u'الْمَكْلُوم', #1
u'المكلوم': u'الْمَكْلُومِ', #1
u'المكلية': u'الْمَكْلِيَّةِ', #1
u'المكمله': u'الْمُكَمِّلَهْ', #1
u'المكمور': u'الْمَكْمُورِ', #6
u'المكنوز': u'الْمَكْنُوزَ', #1
u'المكنوز': u'الْمَكْنُوزُ', #4
u'المكنوز': u'الْمَكْنُوزِ', #4
u'المكودي': u'الْمَكُودِيُّ', #1
u'المكودي': u'الْمَكُّودِيِّ', #1
u'المكى': u'الْمَكِّىُّ', #145
u'المكى': u'الْمَكِّى', #2
u'المكى': u'الْمَكِّىِّ', #48
u'المكى': u'الْمَكِّىَّ', #8
u'المكيدات': u'الْمَكِيدَاتِ', #1
u'المكيدر': u'الْمُكَيْدِرِ', #1
u'المكيس': u'الْمَكِيسِ', #1
u'المكيمن': u'الْمُكَيْمِنِ', #1
u'المكيون': u'الْمَكِّيُّونَ', #5
u'الملا': u'المَلاَ', #1
u'الملا': u'الْمَلاَ', #1
u'الملا،': u'الْمَلا،', #1
u'الملا': u'الْمَلا', #10
u'الملا': u'الْمَلَا', #26
u'الملا': u'الْمَلَّا', #3
u'الملا': u'الْمُلَّا', #7
u'الملاءSوذكر': u'الْمَلَاءِSوَذَكَرَ', #1
u'الملآء': u'الْمُلَآءِ', #1
u'الملأة': u'الْمَلْأَةِ', #1
u'الملاحان': u'الْمَلَّاحَانِ', #13
u'الملاحن': u'الْمَلَاحِنِ', #1
u'الملاحون': u'الْمَلَّاحُونَ', #3
u'الملازق': u'الْمُلَازِقِ', #5
u'الملازق': u'الْمُلَازِقُ', #6
u'الملازقون': u'الْمُلَازِقُونَ', #2
u'الملاغات': u'الْمُلَاغَاتُ', #1
u'الملاقى': u'الْمُلَاقَى', #4
u'الملاقيح': u'الْمَلَاقِيحَ', #1
u'الملاقيح': u'الْمَلاَقِيحِ', #1
u'الملاقيح': u'الْمَلَاقِيحِ', #36
u'الملاقيح': u'الْمَلَاقِيحُ', #5
u'الملاكع': u'الْمَلَاكِعِ', #1
u'الملالة': u'الْمَلَالَةَ', #1
u'الملالة': u'الْمَلَالَةِ', #4
u'الملاما': u'الْمُلَامَا', #2
u'الملاهى': u'الْمَلاَهِى', #3
u'الملاوثة': u'الْمَلَاوِثَةِ', #2
u'الملاوم': u'الْمَلَاوِمِ', #1
u'الملاومة': u'الْمُلَاوَمَة', #1
u'الملآئكة': u'الْمَلآئِكَةِ', #2
u'الملآئكة': u'الْمَلآئِكَةُ', #6
u'الملائكه': u'الملائكه', #1
u'الملائى': u'الْمُلاَئِىُّ', #24
u'الملائى': u'الْمُلاَئِىِّ', #5
u'الملاية': u'الْمِلَايَةِ', #1
u'الملايمة': u'الْمُلَايَمَةُ', #1
u'الملايني': u'الْمَلَايِنِيُّ', #1
u'الملبى': u'الْمُلَبَّى', #1
u'الملبى': u'الْمُلَبِّى', #3
u'الملتاث': u'الْمُلْتَاثُ', #2
u'الملتج': u'الْمُلْتَجِّ', #1
u'الملتذ': u'الْمُلْتَذِّ', #3
u'الملتعن': u'الْمُلْتَعِنَ', #1
u'الملتعن': u'الْمُلْتَعِنُ', #1
u'الملتعنة': u'الملتعنة', #1
u'الملتوت': u'الْمَلْتُوتُ', #1
u'الملتوت': u'الْمَلْتُوتِ', #7
u'الملتوت': u'الْمَلْتُوتَ', #8
u'الملجج': u'الْمُلَجَّجِ', #1
u'الملجوم': u'الْمَلْجُومُ', #1
u'الملحب': u'الْمُلَحّب', #1
u'الملحب': u'الْمُلَحّبِ', #2
u'الملحمه': u'الْمَلْحَمَهْ', #1
u'الملذوذات': u'الْمَلْذُوذَاتِ', #4
u'الملزوق': u'الْمَلْزُوقُ', #1
u'الملزوق': u'الْمَلْزُوقِ', #3
u'الملزوم': u'الْمَلْزُومِ', #283
u'الملزوم': u'الْمَلْزُومَ', #36
u'الملزوم': u'الْمَلْزُومُ', #74
u'الملزومات': u'الْمَلْزُومَاتُ', #2
u'الملزومات': u'الْمَلْزُومَاتِ', #23
u'الملزومة': u'الْمَلْزُومَة', #1
u'الملزومة': u'الْمَلْزُومَةِ', #1
u'الملزومية': u'الْمَلْزُومِيَّةَ', #1
u'الملزومية': u'الْمَلْزُومِيَّةِ', #2
u'الملزومين': u'الْمَلْزُومَيْنِ', #2
u'الملصاء': u'الْمَلْصَاءُ', #1
u'الملطأة': u'الْمِلْطَأَةَ', #2
u'الملطاة': u'الْمِلْطَاةِ', #5
u'الملطاة': u'الْمِلْطَاةُ', #9
u'الملطى': u'الْمِلْطَى', #1
u'الملطى': u'الْمَلَطَى', #2
u'الملطية': u'الْمَلْطِيَّةُ', #1
u'الملطية': u'الْمَلْطِيَّةِ', #1
u'الملقف': u'الْمُلَقَّفِ', #1
u'الملقف': u'الْمُلَقِّفِ', #1
u'الملقم': u'الْمُلْقَمِ', #1
u'الملقوح': u'الْمَلْقُوحُ', #1
u'الملقوطة': u'الْمَلْقُوطَةِ', #34
u'الملقوطة': u'الْمَلْقُوطَةَ', #4
u'الملكاني': u'الْمِلْكَانِيُّ', #1
u'الملكاني': u'الْمِلْكَانِيّ', #4
u'الملكوسئل': u'الْمَلِكِوَسُئِلَ', #1
u'المللين': u'الْمَلَلَيْنِ', #1
u'الملمم': u'الْمُلَمّمِ', #2
u'الملموز': u'الْمَلْمُوزَ', #1
u'الملهوج': u'الْمَلْهُوجِ', #1
u'الملو': u'الْمُلُو', #2
u'الملو': u'الْمُلُوّ', #2
u'الملوان': u'الْمَلَوَانِ', #4
u'الملوخيا': u'الْمُلُوخِيَّا', #2
u'الملوط': u'الْمَلُوطَ', #1
u'الملوط': u'الْمَلُوطُ', #1
u'الملوط': u'الْمَلُوطِ', #5
u'الملوطة': u'الْمَلُوطَةِ', #1
u'الملوطة': u'الْمِلْوَطَةُ', #1
u'الملوكة': u'الْمَلُوكَةَ', #1
u'الملى': u'الْمُلَى', #1
u'الملى': u'المَلى', #2
u'الملى': u'الملى', #3
u'الملى': u'الْمَلِىِّ', #4
u'الملىء': u'الملىء', #1
u'المليجي': u'الْمَلِيجِيُّ', #1
u'المليحالأمة': u'الْمَلِيحِالأُمَّةُ', #1
u'المليق': u'الْمُلِيقِ', #1
u'المليكى': u'الْمُلَيْكِىِّ', #1
u'المليلة': u'الْمَلِيلَةُ', #1
u'الممادح': u'الْمَمَادِحْ', #2
u'الممازج': u'الْمُمَازَجِ', #2
u'الممازج': u'الْمُمَازِجِ', #4
u'المماسكة': u'الْمُمَاسَكَةُ', #1
u'المماسكة': u'الْمُمَاسَكَةِ', #1
u'المماسكة': u'الْمُمَاسَكَةَ', #2
u'المماكس': u'الْمُمَاكِسُ', #1
u'الممالة': u'الْمُمَالَةِ', #1
u'الممالئ': u'الْمُمَالِئُ', #2
u'الممالئين': u'الْمُمَالِئِينَ', #1
u'الممالئين': u'الْمُمَالِئَيْنِ', #1
u'الممائل': u'الْمُمَائِلِ', #1
u'الممايزة': u'الْمُمَايَزَةُ', #1
u'الممايلة': u'الْمُمَايَلَةِ', #1
u'الممترج': u'الْمُمْتَرِجِ', #1
u'الممتشطة': u'الْمُمْتَشِطَةُ', #2
u'الممحض': u'الْمُمَحَّضِ', #1
u'الممحق': u'الْمُمْحِقَ', #1
u'الممحل': u'الممحل', #1
u'الممحل': u'الْمُمْحِلُ', #2
u'الممحلات': u'الْمُمْحِلَاتِ', #2
u'الممخة': u'الْمُمِخّةِ', #1
u'الممخرق': u'الْمُمَخْرَقِ', #1
u'الممدح': u'الْمُمَدّحَ', #2
u'الممدح': u'الْمُمَدّحُ', #2
u'الممدحين،': u'الممدَّحين،', #1
u'الممدرة': u'الْمَمْدَرَةُ', #1
u'الممدرة': u'الْمَمْدَرَةِ', #1
u'الممدوحية': u'الْمَمْدُوحِيَّةَ', #1
u'الممدوحية': u'الْمَمْدُوحِيَّةُ', #1
u'الممدوحية': u'الْمَمْدُوحِيَّةِ', #2
u'الممدوق': u'الْمَمْدُوقُ', #1
u'الممذوق': u'الْمَمْذُوقِ', #1
u'الممرد': u'الْمُمَرَّدُ', #1
u'الممرور': u'الْمَمْرُورَ', #1
u'الممرور': u'الْمَمْرُورُ', #3
u'الممرور': u'الْمَمْرُورِ', #9
u'الممروق': u'الْمَمْرُوقُ', #1
u'الممروق': u'الْمَمْرُوقَ', #2
u'الممروق': u'الْمَمْرُوقِ', #2
u'الممروقية': u'الْمَمْرُوقِيَّةِ', #1
u'الممروقية': u'الْمَمْرُوقِيَّةُ', #2
u'الممشق': u'الْمُمَشَّقُ', #1
u'الممشق': u'الْمُمَشَّقِ', #5
u'الممشق': u'الْمُمَشَّقَ', #6
u'الممض': u'الْمُمِضِّ', #1
u'الممطول': u'الْمَمْطُولُ', #1
u'الممعط': u'الْمُمّعِطِ', #1
u'الممعوط': u'الْمَمْعُوطِ', #1
u'الممغط': u'الْمُمَغَّطِ', #2
u'الممغط': u'الْمُمّغِطِ', #3
u'الممقور': u'الْمَمْقُورُ', #1
u'الممكورة': u'الْمَمْكُورَةِ', #2
u'المملو': u'الْمَمْلُوُّ', #1
u'المملوح': u'الْمَمْلُوحِ', #2
u'المملوح': u'الْمَمْلُوحُ', #3
u'المملوطة': u'الْمَمْلُوطَةُ', #1
u'الممهرين': u'الْمُمَهِّرِينَ', #1
u'الممهور': u'الْمَمْهُورَ', #1
u'الممهور': u'الْمَمْهُورُ', #13
u'الممهور': u'الْمَمْهُورِ', #3
u'الممهورة': u'الْمَمْهُورَةُ', #6
u'الممهورة': u'الْمَمْهُورَةَ', #7
u'الممهورة': u'الْمَمْهُورَةِ', #8
u'المميزه': u'الْمُمَيِّزَهْ', #1
u'المنا': u'اُلْمُنَا', #1
u'المنا': u'الْمَنَا', #2
u'المنابزة': u'الْمُنَابَزَةُ', #1
u'المناجات': u'الْمُنَاجَاتِ', #1
u'المناجح': u'الْمَنَاجِحْ', #2
u'المناجز': u'الْمُنَاجِزَ', #1
u'المناجز': u'الْمُنَاجِزْ', #2
u'المناجش': u'الْمُنَاجِشَ', #2
u'المناحبة': u'الْمُنَاحَبَةُ', #1
u'المناحس': u'الْمَنَاحِسِ', #1
u'المناخات': u'الْمُنَاخَاتِ', #3
u'المناخة': u'الْمُنَاخَةَ', #1
u'المناخة': u'الْمُنَاخَةُ', #1
u'المناخل': u'الْمَنَاخِلِ', #16
u'المناخل': u'الْمَنَاخِلَ', #2
u'المناخل': u'الْمَنَاخِلُ', #4
u'المناخير': u'الْمَنَاخِيرِ', #1
u'المناد،': u'الْمُنَادِ،', #1
u'المناد': u'الْمُنَادِ', #3
u'المناذرة': u'الْمَنَاذِرَة', #1
u'المناذرة': u'الْمَنَاذِرَةُ', #2
u'المناذرة': u'الْمَنَاذِرَةِ', #2
u'المنازلية': u'الْمَنَازِلِيَّةِ', #1
u'المناستري': u'الْمَنَاسِتْرِيُّ', #1
u'المناسخ': u'الْمُنَاسِخَ', #1
u'المناسر': u'الْمَنَاسِرِ', #1
u'المناصاة': u'الْمُنَاصَاةُ', #1
u'المناصح': u'الْمُنَاصِحِ', #2
u'المناصع': u'الْمَنَاصِعُ', #1
u'المناصع،': u'الْمَنَاصِعِ،', #1
u'المناصع': u'الْمَنَاصِعِ', #13
u'المنافر': u'الْمُنَافِرُ', #1
u'المنافى': u'الْمُنَافَى', #1
u'المنافين': u'الْمَنَافَيْنِ', #1
u'المناكح': u'الْمَنَاكِحَ', #1
u'المناكح': u'الْمُنَاكِح', #1
u'المناكح،': u'الْمَنَاكِحِ،', #1
u'المناكح': u'الْمُنَاكِحِ', #3
u'المناكح': u'الْمَنَاكِحِ', #4
u'المناكحه': u'الْمُنَاكَحَهْ', #1
u'المناكر': u'الْمَنَاكِرَ', #1
u'المناكر': u'الْمَنَاكِرُ', #1
u'المناكر': u'الْمُنَاكِرِ', #3
u'المناكر': u'الْمَنَاكِرِ', #6
u'المناكرة': u'الْمُنَاكِرَةِ', #1
u'المناكرة': u'الْمُنَاكَرَةُ', #23
u'المناكرة': u'الْمُنَاكَرَةِ', #37
u'المناكرة': u'الْمُنَاكَرَةَ', #5
u'المناكيب': u'الْمَنَاكِيبُ', #1
u'المنامسا': u'الْمُنَامِسَا', #1
u'المناهز': u'الْمُنَاهِزَ', #3
u'المناهز': u'الْمُنَاهِزِ', #3
u'المناهز': u'الْمُنَاهِزُ', #4
u'المناهلة': u'الْمُنَاهَلَةِ', #1
u'المناهى': u'الْمَنَاهِى', #1
u'المنائح': u'المنائح', #1
u'المنائيا': u'الْمَنَائِيَا', #2
u'المنبتر': u'الْمُنْبَتِرُ', #1
u'المنبجي': u'الْمَنْبِجِيُّ', #1
u'المنبجى': u'الْمَنْبِجِىُّ', #6
u'المنبذ': u'الْمُنَبَّذُ', #1
u'المنبرSفصل': u'الْمِنْبَرِSفَصْلٌ', #1
u'المنبغي': u'الْمُنْبَغِيَ', #2
u'المنبهم': u'الْمُنْبَهِمِ', #1
u'المنبهى': u'الْمَنْبَهِىِّ', #1
u'المنبهى؟': u'الْمَنْبَهِىِّ؟', #1
u'المنبوش': u'الْمَنْبُوشِ', #1
u'المنبوش': u'الْمَنْبُوشُ', #4
u'المنبوشة': u'الْمَنْبُوشَةُ', #3
u'المنبوشة': u'الْمَنْبُوشَةِ', #30
u'المنتأى': u'الْمُنْتَأَى', #1
u'المنتبر': u'المنتبر', #1
u'المنتتف': u'الْمُنْتَتَفِ', #1
u'المنتتف': u'الْمُنْتَتِفَ', #1
u'المنتتف': u'الْمُنْتَتَفُ', #3
u'المنتتف': u'الْمُنْتَتَفَ', #5
u'المنتثر': u'الْمُنْتَثَرِ', #1
u'المنتثر': u'الْمُنْتَثِرَ', #1
u'المنتثرة': u'الْمُنْتَثِرَةِ', #2
u'المنتزل': u'الْمُنْتَزَلْ', #2
u'المنتسبه': u'الْمُنْتَسِبَهْ', #1
u'المنتسخ': u'الْمُنْتَسِخِ', #1
u'المنتسخ': u'الْمُنْتَسَخِ', #4
u'المنتشئ': u'الْمُنْتَشِئُ', #1
u'المنتضح': u'الْمُنْتَضِحُ', #2
u'المنتضح': u'الْمُنْتَضَحُ', #3
u'المنتفق': u'المنتفق', #1
u'المنتفق': u'الْمُنْتَفَقِ', #1
u'المنتفق': u'الْمُنْتَفِقَ', #1
u'المنتفق': u'الْمُنْتَفِقِ', #14
u'المنتفل': u'الْمُنْتَفِلُ', #1
u'المنتفل': u'الْمُنْتَفِلِ', #1
u'المنتفى': u'الْمُنْتَفَى', #20
u'المنتقب': u'الْمُنْتَقِبَ', #1
u'المنتقبات': u'الْمُنْتَقِبَاتِ', #1
u'المنتقبة': u'الْمُنْتَقِبَةَ', #3
u'المنتقبة': u'الْمُنْتَقِبَةِ', #37
u'المنتقش': u'الْمُنْتَقَشُ', #1
u'المنتقع': u'المنتقع', #1
u'المنتمصة': u'الْمُنْتَمِصَة', #1
u'المنتهب': u'الْمُنْتَهِب', #1
u'المنتهب': u'الْمُنْتَهِبَ', #1
u'المنتهب': u'الْمُنْتَهِبِ', #17
u'المنتهب': u'الْمُنْتَهِبُ', #2
u'المنتهب': u'الْمُنْتَهَبُ', #3
u'المنتهب': u'الْمُنْتَهَبِ', #9
u'المنتهبين': u'الْمُنْتَهَبِينَ', #1
u'المنتوف،': u'الْمَنْتُوفُ،', #1
u'المنتوف': u'الْمَنْتُوفِ', #4
u'المنتوف': u'الْمَنْتُوفُ', #5
u'المنثعب': u'المُنْثَعِبْ', #2
u'المنثوري': u'الْمَنْثُورِيُّ', #1
u'المنثوري': u'الْمَنْثُورِيِّ', #1
u'المنجا': u'الْمُنَجَّا', #27
u'المنجاب': u'المنجاب', #1
u'المنجاب': u'الْمِنْجَابُ', #1
u'المنجاب': u'الْمِنْجَابِ', #1
u'المنجانيقات': u'الْمَنْجَانِيقَاتِ', #1
u'المنجحر': u'الْمُنْجَحِرْ', #2
u'المنجمد': u'الْمُنْجَمِدِ', #1
u'المنجنون': u'المنجنون', #1
u'المنجنون': u'المَنْجَنون', #1
u'المنجنون': u'الْمَنْجَنُونُ', #10
u'المنجنون': u'الْمَنْجَنُونِ', #3
u'المنجنيقى': u'الْمَنْجَنِيقِىُّ', #1
u'المنحصرون': u'الْمُنْحَصِرُونَ', #2
u'المنحمنا': u'الْمُنْحَمَنّا', #2
u'المنحور': u'الْمَنْحُور', #1
u'المنحور': u'الْمَنْحُورُ', #1
u'المنحور': u'الْمَنْحُورِ', #3
u'المنحول': u'الْمَنْحُولُ', #3
u'المنحول': u'الْمَنْحُولِ', #5
u'المنحولة': u'الْمَنْحُولَةُ', #1
u'المنخرق': u'الْمُنْخَرِقَ', #2
u'المنخرق': u'الْمُنْخَرِقِ', #3
u'المنخسف': u'الْمُنْخَسِفُ', #3
u'المنخسف': u'الْمُنْخَسِفِ', #8
u'المنخل': u'الْمُنْخُل', #1
u'المنخل،': u'الْمُنْخُلُ،', #1
u'المنخل': u'الْمُنَخَّلِ', #2
u'المنخل': u'الْمُنْخُلَ', #2
u'المنخل': u'الْمُنْخُلُ', #2
u'المنخل': u'الْمُنْخُلِ', #8
u'المنخو': u'الْمَنْخُوّ', #1
u'المنخوسة': u'الْمَنْخُوسَةَ', #1
u'المنخوسة': u'الْمَنْخُوسَةِ', #1
u'المنخول': u'الْمَنْخُولِ', #166
u'المنخول': u'الْمَنْخُولَ', #2
u'المنخول': u'الْمَنْخُولُ', #2
u'المندائي': u'الْمنْدَائِيُّ', #1
u'المندبة': u'الْمَنْدَبَةِ', #1
u'المندبغ': u'الْمُنْدَبِغُ', #1
u'المندسي': u'الْمِنْدَسِيُّ', #1
u'المندملة': u'الْمُنْدَمِلَةِ', #4
u'المندوف': u'الْمَنْدُوفِ', #1
u'المندى': u'الْمُنَدَّى', #29
u'المندى': u'الْمُنَدّى', #3
u'المنذرا': u'الْمُنْذِرَا', #2
u'المنذري': u'الْمُنْذَرِيَّ', #1
u'المنذري': u'الْمُنْذِرِيَّ', #1
u'المنذري': u'الْمُنْذَرِي', #2
u'المنذري': u'الْمُنْذِرِيّ', #2
u'المنذري': u'الْمُنْذِرِيِّ', #22
u'المنذري': u'الْمُنْذِرِيُّ', #294
u'المنزلاوي': u'الْمَنْزَلَاوِيُّ', #1
u'المنزلاوي': u'الْمَنْزَلَاوِيِّ', #1
u'المنزله': u'الْمَنْزِلَهْ', #3
u'المنزوح': u'الْمَنْزُوحِ', #4
u'المنزوح': u'الْمَنْزُوحُ', #6
u'المنزور': u'الْمَنْزُورِ', #3
u'المنزوعي': u'الْمَنْزُوعَيْ', #1
u'المنسا': u'الْمَنْسَا', #1
u'المنساة': u'الْمُنْسَاةُ', #1
u'المنساة': u'الْمُنْسَاةِ', #1
u'المنساة': u'الْمِنْسَاة', #1
u'المنساة': u'الْمِنْسَاةِ', #1
u'المنستير': u'الْمُنَسْتِيرِ', #3
u'المنسر': u'الْمَنْسَرُ', #1
u'المنسر': u'الْمَنْسِرُ', #1
u'المنسر': u'الْمِنْسَرُ', #1
u'المنسفة': u'الْمِنْسَفَةُ', #1
u'المنسفلة': u'الْمُنْسَفِلَةِ', #1
u'المنسوخوالوجه': u'الْمَنْسُوخَوَالْوَجْهُ', #1
u'المنسولة': u'الْمَنْسُولَةِ', #4
u'المنشعب': u'الْمُنْشَعِبِ', #10
u'المنشعبة': u'الْمُنْشَعِبَةَ', #1
u'المنشعبة': u'الْمُنْشَعِبَةِ', #10
u'المنشعبة': u'الْمُنْشَعِبَةُ', #2
u'المنشوش': u'الْمَنْشُوشِ', #5
u'المنشى': u'الْمُنَشَّى', #1
u'المنشئية': u'الْمَنْشَئِيَّةُ', #1
u'المنصفه': u'الْمُنْصِفَهْ', #1
u'المنصوبون': u'الْمَنْصُوبُونَ', #1
u'المنصورى': u'الْمَنْصُورِىُّ', #1
u'المنصورية': u'الْمَنْصُورِيَّةِ', #10
u'المنصوصية': u'الْمَنْصُوصِيَّةَ', #1
u'المنصوصية': u'الْمَنْصُوصِيَّةِ', #1
u'المنضج': u'الْمُنْضِجْ', #1
u'المنضج': u'الْمُنْضِجِ', #2
u'المنضج': u'الْمُنْضَجِ', #3
u'المنضجة': u'الْمُنْضِجَةِ', #1
u'المنضوح': u'الْمَنْضُوحِ', #1
u'المنضوخ': u'الْمَنْضُوخِ', #1
u'المنضول': u'الْمَنْضُولُ', #5
u'المنضولين': u'الْمَنْضُولِينَ', #3
u'المنطاة': u'الْمُنْطَاةُ', #1
u'المنطوقية': u'الْمَنْطُوقِيَّةَ', #1
u'المنطية': u'الْمُنْطِيَةُ', #1
u'المنطية': u'الْمُنْطِيَةِ', #1
u'المنظره': u'الْمَنْظَرَهْ', #8
u'المنعان': u'الْمَنْعَانِ', #1
u'المنعطفه': u'الْمُنْعَطِفَهْ', #1
u'المنعكف': u'الْمُنْعَكِفُ', #1
u'المنعل': u'الْمُنَعَّلُ', #1
u'المنعل': u'الْمُنْعَلِ', #3
u'المنعل': u'الْمُنَعَّلِ', #4
u'المنعلين': u'الْمُنَعَّلَيْنِ', #1
u'المنعنع': u'الْمُنَعْنَعِ', #1
u'المنعه': u'الْمَنَعَهْ', #4
u'المنفحة': u'الْمِنْفَحَةِ', #1
u'المنفحة': u'الْمِنْفَحَةُ', #3
u'المنفخة': u'الْمُنَفَّخَةِ', #1
u'المنفخة': u'الْمُنَفِّخَةِ', #2
u'المنفعه': u'الْمَنْفَعَهْ', #2
u'المنفك': u'الْمُنْفَكَّ', #1
u'المنفك': u'الْمُنْفَكِّ', #3
u'المنفك': u'الْمُنْفَكُّ', #4
u'المنفكة': u'الْمُنْفَكَّةِ', #2
u'المنفكة': u'الْمُنْفَكَّةُ', #9
u'المنفكتين': u'الْمُنْفَكَّتَيْنِ', #1
u'المنفل': u'الْمُنْفَلَ', #1
u'المنفل': u'الْمُنَفَّلِ', #12
u'المنفل': u'الْمُنَفَّلَ', #2
u'المنفل': u'الْمُنَفِّلِ', #3
u'المنفل': u'الْمُنْفَلِ', #4
u'المنفل': u'الْمُنْفَلُ', #5
u'المنفل': u'الْمُنَفَّلُ', #6
u'المنفلة': u'الْمُنَفِّلَةَ', #2
u'المنفلين': u'الْمُنَفَّلِينَ', #1
u'المنفهم': u'الْمُنْفَهِمِ', #3
u'المنفهمة': u'الْمُنْفَهِمَةِ', #1
u'المنفوذ': u'الْمَنْفُوذُ', #1
u'المنفوذة': u'الْمَنْفُوذَةُ', #11
u'المنفوذة': u'الْمَنْفُوذَةِ', #3
u'المنفوذة': u'الْمَنْفُوذَةَ', #7
u'المنفوس': u'الْمَنْفُوسَ', #1
u'المنفوس': u'الْمَنْفُوسُ', #4
u'المنفوس': u'الْمَنْفُوسِ', #6
u'المنفول': u'الْمَنْفُولِ', #1
u'المنق': u'المنق', #2
u'المنقاري': u'الْمِنْقَارِيُّ', #1
u'المنقاري': u'الْمِنْقَارِيِّ', #1
u'المنقاس': u'الْمُنْقَاسُ', #1
u'المنقاش': u'الْمِنْقَاشُ', #1
u'المنقد': u'الْمُنْقِدِ', #1
u'المنقدح': u'الْمُنْقَدِحُ', #1
u'المنقر': u'الْمِنْقَر', #1
u'المنقري': u'المِنْقَرِيِّ', #1
u'المنقري': u'الْمِنْقَرِيّ', #1
u'المنقرى': u'الْمِنْقَرِىِّ', #1
u'المنقرى': u'الْمِنْقَرِىُّ', #14
u'المنقري': u'الْمُنْقِرِيِّ', #2
u'المنقري،': u'الْمِنْقَرِيِّ،', #2
u'المنقري': u'الْمُنْقِرِيُّ', #24
u'المنقري،': u'الْمِنْقَرِيُّ،', #24
u'المنقري': u'الْمِنْقَرِيِّ', #3
u'المنقري': u'المنقري', #4
u'المنقري': u'الْمِنْقَرِيُّ', #9
u'المنقرئ': u'الْمِنْقَرّئ', #1
u'المنقش': u'الْمُنَقَّشُ', #1
u'المنقش': u'الْمُنَقَّشِ', #4
u'المنقشة': u'الْمُنَقَّشَةِ', #4
u'المنقود': u'الْمَنْقُودَ', #16
u'المنقود': u'الْمَنْقُودُ', #36
u'المنقود': u'الْمَنْقُودِ', #45
u'المنقودة': u'الْمَنْقُودَةَ', #1
u'المنقودة': u'الْمَنْقُودَةُ', #2
u'المنقودة': u'الْمَنْقُودَةِ', #6
u'المنقوصون': u'الْمَنْقُوصُونَ', #1
u'المنقوف': u'الْمَنْقُوفُ', #1
u'المنقولية': u'الْمَنْقُولِيَّةِ', #1
u'المنكاب': u'الْمِنْكَابُ', #1
u'المنكثرة': u'الْمُنْكَثِرَةُ', #1
u'المنكثي،': u'الْمُنَكِّثِيُّ،', #1
u'المنكدر': u'الْمُنْكَدَرِ', #1
u'المنكدر': u'الْمُنْكَدِرٍ', #1
u'المنكدر،': u'الْمُنْكَدِرِ،', #118
u'المنكدر،': u'الْمُنْكَدِر،', #2
u'المنكدر': u'الْمُنْكَدِرَ', #3
u'المنكدر': u'المنكدر', #5
u'المنكدر،': u'المنكدر،', #5
u'المنكدر': u'الْمُنْكَدِرِ', #505
u'المنكدر': u'الْمُنْكَدِر', #6
u'المنكدر': u'الْمُنْكَدِرُ', #8
u'المنكدري،': u'الْمُنْكَدِرِيُّ،', #2
u'المنكشط': u'الْمُنْكَشِطِ', #1
u'المنلا': u'الْمُنْلَا', #20
u'المنماص': u'الْمِنْمَاصُ', #2
u'المنهب': u'الْمِنْهَبِ', #2
u'المنهر': u'الْمُنْهَرَ', #1
u'المنهر': u'الْمُنْهَرِ', #1
u'المنهر': u'الْمُنْهِرُ', #1
u'المنهر': u'الْمَنْهَرِ', #2
u'المنهرة': u'الْمَنْهَرَةِ', #1
u'المنهزما': u'الْمُنْهَزِمَا', #2
u'المنهزمه': u'الْمُنْهَزِمَهْ', #1
u'المنهمة': u'الْمَنْهَمَةُ', #1
u'المنهمة': u'الْمُنْهَمَّةُ', #1
u'المنهوس': u'المنهوس', #1
u'المنهومين': u'الْمَنْهُومِينَ', #1
u'المنهى': u'الْمَنْهِىِّ', #2
u'المنهى': u'الْمُنْهَى', #30
u'المنوب': u'الْمُنَوَّبُ', #1
u'المنوب': u'الْمُنَوِّبِ', #2
u'المنوب': u'الْمَنُوبُ', #3
u'المنوب': u'الْمَنُوبَ', #5
u'المنوب': u'الْمَنُوبِ', #71
u'المنوبات': u'الْمُنَوِّبَاتِ', #1
u'المنوبة': u'الْمَنُوبَةَ', #1
u'المنوبين': u'الْمَنُوبَيْنِ', #1
u'المنورق': u'الْمُنْوَرِقِ', #1
u'المنوره': u'الْمُنَوَّرَهْ', #1
u'المنوفي': u'الْمَنُوفِيُّ', #28
u'المنوفي': u'الْمَنُوفِيَّ', #3
u'المنوفي': u'الْمَنُوفِيِّ', #51
u'المنوفية': u'الْمَنُوفِيَّةِ', #2
u'المنوقة': u'المنوقة', #1
u'المنيح': u'الْمَنِيحَ', #1
u'المنيحة': u'المنيحة', #1
u'المنيحة': u'الْمَنِيحَة', #2
u'المنيحة': u'الْمَنِيحَةِ', #3
u'المنيحة': u'الْمَنِيحَةُ', #4
u'المنيذر': u'الْمُنَيْذِرِ', #1
u'المنيعى': u'الْمَنِيعِىَّ', #1
u'المنيعى': u'الْمَنِيعِىِّ', #1
u'المنيعى': u'الْمَنِيعِىُّ', #22
u'المنيعى': u'الْمُنَيْعِىُّ', #3
u'المنيني': u'الْمَنِينِيُّ', #5
u'المنيئة': u'المنيئة', #1
u'المنيئة': u'الْمَنِيئَةَ', #2
u'المنيئة': u'الْمَنِيئَةِ', #2
u'المهاباذي': u'الْمَهَابَاذِيُّ', #1
u'المهابه': u'الْمَهَابَهْ', #1
u'المهابين': u'الْمُهَابِينَ', #1
u'المهاجري': u'الْمُهَاجِرِيَّ', #1
u'المهاجرى': u'الْمُهَاجِرِىَّ', #1
u'المهاجري': u'الْمُهَاجِرِيُّ', #15
u'المهاجري': u'الْمُهَاجِرِيّ', #4
u'المهاجرى': u'الْمُهَاجِرِىُّ', #7
u'المهارشة': u'الْمُهَارَشَةِ', #1
u'المهارى': u'الْمَهَارَى', #3
u'المهازيل': u'الْمَهَازِيلَ', #1
u'المهازيل': u'الْمَهَازِيلُ', #1
u'المهازيل': u'الْمَهَازِيلِ', #12
u'المهاصير': u'الْمَهَاصِيرُ', #1
u'المهال': u'الْمُهَالُ', #1
u'المهالبة': u'الْمَهَالِبَةَ', #1
u'المهالبة': u'الْمَهَالِبَةُ', #1
u'المهالبة': u'الْمَهَالِبَةِ', #1
u'المهامه': u'الْمَهَامِهَ', #1
u'المهامه': u'الْمَهَامِهُ', #1
u'المهامه': u'الْمَهَامِهِ', #7
u'المهأناة': u'الْمُهَأنَاةُ', #1
u'المهاناة': u'الْمُهَانَاةِ', #1
u'المهانأة': u'الْمُهَانَأَةِ', #2
u'المهانه': u'الْمَهَانَهْ', #2
u'المهايأ': u'الْمُهَايَأُ', #1
u'المهايأة': u'الْمُهَايَأَةَ', #147
u'المهايأة': u'الْمُهَايَأَةُ', #271
u'المهايأة': u'الْمُهَايَأَةِ', #409
u'المهايأة': u'الْمُهَايَأَة', #5
u'المهايآت': u'الْمُهَايَآتُ', #1
u'المهايآت': u'الْمُهَايَآتِ', #1
u'المهايات': u'الْمُهَايَاتِ', #2
u'المهايئات': u'الْمُهَايَئَات', #1
u'المهايئات': u'الْمُهَايَئَاتِ', #23
u'المهايئات': u'الْمُهَايَئَاتُ', #4
u'المهايئة': u'الْمُهَايَئَةُ', #1
u'المهتبل': u'الْمُهْتَبِلُ', #1
u'المهتجرين': u'الْمُهْتَجِرَيْنِ', #1
u'المهتدى': u'الْمُهْتَدِى', #3
u'المهجم': u'الْمَهْجَمِ', #6
u'المهجى': u'الْمُهَجَّى', #1
u'المهدا،': u'الْمُهْدَا،', #1
u'المهداني': u'الْمَهْدَانِيّ', #1
u'المهدوي': u'الْمَهْدَوِيُّ', #8
u'المهدوية': u'الْمَهْدَوِيَّةِ', #1
u'المهراة': u'الْمُهَرَّاةِ', #1
u'المهراني،': u'الْمِهْرَانِيُّ،', #1
u'المهرانى': u'الْمِهْرَانِىُّ', #11
u'المهرانى': u'الْمَهْرَانِىُّ', #2
u'المهرجانى': u'الْمِهْرَجاَنِىُّ', #1
u'المهرجانى': u'الْمِهْرَجِانِىُّ', #3
u'المهرجانى': u'الْمِهْرَجَانِىُّ', #363
u'المهرجانى': u'الْمَهْرَجَانِىُّ', #8
u'المهرقاني': u'الْمَهْرِقَانِيّ', #1
u'المهرقاني،': u'الْمُهْرُقَانِيُّ،', #1
u'المهرقانى': u'الْمِهْرَقَانِىُّ', #1
u'المهرقاني،': u'الْمِهْرَقَانِيُّ،', #2
u'المهرواني': u'الْمَهْرَوَانِيُّ', #1
u'المهروب': u'الْمَهْرُوبُ', #2
u'المهرود': u'المهرود', #1
u'المهرودة': u'المهرودة', #1
u'المهروي': u'الْمَهْرَويِّ', #1
u'المهرويه': u'الْمَهْرَوَيْهِ', #1
u'المهرى': u'الْمَهْرِىُّ', #17
u'المهرى': u'الْمَهْرِىَّ', #2
u'المهرى': u'الْمَهْرِىِّ', #22
u'المهزة': u'الْمَهْزَة', #1
u'المهزم': u'المُهَزِّمِ', #1
u'المهزم': u'الْمُهَزَّم', #1
u'المهزم': u'الْمُهَزَّمِ', #1
u'المهزم،': u'الْمُهَزِّمِ،', #1
u'المهزم': u'الْمُهَزِّمِ', #21
u'المهزم': u'الْمِهْزَمِ', #4
u'المهزمين': u'الْمُهْزَمِينَ', #1
u'المهزور': u'الْمَهْزُورِ', #2
u'المهشوم': u'الْمَهْشُومِ', #1
u'المهشوم': u'الْمَهْشُومَ', #2
u'المهقوع': u'الْمَهْقُوعَ', #2
u'المهقوع': u'الْمَهْقُوعُ', #3
u'المهلب': u'المهلب', #1
u'المهلب': u'الْمُهَلّبَ', #1
u'المهلب': u'الْمُهَلِّبِ', #1
u'المهلب،': u'الْمَهَلَّبِ،', #1
u'المهلب': u'الْمُهَلَّبَ', #14
u'المهلب': u'الْمُهَلَّبِ', #152
u'المهلب': u'الْمُهَلّبِ', #2
u'المهلب،': u'الْمُهَلَّبَ،', #2
u'المهلب': u'الْمُهَلَّب', #3
u'المهلب،': u'الْمُهَلَّبِ،', #35
u'المهلب': u'الْمُهَلَّبُ', #63
u'المهلبى': u'الْمُهَلَّبِىُّ', #9
u'المهلوك': u'الْمَهْلُوكَ', #1
u'المهملج': u'الْمُهَمْلَجِ', #1
u'المهملج': u'الْمُهَمْلِجُ', #1
u'المهملجة': u'الْمُهَمْلِجَةُ', #2
u'المهمنداري': u'الْمِهْمِنْدارِيِّ', #1
u'المهمنداري': u'الْمِهْمَنْدَارِي', #16
u'المهمنداري': u'المهمنداري', #2
u'المهمورة': u'الْمَهْمُورَةَ', #1
u'المهنا': u'الْمُهَنَّا', #1
u'المهناوي': u'المهناوي', #1
u'المهندSوذكر': u'الْمُهَنّدِSوَذَكَرَ', #1
u'المهنى': u'الْمَهْنَىِ', #1
u'المهنى': u'الْمُهَنَّى', #1
u'المهيا': u'الْمُهَيَّا', #1
u'المهير': u'الْمَهِيرُ', #1
u'المهيع': u'الْمَهْيِعُ', #1
u'المهيع': u'الْمَهِيعِ', #2
u'المهيع': u'الْمَهْيَعُ', #2
u'المهيع': u'الْمَهِيعُ', #5
u'المهيمنالأمين،': u'الْمُهَيْمِنُالأَمِينُ،', #1
u'المهيومة': u'الْمَهْيُومَةِ', #3
u'المو': u'المو', #1
u'الموءود': u'الْمَوْءُودَ', #1
u'الموءودة': u'الْمَوْءُودَة', #1
u'الموءودة': u'الْمَوْءوُدَةِ', #1
u'الموءودة،': u'الْمَوْءُودَةَ،', #1
u'الموءودة': u'الْمَوْءُودَةَ', #4
u'الموءودة': u'الْمَوْءُودَةُ', #43
u'الموءودة': u'الْمَوْءُودَةِ', #7
u'الموابذة': u'الْمَوَابِذَةُ', #1
u'المؤاتات': u'الْمُؤَاتَات', #1
u'المواتح': u'الْمَوَاتِحُ', #2
u'المواجب': u'الْمُوَاجِبِ', #1
u'المواجب': u'الْمَوَاجِبِ', #3
u'المؤاجر': u'الْمُؤَاجَرُ', #1
u'المواجر': u'الْمَوَاجِرُ', #1
u'المؤاجر': u'الْمُؤَاجِرِ', #108
u'المؤاجر': u'الْمُؤَاجِرَ', #18
u'المؤاجر': u'الْمُؤَاجَرَ', #4
u'المؤاجر': u'الْمُؤَاجِرُ', #75
u'المؤاجر': u'الْمُؤَاجَرِ', #8
u'المؤاجران': u'الْمُؤَاجِرَانِ', #2
u'المؤاجرة': u'الْمُؤَاجَرَةَ', #1
u'المؤاجرة': u'الْمُؤَاجَرَةُ', #5
u'المؤاجرين': u'الْمُؤَاجِرَيْنِ', #5
u'المواجل': u'الْمَوَاجِلَ', #1
u'المواجل': u'الْمَوَاجِلُ', #1
u'المواجل': u'الْمَوَاجِلِ', #8
u'المؤاجلة': u'الْمُؤَاجَلَةِ', #1
u'المواجيز': u'الْمَوَاجِيزِ', #1
u'المواخاة': u'الْمُوَاخَاةَ', #1
u'المؤادة': u'الْمُؤَادَةَ', #1
u'المؤادة': u'الْمُؤَادَةُ', #1
u'المؤادة': u'الْمُؤَادَةِ', #1
u'الموادعون': u'الْمُوَادِعُونَ', #3
u'الموادعين': u'الْمُوَادِعَيْنِ', #1
u'الموادعين': u'الْمُوَادَعِينَ', #12
u'الموادعين': u'الْمُوَادِعِينَ', #20
u'المؤادمة': u'الْمُؤَادَمَةُ', #1
u'الموادمة': u'الْمُوَادَمَةِ', #2
u'المؤادمة': u'الْمُؤَادَمَةِ', #5
u'الموادئة': u'الْمُوَادَئَةَ', #1
u'الموادين': u'الْمُوَادِّينَ', #1
u'الموارث': u'الْمَوَارِثَ', #1
u'الموارث': u'الْمَوَارِثِ', #1
u'الموارث': u'الْمَوَارِثْ', #1
u'الموارثة': u'الْمُوَارَثَةِ', #4
u'الموارثة': u'الْمُوَارَثَةُ', #7
u'المواردين': u'الْمُوَارِدَيْنِ', #1
u'المواز': u'الْمَوَّاز', #1
u'المواز': u'الْمَوَّازُ', #3
u'المواز': u'الْمَوَّازِ', #3078
u'الموازيني': u'الْمَوَازِينِيُّ', #1
u'الموازيني': u'الْمَوَازِينِيِّ', #1
u'المواسما': u'الْمَوَاسِمَا', #1
u'المواسما': u'الْمُوَاسِمَا', #1
u'المواسى': u'المواسى', #1
u'المواسى': u'الْمَوَاسِى', #4
u'المواشى': u'الْمَوَاشِى', #12
u'المواصي': u'الْمَوَاصِي', #1
u'المواضح': u'الْمَوَاضِحَ', #1
u'المواضح': u'الْمَوَاضِحِ', #16
u'المواضح': u'الْمَوَاضِح', #2
u'المواضح': u'الْمَوَاضِحُ', #7
u'المواضحة': u'الْمُوَاضَحَةِ', #1
u'المواضعات': u'الْمُوَاضَعَاتِ', #1
u'المواضعة': u'الْمُوَاضَعَةِ', #401
u'المواضعة': u'الْمُوَاضَعَةَ', #50
u'المواضعة': u'الْمُوَاضَعَةُ', #99
u'المواعيدا': u'الْمَوَاعِيدَا', #1
u'المواق': u'الْمَوَّاق', #16
u'المواق': u'الْمَوَّاقُ', #433
u'المواق': u'الْمَوَّاقَ', #61
u'المواق': u'الْمَوَّاقِ', #710
u'المواقحة': u'الْمُوَاقَحَةِ', #1
u'المواكسة': u'الْمُوَاكَسَةِ', #1
u'المؤالف': u'الْمُؤَالِفَ', #1
u'المؤالف': u'الْمُؤَالِفِ', #1
u'الموالف': u'الْمُوَالِفُ', #1
u'المؤالفين': u'الْمُؤَالِفِينَ', #1
u'المواليه': u'الْمُوَالِيهِ', #1
u'الموانيذ': u'الْمَوَانِيذُ', #1
u'المواه': u'الْمَوَّاهُ', #1
u'المواهبي': u'الْمَوَاهِبِيُّ', #2
u'المواهقة': u'الْمُوَاهَقَةَ', #1
u'المواهقة': u'الْمُوَاهَقَةُ', #1
u'الموائح': u'الْمَوَائِحْ', #2
u'المؤبذ': u'الْمُؤَبَّذُ', #1
u'الموبذان،': u'الَمُوبَذَانِ،', #1
u'الموبذان': u'الْمُوبَذَانِ', #2
u'الموبذان': u'الْمُوبَذَانُ', #3
u'المؤبر': u'الْمُؤَبِّرَ', #1
u'المؤبر': u'الْمُؤَبِّرُ', #1
u'المؤبر': u'الْمُؤَبِّرِ', #1
u'الموبر': u'الْمُوَبَّرَ', #1
u'المؤبر': u'الْمُؤَبَّرَ', #24
u'المؤبر': u'الْمُؤَبَّرُ', #29
u'المؤبر': u'الْمُؤَبَّرِ', #85
u'المؤبرة': u'الْمُؤَبَّرَة', #1
u'الموبرة': u'الْمُوَبَّرَةُ', #1
u'المؤبرة': u'الْمُؤَبَّرَةِ', #130
u'الموبرة': u'الْمُوَبَّرَةِ', #2
u'المؤبرة': u'الْمُؤَبَّرَةُ', #21
u'المؤبرة': u'الْمُؤَبَّرَةَ', #23
u'المؤبل': u'الْمُؤَبَّلِ', #1
u'المؤبل': u'الْمُؤَبّلِ', #4
u'الموتان': u'الْمَوْتَانِ', #1
u'المؤتة': u'الْمُؤُتَة', #1
u'الموتر': u'الْمُوتَرِ', #1
u'الموتر': u'الْمُوتِرُ', #1
u'المؤتسي': u'الْمُؤْتَسِيَ', #1
u'المؤتشرة': u'الْمُؤْتَشِرَةَ', #1
u'المؤتشمة': u'الْمُؤْتَشِمَةَ', #1
u'الموتصل': u'الْمُوتَصِلُ', #1
u'المؤتفكة': u'الْمُؤْتَفِكَةُ', #1
u'المؤتفكة': u'الْمِؤْتَفِكَةِ', #1
u'المؤتم': u'الْمُؤْتَمِّ', #173
u'المؤتم': u'الْمُؤْتَمُّ', #189
u'المؤتم': u'الْمُؤْتَمَّ', #31
u'المؤتمة': u'الْمُؤْتَمَّةِ', #2
u'المؤتمه': u'الْمُؤْتِمَهْ', #1
u'المؤتمون': u'الْمُؤْتَمُّونَ', #4
u'المؤتمين': u'الْمُؤْتَمَّيْنِ', #1
u'المؤتمين': u'الْمُؤْتَمِّينَ', #17
u'المؤتنف': u'الْمُؤْتَنَفِ', #3
u'المؤتنفة': u'الْمُؤْتَنَفَةِ', #1
u'الموتوالوجه': u'الْمَوْتُوَالْوَجْهُ', #1
u'الموتورا': u'الْمَوْتُورَا', #3
u'المؤتى': u'الْمُؤْتَى', #6
u'الموتين': u'الْمَوْتَيْنِ', #24
u'الموتىوالوجه': u'الْمَوْتَىوَالْوَجْهُ', #1
u'الموثر': u'الْمُوَثِّرِ', #1
u'المؤثل': u'الْمُؤَثّلِ', #2
u'المؤثم': u'الْمُؤَثِّمُ', #1
u'المؤثم': u'الْمُؤَثِّمِ', #1
u'المؤثم': u'الْمُؤْثَمَ', #1
u'المؤثم': u'الْمُؤْثَمِ', #1
u'المؤثم': u'الْمُؤْثِمُ', #1
u'المؤثم': u'الْمُؤَثِّمَ', #2
u'المؤثم': u'الْمُؤْثِمَ', #3
u'المؤثم': u'الْمُؤْثِمِ', #3
u'المؤثمة': u'الْمُؤْثَمَةِ', #1
u'المؤثمة': u'الْمُؤَثِّمَةَ', #3
u'المؤثمة': u'الْمُؤَثِّمَةِ', #3
u'المؤثمة': u'الْمُؤْثِمَةُ', #4
u'المؤثمة': u'الْمُؤْثِمَةَ', #6
u'المؤثمة': u'الْمُؤَثِّمَةُ', #8
u'المؤثورات': u'الْمُؤْثُورَاتِ', #1
u'الموثوقي': u'الْمَوْثُوقِي', #1
u'الموجبية': u'الْمُوجَبِيَّةِ', #1
u'الموجبية': u'الْمُوجِبِيَّةِ', #2
u'الموجد': u'الْمُوجَدُ', #1
u'الموجد': u'الْمُوجَدِ', #1
u'الموجد': u'الْمُوجِدُ', #8
u'الموجد': u'الْمُوجِدِ', #9
u'الموجدين': u'الْمُوجِدِينَ', #2
u'الموجر': u'الْمُوجَرِ', #1
u'الموجر': u'الْمُوجِرُ', #1
u'الموجر': u'الْمُوجِرِ', #3
u'الموجرة': u'الْمُوجِرَةِ', #2
u'الموجف': u'الْمُوجَفِ', #1
u'الموجفين': u'الْمُوجِفِينَ', #1
u'الموجل': u'الْمَوْجَلُ', #1
u'الموجل': u'الْمَوْجَلِ', #1
u'الموجل': u'الْمَوْجَلَ', #2
u'الموجوء': u'الْمَوْجُوءَ', #1
u'الموجوب': u'الْمَوْجُوبُ', #1
u'المؤخره': u'الْمُؤَخَّرَهْ', #2
u'المؤدامة': u'الْمُؤَدَامَةِ', #2
u'المودك': u'الْمُوَدَّكُ', #1
u'المودن': u'المودن', #1
u'المودن': u'الْمُودَنُ', #1
u'المودني': u'الْمَوْدَنِيِّ', #1
u'المودود': u'الْمَوْدُودِ', #1
u'المودى': u'الْمُودَى', #1
u'المؤديها': u'الْمُؤَدِّيهَا', #1
u'المؤذني': u'الْمُؤَذِّنِيِّ', #1
u'المؤذى': u'الْمُؤْذَى', #3
u'المورخة': u'الْمُوَرَّخَةُ', #1
u'المورخة': u'الْمُوَرَّخَةِ', #2
u'المورس': u'الْمُوَرّسِ', #1
u'المورس': u'الْمُوَرَّسُ', #1
u'المورس': u'الْمُوَرَّسَ', #2
u'المورس': u'الْمُوَرَّسِ', #6
u'المورع،': u'المورع،', #1
u'المورع': u'الْمُوَرِّعُ', #1
u'المورع،': u'الْمُوَرِّعِ،', #13
u'المورع': u'الْمُوَرِّعِ', #18
u'المورقون': u'الْمُوَرِّقُونَ', #1
u'الموروثية': u'الْمَوْرُوثِيَّةِ', #1
u'المورود': u'الْمَوْرُودَ', #1
u'المورود': u'الْمَوْرُودُ', #6
u'المورود': u'الْمَوْرُودِ', #9
u'المورودة': u'الْمَوْرُودَةُ', #1
u'المورودة': u'الْمَوْرُودَةِ', #1
u'المورية': u'الْمُورِيَةِ', #1
u'المؤزر': u'المؤزر', #1
u'المؤزر': u'الْمُؤَزَّرُ', #1
u'الموسائى': u'الْمُوسَائِىُّ', #2
u'الموسطة': u'الْمُوَسَّطَةِ', #2
u'الموسق': u'الْمُوسَقُ', #1
u'الموسق': u'الْمُوَسَّقِ', #2
u'الموسقة': u'الْمُوسَقَةِ', #1
u'الموسوط': u'الْمَوْسُوطُ', #1
u'الموسوق': u'الْمَوْسُوقُ', #2
u'الموسوق': u'الْمَوْسُوقِ', #3
u'الموسوقات': u'الْمَوْسُوقَاتِ', #1
u'الموسوى': u'الْمُوسَوِىُّ', #3
u'المؤصلي': u'الْمُؤَصِّلِي', #1
u'الموصلى': u'الَمُوصِلِىُّ', #1
u'الموصلى': u'الْمَوْصِلِىُّ', #39
u'الموصليأن': u'الْمَوْصِلِيُّأَنَّ', #1
u'الموصوفية': u'الْمَوْصُوفِيَّةِ', #1
u'الموصولية': u'الْمَوْصُولِيَّةَ', #2
u'الموصولية': u'الْمَوْصُولِيَّةِ', #6
u'الموضأ': u'الْمُوَضَّأِ', #2
u'الموضعإلى': u'الْمَوْضِعُإِلَى', #1
u'الموضئ': u'الْمُوَضِّئِ', #4
u'الموطأعن': u'الْمُوَطَّأِعَنْ', #1
u'الموطوء': u'الْمَوْطُوءَ', #1
u'الموطوء': u'الْمَوْطُوءُ', #14
u'الموطوء': u'الْمَوْطُوءِ', #21
u'الموطوءة': u'الْمَوْطُوءَة', #1
u'الموطوءة': u'الْمَوْطُوءَةُ', #196
u'الموطوءة': u'الْمَوْطُوءَةِ', #466
u'الموطوءة': u'الْمَوْطُوءَةَ', #99
u'الموطوءتين': u'الْمَوْطُوءَتَيْنِ', #3
u'الموطوءين': u'الْمَوْطُوءَيْنِ', #1
u'الموطوآت': u'الْمَوْطُوآتُ', #6
u'الموطوآت': u'الْمَوْطُوآتِ', #9
u'الموظوفة': u'الْمَوْظُوفَةِ', #1
u'الموعب': u'الْمُوعَبُ', #1
u'الموعب': u'الْمُوعَبِ', #1
u'الموعب': u'الْمُوعِبِ', #2
u'الموعبة': u'الْمُوعِبَةِ', #3
u'الموعدا': u'المَوْعِدا', #1
u'الموعدا': u'الْمَوْعِدَا', #6
u'الموعدوه': u'الْمُوعِدُوهُ', #2
u'الموعظ': u'الْمُوعَظَ', #1
u'الموعى': u'الْمُوعَى', #1
u'الموغر': u'الموغر', #2
u'الموغر': u'الْمُوغِرُ', #2
u'الموغرون': u'الموغرون', #2
u'المؤف': u'الْمُؤَفُّ', #1
u'الموفقيات،': u'الْمُوَفَّقِيَّاتِ،', #1
u'الموفى': u'الْمُوفَى', #1
u'الموفى': u'الْمُوَفَّى', #2
u'المؤقتون': u'الْمُؤَقِّتُونَ', #1
u'الموقرى': u'الْمَوْقَرِىُّ', #1
u'الموقرى': u'الْمُوَقَّرِىِّ', #1
u'الموقود': u'الْمَوْقُودَ', #1
u'الموقودة': u'الْمَوْقُودَةِ', #1
u'الموقودة': u'الْمَوْقُودَةُ', #2
u'الموقوذة': u'الْمَوْقُوذَةَ', #13
u'الموقوذة': u'الْمَوْقُوذَةِ', #16
u'الموقوذة': u'الْمَوْقُوذَة', #2
u'الموقوذة': u'الْمَوْقُوذَةُ', #3
u'الموقوفية': u'الموقوفية', #2
u'الموقوقة': u'الْمُوَقْوِقَةِ', #1
u'الموقى': u'الْمُوقَى', #1
u'الموكأ': u'الْمُوكَأِ', #1
u'الموكدا': u'الْمُوَكّدَا', #2
u'الموكف': u'الْمُوكَفُ', #1
u'الموكف': u'الْمُوكَفِ', #1
u'الموكفة': u'الْمُوكَفَةِ', #4
u'الموكفه': u'الْمُوكَفَهْ', #1
u'الموكولة': u'الْمَوْكُولَةِ', #4
u'الموكى': u'الموكى', #1
u'الموكى': u'الْمُوكَى', #2
u'المولتان': u'الْمُولْتَانَ', #1
u'المولم': u'الْمُولِمِ', #2
u'المولم': u'الْمُولِمُ', #5
u'المولوج': u'الْمَوْلُوجِ', #1
u'المولوغ': u'الْمَوْلُوغُ', #4
u'المولوغ': u'الْمَوْلُوغِ', #4
u'المؤلي': u'الْمُؤْلِي', #17
u'المؤلى': u'الْمُؤْلَى', #5
u'المؤلى': u'الْمُؤْلِى', #6
u'الموم': u'الموم', #1
u'الموم': u'الْمُومِ', #1
u'الموم': u'الْمُومُ', #3
u'المؤملى': u'الْمُؤَمَّلِىِّ', #1
u'المؤملى': u'الْمُؤَمِّلِىُّ', #1
u'المؤملي': u'الْمُؤَمّلِيّ', #3
u'المؤملى': u'الْمُؤَمَّلِىُّ', #3
u'المؤمنأنه': u'الْمُؤْمِنِأَنَّهُ', #1
u'المؤمنوالوجه': u'الْمُؤْمِنِوَالْوَجْهُ', #1
u'المؤمنونوالوجه': u'الْمُؤْمِنُونَوَالْوَجْهُ', #2
u'المؤمنينا': u'الْمُؤْمِنِينَا', #4
u'المؤمنيناه': u'الْمُؤْمِنِينَاهُ', #1
u'المؤمنيناه،': u'الْمُؤْمِنِينَاهْ،', #1
u'المؤمنينوروي': u'الْمُؤْمِنِينَوَرُوِيَ', #1
u'المومي': u'الْمُومِي', #10
u'المومي': u'الْمُومِيَ', #2
u'المومى': u'الْمُومَى', #2
u'المومئ': u'الْمُومِئ', #1
u'المومئ': u'الْمُومِئَ', #18
u'المومئ': u'الْمُومِئُ', #18
u'المومئ': u'الْمُومِئِ', #37
u'المومئين': u'الْمُومِئِينَ', #1
u'الموميا': u'الْمُومْيَا', #2
u'المؤنات': u'الْمُؤْنَاتِ', #8
u'المؤنة': u'المؤنة', #1
u'المؤنة،': u'الْمُؤْنَةُ،', #1
u'المؤنة': u'الْمُؤْنَةَ', #152
u'المؤنة': u'الْمُؤْنَةُ', #168
u'المؤنة': u'الْمُؤْنَة', #5
u'المؤنة': u'الْمُؤْنَةِ', #526
u'المؤنتان': u'الْمُؤْنَتَانِ', #1
u'المؤنتين': u'الْمُؤْنَتَيْنِ', #3
u'الموهب': u'الْمُوهَبَ', #1
u'الموهب': u'الْمُوهَبُ', #1
u'الموهب': u'الْمُوهَبِ', #2
u'الموهب': u'الْمَوْهِبُ', #2
u'الموهب': u'الْمُوهِبُ', #5
u'الموهب': u'الْمُوهِبِ', #5
u'الموهج': u'الْمُوهَج', #1
u'الموهج': u'الْمُوَهّجِ', #1
u'الموهج': u'الْمُوهَجْ', #2
u'المؤودة': u'المؤودة', #1
u'الموؤدة': u'الْمَوْؤُدَةُ', #1
u'المؤوف': u'الْمَؤُوفِ', #1
u'المؤوفة': u'الْمَؤْوُفَةَ', #1
u'الموى': u'الموى', #1
u'الموئل': u'الْمَوْئِلُ', #1
u'المؤيدية': u'الْمُؤَيِّدِيَّةِ', #7
u'المويه': u'المويه', #1
u'المئرة': u'الْمِئْرَةُ', #1
u'المئشار': u'المئشار', #1
u'المئشار': u'الْمِئْشَارَ', #2
u'المئلات': u'الْمِئْلَاتُ', #1
u'المئنة': u'المئنة', #1
u'المئنة': u'الْمَئِنَّةَ', #1
u'المئنة': u'الْمِئِنَّةِ', #1
u'المئنة': u'الْمَئِنَّةِ', #22
u'المئون': u'الْمِئُونَ', #1
u'المئون': u'الْمِئُونُ', #1
u'المئونات': u'الْمَئُونَاتِ', #2
u'المئونة': u'الْمَئُونَةَ', #18
u'المئونة': u'الْمَئُونَةِ', #26
u'المئونة': u'الْمَئُونَةُ', #7
u'المياثر': u'الْمَيَاثِرِ', #17
u'المياثر': u'المياثر', #2
u'المياثر،': u'الْمَيَاثِرِ،', #2
u'المياثر': u'الْمَيَاثِر', #3
u'المياثر': u'الْمَيَاثِرُ', #8
u'الميارة': u'الْمَيَّارَةِ', #1
u'الميازب': u'الْمَيَازِبِ', #1
u'الميازر': u'الْمَيَازِرِ', #3
u'المياقي': u'الْمَيَاقِي', #3
u'المياميس': u'الْمَيامِيسَ', #1
u'المياميس': u'الْمَيامِيسُ', #1
u'المياميس': u'الْمَيامِيسِ', #2
u'الميان': u'الْمَيَّانِ', #1
u'الميانجي': u'الْمَيَانَجِيُّ', #1
u'الميانجي': u'الْمَيَانَجِيِّ', #1
u'الميانديهية': u'الميانديهية', #1
u'الميبة': u'الميبة', #2
u'الميتاء': u'الْمِيتَاءَ', #1
u'الميتاء': u'الْمِيْتَاءُ', #1
u'الميتاء': u'الْمِيتَاءِ', #11
u'الميتاء': u'الْمِيتَاءُ', #7
u'الميث': u'الْمَيِّثِ', #1
u'الميثب': u'الْمِيثَبُ', #1
u'الميثرة': u'الْمِيثَرَة', #1
u'الميثرة،': u'الْمِيثَرَةِ،', #1
u'الميثرة': u'الْمِيثَرَةِ', #13
u'الميثرة': u'الْمِيثَرَةَ', #2
u'الميثرة': u'الميثرة', #4
u'الميثرة': u'الْمِيثَرَةُ', #8
u'الميثم': u'الْمِيثَمِ', #1
u'الميجرة': u'الْمِيجَرَةُ', #1
u'الميجرة': u'الْمِيجَرَةِ', #1
u'الميدانى': u'الْمَيْدَانِىُّ', #1
u'الميدومي': u'الْمَيْدُومِيُّ', #7
u'المير': u'الْمَيْرَ', #1
u'المير': u'الْمَيْرُ', #1
u'المير': u'الْمَيْرِ', #1
u'الميرة': u'الْمَيْرَةَ', #1
u'الميرة': u'الْمِيَرَةَ', #1
u'الميرة': u'الْمِيرَةَ', #11
u'الميرة': u'الْمِيرَةِ', #22
u'الميرة': u'الميرة', #3
u'الميرة': u'الْمِيرَةُ', #4
u'الميرتلي': u'المِيرَتُلِيُّ', #1
u'الميرزي': u'الْمَيْرَزِيُّ', #1
u'الميرى': u'الْمِيرَى', #1
u'الميري': u'الْمِيرِيّ', #2
u'الميري': u'الْمِيرِيِّ', #4
u'الميرية': u'الْمِيرِيَّةَ', #1
u'الميرية': u'الْمِيرِيَّةُ', #2
u'الميرية': u'الْمِيرِيَّةِ', #2
u'الميسرالوجه': u'الْمَيْسِرِالْوَجْهُ', #1
u'الميشار': u'الْمِيشَارُ', #1
u'الميض': u'الْمِيَضِ', #3
u'الميضاءات': u'الْمِيضَاءَاتِ', #4
u'الميضأة': u'الْمِيضَأَةُ', #1
u'الميضأة': u'الْمَيْضَأَةَ', #1
u'الميضأة': u'الْمِيضَأَةِ', #24
u'الميضأة': u'الْمَيْضَأَةِ', #3
u'الميضأة': u'الْمِيضَأَةَ', #6
u'الميضآت': u'الْمَيْضَآتِ', #1
u'الميضة': u'الْمَيْضَةِ', #1
u'الميطار': u'الْمِيطَارَ', #1
u'الميعان': u'الْمَيَعَانِ', #1
u'الميفعة': u'الْمَيْفَعَةُ', #1
u'الميفعة': u'الْمَيْفَعَةِ', #2
u'الميقدة': u'الْمِيقَدَةُ', #1
u'الميلتين': u'الْمَيْلَتَيْنِ', #2
u'الميلق': u'الْمَيْلَقِ', #1
u'الميموني': u'المَيْمُونِيُّ', #1
u'الميموني،': u'الْمَيْمُونِيّ،', #1
u'الميموني': u'الْمَيْمُونِيِّ', #106
u'الميمونى': u'الْمَيْمُونِىُّ', #13
u'الميموني،': u'الْمَيْمُونِيِّ،', #14
u'الميموني': u'الْمَيْمُونِيُّ', #179
u'الميموني،': u'المَيْمُونِيُّ،', #5
u'الميموني،': u'الْمَيْمُونِيُّ،', #51
u'المينحي': u'الْمِينَحِيُّ', #2
u'الميهني': u'الْمِيهَنِيِّ', #1
u'الميولات': u'الْمُيُولَاتِ', #6
u'الميئوس': u'الْمَيْئُوسَ', #1
u'الميئوس': u'الْمَيْئُوسِ', #21
u'الميئوس': u'الْمَيْئُوسُ', #4
u'الميئوسة': u'الْمَيْئُوسَةُ', #1
u'الن': u'النّ', #3
u'النا': u'النّا', #5
u'النابلسى': u'الْنَابُلْسِىُّ', #1
u'الناجش': u'النَّاجِشُ', #12
u'الناجش': u'النَّاجِشَ', #3
u'الناجش': u'النَّاجِشِ', #3
u'الناجى': u'النَّاجِى', #1
u'الناجى': u'النَّاجِىَّ', #1
u'الناجى': u'النَّاجِىِّ', #18
u'الناجى': u'النَّاجِىُّ', #5
u'الناد': u'النَّادَّ', #1
u'الناد': u'النَّادِ', #2
u'الناد': u'النَّادِّ', #21
u'الناد': u'النَّادُّ', #7
u'النادة': u'النَّادَّةَ', #1
u'النادرون': u'النَّادِرُونَ', #1
u'النادق': u'النَّادِقِ', #1
u'النادقة': u'النَّادِقَةُ', #1
u'النادى': u'النادى', #1
u'النادى': u'النَّادِى', #4
u'النارا': u'النَّارَا', #1
u'النارجيل': u'النَّارْجِيلُ', #1
u'النارجيل': u'النَّارْجِيلِ', #3
u'النارقال': u'النَّارَقَالَ', #1
u'النارقال': u'النَّارِقَالَ', #1
u'الناركذلك': u'النَّارُكَذَلِكَ', #1
u'النارموسى': u'النَّارَمُوسِىُّ', #1
u'النارنج': u'النَّارَنْجِ', #1
u'النارنج': u'النَّارِنْجَ', #1
u'النارنج': u'النَّارِنْجُ', #3
u'النارنج': u'النَّارِنْجِ', #9
u'الناروالسياق': u'النَّارِوَالسِّيَاقُ', #1
u'الناروروي': u'النَّارِوَرُوِيَ', #1
u'الناز': u'النَّازِّ', #1
u'الناسا': u'النَّاسَا', #1
u'الناسالأكل': u'النَّاسِالْأَكْلُ', #1
u'الناسالوجه': u'النَّاسِالْوَجْهُ', #1
u'الناسإن': u'النَّاسُإِنَّ', #1
u'الناسة': u'النّاسّةُ', #1
u'الناسة': u'النّاسّةَ', #2
u'الناسة': u'النَّاسَّةُ', #2
u'الناسخية': u'النَّاسِخِيَّةُ', #1
u'الناسفخفت': u'النَّاسِفَخِفْتُ', #1
u'الناسقال': u'النَّاسِقَالَ', #2
u'الناسقوله': u'النَّاسِقَوْلُهُ', #1
u'الناسوالوجه': u'النَّاسَوَالْوَجْهُ', #1
u'الناسوت': u'النَّاسُوتِ', #1
u'الناسوتية': u'النَّاسُوتِيَّةُ', #1
u'الناسوتية': u'النَّاسُوتِيَّةِ', #1
u'الناسور': u'النَّاسُورَ', #1
u'الناسوروى': u'النَّاسِوَرُوِِىِ', #1
u'الناسولم': u'النَّاسِوَلَمْ', #1
u'الناسومة': u'النَّاسُومَةُ', #1
u'الناسى': u'النَّاسِى', #3
u'الناشيء': u'النَّاشِيء', #1
u'الناصروالوجه': u'النَّاصِرُوَالْوَجْهُ', #1
u'الناصور': u'النَّاصُورَ', #1
u'الناصور': u'النَّاصُورِ', #2
u'الناصور': u'النَّاصُورُ', #3
u'الناض': u'النَّاضِّ', #56
u'الناض': u'النَّاضَّ', #7
u'الناض': u'النَّاضُّ', #7
u'الناضة': u'النَّاضَّةُ', #2
u'الناضة': u'النَّاضَّةِ', #2
u'الناضة': u'النَّاضَّةَ', #4
u'الناضحي': u'النَّاضِحِيُّ', #1
u'الناطفي': u'النَّاطِفِيُّ', #152
u'الناطفي': u'النَّاطِفِيَّ', #2
u'الناطفي': u'النَّاطِفِي', #6
u'الناطفي': u'النَّاطِفِيِّ', #96
u'الناطفية': u'النَّاطِفِيَّةِ', #2
u'الناطقية': u'النَّاطِقِيَّةِ', #4
u'الناظرينا': u'النّاظِرِينَا', #2
u'الناعوس': u'الناعوس', #1
u'الناعى': u'النَّاعِى', #1
u'النافة': u'النَّافَّةُ', #1
u'النافثيا': u'النّافِثَيْا', #1
u'النافج': u'النَّافِجُ', #1
u'النافجة': u'النَّافِجَةَ', #8
u'النافذه': u'النَّافِذَهْ', #1
u'النافعه': u'النَّافِعَهْ', #1
u'النافقاء': u'النّافِقَاءِ', #1
u'النافقاء': u'النَّافِقَاءَ', #1
u'النافقاء': u'النَّافِقَاءُ', #1
u'النافقاء': u'النَّافِقَاءِ', #4
u'النافلةهل': u'النَّافِلَةِهَلْ', #1
u'النافى': u'النَّافِى', #2
u'الناقضه': u'النَّاقِضَهْ', #1
u'الناقضية': u'النَّاقِضِيَّةِ', #2
u'النامصة': u'النَّامِصَةَ', #2
u'النامصة': u'النَّامِصَةُ', #5
u'النامصة': u'النَّامِصَةِ', #5
u'الناموسة': u'النَّامُوسَةِ', #1
u'الناهى': u'النَّاهِىَ', #1
u'الناوق': u'الناوق', #1
u'الناوقات': u'النَّاوِقَاتُ', #1
u'الناووس': u'النَّاوُوسَ', #1
u'النائتان': u'النَّائِتَانِ', #1
u'النائرات': u'النَّائِرَاتِ', #1
u'النائرة': u'النَّائِرَةُ', #1
u'النائرة': u'النَّائِرَةَ', #3
u'النائرة': u'النَّائِرَةِ', #9
u'النائم': u'النَّائِمً', #1
u'النبا': u'النَّبَا', #2
u'النبآء': u'النّبَآءِ', #1
u'النباء': u'النّبَاءِ', #1
u'النباج': u'النِّبَاجِ', #1
u'النباذ': u'النِّبَاذِ', #3
u'النباع': u'النَّبَّاعِ', #1
u'النباع،': u'النِّبَاعِ،', #1
u'النباوة': u'النَّبَاوَةِ', #1
u'النبائث': u'النّبَائِثِ', #1
u'النبتيتي': u'النَّبِتِيتِيُّ', #1
u'النبتيتي': u'النَّبْتِيتِيُّ', #1
u'النبلا': u'النّبْلَا', #2
u'النبها': u'النُّبَهَا', #1
u'النبهاني': u'النّبْهَانِيّ', #1
u'النبهرج': u'النَّبَهْرَجُ', #3
u'النبهرجة': u'النَّبَهْرَجَةَ', #12
u'النبهرجة': u'النَّبَهْرَجَةُ', #12
u'النبهرجة': u'النَّبَهْرَجَةِ', #24
u'النبوةوالوجه': u'النُّبُوَّةَوَالْوَجْهُ', #1
u'النبوةوالوجه': u'النُّبُوَّةُوَالْوَجْهُ', #1
u'النبى،': u'النبى،', #1
u'النبى': u'النَّبِىَ', #1
u'النبى': u'النِّبِىِّ', #2
u'النبى': u'النَّبِىُّ', #2217
u'النبى': u'النَّبِىَّ', #2742
u'النبى': u'النَّبِىِّ', #4911
u'النبى': u'النبى', #8
u'النبيء': u'النَّبِيءَ', #1
u'النبيء': u'النَّبِيءِ', #1
u'النبيء': u'النَّبِيءُ', #3
u'النبيا': u'النَّبِيَّا', #1
u'النبىالله': u'النَّبِىُّاللَّهِ', #1
u'النبيب': u'النّبِيبِ', #1
u'النبيب': u'النبيب', #4
u'النبيت': u'النَّبِيتُ', #1
u'النبيت': u'النّبِيتِ', #12
u'النبيت': u'النبيت', #2
u'النبيت': u'النّبَيْتِ', #2
u'النبيت': u'النّبِيت', #3
u'النبيت': u'النّبِيتُ', #3
u'النبيت': u'النَّبِيتِ', #7
u'النبيط': u'النَّبِيط', #1
u'النبيط': u'النّبِيطُ', #2
u'النبيط': u'النّبَيْطِ', #2
u'النتء': u'النَّتْءُ', #1
u'النتل': u'النّتْلِ', #1
u'النتنى': u'النّتْنَى', #1
u'النتنى': u'النَّتْنَى', #7
u'النتوج': u'النَتُوجِ', #1
u'النتوج': u'النَّتُوجِ', #1
u'النثا': u'النّثَا', #2
u'النثره': u'النّثِره', #2
u'النثير': u'النَّثِيرِ', #2
u'النجا': u'النَّجَا', #8
u'النجاب': u'النَّجّاب', #1
u'النجاب': u'النِّجَابُ', #1
u'النجاتية': u'النَّجَاتِيَّةِ', #1
u'النجاحى': u'النَّجَاحِىُّ', #1
u'النجاس': u'النَّجَاسِ', #1
u'النجاسه': u'النَّجَاسَهْ', #1
u'النجاشى': u'النَّجَاشِىُّ', #10
u'النجاشى': u'النَّجَاشِى', #3
u'النجاشى': u'النَّجَاشِىِّ', #32
u'النجاشى': u'النَّجَاشِىَ', #4
u'النجاشى': u'النَّجَاشِىَّ', #7
u'النجام': u'النَّجَّامِ', #1
u'النجام': u'النّجّامِ', #2
u'النجج': u'النَّجَجُ', #1
u'النجح': u'النَّجْح', #1
u'النجح': u'النَّجْحِ', #2
u'النجح': u'النُّجْحُ', #2
u'النجح': u'النُّجْحِ', #6
u'النجحين': u'النَّجَحَيْنِ', #1
u'النجراني': u'النجراني', #1
u'النجرانى': u'النَّجْرَانِىِّ', #1
u'النجراني،': u'النَّجْرَانِيِّ،', #2
u'النجراني': u'النَّجْرَانِيُّ', #3
u'النجراني': u'النَّجْرَانِيِّ', #7
u'النجرانية': u'النَّجْرَانِيَّةَ', #1
u'النجرانية': u'الْنَجْرَانِيَّةِ', #1
u'النجرة': u'النّجِرَةِ', #1
u'النجره': u'النّجَره', #1
u'النجره': u'النّجَرَهْ', #1
u'النجش': u'النَّجَشَ', #1
u'النجش': u'النَّجَشُ', #1
u'النجش،': u'النَّجْشِ،', #1
u'النجش': u'النَّجْشَ', #13
u'النجش': u'النجش', #2
u'النجش': u'النَّجَشِ', #2
u'النجش': u'النَّجْش', #2
u'النجش،': u'النَّجَشِ،', #4
u'النجش': u'النَّجْشُ', #43
u'النجش': u'النَّجْشِ', #95
u'النجلا': u'النّجْلَا', #2
u'النجوري': u'النَّجُورِيُّ', #1
u'النجوسي': u'النَّجُوسِيُّ', #2
u'النجيح': u'النَّجِيحِ', #1
u'النجيحة': u'النَّجِيحَةِ', #1
u'النجير،': u'النُّجَيْرِ،', #1
u'النجير': u'النجير', #2
u'النجير': u'النُّجَيْرُ', #2
u'النجير': u'النّجَيْرِ', #4
u'النجير': u'النُّجَيْرَ', #4
u'النجير': u'النُّجَيْرِ', #4
u'النجيرمي': u'النَّجِيرَمِيُّ', #1
u'النجيم': u'النُّجَيْمِ', #2
u'النحاد': u'النّحَادِ', #1
u'النحاز': u'النَّحَّازِ', #1
u'النحاسين': u'النُّحَاسَيْنِ', #1
u'النحاسين': u'النَّحَّاسِينَ', #3
u'النحاط': u'النّحّاط', #1
u'النحاط': u'النّحّاطِ', #7
u'النحرارية': u'النَّحْرَارِيَّةِ', #1
u'النحرونحو': u'النَّحْرِوَنَحْوِ', #1
u'النحريري': u'النِّحْرِيرِيُّ', #1
u'النحريري': u'النِّحْرِيرِيِّ', #1
u'النحز': u'النّحْزُ', #2
u'النحض': u'النّحْضِ', #2
u'النحطة': u'النّحْطَةُ', #1
u'النحوى': u'النَّحَوِىُّ', #1
u'النحوى': u'النُّحَوِىِّ', #1
u'النحوى': u'النَّحْوِىِّ', #19
u'النحوى': u'النَّحْوِىُّ', #30
u'النحيبا': u'النَّحِيبَا', #1
u'النحيين': u'النِّحيَيْن', #1
u'النحيين': u'النّحْيَيْنِ', #2
u'النحيين': u'النَّحْيَيْنِ', #2
u'النخام': u'النُّخَامَ', #1
u'النخام،': u'النَّخَّامِ،', #1
u'النخاورة': u'النّخَاوِرَةُ', #1
u'النخة': u'النَّخَّةُ', #1
u'النخة': u'النُّخَّةَ', #1
u'النخة': u'النَّخَّةِ', #2
u'النخة': u'النُّخَّةُ', #5
u'النخة': u'النُّخَّةِ', #5
u'النخجواني': u'النَّخْجَوانِيُّ', #1
u'النخشبي': u'النَّخْشَبِيُّ', #3
u'النخشبي': u'النَّخْشَبِيِّ', #3
u'النخعي': u'النَّخعِيّ', #1
u'النخعي': u'النَّخَعيّ', #1
u'النخعي': u'النَّخْعيّ', #1
u'النخعي،': u'النَّخَعيّ،', #1
u'النخعي،': u'النَّخَعيُّ،', #1
u'النخعي،': u'النَّخْعي،', #1
u'النخعي،': u'النَّخْعيّ،', #1
u'النخعي': u'النّخَعِيّ', #1
u'النخعي': u'النَّخْعِيُّ', #1
u'النخعي،': u'النّخَعِيُّ،', #1
u'النخعي،': u'النَّخْعِيَّ،', #1
u'النخعي،': u'النخعي،', #10
u'النخعي،': u'النَّخْعِيِّ،', #10
u'النخعى': u'النَّخَعِىَّ', #11
u'النخعي،': u'النَّخْعِيُّ،', #2
u'النخعي': u'النَّخَعِيِّ', #258
u'النخعي': u'النَّخَعِيُّ', #266
u'النخعي': u'النَّخَعِيّ', #275
u'النخعي': u'النَّخْعِيِّ', #3
u'النخعي،': u'النَّخَعِيّ،', #3
u'النخعي،': u'النَّخَعِيُّ،', #32
u'النخعى': u'النَّخَعِىُّ', #36
u'النخعي': u'النخعي', #5
u'النخعي،': u'النَّخَعِيِّ،', #56
u'النخعي': u'النَّخَعِيَّ', #7
u'النخعى': u'النَّخَعِىِّ', #88
u'النخعيون': u'النَّخَعِيُّونَ', #1
u'النخغى': u'النَّخَغِىُّ', #1
u'النخماس': u'النّخْمَاس', #1
u'النخيرجان': u'النَّخِيرْجَانْ', #1
u'النخيلة،': u'النخيلة،', #1
u'النخيلة': u'النُّخَيْلَةُ', #1
u'الندا': u'النّدَا', #2
u'الندا': u'النِّدَا', #2
u'الندا': u'النَّدَا', #3
u'النداءوالإقامة': u'النِّدَاءِوَالْإِقَامَةِ', #1
u'النداد': u'النِّدَادُ', #1
u'النداما': u'النَّدَامَا', #1
u'الندائين،': u'النِّدَائَينِ،', #1
u'الندائين': u'النِّدَائَيْنِ', #1
u'الندبى': u'النَّدَبِىُّ', #1
u'الندح': u'النّدْحِ', #2
u'ألندد': u'أَلَنْدَد', #2
u'الندر': u'الندر', #1
u'الندر،': u'النُّدَّرِ،', #1
u'الندر': u'النُّدَّرِ', #6
u'النده': u'النَّدْهِ', #2
u'النذرا': u'النَّذْرَا', #1
u'النذلا': u'النَّذْلَا', #1
u'النردشير': u'النَّرْدَشِيرِ', #1
u'النردشير': u'النَّرْدَشِيرَ', #3
u'النردشير': u'النَّرْدَشِيرُ', #7
u'النرسي': u'النَّرْسِيَّ', #1
u'النرسى،': u'النرسى،', #1
u'النرسي': u'النرسي', #2
u'النرسي،': u'النرسي،', #2
u'النرسى': u'النَّرْسِىُّ', #38
u'النرسي،': u'النَّرْسِيِّ،', #4
u'النرسى': u'النَّرْسِىِّ', #4
u'النرسي': u'النَّرْسِيُّ', #43
u'النرسي،': u'النَّرْسِيُّ،', #89
u'النزار': u'النّزَارِ', #14
u'النزارية': u'النِّزَارِيَّةُ', #1
u'النسأ': u'النَّسَأَ', #1
u'النسأ': u'النُّسَأِ', #1
u'النسإ': u'النَّسَإِ', #1
u'النسإ': u'النَّسْإِ', #1
u'النسأ': u'النَّسَأِ', #2
u'النسأ': u'النَّسَأُ', #6
u'النساءالوجه': u'النِّسَاءِالْوَجْهُ', #1
u'النساءأي': u'النِّسَاءِأَيْ', #1
u'النساءوروي': u'النِّسَاءُوَرُوِيَ', #1
u'النساءوروي': u'النِّسَاءِوَرُوِيَ', #1
u'النساءوهو': u'النِّسَاءِوَهُوَ', #1
u'النساخة': u'النِّسَاخَةِ', #5
u'النساخين': u'النَّسَّاخِينَ', #1
u'النساسة': u'النَّسَّاسَةَ', #1
u'النسالة': u'النَّسَالَةِ', #1
u'النسالة': u'النُّسَالَةِ', #2
u'النسائى': u'النَّسَائِىَّ', #1
u'النسائى': u'النَّسَائِىِّ', #2
u'النسائى': u'النَّسَائِىُّ', #22
u'النسخاء': u'النَّسْخَاءُ', #1
u'النسطورية،': u'النسطورية،', #1
u'النسطورية': u'النَّسْطُورِيَّةُ', #1
u'النسعة': u'النِّسْعَة', #1
u'النسعة': u'النِّسْعَةُ', #1
u'النسعة،': u'النِّسْعَةُ،', #1
u'النسعة': u'النسعة', #2
u'النسعة': u'النِّسْعَةِ', #6
u'النسو': u'النّسُو', #2
u'النسوائي': u'النَّسَوَائِيِّ', #1
u'النسوخ': u'النُّسُوخِ', #1
u'النسوه': u'النِّسْوَهْ', #2
u'النسوى': u'النَّسَوِىَّ', #1
u'النسوى': u'النَّسَوِىُّ', #53
u'النسىء': u'النَّسِىءَ', #1
u'النسيء': u'النّسِيءِ', #2
u'النسيء': u'النَّسِيءَ', #2
u'النسيء': u'النَّسِيءُ', #30
u'النسيء': u'النّسِيءَ', #4
u'النسيء': u'النّسِيءُ', #6
u'النسىء': u'النَّسِىءُ', #6
u'النسيء': u'النَّسِيءِ', #9
u'النسيايين': u'النسيايين', #1
u'النسيبة': u'النَّسِيبَةُ', #3
u'النسيبة': u'النَّسِيبَةِ', #6
u'النسيخ': u'النَّسِيخِ', #1
u'النسيئ': u'النَّسِيئِ', #1
u'النشاة': u'النَّشَاةِ', #1
u'النشارون': u'النَّشَّارُونَ', #1
u'النشاستج': u'النَّشَاسْتَجُ', #1
u'النشاستج': u'النَّشَاسْتَجِ', #1
u'النشاستجه': u'النَّشَاسْتَجَهْ', #1
u'النشائي،': u'النِّشَائِيُّ،', #1
u'النشائي': u'النَّشَائِيَّ', #3
u'النشائي': u'النَّشَائِيُّ', #50
u'النشائي': u'النَّشَائِيِّ', #6
u'النشدات': u'النَّشَدَاتِ', #1
u'النشدات': u'النِّشْدَاتِ', #2
u'النشرا': u'النَّشْرَا', #1
u'النشرتي': u'النَّشَرْتِيُّ', #1
u'النشيجا': u'النَّشِيجَا', #1
u'النشيجا': u'النّشِيجَا', #2
u'النشيطي،': u'النَّشِيطِي،', #2
u'النشيطي،': u'النَّشِيطِيُّ،', #3
u'النشيطي': u'النُّشَيْطِيُّ', #3
u'النشيلي': u'النَّشِيلِيُّ', #2
u'النشيلي': u'النَّشِيلَيْ', #3
u'النصاري،': u'النصاري،', #2
u'النصاري': u'النَّصَارَي', #2
u'النصاري': u'النَّصَّارِي', #3
u'النصافي': u'النَّصَافِي', #1
u'النصافي': u'النَّصَّافِي', #1
u'النصرآباذي': u'النصرآباذي', #1
u'النصرآباذي': u'النَّصْرَآبَاذِيُّ', #1
u'النصراباذي': u'النَّصْرَابَاذِيِّ', #1
u'النصراباذى': u'النَّصْرَابَاذِىُّ', #1
u'النصراباذي': u'النَّصْرَابَاذِيُّ', #2
u'النصرآباذى': u'النَّصْرَآبَاذِىُّ', #3
u'النصرانى': u'النَّصْرَانِىَّ', #2
u'النصرانى': u'النَّصْرَانِىِّ', #4
u'النصرانى': u'النَّصْرَانِىُّ', #6
u'النصرى': u'النَّصْرِىَّ', #1
u'النصرى': u'النَّصْرِىُّ', #2
u'النصرى': u'النَّصْرِىِّ', #7
u'النصريه': u'النَّصْرِيَّهْ', #1
u'النصفا': u'النِّصْفَا', #1
u'النصور': u'النّصُورَ', #1
u'النصور': u'النُّصُورُ', #1
u'النصور': u'النّصُورُ', #4
u'النصيبا': u'النَّصِيباً', #1
u'النصيبى': u'النَّصِيبِىُّ', #12
u'النصيري': u'النُّصَيْرِيَّ', #1
u'النصيري': u'النُّصَيْرِيُّ', #1
u'النصيرية': u'النُّصَيْرِيَّةُ', #1
u'النصيرية': u'النُّصَيْرِيَّةِ', #1
u'النضاج': u'النِّضَاجَ', #1
u'النضرهاشم': u'النَّضْرِهَاشِمُ', #1
u'النضروى': u'النَّضْرَوىُّ', #1
u'النضروى': u'النَّضْرُوِىُّ', #10
u'النضروى': u'النَّضْرَوِىُّ', #95
u'النضوض': u'النَّضُوضَ', #1
u'النضوض': u'النَّضُوضِ', #15
u'النضوض': u'النُّضُوضِ', #7
u'النضوض': u'النَّضُوضُ', #8
u'النضى': u'النضى', #1
u'النضى': u'النَّضِىِّ', #1
u'النضيج': u'النضيج', #1
u'النضيج': u'النَّضِيجِ', #2
u'النضيري': u'النّضِيرِيّ', #1
u'النضيري': u'النَّضِيرِيِّ', #1
u'النضيري': u'النَّضِيرِيُّ', #2
u'النط': u'النَّطُّ', #1
u'النطاة': u'النَّطَاةُ', #1
u'النطاة': u'النَّطَاةِ', #2
u'النطاة': u'النّطَاةَ', #4
u'النطاة': u'النّطَاةِ', #44
u'النطالة': u'النَّطَّالَةُ', #2
u'النطانط': u'النّطَانِطِ', #1
u'النطة': u'النَّطَّةُ', #1
u'النطرون': u'النَّطْرُونُ', #2
u'النطرون': u'النَّطْرُونِ', #5
u'النطروني': u'النَّطْرُونِيُّ', #8
u'النطقاء': u'النُّطَقَاءُ', #1
u'النطقاء': u'النُّطَقَاءِ', #1
u'النطوح': u'النَّطُوحَ', #1
u'النطوح': u'النَّطُوحِ', #14
u'النظارين': u'النَّظَّارِينَ', #2
u'النظرا': u'النَّظَرَا', #2
u'النظره': u'النَّظْرَهْ', #2
u'النظمين': u'النَّظْمَيْنِ', #1
u'النظيرية': u'النَّظِيرِيَّةِ', #3
u'النعا': u'النّعَا', #1
u'النعار': u'النَّعَّار', #1
u'النعالات': u'النِّعَالَاتِ', #2
u'النعالي': u'النِّعَالِيُّ', #1
u'النعاموالوجه': u'النَّعَامِوَالْوَجْهُ', #1
u'النعف': u'النَّعْفُ', #1
u'النعف': u'النَّعْفِ', #1
u'النعف': u'النّعْفِ', #4
u'النعلا': u'النَّعْلَا', #1
u'النعمام': u'النّعْمَامِ', #1
u'النعمانى': u'النُّعْمَانِىُّ', #4
u'النعوس': u'النّعُوسَ', #2
u'النعوش': u'النُّعُوشُ', #2
u'النعوش': u'النُّعُوشِ', #2
u'النعوف': u'النُّعُوفِ', #1
u'النعى': u'النَّعْىَ', #1
u'النعى': u'النَّعْىِ', #1
u'النغاشي': u'النُّغَاشِيُّ', #1
u'النغام': u'النِّغَامِ', #1
u'النغرة': u'النُّغَرَةَ', #1
u'النغض': u'النغض', #2
u'النغف،': u'النغف،', #1
u'النغف': u'النغف', #2
u'النغف': u'النَّغَفَ', #2
u'النغف': u'النَّغَفُ', #2
u'النغف': u'النَّغَفِ', #3
u'النغفة': u'النغفة', #1
u'النغفة،': u'النَّغْفَةِ،', #1
u'النفات': u'النُّفَاتِ', #2
u'النفاخان': u'النَّفَّاخَانِ', #2
u'النفاقتقدم': u'النِّفَاقُتَقَدَّمَ', #1
u'النفة': u'النَّفَّةِ', #1
u'النفراوي': u'النَّفْرَاوِيِّ', #13
u'النفراوي': u'النَّفْرَاوِيُّ', #38
u'النفريت': u'النِّفْرِيتُ', #1
u'النفساءين': u'النُّفَسَاءَيْنِ', #1
u'النفسوي': u'النّفْسُوِيّ', #1
u'النفسير': u'النَّفسِيرِ', #1
u'النفعان': u'النَّفْعَانِ', #2
u'النفعين': u'النَّفْعَيْنِ', #1
u'النفقه،': u'النفقه،', #1
u'النفقه': u'النَّفَقَهْ', #3
u'النفلة': u'النَّفْلَةِ', #1
u'النفود': u'النفود', #1
u'النفوسي': u'النّفُوسِيّ', #1
u'النفى': u'النَّفْىَ', #1
u'النفى': u'النَّفْىُ', #1
u'النفى': u'النَّفْىِ', #1
u'النفيلي': u'النفيلي', #1
u'النفيلي': u'النّفَيْلِيّ', #1
u'النفيلي': u'النُّفَيْلِي', #1
u'النفيلي،': u'النُّفَيْلِي،', #1
u'النفيلي،': u'النُّفَيْلِيُّ،', #136
u'النفيلي،': u'النُّفَيْلِيِّ،', #15
u'النفيلي': u'النُّفَيْلِيُّ', #44
u'النفيلي،': u'النفيلي،', #6
u'النفيلي': u'النُّفَيْلِيِّ', #6
u'النفيلى': u'النُّفَيْلِىِّ', #6
u'النفيلى': u'النُّفَيْلِىُّ', #69
u'النقاف': u'النَّقَافُ', #1
u'النقاف': u'النِّقَافُ', #1
u'النقاف': u'النِّقَافِ', #2
u'النقاية': u'النُّقَايَةِ', #294
u'النقث': u'النقث', #2
u'النقرى': u'النَّقْرَى', #1
u'النقرى': u'النَّقَرَى', #3
u'النقريزي،': u'النَّقْرِيزِيُّ،', #1
u'النقشبندي': u'النَّقْشَبَنْدِيِّ', #6
u'النقشبندية': u'النَّقْشَبَنْدِيَّةِ', #1
u'النقشواني': u'النقشواني', #1
u'النقشواني': u'النَّقْشَوَانِيَّ', #1
u'النقشواني': u'النَّقْشَوَانِيِّ', #1
u'النقشواني': u'النَّقْشَوَانِيُّ', #19
u'النقصين': u'النَّقْصَيْنِ', #2
u'النقضا': u'النَّقْضَا', #1
u'النقعSتفسير': u'النّقْعُSتَفْسِيرُ', #1
u'النقمى': u'النَّقَمَى', #3
u'النقوذ': u'النُّقُوذُ', #2
u'النقور': u'النَّقُورِ', #1
u'النقور': u'النَّقُّورِ', #1
u'النقى': u'النقى', #1
u'النقى': u'النَّقِىِّ', #1
u'النقى': u'النَّقَى', #2
u'النقيلة': u'النَّقِيلَةِ', #1
u'النكبا': u'النّكْبَا', #2
u'النكباء': u'النَّكْبَاءُ', #1
u'النكباء': u'النَّكْبَاءَ', #2
u'النكباء': u'النّكْبَاءُ', #3
u'النكرى': u'النُّكْرِىُّ', #1
u'النكرى': u'النُّكْرِىِّ', #1
u'النكرى': u'النُّكَرِىُّ', #2
u'النكريش': u'النكريش', #1
u'النكهه': u'النَّكْهَهْ', #1
u'النكوث': u'النُّكُوثِ', #3
u'النكولا': u'النُّكُولَا', #2
u'النما': u'النَّمَا', #2
u'النمار': u'النمار', #1
u'النمار': u'النِّمَار', #1
u'النمار،': u'النِّمَارِ،', #1
u'النمار': u'النِّمَارِ', #20
u'النمار': u'النِّمَارُ', #3
u'النمار': u'النِّمَارَ', #5
u'النماص': u'النِّمَاص', #1
u'النماوي': u'النَّمَاوِيُّ', #1
u'النمرقة': u'النمرقة', #1
u'النمرقة؟': u'النُّمْرُقَةِ؟', #1
u'النمرقة': u'النُّمْرُقَةِ', #15
u'النمرود': u'النّمْرُودُ', #1
u'النمرود': u'النُّمْرُودَ', #1
u'النمرود': u'النُّمْرُودُ', #3
u'النمرود': u'النُّمْرُودِ', #3
u'النمروذ': u'النّمْرُوذِ', #1
u'النمروذ': u'النمروذ', #2
u'النمرى': u'النَّمَرِىُّ', #4
u'النمريجات': u'النمريجات', #1
u'النمص': u'النَّمَصَ', #1
u'النمص': u'النَّمَصُ', #1
u'النمص': u'النَّمْص', #1
u'النمص': u'النَّمْصُ', #1
u'النمص': u'النَّمْصَ', #3
u'النمص': u'النَّمْصِ', #3
u'النميري': u'النميري', #1
u'النميري': u'النّمَيْرِيّ', #1
u'النميري': u'الْنُمَيْرِيِّ', #1
u'النميرى': u'النُّمَيْرِىِّ', #1
u'النميري': u'النُّمَيْرِيُّ', #12
u'النميري': u'النُّمَيْرِيِّ', #13
u'النميرى': u'النُّمَيْرِىُّ', #14
u'النميري،': u'النُّمَيْرِيُّ،', #19
u'النميري': u'النُّمَيْرِيَّ', #2
u'النميري،': u'النُّمَيْرِيِّ،', #4
u'النهاس': u'النَّهَّاس', #1
u'النهاس': u'النَّهَّاسُ', #13
u'النهاس': u'النَّهَّاسِ', #4
u'النهاقة': u'النُّهَاقَةِ', #2
u'النهاوندي،': u'النَّهَاوَنْدِيُّ،', #1
u'النهاوي': u'النَّهَاوِيُّ', #1
u'النهبرة': u'النَّهْبَرَةُ', #1
u'النهبى': u'النُّهْبَى', #24
u'النهدى': u'النَّهْدِىُّ', #13
u'النهدى': u'النَّهْدِىِّ', #42
u'النهدى': u'النَّهْدِىَّ', #7
u'النهرتيري،': u'النهرتيري،', #1
u'النهرتيري': u'النَّهْرُتَيْرِيُّ', #1
u'النهرتيري،': u'النَّهْرُتَيْرِيُّ،', #1
u'النهرتيري،': u'النَّهْرَتِيرِيِّ،', #2
u'النهرتيري': u'النَّهْرَتِيرِيُّ', #3
u'النهرتيري،': u'النَّهْرَتِيرِيُّ،', #5
u'النهرجوري': u'النَّهْرَجُورِيُّ', #1
u'النهرجوري': u'النَّهْرَجُورِيِّ', #1
u'النهروان': u'النهروان', #1
u'النهروان،': u'النهروان،', #1
u'النهروان،': u'النَّهروان،', #1
u'النهروان': u'النَّهْروَانَ', #1
u'النهروان،': u'النَّهْرَوان،', #1
u'النهروان': u'النَهْرَوَانِ', #1
u'النهروان': u'النِّهْرَوَانِ', #1
u'النهروان؟': u'النَّهْرَوَانِ؟', #1
u'النهروان': u'النَّهْرَوَانَ', #2
u'النهروان،': u'النَّهْرَوَانِ،', #2
u'النهروان': u'النَّهْرَوَانِ', #36
u'النهروان': u'النَّهْرَوَانُ', #6
u'النهروانى': u'النَّهْرَوَانِىُّ', #1
u'النهرواني': u'النَّهْرَوَانِيُّ', #14
u'النهس': u'النُّهَسُ', #1
u'النهس': u'النَّهْسِ', #5
u'النهساء': u'النُّهَسَاءُ', #1
u'النهشلي': u'النهشلي', #1
u'النهشلي': u'النَّهْشَلِيُّ', #12
u'النهشلي': u'النّهْشَلِيّ', #2
u'النهشلي': u'النَّهْشَلِيّ', #2
u'النهشلي': u'النَّهْشَلِيَّ', #2
u'النهشلي': u'النَّهْشَلِيِّ', #2
u'النهشلي،': u'النَّهْشَلِيِّ،', #2
u'النهشلي،': u'النهشلي،', #3
u'النهشلى': u'النَّهْشَلِىِّ', #3
u'النهشلي،': u'النَّهْشَلِيُّ،', #6
u'النهشلى': u'النَّهْشَلِىُّ', #9
u'النهشلية': u'النَّهْشَلِيَّةِ', #1
u'النهيرة': u'النَّهِيرَةِ', #1
u'النوابات': u'النَّوَّابَاتِ', #1
u'النواتق': u'النّوَاتِقْ', #1
u'النواتية': u'النَّوَاتِيَّةِ', #18
u'النواتية': u'النَّوَاتِيَّةَ', #2
u'النواتية': u'النَّوَاتِيَّةُ', #3
u'النواحى': u'النَّوَاحِى', #2
u'النوازلي': u'النَّوَازِلِيُّ', #2
u'النواصيا': u'النَّوَاصيَا', #1
u'النواصير': u'النَّوَاصِيرِ', #1
u'النوافج': u'النَّوَافِجِ', #2
u'النوافح': u'النّوَافِح', #1
u'النوافح': u'النّوَافِحُ', #1
u'النواقض': u'النَّوَاقِضَ', #2
u'النواقض': u'النَّوَاقِضُ', #6
u'النواقض': u'النَّوَاقِضِ', #67
u'النواوي': u'النَّوَاوِيّ', #1
u'النواوي': u'النَّوَاوِيَّ', #1
u'النواوي': u'النَّوَاوِيُّ', #19
u'النواوي': u'النَّوَاوِيِّ', #2
u'النواوية': u'النَّوَاوِيَّةِ', #4
u'النواويس': u'النَّوَاوِيسُ', #2
u'النوبري': u'النَّوْبَرِيُّ', #1
u'النوبندجان': u'النّوبَنْدِجَان', #1
u'النورة': u'النُّورَة', #1
u'النورة': u'الَّنْوَرَةِ', #1
u'النورة': u'النُّورَةُ', #19
u'النورة': u'النَّوْرَةُ', #3
u'النورة،': u'النَّوْرَةَ،', #3
u'النورة': u'النُّورَةِ', #34
u'النورة': u'النُّورَةَ', #7
u'النورث': u'النَّوْرَثَ', #1
u'النورزي': u'النَّوْرَزِيُّ', #1
u'النوشجان': u'النَّوْشَجَانِ', #1
u'النوشجان': u'النُّوشَجَانِ', #2
u'النوفلي': u'الْنَّوْفَلِيُّ', #1
u'النوفلي': u'النوفلي', #2
u'النوفلي،': u'النَّوْفَلِيِّ،', #2
u'النوفلى': u'النَّوْفَلِىُّ', #22
u'النوفلي': u'النَّوْفَلِيَّ', #3
u'النوفلي': u'النَّوْفَلِيِّ', #3
u'النوفلي،': u'النَّوْفَلِيُّ،', #5
u'النوفلي': u'النَّوْفَلِيُّ', #6
u'النوفلى': u'النَّوْفَلِىِّ', #7
u'النوقاتي': u'النَّوْقَاتِيُّ', #1
u'النوقاني': u'النَّوْقَانِيُّ', #1
u'النوقانى': u'النَّوْقَانِىُّ', #4
u'النوك': u'النُّوكُ', #1
u'النوك': u'النُّوكِ', #3
u'النوكى': u'النَّوْكَى', #8
u'النوموالوجه': u'النَّوْمُوَالْوَجْهُ', #1
u'النونة': u'النّونَةُ', #1
u'النؤي': u'النّؤْيِ', #1
u'النؤي': u'النُّؤْيُ', #1
u'النؤى': u'النُّؤْىِ', #1
u'النويرة': u'النُّوَيْرَةِ', #1
u'النويري': u'النُّوَيْرِيُّ', #7
u'الني': u'الني', #1
u'الني': u'النِّيُّ', #3
u'الني': u'النِّيّ', #4
u'النياحة': u'النِّيَاحَةَ', #11
u'النياحة': u'النِّيَاحَةُ', #19
u'النياحة': u'النِّيَاحَةِ', #54
u'النياحة': u'النِّيَاحَة', #9
u'النياق': u'النِّيَاقُ', #1
u'النيدة': u'النِّيدَة', #1
u'النيدة': u'النِّيدَةِ', #5
u'النيرب': u'النَّيْرَبِ', #1
u'النيرجات': u'النَّيْرَجَاتِ', #1
u'النيرنج': u'النِّيرِنْجُ', #1
u'النيسأبوري': u'النَّيْسَأبُورِيُّ', #1
u'النيسابوري،': u'النَّيْسَابُورِيَّ،', #1
u'النيسابوري،': u'النَّيْسَابوُرِيِّ،', #1
u'النيسابورى': u'النيسابورى', #1
u'النيسابورى': u'النَّيْسَابُورِىَّ', #10
u'النيسابوري': u'النَّيْسَابُورِيُّ', #111
u'النيسابوري،': u'النَّيْسَابُورِيُّ،', #131
u'النيسابوري': u'النَّيْسَابُورِيَّ', #15
u'النيسابوري': u'النيسابوري', #2
u'النيسابوري': u'النَّيْسَابُورِيّ', #2
u'النيسابورى': u'النَّيْسَابُورِىُّ', #243
u'النيسابوري': u'النّيْسَابُورِيّ', #3
u'النيسابورى': u'النَّيْسَابُورِىِّ', #4
u'النيسابوري': u'النَّيْسَابُورِيِّ', #40
u'النيسابوري،': u'النَّيْسَابُورِيِّ،', #53
u'النيسابوري،': u'النيسابوري،', #9
u'النيسابورية': u'النَّيْسَابُورِيَّة', #4
u'النيص': u'النَّيْصَ', #1
u'النيص': u'النَّيْصُ', #2
u'النيفة': u'النَّيِّفَةِ', #1
u'النيفر': u'النيفر', #1
u'النيك': u'النَّيْكُ', #2
u'النيك': u'النَّيْكَ', #4
u'النيك': u'النَّيْكِ', #9
u'النيكلية': u'النَّيْكَلِيَّةُ', #1
u'النيلان': u'النِّيلَانِ', #1
u'النيلة': u'النَّيْلَةِ', #1
u'النيلة': u'النِّيلَةِ', #13
u'النيلة': u'النِّيلَةَ', #3
u'النيلة': u'النِّيلَةُ', #7
u'النيلق': u'النَّيْلَقِ', #1
u'النيلى': u'النِّيلِىَّ', #1
u'النيلى': u'النِّيلِىُّ', #1
u'النيمرشت': u'النِّيمَرِشْتِ', #1
u'النينوفر': u'النَّيْنُوفَرِ', #1
u'النيه': u'النيه', #1
u'النيه': u'النِّيَّهْ', #5
u'النييء': u'النَّيْيءَ', #1
u'النييء': u'النَّيْيءِ', #1
u'النيىء': u'النيىء', #1
u'النيئ': u'النِّيئِ', #1
u'النيئة': u'النِّيئَةِ', #1
u'الها': u'الهاً', #1
u'الها': u'الْهَا', #1
u'الهاءات': u'الْهَاءَاتُ', #2
u'الهاثم': u'الْهَاثِمِ', #1
u'الهادى': u'الْهَادِى', #1
u'الهازلي': u'الْهَازِلِيِّ', #1
u'الهاشمه': u'الْهَاشِمَهْ', #1
u'الهاشمى': u'الْهَاشِمِىِّ', #14
u'الهاشمى': u'الْهَاشِمِىَّ', #4
u'الهاشمى': u'الْهَاشِمِىُّ', #50
u'الهالكي': u'الْهَالِكِيّ', #4
u'الهاملي': u'الْهَامِلِيُّ', #3
u'الهاملي': u'الْهَامِلِيِّ', #3
u'الهاملية': u'الْهَامِلِيَّةِ', #2
u'الهان': u'الهان', #1
u'ألهانى': u'أَلْهَانِى', #2
u'الهائر': u'الْهَائِرُ', #1
u'الهائعة': u'الْهَائِعَةِ', #1
u'الهائعة': u'الْهَائِعَةُ', #2
u'الهائعة': u'الْهَائِعَةَ', #3
u'الهباآت': u'الْهَبَاآتِ', #3
u'الهباري': u'الهباري', #1
u'الهباري،': u'الهباري،', #1
u'الهباري،': u'الْهَبَّارِيُّ،', #1
u'الهبارى': u'الْهَبَّارِىُّ', #1
u'الهباري': u'الْهَبَّارِيُّ', #2
u'الهبذرة': u'الْهَبْذَرَةُ', #1
u'الهبع': u'الْهُبَعُ', #1
u'الهبه': u'الْهِبَهْ', #8
u'الهبيت': u'الْهَبِيتِ', #2
u'الهبيرية': u'الْهُبَيْرِيَّةُ', #1
u'ألهة': u'أَلِهَةً', #1
u'آلهتتا': u'آلْهِتَتَا', #1
u'الهتعة': u'الْهَتْعَةِ', #1
u'ألهتنى': u'أَلْهَتْنِى', #3
u'الهثيم': u'الْهَثِيمِ', #1
u'الهجرس': u'الهجرس', #1
u'الهجرس': u'الْهِجْرِسِ', #2
u'الهجرسان': u'الْهِجْرِسَانِ', #1
u'الهجرى': u'الْهَجَرِىِّ', #10
u'الهجرى': u'الْهَجَرِىَّ', #3
u'الهجرى': u'الْهَجَرِىُّ', #6
u'الهجف': u'الْهِجَفّ', #2
u'الهجلة': u'الْهَجْلَةَ', #1
u'الهجلة': u'الْهَجْلَةِ', #2
u'الهجنع': u'الْهَجَنَّعِ', #1
u'الهجهج': u'الْهَجْهَجِ', #1
u'الهجيرى': u'الهجيرى', #1
u'الهجيرى': u'الْهِجّيرَى', #1
u'الهجيم': u'الْهُجَيْمِ', #3
u'الهجيمة': u'الْهَجِيمَةِ', #1
u'الهجيمي': u'الْهُجَيْمِيَّ', #1
u'الهجيمي،': u'الْهُجَيْمِيُّ،', #1
u'الهجيمى': u'الْهُجَيْمِىُّ', #10
u'الهجيمي': u'الْهُجَيْمِيُّ', #12
u'الهجيمى': u'الْهُجَيْمِىِّ', #3
u'الهجيمي': u'الْهُجَيْمِيِّ', #32
u'الهجيمي،': u'الْهُجَيْمِيِّ،', #4
u'الهجيمي': u'الهجيمي', #6
u'الهدابة': u'الْهُدَّابَةَ', #1
u'الهدابة': u'الْهُدَّابَةُ', #1
u'الهدادي،': u'الْهَدَادِيُّ،', #1
u'الهدادى': u'الْهَدَادِىُّ', #1
u'الهدادى': u'الْهَدَّادِىُّ', #1
u'الهداوي،': u'الْهَدَاوِيُّ،', #1
u'الهدبد': u'الْهُدَبِدُ', #1
u'الهدلي': u'الْهُدَلِيّ', #1
u'الهدو': u'الْهُدُوِّ', #2
u'الهدو': u'الْهُدُوّ', #3
u'الهديم': u'الْهَدِيمُ', #1
u'الهديم': u'الْهَدِيمِ', #1
u'الهدىيييي': u'الْهُدَىيييي', #1
u'الهذ': u'الهذ', #1
u'الهذ': u'الْهَذّ', #1
u'الهذ': u'الْهَذِّ', #2
u'الهذرمة': u'الْهَذْرَمَةُ', #1
u'الهذلي328': u'الْهُذَلِيّ328', #1
u'الهذلي،': u'الهذلي،', #1
u'الهذلي': u'الهُذلي', #1
u'الهذلي': u'الهّذليّ', #1
u'الهذلي،': u'الهُذلي،', #1
u'الهذلي،': u'الهُذليّ،', #1
u'الهذلي': u'الهُذْليّ', #1
u'الهذلي': u'الْهَذَلِيُّ', #1
u'الهذلي': u'الْهُذَلَيّ', #1
u'الهذلي،': u'الْهُذَلِيَّ،', #1
u'الهذلي،': u'الْهُذْلِيِّ،', #1
u'الهذلى': u'الْهُذَلِىِّ', #18
u'الهذلى': u'الْهُذَلِىَّ', #2
u'الهذلى': u'الْهُذَلِىُّ', #25
u'الهذلي،': u'الهُذَليّ،', #3
u'الهذلي،': u'الْهُذَلِيُّ،', #31
u'الهذلي،': u'الْهُذَلِيِّ،', #37
u'الهذلي': u'الهُذَليّ', #4
u'الهذلي': u'الْهُذَلِيَّ', #4
u'الهذلي': u'الْهُذَلِيُّ', #46
u'الهذلي': u'الهذلي', #6
u'الهذلي': u'الْهُذَلِيِّ', #64
u'الهذلي': u'الْهُذَلِيّ', #92
u'الهذليان': u'الْهُذَلِيّانِ', #2
u'الهذلية': u'الْهُذَلِيَّة', #3
u'الهذليتين': u'الْهُذَلِيَّتَيْنِ', #1
u'الهذليون': u'الُهُذَلِيّونَ', #1
u'الهذليون': u'الْهُذَلِيّونَ', #1
u'الهذليين': u'الْهُذَلِيّينَ', #1
u'الهذليين': u'الْهُذَلِيِّينَ', #3
u'الهذم': u'الْهَذْمُ', #1
u'الهذيل': u'الْهُذَيْلَ', #1
u'الهذيل،': u'الْهُذَيْلُ،', #1
u'الهذيل،': u'الهذيل،', #2
u'الهذيل،': u'الْهُذَيْلِ،', #25
u'الهذيل': u'الهذيل', #5
u'الهذيل': u'الْهُذَيْلُ', #5
u'الهذيل': u'الْهُذَيْلِ', #72
u'الهراة': u'الْهِرَاةِ', #1
u'الهرادي': u'الْهَرَادِيِّ', #19
u'الهرادي': u'الْهَرَادِيّ', #2
u'الهرادي': u'الْهَرَادِيَّ', #3
u'الهرادي': u'الْهَرَادِيُّ', #8
u'الهراسي': u'الْهِرَّاسِيَّ', #1
u'الهراسي': u'الْهِرَّاسِيُّ', #28
u'الهراسي': u'الْهِرَّاسِيِّ', #5
u'الهراسي': u'الْهِرَّاسِيّ', #9
u'الهراش': u'الْهَرَّاشِ', #1
u'الهراش': u'الْهِرَاشُ', #2
u'الهراش': u'الْهِرَاشِ', #9
u'الهراقة': u'الْهِرَاقَةِ', #1
u'الهراو': u'الهراو', #1
u'الهرائس': u'الْهَرَائِسِ', #1
u'الهرائسيين': u'الهرائسيين', #3
u'الهرثمي،': u'الْهَرْثَمِيُّ،', #1
u'الهردي': u'الْهَرْدِيُّ', #1
u'الهردية': u'الْهُرْدِيَّةِ', #1
u'الهردية': u'الْهُرْدِيَّةُ', #3
u'الهرري': u'الهرري', #1
u'الهرشا': u'الْهِرْشَا', #1
u'الهرماس': u'الهرماس', #1
u'الهرماس': u'الْهِرْمَاسِ', #12
u'الهرماس': u'الْهِرْمَاسُ', #8
u'الهرمزان': u'الهرمزان', #1
u'الهرمزان': u'الهُرمُزان', #1
u'الهرمزان': u'الهرْمُزان', #1
u'الهرمزان': u'الهُرْمُزانَ', #1
u'الهرمزان': u'الهُرْمُزَان', #1
u'الهرمزان،': u'الهُرْمُزَان،', #1
u'الهرمزان،': u'الْهُرْمُزَانِ،', #1
u'الهرمزان؟': u'الْهُرْمُزَانِ؟', #1
u'الهرمزان': u'الهُرْمُزان', #11
u'الهرمزان': u'الهُرْمزان', #2
u'الهرمزان،': u'الهُرْمزان،', #2
u'الهرمزان،': u'الهُرْمُزان،', #4
u'الهرمزان': u'الْهُرْمُزَانُ', #6
u'الهرمزان': u'الْهُرْمُزَانَ', #9
u'الهرمزان': u'الْهُرْمُزَانِ', #9
u'الهرمس': u'الْهَرْمَسُ', #1
u'الهرمينية': u'الْهَرْمِينِيَّةِ', #1
u'الهره': u'الْهِرَّهْ', #1
u'الهرواني': u'الْهَرَوَانِيُّ', #1
u'الهروى': u'الْهَرَوِىَّ', #1
u'الهروى': u'الْهَرَوِىِّ', #3
u'الهروى': u'الْهَرَوِىُّ', #99
u'الهزأ': u'الْهُزُأَ', #1
u'الهزاني': u'الهِزَّانِيُّ', #1
u'الهزاني': u'الْهِزَّانِيِّ', #1
u'الهزانى': u'الْهِزَّانِىُّ', #1
u'الهزاني': u'الْهِزَّانِيُّ', #2
u'الهزاني،': u'الْهِزَّانِيُّ،', #2
u'الهزائز': u'الْهَزَائِزْ', #1
u'الهزهاز': u'الْهَزْهَازِ', #1
u'الهزؤ': u'الْهُزْؤِ', #1
u'الهزو': u'الْهُزُوُ', #1
u'الهزيمه': u'الْهَزِيمَهْ', #1
u'الهسنجاني': u'الهسنجاني', #1
u'الهسنجاني،': u'الْهَسْنَجَانِيُّ،', #1
u'الهسنجاني،': u'الْهِسِنْجَانِي،', #1
u'الهسنجانى': u'الْهِسِنْجَانِىَّ', #1
u'الهسنجانى': u'الْهَسِنْجَانِىُّ', #2
u'الهسنجاني': u'الْهِسِنْجَانِيُّ', #26
u'الهسنجاني،': u'الْهِسِنْجَانِيُّ،', #58
u'الهص': u'الْهَصّ', #1
u'الهفاني': u'الْهِفَّانِيِّ', #1
u'الهفاني': u'الْهِفَّانِيُّ', #2
u'الهفعة': u'الْهَفْعَةِ', #1
u'الهفوف': u'الْهُفُوفُ', #2
u'الهقعة': u'الْهَقْعَةِ', #1
u'الهقعة': u'الْهَقْعَةُ', #2
u'الهقل': u'الْهِقْلَ', #1
u'الهقل': u'الْهِقْلِ', #1
u'الهقل،': u'الْهِقْلِ،', #1
u'الهقل': u'الْهِقْلُ', #9
u'الهكاري': u'الْهَكَّارِي', #1
u'الهكارية': u'الْهَكَّارِيَّةِ', #1
u'الهكوري': u'الْهَكْوَرِيُّ', #1
u'الهلاف': u'الْهُلّافُ', #1
u'الهلالى': u'الْهِلاَلِى', #1
u'الهلالى': u'الْهِلاَلِىِّ', #11
u'الهلالى': u'الْهِلاَلِىَّ', #2
u'الهلالى': u'الْهِلاَلِىُّ', #65
u'الهلاليون': u'الْهِلاَلِيُّونَ', #1
u'الهلب': u'الْهُلْبِ', #5
u'الهلباء': u'الْهَلْبَاءُ', #2
u'الهلباء': u'الْهَلْبَاءِ', #5
u'الهلكه': u'الْهَلَكَهْ', #2
u'الهليسع': u'الهليسع', #1
u'الهليلج': u'الهليلج', #1
u'الهليلج': u'الْهَلِيلِجَ', #1
u'الهليلج': u'الْهِلَيلَجَ', #1
u'الهليلج': u'الْهَلِيلَجِ', #2
u'الهليلج': u'الْهَلِيلَجُ', #3
u'الهليلجة': u'الْهَلِيلَجَةِ', #1
u'الهما': u'الْهَمَّا', #2
u'الهمال': u'الْهُمّالِ', #1
u'الهمالجة': u'الْهَمَالِجَةِ', #2
u'الهمامين': u'الْهُمَامَيْنِ', #2
u'الهمايوني': u'الهمايوني', #2
u'الهمداني،': u'الهمْداني،', #1
u'الهمدانى': u'الْهَمَدَانِىِّ', #1
u'الهمداني،': u'الْهَمْدَانِيُّ،', #144
u'الهمداني،': u'الهمداني،', #19
u'الهمداني،': u'الْهَمَدَانِيِّ،', #2
u'الهمداني': u'الْهَمْدَانِيّ', #22
u'الهمداني،': u'الْهَمَدَانِيُّ،', #3
u'الهمدانى': u'الْهَمْدَانِىِّ', #36
u'الهمدانى': u'الْهَمْدَانِىَّ', #4
u'الهمداني،': u'الْهَمْدَانِيَّ،', #5
u'الهمداني،': u'الْهَمْدَانِيِّ،', #66
u'الهمدانى': u'الْهَمْدَانِىُّ', #69
u'الهمداني': u'الْهَمْدَانِيَّ', #7
u'الهمداني': u'الْهَمْدَانِيِّ', #71
u'الهمداني': u'الهمداني', #8
u'الهمداني': u'الْهَمْدَانِيُّ', #84
u'الهمدانيان': u'الْهَمْدَانِيَّانِ', #1
u'الهمدانية': u'الْهَمَدَانِيَّةِ', #1
u'الهمدانية': u'الْهَمْدَانِيّةِ', #1
u'الهمدانية': u'الْهَمْدَانِيَّةُ', #3
u'الهمدانية': u'الْهَمْدَانِيَّةَ', #6
u'الهمدانية': u'الْهَمْدَانِيَّةِ', #9
u'الهمدانيين': u'الهمدانيين', #1
u'الهمذاني،': u'الهَمذاني،', #1
u'الهمذاني': u'الْهَمَذَانِيِّ', #1
u'الهمذاني،': u'الْهَمَذَانِيُّ،', #14
u'الهمذانى': u'الْهَمَذَانِىُّ', #18
u'الهمذاني،': u'الْهَمَذَانِيِّ،', #3
u'الهمذاني': u'الْهَمَذَانِيُّ', #6
u'الهمذانية': u'الْهَمْذَانِيَّةِ', #1
u'الهمزاني،': u'الْهَمَزَانِيُّ،', #1
u'الهمزين': u'الْهَمْزَيْنِ', #1
u'الهمط': u'الْهَمْطُ', #3
u'الهملاج': u'الْهِمْلَاجَ', #3
u'الهملاج': u'الْهِمْلَاجِ', #3
u'الهملاج': u'الْهِمْلَاجُ', #8
u'الهملجة': u'الْهَمْلَجَةَ', #1
u'الهملجة': u'الْهَمْلَجَةُ', #8
u'الهملجة': u'الْهَمْلَجَةِ', #9
u'الهملع': u'الْهَمَلّعِ', #1
u'الهميسع': u'الهميسع', #1
u'الهميسع': u'الهَمَيْسع', #1
u'الهميسع': u'الْهَمَيْسَعَ', #1
u'الهميسع': u'الْهَمَيْسَعُ', #1
u'الهميسع': u'الْهَمَيْسَعِ', #8
u'الهميل': u'الْهُمَيْلُ', #1
u'الهنا': u'الْهَنَا', #2
u'الهناب': u'الهناب', #1
u'الهناني،': u'الْهُنَانِيُّ،', #1
u'الهنائى': u'الْهُنَائِىُّ', #3
u'الهنائى': u'الْهُنَائِىِّ', #5
u'الهنبر': u'الْهِنّبْرِ', #1
u'الهنتاني': u'الْهَنْتَانِيُّ', #1
u'الهنداوي': u'الْهِنْدَاوِيُّ', #2
u'الهندباء': u'الْهِنْدَبَاءَ', #1
u'الهندباء': u'الْهِنْدِبَاءِ', #1
u'الهندلع': u'الْهُنْدَلِعُ', #1
u'الهندوان': u'الْهِنْدُوَانِ', #2
u'الهندواني': u'الْهِنْدُوَانِيَّ', #1
u'الهندواني': u'الْهِنْدُوَانِيُّ', #265
u'الهندواني': u'الْهِنْدُوَانِي', #3
u'الهندواني': u'الْهِنْدُوَانِيِّ', #33
u'الهندى': u'الْهِنْدِىِّ', #5
u'الهنعة': u'الْهَنْعَةِ', #1
u'الهنوك': u'الْهُنُوكَ', #1
u'الهنوك': u'الْهُنُوكِ', #2
u'الهنيد': u'الْهُنَيْدِ', #15
u'الهنيد': u'الْهُنَيْدَ', #3
u'الهنيد': u'الْهُنَيْدُ', #5
u'الهنيدة': u'الْهُنَيْدَةُ', #2
u'الهوازني': u'الْهَوَازِنِيّ', #1
u'الهوازني': u'الْهَوَازِنِيُّ', #1
u'الهوازني': u'الْهَوْاَزنِيّ', #1
u'الهوازنية': u'الهَوَازِنيّة', #1
u'الهوذي': u'الْهَوْذِيّ', #1
u'الهوريني': u'الْهُورِينِيِّ', #1
u'الهوزني': u'الهَوْزني', #1
u'الهوزني': u'الْهَوْزَنِيَّ', #1
u'الهوزنى': u'الْهَوْزَنِىَّ', #2
u'الهوزنى': u'الْهَوْزَنِىُّ', #2
u'الهوزني': u'الهوزني', #3
u'الهوزني،': u'الْهَوْزَنِيُّ،', #3
u'الهوزنى': u'الْهَوْزَنِىِّ', #4
u'الهوزني،': u'الْهَوْزَنِيِّ،', #6
u'الهوزني': u'الْهَوْزَنِيُّ', #8
u'الهوزني': u'الْهَوْزَنِيِّ', #8
u'الهوزي': u'الْهَوْزِيِّ', #2
u'الهونا': u'اُلْهُونَا', #1
u'الهوينى': u'الْهُوَيْنَى', #3
u'إلهى': u'إِلَهِى', #2
u'الهيآت': u'الْهَيْآتِ', #1
u'الهيامة': u'الْهَيّامَة', #1
u'الهيامة': u'الْهَيّامَةُ', #1
u'الهيبان': u'الهَيبان', #1
u'الهيبان،': u'الهَيْبَان،', #1
u'الهيبان': u'الْهَيّبَانَ', #1
u'الهيبان،': u'الْهَيْبَانِ،', #1
u'الهيبان': u'الْهَيَّبَانِ', #3
u'الهيبان': u'الْهَيَبَانِ', #4
u'الهيبان': u'الْهَيّبَانِ', #5
u'الهيبان': u'الْهَيْبَانِ', #5
u'الهية': u'الْهِيَةَ', #1
u'الهيتم': u'الْهَيْتَمِ', #1
u'الهيتمي': u'الْهَيْتَمِيِّ', #12
u'الهيتمي': u'الْهَيْتَمِيُّ', #33
u'الهيجا': u'الهيجا', #1
u'الهيجا': u'الْهَيْجَا', #14
u'الهيجا': u'الهَيْجا', #2
u'الهيزن': u'الْهَيْزَنُ', #1
u'الهيشات': u'الهيشات', #1
u'الهيشة': u'الهيشة', #1
u'الهيصم': u'الْهَيْصَمِ', #1
u'الهيصم،': u'الْهَيْصَمِ،', #1
u'الهيصم،': u'الهيصم،', #2
u'الهيضة': u'الْهَيْضَةُ', #1
u'الهيضل': u'الْهَيْضَلُ', #1
u'الهيطلية': u'الْهَيْطَلِيَّةِ', #1
u'الهيعة': u'الهيعة', #1
u'الهيعة،': u'الْهَيْعَةَ،', #1
u'الهيعة': u'الْهَيْعَةَ', #7
u'الهيلج': u'الْهَيْلَجُ', #1
u'الهيمة': u'الْهِيمَةَ', #1
u'الهيمياء': u'الْهِيمْيَاءِ', #1
u'الهيمياء': u'الْهِيمْيَاءُ', #2
u'الهينمة؟': u'الْهَيْنَمَةُ؟', #1
u'الهينمة': u'الْهَيْنَمَةُ', #4
u'الهينه': u'الْهِينَهْ', #1
u'الوا': u'َالُوا', #1
u'الوابشية': u'الْوَابِشِيَّةِ', #1
u'الوابصي': u'الْوَابِصِيُّ', #1
u'الوابصى': u'الْوَابِصِىُّ', #1
u'الوابي': u'الْوَابِيِّ', #1
u'الواتن': u'الْوَاتِنُ', #2
u'الواتنة': u'الْوَاتِنَةُ', #1
u'الواجبي': u'الْوَاجِبِيُّ', #1
u'الواجبية': u'الْوَاجِبِيَّةِ', #1
u'الواح': u'الواح', #1
u'الواحدالمستسرة': u'الْوَاحِدِالْمُسْتَسِرَةُ', #1
u'الواحدي': u'الْوَاحِدِيَّ', #2
u'الواحدي': u'الْوَاحِدِيّ', #3
u'الواحدي': u'الْوَاحِدِيِّ', #31
u'الواحدي': u'الْوَاحِدِيُّ', #96
u'الواحدية': u'الْوَاحِدِيَّةَ', #1
u'الواحدية': u'الْوَاحِدِيَّةِ', #1
u'ألواحى': u'أَلْوَاحِى', #1
u'ألواحيا': u'أَلْوَاحِيًّا', #4
u'الوادعي': u'الوادعي', #1
u'الوادعي': u'الوادعيّ', #1
u'الوادعي،': u'الوادعي،', #1
u'الوادعي': u'الْوَادِعِيَّ', #1
u'الوادعي،': u'الْوَادِعِيِّ،', #1
u'الوادعى': u'الْوَادِعِىَّ', #1
u'الوادعي،': u'الْوَادِعِيُّ،', #2
u'الوادعى': u'الْوَادِعِىُّ', #2
u'الوادعي': u'الْوَادِعِيِّ', #3
u'الوادعي': u'الْوَادِعِيُّ', #5
u'الوادعى': u'الْوَادِعِىِّ', #6
u'الوادى': u'الوادى', #1
u'الوادى؟': u'الْوَادِى؟', #1
u'الوادى': u'الْوَادِىَ', #12
u'الوادى': u'الْوَادِى', #68
u'الوارثينا': u'الْوَارِثِينَا', #1
u'الواسطي': u'الواسطي', #1
u'الواسطي': u'الوَاسِطِيُّ', #1
u'الواسطي،': u'الْوَاسِطِيّ،', #1
u'الواسطى': u'الْوَاسِطِىِّ', #11
u'الواسطى': u'الْوَاسِطِىُّ', #115
u'الواسطي': u'الْوَاسِطِيَّ', #13
u'الواسطي،': u'الواسطي،', #14
u'الواسطي': u'الْوَاسِطِيُّ', #194
u'الواسطي': u'الْوَاسِطِي', #2
u'الواسطي،': u'الْوَاسِطِيَّ،', #2
u'الواسطي': u'الْوَاسِطِيِّ', #23
u'الواسطي،': u'الْوَاسِطِيُّ،', #272
u'الواسطي،': u'الْوَاسِطِيِّ،', #46
u'الواسطيون،': u'الْوَاسِطِيُّونَ،', #1
u'الواشحى': u'الوَاشِحِىُّ', #1
u'الواشحى': u'الْوَاشِحِىُّ', #1
u'الواشحي': u'الْوَاشِحِيُّ', #2
u'الواشر': u'الْوَاشِرُ', #1
u'الواشرة': u'الْوَاشِرَةَ', #2
u'الواصلية': u'الْوَاصِلِيَّةُ', #1
u'الواصي': u'الْوَاصِي', #2
u'الواطي': u'الْوَاطِي', #1
u'الواطية': u'الْوَاطِيَّةِ', #1
u'الواعب': u'الْوَاعِبِ', #1
u'الواعيه': u'الْوَاعِيَهْ', #2
u'الوافقين': u'الْوَافِقِينَ', #1
u'الواق': u'الْوَاقُ', #1
u'الواقد': u'الْوَاقِدُ', #1
u'الواقدي': u'الواقديُّ', #1
u'الواقدي،': u'الْوَاقِديُّ،', #1
u'الواقدي': u'الْوَاقِدَيْ', #1
u'الواقدي': u'الواقديّ', #14
u'الواقدي': u'الْوَاقدي', #14
u'الواقدي،': u'الْوَاقِدِيِّ،', #14
u'الواقدي': u'الْوَاقِدِيّ', #156
u'الواقدي': u'الواقِديّ', #16
u'الواقدي': u'الوّاقِدِيّ', #2
u'الواقدي': u'الْوَاقِدَيَّ', #2
u'الواقدي،': u'الْوَاقِدِيَّ،', #2
u'الواقدي': u'الواقدي', #28
u'الواقدي،': u'الواقدي،', #3
u'الواقدي': u'الْوَاقِدِيُّ', #350
u'الواقدي،': u'الواقديّ،', #4
u'الواقدي،': u'الْوَاقِدِيُّ،', #51
u'الواقدى': u'الْوَاقِدِىُّ', #59
u'الواقدي،': u'الْوَاقدي،', #6
u'الواقدي': u'الْوَاقِدِيَّ', #7
u'الواقدي،': u'الواقِديّ،', #8
u'الواقدي': u'الْوَاقِدِيِّ', #84
u'الواقدى': u'الْوَاقِدِىِّ', #9
u'الواقصة': u'الْوَاقِصَةَ', #2
u'الواقصة': u'الْوَاقِصَةِ', #4
u'الواقصي': u'الْوَاقِصِي', #1
u'الواقعى': u'الْوَاقِعِىُّ', #1
u'الواقفي،': u'الْوَاقِفِيِّ،', #1
u'الواقفي': u'الْوَاقِفِيَّ', #2
u'الواقفي': u'الْوَاقِفِيِّ', #2
u'الواقفى': u'الْوَاقِفِىِّ', #2
u'الواقفي،': u'الْوَاقِفِيُّ،', #3
u'الواقفي': u'الْوَاقِفِيّ', #5
u'الواقفى': u'الْوَاقِفِىُّ', #5
u'الواقفي': u'الْوَاقِفِيُّ', #6
u'الواقفية': u'الْوَاقِفِيَّةُ', #11
u'الواقفية': u'الْوَاقِفِيَّةِ', #21
u'الواقفية': u'الْوَاقِفِيَّةَ', #3
u'الواقوصة': u'الْوَاقُوصَةِ', #1
u'الوالبة': u'الْوَالِبَةِ', #1
u'الوالبي،': u'الْوَالبي،', #1
u'الوالبى': u'الْوَالِبِىَّ', #1
u'الوالبى': u'الْوَالِبِىُّ', #1
u'الوالبي': u'الْوَالِبِيِّ', #14
u'الوالبي،': u'الْوَالِبِيُّ،', #2
u'الوالبي': u'الْوَالِبِيَّ', #3
u'الوالبى': u'الْوَالِبِىِّ', #3
u'الوالبي': u'الْوَالِبِيُّ', #4
u'الوالبي،': u'الْوَالِبِيِّ،', #8
u'الوالده': u'الْوَالِدَهْ', #2
u'الوالدية': u'الْوَالِدِيَّةَ', #1
u'الوالدية': u'الْوَالِدِيَّةُ', #1
u'الوالدية': u'الْوَالِدِيَّةِ', #3
u'الوالغ': u'الْوَالِغُ', #3
u'الوالوالجية': u'الوالوالجية', #1
u'الوالى': u'الْوَالِىُّ', #1
u'الوالى': u'الْوَالِى', #15
u'الوامصة': u'الْوَامِصَةِ', #1
u'الوامق': u'الْوَامِقِ', #3
u'إلوان': u'إلْوَانٍ', #1
u'الوانجاني': u'الوانجاني', #1
u'الوانجاني': u'الْوَانِجَانِيُّ', #1
u'الوانشريسي': u'الْوَانْشَرِيسِيُّ', #4
u'الوانشيريسي': u'الوانشيريسي', #1
u'الوانغيلي': u'الْوَانْغِيلِيِّ', #1
u'الوانهم': u'الوانهم', #3
u'الوانوغي': u'الْوَانُّوغِيُّ', #36
u'الوانوغي': u'الْوَانُّوغِيِّ', #9
u'الواهى': u'الْوَاهِى', #1
u'الوأواء': u'الْوَأْوَاءِ', #1
u'الواوات': u'الْوَاوَاتِ', #5
u'الوأي': u'الْوَأْيُ', #1
u'الوائدا': u'الْوَائِدَا', #1
u'الوائلي': u'الْوَائِلِيُّ', #1
u'الوائلي': u'الْوَائِلِيَّ', #2
u'الوائلي': u'الْوَائِلِيّ', #5
u'الوبا': u'الْوَبَا', #2
u'الوبرح': u'الوبرح', #1
u'الوبيات': u'الْوَبْيَاتِ', #4
u'الوبية': u'الْوَبِيَّةَ', #1
u'الوبية': u'الْوَبِيَّةُ', #2
u'الوبية': u'الْوَبِيَّةِ', #2
u'الوبيص': u'الوبيص', #10
u'الوبيص': u'الْوَبِيصُ', #2
u'ألوة': u'أُلُوّةٌ', #1
u'ألوة': u'أَلُوَّةٍ', #3
u'الوتائد': u'الْوَتَائِدُ', #1
u'الوترة': u'الْوَتْرَةُ', #1
u'الوترة': u'الْوَتَرَةَ', #12
u'الوترة': u'الْوَتَرَةُ', #3
u'الوترة': u'الْوَتْرَةَ', #4
u'الوترة': u'الْوَتَرَةِ', #7
u'الوتير،': u'الوَتير،', #1
u'الوتير،': u'الوَتِير،', #1
u'الوتير': u'الْوَتِيرِ', #3
u'الوتير': u'الْوَتِيرَ', #5
u'الوتير': u'الْوَتِيرُ', #6
u'الوتيره': u'الْوَتِيرَهْ', #1
u'الوتيرين': u'الْوَتِيرَيْنِ', #1
u'الوثيره': u'الْوَثِيرَهْ', #1
u'الوجء': u'الْوَجْءَ', #1
u'الوجء': u'الْوَجْءِ', #1
u'الوجاء': u'الْوِجَاءَ', #1
u'الوجاء': u'الوجاء', #2
u'الوجاء': u'الْوِجَاء', #2
u'الوجاء': u'الْوِجَاءِ', #3
u'الوجاء': u'الْوِجَاءُ', #6
u'الوجأة': u'الْوَجْأَةِ', #1
u'الوجادة': u'الوجادة', #1
u'الوجادة': u'الْوِجَادَةِ', #1
u'الوجة': u'الوجة', #4
u'الوجنا': u'الْوَجْنَا', #1
u'الوجناء': u'الْوَجْنَاءُ', #1
u'الوجهوروي': u'الْوَجْهِوَرُوِيَ', #1
u'الوجهيني': u'الْوَجْهِينِيُّ', #1
u'الوجيف': u'الْوَجِيفُ', #2
u'الوجيف': u'الْوَجِيفِ', #4
u'الوجيفا': u'الْوَجِيفَا', #1
u'الوحا': u'الْوَحَا', #1
u'الوحاطي،': u'الْوُحَاطيُّ،', #3
u'الوحاظي': u'الْوُحَاظِيَّ', #1
u'الوحاظي': u'الْوُحَاظِيِّ', #2
u'الوحاظي،': u'الْوَحَاظِيُّ،', #2
u'الوحاظى': u'الْوُحَاظِىِّ', #2
u'الوحاظي،': u'الْوُحَاظِيُّ،', #25
u'الوحاظي': u'الْوُحَاظِيُّ', #28
u'الوحاظى': u'الْوُحَاظِىُّ', #6
u'الوحدتي': u'الْوَحْدَتِيُّ', #1
u'الوحس': u'الْوَحْسَ', #1
u'الوحشى': u'الْوَحْشِىِّ', #1
u'الوحى؟': u'الْوَحْىُ؟', #1
u'الوحى': u'الْوَحْىَ', #11
u'الوحى': u'الْوَحْىِ', #17
u'الوحى': u'الوحى', #2
u'الوحى': u'الْوَحْىُ', #54
u'الوحيين': u'الْوَحْيَيْنِ', #1
u'الوحيين': u'الوَحْيَيْنِ', #2
u'الوخش': u'الْوَخْش', #1
u'الوخش': u'الْوَخْشُ', #15
u'الوخش': u'الْوَخْشَ', #6
u'الوخش': u'الْوَخْشِ', #73
u'الوخشة': u'الْوَخْشَةُ', #1
u'الوداك،': u'الودَاك،', #1
u'الوداك': u'الوَدَّاكِ', #1
u'الوداك': u'الْوَدَّاكِ', #57
u'الوداك،': u'الْوَدَّاكِ،', #9
u'الودعه': u'الْوَدَعَهْ', #1
u'الودى': u'الْوَدِىَّ', #1
u'الودى': u'الْوَدِىُّ', #1
u'الودى': u'الْوَدِىِّ', #1
u'الودى': u'الْوَدْىِ', #1
u'الودى': u'الْوَدْىُ', #2
u'الودى': u'الْوَدَى', #3
u'الودينة': u'الْوُدَيْنَةَ', #1
u'الوذاري': u'الْوَذَارِيِّ', #2
u'الوذرة': u'الْوَذِرَةُ', #1
u'الوذيل': u'الْوَذِيلُ', #2
u'الوذيم': u'الْوَذِيمُ', #1
u'الور': u'الْوَرّ', #1
u'الوراثه': u'الْوِرَاثَهْ', #3
u'الوراقون': u'الْوَرَّاقُونَ', #3
u'الوراقين': u'الْوَرَّاقِينَ', #9
u'الورام': u'الْوِرَامِ', #1
u'الورام': u'الورام', #2
u'الورام': u'الْوِرَامَ', #2
u'الورانده': u'الورانده', #1
u'الورثه': u'الْوَرَثَهْ', #1
u'الورحمي': u'الْوَرَحْمِيِّ', #1
u'الورخمتي': u'الورخمتي', #1
u'الورخميني': u'الورخميني', #1
u'الوردا': u'الْوَرْدَا', #1
u'الورسكي': u'الْوَرْسَكِيِّ', #2
u'الورشان': u'الْوَرَشَانُ', #2
u'الورشكي': u'الْوَرْشَكِيِّ', #2
u'الورغمي': u'الْوَرْغَمِّيُّ', #2
u'الورقاوون': u'الْوَرْقَاوُونَ', #1
u'الوركالي': u'الْوَرْكَالِيِّ', #1
u'الوركانى': u'الْوَرْكَانِىِّ', #1
u'الوركاني': u'الْوَرَكَانِيُّ', #12
u'الوركاني': u'الْوَرْكَانِيُّ', #2
u'الوركاني،': u'الْوَرْكَانِيُّ،', #5
u'الوركانى': u'الْوَرْكَانِىُّ', #6
u'الوركانية': u'الْوَرْكَانِيَّةُ', #1
u'الوركشي': u'الوركشي', #1
u'الوركشية': u'الوركشية', #1
u'الورياجلي': u'الْوَرْيَاجِلِيِّ', #1
u'الوزغات': u'الْوَزَغَاتِ', #6
u'الوزيعة': u'الْوَزِيعَةِ', #1
u'الوساطني،': u'الْوَسَاطَنِيُّ،', #1
u'الوساع': u'الْوَسَاعِ', #1
u'الوساق': u'الْوِسَاقُ', #1
u'الوساوسي': u'الْوَسَاوِسِيُّ', #2
u'الوسائدي': u'الْوَسَائِدِيُّ', #1
u'الوسطاني': u'الْوَسْطَانِيَّ', #1
u'الوسقندى': u'الْوَسْقَنْدِىُّ', #1
u'الوسنانين': u'الْوَسْنَانَيْنِ', #1
u'الوسيع': u'الْوَسِيعِ', #1
u'الوسيعة': u'الْوَسِيعَةِ', #1
u'الوسيعة': u'الْوَسِيعَةُ', #2
u'الوشائق': u'الوشائق', #2
u'الوشحة': u'الوشحة', #1
u'الوشل': u'الْوَشَلِ', #5
u'الوشى': u'الْوَشَى', #1
u'الوشى': u'الْوَشْىُ', #1
u'الوشيح': u'الْوَشِيحِ', #1
u'الوشيقة': u'الْوَشِيقَةُ', #1
u'الوشيقة': u'الوشيقة', #2
u'الوصابي،': u'الوصابي،', #1
u'الوصابي': u'الْوَصَابِيِّ', #1
u'الوصابي': u'الْوُصَابِيِّ', #1
u'الوصابي،': u'الْوَصَّابِيِّ،', #1
u'الوصابي': u'الْوَصَّابِيِّ', #2
u'الوصابية،': u'الْوَصَّابِيَّةُ،', #1
u'الوصاة': u'الْوَصَاة', #2
u'الوصاة': u'الْوَصَاةُ', #2
u'الوصاة': u'الْوَصَاةِ', #3
u'الوصافي': u'الْوَصَّافِيِّ', #2
u'الوصافي،': u'الْوَصَّافِيُّ،', #2
u'الوصافي،': u'الْوَصَّافِيِّ،', #2
u'الوصافى': u'الْوَصَّافِىُّ', #2
u'الوصافى': u'الْوَصَّافِىِّ', #2
u'الوصافي': u'الْوَصَّافِيُّ', #3
u'الوصالا': u'الْوِصَالَا', #1
u'الوصالة': u'الْوِصَالَةِ', #2
u'الوصواف': u'الْوُصْوَافَ', #1
u'الوصوف': u'الْوُصُوفِ', #1
u'الوصى': u'الْوَصِىِّ', #1
u'الوصى': u'الْوَصِىُّ', #2
u'الوصيفي': u'الْوَصِيفِيِّ', #1
u'الوصيه': u'الْوَصِيَّهْ', #5
u'الوضر': u'الْوَضَرِ', #1
u'الوضو': u'الْوُضُو', #1
u'الوضوءوالوجه': u'الْوُضُوءِوَالْوَجْهُ', #1
u'الوضوءين': u'الْوُضُوءَيْنِ', #26
u'الوضوءين،': u'الْوُضُوءَيْنِ،', #3
u'الوضوآت': u'الْوُضُوآتِ', #3
u'الوضوحية': u'الْوُضُوحِيَّةُ', #1
u'الوضي': u'الْوَضِيِّ', #1
u'الوضىء': u'الْوَضِىءِ', #3
u'الوضية': u'الْوَضِيَّةِ', #1
u'الوضيمة': u'الْوَضِيمَةُ', #2
u'الوضيمة': u'الْوَضِيمَةَ', #4
u'الوضين': u'الْوَضِينُ', #5
u'الوضين': u'الْوَضِينِ', #7
u'الوطآن': u'الْوَطْآنِ', #3
u'الوطأين': u'الوطأين', #1
u'الوطأين': u'الْوَطْأَيْنِ', #11
u'الوطبة': u'الوطبة', #1
u'الوطبة': u'الْوَطْبَةُ', #1
u'الوطبح': u'الْوَطْبَحَ', #1
u'الوطبح': u'الْوَطْبَحُ', #1
u'الوطح': u'الْوَطْحِ', #1
u'الوطنفي': u'الْوَطَنِفِي', #1
u'الوطئات': u'الْوَطْئَاتِ', #5
u'الوطئان': u'الوطئان', #1
u'الوطئين': u'الْوَطْئَيْنِ', #6
u'الوطئيه': u'الْوَطْئِيَّهْ', #1
u'الوطية': u'الْوَطِيَّةِ', #1
u'الوطية؟': u'الْوَطِيَّةُ؟', #1
u'الوطيح': u'الْوَطِيحُ', #1
u'الوطيح': u'الْوَطِيحَ', #5
u'الوطيح': u'الْوَطِيحِ', #8
u'الوطيحة': u'الْوَطِيحَةَ', #1
u'الوعدة': u'الْوَعْدَةِ', #1
u'الوعلاني،': u'الْوَعْلانِيُّ،', #2
u'الوعلانى': u'الْوَعْلاَنِىُّ', #2
u'الوغليسي': u'الْوَغْلِيسِيِّ', #1
u'الوغليسية': u'الْوَغْلِيسِيَّةِ', #6
u'الوغير': u'الْوَغِيرِ', #1
u'الوفا': u'الْوَفَا', #19
u'الوفاتي': u'الْوَفَاتِيُّ', #2
u'الوفقين': u'الْوَفْقَيْنِ', #7
u'الوفيه': u'الْوَفِيَّهْ', #1
u'الوقاص': u'الْوَقَّاصِ', #1
u'الوقاصي،': u'الْوَقَّاصِيِّ،', #1
u'الوقاصي': u'الْوَقَّاصِي', #2
u'الوقاصي': u'الْوَقَّاصِيِّ', #3
u'الوقاصي،': u'الْوَقَّاصِيُّ،', #3
u'الوقاصي': u'الْوَقَّاصِيُّ', #4
u'الوقاصى': u'الْوَقَّاصِىُّ', #4
u'الوقاقيص': u'الْوَقَاقِيصِ', #1
u'الوقاياتي': u'الْوِقَايَاتِيُّ', #1
u'الوقاياتي': u'الْوِقَايَاتِيِّ', #2
u'الوقتإلا': u'الْوَقْتِإِلَّا', #1
u'الوقذ': u'الْوَقْذَ', #1
u'الوقذ': u'الْوَقْذُ', #1
u'الوقذ': u'الْوَقْذِ', #2
u'الوقرة': u'الْوَقْرَةُ', #1
u'الوقشي': u'الْوَقْشِي', #1
u'الوقشي': u'الْوَقَشِيّ', #2
u'الوقشي': u'الْوَقْشِيّ', #7
u'الوقص': u'الْوَقَصَ', #10
u'الوقص': u'الْوَقْصَ', #25
u'الوقص': u'الْوَقْص', #3
u'الوقص': u'الْوَقْصِ', #31
u'الوقص': u'الْوَقَصُ', #6
u'الوقص': u'الْوَقَصِ', #8
u'الوقص': u'الْوَقْصُ', #9
u'الوقصين': u'الْوَقَصَيْنِ', #2
u'الوقعان': u'الْوَقْعَانِ', #1
u'الوقفا': u'الْوَقْفَا', #2
u'الوقوت': u'الْوُقُوتِ', #2
u'الوقوى': u'الْوَقْوَى', #1
u'الوقية': u'الوَقِيَّةُ', #1
u'الوقية': u'الْوَقِيَّةُ', #1
u'الوقية': u'الْوَقِيَّة', #2
u'الوقية': u'الْوُقِيَّةَ', #3
u'الوقيتين': u'الْوُقِيَّتَيْنِ', #1
u'الوقيذ': u'الْوَقِيذُ', #1
u'الوقيعه': u'الْوَقِيعَهْ', #1
u'الوكادة': u'الْوَكَادَةُ', #1
u'الوكادة': u'الْوَكَادَةِ', #4
u'الوكاعي،': u'الْوِكاعِيُّ،', #1
u'الوكاله': u'الْوَكَالَهْ', #4
u'الوكائل': u'الْوَكَائِلُ', #1
u'الوكت': u'الوكت', #1
u'الوكت': u'الْوَكْت', #1
u'الوكت': u'الْوَكْتِ', #7
u'الوكرة': u'الْوَكْرَةُ', #1
u'الوكلان': u'الْوُكْلَانِ', #1
u'الوكلين': u'الْوَكِلَيْنِ', #1
u'الوكيدة': u'الوكيدة', #1
u'الوكيعي،': u'الوكيعي،', #1
u'الوكيعي': u'الْوَكِيعِيِّ', #1
u'الوكيعي،': u'الْوَكِيعِيَّ،', #1
u'الوكيعي،': u'الْوَكِيعِيِّ،', #1
u'الوكيعي': u'الْوَكِيعِيُّ', #5
u'الوكيعى': u'الْوَكِيعِىُّ', #7
u'الوكيعي،': u'الْوَكِيعِيُّ،', #9
u'الولا': u'الْوَلَا', #11
u'الولاءان': u'الْوِلَاءَانِ', #1
u'الولاءين': u'الْوِلَاءَيْنِ', #2
u'الولات': u'الْوُلَاتِ', #1
u'الولاد': u'الْوِلَادَ', #11
u'الولاد': u'الْوِلَادُ', #16
u'الولاد': u'الْوِلَادِ', #245
u'الولاول': u'الْوَلَاوِلُ', #1
u'الولايا': u'الْوَلَايَا', #1
u'الولدا': u'الْوَلَدَا', #2
u'الولدالوجه': u'الْوَلَدُالْوَجْهُ', #1
u'الولدانية': u'الْوِلْدَانِيَّةِ', #1
u'الولغات': u'الْوَلَغَاتِ', #1
u'الولم': u'الْوَلْمِ', #19
u'الولوالجي': u'الولوالجي', #1
u'الولوالجي': u'الْوَلْوَالِجَيُّ', #1
u'الولوالجي': u'الْوَلْوَالِجِيِّ', #118
u'الولوالجي': u'الْوَلْوَالَجِيُّ', #3
u'الولوالجي': u'الْوَلْوَالِجِيُّ', #334
u'الولوالجي': u'الْوَلْوَالِجِيَّ', #9
u'الولوالجية': u'الولوالجية', #15
u'الولوالجية': u'الْوَلْوَالِجِيَّة', #2
u'الولوالجية': u'الْوَلْوَالِجِيَّةِ', #329
u'الولوالجية': u'الْوَلَوْالِجيَّةِ', #4
u'الولوالجية': u'الْوَلْوَالِجيَّةِ', #949
u'الولوي': u'الْوَلْوِيُّ', #1
u'الولى': u'الْوَلِىِّ', #13
u'الولى': u'الْوَلِىُّ', #15
u'الولى': u'الْوَلِىَّ', #2
u'الونشريسي': u'الْوَنْشَرِيسِيِّ', #15
u'الونشريسي': u'الْوَنْشَرِيسِيُّ', #18
u'الونيم': u'الْوَنِيمَ', #1
u'الونيم': u'الْوَنِيمُ', #1
u'الونيم': u'الْوَنِيمِ', #1
u'الوهاء': u'الْوَهَاءِ', #2
u'الوهاء': u'الْوَهَاءُ', #7
u'الوهب': u'الْوَهْبُ', #1
u'الوهب': u'الْوَهْبِ', #3
u'الوهباني': u'الوهباني', #1
u'الوهباني': u'الْوَهْبَانِيِّ', #16
u'الوهبانية': u'الْوَهْبَانِيَّةُ', #3
u'الوهبانية': u'الْوَهْبَانِيَّةِ', #492
u'الوهبي': u'الوهْبيّ', #1
u'الوهبي،': u'الْوَهْبِيِّ،', #18
u'الوهبي': u'الوهبي', #2
u'الوهبي،': u'الوهبي،', #2
u'الوهبي': u'الْوَهْبِيَّ', #2
u'الوهبي،': u'الْوَهْبِيَّ،', #2
u'الوهبى': u'الْوَهَبِىِّ', #2
u'الوهبى': u'الْوَهْبِىَّ', #2
u'الوهبي': u'الْوَهْبِيُّ', #26
u'الوهبى': u'الْوَهْبِىُّ', #28
u'الوهبى': u'الْوَهْبِىِّ', #3
u'الوهبي،': u'الْوَهْبِيُّ،', #41
u'الوهبية': u'الْوَهْبِيَّةِ', #4
u'الوهط': u'الْوَهَط', #1
u'الوهط': u'الْوَهْط', #1
u'الوهط': u'الْوَهْطَ', #1
u'الوهط،': u'الْوَهْطِ،', #1
u'الوهط': u'الْوَهْطُ', #2
u'الوهط': u'الْوَهْطِ', #3
u'الوهط،': u'الْوَهْطُ،', #3
u'الوهق': u'الْوَهَقُ', #1
u'الوهق': u'الْوَهْقُ', #1
u'الوهوب': u'الْوَهُوبِ', #1
u'الوهى': u'الْوَهَى', #1
u'الويبات': u'الْوَيْبَاتِ', #9
u'الويبة': u'الْوَيْبَةُ', #1
u'الويبة': u'الْوَيْبَةِ', #10
u'الويبة': u'الْوَيْبَةَ', #5
u'الويبتين': u'الْوَيْبَتَيْنِ', #4
u'الي،': u'الي،', #1
u'الى': u'الى', #25
u'الي': u'الي', #3
u'اليا': u'الْيَا', #3
u'الياس': u'الياس', #1
u'الياس': u'الْيَاسُ', #1
u'إلياسين': u'إلْيَاسِينَ', #1
u'اليافعي': u'الْيَافِعِيَّ', #1
u'اليافعي،': u'الْيَافِعِيِّ،', #1
u'اليافعى': u'الْيَافِعِىَّ', #1
u'اليافعى': u'الْيَافِعِىِّ', #1
u'اليافعي': u'الْيَافِعِيُّ', #15
u'اليافعى': u'الْيَافِعِىُّ', #2
u'اليافعي': u'الْيَافِعِيِّ', #3
u'اليافي': u'الْيَافِيِّ', #1
u'اليآفيخ': u'الْيَآفِيخَ', #2
u'إلىالمصلى': u'إِلَىالْمُصَلَّى', #2
u'إلىالنبي': u'إِلَىالنَّبِيِّ', #2
u'إلىأم': u'إِلَىأُمِّ', #1
u'اليامي': u'اليامي', #1
u'اليامي': u'اليَامِيُّ', #1
u'اليامي': u'الْيَامِيّ', #1
u'اليامي': u'الْيَامِيَّ', #2
u'اليامى': u'الْيَامِىِّ', #3
u'اليامي،': u'اليامي،', #4
u'اليامي': u'الْيَامِيُّ', #4
u'اليامى': u'الْيَامِىُّ', #6
u'اليامي': u'الْيَامِيِّ', #7
u'اليامي،': u'الْيَامِيُّ،', #8
u'اليامي،': u'الْيَامِيِّ،', #8
u'الياميان،': u'الْيَامَيَانُ،', #1
u'اليبوس': u'الْيُبُوسَ', #1
u'اليبيسا': u'الْيَبِيسَا', #2
u'إلية': u'إلْيَةَ', #1
u'إلىة': u'إلىة', #1
u'إلية': u'إلْيَةٌ', #3
u'إليته': u'إِلْيَتَهُ', #1
u'إليته': u'إِلْيَتِهِ', #1
u'اليته': u'اليته', #1
u'أليتى': u'أَلْيَتَىِ', #1
u'اليتيما': u'الْيَتِيمَا', #1
u'اليتيموالوجه': u'الْيَتِيمِوَالْوَجْهُ', #1
u'اليتيمية': u'اليتيمية', #1
u'اليتيمية': u'الْيَتِيمِيَّةِ', #4
u'اليثربي،': u'الْيَثْرِبِيُّ،', #1
u'اليثربي؟': u'الْيَثْرِبِيُّ؟', #1
u'اليثربي': u'الْيَثْرِبِيّ', #2
u'اليثربي': u'الْيَثْرِبِيُّ', #3
u'اليحصبي،': u'اليحصبي،', #1
u'اليحصبي': u'الْيَحْصِبِيُّ', #1
u'اليحصبي': u'الْيُحَصْبِيِّ', #1
u'اليحصبي،': u'الْيَحْصَبِيِّ،', #1
u'اليحصبي،': u'الْيَحْصُبِيُّ،', #1
u'اليحصبي،': u'الْيَحْصُبِيِّ،', #1
u'اليحصبي،': u'الْيَحْصِبِيِّ،', #1
u'اليحصبى': u'الْيَحْصَبِىِّ', #1
u'اليحصبى': u'الْيَحْصُبِى', #1
u'اليحصبى': u'الْيُحْصُبِىُّ', #1
u'اليحصبي': u'الْيَحْصِبِيِّ', #2
u'اليحصبى': u'الْيَحْصُبِىُّ', #2
u'اليحصبي،': u'الْيَحْصِبِيُّ،', #3
u'اليحصبى': u'الْيَحْصُبِىِّ', #3
u'اليحصبي': u'الْيَحْصَبِيُّ', #4
u'اليحصبي': u'الْيَحْصَبِيِّ', #5
u'اليحصبي': u'الْيَحْصُبِيُّ', #7
u'اليحصبي': u'الْيَحْصُبِيِّ', #7
u'اليحمدي': u'الْيَحْمَدِيُّ', #1
u'اليحمدي': u'الْيُحْمَدِيُّ', #1
u'اليحمدي،': u'الْيَحْمَدِيِّ،', #1
u'اليحمدي،': u'الْيَحْمَدِيُّ،', #2
u'اليحيائية': u'الْيَحَيَائِيَّةِ', #1
u'اليخني': u'الْيَخْنِيِّ', #1
u'اليدا': u'الْيَدَا', #4
u'اليديتين': u'الْيُدَيَّتَيْنِ', #1
u'اليديتين': u'الْيُدِيَّتَيْنِ', #1
u'اليربوعى': u'الْيَرْبُوعِىُّ', #3
u'اليربوعيون': u'الْيَرْبُوعِيُّونَ', #1
u'اليرتاسي': u'الْيَرْتَاسِيِّ', #1
u'إلىرسول': u'إِلَىرَسُولِ', #1
u'اليرفإ': u'الْيَرْفَإِ', #1
u'اليرناسني': u'الْيَرْنَاسَنِيُّ', #1
u'اليرى': u'الْيَرَى', #2
u'اليريسين،': u'اليَرِيسِيِّنَ،', #1
u'اليريسيون': u'اليريسيون', #1
u'اليريسيين': u'الْيَرِيسِيِّينَ', #1
u'اليزدي': u'الْيَزْدِيُّ', #1
u'اليزقاني': u'اليزقاني', #1
u'اليزناسني': u'الْيَزَنَاسَنِيُّ', #1
u'اليزناسي': u'الْيَزْنَاسِيُّ', #2
u'اليزناسي': u'الْيَزْنَاسِيِّ', #2
u'اليزني': u'اليَزَنيّ', #1
u'اليزني،': u'اليَزَنيّ،', #1
u'اليزني': u'الْيَزِنِي', #1
u'اليزني': u'الْيَزْنِيّ', #1
u'اليزني': u'الْيَزَنِيُّ', #11
u'اليزني،': u'اليزني،', #2
u'اليزني،': u'اليزَني،', #2
u'اليزني،': u'الْيَزْنِيُّ،', #2
u'اليزنى': u'الْيَزَنِىُّ', #2
u'اليزني': u'الْيَزَنِيِّ', #31
u'اليزنى': u'الْيَزَنِىِّ', #5
u'اليزني': u'الْيَزَنِيّ', #6
u'اليزني،': u'الْيَزَنِيِّ،', #6
u'اليزني،': u'الْيَزَنِيُّ،', #9
u'اليزنية': u'الْيَزَنِيّةُ', #1
u'اليزيد': u'الْيَزِيدَ', #2
u'اليزيد': u'الْيَزِيدِ', #2
u'اليزيد': u'الْيَزِيدُ', #3
u'اليس': u'الْيَسْ', #1
u'اليستعور': u'الْيَسْتَعُورُ', #1
u'اليستعور': u'الْيَسْتَعُورِ', #3
u'اليسرين': u'اليسرين', #2
u'اليسومين': u'الْيَسُومَيْنِ', #2
u'اليشب': u'الْيَشْبَ', #2
u'اليشب': u'الْيَشْبُ', #3
u'اليشب': u'الْيَشْبِ', #3
u'اليشكري': u'اليَشْكريّ', #1
u'اليشكري،': u'اليَشْكُريّ،', #1
u'اليشكري،': u'الْيَشْكَرِيِّ،', #1
u'اليشكري،': u'الْيَشْكُرِيَّ،', #1
u'اليشكري،': u'الْيَشْكِرِيُّ،', #1
u'اليشكرى': u'الْيَشْكَرِىُّ', #1
u'اليشكرى': u'الْيَشْكُّرِىِّ', #1
u'اليشكري': u'الْيَشْكُرِيُّ', #15
u'اليشكرى': u'الْيَشْكُرِىُّ', #17
u'اليشكري': u'الْيَشْكُرِيِّ', #20
u'اليشكري': u'اليشكري', #3
u'اليشكري': u'الْيَشْكُرِيَّ', #3
u'اليشكري،': u'الْيَشْكُرِيِّ،', #5
u'اليشكري': u'الْيَشْكُرِيّ', #6
u'اليشكرى': u'الْيَشْكُرِىِّ', #7
u'اليشكري،': u'الْيَشْكُرِيُّ،', #8
u'اليشم': u'الْيَشْمِ', #1
u'إلىصلاة': u'إِلَىصَلَاةِ', #1
u'اليعاليل': u'الْيَعَالِيلُ', #1
u'اليعقوبيون': u'الْيَعْقُوبِيُّونَ', #2
u'اليعمري': u'اليعمري', #1
u'اليعمري': u'اليَعْمُرِيّ', #1
u'اليعمري': u'الْيَعْمَرِيّ', #1
u'اليعمري': u'الْيَعْمَرِيَّ', #1
u'اليعمري': u'الْيَعْمَرِيُّ', #1
u'اليعمري،': u'الْيَعْمَرِيَّ،', #1
u'اليعمري،': u'الْيَعْمُرِيِّ،', #1
u'اليعمرى': u'الْيَعْمَرِىُّ', #1
u'اليعمري': u'الْيَعْمُرِيُّ', #15
u'اليعمري،': u'الْيَعْمَرِيِّ،', #2
u'اليعمري،': u'الْيَعْمُرِيُّ،', #2
u'اليعمرى': u'الْيَعْمُرِىِّ', #2
u'اليعمري': u'الْيَعْمَرِيِّ', #3
u'اليعمري': u'الْيَعْمُرِيّ', #3
u'اليعمرى': u'الْيَعْمَرِىِّ', #6
u'اليعمري': u'الْيَعْمُرِيِّ', #8
u'اليعملات': u'اليَعمُلات', #1
u'اليعملات': u'الْيَعْمُلَاتِ', #1
u'اليعملات': u'الْيَعْمَلَاتِ', #2
u'اليعملة': u'الْيَعْمَلَةُ', #2
u'اليعملة': u'الْيَعْمَلَةِ', #2
u'اليعمله': u'الْيَعْمَلَه', #2
u'اليعمله': u'الْيَعْمَلَهْ', #3
u'إلىغير': u'إِلَىغَيْرِ', #2
u'اليقطينى': u'الْيَقْطِينِىُّ', #1
u'إلىقوله': u'إِلَىقَوْلُهُ', #1
u'اليقينا': u'اليَقينَا', #1
u'اليقينا': u'الْيَقِينَا', #3
u'اليك': u'اليك', #1
u'اليلب': u'الْيَلَبِ', #1
u'اليلب': u'الْيَلَبُ', #2
u'اليلمق': u'الْيَلْمَقِ', #1
u'اليلنجوج': u'الْيَلَنْجُوجِ', #1
u'اليمامه': u'الْيَمَامَهْ', #1
u'اليمامى': u'الْيَمَامِىَّ', #1
u'اليمامى': u'الْيَمَامِىُّ', #23
u'اليمانون': u'الْيَمَانُونَ', #3
u'اليمانى': u'الْيَمَانِىُّ', #1
u'اليمانى؟': u'الْيَمَانِىَ؟', #1
u'اليمانى': u'الْيَمَانِى', #3
u'اليمانى': u'الْيَمَانِىَّ', #3
u'اليمانى': u'الْيَمَانِىِّ', #4
u'اليمانى': u'الْيَمَانِىَ', #9
u'اليمانين': u'الْيَمَانِينَ', #1
u'اليمعر': u'اليمعر', #1
u'إلىمكة': u'إِلَىمَكَّةَ', #2
u'إلىمنى': u'إِلَىمِنًى', #1
u'اليمنىعلى': u'الْيُمْنَىعَلَى', #1
u'اليمينا': u'الْيَمِينَا', #5
u'الينبع': u'الْيَنْبُعِ', #1
u'الينعة': u'الْيَنَعَةِ', #1
u'اليه،': u'اليه،', #2
u'اليه': u'اليه', #4
u'إليهاSإرسال': u'إلَيْهَاSإرْسَالُ', #1
u'اليها': u'اليها', #1
u'إليهاإن': u'إِلَيْهَاإِنَّ', #1
u'إليهالبرق': u'إِلَيْهِالْبَرْقُ', #1
u'إليهأن': u'إِلَيْهِأَنّ', #1
u'إليهأو': u'إِلَيْهِأَوْ', #1
u'إليهقوله': u'إِلَيْهِقَوْلُهُ', #1
u'إليهمالك': u'إِلَيْهِمَالِكٌ', #3
u'اليهو': u'اليهو', #1
u'اليهو': u'الْيَهُو', #1
u'إليهوالوجه': u'إِلَيْهِوَالْوَجْهُ', #3
u'إليهود': u'إليهود', #1
u'اليهودوالنصارى': u'الْيَهُودُوَالنَّصَارَى', #1
u'اليهودوالنصارى،': u'الْيَهُودَوَالنَّصَارَى،', #1
u'اليهودوالوجه': u'الْيَهُودِوَالْوَجْهُ', #1
u'اليهودى': u'الْيَهُودِىِّ', #17
u'اليهودى': u'الْيَهُودِىُّ', #32
u'اليهودى': u'الْيَهُودِىَّ', #7
u'اليو': u'الْيَوْ', #1
u'اليواقيت': u'الْيَوَاقِيت', #1
u'اليواقيت': u'الْيَوَاقِيتِ', #22
u'اليواقيت': u'الْيَوَاقِيتُ', #5
u'أليوسي': u'أليوسي', #1
u'اليوسي': u'الْيُوسِيُّ', #2
u'أليون': u'أليون', #1
u'أليون': u'أَلْيُونَ', #1
u'أليون': u'أَلْيُونُ', #1
u'إليون': u'إِلْيُونُ', #2
u'إليون': u'إِلْيُونَ', #3
u'اليونيني،': u'اليونيني،', #1
u'اليونيني': u'الْيُونِينِيَّ', #1
u'اليونيني': u'الْيُونِينِيّ', #14
u'اليونيني': u'الْيُونِينِيِّ', #5
u'اليونيني': u'الْيُونِينِيُّ', #9
u'اليونينية': u'الْيُونِينِيَّةِ', #1
u'اليير': u'الْيَيْرُ', #1
u'الييض': u'الييض', #1
u'ام': u'امّ', #1
u'ام': u'ام', #2
u'اما': u'اما', #5
u'أماالرجل': u'أَمَّاالرَّجُلُ', #1
u'أماآنفا': u'أَمَّاآنِفًا', #1
u'امات،': u'امات،', #1
u'أماث': u'أماث', #1
u'أماثته،': u'أَمَاثَتْهُ،', #1
u'أماثته': u'أَمَاثَتْهُ', #4
u'اماح': u'امَّاحَ', #1
u'إمارتى': u'إِمَارَتِى', #3
u'أماريد': u'أَمَارِيدِ', #1
u'أماز': u'أَمَازَ', #1
u'أمآق': u'أَمْآقٌ', #1
u'آماق': u'آمَاقٍ', #3
u'إمامأحدث': u'إِمَامٍأَحْدَثَ', #1
u'أمامة': u'أُمامة', #1
u'أمامة': u'أمَامة', #1
u'أمامة،': u'أُمَامة،', #1
u'أمامة': u'أُمَامَةَ', #1429
u'أمامة': u'أُمَامَةُ', #16
u'أمامة': u'أَمَامَةَ', #2
u'أمامة،': u'أُمامة،', #3
u'أمامة': u'أمامة', #34
u'أمامة': u'أُمَامَة', #5
u'أمامة،': u'أمامة،', #6
u'امامة': u'امامة', #7
u'أمامة،': u'أُمَامَةَ،', #78
u'أمامةأيها': u'أُمَامَةَأَيُّهَا', #1
u'أمامة،عن': u'أُمَامَةَ،عَنْ', #1
u'إمامى': u'إِمَامَىِ', #1
u'إمامى': u'إِمَامَىْ', #1
u'أمامى': u'أَمَامِى', #7
u'إماميتها': u'إمَامِيَّتِهَا', #1
u'امانات': u'امانات', #1
u'أمانت': u'أمانت', #1
u'أمانت': u'أَمَانَتْ', #1
u'أمانت': u'أَمَانَّتْ', #1
u'أمأنه': u'أَمْأَنُهُ', #1
u'أمأنهم': u'أَمَأْنَهُمْ', #1
u'أمائر': u'أَمَائِرِ', #1
u'أماير': u'أَمَايِرُ', #1
u'امبر': u'امبر', #1
u'امبر': u'امْبِرٍّ', #1
u'امبر': u'امْبِرِّ', #7
u'أمبرسم،': u'أَمُبَرْسَمٌ،', #1
u'إمة': u'إمّة', #1
u'إمة': u'إمّةٌ', #1
u'امة': u'امَّةٍ', #5
u'أمةقال': u'أُمَّةًقَالَ', #1
u'آمت': u'آمَتْ', #9
u'امتأر': u'امتأر', #1
u'امتأر': u'امْتَأَرَ', #1
u'امتحشوا': u'امتحشوا', #2
u'امتحشوا': u'امْتُحِشُوا', #6
u'امتحشوا': u'امْتَحَشُوا', #7
u'امتحقت': u'امْتَحَقَتْ', #3
u'إمترا': u'إمترا', #1
u'امتراء': u'امْتِرَاءِ', #2
u'امتراء': u'امْتِرَاءٍ', #3
u'امترى': u'امْتَرَى', #3
u'إمتريا': u'إِمْتَرَيَا', #1
u'امتريا': u'امْتَرَيَا', #3
u'امتساس': u'امْتِسَاسِ', #1
u'امتسسنا': u'امْتَسَسْنَا', #1
u'امتشجوا': u'امْتَشَجُوا', #1
u'امتطاكا': u'امْتَطَاكَا', #1
u'أمتعات': u'أَمْتِعَاتِ', #1
u'أمتعنى': u'أَمْتِعْنِى', #1
u'امتك': u'امْتَكَّ', #1
u'امتك': u'امتك', #6
u'امتل': u'امْتَلّ', #1
u'امتلا': u'امْتَلاَ', #1
u'امتلات': u'امْتَلاتْ', #1
u'امتلات': u'امْتَلاتِ', #2
u'امتلاخ': u'امْتِلَاخٌ', #1
u'امتلاخه': u'امْتِلَاخِهِ', #1
u'امتلخه': u'امْتَلَخَهُ', #2
u'امتناء': u'امْتِنَاءِ', #1
u'أمتنى': u'أَمِتْنِى', #1
u'امتهال': u'امْتِهَالٍ', #1
u'امتهل': u'امْتَهَلَ', #7
u'أمتهوكون': u'أَمُتَهَوِّكُونَ', #2
u'أمتى': u'أمتى', #1
u'أمتى': u'أُمَّتِى', #222
u'أمتى': u'أَمَتِى', #3
u'أمتى': u'أَمَتَى', #4
u'امتي': u'امتي', #4
u'امثالها': u'امْثَالُهَا', #1
u'أمثالهاوالوجه': u'أَمْثَالِهَاوَالْوَجْهُ', #1
u'آمج': u'آمَجَ', #1
u'إمحاق': u'إِمْحَاقَ', #1
u'آمد': u'آمُدِّ', #1
u'آمد': u'آمِدُ', #1
u'آمد': u'آمُدّ', #5
u'آمد': u'آمد', #6
u'آمدا': u'آمُدًّا', #1
u'أمداء': u'أَمْدَاءٍ', #1
u'أمداء': u'أَمْدَاءَ', #2
u'أمداد': u'أَمِدَادً', #3
u'آمدم': u'آمُدِمّ', #1
u'آمدن': u'آمَدَّنِ', #1
u'آمدندو': u'آمدندو', #1
u'أمدنى': u'أَمَدَّنِى', #1
u'آمده': u'آمده', #3
u'آمده': u'آمُدّه', #7
u'آمدونها': u'آمدونها', #1
u'آمدى': u'آمدى', #1
u'إمذاء': u'إمْذَاءٍ', #1
u'أمذت': u'أَمَذَتْ', #1
u'أمذت': u'أَمْذَتْ', #1
u'امذقر': u'امْذَقَرَّ', #1
u'أمذي': u'أَمَذْيٌ', #13
u'أمذى': u'أَمَذَى', #24
u'أمذى': u'أَمْذَى', #40
u'أمذي': u'أَمَذْي', #6
u'أمذيت': u'أَمْذَيْتُ', #1
u'إمر': u'إمْرٍ', #1
u'امر': u'امْرِ', #6
u'امر': u'امر', #7
u'امرءا': u'امْرَءًا', #13
u'إمرا،': u'إِمْرًا،', #1
u'امرا': u'امراً', #1
u'إمرا': u'إِمْرًا', #10
u'إمرا': u'إمْرًا', #2
u'امراء': u'امراء', #1
u'امرأةSحول': u'امْرَأَةًSحَوْلَ', #1
u'آمرأة': u'آمْرَأَةٌ', #1
u'إمرأة': u'إمرأة', #1
u'امراة': u'امراة', #1
u'امراة': u'امْرَاةَ', #1
u'إمرأته': u'إمْرَأَتُهُ', #1
u'امراته': u'امراته', #1
u'امرأتى': u'امْرَأَتِى', #106
u'أمرائى': u'أُمَرَائِى', #2
u'امرأين': u'امْرَأَيْنِ', #10
u'أمرتنى': u'أَمَرْتِنِى', #1
u'أمرتنى': u'أَمَرَتْنِى', #4
u'أمرتنى': u'أَمَرْتَنِى', #5
u'أمرجة': u'أَمْرِجَةٍ', #1
u'امركم': u'امْرِكُمْ', #2
u'أمركموه': u'أَمَرَكُمُوهُ', #1
u'أمرنى': u'أَمِّرْنِى', #1
u'أمرنى': u'أَمَرَنِى', #82
u'إمره': u'إِمْرَهَ', #1
u'امره،': u'امره،', #1
u'امره': u'امره', #2
u'امره': u'امْرِهِ', #3
u'امرهم': u'امرهم', #1
u'امرهم،': u'امرهم،', #3
u'أمرهموالوجه': u'أَمْرِهِمْوَالْوَجْهُ', #1
u'أمرهوروي': u'أَمْرِهِوَرُوِيَ', #1
u'امرو': u'امرو', #1
u'امرو': u'امْرُوٌ', #1
u'امروا': u'امُرُوا', #1
u'أمرواوالوجه': u'أُمِرُواوَالْوَجْهُ', #1
u'امروز': u'امروز', #3
u'أمرونى': u'أَمَرُونِى', #1
u'أمرونى': u'أَمِّرُونِى', #1
u'أمريSتحريم': u'أَمْرِيSتَحْرِيمُ', #1
u'امري': u'امْرِي', #4
u'امرىء': u'امْرِىءِ', #1
u'أمريته': u'أَمْرِيَّتُهُ', #1
u'أمزمارة': u'أَمِزْمَارَةُ', #1
u'امسال': u'امسال', #2
u'إمساما': u'إمْسَامًا', #1
u'امساولب': u'امساولب', #1
u'امساولج': u'امساولج', #1
u'امسحى': u'امْسَحِى', #1
u'امسفر': u'امسفر', #1
u'امسفر': u'امْسَفَرٍ', #1
u'امسفر': u'امْسَفَرِ', #6
u'أمسكى': u'أَمْسِكِى', #1
u'امشب': u'امشب', #1
u'أمشر': u'أَمْشَرَ', #1
u'امشى': u'امْشِى', #1
u'امصيام': u'امصيام', #1
u'امصيام': u'امْصِيَامٌ', #2
u'امصيام': u'امْصِيَامُ', #5
u'امضرب': u'امْضَرْبُ', #1
u'امضى': u'امْضِى', #1
u'امطتنعت': u'امْطتَنَعَتْ', #1
u'أمعرتم': u'أَمْعَرْتُمْ', #1
u'أمعرتم': u'أَمْعَرْتُمُ', #2
u'أمعس': u'أَمْعَسُ', #1
u'أمعوص': u'أَمْعُوصَ', #1
u'أمكبوبا': u'أَمَكْبُوبًا', #1
u'امكثى': u'امْكُثِى', #9
u'أمكفقلت': u'أُمُّكَفَقُلْتُ', #1
u'أمكناكها': u'أَمْكَنَّاكَهَا', #3
u'امكنتها،': u'امكنتها،', #1
u'أمكننى': u'أَمْكَنَنِى', #5
u'أمكنونى': u'أَمْكَنُونِى', #1
u'املاء': u'املاء', #1
u'املاء': u'امْلاَءً', #1
u'إملاجة': u'إِمْلَاجَةً', #1
u'إملاجة': u'إِمْلاَجَةً', #1
u'إملاجتين': u'إِمْلَاجَتَيْنِ', #1
u'إملاجتين': u'إِمْلاَجَتَيْنِ', #1
u'إملاص': u'إِمْلاصِ', #1
u'إملاص': u'إِمْلَاص', #1
u'إملاص': u'إِمْلَاصِ', #1
u'إملاص': u'إمْلَاصِ', #3
u'إملاص': u'إِمْلاَصِ', #3
u'أملجته': u'أَمْلَجَتْهُ', #1
u'أملكتكها': u'أَمْلَكْتُكَهَا', #1
u'أملكناكها': u'أَمْلَكْنَاكَهَا', #1
u'املئوا': u'املئوا', #1
u'أملياء': u'أَمْلِيَاءٍ', #1
u'أملياء': u'أَمْلِيَاءِ', #2
u'أملياء': u'أَمْلِيَاءَ', #32
u'أملياء': u'أَمْلِيَاءُ', #7
u'أمم4827id': u'أمم4827id', #1
u'أمناء': u'أَمْنَاءً', #1
u'إمناء': u'إمْنَاءُ', #1
u'إمناء': u'إمْنَاءٍ', #14
u'إمناء': u'إمْنَاءٌ', #2
u'إمناءه': u'إمْنَاءَهُ', #4
u'إمناءها': u'إمْنَاءَهَا', #2
u'إمنائه': u'إمْنَائِهِ', #1
u'امنة': u'امِنَةً', #1
u'امنة': u'امِنْةً', #1
u'آمنتبه': u'آمَنَتْبِهِ', #1
u'أمنتنى': u'أَمَّنْتَنِى', #1
u'أمنعكموه': u'أَمْنَعَكُمُوهُ', #1
u'أمنعكموه': u'أَمْنَعُكُمُوهُ', #4
u'آمنوابه': u'آمَنُوابِهِ', #1
u'آمنونى': u'آمَنُونِى', #1
u'أمهاتى': u'أُمَّهَاتِى', #3
u'أمهة': u'أَمْهَةٍ', #1
u'أمهة': u'أُمَّهَةً', #1
u'أمهة': u'أُمَّهَةٌ', #19
u'أمهة': u'أَمْهَةٌ', #2
u'أمهة': u'أُمَّهَةٍ', #8
u'أمهتي': u'أُمّهَتِي', #1
u'أمهوالوجه': u'أَمَّهْوَالْوَجْهُ', #1
u'أموالكمقوله': u'أَمْوَالَكُمْقَوْلُهُ', #1
u'اموالهم': u'اموالهم', #1
u'أموالهمالوجه': u'أَمْوَالِهِمْالْوَجْهُ', #1
u'أموزند': u'أموزند', #1
u'أموزندد': u'أموزندد', #1
u'أموميته': u'أُمُومِيَّتُهُ', #1
u'أموميتها': u'أُمُومِيَّتُهَا', #1
u'أمى': u'أُمَّىِ', #1
u'أمى': u'أُمَّىْ', #1
u'أمى؟': u'أُمِّى؟', #1
u'أمى': u'أُمِّى', #121
u'أمى': u'أُمِّىَ', #3
u'امية،': u'امية،', #1
u'امية،': u'امَيَّةَ،', #1
u'اميدمى': u'اميدمى', #1
u'أميراخور': u'أَمِيرَاخُورْ', #1
u'أميرى': u'أَمِيرِى', #5
u'اميكني': u'اميكني', #1
u'أميلة': u'أَمِيلَةَ', #1
u'ان': u'انٍ', #1
u'ان': u'انّ', #2
u'ان': u'ان', #34
u'ان': u'انَّ', #5
u'انا': u'انا', #6
u'اناء': u'اناء', #1
u'أناآتيك': u'أَنَاآتِيكَ', #1
u'أناالله': u'أَنَااللَّهُ', #1
u'أناأمشي': u'أَنَاأَمْشِي', #1
u'أناثا': u'أُنَاثًا', #1
u'أناثى': u'أَنَاثَى', #1
u'أنأحتأ': u'أَنْأَحْتُأَ', #2
u'أنأحتك': u'أَنَأَحْتُكَ', #1
u'أناذا،': u'أَنَاذَا،', #1
u'إناس،': u'إِنَاسٌ،', #1
u'اناس': u'اناس', #1
u'إناس': u'إنَاسٌ', #3
u'أنالإمام': u'أَنَّالْإِمَامَ', #1
u'أنالله': u'أَنَّاللَّهَ', #1
u'أنالمؤمن': u'أَنَّالْمُؤْمِنَ', #1
u'أنأمت': u'أَنْأَمْتَ', #1
u'اناوأهم': u'اناوأهم', #1
u'انائم': u'انَّائِمُ', #1
u'انبا': u'انْبَا', #1
u'أنبأء': u'أَنْبَأَءُ', #1
u'أنبابة': u'أَنْبَابَةُ', #1
u'أنبابة': u'أَنْبَابَةَ', #3
u'أنبابة': u'أنبابة', #5
u'أنبابة': u'أُنْبَابَةَ', #9
u'إنباتة': u'إنْبَاتَةِ', #1
u'أنبأتكموه': u'أَنْبَأْتُكُمُوهُ', #2
u'أنبارخانه': u'أنبارخانه', #1
u'أنباركر': u'أَنْبَارْكَرْ', #2
u'أنباسفيان': u'أنباسُفْيَان', #1
u'إنباعها': u'إنْبَاعِهَا', #1
u'انبان': u'انبان', #1
u'انبأنا': u'انبأنا', #1
u'أنبانكم': u'أنبانكم', #1
u'أنبأنى': u'أَنْبَأَنِى', #46
u'أنبأنيه': u'أَنْبَأَنِيهِ', #18
u'أنبأنيه': u'أَنَبَأَنِيهِ', #2
u'انبتنا': u'انبتنا', #1
u'أنبتى': u'أَنْبِتِى', #1
u'أنبجان': u'أَنْبَجَانَ', #1
u'أنبجان': u'أَنْبِجَان', #1
u'أنبجان': u'أنبجان', #3
u'أنبجاني': u'أنبجانيّ', #1
u'أنبجاني': u'أَنْبِجَانِيّ', #1
u'انبجاني': u'انبجاني', #1
u'أنبجاني': u'أَنْبَجَانِيُّ', #2
u'أنبجانيا': u'أَنْبِجَانِيًّا', #3
u'أنبجانية': u'أَنْبِجَانِيَّةَ', #1
u'أنبجانية': u'أَنْبِجَانِيَّةٌ', #2
u'أنبجانية': u'أَنْبِجَانِيَّةً', #6
u'انبغاء': u'انْبِغَاءَ', #1
u'انبغاء': u'انْبِغَاءِ', #3
u'انبغاءه': u'انْبِغَاءَهُ', #2
u'انبغى': u'انْبَغَى', #11
u'انبهام': u'انْبِهَامٌ', #1
u'انبهام': u'انْبِهَامَ', #1
u'انبهام': u'انْبِهَامُ', #3
u'انبهام': u'انْبِهَامِ', #4
u'انبهاما': u'انْبِهَامًا', #1
u'انبهامه': u'انْبِهَامُهُ', #1
u'انبهامها': u'انْبِهَامُهَا', #1
u'انبهامها': u'انْبِهَامِهَا', #1
u'أنبهتنى': u'أَنْبَهْتَنِى', #1
u'انبهم': u'انْبَهَمْ', #1
u'انبهم': u'انْبَهَمَ', #16
u'انبهمت': u'انْبَهَمَتْ', #3
u'انبوهي': u'انبوهي', #1
u'أنبئينى': u'أَنْبِئِينِى', #9
u'إنة': u'إنة', #1
u'انتاطت': u'انْتَاطَتِ', #1
u'انتتاف': u'انْتِتَافٌ', #1
u'انتتاف': u'انْتِتَافَ', #1
u'انتتاف': u'انْتِتَافِ', #2
u'انتتافه': u'انْتِتَافُهُ', #2
u'انتتافه': u'انْتِتَافِهِ', #3
u'انتتف': u'اُنْتُتِفَ', #12
u'انتتف': u'انْتَتَفَ', #3
u'انتثار': u'انْتِثَارٌ', #1
u'انتثار': u'انْتِثَارَ', #1
u'انتثار': u'انْتِثَارٍ', #2
u'انتثار': u'انْتِثَارُ', #5
u'انتثار': u'انْتِثَارِ', #5
u'انتثاره': u'انْتِثَارِهِ', #1
u'انتثارها': u'انْتِثَارُهَا', #1
u'انتثر': u'انْتَثَرَ', #22
u'انتثروا': u'انْتَثِرُوا', #1
u'انتخم': u'انْتَخَمَ', #1
u'انتخوا': u'انْتَخُوا', #1
u'انتخوا': u'انْتَخَوْا', #4
u'انتذرت': u'انْتَذَرْت', #1
u'انتزى': u'انتزى', #1
u'انتزى': u'انْتَزَى', #14
u'انتسج': u'انْتَسَجْ', #1
u'انتسفته': u'انْتَسَفَتْهُ', #1
u'انتسموا': u'انْتَسِمُوا', #1
u'انتشاب': u'انْتِشَابِ', #1
u'انتشاف': u'انْتِشَافِ', #1
u'انتشب': u'انْتَشَبَ', #1
u'انتشط': u'انْتَشَطَ', #2
u'انتضاه': u'انْتَضَاهُ', #1
u'انتضد': u'انْتَضَدَ', #3
u'انتضل': u'انْتَضَلَ', #1
u'انتضل': u'اِنْتَضَلَ', #2
u'انتضلوا': u'اِنْتَضَلُوا', #2
u'انتضوا': u'انْتَضَوْا', #1
u'أنتطف': u'أنتطف', #1
u'أنتطف': u'أَنْتَطِفْ', #1
u'أنتظرته': u'أَنْتَظَرَتْهُ', #1
u'انتظرنى': u'انْتَظِرْنِى', #1
u'إنتظروا': u'إنْتَظِرُوا', #1
u'انتظرى': u'انْتَظِرِى', #5
u'انتفاجة': u'انْتِفَاجَةُ', #1
u'انتفح': u'انْتَفَحَ', #3
u'انتفط': u'انْتَفَطَ', #2
u'انتقاب': u'انْتِقَابُ', #3
u'انتقابها': u'انْتِقَابِهَا', #1
u'انتقاضة': u'انْتِقَاضَةً', #2
u'انتقاعه': u'انْتِقَاعِهِ', #1
u'أنتقب': u'أَنْتَقِبُ', #1
u'انتقب': u'انْتَقَبَ', #1
u'انتقبت': u'انْتَقَبَتْ', #4
u'انتقخ': u'انْتَقَخَ', #1
u'انتقضهم': u'انْتَقَضَهُمْ', #1
u'انتقع': u'انْتَقِعْ', #1
u'انتقع': u'اُنْتُقِعَ', #2
u'انتقع': u'انْتَقَعَ', #5
u'انتقلى': u'انْتَقِلِى', #4
u'انتقمقوله': u'انْتَقَمَقَوْلُهُ', #1
u'انتكث': u'انْتَكَثَ', #1
u'انتكثت': u'انْتَكَثَتْ', #1
u'أنتمو': u'أَنْتُمُو', #1
u'انتهائم': u'انتهائم', #1
u'انتهش': u'انْتَهَشَ', #1
u'أنتهى': u'أَنْتَهَى', #1
u'إنتهى': u'إنتهى', #1
u'إنتهى': u'إنْتَهَى', #1
u'أنتهى': u'أَنْتَهِى', #3
u'انتهىإليه': u'انْتَهَىإِلَيْهِ', #1
u'انتهيتن': u'انْتَهَيْتُنَّ', #1
u'انتهيناإلى': u'انْتَهَيْنَاإِلَى', #1
u'انتوت': u'انْتَوَتْ', #1
u'انتول': u'انْتَوَلَ', #1
u'انتوى': u'انْتَوَى', #4
u'أنثتان': u'أُنْثَتَانِ', #1
u'انثرار': u'انْثِرَارٌ', #1
u'انثوت': u'انْثَوَتْ', #1
u'انثووا': u'انثووا', #1
u'انثوى': u'انثوى', #1
u'انثوى': u'انْثَوَى', #2
u'انثى': u'انثى', #1
u'أنثى': u'أُنْثًى', #2
u'إنجانة': u'إنْجَانَةٌ', #1
u'أنجانى': u'أَنْجَانِى', #2
u'انجحار': u'انْجِحَارَ', #2
u'انجدل': u'انْجَدَلَ', #1
u'انجدل': u'انْجَدِلْ', #1
u'انجدل': u'انْجَدَلْ', #2
u'انجرح': u'انْجَرَحَ', #2
u'أنجشة،': u'أَنْجَشَةُ،', #1
u'أنجشة': u'أَنْجَشَةَ', #2
u'أنجشة': u'أَنْجَشَةُ', #43
u'أنجشه': u'أَنَجْشُهُ', #1
u'أنجشه': u'أَنْجُشُهُ', #1
u'انجعافها': u'انْجِعَافُهَا', #5
u'انجعف': u'انْجَعَفَ', #2
u'انجفل': u'انْجَفَلَ', #3
u'انجفل': u'اِنْجَفَلَ', #4
u'انجمد': u'انْجَمَدَ', #11
u'آنجه': u'آنَجْه', #1
u'آنجه': u'آنجه', #5
u'آنح': u'آنِحْ', #1
u'انحاش': u'انْحَاشَ', #1
u'انحتامه': u'انْحِتَامِهِ', #2
u'انحتم': u'انْحَتَمَ', #2
u'انحجار': u'انْحِجَارُ', #2
u'انحجار': u'انْحِجَارَ', #4
u'انحجار': u'انْحِجَارِ', #9
u'انحجاره': u'انْحِجَارَهُ', #1
u'انحجاره': u'انْحِجَارُهُ', #1
u'انحجر': u'انحجر', #1
u'انحجر': u'انْحَجَرَ', #11
u'انحجز': u'اِنْحَجَزَ', #2
u'انحجزوا': u'انْحَجَزُوا', #3
u'انحرافة': u'انْحِرَافَةً', #1
u'انحرق': u'انْحَرَقَ', #1
u'انحرى': u'انْحَرِى', #1
u'انحست': u'اِنْحَسَّتْ', #1
u'انحش': u'اِنْحَشَّ', #1
u'انحفارا': u'انْحِفَارًا', #2
u'انحفر': u'انْحَفَرَ', #4
u'انحفرت': u'انْحَفَرَتْ', #2
u'آنخ': u'آنِخْ', #1
u'انختام': u'انْخِتَامِ', #1
u'انخزعت': u'انْخَزَعَتْ', #1
u'انخزعوا': u'انْخَزَعُوا', #1
u'انخزل': u'انْخَزَلَ', #5
u'انخلاق': u'انْخِلَاقَ', #1
u'انخلاقه': u'انْخِلَاقِهِ', #2
u'انخلق': u'انْخَلَقَ', #4
u'انخناس': u'انْخِنَاسٍ', #1
u'انخناس': u'انْخِنَاسَ', #4
u'انخنست': u'انْخَنَسَتْ', #1
u'آندا': u'آندا', #1
u'انداح': u'انْدَاحَ', #4
u'انداخت': u'انداخت', #1
u'انداز': u'انداز', #2
u'أنددركردن': u'أنددركردن', #1
u'اندرءوا': u'انْدَرَءُوا', #2
u'اندرأ': u'انْدَرَأَ', #1
u'أندرا': u'أَنْدَرًا', #2
u'اندرأت': u'انْدَرَأَتْ', #1
u'إندراسب': u'إندراسب', #1
u'اندراست': u'اندراست', #1
u'اندرآيي': u'اندرآيي', #1
u'اندرثر': u'اندرثر', #1
u'اندرجهانيد': u'اندرجهانيد', #1
u'أندرجوا': u'أَنْدَرَجُوا', #1
u'اندرشكست': u'اندرشكست', #1
u'أندرنباشم': u'أندرنباشم', #1
u'اندرنيايم': u'اندرنيايم', #1
u'أندروس': u'أندروس', #1
u'اندرين': u'اندرين', #20
u'اندلج': u'انْدَلَجَ', #1
u'أندملت': u'أَنْدَمَلَتْ', #1
u'اندو': u'اندو', #1
u'أندوج': u'أَنَدُوجُ', #1
u'اندوهمجنين': u'اندوهمجنين', #1
u'انديشم': u'انديشم', #1
u'أنذركموه': u'أُنْذِرُكُمُوهُ', #1
u'انذلق': u'انذلق', #1
u'أنذيت': u'أنذيت', #1
u'آنرابهاني': u'آنرابهاني', #1
u'آنراجدرى': u'آنراجدرى', #1
u'آنرامى': u'آنرامى', #1
u'آنرمى': u'آنرمى', #1
u'آنروزكه': u'آنروزكه', #1
u'إنزاء': u'إنْزَاءَ', #1
u'إنزاء': u'إِنْزَاء', #1
u'إنزاء': u'إِنْزَاءِ', #1
u'إنزاء': u'إنْزَاءُ', #15
u'إنزاء': u'إنْزَاءِ', #15
u'إنزاء': u'إنْزَاءٍ', #3
u'إنزاعه': u'إنْزَاعُهُ', #1
u'انزال': u'انزال', #1
u'إنزاها': u'إنْزَاهًا', #2
u'إنزاؤه': u'إنْزَاؤُهُ', #3
u'إنزائه': u'إنْزَائِهِ', #4
u'إنزائها': u'إِنْزَائِهَا', #1
u'انزلت': u'انزلت', #1
u'أنزلكه': u'أَنْزَلَكَهُ', #5
u'أنزلكها': u'أَنْزَلَكَهَا', #1
u'أنزلنى': u'أَنْزَلَنِى', #1
u'أنزلنيه': u'أَنْزِلْنِيهِ', #1
u'انزهاق': u'انْزِهَاقُ', #2
u'انزهق': u'انْزَهَقَ', #5
u'انزهقت': u'انْزَهَقَتْ', #2
u'أنزى': u'أَنْزَى', #19
u'أنس': u'أَنَسً', #2
u'أنساع': u'أَنْسَاعَ', #1
u'انسان': u'انسان', #1
u'انسانا': u'انسانا', #1
u'إنسانة': u'إنْسَانَةً', #1
u'انسانة،': u'انسانة،', #1
u'إنسانة': u'إنْسَانَةٌ', #4
u'أنسانيه': u'أنسانيه', #1
u'أنسانيه': u'أَنْسَانِيهُ', #12
u'أنسانيه': u'أَنْسَانِيهِ', #3
u'انسبتت': u'اِنْسَبَتَتْ', #1
u'انست': u'انست', #1
u'انسحج': u'انْسَحَجَ', #1
u'انسحلت': u'انْسَحَلَتْ', #2
u'أنسفأخرج': u'أَنَسٍفَأُخْرِجَ', #1
u'انسفال': u'انْسِفَالٌ', #1
u'أنسنهى': u'أَنَسٌنَهَى', #1
u'إنشاز': u'إنْشَازُ', #4
u'انشانده': u'انشانده', #1
u'انشايي': u'انشايي', #1
u'انشبكت': u'اِنْشَبَكَتْ', #1
u'أنشدنيه': u'أَنَشَدَنِيهِ', #1
u'أنشدنيه': u'أَنْشَدَنِيهِ', #2
u'أنشدنيها': u'أَنْشَدَنِيهَا', #25
u'انشلى': u'انْشَلَى', #4
u'انشمندي': u'انشمندي', #1
u'انصار': u'انصار', #2
u'إنصاصا': u'إنْصَاصًا', #1
u'انصان': u'انْصَانَ', #1
u'أنصائهم': u'أَنْصَائِهِمْ', #1
u'انصبابة': u'انْصِبَابَةً', #3
u'انصبغ': u'انْصَبَغَ', #27
u'انصدام': u'انْصِدَامٍ', #1
u'انصدام': u'انْصِدَامِ', #3
u'انصدم': u'انْصَدَمْ', #1
u'انصدم': u'انْصَدَمَ', #18
u'انصرافة': u'انْصِرَافَةً', #1
u'انصرافى': u'انْصِرَافِى', #1
u'انصرفعلى': u'انْصَرَفَعَلَى', #1
u'إنضاف': u'إنْضَاف', #1
u'انضحى': u'انضحى', #2
u'انضحى': u'انْضَحِى', #2
u'انضرارا': u'انْضِرَارًا', #3
u'انضمها': u'انْضَمّهَا', #1
u'إنطابلس': u'إنْطَابُلْسَ', #1
u'انطابلس،': u'انطابلس،', #1
u'أنطابلس': u'أَنْطَابُلُسَ', #2
u'إنطاكية': u'إنطاكية', #1
u'انطقى': u'انْطِقِى', #2
u'إنطلق': u'إنطلق', #1
u'انطلقى': u'انْطَلِقِى', #5
u'انطمت': u'انْطَمَّتْ', #2
u'أنطيتهم': u'أَنْطَيْتُهُمْ', #1
u'أنطيناك': u'أَنْطَيْنَاك', #2
u'أنظرنى': u'أَنْظِرْنِى', #1
u'أنظرى': u'أنظرى', #1
u'انظرى': u'انْظُرِى', #6
u'أنظرينى': u'أَنْظِرِينِى', #1
u'إنعاظ': u'إنعاظ', #1
u'إنعاظ': u'إنْعَاظٍ', #3
u'إنعاظ': u'إنْعَاظٌ', #4
u'إنعاظا': u'إنعاظا', #1
u'إنعاظا': u'إنْعَاظًا', #1
u'إنعاظه': u'إنْعَاظُهُ', #1
u'إنعاظه': u'إنعاظه', #2
u'إنعاظه': u'إنْعَاظِهِ', #6
u'إنعاظه': u'إنْعَاظَهُ', #8
u'انعد': u'انْعَدَّ', #1
u'انعذق': u'انْعَذَقْ', #1
u'أنعقدت': u'أَنْعَقَدَتْ', #1
u'انعلاق': u'انْعِلَاقَ', #2
u'انعلق': u'انْعَلَقَ', #11
u'انعوجت': u'انْعَوَجْت', #1
u'انعوجنا': u'انْعَوَجْنَا', #1
u'انغلب': u'انْغَلَبَ', #1
u'انغلبت': u'انْغَلَبَتْ', #1
u'انغماسة،': u'انْغِمَاسَةً،', #1
u'انغماسة': u'انْغِمَاسَةً', #2
u'إنفاع': u'إنْفَاعُ', #5
u'انفتاله': u'انْفِتَالِهِ', #1
u'أنفجت': u'أَنْفَجْتُ', #1
u'إنفجر': u'إنفجر', #1
u'أنفجنا': u'أَنْفَجْنَا', #13
u'إنفحة': u'إنْفَحَةً', #12
u'إنفحة': u'إنْفَحَةٌ', #5
u'إنفحة': u'إنْفَحَةٍ', #5
u'إنفحة': u'إنْفَحَةِ', #6
u'إنفحة': u'إنْفَحَةُ', #8
u'إنفحته': u'إنْفَحَتُهُ', #1
u'إنفحته': u'إِنْفَحَتُهُ', #1
u'إنفحتها': u'إنْفَحَتَهَا', #1
u'إنفحتها': u'إنْفَحَتِهَا', #1
u'انفحى': u'انفحى', #2
u'انفحى': u'انْفَحِى', #2
u'انفرداه': u'انْفَرَدَاهُ', #1
u'انفرش': u'انْفَرَشَ', #6
u'انفرض': u'انْفَرَضَ', #1
u'انفرى': u'انْفِرِى', #1
u'انفسد': u'انْفَسَدَ', #2
u'أنفسهموالوجه': u'أَنْفُسَهُمْوَالْوَجْهُ', #1
u'انفضخ': u'انْفَضَخَ', #1
u'آنفكاك': u'آنْفِكَاكِ', #1
u'انفهام': u'انْفِهَامَ', #1
u'انفهام': u'انْفِهَامُ', #4
u'انفهام': u'انْفِهَامِ', #4
u'انفهامه': u'انْفِهَامُهُ', #4
u'انفهامه': u'انْفِهَامِهِ', #9
u'انفهامها': u'انْفِهَامُهَا', #1
u'انفهامها': u'انْفِهَامِهَا', #1
u'انفهقت': u'انفهقت', #1
u'انفهقت': u'انْفَهَقَتْ', #4
u'إنقاد': u'إنْقَادِ', #1
u'إنقاد': u'إنْقَادٌ', #2
u'انقادى': u'انْقَادِى', #4
u'انقام': u'انْقَامَ', #2
u'انقحمت': u'انْقَحَمْت', #1
u'انقداح': u'انْقِدَاحِ', #2
u'انقدح': u'انْقَدَحَ', #14
u'انقدحت': u'انْقَدَحَتْ', #1
u'انقدم': u'انْقَدَمَ', #1
u'أنقروي': u'أَنْقِرْوِيٍّ', #1
u'أنقروي': u'أنقروي', #10
u'أنقروي': u'أَنْقِرْوِيّ', #19
u'أنقروي': u'أَنْقِرْوِيَّ', #2
u'أنقروي': u'أَنْقِرْوِيٌّ', #38
u'أنقسمت': u'أنقسمت', #1
u'انقصار': u'انْقِصَارُ', #1
u'إنقصاما': u'إنْقِصَامًا', #1
u'انقضه': u'اُنْقُضْهُ', #1
u'أنقطعت': u'أَنْقَطَعَتِ', #1
u'انقطعها': u'انْقَطَعَهَا', #1
u'انقمع': u'اِنْقَمَعَ', #2
u'انقمع': u'انْقَمَعَ', #4
u'انقمعت': u'انْقَمَعَتْ', #1
u'انقمعن': u'انْقَمَعْنَ', #1
u'إنكاء': u'إنْكَاءٍ', #1
u'إنكاء': u'إنْكَاءَ', #1
u'إنكاء': u'إنْكَاءِ', #1
u'إنكاء': u'إنْكَاءً', #3
u'إنكاء': u'إنْكَاءٌ', #3
u'آنكار': u'آنكار', #1
u'آنكار': u'آنِكَار', #2
u'إنكاسها': u'إِنْكَاسِهَا', #1
u'إنكان': u'إِنْكَانَ', #1
u'إنكائها': u'إنْكَائِهَا', #2
u'إنكائهم': u'إنْكَائِهِمْ', #1
u'أنكحتكها': u'أَنْكَحْتُكهَا', #11
u'أنكحتكها': u'أَنْكَحْتُكَهَا', #7
u'أنكحكها': u'أُنْكِحُكَهَا', #1
u'أنكحناكها': u'أَنْكَحْنَاكَهَا', #1
u'أنكحنى': u'أَنْكَحَنِى', #1
u'أنكحنيك': u'أَنْكَحَنِيكَ', #1
u'أنكحنيها': u'أَنْكِحْنِيهَا', #2
u'انكحى': u'انْكَحِى', #1
u'انكحى': u'انْكِحِى', #11
u'آنكس': u'آنَكَسَ', #1
u'انكشاط': u'انْكِشَاطِ', #1
u'انكشاطها': u'انْكِشَاطُهَا', #1
u'انكشافة': u'انْكِشَافَةٍ', #1
u'انكشطت': u'انْكَشَطَتْ', #10
u'انكشفها': u'انْكَشَفَهَا', #1
u'إنكه': u'إنَّكَهُ', #1
u'آنكه': u'آنَكِهَ', #2
u'آنكه': u'آنكه', #4
u'أنلزمكموها': u'أَنُلْزِمُكُمُوهَا', #3
u'انما': u'انما', #4
u'إنماط': u'إنْمَاطٌ', #1
u'انماع': u'انْمَاعَ', #11
u'انماعت': u'انْمَاعَتْ', #1
u'أنمالكا': u'أنمالكا', #1
u'انمساح': u'انْمِسَاحِ', #3
u'انمساح': u'انْمِسَاحُ', #5
u'انمساحه': u'انْمِسَاحِهِ', #3
u'انمساسه': u'انْمِسَاسُهُ', #2
u'انمسحت': u'انْمَسَحَتْ', #1
u'أنموذج': u'أَنَمُوذَجً', #1
u'انمياعه': u'انْمِيَاعِهِ', #3
u'اننا': u'انّنَا', #1
u'أنناسا': u'أَنَّنَاسًا', #1
u'إننالننظر': u'إِنَّنَالَنَنْظُرُ', #1
u'أننزى': u'أَنُنْزِى', #1
u'انني': u'انني', #1
u'إننى': u'إِنَّنِى', #2
u'انها': u'انها', #1
u'أنهاأنزلت': u'أَنَّهَاأُنْزِلَتْ', #1
u'أنهابقعة': u'أَنَّهَابُقْعَةٌ', #1
u'إنهإذا': u'إنَّهُإِذَا', #1
u'أنهإذا': u'أَنَّهُإِذَا', #2
u'إنهاش': u'إنْهَاشِ', #1
u'إنهاش': u'إنْهَاشُ', #2
u'أنهافتقر': u'أَنَّهُافْتَقَرَ', #1
u'أنهاكانت': u'أَنَّهَاكَانَتْ', #1
u'انهدر': u'انْهَدَرَ', #2
u'انهدرت': u'انْهَدَرَتْ', #2
u'أنهرأى': u'أَنَّهُرَأَى', #1
u'أنهريق': u'أَنُهَرِيقُ', #1
u'أنهريق': u'أَنُهْرِيقُ', #1
u'انهسوا': u'انْهَسُوا', #3
u'انهسوه': u'انْهَسُوهُ', #1
u'أنهسئل': u'أنهسئل', #1
u'أنهسئل': u'أَنَّهُسُئِلَ', #4
u'أنهلحق': u'أَنَّهُلَحِقَ', #1
u'أنهلما': u'أَنَّهُلَمَّا', #1
u'أنهمسجد': u'أَنَّهُمَسْجِدُ', #1
u'أنهمكانوا': u'أَنَّهُمْكَانُوا', #1
u'أنهن': u'أَنَّهُنًّ', #1
u'أنهنهى': u'أَنَّهُنَهَى', #8
u'إنهو': u'إِنَّهُوُ', #1
u'انهى': u'انْهَى', #1
u'أنؤاخذ': u'أَنُؤَاخَذُ', #9
u'أنواط': u'أَنْوَاطٍ', #27
u'أنواط،': u'أَنْوَاطٍ،', #4
u'أنوثيته': u'أُنُوثِيَّتَهُ', #1
u'أنوثيته': u'أُنُوثِيَّتِهِ', #5
u'أنوثيته': u'أُنُوثِيَّتُهُ', #6
u'أنوثيتهما': u'أُنُوثِيَّتِهِمَا', #2
u'أنوشروان': u'أَنُوشِرْوَانَ', #21
u'آنى': u'آنَى', #1
u'إنى': u'إنِّى', #1
u'«إنى': u'«إِنِّى', #1
u'إنى': u'إِنَى', #1
u'إنى': u'إِنِّى', #1662
u'إنى': u'إنًى', #2
u'انى': u'انى', #3
u'اني': u'اني', #4
u'إنى': u'إِنَّى', #7
u'إنية': u'إنية', #1
u'إنية': u'إنِّيَّةَ', #1
u'آنيت': u'آنَيْتَ', #1
u'إنيتها': u'إنِّيَّتِهَا', #1
u'أنيجانباشم': u'أنيجانباشم', #1
u'أنيرفع': u'أَنْيَرْفَعَ', #1
u'أنيسةعن': u'أُنَيْسَةَعَنْ', #1
u'أنيصل': u'أَنْيَصِلَ', #1
u'أنيصلي': u'أَنْيُصَلِّيَ', #1
u'أنيفة': u'أُنَيْفَة', #1
u'أنيفة': u'أُنَيْفَةُ', #1
u'أنيق': u'أَنِيقً', #3
u'أنيقرأ': u'أَنْيَقْرَأَ', #1
u'أنيقطعها': u'أَنْيَقْطَعَهَا', #1
u'أنيكك': u'أَنِيكُكِ', #1
u'أنيكك': u'أَنِيكُك', #3
u'أنيؤمن': u'أَنْيُؤْمِنَ', #1
u'أنيومئ': u'أنيومئ', #1
u'اه': u'اه', #18
u'اهـ': u'اهـ', #6
u'آها': u'آهًا', #1
u'أها': u'أَهَا', #5
u'إهالة': u'إهَالَةً', #1
u'إهالة': u'إِهَالَةِ', #1
u'إهالة': u'إهَالَةَ', #2
u'إهالة': u'إِهَالَةً', #2
u'إهالة': u'إِهَالَةٌ', #2
u'إهالة': u'إهَالَةِ', #26
u'إهالة': u'إهَالَةُ', #5
u'أهاويل': u'أَهَاوِيلُ', #2
u'آهب': u'آهَبَ', #1
u'أهببتنى': u'أَهْبَبْتَنِى', #1
u'اهتامه': u'اهْتَامَهُ', #1
u'اهتدا': u'اهْتِدَا', #1
u'اهتضام': u'اهْتِضَامٌ', #1
u'اهتضام': u'اهْتِضَامٍ', #1
u'اهتضام': u'اهْتِضَامَ', #1
u'اهتضام': u'اهْتِضَامُ', #2
u'اهتضاما': u'اهْتِضَامًا', #2
u'اهدنى': u'اهْدِنِى', #9
u'أهذا': u'أَهَذًّا', #4
u'أهراق': u'أُهَرَاقُ', #1
u'اهراق': u'اِهْرَاقَ', #1
u'أهراق': u'أَهْرَاقَ', #31
u'أهراق': u'أَهَرَاقَ', #9
u'إهراقة': u'إهراقة', #1
u'إهراقة': u'إهْرَاقَةً', #1
u'إهراقة': u'إِهْرَاقَةُ', #1
u'أهراقه': u'أَهَرَاقَهُ', #1
u'أهراقه،': u'أَهْرَاقَهُ،', #1
u'أهراقه': u'أَهْرَاقَهُ', #18
u'أهراقها': u'أَهْرَاقَهَا', #1
u'إهرياقا': u'إِهْرِيَاقًا', #1
u'أهريق': u'أَهَرِيقَ', #1
u'أهريق': u'أُهَرِيقَ', #12
u'أهريق': u'أُهَرِيقُ', #3
u'أهريق': u'أُهْرِيقَ', #32
u'أهريقت': u'أُهْرِيقَتْ', #7
u'أهريقه': u'أَهَرِيقُهُ', #1
u'أهريقه': u'أُهْرِيقَهُ', #1
u'أهريقه': u'أُهْرِيقُهُ', #2
u'أهريقوا': u'أُهْرِيقُوا', #2
u'أهريقوا': u'أَهْرِيقُوا', #9
u'أهريقوها': u'أَهْرِيقُوهَا', #5
u'أهريقى': u'أَهْرِيقِى', #1
u'اهل': u'اهْلِ', #1
u'اهل': u'اهْل', #27
u'اهلاكها،': u'اهلاكها،', #1
u'أهلالمدينة': u'أَهْلَالْمَدِينَةِ', #1
u'أهلب': u'أَهْلَبُ', #3
u'أهلب': u'أَهْلَبَ', #5
u'أهله26500id': u'أهله26500id', #1
u'اهله': u'اهله', #1
u'اهله،': u'اهله،', #1
u'اهلها': u'اهلها', #2
u'اهلها': u'اهْلِهَا', #4
u'أهلوههم،': u'أَهْلُوهُهُمْ،', #1
u'أهلى': u'أَهْلِّى', #1
u'أهلى': u'أَهْلِى', #146
u'أهلى': u'أَهْلِىَ', #2
u'أهلى': u'أَهِلِّى', #7
u'إهليجي': u'إهْلِيجِيٍّ', #1
u'إهليجيا': u'إهْلِيجِيًّا', #1
u'إهليلج': u'إهْلِيلَجٍ', #1
u'إهليلج': u'إهْلِيلَجَ', #1
u'إهليلج': u'إهْلِيلِجٍ', #1
u'إهليلجا': u'إهْلِيلَجًا', #1
u'أهليلجة': u'أَهْلِيلَجَةً', #1
u'إهليلجة': u'إهْلِيلِجَةً', #1
u'إهليلجة': u'إهْلِيلَجَةٌ', #2
u'إهليلجة': u'إهْلِيلَجَةً', #3
u'أهمنى': u'أَهَمَّنِى', #1
u'آهن': u'آهن', #1
u'آهنين': u'آهَنِين', #1
u'آهو': u'آهو', #2
u'آهو': u'آهُو', #28
u'أهوار': u'أَهْوَارَ', #1
u'اهودا': u'اهودا', #2
u'إهي': u'إِهِي', #2
u'أهى': u'أَهِىَ', #5
u'أهيا': u'أَهْيَا', #4
u'أهياه': u'أَهْيَاهُ', #5
u'أهيس': u'أَهْيَسَ', #1
u'أهيس': u'أَهْيَسُ', #1
u'أهيضب': u'أُهَيْضِبَ', #1
u'أهيضب': u'أُهَيْضِبُ', #1
u'أو': u'أًوَ', #1
u'إو': u'إو', #1
u'او': u'اوْ', #1
u'او': u'او', #3
u'أؤاجر': u'أُؤَاجِرُ', #1
u'أؤاجرك': u'أُؤَاجِرُكَ', #1
u'أؤاجرك': u'أُؤَاجِرْك', #1
u'أؤاجرك': u'أُؤَاجِرُك', #3
u'أؤاجره': u'أُؤَاجِرُهُ', #1
u'أؤاجرها': u'أُؤَاجِرَهَا', #2
u'أواحد': u'أَوَاحِدً', #1
u'أؤاخذ': u'أُؤَاخَذَ', #1
u'أؤاخذ': u'أُؤَاخَذُ', #1
u'أؤاخذك': u'أُؤَاخِذُكَ', #1
u'أؤاخذك': u'أُؤَاخِذْكَ', #2
u'أؤاخذكم': u'أُؤَاخِذْكُمْ', #1
u'أؤاخذكم': u'أُؤَاخِذُكُمْ', #4
u'أؤاخذكمقوله': u'أُؤَاخِذُكُمْقَوْلُهُ', #1
u'أؤاخذه': u'أُؤَاخِذُهُ', #2
u'أؤاخي': u'أُؤَاخِي', #2
u'أواصيل': u'أَوَاصِيلَ', #1
u'أواصيل': u'أَوَاصِيلُ', #1
u'أوافصدني': u'أَوَافْصِدُنِي', #1
u'آواق': u'آوَاقٍ', #2
u'أواقا': u'أَوَاقَّا', #1
u'أواقى': u'أَوَاقِى', #1
u'أوالا': u'أَوَالَا', #1
u'أوالب': u'أَوَالِبُ', #1
u'أوالتابعى': u'أوَالتَّابِعِىَّ', #1
u'أوالمثلة': u'أَوَالْمُثْلَةُ', #1
u'أوام': u'أَوَامُّ', #1
u'أوام': u'أَوَامَّ', #2
u'أؤامر': u'أُؤَامِرُ', #1
u'أؤامر': u'أُؤَامِرَّ', #1
u'أؤامر': u'أُؤَامِرَ', #2
u'أوإنا': u'أَوَإِنَّا', #1
u'أوإنما': u'أَوْإِنَّمَا', #1
u'أوانى': u'أَوَانِى', #4
u'آوانيهما': u'آوَانِيهِمَا', #1
u'أوبادا': u'أَوْبَادًا', #1
u'أؤبره': u'أُؤَبِّرُهُ', #1
u'أؤبرها': u'أؤبرها', #1
u'أوبزركترا': u'أوبزركترا', #1
u'أوبزركترين': u'أوبزركترين', #1
u'أوتالله': u'أَوَتَاللَّهِ', #1
u'اوتقى': u'اوْتَقَى', #1
u'اوتكلت': u'اوْتَكَلْتُ', #1
u'أؤتمر': u'أُؤْتُمِرَ', #1
u'أؤتمن': u'أُؤْتُمِنَ', #3
u'أؤتمن': u'أُؤْتَمَنَ', #4
u'اؤتنف': u'اُؤْتُنِفْ', #1
u'اوتهمت': u'اوْتَهَمْتُ', #1
u'أؤثمه': u'أُؤَثِّمُهُ', #1
u'أوجبو': u'أَوْجَبُو', #1
u'اؤجرني': u'اُؤْجُرْنِي', #2
u'أوجعتنى': u'أَوْجَعَتْنِى', #2
u'أوجعتنى': u'أَوْجَعْتَنِى', #3
u'اوجنك': u'اوجنك', #1
u'أوجه': u'أَوَجُهً', #1
u'أوحانوت': u'أَوَحَانُوتً', #1
u'أوخسب': u'أوخسب', #2
u'اوددت': u'اوددت', #1
u'أودعتكه': u'أَوْدَعْتَكَهُ', #1
u'أودعتكه': u'أَوْدَعْتُكَهُ', #4
u'أودعتكها': u'أَوْدَعْتُكَهَا', #1
u'أودعتكها': u'أَوْدَعْتُكهَا', #3
u'أودعتنيه': u'أَوَدَعَتْنِيهِ', #2
u'أودعتنيه': u'أَوْدَعْتَنِيهِ', #2
u'أودعنيه': u'أَوْدَعْنِيهِ', #1
u'أودعنيه': u'أَوْدِعْنِيهِ', #2
u'أودعنيه': u'أَوْدَعَنِيهِ', #75
u'أودعنيها': u'أَوْدَعْنِيهَا', #1
u'أودعنيها': u'أَوْدَعَنِيهَا', #33
u'أودمنهى': u'أودمنهى', #1
u'أودنة': u'أُودَنَةَ', #1
u'أودونم': u'أَوَدُونَمً', #1
u'أؤذي': u'أُؤْذِي', #1
u'أؤذيك': u'أُؤْذِيك', #1
u'أؤذيك': u'أُؤْذِيكَ', #1
u'أؤذيك': u'أُؤْذِيكِ', #1
u'أورابهيج': u'أورابهيج', #1
u'أوراشلم': u'أُورَاشَلِمُ', #1
u'أوراشلم': u'أَوْرْاشَلِمَ', #1
u'آوردسه': u'آوردسه', #1
u'آوردن': u'آوردن', #2
u'آورده': u'آوَرَدَهُ', #2
u'آورده': u'آورده', #3
u'آوردى': u'آوردى', #2
u'أورستاق': u'أَوَرُسْتَاقَ', #1
u'أورسليم': u'أُورْسُلَيْمٌ', #1
u'اوزارهم': u'اوزارهم', #1
u'أوزة': u'أَوَزَّةً', #1
u'أوزجند': u'أُوزْجَنْدَ', #10
u'أوزلغ': u'أُوزَلْغَ', #1
u'إوزون': u'إوَزُّونَ', #1
u'أوسبي': u'أَوَسَبْيً', #1
u'أوسة؟': u'أوسة؟', #1
u'أوسة': u'أَوْسَةٌ', #1
u'اوست': u'اوست', #1
u'أوسعيته': u'أَوْسَعِيَّتُهُ', #1
u'أوسلاح': u'أَوَسِلَاحً', #1
u'اوسه': u'اوسه', #4
u'أوصاف': u'أَوِصَافً', #1
u'أوصانى': u'أَوْصَانِى', #18
u'أوصنى': u'أَوْصِنِى', #2
u'أوضية': u'أَوْضِيَةٍ', #6
u'أوطلاق': u'أَوَطَلَاقً', #1
u'أوطئة': u'أَوْطِئَةِ', #3
u'أوعدنى': u'أَوْعَدَنِى', #1
u'أوعلى': u'أَوَعَلًى', #1
u'أوغندة': u'أُوغَنْدَة', #1
u'أوفاناه': u'أَوْفَانَاهُ', #1
u'أوفيتكها': u'أَوْفَيْتُكهَا', #1
u'أوفيتكها': u'أَوْفَيْتُكَهَا', #2
u'أوفيتنى': u'أَوْفَيْتَنِى', #2
u'أوفيكه': u'أُوفِيكَهُ', #1
u'أوفيكها': u'أُوَفِّيكهَا', #1
u'أوقيات': u'أُوقِيَّاتٌ', #1
u'أوقيات': u'أُوقِيَّاتِ', #1
u'أوقيات': u'أُوقِيَّاتٍ', #4
u'أوقيانوس': u'أُوقْيَانُوسَ', #1
u'أوقيانوس': u'أُوقْيَانُوسُ', #3
u'أوقيةS': u'أُوقِيّةًS', #1
u'أوكأ': u'أَوْكَأ', #1
u'أوكأ': u'أَوْكَأَ', #8
u'أوكأها': u'أَوْكَأَهَا', #1
u'أوكأها،': u'أَوْكَأَهَا،', #1
u'أوكثير': u'أَوَكَثِيرً', #1
u'آوكلة': u'آوَكِلَةً', #1
u'أوكه': u'أوكه', #1
u'أوكوا': u'أوكوا', #3
u'اوكويد': u'اوكويد', #1
u'أوكى': u'أَوْكَى', #4
u'أوكئ': u'أُوكِئَ', #2
u'أوكئه': u'أُوكِئُهُ', #1
u'أوكيت': u'أَوَكَيْت', #2
u'اول': u'اول', #1
u'اولادهم': u'اولادهم', #1
u'أولاس': u'أُولَاسَ', #1
u'أولة': u'أُولَةً', #1
u'أولة': u'أَوَّلَةٌ', #1
u'أولة': u'أَوَّلَةٍ', #3
u'أولدتيه': u'أَوَلَدْتِيهِ', #1
u'أولستاأسعى': u'أَوَلَسْتُاأَسْعَى', #1
u'آولله': u'آوَللّهِ', #1
u'أولهاالوجه': u'أَوَّلُهَاالْوَجْهُ', #1
u'اولوب': u'اولوب', #1
u'اولور': u'اولور', #1
u'أولور': u'أولور', #4
u'اولي': u'اولي', #1
u'أؤلئك': u'أُؤلَئِكَ', #2
u'أولياء': u'أَوْلِيَاءً', #5
u'أوليآؤهم': u'أَوْلِيَآؤُهُمُ', #1
u'أوليائى': u'أَوْلِيَائِى', #1
u'أوليكها': u'أُوَلِّيكهَا', #1
u'أوليكها': u'أُوَلِّيكَهَا', #3
u'أوم': u'أُومِ', #2
u'أوم': u'أَوْمِ', #3
u'أومخرجى': u'أَوَمُخْرِجِىَّ', #3
u'أومؤجل': u'أَوَمُؤَجَّلً', #1
u'أومى': u'أَوَمَى', #1
u'اومى': u'اومى', #1
u'أومي': u'أُومِي', #2
u'أومى': u'أَوْمَى', #5
u'أوميراث': u'أَوَمِيرَاثً', #1
u'اون': u'اون', #1
u'اونايزه': u'اونايزه', #1
u'أؤنبئكم': u'أَؤُنَبِّئُكُم', #1
u'أؤنبئكم': u'أَؤُنَبِّئُكُمْ', #5
u'أويأتى': u'أَوَيَأْتِى', #2
u'أويخرجونى': u'أَوْيُخْرِجُونِى', #1
u'أويدما': u'أُوَيْدِمًا', #2
u'أويس': u'أَوَيْسً', #1
u'أويسا': u'أُوَيْسًا', #15
u'أويسا،': u'أُوَيْسًا،', #3
u'أويسامتها': u'أَوَيُسَامِتُهَا', #1
u'أويكعنا': u'أُوَيْكَعُنَا', #1
u'أويكعنا': u'أُوَيْكِعُنَا', #1
u'آى': u'آىِ', #1
u'آى': u'آَىٌ', #1
u'أي': u'أَيًّ', #1
u'أى': u'أَى', #1
u'أى': u'أُىَّ', #1
u'اى': u'اى', #1
u'أى': u'أَىٌّ', #10
u'أى': u'أَىِ', #12
u'أى': u'أَىْ', #179
u'أى': u'أَىُّ', #190
u'آى': u'آىٍ', #2
u'إى': u'إِى', #25
u'آى': u'آىٌ', #3
u'أى؟': u'أَىُّ؟', #4
u'اي': u'اي', #4
u'أى': u'أى', #41
u'أى': u'أَىَّ', #49
u'إى': u'إِىْ', #5
u'أى؟': u'أَىٌّ؟', #6
u'أى': u'أَىِّ', #91
u'آئبون': u'آئِبُونَ', #1
u'ائتجروا': u'ائْتَجِرُوا', #2
u'ائتدب': u'اِئْتَدَبَ', #1
u'ائتدموا': u'ائْتَدِمُوا', #5
u'ائتساء': u'ائْتِسَاءً', #1
u'ائتسوا': u'ائْتَسَوْا', #1
u'ائتسى': u'ائْتَسَى', #1
u'ائتطم': u'ائْتَطَمَ', #2
u'ائتفكت': u'ائْتَفَكَتْ', #2
u'ائتلفته': u'ائْتَلَفَتْهُ', #1
u'ائتما': u'ائْتَمَّا', #3
u'ائتمام': u'ائْتِمَامَ', #2
u'ائتمام': u'ائْتِمَامُ', #35
u'ائتمام': u'ائْتِمَامٍ', #4
u'ائتمام': u'ائْتِمَامِ', #7
u'ائتماما': u'ائْتِمَامًا', #2
u'ائتمامه': u'ائْتِمَامُهُ', #8
u'ائتمامه': u'ائْتِمَامِهِ', #9
u'ائتمامها': u'ائْتِمَامُهَا', #2
u'ائتمامهم': u'ائْتِمَامُهُمْ', #1
u'ائتمبه': u'ائْتَمَّبِهِ', #1
u'ائتمتا': u'ائْتَمَّتَا', #3
u'ائتممن': u'ائْتَمَمْنَ', #1
u'أئتمنك': u'أَئْتَمِنُكَ', #1
u'أئتمنه': u'أَئْتَمِنُهُ', #1
u'ائتموا': u'اِئْتَمُّوا', #1
u'ائتموا': u'ائْتَمُّوا', #14
u'ائتناف': u'ائْتِنَافُ', #1
u'ائتناف': u'ائْتِنَافِ', #3
u'ائتنافا': u'ائْتِنَافًا', #1
u'ائتنف': u'ائْتَنِفِ', #1
u'ائتنف': u'ائْتَنِفْ', #1
u'ائتنف': u'ائْتَنَفَ', #3
u'ائتنفوا': u'اِئْتَنِفُوا', #1
u'ائتنى': u'ائْتِنِى', #19
u'ائتونى': u'ائْتُونِى', #20
u'ائتى': u'ائْتِى', #1
u'إئتيا': u'إِئْتِيَا', #3
u'إئتياني': u'إئْتِيَانِي', #1
u'أئذا': u'أَئِذَا', #11
u'أئذن': u'أئذَنْ', #1
u'أئذنوا': u'أئذنوا', #1
u'ائذنى': u'ائْذَنِى', #2
u'آئل': u'آئِلٍ', #2
u'آئل': u'آئِلِ', #2
u'آئل': u'آئِلُ', #3
u'آئلا': u'آئِلًا', #1
u'آئلة': u'آئِلَةٍ', #1
u'أئمةالحديث': u'أَئِمَّةُالحَدِيثِ', #1
u'أئمةهشام': u'أَئِمَّةٌهِشَامٌ', #1
u'أئنا': u'أَئِنَّا', #12
u'أئنا': u'أَئِنّا', #2
u'ايات': u'ايات', #2
u'اياتنا': u'ايَاتِنَا', #6
u'اياتها': u'ايَاتِهَا', #1
u'أيأتى': u'أَيَأْتِى', #8
u'أيأحاديث': u'أَيْأَحَادِيثُ', #1
u'إياد': u'إيَادَ', #1
u'إياد': u'إِيَاد', #1
u'إياد': u'إِيَادٌ', #10
u'إياد': u'إِيَادٍ', #19
u'إياد': u'إياد', #2
u'إياد': u'إِيَادَ', #2
u'إياد،': u'إِيَادٍ،', #3
u'اياد': u'اياد', #4
u'إياد': u'إِيَادِ', #50
u'إياد': u'إيَادِ', #7
u'إياد': u'إيَادٌ', #9
u'إياد': u'إيَادٍ', #9
u'إياد': u'إِيَادُ', #9
u'إيادا': u'إيَادًا', #1
u'أيادى': u'أَيَادَى', #1
u'إيار': u'إيَّارَ', #1
u'أيارض': u'أَيْارْضَ', #1
u'أيأرضى': u'أَيْأَرْضَى', #1
u'أياز': u'أَيَازٍ', #1
u'إياز': u'إيَازٍ', #5
u'أياس': u'أَيَاسَ', #1
u'إياس،': u'إِيَاسَ،', #10
u'إياس': u'إِيَاسِ', #102
u'إياس،': u'إياس،', #13
u'إياس': u'إِيَاسَ', #14
u'إياس': u'إيَاسٌ', #15
u'إياس': u'إياس', #18
u'إياس': u'إِيَاس', #3
u'إياس': u'إِيَاسٍ', #317
u'إياس': u'إيَاسُ', #33
u'إياس': u'إيَاسِ', #49
u'إياس،': u'إِيَاسٌ،', #5
u'إياس': u'إيَاسَ', #6
u'إياس': u'إِيَاسٌ', #6
u'إياس': u'إِيَاسُ', #79
u'إياس': u'إيَاسٍ', #87
u'إياس،': u'إِيَاسٍ،', #93
u'إياسا': u'إِيَاسًا', #1
u'إياسا': u'إيَاسًا', #6
u'إياسنا': u'إيَاسِنَا', #2
u'إياسه': u'إيَاسَهُ', #1
u'إياسه': u'إيَاسِهِ', #4
u'إياسها': u'إيَاسَهَا', #1
u'إياسها': u'إيَاسُهَا', #1
u'إياسها': u'إيَاسِهَا', #3
u'إياسهن': u'إيَاسِهِنَّ', #2
u'ايأسوا': u'ايْأَسُوا', #1
u'أيالخوف': u'أَيْالْخَوْفُ', #1
u'أيالذين': u'أَيْالَّذِينَ', #1
u'أيالفريقين': u'أَيْالْفَرِيقَيْنِ', #1
u'أيام': u'أَيَّامً', #1
u'إيام': u'إِيَام', #1
u'ايام،': u'ايام،', #1
u'ايام': u'ايام', #2
u'إياما': u'إيَامًا', #1
u'أيامالفطر': u'أَيَّامِالْفِطْرِ', #1
u'أيأمننى': u'أَيَأْمَنُنِى', #3
u'إيامها': u'إيَامِهَا', #1
u'أيإن': u'أَيْإِنَّ', #1
u'أيانق': u'أَيَانِقِ', #1
u'أيإني': u'أَيْإِنِّي', #1
u'أياه': u'أَيَّاهُ', #1
u'أياها': u'أَيَّاهَا', #6
u'أياهما': u'أَيَّاهُمَا', #1
u'إياى': u'إِيَّاىَ', #12
u'آيب': u'آيِبٌ', #1
u'آيب': u'آيِبٍ', #1
u'آيب': u'آيِبُ', #1
u'آيب': u'آيِبِ', #1
u'أيبا': u'أَيْبًا', #1
u'آيبا': u'آيِبًا', #2
u'أيبارئ': u'أَيُبَارِئُ', #1
u'أيبأعمالهم': u'أَيْبِأَعْمَالِهِمْ', #2
u'أيبسى': u'أَيْبِسِى', #1
u'أيبك': u'أَيْبَكُ', #1
u'أيبك': u'أَيْبَكَ', #4
u'أيبه،': u'أَيِبهِ،', #1
u'أيبوحي': u'أَيْبِوَحْي', #1
u'آيبون،': u'آيِبُونَ،', #4
u'آيبون': u'آيِبُونَ', #72
u'آيبين': u'آيِبِينَ', #2
u'إية': u'إيّة', #1
u'اية': u'ايَةٍ', #1
u'إيت': u'إِيتِ', #2
u'ايت': u'ايتِ', #4
u'إيتان': u'إيتَانٍ', #1
u'أيتحاصون': u'أَيَتَحَاصُّونَ', #2
u'ايتدام': u'ايتدام', #1
u'ايتدرمك': u'ايتدرمك', #2
u'أيتدم': u'أيتدم', #1
u'ايتدوكى': u'ايتدوكى', #1
u'ايتديكي': u'ايتديكي', #1
u'أيتسرر': u'أَيَتَسَرَّرُ', #1
u'أيتكارى': u'أَيَتَكَارَى', #2
u'ايتمش': u'ايتمش', #1
u'أيتمكه': u'أيتمكه', #1
u'ايتنى': u'ايتِنِى', #1
u'ايتهن': u'ايِتِهُنَّ', #1
u'أيتواضعانها': u'أَيَتَوَاضَعَانِهَا', #2
u'ايتوه': u'ايتُوهُ', #1
u'ايتوهم': u'ايتُوهُمْ', #1
u'ايجاب': u'ايجاب', #1
u'أيجتزئ': u'أَيَجْتَزِئُ', #1
u'أيجون': u'أيجون', #1
u'ايجون': u'ايجون', #2
u'أيحاص': u'أَيُحَاصُّ', #1
u'أيحتجم': u'أَيَحْتَجِمُ', #1
u'إيخافه': u'إيخَافِهِ', #1
u'أيخالدا': u'أَيْخَالِدًا', #1
u'آيد': u'آيَدُ', #1
u'آيد': u'آيد', #6
u'آيد': u'آيَد', #8
u'آيدا': u'آيَدًا', #1
u'آيداي': u'آيداي', #1
u'آيدبر': u'آيدبر', #2
u'آيدكه': u'آيدكه', #2
u'أيدوب': u'أيدوب', #1
u'آيدوتن': u'آيدوتن', #1
u'إيذن': u'إِيذَنْ', #1
u'ايذن': u'ايذَنْ', #3
u'ايذن': u'اِيذَنْ', #3
u'آير': u'آير', #1
u'إيرج': u'إيرج', #1
u'أيزدبروي': u'أيزدبروي', #1
u'آيسا': u'آيِسًا', #30
u'أيسة': u'أَيِسَةً', #1
u'آيسة': u'آيِسَةً', #121
u'آيسة': u'آيِسَةٌ', #26
u'آيسة': u'آيِسَةٍ', #45
u'آيست': u'آيَسَتْ', #2
u'آيست': u'آيَسْت', #2
u'آيست': u'آيَسْتُ', #2
u'أيستبني': u'أَيَسْتَبُّنِي', #1
u'أيستتاب': u'أَيُسْتَتَابُ', #1
u'ايستد': u'ايستد', #1
u'أيستنثر': u'أَيَسْتَنْثِرُ', #1
u'آيسته': u'آيَسْتَهُ', #1
u'أيسجدها': u'أَيَسْجُدُهَا', #2
u'أيسميع': u'أَيْسَمِيعٌ', #1
u'أيسميع': u'أَيْسُمَيْعٌ', #1
u'آيسه': u'آيَسَهُ', #4
u'آيسون': u'آيِسُونَ', #2
u'آيسين': u'آيِسِينَ', #1
u'آيسين': u'آيِسَيْنِ', #1
u'أيش': u'أَيْش', #1
u'أيش': u'أَيْشَ', #1
u'أيش': u'أَيْشُ', #1
u'أيش': u'أَيْشْ', #1
u'إيش': u'إيشَ', #1
u'إيش': u'إَيْشٍ', #1
u'أيش': u'أَيْشٌ', #2
u'أيش': u'أَيْشٍ', #28
u'أيش': u'أيش', #3
u'إيش': u'إِيشْ', #3
u'إيش': u'إيشِ', #5
u'إيش': u'إيشْ', #7
u'إيشان': u'إيشان', #1
u'ايشان': u'ايشان', #7
u'ايشانرا': u'ايشانرا', #1
u'أيشلسم': u'أيشلسم', #1
u'إيصدرون': u'إيَصْدُرُونَ', #1
u'أيضاااا': u'أَيْضًاااا', #1
u'إيضاب': u'إيضَابِ', #1
u'أيطؤها': u'أَيَطَؤُهَا', #8
u'أيعبرة': u'أَيْعِبْرَةً', #1
u'أيعذاب': u'أَيْعَذَابُ', #1
u'أيعليم': u'أَيْعَلِيمٌ', #3
u'أيفكيدوني': u'أَيْفَكِيدُونِي', #1
u'أيفلم': u'أَيْفَلَمْ', #1
u'أيفليجمعوا': u'أَيْفَلْيُجْمِعُوا', #1
u'إيقاعتين': u'إيقَاعَتَيْنِ', #1
u'أيقرآن': u'أَيُقْرَآنِ', #1
u'أيقطعا': u'أَيْقَطْعًا', #1
u'أيقظنى': u'أَيْقَظَنِى', #7
u'إيكاء': u'إيكَاءُ', #3
u'إيكافا': u'إيكَافًا', #1
u'أيكوز': u'أيكوز', #1
u'ايكي': u'ايكي', #1
u'آيل': u'آيِل', #1
u'آيل': u'آيِلَ', #1
u'آيل': u'آيِلِ', #1
u'إيل': u'إيل', #1
u'إيل': u'إِيلْ', #1
u'إيل': u'إيّلُ', #1
u'إيل': u'إيَّلٍ', #1
u'إيل': u'إيَّلُ', #1
u'إيل': u'إِيَلُ', #1
u'آيل': u'آيِلٍ', #31
u'إيل': u'إيَّلَ', #4
u'آيل': u'آيِلٌ', #59
u'إيلا': u'إِيلاً', #1
u'إيلا': u'إيَّلَا', #2
u'آيلا': u'آيِلًا', #28
u'إيلات': u'إيلَاتَ', #1
u'إيلاجة': u'إيلَاجَةٍ', #1
u'إيلاها': u'إيلَاهَا', #1
u'آيلة': u'آيِلَةَ', #1
u'أيلة': u'أيلة', #1
u'أيلة': u'أَيْلة', #1
u'أيلة': u'أَيْلَةٌ', #1
u'ايلة': u'ايلة', #1
u'آيلة': u'آيِلَةٌ', #18
u'آيلة': u'آيِلَة', #2
u'أيلة': u'أَيْلَة', #2
u'أيلة': u'أَيْلَةُ', #4
u'أيلة،': u'أَيْلَةَ،', #6
u'آيلة': u'آيِلَةٍ', #7
u'آيلة': u'آيِلَةً', #8
u'أيلة': u'أَيْلَةَ', #83
u'إيلسه': u'إيلسه', #1
u'ايلسه': u'ايلسه', #1
u'أيلسه': u'أيلسه', #2
u'أيلشتمناك': u'أَيْلَشَتَمْنَاكَ', #1
u'ايلمش': u'ايلمش', #1
u'إيله': u'إيله', #1
u'أيلولته': u'أَيْلُولَتِهِ', #1
u'أيلولتها': u'أَيْلُولَتِهَا', #1
u'أيلى': u'أَيْلَى', #2
u'إيليا': u'إيلْيَا', #1
u'إيليا،': u'إِيلِيَا،', #1
u'إيليا،': u'إِيلْيَا،', #1
u'إيليا': u'إِيلْيَا', #4
u'إيليا': u'إِيلِيَا', #5
u'أيلياء': u'أَيْلَياء', #1
u'إيلياء': u'إيلياء', #1
u'إيلياء،': u'إيلياء،', #1
u'إيلياء': u'إيلِيَاء', #1
u'إيلياء': u'إيلْيَاءَ', #13
u'إيلياء': u'إيلِيَاءِ', #2
u'إيلياء': u'إِيلِيَاءَ', #21
u'إيلياء': u'إِيلْيَاءَ', #3
u'إيلياء،': u'إِيلِيَاءَ،', #3
u'إيلياء': u'إيلِيَاءَ', #37
u'إيلياء': u'إيلِيَاءُ', #9
u'أيليس': u'أَيْلَيْسَ', #1
u'آيم': u'آيُمَّ', #1
u'ايم': u'ايْمُ', #3
u'آيم': u'آيم', #4
u'ايم': u'اَيْمُ', #7
u'إيماناوالوجه': u'إِيمَانًاوَالْوَجْهُ', #2
u'إيمانة': u'إيمَانَةِ', #1
u'أيمانكم': u'أَيْمَانُكُمًًًًْ', #1
u'إيمانهموالوجه': u'إِيمَانِهِمْوَالْوَجْهُ', #1
u'ايمائهم': u'ايمائهم', #1
u'ايمش': u'ايمش', #1
u'أيمطوقة': u'أَيْمُطَوَّقَةٌ', #1
u'أيمنيرا': u'أَيْمُنِيرًا', #1
u'اين': u'ايْنَ', #1
u'اين': u'ايْن', #3
u'اين': u'اين', #35
u'اينجا': u'اينجا', #2
u'اينجنين': u'اينجنين', #1
u'اينحال': u'اينحال', #1
u'اينخانه': u'اينخانه', #3
u'آيند': u'آيند', #1
u'اينك': u'اينك', #5
u'اينكار': u'اينكار', #1
u'أينكارنكر': u'أينكارنكر', #1
u'إينكارنكنم': u'إينكارنكنم', #1
u'اينكارنكنم': u'اينكارنكنم', #1
u'أينكارنكنم': u'أينكارنكنم', #2
u'اينكت': u'اينكت', #1
u'اينكه': u'اينكه', #4
u'إينما': u'إينما', #1
u'آيه': u'آيَهً', #1
u'إيها': u'إِيْهًا', #1
u'إيها': u'إيهًا', #5
u'إيها': u'إِيهًا', #5
u'أيهاالنبي': u'أَيُّهَاالنَّبِيُّ', #2
u'أيهات': u'أيهات', #1
u'أيهات': u'أَيْهَاتَ', #1
u'أيهات،': u'أَيْهَاتَ،', #1
u'أيهاه': u'أيهاه', #1
u'أيهاه': u'أَيْهَاهْ', #6
u'أيهذا': u'أَيُّهَذَا', #1
u'أيهذا': u'أَيّهَذَا', #5
u'أيهراق': u'أَيُهْرَاقُ', #2
u'أيهلكة': u'أَيْهَلَكَةٍ', #1
u'إيهيه': u'إِيهِيهِ', #2
u'أيؤاجرها': u'أَيُؤَاجِرُهَا', #1
u'أيؤاخذ': u'أيؤاخذ', #1
u'أيؤاخذ': u'أَيُؤَاخِذُ', #1
u'أيؤاخذ': u'أَيُؤَاخَذُ', #5
u'أيوالله': u'أَيْوَاللَّهِ', #1
u'أيوام': u'أَيْوَامٍ', #1
u'أيوان': u'أَيْوَانَ', #1
u'أيوب': u'أَيُّوبً', #1
u'أيور': u'أُيُورُ', #4
u'أيوقار': u'أَيْوَقَارٌ', #1
u'أييتقدموه': u'أَيْيَتَقَدَّمَوهُ', #1
u'أييشركون': u'أَيْيُشْرِكُونَ', #2
u'أييطعنون': u'أَيْيَطْعَنُونَ', #1
u'أييعجل': u'أَيْيُعَجِّلُ', #1
u'بأ': u'بِأُ', #1
u'با': u'با', #13
u'با': u'َبَا', #2
u'با': u'بَا', #5
u'با': u'بِا', #7
u'باءات': u'بَاءَاتٍ', #3
u'باءوا': u'بَاءُوا', #4
u'باب': u'بَابً', #1
u'بأبا': u'بِأَبَا', #3
u'بابازير': u'بابازير', #1
u'بإباق': u'بِإِبَاقٍ', #18
u'بإباق': u'بِإِبَاقِ', #3
u'بإباقه': u'بِإِبَاقِهِ', #50
u'بإباقها': u'بِإِبَاقِهَا', #1
u'بأبان': u'بأبان', #1
u'بأبان': u'بِأَبَانَ', #2
u'بأبانين': u'بِأَبَانِينَ', #1
u'بإباية': u'بِإِبَايَةِ', #2
u'بأبة': u'بِأَبَّةِ', #1
u'بابة': u'بَابَةَ', #3
u'بابتداء': u'بِابْتِدَاءً', #1
u'بابتداره': u'بِابْتِدَارِهِ', #1
u'بابتدئ': u'بِابْتَدِئْ', #2
u'بابتكم': u'بَابَتِكُمْ', #1
u'بأبدا': u'بِأَبَدًا', #13
u'بأبرأتك': u'بِأَبْرَأْتُك', #1
u'بأبرأتك': u'بِأَبْرَأْتُكَ', #1
u'بأبرأتني': u'بِأَبْرَأْتَنِي', #1
u'بأبرأته': u'بِأَبْرَأَتْهُ', #1
u'بإبراهيمي': u'بِإِبْرَاهِيمِيِّ', #1
u'بإبراهيمي': u'بِإِبْرَاهِيمِيٍّ', #3
u'بأبردوا': u'بِأَبْرِدُوا', #1
u'بإبريسم': u'بإبريسم', #1
u'بإبريسم': u'بِإِبْرَيْسَمٍ', #10
u'بابزن': u'بابزن', #1
u'بابشاذ': u'بَابْشَاذَ', #5
u'بإبضاعها': u'بِإِبْضَاعِهَا', #2
u'بأبطلتها': u'بِأَبْطَلْتُهَا', #1
u'بأبطلنا': u'بِأَبْطَلْنَا', #1
u'بإبعاضه': u'بِإِبْعَاضِهِ', #1
u'بأبعرة': u'بِأَبْعِرَةٍ', #1
u'بأبغض': u'بِأَبْغَضُ', #1
u'بآبق': u'بِآبِقٍ', #20
u'بأبقى': u'بِأَبْقَى', #1
u'بآبقي': u'بِآبِقِي', #4
u'بأبقيت': u'بِأَبْقَيْتُ', #2
u'بأبقيت': u'بِأَبْقَيْت', #4
u'بأبلاه': u'بِأَبْلَاهُ', #2
u'بأبلغية': u'بِأَبْلَغِيَّةِ', #2
u'بأبلغيتها': u'بِأَبْلَغِيَّتِهَا', #3
u'بأبلوجة': u'بِأُبْلُوجَةٍ', #1
u'بأبنت': u'بِأَبَنْتُ', #5
u'بأبنتك': u'بِأَبَنْتُك', #2
u'بابنتى': u'بِابْنَتِى', #2
u'بابنوس،': u'بَابَنُوسَ،', #1
u'بابنوس': u'بَابَنُوسَ', #9
u'بابنى': u'بِابْنَىِ', #1
u'بابنى': u'بِابْنَىْ', #2
u'بابنى': u'بِابْنِى', #3
u'بأبؤس': u'بِأَبْؤُسِ', #1
u'بابوس': u'بَابُوسُ', #1
u'بأبوى': u'بِأَبَوَىَّ', #1
u'بأبى': u'بِأَبِى', #117
u'بابى': u'بَابَىْ', #3
u'بابى': u'بَابِى', #7
u'بأبيار': u'بِأَبْيَارِ', #8
u'بأبيح': u'بِأُبِيحَ', #1
u'بأبيني': u'بِأَبِينِي', #3
u'باتبعك': u'بِاتَّبَعَك', #1
u'باتبعوا': u'بِاتَّبَعُوا', #1
u'باتجاذكم': u'باتجاذكم', #1
u'باتخذ': u'بِاتَّخَذَ', #1
u'باتخذ': u'بِاتُّخِذَ', #1
u'باتخذه': u'بِاتَّخَذَهُ', #1
u'باتصل': u'بِاتَّصَلَ', #2
u'باتفقا': u'بِاتَّفَقَا', #4
u'بأتلف': u'بِأَتْلَفَ', #1
u'بأتلفهما': u'بِأَتْلَفَهُمَا', #1
u'باتله': u'بَاتِلُهُ', #1
u'باتهاب': u'بِاتِّهَابٍ', #5
u'باتهابه': u'بِاتِّهَابِهِ', #1
u'بإتهامهم': u'بِإِتْهَامِهِمْ', #2
u'بآتوا': u'بِآتُوا', #1
u'بإتواء': u'بِإِتْوَاءِ', #2
u'بإتوائه': u'بإتوائه', #1
u'باتوجه': u'باتوجه', #1
u'باتودر': u'باتودر', #1
u'باتوراست': u'باتوراست', #1
u'باتوسخن': u'باتوسخن', #1
u'باتونباشمي': u'باتونباشمي', #1
u'باتونمي': u'باتونمي', #1
u'بأتى': u'بِأَتَى', #4
u'بأثابكم': u'بِأَثَابَكُمْ', #1
u'بإثبانه': u'بِإِثْبَانِهِ', #1
u'بأثبت': u'بِأَثْبَتِ', #2
u'بأثبت': u'بِأَثْبَتَ', #37
u'بأثكال': u'بِأَثْكَالِ', #1
u'بإثكال': u'بَإِثْكَالِ', #1
u'بإثكال': u'بِإِثْكَالٍ', #1
u'بإثكال': u'بِإِثْكَالِ', #2
u'بأثكول': u'بَأَثْكُولِ', #1
u'بأثم': u'بِأَثِمٍ', #2
u'بأثم': u'بِأَثِمَ', #3
u'بإثمد': u'بِإِثْمِدٍ', #18
u'بإثمد': u'بِإِثْمِدِ', #2
u'بأثمر': u'بِأَثْمَرَ', #1
u'باثنى': u'بِاثْنَى', #1
u'بأثنى': u'بِأُثْنَى', #2
u'باثنى': u'بِاثْنَىْ', #6
u'بأثواركم': u'بِأَثْوَارِكُمْ', #1
u'بأثيب': u'بِأُثِيبَ', #2
u'بأجأ': u'بِأَجَأِ', #1
u'بأجابوا': u'بِأَجَابُوا', #1
u'بإجامه': u'بإجامه', #1
u'باجامه': u'باجامه', #1
u'بإجانات': u'بِإِجَّانَاتِ', #1
u'بأجبت': u'بِأَجَبْت', #1
u'بأجبت': u'بِأَجَبْتُ', #1
u'بأجبنكم': u'بِأَجْبَنِكُمْ', #2
u'باجة': u'بَاجَةِ', #1
u'باجة': u'بَاجَّةٍ', #1
u'باجة': u'بَاجَةَ', #10
u'باجتزائها': u'بِاجْتِزَائِهَا', #1
u'باجتنبوا': u'بِاجْتَنَبُوا', #2
u'باجتهد': u'بِاجْتَهِدْ', #1
u'باجتهدا': u'بِاجْتَهَدَا', #1
u'باجتين': u'بَاجَّتَيْنِ', #5
u'بأجد': u'بِأَجِدُ', #1
u'بإجذاع': u'بِإِجْذَاعِ', #2
u'بأجرأ': u'بِأَجْرَأ', #1
u'بأجرأ': u'بِأَجْرَأَ', #1
u'بأجرة': u'بِأُجْرَةً', #1
u'بأجرت': u'بِأَجَّرْتُ', #1
u'بأجروان': u'بأجروان', #1
u'بأجرى': u'بِأَجْرَى', #1
u'بإجريا': u'بِإِجْرِيّا', #4
u'بأجزأ': u'بِأَجْزَأَ', #6
u'بأجزأته': u'بِأَجْزَأَتْهُ', #2
u'بأجزاع': u'بِأَجْزَاعِ', #2
u'بأجزت': u'بِأَجَزْتُ', #2
u'بأجسم': u'بِأَجْسَمَ', #1
u'بأجسم': u'بِأَجْسَمِ', #1
u'بإجعالهم': u'بِإِجْعَالِهِمْ', #1
u'بأجعل': u'بِأَجْعَلُ', #1
u'باجعلا': u'بِاجْعَلَا', #1
u'بأجلت': u'بِأُجِّلَتْ', #1
u'بأجلح': u'بِأَجْلَحَ', #1
u'بأجلى': u'بِأَجْلَى', #2
u'بإجمار': u'بِإِجْمَارِ', #6
u'بأجنادين،': u'بأجْنَادَيْن،', #1
u'بأجنادين': u'بِأَجْنَادَيْنِ', #1
u'بأجنادين': u'بِأَجْنَادِينَ', #16
u'بأجنادين،': u'بأجنادين،', #3
u'بأجنادين': u'بأجنادين', #6
u'بأجنادين': u'بِأَجْنَادَيْنَ', #6
u'باجندان': u'باجندان', #1
u'بأجهضت': u'بِأَجْهَضَتْ', #1
u'بأجهضت': u'بِأُجْهِضَتْ', #1
u'باجوري': u'بَاجُورِيٌّ', #1
u'باجوري': u'بَاجُورِيّ', #4
u'بأجيرد': u'بِأُجَيْرِدٍ', #1
u'بأحببت': u'بِأَحْبَبْتُ', #1
u'بأحبلها': u'بِأَحْبَلَهَا', #2
u'باحتزام': u'بِاحْتِزَامٍ', #1
u'باحتشاش': u'بِاحْتِشَاشٍ', #1
u'باحتياز': u'بِاحْتِيَازِ', #2
u'بأحج': u'بِأَحُجُّ', #1
u'بإحجاج': u'بِإِحْجَاجِ', #2
u'بإحجاجه': u'بِإِحْجَاجِهِ', #1
u'بأحدا': u'بِأَحَدًا', #1
u'بإحداد': u'بِإِحْدَادِ', #2
u'بإحدهما': u'بِإِحَدِهِمَا', #1
u'بأحرقته': u'بِأَحْرَقَتْهُ', #1
u'بأحرم': u'بِأَحْرَمَ', #4
u'بإحسانالوجه': u'بِإِحْسَانٍالْوَجْهُ', #1
u'بإحسانقوله': u'بِإِحْسَانٍقَوْلُهُ', #1
u'باحسه': u'باحسه', #1
u'بإحصار': u'بِإِحْصَارِ', #1
u'بإحصار': u'بِإِحْصَارٍ', #9
u'بأحصن': u'بِأَحْصَنَ', #3
u'بأحضر': u'بِأَحْضَرَ', #2
u'بأحظ': u'بِأَحَظَّ', #1
u'بإحفاء': u'بِإِحْفَاءِ', #7
u'بأحفته': u'بِأَحِفَّتِهِ', #1
u'بأحفتها': u'بِأَحِفَّتِهَا', #2
u'بأحقيته': u'بِأَحَقِّيَّتِهِ', #2
u'بأحل': u'بِأَحَلَّ', #2
u'بأحلتك': u'بِأَحَلْتُكَ', #1
u'بأحلف': u'بِأَحْلِفُ', #4
u'بأحللنا': u'بِأَحْلَلْنَا', #2
u'بأحمدا': u'بِأَحْمَدَا', #1
u'بأحموقة': u'بِأُحْمُوقَةٍ', #1
u'بأحوط': u'بِأَحْوَط', #1
u'بأحوط': u'بِأَحْوَطِ', #1
u'بأحوطهما': u'بِأَحْوَطِهِمَا', #3
u'باحويه': u'بَاحَوَيهِ', #1
u'باحويه،': u'بَاحَوَيْهِ،', #1
u'باحويه': u'بَاحَوَيْهِ', #3
u'باخبار': u'باخبار', #1
u'باخباره': u'باخباره', #1
u'بأخبر': u'بِأَخْبَرَ', #7
u'بأخبرنا': u'بأَخْبَرَنَا', #1
u'بأخبرنا': u'بِأَخْبَرِنَا', #1
u'بأخبرنا': u'بِأَخْبَرَنَا', #2
u'باختارت': u'بِاخْتَارَتْ', #1
u'باختاري': u'بِاخْتَارِي', #2
u'باخترت': u'بِاخْتَرْت', #3
u'باخترت': u'بِاخْتَرْتُ', #7
u'باختلاع': u'بِاخْتِلَاعِ', #2
u'باختلاعها': u'بِاخْتِلَاعِهَا', #8
u'باختلط': u'بِاخْتَلَطَ', #1
u'باختلعت': u'بِاخْتَلَعْتُ', #1
u'باختلف': u'بِاخْتَلَفَ', #1
u'باختن': u'باختن', #1
u'باختيارا': u'بِاخْتِيَارًا', #1
u'باختيارة': u'بِاخْتِيَارَةٍ', #3
u'بأختيتها': u'بِأُخْتِيَّتِهَا', #1
u'باخداكه': u'باخداكه', #1
u'بإخدام': u'بِإِخْدَامِ', #1
u'بإخدامها': u'بِإِخْدَامِهَا', #4
u'بأخذت': u'بِأَخَذْت', #1
u'بأخذت': u'بِأَخَذْتَ', #1
u'بأخذت': u'بِأَخَذْتُ', #1
u'بإخرابه': u'بِإِخْرَابِهِ', #2
u'بإخراق': u'بِإِخْرَاقِ', #1
u'بأخرج': u'بِأَخْرَجَ', #3
u'بأخرجها': u'بِأَخْرَجَهَا', #1
u'بأخس': u'بِأَخَسِّ', #8
u'بأخسها': u'بِأَخَسِّهَا', #1
u'بأخسهما': u'بِأَخَسِّهِمَا', #3
u'بأخشم': u'بِأَخْشَمَ', #8
u'بإخصاء': u'بِإِخْصَاءِ', #1
u'بإخصائه': u'بِإِخْصَائِهِ', #1
u'بإخصائها': u'بِإِخْصَائِهَا', #1
u'بأخصر': u'بأخصر', #1
u'بأخصر': u'بِأَخْصَرَ', #4
u'بأخصر': u'بِأَخْصَرِ', #6
u'باخق': u'بَاخِقَ', #1
u'باخق': u'بِاخَقٌ', #1
u'بأخى': u'بِأَخِى', #4
u'بأخية؟،': u'بِأُخَيَّةٍ؟،', #1
u'باخيره': u'باخيره', #1
u'باخين': u'باخين', #1
u'بأد': u'بِأَدِّ', #1
u'بادءهم': u'بادءهم', #1
u'باداست': u'باداست', #1
u'بادان': u'بَادَانِ', #1
u'بادبان': u'بادبان', #2
u'بأدبت': u'بِأُدِّبَتْ', #3
u'بإدخاره': u'بِإِدْخَارِهِ', #1
u'بادخانة': u'بادخانة', #1
u'بأدخل': u'بِأَدْخَلَ', #1
u'بأدخل': u'بِأَدْخَلِ', #1
u'بادخلوها': u'بِادْخُلُوهَا', #1
u'بأدركتم': u'بِأَدْرَكْتُمْ', #1
u'بادرنى': u'بَادَرَنِى', #1
u'بادزار': u'بادزار', #1
u'بادشاه': u'بادشاه', #2
u'بادشاه': u'بَادْشَاهْ', #7
u'بادشمنان': u'بادشمنان', #1
u'بادعى': u'بِادَّعَى', #6
u'بادفع': u'بِادْفَعْ', #1
u'بادكار': u'بِادِّكَارِ', #1
u'بادكاره': u'بِادِّكَارِهِ', #1
u'بادكاري': u'بِادِّكَارِي', #1
u'بادكن': u'بادكن', #1
u'بادماج': u'بِادِّمَاجِ', #1
u'بآدمى': u'بِآدَمِىٍّ', #1
u'بادهان': u'بِادِّهَانٍ', #1
u'بادهانه': u'بِادِّهَانِهِ', #2
u'بإدهانهم': u'بِإِدْهَانِهِمْ', #1
u'بادهانهم': u'بِادِّهَانِهِمْ', #1
u'بادهنج': u'بادهنج', #1
u'بأدوأ': u'بِأَدْوَأِ', #1
u'بأدون': u'بِأَدْوَنَ', #4
u'بأدونه': u'بِأَدْوَنِهِ', #1
u'بأدونهما': u'بِأَدْوَنِهِمَا', #1
u'بأدى': u'بِأَدَّى', #2
u'بأديت': u'بِأَدَّيْت', #1
u'بأذ': u'بِأَذٍ', #1
u'بإذ': u'بِإِذْ', #10
u'باذ': u'باذ', #3
u'بإذا': u'بِإِذَا', #89
u'بأذاخر': u'بِأَذَاخِرَ', #2
u'باذام،': u'باذام،', #1
u'باذام،': u'بَاذَامُ،', #1
u'باذام': u'بَاذَامُ', #2
u'باذام،': u'بَاذَامَ،', #2
u'باذام': u'بَاذَامَ', #3
u'باذان،': u'بَاذَانُ،', #1
u'باذان': u'بَاذَانَ', #15
u'باذان': u'بَاذَانُ', #9
u'بإذاية': u'بِإِذَايَةِ', #3
u'بإذايتك': u'بِإِذَايَتِكَ', #2
u'بإذايته': u'بِإِذَايَتِهِ', #1
u'باذة': u'بَاذَّةُ', #1
u'بإذخر': u'بِإِذْخِرٍ', #7
u'بإذخرة': u'بِإِذْخِرَةٍ', #6
u'بأذرائنا': u'بِأَذْرَائِنَا', #4
u'بأذرح': u'بِأَذْرُحَ', #1
u'بأذرعات': u'بِأذْرِعَاتٍ', #1
u'بأذرعات،': u'بِأَذرِعَاتَ،', #1
u'بأذرعات': u'بِأَذْرَعَاتٍ', #1
u'بأذرعات': u'بِأَذْرِعَاتٍ', #1
u'بأذرعتنا': u'بِأَذْرِعَتِنَا', #1
u'باذقا': u'بَاذِقًا', #2
u'باذكر': u'بِاذْكُرْ', #1
u'بأذناي': u'بِأُذُنَايَ', #1
u'بأذنة،': u'بِأَذَنَةَ،', #4
u'باذنجانة': u'بَاذِنْجَانَةٍ', #8
u'بأذنى': u'بِأُذُنِىَّ', #1
u'بإذنى': u'بِإِذْنِى', #3
u'بأذنى': u'بِأُذُنِى', #6
u'بأذنى': u'بِأُذُنَىَّ', #8
u'باذه': u'بَاذّه', #1
u'باذه': u'بَاذَّهُ', #2
u'بأذهب': u'بِأَذْهَبَ', #1
u'باذهبي': u'بِاذْهَبِي', #3
u'باذهنج': u'باذهنج', #1
u'باذهنج': u'بَاذَهَنْجُ', #2
u'باذو': u'باذو', #1
u'بأذواد': u'بِأَذْوَادٍ', #1
u'بأذواد': u'بِأَذْوَادِ', #2
u'بأذى': u'بِأَذًى', #21
u'بارأ': u'بَارَأَ', #1
u'بإراءة': u'بِإِرَاءَةِ', #4
u'بإراءته': u'بِإِرَاءَتِهِ', #1
u'بإراءتها': u'بِإِرَاءَتِهَا', #2
u'بارأت': u'بَارَأَتْ', #1
u'بارأتك': u'بَارَأْتُك', #14
u'بارأتك': u'بَارَأْتُكِ', #9
u'بارأته': u'بَارَأَتْهُ', #1
u'بارأتها': u'بَارَأْتُهَا', #1
u'بأراد': u'بِأَرَادَ', #4
u'بارأها': u'بَارَأَهَا', #13
u'بإرباغ': u'بإرباغ', #1
u'بإرباغ': u'بِإِرْبَاغِ', #1
u'باربآن': u'باربآن', #1
u'باربد': u'بَارْبِدَ', #1
u'بأربد': u'بِأَرْبَدَ', #2
u'بأربعا': u'بِأَرْبَعًا', #2
u'بأرت': u'بِأَرَتَّ', #2
u'بأرت': u'بَأَرْت', #3
u'بارتاب': u'بِارْتَابَ', #2
u'بارتثاث': u'بِارْتِثَاثٍ', #1
u'بارتدافه': u'بِارْتِدَافِهِ', #1
u'بارتدت': u'بِارْتَدَّتْ', #1
u'بارتضاع': u'بِارْتِضَاعِ', #1
u'بارتضاعه': u'بِارْتِضَاعِهِ', #1
u'بارتضاعها': u'بِارْتِضَاعِهَا', #3
u'بارتفاض': u'بِارْتِفَاضِ', #3
u'بارتفاضها': u'بِارْتِفَاضِهَا', #1
u'بارتفاق': u'بِارْتِفَاقِ', #2
u'بارتفاق': u'بِارْتِفَاقٍ', #5
u'بأرث': u'بِأَرَثِّ', #2
u'بارجعي': u'بِارْجَعِي', #1
u'بأرجو': u'بِأَرْجُو', #1
u'بأرجى': u'بِأَرْجَى', #9
u'بأرخ': u'بَأَرَّخَ', #2
u'بإرخاد': u'بإرخاد', #1
u'بإرخاص': u'بِإِرْخَاصِ', #2
u'بإردار': u'بإردار', #1
u'بإردب': u'بِإِرْدَبِّ', #13
u'بإردب': u'بِإِرْدَبٍّ', #6
u'بإردبين': u'بِإِرْدَبَّيْنِ', #1
u'بأردى': u'بِأَرْدَى', #1
u'بارزنى': u'بَارَزَنِى', #2
u'بأرس': u'بِأَرْسِ', #1
u'بارسا': u'بَارْسَا', #2
u'بأرش': u'بِأَرْشٍ', #32
u'بأرش': u'بِأَرْشِ', #326
u'بأرشدية': u'بِأَرْشَدِيَّةِ', #8
u'بأرشه': u'بِأَرْشِهِ', #76
u'بأرشها': u'بِأَرْشِهَا', #46
u'بأرشهما': u'بِأَرْشِهِمَا', #6
u'بارض': u'بَارِضَ', #1
u'بأرضعت': u'بِأَرْضَعَتْ', #1
u'بأرضعته': u'بِأَرْضَعَتْهُ', #1
u'بأرضى': u'بِأَرْضِى', #2
u'بأرغد': u'بِأَرْغَدِ', #1
u'بأرفق': u'بِأَرْفَقِ', #4
u'بأرفق': u'بِأَرْفَقَ', #5
u'بأرفقهما': u'بِأَرْفَقِهِمَا', #1
u'بإرقاق': u'بِإِرْقَاقِ', #5
u'بإرقاقه': u'بِإِرْقَاقِهِ', #6
u'باركران': u'باركران', #1
u'باركشند': u'باركشند', #1
u'بإرمينية': u'بإرمينية', #1
u'بإرمينية': u'بِإِرْمِينِيَّةَ', #1
u'بأرؤس': u'بِأَرْؤُسٍ', #2
u'بأروش': u'بِأُرُوشِ', #2
u'باروكه': u'بَارُوكِهِ', #2
u'باريء': u'بَارِيءِ', #1
u'بارئني': u'بَارِئْنِي', #6
u'بأريحا': u'بِأَرِيحَا', #3
u'بأزاد': u'بِأَزَادَ', #1
u'بازاد': u'بَازَادَ', #1
u'بازاده': u'بازاده', #1
u'بازازد': u'بازازد', #1
u'بأزال': u'بِأَزَالَ', #1
u'بازامد': u'بازامد', #1
u'بازبان': u'بازبان', #1
u'بازج': u'بَازِجٌ', #1
u'بازخواستن': u'بازخواستن', #1
u'بازخوانم': u'بازخوانم', #1
u'بازدا': u'بازدا', #1
u'بازدادم': u'بازدادم', #2
u'بازدادمت': u'بازدادمت', #1
u'بازدار': u'بازدار', #4
u'بازدارند': u'بازدارند', #1
u'بازداشتم': u'بازداشتم', #1
u'بازداشتي': u'بازداشتي', #1
u'بازداشتى': u'بازداشتى', #1
u'بازدحم': u'بِازْدَحَمَ', #1
u'بأزدشير': u'بِأَزْدِشِيرَ', #1
u'بازده': u'بازده', #8
u'بازدهم': u'بازدهم', #1
u'بإزرار': u'بِإِزْرَارٍ', #1
u'بإزراره': u'بِإِزْرَارِهِ', #1
u'بإزرة': u'بِإِزْرَةِ', #1
u'بأزرته': u'بِأُزْرَتِهِ', #1
u'بأزرتي': u'بِأُزْرَتِي', #1
u'بازرد': u'بازرد', #1
u'بأزعج': u'بِأَزْعَج', #1
u'بازغى': u'بازغى', #1
u'بازكردن': u'بازكردن', #1
u'بازكوبي': u'بازكوبي', #1
u'بأزمير': u'بأزمير', #1
u'بازن': u'بازن', #1
u'بازنان': u'بازنان', #1
u'بأزهد': u'بِأَزْهَدَ', #2
u'بازوبند': u'بازوبند', #1
u'بازوي': u'بازوي', #1
u'بازياره': u'بازياره', #1
u'بازير': u'بازير', #1
u'بأزيلوا': u'بِأَزِيلُوا', #1
u'بأس': u'بَأْسً', #1
u'بأسارانا': u'بِأُسَارَانَا', #1
u'بأسارى': u'بِأُسَارَى', #16
u'بأسارى': u'بِأَسَارَى', #8
u'باسأل': u'بِاِسْأَلْ', #1
u'بأسأل': u'بِأَسْأَلُ', #3
u'بأسامة،': u'بأسامة،', #1
u'بأسامة': u'بِأُسَامَةَ', #10
u'بإسامة': u'بِإِسَامَةِ', #6
u'بإسامته': u'بِإِسَامَتِهِ', #3
u'بإسامتها': u'بِإِسَامَتِهَا', #5
u'بإسامتهما': u'بِإِسَامَتِهِمَا', #1
u'بأسبال': u'بِأَسْبَالِ', #1
u'باسبان': u'باسبان', #1
u'بأسبه': u'بَأْسَبِهِ', #2
u'بإسبيجاب': u'بِإِسْبِيجَابَ', #1
u'باستأجرتك': u'بِاسْتَأْجَرْتُكَ', #1
u'باستبابهم': u'بِاسْتِبَابِهِمْ', #1
u'باستتابة': u'بِاسْتِتَابَةِ', #1
u'باستتابتنا': u'بِاسْتِتَابَتِنَا', #1
u'باستتمام': u'بِاسْتِتْمَامِ', #1
u'باستثنى': u'بِاسْتَثْنَى', #1
u'باستجاب': u'بِاسْتَجَابَ', #1
u'باستجرائه': u'باسْتِجْرائِهِ', #1
u'باستجمار': u'بِاسْتِجْمَارٍ', #6
u'باستحاضة': u'بِاسْتِحَاضَةٍ', #12
u'بأستحسن': u'بِأَسْتَحْسِنُ', #1
u'باستحسن': u'بِاسْتَحْسَنَ', #1
u'باستحق': u'بِاسْتُحِقَّ', #1
u'باستحق': u'بِاسْتَحَقَّ', #2
u'باستخلص': u'بِاسْتَخْلَصَ', #1
u'باستخلف': u'بِاسْتَخْلَفَ', #1
u'باستدام': u'بِاسْتَدَامَ', #1
u'باستدخال': u'بِاسْتِدْخَالٍ', #2
u'باستدخال': u'بِاسْتِدْخَالِ', #50
u'باستدخاله': u'بِاسْتِدْخَالِهِ', #3
u'باستدخالها': u'بِاسْتِدْخَالِهَا', #15
u'باستدل': u'بِاسْتَدَلَّ', #1
u'باسترسل': u'بِاسْتَرْسَلَ', #1
u'باسترقاق': u'بِاسْتِرْقَاقِ', #16
u'باسترقاق': u'بِاسْتِرْقَاقٍ', #3
u'باسترقاقه': u'بِاسْتِرْقَاقِهِ', #13
u'باسترقاقها': u'بِاسْتِرْقَاقِهَا', #1
u'باسترقاقهم': u'بِاسْتِرْقَاقِهِمْ', #2
u'باسترقاقهما': u'بِاسْتِرْقَاقِهِمَا', #1
u'باسترقت': u'بِاسْتُرِقَّتْ', #1
u'باستسعاء': u'بِاسْتِسْعَاءِ', #9
u'باستسعائه': u'بِاسْتِسْعَائِهِ', #1
u'باستسمان': u'بِاسْتِسْمَانِ', #1
u'باستشكل': u'بِاسْتُشْكِلَ', #1
u'باستشكل': u'بِاسْتَشْكَلَ', #2
u'باستصناع': u'بِاسْتِصْنَاعٍ', #1
u'باستصناعه': u'بِاسْتِصْنَاعِهِ', #2
u'باستصناعها': u'بِاسْتِصْنَاعِهَا', #1
u'باستضرارهم': u'بِاسْتِضْرَارِهِمْ', #1
u'باستطراق': u'بِاسْتِطْرَاقٍ', #1
u'باستطراق': u'بِاسْتِطْرَاقِ', #2
u'باستعمل': u'بِاسْتَعْمَلَ', #1
u'بأستغفر': u'بِأَسْتَغْفِرُ', #1
u'باستغفروا': u'بِاسْتَغْفِرُوا', #1
u'باستغنامه': u'بِاسْتِغْنَامِهِ', #1
u'باستغواء': u'بِاسْتِغْوَاءِ', #1
u'باستغواء': u'بِاسْتْغْوَاءِ', #1
u'باستفراش': u'بِاسْتِفْرَاشِ', #8
u'باستفراشه': u'بِاسْتِفْرَاشِهِ', #2
u'باستفضاله': u'بِاسْتِفْضَالِهِ', #1
u'باستقرا': u'بِاسْتَقَرَّا', #1
u'باستقرض': u'بِاسْتَقْرَضَ', #1
u'باستكتام': u'بِاسْتِكْتَامِ', #1
u'باستكراء': u'بِاسْتِكْرَاءِ', #2
u'باستلائه': u'بِاسْتِلَائِهِ', #1
u'باستلزاما': u'بِاسْتِلْزَامًا', #1
u'باستمرت': u'بِاسْتَمَرَّتْ', #2
u'باستنان': u'بِاسْتِنَانِ', #5
u'باستنانا': u'بِاسْتِنَانًا', #1
u'باستنانه': u'بِاسْتِنَانِهِ', #2
u'باستنانها': u'بِاسْتِنَانِهَا', #1
u'باستنبطتها': u'بِاسْتَنْبَطْتُهَا', #1
u'باستنجاء': u'بِاسْتِنْجَاءٍ', #8
u'باستنزاه': u'بِاسْتِنْزَاهِ', #2
u'باستنزهوا': u'بِاسْتَنْزِهُوا', #1
u'باستنظارها': u'بِاسْتِنْظَارِهَا', #1
u'باستنكاهه': u'بِاسْتِنْكَاهِهِ', #10
u'باستهلك': u'بِاسْتَهْلَكَ', #1
u'باستؤذنت': u'بِاسْتُؤْذِنَتْ', #1
u'باستوفى': u'بِاسْتَوْفَى', #1
u'باستؤنف': u'بِاسْتُؤْنِفَ', #1
u'باستياك': u'بِاسْتِيَاكِ', #1
u'باستياك': u'بِاسْتِيَاكٍ', #9
u'باستياكه': u'بِاسْتِيَاكِهِ', #1
u'باستينائه': u'بِاسْتِينَائِهِ', #1
u'باستيهاب': u'بِاسْتِيهَابِ', #2
u'بأسجال': u'بِأَسْجَالٍ', #1
u'بإسجاله': u'بِإِسْجَالِهِ', #1
u'بإسحق': u'بِإِسْحَقَ', #1
u'بأسداباذ': u'بِأَسَدَابَاذَ', #2
u'بأسراء': u'بِأُسَرَاءَ', #2
u'بأسراء': u'بِأُسَرَاءِ', #9
u'بإسرار': u'بِإِسْرَارٍ', #2
u'بإسرار': u'بِإِسْرَارِ', #3
u'بإسرافيل': u'بِإِسْرَافِيلَ', #1
u'بأسرائهم': u'بِأُسَرَائِهِمْ', #2
u'باسرومي': u'باسرومي', #1
u'باسطاع': u'بِاسْطَاعَ', #1
u'باسطوانة': u'بِاسْطُوَانَةٍ', #1
u'بإسعاط': u'بِإِسْعَاطٍ', #1
u'بإسفرائن': u'بِإِسْفَرَائِنَ', #1
u'بإسفرائين': u'بِإِسْفِرَائِينَ', #1
u'بإسفيداج': u'بِإِسْفِيدَاجِ', #1
u'بإسقاء': u'بِإِسْقَاءِ', #1
u'بإسقاف': u'بِإِسْقَافِ', #1
u'بإسقائه': u'بِإِسْقَائِهِ', #2
u'بأسقطت': u'بِأَسْقَطْت', #1
u'بأسقطت': u'بِأَسْقَطْتُ', #1
u'بأسقطتها': u'بِأَسْقَطْتُهَا', #1
u'باسقني': u'بِاسْقِنِي', #6
u'باسقيني': u'بِاسْقِينِي', #1
u'بأسكفة': u'بِأُسْكُفَّةِ', #2
u'بإسلامى': u'بِإِسْلاَمِى', #1
u'بأسمآئهم': u'بِأَسْمَآئِهِمْ', #2
u'بإسمة': u'بإسمة', #1
u'بأسمع': u'بِأَسْمَعَ', #29
u'باسمى': u'بِاسْمِى', #19
u'باسميتها': u'بِاسْمِيَّتِهَا', #2
u'باسناده،': u'باسناده،', #1
u'بإسنادهإن': u'بِإِسْنَادِهِإِنَّ', #1
u'بإسنادهإني': u'بِإِسْنَادِهِإِنِّي', #1
u'بإسنادهأيتهن': u'بِإِسْنَادِهِأَيَّتُهُنَّ', #1
u'بإسنادهذبح': u'بِإِسْنَادِهِذَبَحَ', #1
u'بإسنادهرأيت': u'بِإِسْنَادِهِرَأَيْتُ', #2
u'بإسنادهرخص': u'بِإِسْنَادِهِرَخَّصَ', #1
u'بإسنادهفغاب': u'بِإِسْنَادِهِفَغَابَ', #1
u'بإسنادهمن': u'بِإِسْنَادِهِمَنْ', #1
u'بإسنادهنهاني': u'بِإِسْنَادِهِنَهَانِي', #1
u'بإسنادهنهى': u'بِإِسْنَادِهِنَهَى', #1
u'بإسنادههاتوه،': u'بِإِسْنَادِهِهَاتُوهُ،', #1
u'بإسنادهوإذا': u'بِإِسْنَادِهِوَإِذَا', #2
u'بإسنادهوإن': u'بِإِسْنَادِهِوَإِنْ', #1
u'بأسند': u'بِأَسْنَدَ', #2
u'بأسهمى': u'بِأَسْهُمِى', #1
u'باسورة': u'بَاسُورَةٍ', #1
u'بأسوق': u'بأسوق', #1
u'باسيابارآورد': u'باسيابارآورد', #1
u'بأسيار': u'بِأَسْيَارِ', #2
u'بأشار': u'بِأَشَارَ', #2
u'بإشالته': u'بِإِشَالَتِهِ', #1
u'بأشبع': u'بِأَشْبَعَ', #1
u'بأشبهت': u'بِأَشْبَهَتْ', #1
u'باشتر': u'بِاشْتَرِ', #1
u'باشتراه': u'بِاشْتَرَاهُ', #1
u'باشتراها': u'بِاشْتَرَاهَا', #1
u'باشترط': u'بِاشْتُرِطَ', #1
u'باشترطي': u'بِاشْتَرِطِي', #1
u'باشترك': u'بِاشْتَرَكَ', #2
u'باشتركنا': u'بِاشْتَرَكْنَا', #1
u'باشترى': u'بِاشْتَرَى', #7
u'باشتريت': u'بِاشْتَرَيْت', #1
u'باشتريت': u'بِاشْتَرَيْتَ', #2
u'باشتريت': u'بِاشْتَرَيْتُ', #8
u'باشتريتها': u'بِاشْتَرَيْتُهَا', #3
u'باشتغل': u'بِاشْتَغَلَ', #1
u'باشتهرت': u'بِاشْتُهِرَتْ', #1
u'بأشج': u'بِأَشَجِّ', #1
u'بأشح': u'بِأَشَحَّ', #1
u'بإشحان': u'بِإِشْحَانِ', #3
u'بإشخاصه': u'بِإِشْخَاصِهِ', #1
u'باشد': u'باشد', #17
u'باشدتا': u'باشدتا', #1
u'باشده': u'باشده', #1
u'باشدواين': u'باشدواين', #1
u'بأشديته': u'بِأَشَدِّيَّتِهِ', #1
u'بأشركم': u'بأشرِّكم', #2
u'باششتك': u'بَاشَشْتُكِ', #1
u'بأشطان': u'بِأَشْطَانِ', #1
u'بإشفاعه': u'بِإشْفَاعِهِ', #1
u'بأشفى': u'بِأَشْفَى', #1
u'بإشفى': u'بِإِشْفَى', #3
u'بإشلاء': u'بِإِشْلَاءِ', #3
u'بإشلائه': u'بِإِشْلَائِهِ', #3
u'بأشلق': u'بأشلق', #1
u'باشم': u'باشم', #4
u'بأشمط': u'بأشْمَطَ', #1
u'بأشمط': u'بِأَشْمَطَ', #2
u'بأشنان': u'بِأُشْنَانِ', #1
u'بأشنان': u'بِأُشْنَانٍ', #10
u'باشند': u'باشند', #2
u'بأشهد': u'بِأَشْهَدُ', #10
u'بأشهد': u'بِأَشْهَدَ', #4
u'باشى': u'باشى', #2
u'بأشياء': u'بِأَشْيَاءً', #1
u'بأشيخة': u'بِأَشْيِخَةٍ', #1
u'باشيد': u'باشيد', #3
u'باشيدم': u'باشيدم', #2
u'باشيدن': u'باشيدن', #1
u'باشيده': u'باشيده', #1
u'باشيدي': u'باشيدي', #1
u'باشيم': u'باشيم', #1
u'بأصاب': u'بِأَصَابَ', #2
u'بأصابك': u'بِأَصَابَكَ', #1
u'باصبرين': u'بَاصَبْرِينٍ', #1
u'بإصبعى': u'بِإِصْبَعَىَّ', #1
u'بإصبعى': u'بِإِصْبَعِى', #1
u'بإصبعين': u'بِإِصْبَعَيْنِ', #7
u'بأصبهان،': u'بأصبهان،', #1
u'بأصبهان': u'بأَصْبَهَانَ', #1
u'بأصبهان': u'بِأَصْبَهَانَ', #25
u'بأصبهان،': u'بِأَصْبَهَانَ،', #3
u'بأصبوع': u'بِأُصْبُوعِ', #1
u'بأصحابى': u'بِأَصْحَابِى', #6
u'بأصحية': u'بِأَصَحِّيَّةِ', #3
u'بأصر': u'بِأَصَرَّ', #2
u'بإصرافة': u'بِإِصْرَافَةِ', #1
u'بأصرام': u'بِأَصْرَامٍ', #1
u'بأصرحيتها': u'بِأَصْرَحِيَّتِهَا', #1
u'باصطبار': u'بِاصْطِبَارٍ', #1
u'بإصطخر': u'بِإِصْطَخْرَ', #1
u'بإصطخر': u'بِإِصْطَخْرِ', #1
u'بآصع': u'بِآصُعَ', #1
u'بآصع': u'بِآصُعِ', #1
u'بآصع': u'بِآصُعٍ', #4
u'بآصعها': u'بِآصُعِهَا', #1
u'باصور': u'بَاصُورٌ', #1
u'بأصوم': u'بأصوم', #1
u'بأصوم': u'بِأَصُومَ', #1
u'بأصوم': u'بِأَصُومُ', #1
u'بأضاءة': u'بِأَضَاءَةِ', #1
u'بأضاة': u'بِأَضَاةِ', #1
u'بأضاف': u'بِأَضَافَ', #1
u'بإضاقة': u'بِإِضَاقَةِ', #2
u'بأضبعه': u'بِأُضْبَعِهِ', #1
u'بأضر': u'بِأَضَرَّ', #1
u'بأضر': u'بِأَضَرِّ', #8
u'بأضرب': u'بِأَضْرُبِ', #1
u'باضرب': u'بِاضْرِبْ', #1
u'بأضرها': u'بِأَضَرِّهَا', #1
u'باضعت': u'بَاضَعْتُ', #2
u'بأضعف': u'بِأَضْعَفِ', #5
u'بأضعف': u'بِأَضْعَفَ', #6
u'بأضعفهم': u'بأضعفهم', #1
u'بأضعفهم': u'بِأَضْعَفِهِمْ', #18
u'بأضعفهم،': u'بأضعفهم،', #2
u'بأضعفهما': u'بِأَضْعَفِهِمَا', #2
u'بأضلت': u'بِأُضِلَّتْ', #1
u'بإضم': u'بِإِضَمَ', #1
u'بأضيع': u'بأضيع', #1
u'باطا': u'باطا', #1
u'باطا': u'بَاطَا', #29
u'باطال': u'بَاطَالَ', #1
u'بآطام': u'بِآطَامِ', #3
u'باطراح': u'بِاطِّرَاحِ', #1
u'بإطراحه': u'بِإِطْرَاحِهِ', #1
u'باطراحه': u'بِاطِّرَاحِهِ', #1
u'بإطراحها': u'بِإِطْرَاحِهَا', #1
u'بأطرف': u'بِأَطْرُفِ', #1
u'بأطرقا': u'بِأَطْرِقَا', #1
u'بأطرقه': u'بَأَطْرُقِهِ', #1
u'بأطرقه،': u'بِأَطْرُقِهِ،', #1
u'بأطرقه': u'بِأَطْرُقِهِ', #5
u'باطعامها': u'بِاطِّعَامِهَا', #1
u'باطل17035id': u'باطل17035id', #1
u'باطل': u'بَاطِلً', #1
u'بإطلاقة': u'بِإِطْلَاقَةِ', #2
u'باطلاقهم': u'بِاطِّلَاقِهِمْ', #1
u'بأطلق': u'بِأَطْلَقَ', #5
u'بأطلقك': u'بِأُطَلِّقُك', #1
u'بإطماع': u'بِإِطْمَاعِ', #2
u'بإطماعه': u'بِإِطْمَاعِهِ', #2
u'بأطنب': u'بِأَطْنَبَ', #1
u'بأطهر': u'بِأَطْهَرَ', #3
u'بأطوع': u'بِأَطْوَعَ', #1
u'باطيا': u'باطيا', #1
u'باطيا': u'بَاطَيَا', #3
u'باطيس': u'بَاطِيسَ', #1
u'باطيش': u'بَاطِيشٍ', #4
u'بأظن': u'بِأَظُنُّ', #1
u'بأظهرية': u'بِأَظْهَرِيَّةِ', #2
u'بأعاد': u'بِأَعَادَ', #5
u'بأعاده': u'بِأَعَادَهُ', #1
u'بأعانه': u'بِأَعَانَهُ', #1
u'بأعاهد': u'بِأُعَاهِدُ', #1
u'باعبدوا': u'بِاعْبُدُوا', #2
u'باعتادوا': u'بِاعْتَادُوا', #2
u'بأعتبر': u'بِأَعْتَبِرُ', #1
u'باعتبر': u'بِاعْتَبَرَ', #1
u'باعتبر': u'بِاعْتُبِرْ', #1
u'باعتدا': u'بِاعْتِدَا', #1
u'باعتدت': u'بِاعْتَدَّتْ', #1
u'باعتددن': u'بِاعْتَدَدْنَ', #1
u'باعتدلتا': u'بِاعْتَدَلَتَا', #1
u'باعتدي': u'بِاعْتَدِّي', #5
u'بأعتذر': u'بِأَعْتَذِرُ', #1
u'باعتذروا': u'بِاعْتَذَرُوا', #1
u'باعترض': u'بِاعْتَرَضَ', #2
u'باعتضاد': u'بِاعْتِضَادِ', #1
u'باعتضاده': u'بِاعْتِضَادِهِ', #2
u'باعتضادها': u'بِاعْتِضَادِهَا', #2
u'بأعتق': u'بِأَعْتَقَ', #4
u'بأعتقوا': u'بِأَعْتِقُوا', #2
u'بأعتقوها': u'بِأَعْتِقُوهَا', #1
u'باعتل': u'بِاعْتَلَّ', #1
u'باعتمد': u'بِاعْتُمِدَ', #1
u'باعتنيها': u'بَاعَتْنِيهَا', #1
u'بأعتى': u'بِأَعْتَى', #1
u'باعتيد': u'بِاعْتِيدَ', #1
u'باعتيد': u'بِاُعْتِيدَ', #1
u'بأعجلهم': u'بِأَعْجَلِهِمْ', #2
u'بأعددته': u'بِأَعْدَدْته', #1
u'بإعراء': u'بِإِعْرَاءِ', #2
u'بأعرابى': u'بِأَعْرَابِىٍّ', #1
u'بإعرائه': u'بِإِعْرَائِهِ', #1
u'بأعرتك': u'بِأَعَرْتُك', #1
u'بأعرتك': u'بِأَعَرْتُكَ', #7
u'بأعزم': u'بِأَعْزِمُ', #2
u'بأعسم': u'بِأَعْسَمَ', #10
u'باعشن': u'بَاعَشَنٍ', #62
u'بأعضب': u'بِأَعْضَب', #2
u'بأعضب': u'بِأَعْضَبِ', #7
u'بأعطوا': u'بِأَعْطُوا', #1
u'بأعطوه': u'بِأَعْطُوهُ', #1
u'بأعطى': u'بِأَعْطَى', #4
u'بأعطياتهم،': u'بِأُعْطِيَاتِهِمْ،', #1
u'باعكه': u'بَاعَكَهُ', #2
u'باعكها': u'بَاعَكهَا', #1
u'بأعلا': u'بِأَعْلَا', #1
u'باعلتك': u'بَاعَلْتُك', #2
u'باعلتك': u'بَاعَلْتُكِ', #2
u'بأعلمية': u'بِأَعْلَمِيَّةٍ', #1
u'بأعلمية': u'بِأَعْلَمِيَّةِ', #1
u'باعلها': u'بَاعَلَهَا', #1
u'بأعمل': u'بِأَعْمَلَ', #1
u'باعمل': u'بِاعْمَلْ', #7
u'بأعملكم': u'بِأَعْمَلِكُمْ', #1
u'بأعميته': u'بِأَعَمِّيَّتِهِ', #1
u'باعنى': u'بَاعَنِى', #2
u'بأعني': u'بِأَعْنِي', #3
u'باعنيه': u'بَاعَنِيهِ', #14
u'باعنيها': u'بَاعَنِيهَا', #11
u'باعوثا': u'بَاعُوثًا', #5
u'بأعوذ': u'بِأَعُوذُ', #2
u'باعورا': u'بَاعُورَا', #2
u'باعوراء': u'بَاعُورَاءَ', #4
u'باعورة،': u'بَاعُورةَ،', #1
u'باعورة،': u'بَاعُورَةَ،', #1
u'باعوكموها': u'بَاعُوكُمُوهَا', #1
u'باعونى': u'بَاعُونِى', #1
u'باغا': u'بَاغًا', #1
u'باغا': u'بَاغًّا', #1
u'باغا': u'بَاغَا', #2
u'باغتسل': u'بِاغْتَسَلَ', #1
u'باغتفاله': u'باغتفاله', #1
u'باغتفر': u'بِاغْتَفَرَ', #1
u'باغسلوا': u'بِاغْسِلُوا', #4
u'بأغشهم': u'بِأَغَشِّهِمْ', #3
u'بأغمات': u'بِأَغْمَاتَ', #1
u'بأغوى': u'بِأَغْوَى', #2
u'باغى': u'بَاغِىَ', #2
u'باف': u'باف', #2
u'بإفاء': u'بِإِفَاءِ', #1
u'بافاء': u'بَافَاءِ', #1
u'بأفادتكم': u'بِأَفَادَتْكُمْ', #1
u'بأفاده': u'بِأَفَادَهُ', #1
u'بأفادهم': u'بِأَفَادَهُمْ', #1
u'بافت': u'بافت', #2
u'بأفتتح': u'بِأَفْتَتِحُ', #2
u'بافتدى': u'بِافْتَدَى', #1
u'بافتراغ': u'بِافْتِرَاغِ', #1
u'بافترت': u'بِافْتَرَّتْ', #1
u'بافتضائه': u'بِافْتِضَائِهِ', #1
u'بافتقر': u'بِافْتَقَرَ', #1
u'بافتكاك': u'بِافْتِكَاكٍ', #2
u'بافتكاك': u'بِافْتِكَاكِ', #2
u'بافتكاكه': u'بِافْتِكَاكِهِ', #3
u'بافته': u'بافته', #2
u'بأفتى': u'بِأَفْتَى', #2
u'بافتياته': u'بِافْتِيَاتِهِ', #2
u'بافتياتهم': u'بِافْتِيَاتِهِمْ', #1
u'بأفتيت': u'بِأَفْتَيْت', #1
u'بأفحم': u'بِأَفْحَم', #1
u'بافد': u'بافد', #2
u'بأفراس': u'بِأَفْرَاسٍ', #12
u'بأفرد': u'بِأَفْرَدَ', #1
u'بأفرغته': u'بِأَفْرَغْتُهُ', #1
u'بأفريق': u'بِأَفْرِيقَ', #1
u'بأفسد': u'بِأَفْسَدَ', #9
u'بأفسق': u'بِأَفْسَقِ', #1
u'بإفشاخ': u'بإفشاخ', #1
u'بافضل': u'بَافَضْلَ', #10
u'بافضل': u'بَافَضْلٌ', #2
u'بافضل': u'بَافْضَلٍ', #2
u'بافضل': u'بَافَضْلٍ', #755
u'بأفطر': u'بِأَفْطَرَ', #2
u'بأفطرناه': u'بِأَفْطَرْنَاهُ', #1
u'بأفعل': u'بَأَفْعَلَ', #1
u'بأفعل': u'بِأَفْعُلٍ', #1
u'بأفعل': u'بِأَفْعَلِ', #16
u'بافعل': u'بِافْعَلْ', #2
u'بأفعل': u'بِأَفْعَلَ', #7
u'بافعلوا': u'بِافْعَلُوا', #1
u'بأفقههم': u'بِأَفْقَهِهِمْ', #2
u'بافلان': u'بافلان', #2
u'بأفلس': u'بأفلس', #1
u'بأفلس': u'بِأَفْلَسِ', #1
u'بأفلس': u'بِأَفْلُسٍ', #1
u'بافند': u'بافند', #2
u'بافنده': u'بافنده', #10
u'بأفنيائهم': u'بِأَفْنِيَائِهِمْ', #1
u'بأفواهم': u'بأفواهم', #1
u'بأفوق': u'بِأَفْوَقِ', #1
u'بأفوق': u'بِأَفْوَقَ', #2
u'باقا': u'بَاقَا', #2
u'بإقادة': u'بِإِقَادَةِ', #1
u'بأقام': u'بِأَقَامَ', #1
u'بإقام': u'بِإِقَامِ', #3
u'بأقاما': u'بِأَقَامَا', #5
u'باقاني': u'بَاقَانِي', #1
u'باقاني': u'بَاقَانِيٌّ', #13
u'بإقباض': u'بِإِقْبَاضِ', #17
u'بإقباض': u'بِإِقْبَاضٍ', #7
u'بإقباضه': u'بِإِقْبَاضِهِ', #34
u'بإقباضها': u'بِإِقْبَاضِهَا', #1
u'باقبضوا': u'بِاقْبَضُوا', #1
u'بأقبلها': u'بِأَقْبَلِهَا', #1
u'بأقتابها': u'بِأَقْتَابِهَا', #3
u'باقتدا': u'بِاقْتِدَا', #1
u'باقتدى': u'بِاقْتَدَى', #1
u'باقتربت': u'بِاقْتَرَبَتِ', #1
u'باقتربت': u'بِاقْتَرَبَتْ', #3
u'باقتص': u'بِاقْتَصَّ', #1
u'باقتضا': u'بِاقْتِضَا', #1
u'باقتضاض': u'بِاقْتِضَاضِ', #1
u'باقتضاضه': u'بِاقْتِضَاضِهِ', #1
u'باقتضى': u'بِاقْتَضَى', #2
u'باقتطع': u'بِاقْتَطَعَ', #1
u'بأقحم': u'بِأَقْحَمَ', #1
u'بإقدار': u'بِإِقْدَارِ', #4
u'بإقداره': u'بِإِقْدَارِهِ', #2
u'بأقر': u'بِأَقْرٍ', #1
u'بأقر': u'بِأُقِرُّ', #1
u'بأقر': u'بِأَقَرَّ', #7
u'باقرأ': u'بِاقْرَأْ', #2
u'بأقراء': u'بِأَقْرَاءٍ', #16
u'بأقراء': u'بِأَقْرَاءِ', #2
u'بأقرائها': u'بِأَقْرَائِهَا', #10
u'بأقربية': u'بِأَقْرَبِيَّةِ', #3
u'بأقسم': u'بأقسم', #1
u'بأقسم': u'بِأُقْسِمُ', #7
u'بأقسمت': u'بِأَقْسَمْت', #1
u'بأقسمت': u'بِأَقْسَمْتُ', #2
u'باقشير': u'بَاقُشَيْرٍ', #13
u'باقشير': u'بَاقُشَيْرٌ', #2
u'باقضام': u'بَاقْضَامْ', #3
u'بأقضى': u'بِأَقْضَى', #2
u'بأقط': u'بِأَقِطٍ', #1
u'باقعة': u'بَاقِعَةُ', #1
u'بأقفزة': u'بِأَقْفِزَةٍ', #3
u'باقل': u'بَاقِلُ', #1
u'باقلا': u'بَاقِلَا', #1
u'باقلا': u'بَاقِلَّا', #11
u'باقلا': u'بَاقِلًا', #2
u'باقلاءة': u'بَاقِلَّاءَةٌ', #1
u'باقلاة': u'بَاقِلَّاةٌ', #3
u'باقلة': u'بَاقِلَةً', #1
u'باقلة': u'بَاقِلَةٍ', #1
u'باقلي': u'بَاقِلِّيٌّ', #1
u'بأقنابها': u'بِأَقْنَابِهَا', #1
u'باقنده': u'باقنده', #1
u'باقورة': u'بَاقُورَةٌ', #1
u'باقورة': u'بَاقُورَةٍ', #2
u'باقورة': u'بَاقُورَةً', #9
u'بأقول': u'بِأَقُولُ', #1
u'باقوم': u'بَاقُومٌ', #1
u'باقوم': u'بَاقُومُ', #3
u'بأقووية': u'بِأَقْوَوِيَّةِ', #1
u'باقى': u'بَاقِى', #4
u'باقى': u'بَاقِىَ', #54
u'بأقيس': u'بِأَقْيَسِ', #1
u'بأقيموا': u'بِأَقِيمُوا', #1
u'بإكاف': u'بِإِكَافٍ', #57
u'باكبر': u'بَاكَبْرٍ', #1
u'بأكتب': u'بِأَكْتُبَ', #2
u'باكترى': u'بِاكْتَرَى', #1
u'بأكتع': u'بِأَكْتَعَ', #1
u'باكتفي': u'بِاكْتُفِيَ', #1
u'بأكد': u'بِأَكِّدِ', #1
u'بآكد': u'بِآكَدَ', #4
u'بآكد': u'بِآكَدِ', #5
u'باكدش': u'باكدش', #1
u'بأكرار': u'بِأَكْرَارِ', #1
u'بإكراها': u'بِإِكْرَاهًا', #1
u'باكس': u'باكس', #1
u'بأكساب': u'بِأَكْسَابِ', #3
u'بأكسابه': u'بِأَكْسَابِهِ', #16
u'بأكسابها': u'بِأَكْسَابِهَا', #4
u'بأكسابهم': u'بِأَكْسَابِهِمْ', #1
u'بأكسب': u'بِأَكْسَبَ', #1
u'باكسي': u'باكسي', #1
u'باكسي': u'بَاكِسِي', #1
u'بأكلت': u'بِأَكَلْت', #1
u'بأكلت': u'بِأَكَلْتُ', #1
u'بأكنى': u'بِأَكْنَى', #1
u'بأكون': u'بِأَكُونُ', #1
u'باكويه': u'بَاكَوَيْهِ', #2
u'بأكيدر': u'بِأُكَيْدِرٍ', #4
u'باكير': u'بَاكِيرُ', #1
u'باكير': u'بَاكِيرٌ', #39
u'باكير': u'بَاكِيرٍ', #6
u'باكيزه': u'باكيزه', #3
u'بأل': u'بِأَلْ', #136
u'بإل': u'بِإِلّ', #2
u'بإلا': u'بِإِلّا', #1
u'بإلا': u'بِإِلَّا', #114
u'بألاء': u'بِأَلَاءَ', #2
u'بالإبار': u'بِالْإِبَارِ', #4
u'بالإباق': u'بِالإِبَاقِ', #1
u'بالإباق': u'بِالْإِبَاقِ', #83
u'بالابتغاوية': u'بالابتغاوية', #2
u'بالأبذار': u'بِالْأَبْذَارِ', #1
u'بالأبذال': u'بِالْأَبْذَالِ', #1
u'بالابرا': u'بِالِابْرَا', #1
u'بالأبراء': u'بِالْأَبْرَاءِ', #1
u'بالإبراد': u'بِالإِبْرَادِ', #1
u'بالإبراد': u'بِالْإِبْرَادِ', #33
u'بالأبراش': u'بِالْأَبْرَاشِ', #1
u'بالإبريسم': u'بِالْإِبْرَيْسَمِ', #9
u'بالابصار': u'بالابصار', #1
u'بالإبضاع': u'بِالْإِبْضَاعِ', #4
u'بالأبضاع': u'بِالْأَبْضَاعِ', #8
u'بالأبعرة': u'بِالْأَبْعِرَةِ', #3
u'بالأبغضية': u'بِالْأَبْغَضِيَّةِ', #2
u'بالآبق': u'بِالْآبِقِ', #48
u'بالأبقع': u'بِالْأَبْقَعِ', #11
u'بالأبل': u'بِالْأَبِلِ', #1
u'بالأبلة': u'بِالأُبُلَّةِ', #1
u'بالأبلة،': u'بِالأَبُلَّةِ،', #1
u'بالأبلة،': u'بالأبلة،', #4
u'بالأبلة،': u'بِالأُبُلَّةِ،', #5
u'بالأبلغية': u'بِالْأَبْلَغِيَّةِ', #1
u'بالإبنية': u'بِالْإبْنِيَّةِ', #2
u'بالأبواء،': u'بالأبواء،', #1
u'بالأبواء': u'بالأَبُواء', #1
u'بالأبواء': u'بَالْأَبْوَاءِ', #1
u'بالأبواء': u'بِالأَبْوَاءِ', #15
u'بالأبواء،': u'بِالأَبْوَاءِ،', #2
u'بالأبواء': u'بِالْأَبْوَاءِ', #53
u'بالأبينا': u'بِالْأَبِينَا', #1
u'بالاتجاء': u'بِالِاتِّجَاءِ', #1
u'بالأتحمية': u'بِالْأَتْحَمِيّةِ', #2
u'بالأترسة': u'بِالْأَتْرِسَة', #1
u'بالأتقنية': u'بالْأَتْقَنِيَّةِ', #1
u'بالأتقيا': u'بِالْأَتْقِيَا', #1
u'بالأتمية': u'بِالْأَتَمِّيَّةِ', #1
u'بالاتهاب': u'بِالِاتِّهَابِ', #13
u'بالإتهام': u'بِالْإِتْهَامِ', #2
u'بالأثابة': u'بِالْأُثَابَةِ', #1
u'بالأثاية': u'بِالأُثَايَةِ', #1
u'بالإثاية': u'بالإثاية', #1
u'بالأثاية': u'بِالأَثَايَةِ', #2
u'بالأثاية': u'بِالْأَثَايَةِ', #2
u'بالأثاية': u'بِالْأُثَايَة', #2
u'بالأثاية': u'بِالْأُثَايَةِ', #2
u'بالإثمد': u'بالإِثْمِدِ', #1
u'بالإثمد': u'بِالإِثْمِدِ', #4
u'بالإثمد': u'بِالْإِثْمِدِ', #58
u'بالاثنا': u'بِالِاثْنَا', #1
u'بالاثنا': u'بِاَلْاِثْنَا', #1
u'بالاثني': u'بِالِاثْنَيْ', #9
u'بالأثوار': u'بِالْأَثْوَارِ', #3
u'بالأجانة': u'بِالْأَجَّانَةِ', #1
u'بالأجحار': u'بِالْأَجْحَارِ', #1
u'بالإجذاع': u'بِالْإِجْذَاعِ', #3
u'بالأجلح': u'بِالأَجْلَحِ', #1
u'بالأجلح': u'بِالْأَجْلَحِ', #3
u'بالإجماعالمنع': u'بِالْإِجْمَاعِالْمَنْعُ', #1
u'بالأجودية': u'بِالْأَجْوَدِيَّةِ', #1
u'بالأحامس': u'بِالْأَحَامِسِ', #2
u'بالأحائم': u'بِالْأَحَائِمِ', #1
u'بالأحبل': u'بِالْأَحْبُلِ', #3
u'بالاحتباك': u'بِالِاحْتِبَاكِ', #3
u'بالاحتجار': u'بِالِاحْتِجَارِ', #1
u'بالاحتجام': u'بِالِاحْتِجَامِ', #1
u'بالاحتزام': u'بِالِاحْتِزَامِ', #1
u'بالاحتشاش': u'بِالِاحْتِشَاشِ', #1
u'بالاحتفار': u'بِالِاحْتِفَارِ', #1
u'بالإحجاج': u'بِالْإِحْجَاجِ', #18
u'بالإحداد': u'بِالْإِحْدَادِ', #8
u'بالإحدى': u'بِالْإِحْدَى', #3
u'بالأحذق': u'بِالْأَحْذَقِ', #1
u'بالإحرار': u'بِالْإِحْرَارِ', #1
u'بالأحروية': u'بِالْأَحْرَوِيَّةِ', #2
u'بالإحزاء': u'بِالْإِحْزَاءِ', #1
u'بالأحزم': u'بِالْأَحْزَمِ', #1
u'بالأحسد': u'بِالْأَحْسَدِ', #1
u'بالإحصار': u'بِالإِحْصَارِ', #3
u'بالإحصار': u'بِالْإِحْصَارِ', #56
u'بالأحظ': u'بِالْأَحَظِّ', #28
u'بالأحظية': u'بِالْأَحَظِّيَّةِ', #1
u'بالإحفاء': u'بِالإِحْفَاءِ', #1
u'بالإحفاء': u'بِالْإِحْفَاءِ', #4
u'بالأحفظ': u'بِالْأَحْفَظِ', #1
u'بالأحقاف': u'بِالأَحْقَافِ', #2
u'بالأحقاف،': u'بِالأَحْقَافِ،', #2
u'بالإحقان': u'بِالْإِحْقَانِ', #1
u'بالأحمز': u'بِالْأَحْمَزِ', #1
u'بالأحمسيين': u'بِالأَحْمَسِيِّينَ', #2
u'بالأحمسيين': u'بِالْأَحْمَسِيِّينَ', #2
u'بالأحوط': u'بِالْأَحْوَطِ', #105
u'بالأحوى': u'بِالْأَحْوَى', #1
u'بالأحيرش': u'بِالْأُحَيْرِشِ', #1
u'بالإخاوة': u'بِالْإِخَاوَةِ', #2
u'بالاختدام': u'بِالِاخْتِدَامِ', #1
u'بالاختصاء': u'بِالِاخْتِصَاءِ', #1
u'بالاختلاع': u'بِالِاخْتِلَاعِ', #5
u'بالإخدام': u'بِالْإِخْدَامِ', #5
u'بالآخره': u'بالآخِرَهْ', #1
u'بالآخرية': u'بِالْآخِرِيَّةِ', #24
u'بالأخس': u'بِالْأَخَسِّ', #7
u'بالأخشبين': u'بِالْأَخْشَبَيْنِ', #2
u'بالأخشم': u'بِالْأَخْشَمِ', #1
u'بالإخصاء': u'بِالْإِخْصَاءِ', #2
u'بالأخصر': u'بِالْأَخْصَرِ', #1
u'بالأخصية': u'بِالْأَخَصِّيَّةِ', #3
u'بالإخلاق': u'بِالْإِخْلَاقِ', #1
u'بالأخنم': u'بِالْأَخْنَمِ', #1
u'بالإدخار': u'بِالْإِدْخَارِ', #2
u'بالإدراب': u'بِالْإِدْرَابِ', #1
u'بالأدرة': u'بِالْأُدْرَةِ', #5
u'بالآدم': u'بِالآدَمِ', #1
u'بالآدم،': u'بِالْآدَمِ،', #1
u'بالآدم': u'بِالْآدَمِ', #2
u'بالإدهان': u'بِالْإِدْهَانِ', #1
u'بالادهان': u'بِالِادِّهَانِ', #3
u'بالأدون': u'بِالْأَدْوَنِ', #4
u'بالإذايات': u'بِالْإذَايَاتِ', #1
u'بالإذاية': u'بِالْإِذِايَةِ', #1
u'بالإذاية': u'بِالْإِذَايَةِ', #11
u'بالإذخر': u'بِالْإِذْخِرِ', #9
u'بالإراءة': u'بِالْإِرَاءَةِ', #2
u'بالإربة': u'بِالْإِرْبَةِ', #1
u'بالإرتاج': u'بِالْإِرْتَاجِ', #1
u'بالارتضاع': u'بِالِارْتِضَاعِ', #6
u'بالارتفاق': u'بِالِارْتِفَاقِ', #10
u'بالإردب': u'بِالْإِرْدَبِّ', #8
u'بالأردبيس': u'بِالْأَرْدَبِيسِ', #1
u'بالإردبين': u'بِالْإِرْدَبَّيْنِ', #1
u'بالأرسال': u'بِالْأَرْسَالِ', #1
u'بالأرش': u'بِالْأَرْشِ', #479
u'بالإرشاق': u'بِالْإِرْشَاقِ', #1
u'بالأرشدية': u'بِالْأَرْشَدِيَّةِ', #10
u'بالأرشين': u'بِالْأَرْشَيْنِ', #8
u'بالأرفاق': u'بِالْأَرْفَاقِ', #1
u'بالأرفق': u'بِالْأَرْفَقِ', #2
u'بالإرقاق': u'بِالْإِرْقَاقِ', #7
u'بالأروج': u'بِالْأَرْوَجِ', #3
u'بالأروسية': u'بِالْأَرُوسِيَّةِ', #1
u'بالأزارقة': u'بِالْأَزَارَقَةِ', #1
u'بالأزج': u'بِالْأَزَجِ', #1
u'بالأزج': u'بِالْأَزَجِّ', #1
u'بالأزد': u'بِالأَزْدِ', #1
u'بالأزد': u'بِالْأَزْدِ', #1
u'بالازدراع': u'بِالِازْدِرَاعِ', #1
u'بالأزرة': u'بِالْأُزْرَةِ', #2
u'بالإزرة': u'بِالْإِزْرَةِ', #2
u'بالإزلاق': u'بِالْإِزْلَاقِ', #3
u'بالأساتير': u'بِالْأَسَاتِيرِ', #3
u'بالأسارى': u'بِالأَسَارَى', #1
u'بالأسارى،': u'بِالأُسَارَى،', #1
u'بالأسارى،': u'بِالْأُسَارَى،', #1
u'بالأسارى': u'بِالأُسَارَى', #2
u'بالأسارى': u'بِالْأُسَارَى', #24
u'بالأسارى': u'بِالْأَسَارَى', #6
u'بالإسامة': u'بِالْإِسَامَةِ', #8
u'بالأسانين': u'بِالْأَسَانِينِ', #1
u'بالإسبيجابي': u'بالإسبيجابي', #1
u'بالاستتابة': u'بِالِاسْتِتَابَةِ', #4
u'بالاستثابة': u'بِالِاسْتِثَابَةِ', #1
u'بالاستجرار': u'بِالِاسْتِجْرَارِ', #3
u'بالاستجمار': u'بِالاِسْتِجْمَارِ', #1
u'بالاستجمار': u'بِالِاسْتِجْمَارِ', #9
u'بالاستحاضة': u'بِالِاسْتِحَاضَةِ', #22
u'بالاستحداد': u'بِالِاسْتِحْدَادِ', #3
u'بالاستحشاف': u'بِالِاسْتِحْشَافِ', #1
u'بالاستخلال': u'بِالِاسْتِخْلَالِ', #1
u'بالاستدخال': u'بِالِاسْتِدْخَالِ', #7
u'بالاسترقاء': u'بِالِاسْتِرْقَاءِ', #8
u'بالاسترقاق': u'بِالِاسْتِرْقَاقِ', #34
u'بالاستزكاء': u'بِالِاسْتِزْكَاءِ', #1
u'بالاستسعاء': u'بِالِاسْتِسْعَاءِ', #29
u'بالاستسفار': u'بِالِاسْتِسْفَارِ', #1
u'بالاستسلاف': u'بِالِاسْتِسْلَافِ', #1
u'بالاستسلاف': u'بِالاِسْتِسْلاَفِ', #1
u'بالاستسمان': u'بِالِاسْتِسْمَانِ', #1
u'بالاستصناع': u'بِالِاسْتِصْنَاعِ', #7
u'بالاستضرار': u'بِالِاسْتِضْرَارِ', #1
u'بالاستطراق': u'بِالِاسْتِطْرَاقِ', #5
u'بالاستطهار': u'بِالاِسْتِطْهَارِ', #1
u'بالاستعاط': u'بِالِاسْتِعَاطِ', #3
u'بالاستغنام': u'بِالِاسْتِغْنَامِ', #1
u'بالاستفراش': u'بِالِاسْتِفْرَاشِ', #9
u'بالاستفصال': u'بِالِاسْتِفْصَالِ', #1
u'بالاستقاءة': u'بِالِاسْتِقَاءَةِ', #11
u'بالاستكتام': u'بِالِاسْتِكْتَامِ', #1
u'بالاستنان': u'بِالِاسْتِنَانِ', #3
u'بالاستنثار': u'بِالِاسْتِنْثَارِ', #3
u'بالاستنجاء': u'بِالِاسْتِنْجَاءِ', #39
u'بالاستنزاه': u'بِالِاسْتِنْزَاهِ', #2
u'بالاستنصات': u'بِالِاسْتِنْصَاتِ', #1
u'بالاستنكاه': u'بِالِاسْتِنْكَاهِ', #5
u'بالاستنماء': u'بِالِاسْتِنْمَاءِ', #2
u'بالاستهام': u'بِالِاسْتِهَامِ', #7
u'بالاستياك': u'بِالِاسْتِيَاكِ', #2
u'بالاستيام': u'بِالِاسْتِيَامِ', #1
u'بالاستيفا': u'بِالِاسْتِيفَا', #1
u'بالاستيقاء': u'بِالِاسْتِيقَاءِ', #1
u'بالاستيناء': u'بِالِاسْتِينَاءِ', #1
u'بالاستيهاب': u'بِالِاسْتِيهَابِ', #4
u'بالأسداد': u'بِالْأَسْدَادِ', #2
u'بالأسراء': u'بِالْأُسَرَاءِ', #13
u'بالإسرار': u'بِالْإِسْرَارِ', #5
u'بالإسرائليات': u'بالإسْرائِلِيَّاتِ', #1
u'بالأسرب': u'بِالْأَسْرُبِّ', #1
u'بالأسريقون': u'بالأسريقون', #1
u'بالإسعاط': u'بِالْإِسْعَاطِ', #6
u'بالإسفاه': u'بِالْإِسْفَاهِ', #5
u'بالأسفيذاج': u'بِالْأَسْفِيذَاجِ', #1
u'بالإسفيذاج': u'بِالْإِسْفِيذَاجِ', #2
u'بالإسكندروس': u'بالإسكندروس', #1
u'بالاسلام': u'بالاسلام', #1
u'بالأسلحه': u'بِالْأَسْلِحَهْ', #1
u'بالأسلمي': u'بِالْأَسْلَمِيِّ', #1
u'بالإسنوي': u'بِالْإِسْنَوِيِّ', #1
u'بالأسواف،': u'بِالأَسْوَافِ،', #1
u'بالأسواف': u'بِالأَسْوَافِ', #2
u'بالأسواف': u'بِالْأَسْوَافِ', #4
u'بالأشبانيين': u'بِالْأشْبانِيِّين', #1
u'بالأشبهية': u'بِالْأَشْبَهِيَّةِ', #1
u'بالأشتر': u'بالأشتر', #1
u'بالإشخاص': u'بِالْإِشْخَاصِ', #1
u'بالأشراس': u'بالأشراس', #1
u'بالأشرفي': u'بِالْأَشْرَفِي', #1
u'بالأشرفي': u'بِالْأَشْرَفِيِّ', #6
u'بالإشفاع': u'بِالْإِشْفَاعِ', #1
u'بالأشفى': u'بِالْأَشْفَى', #1
u'بالإشفى': u'بِالْإِشْفَى', #1
u'بالإشلاء': u'بِالْإِشْلَاءِ', #4
u'بالإشنان': u'بِالْإِشْنَانِ', #1
u'بالأشنان': u'بِالْأُشْنَانِ', #23
u'بالإشواء': u'بِالْإِشْوَاءِ', #1
u'بالأصافر': u'بِالأَصَافِرِ', #1
u'بالأصافر': u'بَالْأَصَافِرِ', #1
u'بالأصافر': u'بِالْأَصَافِرِ', #1
u'بالأصبهاني': u'بِالْأَصْبَهَانِيّ', #1
u'بالأصبهاني': u'بِالْأَصْبَهَانِيِّ', #1
u'بالأصحية': u'بِالْأَصَحِّيَّةِ', #2
u'بالإصرافة': u'بِالْإِصْرَافَةِ', #3
u'بالاصطباح': u'بِالِاصْطِبَاحِ', #1
u'بالاصطبار': u'بِالِاصْطِبَارِ', #1
u'بالأصطبة': u'بِالْأُصْطُبَّةِ', #1
u'بالإصطخري': u'بِالْإِصْطَخْرِيِّ', #1
u'بالاصطلام': u'بِالِاصْطِلَامِ', #5
u'بالأصلحية': u'بِالْأَصْلَحِيَّةِ', #1
u'بالأصولين': u'بِالْأُصُولِينَ', #1
u'بالإضاقة': u'بِالْإِضَاقَةِ', #1
u'بالأضر': u'بِالْأَضَرِّ', #24
u'بالاضطباع': u'بِالِاضْطِبَاعِ', #6
u'بالأضعف': u'بِالْأَضْعَفِ', #15
u'بالإضمان': u'بِالْإِضْمَانِ', #1
u'بالاطعام': u'بِالِاطِّعَامِ', #1
u'بالإطماع': u'بِالْإِطْمَاعِ', #1
u'بالأطهر': u'بِالْأَطْهَرِ', #2
u'بالأطيبية': u'بِالْأَطْيَبِيَّةِ', #3
u'بالأعبد': u'بِالْأَعْبُدِ', #2
u'بالاعتلاف': u'بِالِاعْتِلَافِ', #1
u'بالاعتمال': u'بِالِاعْتِمَالِ', #3
u'بالأعدلية': u'بِالْأَعْدَلِيَّةِ', #6
u'بالإعراء': u'بِالْإِعْرَاءِ', #3
u'بالأعرابى': u'بِالأَعْرَابِىِّ', #1
u'بالأعكان': u'بِالْأَعْكَانِ', #1
u'بالإعلاق': u'بِالْإِعْلَاقِ', #1
u'بالأعلمية': u'بِالْأَعْلَمِيَّةِ', #4
u'بالأغاليظ،': u'بِالْأَغَالِيظِ،', #1
u'بالأغبرة': u'بِالْأَغْبِرَةِ', #1
u'بالأغبط': u'بِالْأَغْبَطِ', #6
u'بالإغسال': u'بِالْإِغْسَالِ', #1
u'بالأغلظية': u'بِالْأَغْلَظِيَّةِ', #1
u'بالإغما': u'بِالْإِغْمَا', #1
u'بالإغياء': u'بِالْإِغْيَاءِ', #2
u'بالإفاتة': u'بِالْإِفَاتَةِ', #1
u'بالأفاوية': u'بِالْأَفَاوِيَةِ', #1
u'بالافتكاك': u'بِالِافْتِكَاكِ', #5
u'بالافتيات': u'بِالِافْتِيَاتِ', #15
u'بالإفرار': u'بِالْإِفْرَارِ', #1
u'بالأفراس': u'بِالْأَفْرَاسِ', #8
u'بالأفرع': u'بِالْأَفْرَعِ', #2
u'بالإفعال': u'بِالْإِفْعَالِ', #1
u'بالأفقه': u'بِالْأَفْقَهِ', #5
u'بالأفقهية': u'بِالْأَفْقَهِيَّةِ', #1
u'بالأفلس': u'بِالْأَفْلُسِ', #1
u'بألافه': u'بِأُلّافِهِ', #1
u'بالأقارير': u'بِالْأَقَارِيرِ', #2
u'بالأقاصرة': u'بِالْأَقَاصِرَةِ', #1
u'بالأقاقيا': u'بالأقاقيا', #1
u'بالإقباض': u'بِالْإِقْبَاضِ', #68
u'بالأقتاب': u'بِالْأَقْتَابِ', #1
u'بالإقتحام': u'بالإقتحام', #1
u'بالاقتضاض': u'بِالِاقْتِضَاضِ', #2
u'بالإقدار': u'بِالْإِقْدَارِ', #7
u'بالأقرا': u'بِالْأَقْرَا', #1
u'بالأقراء': u'بِالْأَقْرَاءِ', #296
u'بالأقربية': u'بِالْأَقْرَبِيَّةِ', #18
u'بالأقرئية': u'بِالْأَقْرَئِيَّةِ', #4
u'بالأقصياء': u'بالأَقْصِياءِ', #1
u'بالأقط،': u'بِالأَقِطِ،', #2
u'بالأقط': u'بِالْأَقِطِ', #20
u'بالأقط': u'بِالأَقِطِ', #4
u'بالأقفزة': u'بِالْأَقْفِزَةِ', #1
u'بالأقلاد': u'بِالْأَقْلَادِ', #2
u'بالأقلف': u'بِالْأَقْلَفِ', #2
u'بالأقيس': u'بِالْأَقْيَسِ', #1
u'بالأقيشر': u'بالأقَيْشِر', #1
u'بالإكاف': u'بِالْإِكَافِ', #4
u'بالأكام': u'بِالْأَكَامِ', #1
u'بالأكبار': u'بِالْأَكْبَارِ', #3
u'بالآكد': u'بِالْآكَدِ', #4
u'بالأكدرية': u'بِالْأَكْدَرِيَّةِ', #10
u'بالآكدية': u'بِالْآكَدِيَّةِ', #2
u'بالأكرار': u'بِالْأَكْرَارِ', #2
u'بالأكساب': u'بِالْأَكْسَابِ', #9
u'بالأكيدر': u'بِالأُكَيْدِرِ', #1
u'بالالتداد': u'بِالِالْتِدَادِ', #1
u'بالالتعان': u'بِالِالْتِعَانِ', #1
u'بالإلهة': u'بِالْإِلَهَةِ', #1
u'بالألواج': u'بالألواج', #1
u'بالألوة': u'بِالأُلُوَّةِ', #1
u'بالألوة': u'بِالْأَلْوَةِ', #1
u'بالألوة': u'بِالأَلُوَّةِ', #2
u'بالألوة': u'بِالْأُلُوَّةِ', #2
u'بالألون': u'بالألون', #1
u'بالام': u'بالام', #1
u'بالام': u'بَالاَمُ', #1
u'بالأمثله': u'بِالْأَمْثِلَهْ', #1
u'بالأمثلية': u'بِالْأَمْثَلِيَّةِ', #1
u'بالآمدي': u'بِالْآمِدِيِّ', #1
u'بالأمراليسير': u'بِالْأَمْرِالْيَسِيرِ', #1
u'بالأمران': u'بِالْأَمْرَانِ', #1
u'بالإمناء': u'بِالْإِمْنَاءِ', #7
u'بالأمنان': u'بِالْأَمْنَانِ', #1
u'بالأنبجانى': u'بِالأَنْبِجَانِىِّ', #1
u'بالانبغاء': u'بِالِانْبِغَاءِ', #4
u'بالانتتاف': u'بِالِانْتِتَافِ', #1
u'بالانتثار': u'بِالِانْتِثَارِ', #1
u'بالانتقاع': u'بِالِانْتِقَاعِ', #2
u'بالأنجيل': u'بِالْأَنْجِيلِ', #1
u'بالانحرار': u'بِالِانْحِرَارِ', #1
u'بالانخناس': u'بِالِانْخِنَاسِ', #1
u'بالإنزاء': u'بِالْإِنْزَاءِ', #2
u'بالأنزر': u'بِالْأَنْزَرِ', #1
u'بالإنساب': u'بِالْإِنْسَابِ', #1
u'بالأنصارى': u'بِالأَنْصَارِىِّ', #2
u'بالأنصال': u'بِالْأَنْصَالِ', #1
u'بالانصباغ': u'بِالِانْصِبَاغِ', #2
u'بالأنظر': u'بِالْأَنْظَرِ', #5
u'بالإنعاظ': u'بِالْإِنْعَاظِ', #12
u'بالإنفحة': u'بِالْإِنْفَحَةِ', #15
u'بالإنقاد': u'بِالْإِنْقَادِ', #1
u'بالأنقص': u'بِالْأَنْقَصِ', #12
u'بالأنكحة': u'بِالْأَنْكِحَةِ', #11
u'بالأنوام': u'بِالْأَنْوَامِ', #1
u'بالإهطاع': u'بالإهطاع', #1
u'بالأهوية': u'بِالْأَهْوِيَةِ', #1
u'بالأواق': u'بِالأَوَاقِ', #2
u'بالأوثقية': u'بِالْأَوْثَقِيَّةِ', #1
u'بالأوزاعي': u'بِالأَوْزَاعِيِّ', #1
u'بالأوسق': u'بِالْأَوْسُقِ', #5
u'بالأوفاض': u'بِالأَوْفَاضِ', #1
u'بالأوقاص': u'بِالْأَوْقَاصِ', #2
u'بالأوكد': u'بِالْأَوْكَدِ', #3
u'بالأولاج،': u'بِالأَوْلاجِ،', #1
u'بالأولة': u'بِالْأَوَّلَةِ', #1
u'بالأولة': u'بِالْأُولَةِ', #3
u'بالأولى': u'بِالْأُولًى', #1
u'بالائتمام': u'بِالِائْتَمَامِ', #1
u'بالائتمام': u'بِالِائْتِمَامَ', #1
u'بالائتمام': u'بِالِائْتِمَامِ', #2
u'بالإياس': u'بِالإِيَاسِ', #1
u'بالإياس': u'بِالْإِيَاسِ', #33
u'بالإيام': u'بِالْإِيَامِ', #1
u'بالإيتان': u'بِالْإِيتَانِ', #1
u'بالإيخاء': u'بِالْإِيخَاءِ', #1
u'بالأيدى': u'بَالأَيْدِى', #1
u'بالأيدى': u'بِالأَيْدِى', #3
u'بالإيراحات': u'بِالْإِيرَاحَاتِ', #1
u'بالآيس': u'بِالْآيِسِ', #1
u'بالآيسة': u'بِالْآيِسَةِ', #4
u'بالآيل': u'بِالْآيِلِ', #1
u'بالأيلة': u'بِالْأَيْلَةِ', #1
u'بالإيمانقال': u'بِالإِيمَانِقَالَ', #1
u'بالبا': u'بِالْبَا', #1
u'بالباذروج': u'بِالْبَاذَرُوجِ', #1
u'بالباذق': u'بِالْبَاذِقِ', #2
u'بالباشاه': u'بِالْبَاشَاهْ', #2
u'بالباطلالوجه': u'بِالْبَاطِلِالْوَجْهُ', #1
u'بالباغ': u'بِالْبَاغِ', #1
u'بالباغ': u'بِالْبَاغِّ', #1
u'بالباقلا': u'بِالْبَاقِلَّا', #2
u'بالبالوصة': u'بِالْبَالُوصَةِ', #1
u'بالبانيذ': u'بالبانيذ', #1
u'بالباهلة': u'بِالْبَاهِلَةِ', #1
u'بألبتة': u'بِأَلْبَتَّةَ', #3
u'بالبتيراء': u'بالبتيراء', #1
u'بالبتيراء': u'بِالْبُتَيْرَاءِ', #1
u'بالبثرات': u'بِالْبَثَرَاتِ', #1
u'بالبحوحة': u'بِالْبُحُوحَةِ', #1
u'بالبداء': u'بِالْبَدَاءِ', #1
u'بالبدار': u'بِالْبِدَارِ', #6
u'بالبذي': u'بِالْبَذِيِّ', #1
u'بالبذية': u'بِالْبَذِيَّةِ', #1
u'بالبرابط': u'بِالْبَرَابِطِ', #1
u'بالبراجم': u'بِالْبَرَاجِمِ', #15
u'بالبربابكن': u'بالبربابكن', #1
u'بالبرسام': u'بِالْبِرْسَامِ', #1
u'بالبرلس': u'بالبُرلُس', #1
u'بالبرلس': u'بِالْبُرُلُّسِ', #1
u'بالبز': u'بِالْبَزِّ', #7
u'بالبزدوي': u'بِالْبَزْدَوِيِّ', #1
u'بالبسائط': u'بِالْبَسَائِطِ', #2
u'بالبسل': u'بِالْبَسْلِ', #1
u'بالبسوطة': u'بِالْبُسُوطَةِ', #2
u'بالبسيس': u'بِالْبَسِيسِ', #2
u'بالبسيلة': u'بِالْبَسِيلَةِ', #1
u'بالبصال': u'بِالْبَصَّالِ', #1
u'بالبطارخ': u'بِالْبَطَارِخِ', #3
u'بالبطاطيخ': u'بِالْبَطَاطِيخِ', #1
u'بالبعونة': u'بِالْبُعُونَةِ', #1
u'بالبغاث': u'بِالْبُغَاثِ', #1
u'بالبغضة': u'بِالْبِغْضَةِ', #1
u'بالبغى': u'بِالْبَغْىِ', #1
u'بالبقا': u'بِالْبَقَا', #1
u'بالبقجة': u'بِالْبُقْجَةِ', #2
u'بالبقم': u'بِالْبَقْمِ', #1
u'بالبقم': u'بِالْبُقَّمِ', #1
u'بالبقور': u'بِالْبُقُورِ', #1
u'بالبكا': u'بِالْبُكَا', #1
u'بالبلاليج': u'بِالبَلَالِيجِ', #1
u'بالبلان': u'بِالْبَلَّانِ', #1
u'بالبلدقوله': u'بِالْبَلَدِقَوْلُهُ', #1
u'بالبلغم': u'بِالْبَلْغَمِ', #5
u'بالبلكفه': u'بِالْبَلْكَفَهْ', #1
u'بالبلى': u'بِالْبِلَى', #10
u'بالبليلة': u'بِالْبَلِيلَةِ', #4
u'بالبنون': u'بِالْبَنُونَ', #2
u'بالبنينا': u'بِالْبَنِينَا', #1
u'بالبهشمية': u'بِالْبَهْشَمِيَّةِ', #1
u'بالبهق': u'بِالْبَهَقِ', #2
u'بالبو': u'بِالْبَوِّ', #1
u'بألبوا': u'بِأَلَبُوا', #1
u'بالبواريج': u'بِالْبَوَارِيجِ', #2
u'بالبوازيج': u'بِالْبَوَازِيجِ', #2
u'بالبواطيل': u'بِالْبَوَاطِيلِ', #1
u'بالبوص': u'بِالْبُوصِ', #1
u'بالبوظة': u'بِالْبُوظَةِ', #1
u'بالبولصة': u'بِالْبُولِصَةِ', #1
u'بالبويب': u'بِالْبُوَيْبِ', #1
u'بالبويرة': u'بِالْبُوَيْرَة', #1
u'بالبويرة': u'بِالْبُوَيْرَةِ', #24
u'بالبيارة': u'بِالْبَيَّارَةِ', #1
u'بالبيازين': u'بِالْبَيَازِينَ', #2
u'بالبيتوتة': u'بِالْبَيْتُوتَةِ', #9
u'بالبيرخشك': u'بالبيرخشك', #1
u'بالبينه': u'بِالْبَيِّنَهْ', #3
u'بالبيهقي': u'بِالْبَيْهَقِيِّ', #1
u'بالبيوتة': u'بِالْبَيُّوتَةِ', #1
u'بالبيوعات': u'بِالْبُيُوعَاتِ', #1
u'بالتاد': u'بالتاد', #1
u'بالتأذي': u'بِالتَّأَذِّي', #1
u'بالتأسية': u'بِالتَّأْسِيَةِ', #1
u'بالتافة': u'بِالتَّافَةِ', #1
u'بالتأقيت': u'بِالتَّأْقِيتِ', #14
u'بالتالف': u'بِالتَّالِفِ', #8
u'بالتأيم': u'بِالتَّأَيُّمِ', #1
u'بالتبحير': u'بِالتَّبْحِيرِ', #1
u'بالتبدئة': u'بِالتَّبْدِئَةِ', #6
u'بالتبديع': u'بِالتَّبْدِيعِ', #2
u'بالتبرين': u'بِالتِّبْرَيْنِ', #2
u'بالتبس': u'بالتبس', #1
u'بالتبصرة': u'بِالتَّبْصِرَةِ', #2
u'بالتبعض': u'بِالتَّبَعُّضِ', #1
u'بالتبوء': u'بِالتَّبَوُّءِ', #1
u'بالتبوئة': u'بِالتَّبْوِئَةِ', #31
u'بالتبيع': u'بِالتَّبِيعِ', #3
u'بالتترس': u'بِالتَّتَرُّسِ', #2
u'بالتتريب': u'بِالتَّتْرِيبِ', #8
u'بالتتن': u'بِالتُّتُن', #2
u'بالتجاحد': u'بِالتَّجَاحُدِ', #1
u'بالتجانف': u'بِالتَّجَانُفِ', #1
u'بالتجزي': u'بالتجزي', #1
u'بالتجزي': u'بِالتَّجَزِّيِ', #2
u'بالتجزي': u'بِالتَّجَزِّي', #36
u'بالتجسيس': u'بالتجسيس', #1
u'بالتجمير': u'بِالتَّجْمِيرِ', #3
u'بالتجوير': u'بِالتَّجْوِيرِ', #2
u'بالتحاص': u'بِالتَّحَاصِّ', #2
u'بالتحتيت': u'بِالتَّحْتِيتِ', #1
u'بالتحدير': u'بِالتَّحْدِيرِ', #1
u'بالتحرم': u'بِالتَّحَرُّمِ', #47
u'بالتحزير': u'بِالتَّحْزِيرِ', #1
u'بالتحزينة': u'بِالتَّحْزِينَةِ', #1
u'بالتحلم': u'بِالتَّحَلُّمِ', #7
u'بالتحنيث': u'بِالتَّحْنِيثِ', #3
u'بالتحيل': u'بِالتَّحَيُّلِ', #14
u'بالتخاير': u'بِالتَّخَايُرِ', #14
u'بالتختم': u'بِالتَّخَتُّمِ', #12
u'بالتخرص': u'بِالتَّخَرُّصِ', #2
u'بالتخريص': u'بِالتَّخْرِيصِ', #7
u'بالتخليه': u'بِالتَّخْلِيَهْ', #1
u'بالتدام': u'بِالْتِدَامِ', #1
u'بالتدام': u'بِالْتِدَامْ', #1
u'بالتداوى': u'بِالتَّدَاوِى', #1
u'بالتراد': u'بِالتَّرَادِّ', #5
u'بالتراكن': u'بِالتَّرَاكُنِ', #1
u'بالترترة': u'بِالتَّرْتَرَةِ', #2
u'بالترخص': u'بِالتَّرَخُّصِ', #9
u'بالتروك': u'بِالتُّرُوكِ', #2
u'بالتريب': u'بِالتَّرَيُّبِ', #1
u'بالتزداد': u'بالتزداد', #1
u'بالتزريق': u'بِالتَّزْرِيقِ', #1
u'بالتزم': u'بِالْتَزَمَ', #3
u'بالتزمه': u'بِالْتَزَمَهُ', #1
u'بالتزييرة': u'بِالتَّزْيِيرَةِ', #1
u'بالتسجام': u'بِالتّسْجَامِ', #1
u'بالتسحب': u'بِالتَّسَحُّبِ', #1
u'بالتسحر': u'بِالتَّسَحُّرِ', #2
u'بالتسخيم': u'بِالتَّسْخِيمِ', #1
u'بالتسرر': u'بِالتَّسَرُّرِ', #1
u'بالتسري': u'بِالتَّسَرِّي', #31
u'بالتسليمة': u'بِالتَّسْلِيمَةِ', #52
u'بالتسليمتين': u'بِالتَّسْلِيمَتَيْنِ', #21
u'بالتسمح': u'بِالتَّسَمُّحِ', #9
u'بالتسميه': u'بِالتَّسْمِيَهْ', #1
u'بالتشرع': u'بِالتَّشَرُّعِ', #2
u'بالتشريج': u'بِالتَّشْرِيجِ', #3
u'بالتشطر': u'بِالتَّشَطُّرِ', #5
u'بالتشقيص': u'بِالتَّشْقِيصِ', #35
u'بالتشوت': u'بِالتَّشَوُّتِ', #1
u'بالتصارم': u'بِالتَّصَارُمِ', #1
u'بالتصبيب': u'بِالتَّصْبِيبِ', #1
u'بالتصرية': u'بِالتَّصْرِيَةِ', #35
u'بالتصقت': u'بِالْتَصَقَتْ', #1
u'بالتضبيب': u'بِالتَّضْبِيبِ', #20
u'بالتطليقة': u'بِالتَّطْلِيقَةِ', #19
u'بالتطليقتين': u'بِالتَّطْلِيقَتَيْنِ', #3
u'بالتعان': u'بِالْتِعَانِ', #5
u'بالتعانة': u'بالتعانة', #1
u'بالتعانه': u'بِالْتِعَانِهِ', #6
u'بالتعانها': u'بِالْتِعَانِهَا', #4
u'بالتعانهما': u'بِالْتِعَانِهِمَا', #2
u'بالتعاوض': u'بِالتَّعَاوُضِ', #1
u'بالتعريص': u'بِالتَّعْرِيصِ', #1
u'بالتعيب': u'بِالتَّعَيُّبِ', #20
u'بالتغالي': u'بِالتَّغَالِي', #2
u'بالتغبر': u'بِالتَّغَبُّرِ', #1
u'بالتغميط': u'بِالتَّغْمِيطِ', #1
u'بالتفاء': u'بِالْتِفَاءِ', #1
u'بالتفث': u'بالتفث', #1
u'بالتفروق': u'بِالتُّفْرُوقِ', #1
u'بالتقاص': u'بِالتَّقَاصِّ', #25
u'بالتقصيع': u'بِالتَّقْصِيعِ', #1
u'بالتقلل': u'بِالتَّقَلُّلِ', #2
u'بالتكدي': u'بالتكدي', #1
u'بالتكدي': u'بِالتَّكَدِّي', #15
u'بالتكفي': u'بِالتَّكَفِّي', #1
u'بالتلاعة': u'بِالتَّلَاعَةِ', #1
u'بالتلاعة': u'بِالتّلَاعَةِ', #2
u'بالتلاف': u'بِالتَّلَافِ', #1
u'بالتلبينة': u'بِالتَّلْبِينَةِ', #4
u'بالتلتلة': u'بِالتَّلْتَلَةِ', #2
u'بالتلحي': u'بِالتَّلَحِّي', #3
u'بالتلمح': u'بِالتَّلَمُّحِ', #1
u'بالتمالؤ': u'بِالتَّمَالُؤِ', #5
u'بالتمجس': u'بِالتَّمَجُّسِ', #1
u'بالتمحل': u'بِالتَّمَحُّلِ', #1
u'بالتمحيض': u'بِالتَّمْحِيضِ', #3
u'بالتمشدق': u'بِالتَّمَشْدُقِ', #1
u'بالتمشك': u'بِالتُّمُشْكِ', #2
u'بالتمعدد': u'بِالتَّمَعْدُدِ', #1
u'بالتمعك': u'بِالتَّمَعُّكِ', #1
u'بالتمير': u'بالتمير', #1
u'بالتناجز': u'بِالتَّنَاجُزِ', #2
u'بالتنباك': u'بِالتُّنْبَاكِ', #1
u'بالتنضيض': u'بِالتَّنْضِيضِ', #16
u'بالتنقيه': u'بِالتَّنْقِيَهْ', #1
u'بالتهارج': u'بِالتَّهَارُجِ', #1
u'بالتهايؤ': u'بِالتَّهَايُؤِ', #35
u'بالتهني': u'بِالتَّهَنِّي', #1
u'بالتواجب': u'بِالتَّوَاجُبِ', #2
u'بالتوبةوالمغفرة': u'بِالتَّوْبَةِوَالْمَغْفِرَةِ', #1
u'بالتوثقة': u'بِالتَّوْثِقَةِ', #2
u'بالتور': u'بِالتَّوْرِ', #2
u'بالتوضي': u'بِالتَّوَضِّي', #2
u'بالتوقان': u'بِالتَّوَقَانِ', #9
u'بالتولاء': u'بِالتَّوْلَاءِ', #1
u'بالتى': u'بِالَّتِى', #13
u'بالتيام': u'بِالْتِيَامٍ', #1
u'بالتيمارخانة': u'بالتيمارخانة', #1
u'بالث': u'بِالثّ', #1
u'بالثانى': u'بِالثَّانِى', #3
u'بالثجير': u'بِالثَّجِيرِ', #6
u'بالثجيرة': u'بِالثَّجِيرَةِ', #1
u'بالثخانة': u'بِالثَّخَانَةِ', #2
u'بالثروب': u'بِالثُّرُوبِ', #1
u'بالثفروق': u'بِالثُّفْرُوقِ', #1
u'بالثلثمائة': u'بِالثَّلَثِمِائَةِ', #1
u'بالثليث': u'بِالثَّلِيثِ', #1
u'بالثمام': u'بِالثُّمَامِ', #4
u'بالثمان': u'بِالثَّمَانِ', #1
u'بالثندوة': u'بِالثَّنْدُوَةِ', #2
u'بالثنيا': u'بِالثُّنْيَا', #11
u'بالثنيات': u'بِالثَّنِيَّاتِ', #5
u'بالثنيان': u'بِالثُّنْيَانِ', #3
u'بالثولاء': u'بِالثَّوْلَاءِ', #4
u'بالثيابة': u'بِالثِّيَابَةِ', #4
u'بالثيوبة': u'بِالثُّيُوبَةِ', #17
u'بالج': u'بَالِجِ', #1
u'بالج': u'بِالْجَ', #1
u'بالجارود': u'بِالْجَارُودِ', #1
u'بالجاروق': u'بِالْجَارُوقِ', #2
u'بالجباجب': u'بِالْجَبَاجِبِ', #2
u'بالجبت': u'بِالْجِبْتِ', #19
u'بالجبران': u'بِالْجُبْرَانِ', #19
u'بالجبوب': u'بِالْجَبُوبِ', #4
u'بالجبيرة': u'بِالْجَبِيرَةِ', #4
u'بالجحف': u'بِالْجَحْفِ', #1
u'بالجحف': u'بِالْجُحَفِ', #1
u'بالجحفة،': u'بِالْجُحْفَةِ،', #2
u'بالجحفة': u'بِالْجُحْفَةِ', #42
u'بالجدرات': u'بِالْجَدَرَاتِ', #2
u'بالجدودة': u'بِالْجُدُودَةِ', #26
u'بالجدين': u'بِالْجَدَّيْنِ', #1
u'بالجذعة': u'بِالْجَذَعَةِ', #4
u'بالجذوذ': u'بِالْجُذُوذِ', #1
u'بالجرجانية': u'بالجرجانية', #1
u'بالجرموق': u'بِالْجُرْمُوقِ', #2
u'بالجرن': u'بِالْجُرْنِ', #2
u'بالجريب': u'بِالْجَرِيبِ', #1
u'بالجريش': u'بِالْجَرِيشِ', #2
u'بالجرين': u'بِالْجَرِينِ', #2
u'بالجزورة': u'بالجزورة', #1
u'بالجزولية': u'بِالْجَزُولِيَّةِ', #1
u'بالجزيةوروي': u'بِالْجِزْيَةِوَرُوِيَ', #1
u'بالجعالة': u'بِالْجَعَالَةِ', #13
u'بالجعالة': u'بِالْجِعَالَةِ', #3
u'بالجعائل': u'بِالْجَعَائِلِ', #2
u'بالجعرانة': u'بالجِعرانة', #1
u'بالجعرانة،': u'بالجِعْرَانة،', #1
u'بالجعرانة': u'بِالْجِعْرَانَة', #1
u'بالجعرانة': u'بالجعرانة', #2
u'بالجعرانة': u'بَالْجِعِرَّانَةِ', #3
u'بالجعرانة،': u'بِالْجِعْرَانَةِ،', #5
u'بالجعرانة': u'بِالْجِعْرَانَةِ', #51
u'بالجعرانة': u'بِالْجِعِرَّانَةِ', #6
u'بالجعرانة': u'بِالْجِعِرّانَةِ', #7
u'بالجعرانية': u'بالجعرانية', #1
u'بالجعفي،': u'بِالْجُعْفِيِّ،', #1
u'بالجلابين': u'بِالْجَلَّابِينَ', #1
u'بالجلاجل': u'بِالْجَلَاجِلِ', #3
u'بالجلاح': u'بِالْجُلَاحِ', #1
u'بالجلاز': u'بِالْجَلَّازِ', #1
u'بالجلاسة': u'بالجلاسة', #1
u'بالجلاهق': u'بِالْجُلَاهِقِ', #2
u'بالجلجان': u'بِالْجُلْجَانِ', #1
u'بالجلدات': u'بِالْجَلَدَاتِ', #2
u'بالجلمين': u'بِالْجَلَمَيْنِ', #6
u'بالجلهتين': u'بِالْجَلْهَتَيْنِ', #2
u'بالجماء': u'بِالْجَمَّاءِ', #13
u'بالجماء': u'بِالْجَمّاءِ', #3
u'بالجماعه': u'بِالْجَمَاعَهْ', #1
u'بالجنف': u'بِالْجَنَفِ', #1
u'بالجنيب': u'بِالْجَنِيبِ', #2
u'بالجنيد': u'بِالْجُنَيْدِ', #2
u'بالجوانية': u'بِالْجَوّانِيّةِ', #1
u'بالجوزجان': u'بالجَوْزَجَان', #1
u'بالجوشن': u'بِالْجَوْشَنِ', #1
u'بالجوعين': u'بِالْجَوْعَيْنِ', #4
u'بالجويرة،': u'بالجُوَيْرة،', #1
u'بالجيزة،': u'بِالْجِيزَةِ،', #1
u'بالجيزة': u'بِالْجِيزَةِ', #3
u'بالحاظر': u'بِالْحَاظِرِ', #1
u'بالحبشى': u'بِالْحَبَشَى', #1
u'بالحبشى': u'بِالْحُبْشِىِّ', #1
u'بالحبلان': u'بِالْحَبْلَانِ', #1
u'بالحبلقة': u'بِالْحَبْلَقَةِ', #1
u'بالحثيات': u'بِالْحَثَيَاتِ', #1
u'بالحثية': u'بِالْحَثْيَةِ', #1
u'بالحجف': u'بِالْحَجَفِ', #1
u'بالحجه': u'بِالْحُجَّهْ', #1
u'بالحجون': u'بِالْحَجُونٌٌٌٌِ', #1
u'بالحجون': u'بِالْحُجُونِ', #1
u'بالحجون': u'بِالْحَجُونِ', #19
u'بالحجون،': u'بِالْحَجُونِ،', #3
u'بالحجونين': u'بِالْحَجُونَيْنِ', #1
u'بالحدثان': u'بِالْحَدَثَانِ', #2
u'بالحدوبة': u'بِالْحُدُوبَةِ', #1
u'بالحدوة': u'بِالْحَدْوَةِ', #1
u'بالحدودوروي': u'بِالْحُدُودِوَرُوِيَ', #1
u'بالحرانية': u'بِالْحَرّانِيَّةِ', #1
u'بالحربث': u'بِالْحُرْبُثِ', #1
u'بالحرزة': u'بِالْحَرَزَةِ', #1
u'بالحرقان': u'بِالْحُرْقَانِ', #3
u'بالحركه': u'بِالْحَرَكَهْ', #1
u'بالحرمه': u'بِالْحُرْمَهْ', #1
u'بالحرى': u'بِالْحَرِىِّ', #1
u'بالحزاة': u'بِالْحُزَاةِ', #1
u'بالحزة': u'بِالْحُزَّةِ', #1
u'بالحزورة': u'بِالْحَزُورَةِ', #1
u'بالحزورة': u'بِالْحَزَوَّرَةِ', #1
u'بالحزورة،': u'بِالْحَزْوَرَةَ،', #1
u'بالحزورة،': u'بِالْحَزْوَرَةِ،', #1
u'بالحزورة': u'بِالْحَزْوَرَةِ', #10
u'بالحسمانية': u'بالحسمانية', #1
u'بالحشوش': u'بِالْحُشُوشِ', #3
u'بالحصا': u'بِالْحَصَا', #2
u'بالحصا،': u'بِالْحَصَا،', #3
u'بالحصاب': u'بِالْحِصَابِ', #2
u'بالحصحاص': u'بِالْحِصْحَاصِ', #1
u'بالحصكفي': u'بِالْحَصْكَفِيُّ', #1
u'بالحصيدقرى': u'بِالْحَصِيدِقُرًى', #1
u'بالحضرمة': u'بِالْحَضْرَمَةِ', #1
u'بالحطة': u'بِالْحِطَّةِ', #1
u'بالحطيم': u'بِالْحَطِيمِ', #12
u'بالحفا': u'بِالْحَفَا', #2
u'بألحقت': u'بِأُلْحِقَتْ', #1
u'بالحلاوه': u'بِالْحَلَاوَهْ', #1
u'بالحلزمان': u'بِالْحِلْزِمَانِ', #1
u'بالحلوا': u'بِالْحَلْوَا', #1
u'بالحماحمي': u'بالْحَمَاحِمِيِّ', #1
u'بالحملاء': u'بِالْحُمَلَاءِ', #3
u'بالحميرية': u'بِالْحِمْيَرِيَّةِ', #1
u'بالحميرية': u'بِالْحِمْيَرِيّةِ', #3
u'بالحنا': u'بِالْحِنَّا', #4
u'بالحنتم': u'بِالْحَنْتَمِ', #4
u'بالحوابط': u'بِالْحَوَابِطِ', #1
u'بالحولة': u'بِالْحُولَةِ', #1
u'بالحولة،': u'بِالْحُولَةِ،', #1
u'بالحولقة': u'بِالْحَوْلَقَةِ', #1
u'بالحويل': u'بِالْحَوِيلِ', #1
u'بالحيا': u'بِالْحَيَا', #1
u'بالحيس': u'بِالْحَيْسِ', #1
u'بالخ': u'بالخ', #1
u'بإلخاء': u'بِإِلْخَاءِ', #1
u'بالخانكة': u'بِالْخَانْكَةَ', #1
u'بالخبت': u'بِالْخَبْتِ', #1
u'بالختمات': u'بِالْخَتْمَاتِ', #1
u'بالختمات': u'بِالْخِتْمَاتِ', #1
u'بالختمات': u'بِالْخَتَمَاتِ', #4
u'بالخدب': u'بِالْخَدَبِ', #1
u'بالخدوة': u'بِالْخُدْوَةِ', #1
u'بالخذوات': u'بِالْخَذَوَاتِ', #1
u'بالخرء': u'بِالْخَرْءِ', #2
u'بالخرار': u'بالخرار', #1
u'بالخرار': u'بِالْخِرَارِ', #1
u'بالخرار،': u'بِالْخَرَّارِ،', #1
u'بالخرار': u'بِالْخَرَّارِ', #3
u'بالخراسانيي': u'بِالْخُرَاسَانِيِّي', #1
u'بالخربز': u'بِالْخِرْبِزِ', #1
u'بالخروبة': u'بِالْخَرُّوبَةِ', #1
u'بالخريبة': u'بِالْخُرَيْبَةِ', #1
u'بالخزار': u'بِالْخَزَّارِ', #1
u'بالخزام': u'بِالْخُزَامِ', #1
u'بالخزام': u'بِالْخِزَامِ', #1
u'بالخزب': u'بِالْخَزَبِ', #1
u'بالخشني': u'بِالْخُشَنِيِّ', #1
u'بالخصص': u'بِالْخُصُصِ', #1
u'بالخصعة': u'بِالْخَصْعَةِ', #1
u'بالخضخاض': u'بِالْخَضْخَاضِ', #2
u'بالخطا': u'بِالْخَطَا', #1
u'بالخطا': u'بِالْخُطَا', #1
u'بالخطائي': u'بِالْخَطَائِيِّ', #1
u'بالخطبةالوجه': u'بِالْخِطْبَةِالْوَجْهُ', #1
u'بالخطمى': u'بِالْخِطْمِىِّ', #5
u'بالخفتانات': u'بالخفتانات', #1
u'بالخلا': u'بِالْخَلَا', #1
u'بالخلاوي': u'بِالْخَلَاوِي', #6
u'بالخلةالوجه': u'بِالْخُلَّةِالْوَجْهُ', #1
u'بالخليصاء': u'بِالْخُلَيْصَاءِ', #1
u'بالخليطين؟': u'بِالْخَلِيطَينِ؟', #1
u'بالخليطين': u'بِالْخَلِيطَيْنِ', #9
u'بالخماسين': u'بِالْخَمَاسِينِ', #1
u'بالخميصة': u'بِالْخَمِيصَةِ', #1
u'بالخندمة': u'بِالْخَنْدَمَةِ', #4
u'بالخندمه': u'بِالْخَنْدَمَهْ', #2
u'بالخوانق': u'بِالْخَوَانِقِ', #6
u'بالخورنق': u'بِالْخَوَرْنَقِ', #1
u'بالخورنق،': u'بِالْخَوَرْنَقِ،', #1
u'بالخوصتين': u'بِالْخُوصَتَيْنِ', #3
u'بالخيروم': u'بِالْخَيْرُومِ', #1
u'بالخيور': u'بِالْخُيُورِ', #5
u'بالد': u'بِالدّ', #1
u'بالدارصيني': u'بِالدَّارَصِينِيِّ', #1
u'بالدافة': u'بِالدَّافَّةِ', #1
u'بالدامغان': u'بِالدَّامَغَانِ', #2
u'بالدامغان': u'بِالدَّامِغَانِ', #4
u'بالدانق': u'بِالدَّانَقِ', #7
u'بالدانق': u'بِالدَّانِقِ', #8
u'بالدبيلة': u'بِالدُّبَيْلَةِ', #1
u'بالدثنية': u'بِالْدَثِنَيَّةِ', #1
u'بالدخ': u'بِالدّخّ', #1
u'بالدرابزين': u'بِالدَّرَابْزِينِ', #1
u'بالدربكة': u'بِالدَّرَبُكَّةِ', #3
u'بالدرمك': u'بِالدّرْمَكِ', #1
u'بالدستمان': u'بِالدِّسْتِمَانِ', #1
u'بالدستيمان': u'بالدستيمان', #1
u'بالدستيمان': u'بِالدَّسْتِيمَانِ', #3
u'بالدعا': u'بِالدُّعَا', #1
u'بالدعاءوالتصريح': u'بِالدُّعَاءِوَالتَّصْرِيحِ', #1
u'بالدعجي': u'بِالدَّعْجِي', #1
u'بالدعيثة': u'بِالدُّعَيْثَةِ', #1
u'بالدفاف': u'بِالدِّفَافِ', #1
u'بالدقاقين': u'بِالدَّقَّاقِينَ', #1
u'بالدقعاء': u'بِالدَّقْعَاءِ', #2
u'بالدكادك': u'بِالدّكَادِكِ', #2
u'بالدلجة': u'بِالدُّلْجَةِ', #7
u'بالدلدل': u'بِالدُّلْدُلِ', #1
u'بالدنارين': u'بالدنارين', #1
u'بالدنيبة': u'بِالدِّنِيبَةِ', #1
u'بالده': u'بالده', #3
u'بالدهنا': u'بِالدَّهْنَا', #1
u'بالدهيم': u'بِالدّهَيْمِ', #2
u'بالدوا': u'بِالدَّوَا', #1
u'بالدوالى': u'بِالدَّوَالِى', #3
u'بالدوانق': u'بِالدَّوَانِقِ', #5
u'بالدوكان': u'بِالدُّوكَانِ', #1
u'بالدي': u'بِالدِّي', #2
u'بالدئل': u'بِالدّئِلِ', #1
u'بالدياس': u'بِالدِّيَاسِ', #1
u'بالدينا': u'بَالِدِينَا', #1
u'بالذباذب': u'بِالذّبَاذِبِ', #1
u'بالذحول': u'بِالذّحُولِ', #1
u'بالذرا': u'بِالذّرَا', #2
u'بالذرارى': u'بِالذَّرَارِىِّ', #1
u'بالذريرة': u'بِالذَّرِيرَةِ', #2
u'بالذعارة': u'بِالذِّعَارَةِ', #6
u'بالذفر': u'بِالذّفَرِ', #1
u'بالذفر': u'بِالذّفَرْ', #2
u'بالذفر': u'بِالذَّفَرِ', #2
u'بالذى': u'بِالَّذِى', #70
u'بالرءوس': u'بِالرُّءُوسِ', #14
u'بالرازي': u'بِالرَّازِيِّ', #1
u'بالراعى': u'بِالرَّاعِى', #1
u'بالراوند': u'بالراوند', #3
u'بالرأى': u'بِالرَّأْىِ', #3
u'بالرايطتين': u'بِالرَّايِطَتَيْنِ', #2
u'بالربائث': u'بِالرَّبَائِثِ', #1
u'بالرتقاء': u'بِالرَّتْقَاءِ', #11
u'بالرحا': u'بِالرَّحَا', #7
u'بالرحمن': u'بالرحمن', #2
u'بالرحمن': u'بِالرَّحْمَنْ', #3
u'بالرحمن': u'بِالرَّحْمَنِ', #49
u'بالرحمن': u'بِالرّحْمَنِ', #9
u'بالرحيلSغيلان': u'بِالرّحِيلِSغَيْلَانُ', #1
u'بالرخج': u'بِالرُّخَّجِ', #2
u'بالرستاق': u'بِالرُّسْتَاقِ', #1
u'بالرشتة': u'بِالرِّشْتَةِ', #2
u'بالرضم،': u'بِالرَّضْمِ،', #1
u'بالرعة': u'بِالرِّعَةِ', #2
u'بالرقبه': u'بِالرَّقَبَهْ', #1
u'بالرقبى': u'بِالرُّقْبَى', #2
u'بالرقمتين': u'بِالرَّقْمَتَيْنِ', #1
u'بالرقمتين': u'بِالرّقْمَتَيْنِ', #2
u'بالركاز': u'بِالرِّكَازِ', #18
u'بالركبان': u'بِالرّكْبَانِ', #2
u'بالركبان': u'بِالرُّكْبَانِ', #4
u'بالركبانية': u'بالركبانية', #2
u'بالركية': u'بِالرَّكِيَّةِ', #4
u'بالرمث': u'بِالرَّمَثِ', #1
u'بالرمى': u'بِالرَّمْىِ', #2
u'بالرميصاء': u'بِالرُّمَيْصَاءِ', #4
u'بالرند': u'بِالرَّنْدِ', #1
u'بالرندك': u'بالرندك', #1
u'بالروثة': u'بِالرَّوْثَةِ', #10
u'بالروحاء': u'بالروحاء', #1
u'بالروحاء': u'بالرَّوحاء', #1
u'بالروحاء،': u'بالرَّوْحاء،', #1
u'بالروحاء،': u'بِالرَّوْحَاءِ،', #2
u'بالروحاء': u'بِالرّوْحَاءِ', #20
u'بالروحاء': u'بِالرَّوْحَاءِ', #30
u'بالروشن': u'بِالرَّوْشَنِ', #1
u'بالرى': u'بِالرِّىِّ', #1
u'بالرى': u'بِالرَّىِّ', #23
u'بالريالات': u'بِالرِّيَالَاتِ', #4
u'بالريطتين': u'بِالرَّيْطَتَيْنِ', #2
u'بالزاب': u'بِالزَّابِ', #1
u'بالزاى': u'بِالزَّاى', #1
u'بالزبيل': u'بِالزَّبِيلِ', #1
u'بالزجيج': u'بِالزَّجِيجِ', #1
u'بالزراجين': u'بِالزَّرَاجِينِ', #1
u'بالزرانيق': u'بِالزَّرَانِيقِ', #1
u'بالزرموزة': u'بِالزُّرْمُوزَةِ', #1
u'بالزطي': u'بِالزُّطِّيِّ', #5
u'بالزغابة': u'بِالزّغَابَةِ', #4
u'بالزغاليط': u'بِالزَّغَالِيطِ', #1
u'بالزغف': u'بِالزّغْفِ', #3
u'بالزلخة': u'بِالزّلَخَةِ', #1
u'بالزلدوي': u'بِالزَّلْدَوِيِّ', #1
u'بالزلقه': u'بِالزَّلْقَهْ', #1
u'بألزم': u'بِأَلْزَمَ', #1
u'بالزمنة': u'بِالزَّمِنَةِ', #1
u'بألزمه': u'بِأَلْزَمَهُ', #1
u'بألزموا': u'بِأَلْزَمُوا', #1
u'بالزنية': u'بِالزَّنْيَةِ', #1
u'بالزنية': u'بِالزِّنْيَةِ', #1
u'بالزهراني': u'بِالزَّهْرَانِيِّ', #1
u'بالزوراء': u'بِالزَّوْرَاءِ', #15
u'بالزوزني': u'بِالزَّوْزَنِيِّ', #1
u'بالزيافة': u'بِالزِّيَافَةِ', #13
u'بالزيلعي': u'بِالزَّيْلَعِيِّ', #1
u'بالس': u'بِالسَّ', #1
u'بالس': u'بَالِسُ', #1
u'بالس': u'بَالِسَ', #8
u'بالسابريتين': u'بالسابريتين', #1
u'بالسابريتين': u'بالسَّابِرِيّتَيْن', #1
u'بالساج،': u'بالسّاج،', #1
u'بالساج': u'بِالسّاجِ', #1
u'بالساج': u'بِالسَّاجِ', #8
u'بالسالحين': u'بِالسَّالِحِينَ', #1
u'بالسباء': u'بِالسِّبَاءِ', #1
u'بالسبالين': u'بِالسِّبَالَيْنِ', #2
u'بالسباهي': u'بِالسَّبَاهِي', #2
u'بالسبعان': u'بِالسّبُعَانِ', #1
u'بالسبوطة': u'بِالسُّبُوطَةِ', #1
u'بالسبى': u'بِالسَّبْىِ', #3
u'بألست': u'بِأَلَسْتُ', #1
u'بالستوق': u'بِالسَّتُّوقِ', #1
u'بالستوقة': u'بِالسَّتُّوقَةِ', #3
u'بالسحل': u'بِالسَّحْلِ', #2
u'بالسحلية': u'بِالسَّحْلِيَّةِ', #1
u'بالسحلية': u'بِالسِّحْلِيَّةِ', #3
u'بالسخال': u'بِالسِّخَالِ', #3
u'بالسخل': u'بِالسَّخْلِ', #7
u'بالسخلة': u'بِالسَّخْلَةِ', #21
u'بالسراباتية': u'بالسراباتية', #1
u'بالسراطين': u'بِالسَّرَاطِينَ', #1
u'بالسرغ': u'بِالسَّرْغِ', #1
u'بالسرف': u'بِالسَّرَفِ', #31
u'بالسرقنة': u'بِالسَّرْقَنَةِ', #1
u'بالسرقين': u'بِالسِّرْقِينِ', #7
u'بالسرموزة': u'بالسُّرْمُوزَةِ', #1
u'بالسرموزة': u'بِالسُّرْمُوزَةِ', #1
u'بالسريجية': u'بِالسَّرِيجِيَّةِ', #1
u'بالسريجية': u'بِالسُّرَيْجِيَّةِ', #4
u'بالسعوط': u'بِالسُّعُوطِ', #1
u'بالسعوط': u'بِالسَّعُوطِ', #11
u'بالسفاتج': u'بِالسَّفَاتِجِ', #1
u'بالسفتجات': u'بِالسَّفْتَجَاتِ', #2
u'بالسقلي': u'بِالسَّقَلِّيِّ', #2
u'بالسقى': u'بِالسُّقَّى', #2
u'بالسقية': u'بِالسَّقِيَّةِ', #5
u'بالسكاء': u'بِالسَّكَّاءِ', #1
u'بالسكنجبين': u'بِالسَّكَنْجَبِينِ', #1
u'بالسكوتالوجه': u'بِالسُّكُوتِالْوَجْهُ', #1
u'بالسكونة': u'بِالسُّكُونَةِ', #1
u'بالسلاليم': u'بِالسَّلَالِيمِ', #1
u'بالسلل': u'بِالسِّلَلِ', #1
u'بالسمحاق': u'بِالسِّمْحَاقِ', #3
u'بالسمهري': u'بِالسّمْهَرِيّ', #2
u'بالسميذ': u'بِالسَّمِيذِ', #3
u'بالسنا': u'بِالسَّنَا', #5
u'بالسندروس': u'بالسندروس', #1
u'بالسنقري': u'بِالسُّنْقُرِيِّ', #2
u'بالسنه': u'بِالسَّنَهْ', #1
u'بالسنهوري': u'بِالسَّنْهُورِيِّ', #1
u'بالسنوت': u'بِالسَّنُّوتِ', #1
u'بالسهمان': u'بِالسّهْمَانِ', #2
u'بالسوا': u'بِالسَّوَا', #1
u'بالسوانى': u'بِالسَّوَانِى', #1
u'بالسودد': u'بِالسُّوْدُدِ', #2
u'بالسويق': u'بِالسّوِيقِ', #1
u'بالسويق،': u'بِالسَّوِيقِ،', #3
u'بالسويق': u'بِالسَّوِيقِ', #63
u'بالسيبيا': u'بِالسِّيبْيَا', #1
u'بالسيفوروي': u'بِالسَّيْفِوَرُوِيَ', #1
u'بالسيلقون': u'بالسيلقون', #1
u'بالسيور': u'بِالسُّيُورِ', #4
u'بالشاء': u'بِالشّاءِ', #2
u'بالشاء': u'بِالشَّاءِ', #5
u'بالشابرقان': u'بِالشَّابِرْقَانِ', #1
u'بالشادوف': u'بِالشَّادُوفِ', #1
u'بالشاذروان': u'بِالشَّاذَرْوَانِ', #3
u'بالشاطبي': u'بِالشَّاطِبِيِّ', #1
u'بالشاغية': u'بِالشَّاغِيَةِ', #1
u'بالشاف': u'بِالشَّافِّ', #1
u'بالشآم': u'بِالشّآمِ', #1
u'بالشاية': u'بِالشَّايَةِ', #1
u'بالشبابة': u'بِالشَّبَّابَةِ', #3
u'بالشبرم': u'بِالشُّبْرُمِ', #3
u'بالشبور': u'بِالشَّبُّورِ', #2
u'بالشتمة': u'بِالشَّتْمَةِ', #1
u'بالشحاثة': u'بِالشَّحَّاثَةِ', #2
u'بالشحة': u'بِالشُّحَّةِ', #1
u'بالشحة': u'بِالشِّحَّةِ', #1
u'بالشخشير': u'بِالشَّخْشِيرِ', #3
u'بالشداخ': u'بِالشّدّاخِ', #2
u'بالشرقاء': u'بِالشَّرْقَاءِ', #8
u'بالشرواني': u'بِالشِّرْوَانِيِّ', #1
u'بالشريجة': u'بِالشَّرِيجَةِ', #3
u'بالشريحية': u'بِالشُّرَيْحِيَّةِ', #1
u'بالشطح': u'بِالشَّطْحِ', #1
u'بالشظاظ': u'بِالشّظَاظِ', #2
u'بالشعيبة': u'بِالشُّعَيْبَةِ', #2
u'بالشفائين': u'بالشفائين', #1
u'بالشفائين': u'بِالشِّفَائَيْنِ', #1
u'بالشفعات': u'بِالشُّفُعَاتِ', #2
u'بالشفعه': u'بِالشُّفْعَهْ', #1
u'بالشفعوية': u'بِالشَّفْعَوِيَّةِ', #7
u'بالشقدف': u'بِالشُّقْدُفِ', #2
u'بالشقص': u'بِالشِّقْصِ', #59
u'بالشلبي': u'بِالشَّلَبِيِّ', #1
u'بالشلبية': u'بِالشِّلْبِيَّةِ', #1
u'بالشماريخ': u'بِالشَّمَارِيخِ', #1
u'بالشمشق': u'بِالشَّمْشَقِ', #1
u'بالشميسي': u'بالشميسي', #1
u'بالشنة،': u'بالشّنَّة،', #1
u'بالشنة': u'بِالشّنّةِ', #2
u'بالشهاده': u'بِالشَّهَادَهْ', #2
u'بالشهاردة': u'بِالشَّهَارْدَةِ', #1
u'بالشواب': u'بِالشَّوَابِّ', #3
u'بالشورة': u'بِالشُّورَةِ', #1
u'بالشورة': u'بِالشَّوْرَةِ', #1
u'بالشوم': u'بِالشُّومِ', #1
u'بالشون': u'بِالشُّوَنِ', #1
u'بالشونيز': u'بِالشُّونِيزِ', #1
u'بالشىء': u'بالشىء', #1
u'بالشىء': u'بِالشَّىْءِ', #11
u'بالشيخونية': u'بالشيخونية', #1
u'بالشيخونية': u'بالشَّيْخُونِيَّةِ', #1
u'بالشيزري': u'بِالشَّيْزَرِيِّ', #1
u'بالشيئة': u'بِالشِّيئَةِ', #1
u'بالصالحية': u'بِالصَّالِحِيَّةِ', #1
u'بالصبى': u'بِالصَّبِىِّ', #12
u'بالصحتان': u'بِالصِّحَّتَانِ', #1
u'بالصراصر': u'بِالصَّرَاصِرِ', #1
u'بالصرائح': u'بِالصَّرَائِحِ', #5
u'بالصردح': u'بالصّرْدحِ', #1
u'بالصردح': u'بِالصّرْدَحِ', #1
u'بالصرورة': u'بِالصَّرُورَةِ', #2
u'بالصرورة': u'بِالصَّرُورِةِ', #2
u'بالصعدات': u'بِالصُّعُدَاتِ', #3
u'بالصغد،': u'بالصغد،', #1
u'بالصفره': u'بالصفره', #1
u'بالصفف': u'بِالصَّفَفِ', #1
u'بالصفه': u'بِالصِّفَهْ', #2
u'بالصفيراء': u'بِالصُّفَيْرَاءِ', #1
u'بالصلاتية': u'بِالصَّلَاتِيَّةِ', #2
u'بالصلق': u'بِالصَّلْقِ', #3
u'بالصمعاء': u'بِالصَّمْعَاءِ', #1
u'بالصميران': u'بالصميران', #1
u'بالصنبرة،': u'بِالصِّنَّبَرَةِ،', #1
u'بالصنجات': u'بِالصَّنْجَاتِ', #2
u'بالصنجات': u'بِالصَّنَجَاتِ', #8
u'بالصنجة': u'بِالصَّنْجَةِ', #3
u'بالصهرة': u'بِالصِّهْرَةِ', #4
u'بالصهوبة': u'بِالصُّهُوبَةِ', #1
u'بالصواع': u'بِالصُّوَاعِ', #4
u'بالصوباشاه': u'بالصوباشاه', #1
u'بالصول': u'بِالصُّولِ', #1
u'بالصول': u'بِالصَّوْلِ', #9
u'بالصياقل': u'بِالصَّيَاقِلِ', #1
u'بالصيال': u'بِالصِّيَالِ', #7
u'بالصيحاني': u'بِالصَّيْحَانِيِّ', #1
u'بالصيقل': u'بِالصَّيْقَلِ', #2
u'بالصيلم': u'بِالصّيْلَمِ', #1
u'بالصيود': u'بِالصَّيُودِ', #2
u'بالضاربية': u'بِالضَّارِبِيَّةِ', #2
u'بالضبات': u'بِالضَّبَّاتِ', #1
u'بالضبطين': u'بِالضّبْطَيْنِ', #1
u'بالضبوعة': u'بِالضَّبُوعَةِ', #1
u'بالضبوعة': u'بِالضّبُوعَةِ', #2
u'بالضحيان': u'بِالضّحْيَانِ', #1
u'بالضغابيس': u'بِالضَّغَابِيسِ', #1
u'بالضفاع': u'بِالضَّفَاعِ', #1
u'بالضيفان': u'بِالضِّيفَانِ', #1
u'بالطاب': u'بِالطَّابِ', #10
u'بالطابران': u'بالطَّابَرَانِ', #1
u'بالطابران': u'بِالطَّابَرَانَ', #1
u'بالطابران': u'بِالطَّابَرِانِ', #1
u'بالطابران': u'بِالطَّابِرَانَ', #1
u'بالطابران،': u'بِالطَّابَرَانِ،', #1
u'بالطابران': u'بِالطَّابَرَانِ', #12
u'بالطابران': u'بِالطَّابِرَانِ', #16
u'بالطابران،': u'بالطابران،', #6
u'بالطابو': u'بِالطَّابُو', #24
u'بالطافى': u'بِالطَّافِى', #1
u'بالطالقان': u'بِالطَّالَقَانِ', #1
u'بالطالقية': u'بِالطَّالِقِيَّةِ', #1
u'بالطاهرية': u'بِالطَّاهِرِيَّةِ', #3
u'بالطبرزين': u'بالطّبَرْزين', #1
u'بالطبرزين': u'بِالطّبَرْزِينِ', #1
u'بالطبرزين': u'بِالطّبْرَزِينِ', #1
u'بالطبرية': u'بِالطَّبَرِيَّةِ', #1
u'بالطحينة': u'بِالطَّحِينَةِ', #3
u'بالطرار': u'بِالطِّرَارِ', #1
u'بالطرطشة': u'بِالطَّرْطَشَةِ', #1
u'بالطرطوشي': u'بِالطُّرْطُوشِيِّ', #4
u'بالطسق': u'بِالطَّسْقِ', #1
u'بالطفيل': u'بالطُّفَيْل', #1
u'بالطفيل': u'بِالطّفَيْلِ', #1
u'بالطلبقة': u'بِالطَّلْبَقَةِ', #2
u'بالطهرين': u'بِالطُّهْرَيْنِ', #6
u'بالطواغى': u'بِالطَّوَاغِى', #1
u'بالطوفة': u'بِالطَّوْفَةِ', #1
u'بالطولة': u'بِالطَّوْلَةِ', #1
u'بالظبا': u'بِالظِّبَا', #1
u'بالظريبة': u'بِالظُّرَيْبَةِ', #1
u'بالظريبة': u'بِالظّرَيْبَةِ', #6
u'بالظهران': u'بِالظَّهْرَانِ', #2
u'بالظهران': u'بِالظّهْرَانِ', #4
u'بالظؤرة': u'بِالظُّؤْرَةِ', #2
u'بالظئورة': u'بِالظَّئُورَةِ', #1
u'بالظئورة': u'بِالظُّئُورَةِ', #1
u'بالعادلية': u'بِالْعَادِلِيَّةِ', #4
u'بالعاده': u'بِالْعَادَهْ', #1
u'بالعاطب': u'بِالْعَاطِبِ', #1
u'بالعامرية': u'بِالْعَامِرِيَّةِ', #1
u'بالعاين': u'بِالْعَايِنِ', #1
u'بالعبدري': u'بِالْعَبْدَرِيِّ', #1
u'بالعبدلاوي': u'بالعبدلاوي', #1
u'بالعبدلاوي': u'بِالْعَبْدَلَاوِيّ', #1
u'بالعبلات': u'بِالْعَبْلَاتِ', #1
u'بالعتقاء': u'بِالْعُتَقَاءِ', #14
u'بالعتيرة': u'بِالْعَتِيرَةِ', #3
u'بالعثاعث': u'بِالْعَثَاعِثِ', #3
u'بالعثكال': u'بِالْعِثْكَالِ', #1
u'بالعثكال': u'بِالْعُثْكَالِ', #13
u'بالعجاجيل': u'بِالْعَجَاجِيلِ', #1
u'بالعدات': u'بِالْعِدَّاتِ', #1
u'بالعداله': u'بِالْعَدَالَهْ', #1
u'بالعدان': u'بِالْعَدَانِ', #1
u'بالعدلوروي': u'بِالْعَدْلِوَرُوِيَ', #1
u'بالعذبطة': u'بِالْعِذْبَطَةِ', #1
u'بالعذيب': u'بالعذيب', #1
u'بالعذيب': u'بِالْعُذَيْبِ', #7
u'بالعرا': u'بِالْعُرَا', #1
u'بالعراية': u'بِالْعَرَايَةِ', #1
u'بالعرنيين': u'بِالْعُرَنِيّينَ', #1
u'بالعرنيين': u'بِالْعُرَنِيِّينَ', #10
u'بالعزرمي': u'بِالْعَزْرَمِيِّ', #1
u'بالعسار': u'بِالْعِسَارِ', #1
u'بالعسيب': u'بِالْعَسِيبِ', #1
u'بالعسيلة': u'بِالْعُسَيْلَةِ', #5
u'بالعشى': u'بِالْعَشِىِّ', #6
u'بالعصفر': u'بِالْعُصْفُرََََِ', #1
u'بالعصفر': u'بِالْعُصْفُرِ', #40
u'بالعصفر': u'بالعصفر', #8
u'بالعصوبة': u'بِالْعُصُوبَة', #1
u'بالعصوبة': u'بِالْعُصُوبَةِ', #197
u'بالعضب': u'بِالْعَضْبِ', #4
u'بالعضباء': u'بِالْعَضْبَاءِ', #1
u'بالعضباء،': u'بِالْعَضْبَاءِ،', #1
u'بالعضه': u'بِالْعَضْهِ', #1
u'بالعضوب': u'بِالْعُضُوبِ', #1
u'بالعضيهة': u'بِالْعَضِيهَةِ', #1
u'بالعطارين': u'بِالْعَطَّارِينَ', #3
u'بالعطشين': u'بِالْعَطِشَيْنِ', #1
u'بالعطن': u'بِالْعَطَنِ', #7
u'بالعطيه': u'بِالْعَطِيَّهْ', #1
u'بالعفاص': u'بِالْعِفَاصِ', #1
u'بالعفص': u'بِالْعَفْصِ', #7
u'بالعقنقل': u'بالعَقَنْقَل', #1
u'بالعقنقل': u'بِالْعَقَنْقَلِ', #2
u'بالعقورية': u'بِالْعُقُورِيَّةِ', #1
u'بالعكار': u'بِالْعَكَّارِ', #1
u'بالعكام': u'بِالْعَكَّامِ', #1
u'بالعكوس': u'بِالْعُكُوسِ', #7
u'بالعلوفة': u'بِالْعَلُوفَةِ', #1
u'بالعمره': u'بِالْعُمْرَهْ', #1
u'بالعمرى': u'بِالْعُمْرَى', #32
u'بالعنام': u'بِالْعَنَامِ', #1
u'بالعنة': u'بِالْعُنَّةِ', #59
u'بالعندية': u'بِالْعِنْدِيَّةِ', #1
u'بالعنين': u'بِالْعِنِّينِ', #7
u'بالعوار': u'بِالْعَوَارِ', #2
u'بالعوالى': u'بِالْعَوَالِى', #2
u'بالعوامد': u'بِالْعَوَامِدِ', #2
u'بالعوذاء': u'بِالْعَوْذَاءِ', #1
u'بالعويد': u'بِالْعُوَيْدِ', #1
u'بالعيافة': u'بِالْعِيَافَةِ', #1
u'بالعيدروس': u'بِالْعَيْدَرُوسِ', #1
u'بالعيسوي': u'بِالْعِيسَوِيِّ', #1
u'بالعيص': u'بِالْعِيصِ', #4
u'بالعيلم': u'بِالْعَيْلَمِ', #1
u'بالغاروقة': u'بِالْغَارُوقَةِ', #1
u'بالغالط': u'بِالْغَالِطِ', #3
u'بالغامدية': u'بِالْغَامِدِيَّةِ', #8
u'بالغداف': u'بِالْغُدَافِ', #1
u'بالغزى': u'بِالْغُزَّى', #1
u'بالغصوب': u'بِالْغُصُوبِ', #5
u'بالغطنة': u'بالغطنة', #1
u'بالغلوة': u'بِالْغَلْوَةِ', #2
u'بالغموس': u'بِالْغَمُوسِ', #6
u'بالغميصاء': u'بِالْغُمَيْصَاءِ', #4
u'بالغميم': u'بالغميم', #1
u'بالغميم': u'بِالْغَمِيمِ', #7
u'بالغوراء': u'بِالْغَوْرَاءِ', #1
u'بالغوطة': u'بِالْغُوطَةِ', #1
u'بالغوطة،': u'بِالْغُوطَةِ،', #2
u'بالغوير': u'بِالْغُوَيْرِ', #1
u'بالغياطل': u'بِالْغَيَاطِلِ', #1
u'بالغيداق': u'بِالْغَيْدَاقِ', #2
u'بالغيل': u'بِالْغَيْلِ', #1
u'بألفا': u'بِأَلْفًا', #1
u'بالفا': u'بِالْفَا', #2
u'بالفارسى': u'بِالْفَارِسِىِّ', #1
u'بالفاس': u'بِالْفَاسِ', #2
u'بالفانيد': u'بِالْفَانِيدِ', #6
u'بالفتخات': u'بِالْفَتَخَاتِ', #1
u'بالفتخة': u'بِالْفَتْخَةِ', #1
u'بالفتيا': u'بِالْفُتْيَا', #13
u'بالفحت': u'بِالْفَحْتِ', #1
u'بالفرافر': u'بِالْفَرَافِرِ', #1
u'بالفرافر': u'بِالْفُرَافِرِ', #1
u'بالفرما،': u'بالفرما،', #1
u'بالفرما': u'بِالْفَرَمَا', #2
u'بالفروسة': u'بِالْفُرُوسَةِ', #1
u'بالفساخ': u'بِالْفِسَاخِ', #1
u'بالفسكل': u'بِالْفِسْكِلِ', #1
u'بالفسوخ': u'بِالْفُسُوخِ', #2
u'بالفسيل': u'بِالْفَسِيلِ', #4
u'بالفضيخ': u'بِالْفَضِيخِ', #1
u'بالفقء': u'بِالْفَقْءِ', #6
u'بالفقوع': u'بِالْفُقُوعِ', #1
u'بالفلو': u'بِالْفَلُوِّ', #1
u'بالفهري': u'بِالْفِهْرِيِّ', #1
u'بالفهرى': u'بِالْفِهْرِىِّ', #1
u'بالفوائت': u'بِالْفَوَائِتِ', #11
u'بالفويسقة': u'بِالْفُوَيْسِقَةِ', #2
u'بالفي': u'بِالْفِي', #1
u'بألفى': u'بِأَلْفَىْ', #2
u'بالفئ،': u'بالفَئْ،', #1
u'بالفئام': u'بِالْفِئَامِ', #2
u'بالفئوس': u'بِالْفُئُوسِ', #2
u'بألفيا': u'بِأُلْفِيَا', #1
u'بالفيتور': u'بِالْفِيتُورِ', #1
u'بالفيروزج': u'بِالْفَيْرُوزَجِ', #11
u'بالفين': u'بِالْفَيْنِ', #1
u'بالفيول': u'بِالْفُيُولِ', #1
u'بالفيوم': u'بِالْفَيُّومِ', #1
u'بالق': u'بَالِق', #1
u'بالق': u'بِالْق', #1
u'بالقاحة': u'بِالْقَاحَّةِ', #1
u'بالقاحة': u'بِالْقَاحَةِ', #11
u'بالقاحوحة': u'بِالْقَاحُوحَةِ', #1
u'بالقاض': u'بِالْقَاضِ', #1
u'بالقاضى': u'بِالْقَاضِى', #2
u'بالقافة': u'بِالْقَافَّةِ', #1
u'بالقافة': u'بِالْقَافَةِ', #28
u'بالقاقيا': u'بالقاقيا', #1
u'بالقاووت': u'بِالْقَاوُوتِ', #1
u'بالقائف': u'بِالْقَائِفِ', #16
u'بالقايسة': u'بِالْقَايِسَةِ', #1
u'بالقبابين،': u'بِالْقَبَابِينَ،', #1
u'بالقباطي': u'بِالْقُبَاطِيِّ', #1
u'بالقباطى': u'بِالْقَبَاطِى', #1
u'بالقباطى': u'بِالْقَبَاطِىِّ', #1
u'بالقباطي': u'بِالْقَبَاطِيِّ', #3
u'بالقبربمنزلة': u'بِالْقَبْرِبِمَنْزِلَةِ', #1
u'بالقبضين': u'بِالْقَبْضَيْنِ', #2
u'بالقبلةمكة': u'بِالْقِبْلَةِمَكَّةَ', #1
u'بالقتاليقول': u'بِالْقِتَالِيَقُولُ', #1
u'بالقتب': u'بِالْقَتَبِ', #1
u'بالقرءاة': u'بالقرءاة', #1
u'بالقرءان': u'بِالْقُرْءَانِ', #1
u'بالقرافة': u'بِالْقَرَافَةِ', #11
u'بالقرافي': u'بِالْقَرَافِيِّ', #1
u'بالقرامد': u'بِالْقَرَامِدِ', #1
u'بالقرامل': u'بِالْقَرَامِلِ', #4
u'بالقردواني،': u'بِالْقَرْدُوَانِيِّ،', #1
u'بالقرسطون': u'بالقرسطون', #2
u'بالقرطق': u'بِالْقُرْطَقِ', #2
u'بالقرظ': u'بالقرظ', #1
u'بالقرظ': u'بِالْقَرَظِ', #17
u'بالقرظ': u'بِالْقَرْظِ', #3
u'بالقرقوس': u'بِالْقَرْقُوسِ', #1
u'بالقرم': u'بِالْقَرْمِ', #1
u'بالقرمود': u'بِالْقَرْمُودِ', #1
u'بالقريشة': u'بِالْقَرِيشَةِ', #1
u'بالقساسية': u'بِالْقَسَاسِيّةِ', #1
u'بالقساسية': u'بِالّقُسَاسِيّةِ', #2
u'بالقسطنطينة': u'بِالْقُسْطُنْطِينَةِ', #1
u'بالقصواء،': u'بِالْقَصْوَاءِ،', #1
u'بالقصواء': u'بِالْقَصْوَاءِ', #13
u'بالقصيم': u'بِالْقَصِيمِ', #2
u'بالقضا': u'بِالْقَضَا', #9
u'بالقضيف': u'بِالْقَضِيفِ', #1
u'بالقطارش': u'بالقطارش', #1
u'بالقعدد': u'بالقعدد', #1
u'بالقعدد': u'بِالْقُعْدُدِ', #3
u'بالقعص': u'بِالْقَعْصِ', #1
u'بالقعنبي': u'بِالْقَعْنَبِيِّ', #1
u'بالقف': u'بِالْقُفِّ', #2
u'بالقفاء': u'بِالْقَفَاءِ', #1
u'بالقفاف': u'بِالْقِفَافِ', #1
u'بالقفزان': u'بِالْقُفْزَانِ', #1
u'بالقفيز': u'بِالْقَفِيزِ', #21
u'بالقفيزين': u'بِالْقَفِيزَيْنِ', #1
u'بالقلاص': u'بِالْقَلاصِ', #1
u'بالقلاص': u'بِالْقِلَاصِ', #3
u'بالقلائص': u'بِالْقَلَائِصِ', #2
u'بالقلح': u'بِالْقَلَحِ', #1
u'بالقلزم': u'بِالْقُلْزُمِ', #2
u'بالقلشين': u'بِالْقَلْشِينَ', #1
u'بالقلفطة': u'بِالْقُلْفُطَةِ', #1
u'بالقلفونية': u'بالقلفونية', #1
u'بالقلقند': u'بالقلقند', #1
u'بالقلقند': u'بِالْقَلْقَنْدُ', #1
u'بالقليب': u'بِالْقَلِيبِ', #11
u'بالقميصة': u'بِالْقَمِيصَةِ', #1
u'بالقنا': u'بِالْقَنَا', #14
u'بالقناء': u'بِالْقِنَاءِ', #1
u'بالقند': u'بِالْقَنْدِ', #4
u'بالقنقل': u'بِاْلَقَنْقَلِ', #1
u'بالقهقرى': u'بِالْقَهْقَرَى', #1
u'بالقهوات': u'بِالْقَهَوَاتِ', #1
u'بالقوادح': u'بِالْقَوَادِحِ', #3
u'بالقواصل': u'بِالْقَوَاصِلِ', #3
u'بالقوصرة': u'بِالْقَوْصَرَّةِ', #1
u'بالقولان': u'بِالْقَوْلَانِ', #1
u'بالقولنج': u'بِالْقُولَنْجِ', #2
u'بالقولوروي': u'بِالْقَوْلِوَرُوِيَ', #1
u'بالقوهي': u'بِالْقُوهِيِّ', #12
u'بالقي': u'بِالْقِيِّ', #1
u'بالقياسات': u'بِالْقِيَاسَاتِ', #1
u'بالقير': u'بِالْقِيرِ', #2
u'بالقيلي': u'بِالْقَيْلِي', #1
u'بالقيليط': u'بِالْقَيْلِيطِ', #1
u'بالقيمه': u'بِالْقِيمَهْ', #1
u'بالكارع': u'بِالْكَارِعِ', #2
u'بالكافرون': u'بِالْكَافِرُونَ', #15
u'بالكالئ': u'بالكالئ', #1
u'بالكالئ،': u'بِالْكَالِئِ،', #1
u'بالكالئ': u'بِالْكَالِئِ', #122
u'بالكانية': u'بِالْكَانِيَّةَ', #1
u'بالكأنية': u'بِالْكَأَنِّيَّةِ', #2
u'بالكايل': u'بِالْكَايِلِ', #1
u'بالكبيس': u'بِالْكَبِيسِ', #1
u'بالكتد': u'بِالْكَتَدِ', #4
u'بالكثره': u'بِالْكَثْرَهْ', #1
u'بالكج': u'بِالْكَجِّ', #1
u'بالكجة': u'بِالْكُجَّةِ', #1
u'بالكدش': u'بِالْكَدْشِ', #1
u'بالكدك': u'بِالْكَدَكِ', #2
u'بالكدورات': u'بِالْكَدُورَاتِ', #1
u'بالكدورة': u'بِالْكُدُورَةِ', #1
u'بالكديد،': u'بالكُدَيْد،', #1
u'بالكديد،': u'بِالْكَدِيدِ،', #1
u'بالكديد': u'بِالْكُدَيْدِ', #2
u'بالكديد،': u'بِالْكُدَيْدِ،', #2
u'بالكديد': u'بِالْكَدِيدِ', #23
u'بالكرا': u'بِالْكِرَا', #3
u'بالكرابيسي': u'بِالْكَرَابِيسِيِّ', #1
u'بالكراسف': u'بِالْكَرَاسِفِ', #1
u'بالكرباس': u'بِالْكِرْبَاسِ', #4
u'بالكرتاء': u'بِالْكَرْتَاءِ', #1
u'بالكرج': u'بِالْكُرّجِ', #2
u'بالكرخ': u'بِالْكَرْخِ', #1
u'بالكردار': u'بِالْكِرْدَارِ', #3
u'بالكرسف': u'بِالْكُرْسُفِ', #4
u'بالكركر': u'بِالْكَرْكَرِ', #1
u'بالكركم': u'بِالْكُرْكُمِ', #4
u'بالكركيش': u'بِالْكَرْكِيشِ', #1
u'بالكرين': u'بِالْكُرَّيْنِ', #1
u'بالكس': u'بِالْكُسِّ', #1
u'بالكستيج': u'بِالْكُسْتِيجِ', #2
u'بالكستيجات': u'بالكستيجات', #1
u'بالكستيجات': u'بِالْكَسْتِيجَاتِ', #1
u'بالكستيجات': u'بِالْكُسْتِيجَاتِ', #4
u'بالكستيجان': u'بِالْكُسْتِيجَانِ', #1
u'بالكسكري': u'بِالْكَسْكَرِيِّ', #1
u'بالكشري': u'بِالْكُشَرِي', #1
u'بالكفرى': u'بِالْكُفُرَّى', #1
u'بالكلامين': u'بِالْكَلَامَيْنِ', #2
u'بالكلمه': u'بِالْكَلِمَهْ', #1
u'بإلكم': u'بِإِلّكُمْ', #1
u'بالكماة': u'بِالْكُمَاةِ', #3
u'بالكمخاء': u'بِالْكَمْخَاءِ', #2
u'بالكنود': u'بِالْكَنُودِ', #1
u'بالكهر': u'بِالْكَهْرِ', #2
u'بالكوارة': u'بِالْكُوَّارَةِ', #1
u'بالكوبات': u'بِالْكُوبَاتِ', #1
u'بالكوبة': u'بِالْكُوبَةِ', #2
u'بالكوش': u'بِالْكَوْشِ', #1
u'بالكى': u'بالكى', #6
u'بإلكيا': u'بِإِلْكِيَا', #1
u'بالكيالين': u'بِالْكَيَّالِينَ', #1
u'بالكيب': u'بِالْكِيبِ', #1
u'بالكيتلاني': u'بالكيتلاني', #1
u'بالكيزان': u'بِالْكِيزَانِ', #1
u'باللازمه': u'بِاللَّازِمَهْ', #1
u'باللآلي': u'بِاللَّآلِي', #1
u'باللاوقوع': u'بِاللَّاوُقُوعِ', #1
u'باللحون': u'بِاللُّحُونِ', #4
u'باللخمي': u'بِاللَّخْمِيِّ', #3
u'باللديغ': u'بِاللَّدِيغِ', #1
u'باللقس': u'بِاللَّقَسِ', #1
u'باللنجر': u'بِاللَّنْجَرِ', #1
u'باللهوالوجه': u'بِاللَّهِوَالْوَجْهُ', #1
u'باللهوروي': u'بِاللَّهِوَرُوِيَ', #1
u'باللؤلؤة': u'بِاللُّؤْلُؤَةِ', #1
u'باللياطة': u'بِاللِّيَاطَةِ', #1
u'بالليطة': u'بِاللِّيطَةِ', #4
u'بالليلوالوجه': u'بِاللَّيْلِوَالْوَجْهُ', #1
u'بالم': u'بِالم', #1
u'بالما': u'بِالْمَا', #2
u'بالماءالوجه': u'بِالْمَاءِالْوَجْهُ', #1
u'بالمأبور': u'بِالْمَأْبُورِ', #2
u'بالمأبون': u'بِالْمَأْبُونِ', #3
u'بالمأتي': u'بِالْمَأْتِيِّ', #4
u'بالماذيانات': u'بِالْمَاذِيَانَاتِ', #6
u'بالماش': u'بِالْمَاشِّ', #1
u'بالماش': u'بِالْمَاشِ', #4
u'بالماصدق': u'بِالْمَاصَدَقَ', #1
u'بالماصدقات': u'بِالْمَاصَدَقَاتِ', #1
u'بالماطرون': u'بِالْمَاطِرُونَ', #1
u'بالماقص': u'بِالْمَاقِصِ', #2
u'بالماليخوليا': u'بالماليخوليا', #1
u'بالمأمومية': u'بالمأمومية', #1
u'بالمأمومية': u'بالْمَأْمُومِيَّةِ', #1
u'بالماميتا': u'بالماميتا', #1
u'بالماميثا': u'بالماميثا', #1
u'بالمانعية': u'بِالْمَانِعِيَّةِ', #2
u'بالمائتي': u'بِالْمِائَتَيْ', #4
u'بالمبارأة': u'بِالْمُبَارَأَةِ', #2
u'بالمباضعة': u'بِالْمُبَاضَعَةِ', #1
u'بالمبالى': u'بِالْمُبَالَى', #2
u'بالمبان': u'بِالْمُبَانِ', #6
u'بالمبانة': u'بِالْمُبَانَةِ', #2
u'بالمباهلة': u'بِالْمُبَاهَلَةِ', #6
u'بالمباين': u'بِالْمُبَايِنِ', #6
u'بالمباينة': u'بِالْمُبَايِنَةِ', #1
u'بالمباينة': u'بِالْمُبَايَنَةِ', #4
u'بالمبتر': u'بِالْمُبْتَرِ', #1
u'بالمبتر': u'بِالْمُبْتِرِ', #1
u'بالمبتر': u'بِالْمِبْتِرِ', #1
u'بالمبتوتات': u'بِالْمَبْتُوتَاتِ', #1
u'بالمبتوتة': u'بِالْمَبْتُوتَةِ', #6
u'بالمبرإ': u'بِالْمُبْرَإِ', #1
u'بالمبرأ': u'بِالْمُبَرَّأِ', #10
u'بالمبرإ': u'بِالْمُبَرَّإِ', #5
u'بالمبرأ': u'بِالْمُبْرَأِ', #6
u'بالمبعض': u'بِالْمُبَعَّضِ', #5
u'بالمبغوضية': u'بالمبغوضية', #1
u'بالمبغوضية': u'بالْمَبْغُوضِيَّةِ', #1
u'بالمبقى': u'بِالْمُبْقَى', #1
u'بالمتأذي': u'بِالْمُتَأَذِّي', #2
u'بالمتاركة': u'بِالْمُتَارَكَةِ', #15
u'بالمتجالة': u'بِالْمُتَجَالَّةِ', #2
u'بالمتجوز': u'بِالْمُتَجَوِّزِ', #1
u'بالمتجوز': u'بِالْمُتَجَوَّزِ', #3
u'بالمتحرف': u'بِالْمُتَحَرِّفِ', #1
u'بالمتحشف': u'بِالْمُتَحَشِّفِ', #1
u'بالمتداني': u'بِالْمُتَدَانِي', #1
u'بالمتضايفين': u'بِالْمُتَضَايِفَيْنِ', #1
u'بالمتقاطر': u'بِالْمُتَقَاطَرِ', #3
u'بالمتقاطر': u'بِالْمُتَقَاطِرِ', #4
u'بالمتكلمون': u'بِالْمُتَكَلِّمُون', #1
u'بالمثالثة': u'بِالْمُثَالَثَةِ', #1
u'بالمثفل': u'بِالْمُثْفِلِ', #1
u'بالمثلة': u'بِالْمَثُلَةِ', #3
u'بالمثلة': u'بِالْمُثْلَةِ', #40
u'بالمثمون': u'بِالْمَثْمُونِ', #5
u'بالمثمونة': u'بِالْمَثْمُونَةِ', #1
u'بالمجاذيف': u'بِالْمَجَاذِيفِ', #3
u'بالمجاعل': u'بِالْمُجَاعَلِ', #1
u'بالمجبوب': u'بِالْمَجْبُوبِ', #9
u'بالمجبوبين': u'بِالْمَجْبُوبِينَ', #2
u'بالمجة': u'بِالْمَجَّةِ', #3
u'بالمجحود': u'بِالْمَجْحُودِ', #10
u'بالمجحودتين': u'بِالْمَجْحُودَتَيْنِ', #1
u'بالمجدح': u'بِالْمِجْدَحِ', #1
u'بالمجزور': u'بِالْمَجْزُورِ', #1
u'بالمجزوز': u'بِالْمَجْزُوزِ', #1
u'بالمجلوبين': u'بِالْمَجْلُوبِينَ', #4
u'بالمجموعية': u'بالمجموعية', #1
u'بالمحابيب': u'بِالْمَحَابِيبِ', #1
u'بالمحاججة': u'بِالْمُحَاجَجَةِ', #1
u'بالمحاصة': u'بِالْمُحَاصَّةِ', #64
u'بالمحاللة': u'بِالْمُحَالَلَةِ', #2
u'بالمحاويج': u'بِالْمَحَاوِيجِ', #3
u'بالمحاياة': u'بِالْمُحَايَاةِ', #1
u'بالمحجن،': u'بِالْمِحْجَنِ،', #1
u'بالمحجن': u'بِالْمِحْجَنِ', #5
u'بالمحجوم': u'بِالْمَحْجُومِ', #2
u'بالمحراق': u'بِالْمِحْرَاقِ', #1
u'بالمحصر': u'بِالْمُحْصَرِ', #6
u'بالمحققه': u'بِالْمُحَقَّقَهْ', #2
u'بالمحمودية': u'بِالْمَحْمُودِيَّةِ', #4
u'بالمحمولية': u'بِالْمَحْمُولِيَّةِ', #1
u'بالمحوج': u'بِالْمُحْوِجِ', #1
u'بالمخابطة': u'بِالْمُخَابَطَةِ', #1
u'بالمخارجة': u'بِالْمُخَارَجَةِ', #2
u'بالمخالع': u'بِالْمُخَالَعِ', #1
u'بالمختال': u'بِالْمُخْتَالِ', #1
u'بالمختلعة': u'بِالْمُخْتَلِعَةِ', #1
u'بالمختلفي': u'بِالْمُخْتَلِفَيْ', #1
u'بالمخدج': u'بالمخدَّج', #1
u'بالمخدج': u'بِالْمُخْدَجِ', #1
u'بالمخراق': u'بِالْمِخْرَاقِ', #1
u'بالمخرق': u'بِالْمَخْرَقِ', #1
u'بالمخرقة': u'بِالْمُخْرِقَةِ', #1
u'بالمخصوف': u'بِالْمَخْصُوفِ', #1
u'بالمخمص': u'بِالْمُخَمَصِ', #1
u'بالمخمص': u'بِالْمُخْمَصِ', #1
u'بالمخمص': u'بِالْمُخَمَّصِ', #4
u'بالمخمصة': u'بِالْمَخْمَصَةِ', #4
u'بالمخوزق': u'بِالْمُخَوْزَقِ', #1
u'بالمدارأة': u'بِالْمُدَارَأَةِ', #1
u'بالمداسم': u'بِالْمَدَاسِمِ', #1
u'بالمداين': u'بِالْمَدَايِنِ', #1
u'بالمدران': u'بِالْمِدْرَانِ', #1
u'بالمدرى': u'بِالْمِدْرَى', #5
u'بالمدنف': u'بِالْمُدْنَفِ', #1
u'بالمدنف': u'بِالْمُدْنِفِ', #4
u'بالمدواة': u'بِالْمُدَوَاةِ', #1
u'بالمذاد': u'بِالْمُذَادِ', #1
u'بالمذرورات': u'بِالْمَذْرُورَاتِ', #2
u'بالمذفف': u'بِالْمُذَفِّفِ', #1
u'بالمذكاة': u'بِالْمُذَكَّاةِ', #4
u'بالمذكى': u'بِالْمُذَكَّى', #4
u'بالمذي': u'بِالْمَذْي', #1
u'بالمذى': u'بِالْمَذْىِ', #1
u'بالمذي': u'بِالْمَذْيِ', #12
u'بالمراجيح': u'بِالْمَرَاجِيحِ', #1
u'بالمرادي': u'بِالْمُرَادِي', #1
u'بالمرازقة': u'بِالْمَرَازِقَةِ', #1
u'بالمراصة': u'بِالْمُرَاصَّةِ', #1
u'بالمراطلة': u'بِالْمُرَاطَلَةِ', #6
u'بالمراغة': u'بِالْمَرَاغَةِ', #2
u'بالمراغمة': u'بِالْمُرَاغَمَةِ', #4
u'بالمراوضة': u'بِالْمُرَاوَضَةِ', #1
u'بالمربوب': u'بِالْمَرْبُوبِ', #2
u'بالمرتضع': u'بِالْمُرْتَضِعِ', #1
u'بالمرتضى': u'بِالْمُرْتَضَى', #1
u'بالمرتك': u'بِالْمُرْتَكِ', #1
u'بالمردان': u'بِالْمُرْدَانِ', #4
u'بالمرزبانة': u'بِالْمَرْزُبَانَةِ', #1
u'بالمرزبة': u'بِالْمِرْزَبَّةِ', #1
u'بالمرقال،': u'بالمِرْقال،', #1
u'بالمرقوق': u'بِالْمَرْقُوقِ', #4
u'بالمرقوقة': u'بِالْمَرْقُوقَةِ', #1
u'بالمروانية': u'بِالْمَرْوَانِيَّةِ', #1
u'بالمريسيع': u'بِالْمُرَيْسِيعَ', #1
u'بالمريسيع،': u'بِالْمُرَيْسِيعِ،', #1
u'بالمريسيع': u'بِالْمُرَيْسِيعِ', #3
u'بالمزابنة': u'بِالْمُزَابَنَةِ', #4
u'بالمزجد': u'بِالْمُزَجَّدِ', #1
u'بالمزحوم': u'بِالْمَزْحُومِ', #1
u'بالمزراق': u'بِالْمِزْرَاقِ', #2
u'بالمزعفر': u'بِالْمُزَعْفَرِ', #3
u'بالمزمزة': u'بِالْمَزْمَزَةِ', #1
u'بالمزهق': u'بِالْمُزْهَقِ', #1
u'بالمزهق': u'بِالْمُزْهِقِ', #7
u'بالمزيقياء': u'بِالْمُزَيْقِيَاءِ', #1
u'بالمسابة': u'بِالْمُسَابَّةِ', #2
u'بالمساحى': u'بِالْمَسَاحِى', #2
u'بالمسافره': u'بِالْمُسَافَرَهْ', #1
u'بالمسامتة': u'بِالْمُسَامَتَةِ', #10
u'بالمساوقة': u'بِالْمُسَاوَقَةِ', #3
u'بالمساوى': u'بِالْمُسَاوَى', #1
u'بالمسببية': u'بِالْمُسَبَّبِيَّة', #1
u'بالمسبل': u'بِالْمُسَبَّلِ', #2
u'بالمسبلات': u'بِالْمُسْبَلَاتِ', #1
u'بالمسبلات': u'بِالْمُسْبِلَاتِ', #3
u'بالمسبلة': u'بِالْمُسْبَلَةِ', #2
u'بالمسبلة': u'بِالْمُسَبَّلَةِ', #6
u'بالمسبوقية': u'بالمسبوقية', #1
u'بالمستام': u'بِالْمُسْتَامِ', #1
u'بالمستبحر': u'بِالْمُسْتَبْحَرِ', #1
u'بالمستبحر': u'بِالْمُسْتَبْحِرِ', #1
u'بالمستبرأة': u'بِالْمُسْتَبْرَأَةِ', #8
u'بالمستبرآت': u'بِالْمُسْتَبْرَآتِ', #1
u'بالمستجمر': u'بِالْمُسْتَجْمَرِ', #1
u'بالمستجمر': u'بِالْمُسْتَجْمِرِ', #4
u'بالمستحاضة': u'بِالْمُسْتَحَاضَةِ', #22
u'بالمستحشف': u'بِالْمُسْتَحْشِفِ', #1
u'بالمستحشفة': u'بِالْمُسْتَحْشِفَةِ', #3
u'بالمستخبث': u'بِالْمُسْتَخْبَثِ', #1
u'بالمستخسف': u'بِالْمُسْتَخْسِفِ', #1
u'بالمستدخلة': u'بِالْمُسْتَدْخِلَة', #1
u'بالمستسعاة': u'بِالْمُسْتَسْعَاةِ', #1
u'بالمستصفى': u'بِالْمُسْتَصْفَى', #1
u'بالمستصنع': u'بِالْمُسْتَصْنَعِ', #2
u'بالمستقذر': u'بِالْمُسْتَقْذَرِ', #1
u'بالمستقرض': u'بِالْمُسْتَقْرِضِ', #4
u'بالمستلحق': u'بِالْمُسْتَلْحَقِ', #1
u'بالمستنكح': u'بِالْمُسْتَنْكِحِ', #2
u'بالمستوزر': u'بِالْمُسْتَوْزِرِ', #1
u'بالمستوفى': u'بِالْمُسْتَوْفَى', #8
u'بالمسحين': u'بِالْمَسْحَيْنِ', #1
u'بالمسطاح': u'بِالْمِسْطَاحِ', #1
u'بالمسعط': u'بِالْمُسْعُطِ', #1
u'بالمسعودي': u'بِالْمَسْعُودِيِّ', #1
u'بالمسقفات': u'بِالْمُسَقَّفَاتِ', #1
u'بالمسقفات': u'بِالْمُسْقَفَاتِ', #1
u'بالمسناة': u'بِالْمُسَنَّاةِ', #1
u'بالمسيجيد': u'بِالْمُسَيْجِيد', #1
u'بالمسيجيد': u'بِالْمُسَيْجِيدِ', #1
u'بالمشا': u'بِالْمُشَا', #1
u'بالمشالة': u'بِالْمُشَالَةِ', #3
u'بالمشتراة': u'بِالْمُشْتَرَاةِ', #3
u'بالمشترى': u'بِالْمُشْتَرَى', #31
u'بالمشروطية': u'بالمشروطية', #1
u'بالمشروطية': u'بِالْمَشْرُوطِيَّة', #1
u'بالمشرى': u'بِالْمُشْرَى', #1
u'بالمشفوعة': u'بِالْمَشْفُوعَةِ', #2
u'بالمشلل،': u'بِالْمُشَلَّلِ،', #2
u'بالمشلل': u'بِالْمُشَلّلِ', #3
u'بالمشلل': u'بِالْمُشَلَّلِ', #9
u'بالمشى': u'بِالْمَشْىِ', #2
u'بالمصراة': u'بِالْمُصْرَاةِ', #1
u'بالمصراة': u'بِالْمُصَرَّاةِ', #5
u'بالمصرور': u'بِالْمَصْرُورِ', #2
u'بالمصطلق': u'بَالْمُصْطَلِقِ', #1
u'بالمصلحه': u'بِالْمَصْلَحَهْ', #2
u'بالمصلوق': u'بِالْمَصْلُوقِ', #2
u'بالمضروبية': u'بالمضروبية', #2
u'بالمضطبع': u'بِالْمُضْطَبِعِ', #1
u'بالمضنون': u'بِالْمَضْنُونِ', #3
u'بالمضنونة': u'بِالْمَضْنُونَةِ', #1
u'بالمضيعه': u'بِالْمَضِيعَهْ', #1
u'بالمطابقية': u'بالمطابقية', #1
u'بالمطبوب': u'بِالْمَطْبُوبِ', #1
u'بالمطحولين': u'بِالْمَطْحُولِينَ', #1
u'بالمطموع': u'بِالْمَطْمُوعِ', #1
u'بالمعاصى': u'بِالْمُعَاصَى', #1
u'بالمعاصى': u'بِالْمَعَاصِى', #3
u'بالمعاطاة': u'بِالْمُعَاطَاةِ', #78
u'بالمعالق': u'بِالْمَعَالِقِ', #1
u'بالمعانده': u'بِالْمُعَانَدَهْ', #1
u'بالمعبوك': u'بِالْمَعْبُوكِ', #1
u'بالمعتصبة': u'بِالْمُعْتَصِبَةِ', #1
u'بالمعتمدية': u'بالمُعْتَمِدِيَّةِ', #1
u'بالمعتمل': u'بِالْمُعْتَمَلِ', #1
u'بالمعتمل': u'بِالْمُعْتَمِلِ', #2
u'بالمعتوق': u'بِالْمَعْتُوقِ', #1
u'بالمعراض': u'بالمعراض', #1
u'بالمعراض': u'بِالْمِعْرَاضِ', #25
u'بالمعراض،': u'بِالْمِعْرَاضِ،', #3
u'بالمعسور': u'بِالْمَعْسُورِ', #63
u'بالمعصفر': u'بِالْمُعَصْفَرِ', #4
u'بالمعضوب': u'بِالْمَعْضُوبِ', #3
u'بالمعضى': u'بِالْمُعَضّى', #2
u'بالمعطن': u'بِالْمَعْطِنِ', #1
u'بالمعلا': u'بِالْمُعَلَّا', #1
u'بالمعلومية': u'بِالْمَعْلُومِيَّةِ', #6
u'بالمعنسة': u'بِالْمُعَنِّسَةِ', #1
u'بالمعنق': u'بالمُعْنق', #1
u'بالمغابنة': u'بالمغابنة', #2
u'بالمغارسة': u'بِالْمُغَارَسَةِ', #1
u'بالمغازى': u'بِالْمَغَازِى', #3
u'بالمغالية': u'بِالْمُغَالِيَةِ', #1
u'بالمغايظ': u'بِالْمَغَايِظِ', #2
u'بالمغر': u'بِالْمُغْرِ', #1
u'بالمغرة': u'بِالْمَغْرَةِ', #9
u'بالمغزدرات': u'بِالْمُغَزْدِرَاتِ', #1
u'بالمغزولة': u'بِالْمَغْزُولَةِ', #1
u'بالمغفر': u'بِالْمِغْفَرِ', #2
u'بالمغلوث': u'بالمغلوث', #1
u'بالمغلى': u'بِالْمُغْلَى', #1
u'بالمغمس': u'بِالْمُغَمّس', #1
u'بالمغمس': u'بِالْمُغَمَّسِ', #4
u'بالمغمس': u'بِالْمُغَمّسِ', #6
u'بالمفاعلة': u'بِالْمُفَاعَلَةِ', #9
u'بالمفدم': u'بِالْمُفَدَّمِ', #1
u'بالمفضاة': u'بِالْمُفْضَاةِ', #1
u'بالمفضولية': u'بالمفضولية', #1
u'بالمقاثي': u'بِالْمَقَاثِي', #2
u'بالمقاثئ': u'بِالْمَقَاثِئِ', #3
u'بالمقايل': u'بِالْمُقَايِلِ', #1
u'بالمقايل': u'بِالْمُقَايَلِ', #4
u'بالمقايلة': u'بِالْمُقَايَلَةِ', #1
u'بالمقتب': u'بِالْمُقَتَّبِ', #2
u'بالمقتص': u'بِالْمُقْتَصِّ', #4
u'بالمقتنى': u'بِالْمُقْتَنَى', #2
u'بالمقثأة': u'بِالْمَقْثَأَةِ', #1
u'بالمقداد': u'بِالْمِقْدَادِ', #2
u'بالمقصة': u'بِالْمِقَصَّةِ', #2
u'بالمقصصة': u'بِالْمُقَصَّصَةِ', #1
u'بالمقصودية': u'بالمقصودية', #1
u'بالمقضى': u'بِالْمُقَضَّى', #1
u'بالمقضى': u'بِالْمُقْضَى', #1
u'بالمقطم': u'بِالْمُقَطَّمِ', #1
u'بالمقلوة': u'بِالْمَقْلُوَّةِ', #2
u'بالمقيس': u'بِالْمَقِيسِ', #5
u'بالمقيمه': u'بِالْمُقِيمَهْ', #1
u'بالمكاتل': u'بِالْمَكَاتِلِ', #1
u'بالمكاس': u'بِالْمَكَّاسِ', #1
u'بالمكاعب': u'بِالْمَكَاعِبِ', #1
u'بالمكامعة': u'بِالْمُكَامَعَةِ', #1
u'بالمكايسة': u'بِالْمُكَايَسَةِ', #4
u'بالمكترى': u'بِالْمُكْتَرَى', #1
u'بالمكتين': u'بِالْمَكّتَيْنِ', #1
u'بالمكتين': u'بِالْمَكَّتَيْنِ', #1
u'بالمكسود': u'بِالْمَكْسُودِ', #1
u'بالمكلوء': u'بِالْمَكْلُوءِ', #1
u'بالمكمور': u'بالمكمور', #1
u'بالمكوتية': u'بِالْمَكُوتِيَّةِ', #1
u'بالمكى': u'بِالْمَكِّىِّ', #1
u'بالملا': u'بِالْمَلا', #3
u'بالملاقى': u'بِالْمُلَاقَى', #1
u'بالملاية': u'بِالْمِلَايَةِ', #1
u'بالملدين': u'بِالْمُلِدَّيْنِ', #1
u'بالملزوم': u'بِالْمَلْزُومِ', #13
u'بالملطاة': u'بِالْمِلْطَاةِ', #1
u'بالملطى': u'بِالْمَلَطِىِّ', #1
u'بالملقف': u'بِالْمُلَقَّفِ', #1
u'بالمماثله': u'بِالْمُمَاثَلَهْ', #1
u'بالممازج': u'بِالْمُمَازِجِ', #2
u'بالممشق': u'بِالْمُمَشَّقِ', #1
u'بالممقور': u'بِالْمَمْقُورِ', #1
u'بالمناثر': u'بِالْمُنَاثَرِ', #1
u'بالمناخل': u'بِالْمَنَاخِلِ', #1
u'بالمناذرة': u'بِالْمَنَاذِرَةِ', #1
u'بالمناسر': u'بِالْمَنَاسِرِ', #2
u'بالمناصل': u'بِالْمَنَاصِلِ', #2
u'بالمنافر': u'بِالْمَنَافِرِ', #1
u'بالمناكر': u'بِالْمَنَاكِرِ', #1
u'بالمناكرة': u'بِالْمُنَاكَرَةِ', #1
u'بالمنبهم': u'بِالْمُنْبَهِمِ', #1
u'بالمنتصرون': u'بِالْمُنْتَصِرُونَ', #1
u'بالمنتفل': u'بِالْمُنْتَفَلِ', #1
u'بالمنتفل': u'بِالْمُنْتَفِلِ', #2
u'بالمنتهب': u'بِالْمُنْتَهِبِ', #1
u'بالمنحجم': u'بِالْمُنْحَجِمِ', #1
u'بالمنخل': u'بِالْمُنْخُلِ', #1
u'بالمنخول': u'بِالْمَنْخُولِ', #2
u'بالمنسر': u'بِالْمَنْسَرِ', #1
u'بالمنسر': u'بِالْمِنْسَرِ', #1
u'بالمنسر': u'بِالْمَنْسِرِ', #2
u'بالمنطوقية': u'بالمنطوقية', #1
u'بالمنطوقية': u'بِالْمَنْطُوقِيَّة', #2
u'بالمنفل': u'بِالْمُنَفَّلِ', #1
u'بالمنفل': u'بِالْمُنَفِّلِ', #1
u'بالمنقاري': u'بِالْمِنْقِارِيِّ', #1
u'بالمنقاري': u'بِالْمِنْقَارِيِّ', #2
u'بالمنقاش': u'بِالْمِنْقَاشِ', #2
u'بالمنقود': u'بِالْمَنْقُودِ', #1
u'بالمنماص': u'بِالْمِنْمَاصِ', #2
u'بالمنوب': u'بِالْمَنُوبِ', #1
u'بالمهازيل': u'بِالْمَهَازِيلِ', #1
u'بالمهايأة': u'بِالْمُهَايَأَةِ', #73
u'بالمهايئات': u'بِالْمُهَايَئَاتِ', #2
u'بالمهجات': u'بِالْمُهُجَاتِ', #1
u'بالمهجم': u'بِالْمَهْجَمِ', #3
u'بالمهران': u'بِالْمَهْرَانِ', #1
u'بالمهلب،': u'بِالْمُهَلَّبِ،', #1
u'بالمهيعة': u'بِالْمَهْيَعَة', #1
u'بالمواجب': u'بِالْمَوَاجِبِ', #1
u'بالمؤاجر': u'بِالْمُؤَاجَرِ', #1
u'بالمؤاجر': u'بِالْمُؤَاجِرِ', #1
u'بالمؤاجرة،': u'بِالْمُؤَاجَرَةِ،', #1
u'بالمؤاجرة': u'بِالْمُؤَاجَرَةِ', #14
u'بالموارثة': u'بِالْمُوَارَثَةِ', #6
u'بالمواضعة': u'بِالْمُوَاضَعَةِ', #31
u'بالموإلى': u'بالموإلى', #1
u'بالموانيد': u'بِالْمَوَانِيد', #1
u'بالموانيذ': u'بِالْمَوانِيذِ', #2
u'بالمؤبر': u'بِالْمُؤَبَّرِ', #1
u'بالمؤبرة': u'بِالْمُؤَبَّرَةِ', #4
u'بالمؤتم': u'بِالْمُؤْتَمِّ', #4
u'بالمؤتى': u'بِالْمُؤْتَى', #1
u'بالمؤثرية': u'بِالْمُؤَثِّرِيَّةِ', #2
u'بالمورب': u'بِالْمَوْرِبِ', #1
u'بالمورخة': u'بِالْمُوَرَّخَةِ', #1
u'بالموصوفون': u'بِالْمَوْصُوفُونَ', #1
u'بالموطوءة': u'بِالْمَوْطُوءَةِ', #30
u'بالموطوءتين': u'بِالْمَوْطُوءَتَيْنِ', #2
u'بالموطوآت': u'بِالْمَوْطُوآتِ', #2
u'بالموقوذة': u'بِالْمَوْقُوذَةِ', #2
u'بالموقوفية': u'بِالْمَوْقُوفِيَّة', #1
u'بالموكإ': u'بِالْمُوكَإِ', #2
u'بالموكى': u'بِالْمُوكَى', #1
u'بالموماة': u'بِالْمَوْمَاةِ', #2
u'بالمومي': u'بِالْمُومِي', #3
u'بالمومئ': u'بِالْمُومِئِ', #22
u'بالمؤنة': u'بِالْمُؤْنَةِ', #36
u'بالمئشار': u'بِالْمِئْشَارِ', #2
u'بالمئونة': u'بِالْمَئُونَةِ', #1
u'بالميازر': u'بالميازر', #1
u'بالميازر': u'بِالْمَيَازِرِ', #1
u'بالميتدة': u'بِالْمِيتَدَةِ', #1
u'بالميثرة': u'بِالْمِيثَرَةِ', #1
u'بالمير': u'بِالْمَيْرِ', #1
u'بالميرة': u'بِالْمِيرَةِ', #3
u'بالميرى': u'بِالْمَيْرَى', #1
u'بالميشار': u'بِالْمِيشَارِ', #2
u'بالميضأة،': u'بِالْمَيْضَأَةِ،', #1
u'بالميضاة': u'بِالْمِيضَاةِ', #1
u'بالميضأة': u'بِالْمِيضَأَةِ', #5
u'بالميكلة': u'بِالْمِيكَلَةِ', #1
u'بالميولات': u'بِالْمُيُولَاتِ', #1
u'بالميئوس': u'بِالْمَيْئُوسِ', #3
u'بالناجش': u'بِالنَّاجِشِ', #9
u'بالناد': u'بِالنَّادِّ', #1
u'بالناصبي': u'بِالنَّاصِبِيِّ', #1
u'بالناض': u'بِالنَّاضِّ', #21
u'بالناعوت': u'بِالنَّاعُوتِ', #1
u'بالنام': u'بِالنَّامِّ', #1
u'بالناهى': u'بِالنَّاهِى', #1
u'بالناهى': u'بِالنَّاهِىِ', #1
u'بالنائرة': u'بِالنَّائِرَةِ', #2
u'بالنباءة': u'بِالنَّبَاءَةِ', #3
u'بالنباة': u'بِالنَّبَاةِ', #1
u'بالنباوة': u'بِالنِّبَاوَةِ', #1
u'بالنباوة': u'بِالنَّبَاوَةِ', #3
u'بالنبطيه': u'بالنبطيه', #1
u'بالنبهرجة': u'بِالنَّبَهْرَجَة', #3
u'بالنبهرجة': u'بِالنَّبَهْرَجَةِ', #3
u'بالنبى': u'بِالنَّبِىِّ', #21
u'بالنبيء': u'بِالنَّبِيءِ', #2
u'بالنثور': u'بِالنَّثُورِ', #1
u'بالنجاشى': u'بِالنَّجَاشِى', #1
u'بالنجاشى': u'بِالنَّجَاشِىِّ', #3
u'بالنجش': u'بِالنَّجْشِ', #7
u'بالنحض': u'بِالنّحْضِ', #2
u'بالنخام': u'بِالنُّخَامِ', #1
u'بالنخبار': u'بِالنّخْبَارِ', #2
u'بالنخعي،': u'بِالنَّخَعِيِّ،', #1
u'بالنخيلة،': u'بالنُّخَيْلة،', #1
u'بالنخيلة': u'بِالنُخَيْلَةِ', #1
u'بالنخيلة،': u'بِالنُّخَيْلَةِ،', #1
u'بالنخيلة': u'بِالنُّخَيْلَةِ', #5
u'بالنردشير': u'بِالنَّرْدَشِيرَ', #1
u'بالنردشير': u'بِالنَّرْدِشِيرِ', #1
u'بالنردشير': u'بِالنَّرْدَشِيرِ', #21
u'بالنسأ': u'بِالنَّسَأِ', #1
u'بالنسة': u'بِالنَّسَّةِ', #3
u'بالنسكان': u'بِالنِّسْكَانِ', #1
u'بالنسلان': u'بِالنّسَلَانِ', #1
u'بالنسلان': u'بِالنَّسَلاَنِ', #1
u'بالنسيء': u'بِالنَّسِيءِ', #1
u'بالنسيبة': u'بِالنَّسِيبَةِ', #1
u'بالنسيه': u'بِالنَّسِيَّهْ', #1
u'بالنسيئ': u'بِالنَّسِيئِ', #1
u'بالنشاستج': u'بالنشاستج', #1
u'بالنشاستج': u'بِالنَّشَاسْتَجْ', #1
u'بالنضوض': u'بِالنَّضُوضِ', #1
u'بالنضوض': u'بِالنُّضُوضِ', #1
u'بالنطاة': u'بِالنَّطَاةِ', #3
u'بالنطاة': u'بِالنّطَاةِ', #5
u'بالنطرون': u'بِالنَّطْرُونِ', #6
u'بالنعف': u'بِالنَّعْفِ', #2
u'بالنعف': u'بِالنّعْفِ', #4
u'بالنعيمان': u'بِالنُّعَيْمَانِ', #9
u'بالنقاخ': u'بِالنُّقَّاخِ', #1
u'بالنقاخ': u'بِالنُّقَاخِ', #3
u'بالنقاض': u'بِالنِّقَاضِ', #1
u'بالنقرازان': u'بِالنَّقْرَازَانِ', #1
u'بالنقرى': u'بِالنّقَرَى', #6
u'بالنقطجي': u'بِالنُّقْطَجِيِّ', #1
u'بالنهارفي': u'بِالنَّهَارِفِي', #1
u'بالنهدة': u'بِالنِّهْدَةِ', #1
u'بالنهروان،': u'بِالنَّهْرَوَانِ،', #1
u'بالنهروان': u'بِالنَّهْرَوَانِ', #13
u'بالنوا': u'بِالنّوَا', #2
u'بالنواقض': u'بِالنَّوَاقِضِ', #10
u'بالنورالقرآن،': u'بِالنُّورِالْقُرْآنَ،', #1
u'بالنورة': u'بِالنُّورَةِ', #60
u'بالنورسة': u'بِالنَّوْرَسَةِ', #1
u'بالنوشة': u'بَالنَّوْشَةِ', #1
u'بالنوشة': u'بِالنَّوْشَةِ', #1
u'بالنوقاني': u'بِالنَّوْقَانِيِّ', #1
u'بالنونة': u'بِالنُّونَةِ', #1
u'بالنئور': u'بِالنَّئُورِ', #1
u'بالنياحة': u'بِالنِّيَاحَةِ', #15
u'بالنيافق': u'بِالنَّيَافِقِ', #1
u'بالنيك': u'بِالنَّيْكِ', #2
u'بالنيلة': u'بِالنِّيلَةِ', #2
u'بالنيني': u'بالنيني', #1
u'بالنيني': u'بِالنِّينِي', #1
u'بالنيه': u'بِالنِّيَّهْ', #1
u'بالنيئة': u'بِالنِّيئَةِ', #1
u'بالهاذم': u'بِالْهَاذِمِ', #1
u'بألهاكم': u'بِأَلْهَاكُمْ', #1
u'بالهجلة': u'بِالْهَجْلَةِ', #6
u'بالهجيرالوجه': u'بِالْهَجِيرِالْوَجْهُ', #1
u'بالهذلي': u'بِالْهُذَلِيّ', #3
u'بالهرمزان،': u'بالهُرْمُزان،', #1
u'بالهملجة': u'بِالْهَمْلَجَةِ', #5
u'بالهميان': u'بِالْهِمْيَانِ', #8
u'بالهنوك': u'بِالْهُنُوكِ', #1
u'بالهوينى': u'بِالْهُوَيْنَى', #2
u'بالهيدورة': u'بِالْهَيْدُورَةِ', #1
u'بالهيمياء': u'بِالْهِيمْيَاءِ', #1
u'بالوابور': u'بِالْوَابُورِ', #1
u'بالوادى': u'بِالْوَادِى', #2
u'بالواسطي': u'بِالْوَاسِطِيِّ', #1
u'بالواقدي': u'بِالْوَاقِدِيِّ', #2
u'بالواوات': u'بِالْوَاوَاتِ', #1
u'بالوترة': u'بِالْوَتْرَةِ', #1
u'بالوتير': u'بالوَتِير', #1
u'بالوتير': u'بِالْوَتِيرِ', #9
u'بالوجادة': u'بِالْوِجَادَةِ', #1
u'بالوحى': u'بِالْوَحْىِ', #5
u'بالوخش': u'بِالْوَخْشِ', #2
u'بالوصاة': u'بِالْوَصَاةِ', #3
u'بالوضو': u'بِالْوُضُو', #1
u'بالوضوءلمن': u'بِالْوُضُوءِلِمَنْ', #1
u'بالوضوءين': u'بِالْوُضُوءَيْنِ', #1
u'بالوضوآت': u'بِالْوُضُوآتِ', #1
u'بالوطءة': u'بالوطءة', #1
u'بالوطيح': u'بِالْوَطِيحِ', #1
u'بالوع': u'بَالُوعُ', #4
u'بالوعا': u'بَالُوعًا', #3
u'بالوقاقيص': u'بِالْوَقَاقِيصِ', #1
u'بالوقص': u'بِالْوَقْصِ', #12
u'بالوقص': u'بِالْوَقَصِ', #3
u'بالوكيد': u'بالوكيد', #1
u'بالوكيد': u'بِالْوَكِيدِ', #1
u'بالولا': u'بَالْوَلَا', #1
u'بالولا': u'بِالْوَلَا', #2
u'بالولاد': u'بِالْوِلَادِ', #24
u'بالولدوروي': u'بِالْوَلَدِوَرُوِيَ', #1
u'بالولى': u'بِالْوَلِىِّ', #1
u'بالوهط،': u'بِالْوَهْطِ،', #1
u'بالوهط': u'بِالْوَهْطِ', #3
u'بالوهق': u'بِالْوَهَقِ', #1
u'بالويبات': u'بِالْوَيْبَاتِ', #1
u'بالويه،': u'بَالَوَيْه،', #1
u'بالويه،': u'بِالَوَيْهِ،', #1
u'بالويه،': u'بَالُوَيْهِ،', #13
u'بالويه': u'بَالَوَيْهِ', #53
u'بالويه': u'بَالُوَيْهِ', #70
u'بالويه،': u'بالويه،', #8
u'بالويه،': u'بَالَوَيْهِ،', #82
u'بآلى': u'بِآلَى', #1
u'بإلى': u'بِإِلَى', #82
u'باليرناء': u'بِالْيُرَنَّاءِ', #1
u'باليزناسي': u'بِالْيَزَنَاسِيِّ', #1
u'باليشب': u'بِالْيَشْبِ', #2
u'بإلىل': u'بإلىل', #1
u'بإما': u'بِإِمَّا', #1
u'باما': u'باما', #1
u'بأما': u'بِأَمَّا', #29
u'بأماته': u'بِأَمَاتَهُ', #5
u'بأمامة': u'بِأُمَامَةَ', #3
u'بامامي': u'بامامي', #1
u'بامتثلت': u'بِامْتَثَلَتْ', #2
u'بامتنع': u'بِامْتَنَعَ', #2
u'بامتنعت': u'بِامْتَنَعَتْ', #3
u'بامتولى': u'بامتولى', #1
u'بأمتى': u'بِأُمَّتِى', #2
u'بامخرمة': u'بَامَخْرَمَةَ', #6
u'بإمرأة': u'بإمرأة', #1
u'بامرأتى': u'بِامْرَأَتِى', #3
u'بأمراق': u'بِأَمْرَاقٍ', #3
u'بامرنا': u'بامرنا', #1
u'بأمره29358id': u'بأمره29358id', #1
u'بامروي': u'بامروي', #1
u'بأمسحتهم': u'بِأَمْسِحَتِهِمْ', #1
u'بأمسكتها': u'بِأَمْسَكْتُهَا', #2
u'بامسنة': u'بامسنة', #1
u'بأمشير': u'بِأَمْشِيرِ', #1
u'بأمطر': u'بِأَمْطَرَ', #1
u'بامع': u'بامع', #1
u'بامغ': u'بامغ', #1
u'بامن': u'بامن', #9
u'بإمناء': u'بِإِمْنَاءٍ', #5
u'بإمنائه': u'بِإِمْنَائِهِ', #1
u'بأمنت': u'بِأَمِنَتْ', #1
u'بأمنت': u'بِأُمِنَتْ', #1
u'بآمنتم': u'بِآمَنْتُمْ', #1
u'بأموميتها': u'بِأُمُومِيَّتِهَا', #1
u'بأمى': u'بِأُمِّى', #1
u'بامياء': u'بَامْيَاءَ', #1
u'بإنا': u'بِإِنَّا', #2
u'بأناب': u'بِأَنَابَ', #1
u'باناس': u'بَانَاسٍ', #1
u'بأنالمسجد': u'بِأَنَّالْمَسْجِدَ', #1
u'بإنائين': u'بِإِنَائَيْنِ', #2
u'بأنبجاني': u'بِأَنْبِجَانِيِّ', #1
u'بأنبجانية': u'بأنبجانية', #1
u'بأنبجانية': u'بِأَنْبِجَانِيَّةٍ', #2
u'بأنبجانية،': u'بِأَنْبِجَانِيَّةٍ،', #3
u'بأنبجانية': u'بِأَنْبِجَانِيَّةِ', #7
u'بأنبجانيته': u'بأَنبَجانيَّتِهِ', #1
u'بأنبجانيته': u'بِأَنْبِجَانِيَتِهِ', #1
u'بأنبجانيته': u'بِأَنْبِجَانِيَّتِهِ', #8
u'بأنبجانيه': u'بِأَنْبِجَانِيِّهِ', #2
u'بانة': u'بَانَةٌ', #1
u'بانة': u'بَانَةَ', #1
u'بانة': u'بَانَةٍ', #2
u'بأنت': u'بِأَنْتَ', #10
u'بأنت': u'بِأَنْتِ', #152
u'بانتزع': u'بِانْتَزَعَ', #1
u'بانتزع': u'بِانْتُزِعَ', #1
u'بانتصر': u'بِانْتَصَرَ', #1
u'بانتظر': u'بِانْتَظَرَ', #1
u'بانتفى': u'بِانْتَفَى', #1
u'بانتقاعه': u'بِانْتِقَاعِهِ', #1
u'بانتقل': u'بِانْتَقَلَ', #1
u'بانتقلت': u'بِانْتَقَلَتْ', #1
u'بأنتن': u'بِأَنْتَنِ', #1
u'بأنجب': u'بِأَنْجَبَ', #2
u'بانجراح': u'بِانْجِرَاحِ', #1
u'بانجلا': u'بِانْجَلَا', #1
u'بانجلا': u'بِانْجِلَا', #1
u'بانجماد': u'بِانْجِمَادِ', #1
u'بانح': u'بانح', #1
u'بانحقانه': u'بِانْحِقَانِهِ', #1
u'بانحكاكه': u'بِانْحِكَاكِهِ', #1
u'بانحلت': u'بِانْحَلَّتْ', #1
u'بانحنا': u'بِانْحِنَا', #1
u'بانخناس': u'بِانْخِنَاسٍ', #11
u'بأندة': u'بِأُنْدَةَ', #1
u'باندفع': u'بِانْدَفَعَ', #2
u'بإنزاء': u'بِإِنْزَاءٍ', #1
u'بإنزاء': u'بِإِنْزَاءِ', #3
u'بإنزائه': u'بِإِنْزَائِهِ', #2
u'بانزده': u'بانزده', #1
u'بأنزعا': u'بِأَنْزَعَا', #8
u'بأنسبية': u'بِأَنْسَبِيَّةِ', #1
u'بأنست': u'بِأَنِسَتْ', #1
u'بأنصارى': u'بِأَنْصَارِىٍّ', #1
u'بانصدامه': u'بِانْصِدَامِهِ', #1
u'بانصدي': u'بانصدي', #1
u'بانصدى': u'بانصدى', #1
u'بانصرافSحول': u'بِانْصِرَافِSحَوْلَ', #1
u'بأنصنا': u'بأنصنا', #1
u'بأنضح': u'بِأَنْضَحَ', #1
u'بإنعاشة': u'بِإِنْعَاشَةِ', #1
u'بإنفحة': u'بِإِنْفَحَةِ', #4
u'بأنفذ': u'بِأَنْفَذُ', #3
u'بأنفذ': u'بِأَنْفَذِ', #6
u'بأنفذت': u'بِأَنْفَذْت', #1
u'بانفصل': u'بِانْفَصَلَ', #6
u'بانفصلت': u'بِانْفَصَلَتْ', #1
u'بأنفق': u'بِأَنْفَقَ', #6
u'بأنفقت': u'بِأَنْفَقْتُ', #1
u'بانفهام': u'بِانْفِهَامِ', #1
u'بأنفى': u'بِأَنْفِى', #2
u'بانقاد': u'بِانْقَادَ', #1
u'بأنقص': u'بِأَنْقَص', #1
u'بأنقص': u'بِأَنْقَصِ', #1
u'بأنقص': u'بِأَنْقَصَ', #119
u'بانقطع': u'بِانْقَطَعَ', #1
u'بانقلب': u'بِانْقَلِبْ', #1
u'بانقلبت': u'بِانْقَلَبَتْ', #1
u'بانقيا': u'بانقيا', #2
u'بانقيا': u'بَانِقْيَا', #2
u'بإنك': u'بِإِنَّك', #1
u'بأنكحة': u'بِأَنْكِحَةٍ', #2
u'بأنكحة': u'بِأَنْكِحَةِ', #7
u'بأنكحت': u'بِأَنْكَحْت', #1
u'بأنكحت': u'بِأَنْكَحْتُ', #12
u'بانكسر': u'بِانْكَسَرَ', #1
u'بأنما': u'بِأَنَّمَا', #1
u'بإنما': u'بِإِنَّمَا', #33
u'بأننى': u'بأننى', #1
u'بإنني': u'بِإِنَّنِي', #3
u'بإنه': u'بِإِنَّهُ', #1
u'بإنها': u'بِإِنَّهَا', #9
u'بإنهاش': u'بِإِنْهَاشِ', #3
u'بإنهما': u'بِإِنَّهُمَا', #2
u'بأنوثيته': u'بِأُنُوثِيَّتِهِ', #1
u'بأنى': u'بِأَنَّى', #2
u'بأنى': u'بِأَنِّى', #3
u'بانياس': u'بَانْيَاسَ', #2
u'بإهالة': u'بِإِهَالَةٍ', #3
u'باهان': u'باهان', #2
u'باهان،': u'باهان،', #2
u'باهان': u'بَاهَانُ', #3
u'بأهبط': u'بِأُهْبِطَ', #2
u'باهجروهن': u'بِاهْجُرُوهُنَّ', #1
u'باهل': u'بَاهِلِ', #3
u'باهلا': u'بَاهِلًا', #1
u'باهلة': u'بَاهِلَةٌ', #1
u'باهلة،': u'بَاهِلَةٍ،', #1
u'باهلة': u'بِاهِلَةَ', #2
u'باهلة،': u'بَاهِلَةَ،', #2
u'باهلة': u'باهلة', #3
u'باهلة': u'بَاهِلَةَ', #30
u'باهلة': u'بَاهِلَةُ', #4
u'باهلته': u'بَاهَلَتْهُ', #1
u'باهلته': u'بَاهَلْته', #13
u'باهلته': u'بَاهَلْتُهُ', #18
u'باهلته': u'بَاهَلْتَهُ', #2
u'بأهلكت': u'بِأَهْلَكْت', #1
u'بأهلكت': u'بِأُهْلِكَتْ', #1
u'باهلني': u'بَاهَلَنِي', #4
u'باهله': u'بَاهِلِهِ', #1
u'باهله': u'بَاهِلَهْ', #3
u'باهلوني': u'بَاهَلُونِي', #1
u'باهلي': u'بَاهِلِيّ', #1
u'بأهلى': u'بِأَهْلِى', #2
u'باهلي': u'بَاهِلِيٌّ', #2
u'باهلي': u'بَاهِلِيُّ', #6
u'باهلي': u'بَاهِلِيٍّ', #7
u'باهليا': u'بَاهِلِيًّا', #1
u'بأو': u'بِأَوْ', #660
u'بأوحى': u'بِأَوْحَى', #1
u'بأودع': u'بِأَوْدَعَ', #1
u'باوري': u'باوري', #1
u'بأوزجند': u'بِأُوزَجَنْدَ', #4
u'بأوزع': u'بِأَوْزَعَ', #1
u'بأوشك': u'بِأَوْشَكَ', #4
u'بأوصى': u'بَأَوْصَى', #1
u'بأوصى': u'بِأَوْصَى', #8
u'بأوصيت': u'بِأَوْصَيْتُ', #6
u'بأوطاس،': u'بأوطاس،', #1
u'بأوطاس': u'بِأَوْطَاسٍ', #26
u'بأوطاس': u'بَأَوْطَاسٍ', #5
u'بأوطد': u'بِأَوْطَدَ', #2
u'بأوطد': u'بِأَوْطَدِ', #3
u'بأوعب': u'بأوعب', #2
u'بأوفاق': u'بِأَوْفَاقِ', #1
u'بأوقعت': u'بِأَوْقَعْتُ', #2
u'بأوكد': u'بِأَوْكَدِ', #3
u'بأوكد': u'بِأَوْكَدَ', #5
u'بأوكدية': u'بِأَوْكَدِيَّةِ', #1
u'بأولا': u'بِأَوَّلًا', #4
u'باولج': u'باولج', #1
u'بأولى': u'بِأُولًى', #1
u'بأومأ': u'بِأَوْمَأَ', #2
u'بآوندى': u'بآوندى', #1
u'بأوهم': u'بِأَوْهَمَ', #1
u'باوي': u'باوي', #1
u'باوى': u'باوى', #2
u'بأويس': u'بأُوَيْس', #1
u'بأويس': u'بِأُوَيْسٍ', #1
u'بأى': u'بَأَى', #1
u'باي': u'باي', #11
u'بأى': u'بِأَىِّ', #35
u'بائتم': u'بِائْتَمَّ', #1
u'بائتمام': u'بِائْتِمَامِ', #1
u'بائتمامهم': u'بِائْتِمَامِهِمْ', #1
u'بائغة': u'بَائِغَةً', #1
u'بائقة': u'بائقة', #1
u'بائقة': u'بَائِقَةَ', #1
u'بائقة': u'بَائِقَةٍ', #2
u'بائنون': u'بَائِنُونَ', #1
u'بإياس': u'بِإِيَاسِ', #1
u'بإياس': u'بِإِيَاسٍ', #4
u'بإياسه': u'بِإِيَاسِهِ', #3
u'بإياسها': u'بِإِيَاسِهَا', #28
u'بإياسي': u'بِإِيَاسِي', #1
u'بإياك': u'بِإِيَّاكَ', #2
u'بأياما': u'بِأَيَّامًا', #8
u'بايت': u'بايت', #1
u'بايتو': u'بايتو', #1
u'بايد': u'بايد', #21
u'بايد': u'بَايْدَ', #4
u'بايدبدين': u'بايدبدين', #1
u'بايدت': u'بايدت', #2
u'بايدحال': u'بايدحال', #1
u'بايددادادن': u'بايددادادن', #1
u'بايدكه': u'بايدكه', #2
u'بأيدهم': u'بِأَيْدِهِمْ', #5
u'بأيدى': u'بِأَيْدِى', #4
u'بايزد': u'بايزد', #2
u'بايزدان': u'بايزدان', #1
u'بايزيد': u'بَايَزِيدَ', #1
u'بايزيد': u'بايزيد', #2
u'بايزيدخان': u'بَايَزِيدْخَانْ', #1
u'بآيس': u'بِآيِسٍ', #1
u'بآيسة': u'بِآيِسَةٍ', #7
u'بايست': u'بايست', #3
u'بأيش': u'بِأَيْشِ', #1
u'بأيضا': u'بِأَيْضًا', #4
u'بايعنى': u'بَايَعَنِى', #1
u'بايعنى': u'بَايِعْنِى', #1
u'بايعونى': u'بَايِعُونِى', #2
u'بأيقن': u'بِأَيْقَنَ', #2
u'بايك': u'بايك', #2
u'بايكار': u'بايكار', #1
u'بايكاه': u'بايكاه', #1
u'بآيل': u'بِآيِلٍ', #1
u'بأيلة': u'بِأَيْلَةَ', #1
u'بإيليا': u'بِإِيلْيَا', #1
u'بإيلياء': u'بِإِيلِيَاء', #1
u'بإيلياء': u'بِإِيلِيَاءَ', #13
u'بإيلياء': u'بإيلياء', #2
u'بإيلياء،': u'بِإِيلِيَاءَ،', #3
u'بإيلياء': u'بِإِيلْيَاءَ', #4
u'بايم': u'بِاَيْمِ', #1
u'بأيما': u'بِأَيِّمَا', #1
u'باين': u'باين', #18
u'باين': u'بَايَنَ', #33
u'باينا': u'بَايَنَا', #1
u'باينا': u'بَايِنًا', #1
u'باينت': u'بَايَنَتْ', #11
u'باينت': u'بَايَنْتَ', #2
u'باينتك': u'بَايَنْتُك', #2
u'باينتك': u'بَايَنْتُكِ', #2
u'باينته': u'بَايَنَتْهُ', #8
u'باينتها': u'بَايَنَتْهَا', #6
u'باينتهم': u'بَايَنَتْهُمْ', #1
u'باينجهان': u'باينجهان', #1
u'باينخانه': u'باينخانه', #3
u'باينه': u'بَايَنَهُ', #7
u'باينها': u'بَايَنَهَا', #8
u'باينهما': u'بَايَنَهُمَا', #2
u'باينوا': u'بَايَنُوا', #2
u'باينوه': u'بَايَنُوهُ', #1
u'باينوهم': u'بَايَنُوهُمْ', #1
u'ببا': u'ببا', #2
u'بباجة': u'بِبَاجَّةِ', #1
u'ببادرت': u'بِبَادَرَتْ', #2
u'بباذغيس': u'بباذَغِيس', #1
u'ببارتا': u'ببارتا', #1
u'بباس': u'بِبَاسِ', #1
u'بباسطا': u'بِبَاسِطًا', #1
u'بباشروهن': u'بِبَاشِرُوهُنَّ', #1
u'ببافت': u'ببافت', #2
u'بباقنده': u'بباقنده', #1
u'بباقيا': u'بِبَاقِيًا', #1
u'ببالس،': u'بِبَالِسَ،', #1
u'ببالى': u'بِبَالِى', #1
u'ببامية': u'بِبَامِيَةٍ', #1
u'ببأن': u'بِبَأَنَّ', #1
u'ببأن': u'بِبَأَنْ', #1
u'ببانا': u'بَبَّانَا', #3
u'ببانا': u'بَبَّانًا', #6
u'ببانت': u'بِبَانَتْ', #3
u'ببة': u'بَبّة', #1
u'ببة،': u'بَبَّةَ،', #1
u'ببثينة،': u'بِبُثَيْنَةَ،', #1
u'ببجات': u'بِبِجَاتَ', #1
u'ببجاية': u'بِبِجَايَةَ', #1
u'ببجيلة': u'بِبَجِيلَةٍ', #1
u'ببجيلة': u'بِبَجِيلَةَ', #1
u'ببحران': u'بِبَحْرَانِ', #1
u'ببحران،': u'بِبُحْرَانَ،', #1
u'ببحران': u'بِبُحْرَان', #2
u'ببحران': u'بِبُحْرَانَ', #2
u'ببحرة': u'بِبَحْرَةِ', #2
u'ببحرة': u'بِبُحْرَةِ', #2
u'ببحيرا،': u'بِبَحِيرَا،', #1
u'ببحيرى': u'بِبَحِيرَى', #2
u'ببخارى': u'بِبُخَارَى', #164
u'ببخارى،': u'بِبُخَارَى،', #19
u'ببخارى': u'ببخارى', #2
u'ببخارى،': u'ببخارى،', #2
u'ببخية': u'بِبَخِيَّةٍ', #1
u'ببدا': u'بِبَدَا', #1
u'ببداء': u'بِبَدَاءِ', #1
u'ببدلا': u'بِبَدَلًا', #3
u'ببدليته': u'بِبَدَلِيَّتِهِ', #1
u'ببدنى': u'ببدنى', #1
u'ببدئ': u'بِبُدِئَ', #1
u'ببذرى': u'بِبَذْرِى', #1
u'ببذلت': u'بِبَذَلْت', #1
u'ببراءتى': u'بِبَرَاءَتِى', #1
u'ببرابير': u'بِبَرَابِيرِ', #1
u'ببراجمه': u'بِبَرَاجِمِهِ', #1
u'ببردا': u'بِبَرَدَا', #2
u'ببرديا': u'ببرديا', #1
u'ببرسام': u'بِبِرْسَامٍ', #2
u'ببرصة': u'بِبِرْصَة', #1
u'ببرقاء': u'بِبَرْقَاءِ', #1
u'ببرقة،': u'بِبَرْقَةَ،', #1
u'ببرقة': u'بِبَرْقَةَ', #2
u'ببرقة': u'بِبُرْقَةَ', #2
u'ببرنج': u'ببرنج', #1
u'ببرند': u'بِبَرْنَدْ', #1
u'ببرند': u'بِبِرْنَدٌ', #1
u'ببرى': u'ببرى', #2
u'ببرىء': u'بِبَرِىءٍ', #1
u'ببرئ': u'بِبَرِئَ', #4
u'ببريدة': u'بِبُرَيْدَةَ', #1
u'ببريرة': u'ببريرة', #1
u'ببريرة': u'بِبَرِيرَةَ', #2
u'ببز': u'بِبَزِّ', #1
u'ببز': u'بِبَزٍّ', #3
u'ببزاخة': u'بِبُزَاخَةَ', #1
u'ببزاخة،': u'بِبُزَاخَةَ،', #3
u'ببزيغ': u'بِبُزَيْغٍ', #4
u'ببس': u'ببس', #1
u'ببست': u'بِبُسْتَ', #2
u'ببست،': u'بِبُسْتَ،', #21
u'ببسيس': u'بِبَسِيسٍ', #1
u'ببشارة': u'بِبِشَارَةً', #1
u'ببصرى': u'بِبَصَرِى', #1
u'ببصرى،': u'بِبُصْرَى،', #1
u'ببصرى': u'بِبُصْرَى', #5
u'ببطحان': u'بِبُطْحَانَ', #1
u'ببطلت': u'بِبَطَلَتْ', #1
u'ببطلتا': u'بِبَطَلَتَا', #1
u'ببعت': u'بِبِعْت', #1
u'ببعت': u'بِبِعْتُ', #5
u'ببعج': u'بِبَعْجِ', #2
u'ببعضا': u'بِبَعْضًا', #1
u'ببعضوالوجه': u'بِبَعْضٍوَالْوَجْهُ', #1
u'ببعلبك': u'بِبَعْلَبَكّ', #1
u'ببعلبك،': u'بِبَعْلَبَكَّ،', #1
u'ببعلبك': u'بِبَعْلَبَكَّ', #4
u'ببعني': u'بِبِعْنِي', #4
u'ببغا': u'بَبْغَا', #1
u'ببغا': u'بَبَّغَا', #3
u'ببغدادأخبرنا': u'بِبَغْدَادَأَخْبَرَنَا', #1
u'ببغلان،': u'بِبَغْلانَ،', #1
u'ببغمبر': u'ببغمبر', #1
u'ببقعاء': u'بِبَقْعَاءِ', #1
u'ببقعاء': u'بِبَقْعَاءَ', #3
u'ببقلة': u'بِبَقْلَةِ', #1
u'ببقلة': u'بِبَقْلَةٍ', #6
u'ببقور': u'بِبُقُورٍ', #1
u'ببقورة': u'بِبَقُورَةِ', #1
u'ببلا': u'بِبَلَا', #1
u'ببلاعة': u'بِبَلَّاعَةٍ', #1
u'ببلاها': u'بِبَلاهَا', #1
u'ببلبيس': u'بِبُلْبَيْسَ', #2
u'ببلبيس': u'بِبِلْبِيسَ', #6
u'ببلخ': u'بِبَلَخٍ', #1
u'ببلخ': u'بِبَلْخَ', #1
u'ببلخ،': u'بِبَلْخَ،', #1
u'ببلخ': u'بِبَلْخٍ', #39
u'ببلخي': u'بِبَلْخِيِ', #1
u'ببلدح،': u'بِبَلْدَحٍ،', #1
u'ببلدح': u'بِبَلْدَحٍ', #2
u'ببلدح': u'بِبَلْدَحَ', #2
u'ببلغا': u'بِبَلّغَا', #1
u'ببلغد': u'ببلغد', #1
u'ببلغم': u'بِبَلْغَمٍ', #1
u'ببلغهم': u'بِبَلِّغُهُمْ', #1
u'ببلقع': u'ببَلْقَعِ', #1
u'ببلنجر،': u'ببَلَنْجَر،', #1
u'ببلهط': u'بِبلهط', #1
u'ببلى': u'بِبَلَى', #11
u'ببليت': u'بِبُلِيتُ', #1
u'ببنا': u'بِبِنَا', #1
u'ببناطيا': u'بِبَنَاطِيًّا', #1
u'ببنة': u'بِبِنَّةِ', #1
u'ببه': u'بِبِهِ', #1
u'ببه': u'ببه', #2
u'ببه': u'ببِهِ', #2
u'ببه': u'بَبَّهْ', #2
u'ببوانة': u'بِبُوانَةَ', #1
u'ببوانة': u'بِبُوَانَةَ', #4
u'ببوائقه': u'بِبَوَائِقِهِ', #1
u'ببوران': u'بِبَوَرَانِ', #1
u'ببورقة': u'ببورقة', #1
u'ببولاء': u'ببولاء', #1
u'ببولاد': u'ببولاد', #1
u'ببولاق': u'بِبُولَاقَ', #10
u'ببولاق': u'بِبُولَاقِ', #2
u'ببئار': u'بِبِئَارِ', #1
u'ببيتا': u'بِبَيْتًا', #3
u'ببيتة': u'بِبِيتَةِ', #1
u'ببيرحاء': u'بِبَيْرُحَاء', #1
u'ببيرحاء': u'بِبَيْرُحَاءَ', #1
u'ببيرخشك': u'ببيرخشك', #1
u'ببيسان': u'بِبَيْسَانَ', #1
u'ببيشة': u'بِبِيشَةِ', #1
u'ببيشة': u'بِبِيشَةَ', #2
u'ببيضا': u'بِبَيْضَا', #1
u'ببيعا': u'بِبَيْعًا', #1
u'ببيعت': u'بِبِيعَتْ', #1
u'ببينة': u'بِبَيِّنَةً', #1
u'ببينت': u'بِبُيِّنَتْ', #1
u'ببيهق': u'بِبَيْهَقَ', #6
u'ببيوعات': u'بِبُيُوعَاتٍ', #1
u'بة': u'بَةِ', #2
u'بت': u'بَتًّ', #1
u'بتأبر': u'بِتَأَبُّرِ', #1
u'بتأبر': u'بِتَأَبَّرَ', #2
u'بتابستان': u'بتابستان', #2
u'بتأخذ': u'بِتَأْخُذْ', #1
u'بتأدي': u'بِتَأَدِّي', #5
u'بتأديه': u'بِتَأَدِّيهِ', #1
u'بتأذي': u'بِتَأَذِّي', #2
u'بتأذيه': u'بِتَأَذِّيهِ', #2
u'بتأذيه': u'بِتَأَذِّيه', #3
u'بتاركا': u'بِتَارِكًا', #1
u'بتاصاليت': u'بتاصاليت', #2
u'بتأقيت': u'بِتَأْقِيتٍ', #1
u'بتأقيت': u'بِتَأْقِيتِ', #2
u'بتأقيته': u'بِتَأْقِيتِهِ', #1
u'بتأقيتها': u'بِتَأْقِيتِهَا', #1
u'بتاكا': u'بَتّاكًا', #1
u'بتاكا': u'بَتّاكَا', #1
u'بتأكال': u'بِتَأْكَالِ', #2
u'بتالة': u'بِتَالَّةٍ', #1
u'بتالق': u'بِتَالِقٍ', #1
u'بتالله': u'بِتَاللَّهِ', #1
u'بتاما': u'بِتَامًّا', #1
u'بتآويل': u'بِتَآوِيلَ', #2
u'بتأويلان': u'بِتَأْوِيلَانِ', #5
u'بتبالة': u'بِتَبَالَةَ', #6
u'بتبة': u'بتبة', #1
u'بتبتيل': u'بِتَبْتِيلِ', #1
u'بتبدئة': u'بِتَبْدِئَةِ', #33
u'بتبدئة': u'بِتَبْدِئَةٍ', #4
u'بتبذيلهم': u'بِتَبْذِيلِهِمْ', #2
u'بتبرعا': u'بِتَبَرُّعًا', #1
u'بتبرين': u'بِتِبْرَيْنِ', #3
u'بتبريه': u'بِتَبَرِّيهِ', #3
u'بتبصرة': u'بِتَبْصِرَةِ', #1
u'بتبطل': u'بِتَبْطُلُ', #3
u'بتبطيل': u'بِتَبْطِيلِ', #1
u'بتبعا': u'بِتَبَعًا', #1
u'بتبعضها': u'بِتَبَعُّضِهَا', #1
u'بتبكي': u'بِتُبْكِي', #1
u'بتبنة': u'بِتِبْنَةٍ', #13
u'بتبنة': u'بِتَبِنَةِ', #2
u'بتبنة': u'بِتَبِنَةٍ', #3
u'بتبوك،': u'بتَبُوك،', #1
u'بتبوك': u'بتبوك', #2
u'بتبوك': u'بِتَبُوكَ', #61
u'بتبوك،': u'بِتَبُوكَ،', #7
u'بتبوئة': u'بِتَبْوِئَةٍ', #2
u'بتبوئتها': u'بِتَبْوِئَتِهَا', #1
u'بتبيع': u'بِتَبِيعٍ', #4
u'بتبيعين': u'بِتَبِيعَيْنِ', #1
u'بتترسهم': u'بِتَتَرُّسِهِمْ', #1
u'بتتريب': u'بِتَتْرِيبٍ', #1
u'بتتصف': u'بِتَتَّصِفْ', #1
u'بتتقون': u'بِتَتَّقُونَ', #1
u'بتتواضع': u'بِتَتَوَاضَعَ', #1
u'بتتواضع': u'بِتَتَوَاضَعُ', #1
u'بتثرد': u'بِتَثَرُّدِ', #1
u'بتجب': u'بِتَجِبُ', #13
u'بتجتنب': u'بِتَجْتَنِبُ', #2
u'بتجزي': u'بِتَجَزِّي', #3
u'بتجزيه': u'بِتَجَزِّيهِ', #1
u'بتجسيس': u'بِتَجْسِيسٍ', #1
u'بتجعل': u'بِتُجْعَلُ', #1
u'بتجوير': u'بِتَجْوِيرِ', #1
u'بتحاملوا': u'بِتَحَامَلُوا', #1
u'بتحرم': u'بِتَحْرُمُ', #1
u'بتحرم': u'بِتَحَرُّمِ', #2
u'بتحرمه': u'بِتَحَرُّمِهِ', #1
u'بتحرمها': u'بِتَحَرُّمِهَا', #3
u'بتحرمهم': u'بِتَحَرُّمِهِمْ', #1
u'بتحصينا': u'بِتَحْصِينًا', #1
u'بتحظر': u'بِتُحْظَرُ', #1
u'بتحكمون': u'بِتَحْكُمُونَ', #1
u'بتحلف': u'بِتَحْلِفُ', #1
u'بتحنيث': u'بِتَحْنِيثِ', #3
u'بتحنيثه': u'بِتَحْنِيثِهِ', #8
u'بتحيل': u'بِتَحَيُّلٍ', #1
u'بتحيل': u'بِتَحَيُّلِ', #1
u'بتخاير': u'بِتَخَايُرٍ', #1
u'بتخايرهما': u'بِتَخَايُرِهِمَا', #3
u'بتخبيبهم': u'بِتَخْبِيبِهِمْ', #1
u'بتخريصه': u'بِتَخْرِيصِهِ', #1
u'بتخمينا': u'بِتَخْمِينًا', #2
u'بتدرأ': u'بِتَدْرَأَ', #1
u'بتدمر،': u'بِتَدْمُرَ،', #1
u'بتراد': u'بِتَرَادِّ', #1
u'بتربان': u'بِتُرْبَانَ', #4
u'بتربت': u'بِتَرِبَتْ', #1
u'بترتدد': u'بِتَرْتَدِدْ', #1
u'بترشيش': u'بِتَرْشِيشِ', #1
u'بتركت': u'بِتَرَكْت', #1
u'بترم': u'بترم', #1
u'بترمذ': u'بِتِرْمِذَ', #1
u'بترمذ،': u'بِتِرْمِذَ،', #2
u'بترنجبين': u'بِتَرَنْجَبِينٍ', #1
u'بتزوجت': u'بِتَزَوَّجْت', #1
u'بتزوجت': u'بِتَزَوَّجْتَ', #1
u'بتزوجت': u'بِتَزَوَّجْتُ', #2
u'بتزوجتك': u'بِتَزَوَّجْتُك', #4
u'بتزوجتك': u'بِتَزَوَّجْتُكِ', #7
u'بتزيد': u'بِتَزَيُّدِ', #1
u'بتزيده': u'بِتَزَيُّدِهِ', #1
u'بتزيل': u'بِتَزَيُّلِ', #1
u'بتستفاد': u'بِتُسْتَفَادُ', #1
u'بتسحر': u'بِتَسَحُّرٍ', #5
u'بتسخط': u'بِتَسَخُّطٍ', #1
u'بتسر': u'بِتَسَرٍّ', #4
u'بتسرر': u'بِتَسَرُّرٍ', #1
u'بتسلمة': u'بِتَسْلِمَةٍ', #1
u'بتسليمة': u'بِتَسْلِيمَةِ', #25
u'بتسليمة': u'بِتَسْلِيمَةٍ', #306
u'بتسليمتين': u'بِتَسْلِيمَتَيْنِ', #94
u'بتسمح': u'بِتَسَمُّحٍ', #2
u'بتسوغ': u'بِتَسُوغُ', #1
u'بتسويتهالأنه': u'بِتَسْوِيَتِهَالِأَنَّهُ', #1
u'بتشترط': u'بِتُشْتَرَطُ', #1
u'بتشحين': u'بِتَشْحِينِ', #4
u'بتشرع': u'بِتُشْرَعُ', #2
u'بتشطر': u'بِتَشَطُّرِ', #1
u'بتشطر': u'بِتَشَطَّرَ', #2
u'بتشقص': u'بِتَشَقُّصٍ', #1
u'بتشقيص': u'بِتَشْقِيصِ', #3
u'بتشقيص': u'بِتَشْقِيصٍ', #5
u'بتشقيصه': u'بِتَشْقِيصِهِ', #2
u'بتصادقا': u'بِتَصَادَقَا', #1
u'بتصح': u'بِتَصِحُّ', #10
u'بتصدقت': u'بِتَصَدَّقْتُ', #2
u'بتصريتها،': u'بتصريتها،', #1
u'بتصريتها': u'بِتَصْرِيَتِهَا', #5
u'بتصف': u'بِتَصِفُ', #1
u'بتصل': u'بِتَصِلُ', #1
u'بتضبيب': u'بِتَضْبِيبٍ', #1
u'بتضبيبه': u'بِتَضْبِيبِهِ', #1
u'بتضرب': u'بِتَضْرِبُ', #1
u'بتطرية': u'بِتَطْرِيَةٍ', #1
u'بتطليقة': u'بِتَطْلِيقَةِ', #1
u'بتطليقة': u'بِتَطْلِيقَةٍ', #182
u'بتطليقتين': u'بِتَطْلِيقَتَيْنِ', #23
u'بتطول': u'بِتَطَوُّلِ', #1
u'بتظهر': u'بِتَظْهَرُ', #1
u'بتظهره': u'بِتَظَهُّرِهِ', #2
u'بتعا': u'بِتْعًا', #1
u'بتعتد': u'بِتَعْتَدُّ', #3
u'بتعدل': u'بِتَعَدُّلِ', #1
u'بتعز': u'بِتَعِزَّ', #9
u'بتعصية': u'بِتَعْصِيَةِ', #1
u'بتعم': u'بِتَعُمُّ', #2
u'بتعهن': u'بِتَعْهِنَ', #1
u'بتعهن': u'بِتِعْهِنَ', #2
u'بتعول': u'بِتَعُولُ', #1
u'بتعيب': u'بِتَعَيُّبٍ', #2
u'بتعيب': u'بِتَعَيُّبِ', #4
u'بتعيبه': u'بِتَعَيُّبِهِ', #13
u'بتعيبها': u'بِتَعَيُّبِهَا', #3
u'بتعيبهما': u'بِتَعَيُّبِهِمَا', #1
u'بتعيد': u'بِتُعِيدُ', #1
u'بتغلظ': u'بِتَغَلُّظِ', #2
u'بتغلظها': u'بِتَغَلُّظِهَا', #2
u'بتفاريعه': u'بِتَفَارِيعِهِ', #1
u'بتفاريعها': u'بِتَفَارِيعِهَا', #1
u'بتفث': u'بِتَفَثِ', #13
u'بتقارر': u'بَتَقَارُرِ', #1
u'بتقارر': u'بِتَقَارُرٍ', #1
u'بتقارر': u'بِتَقَارُرِ', #2
u'بتقارهما': u'بِتَقَارِّهِمَا', #2
u'بتقال': u'بِتَقَالٍّ', #1
u'بتقام': u'بتقام', #1
u'بتقايؤ': u'بِتَقَايُؤٍ', #2
u'بتقايؤها': u'بتقايؤها', #1
u'بتقايئه': u'بِتَقَايُئِهِ', #1
u'بتقايئها': u'بِتَقَايُئِهَا', #2
u'بتكفلت': u'بِتَكَفَّلْتُ', #1
u'بتكفئه': u'بِتَكَفُّئِهِ', #1
u'بتكها': u'بَتَكَهَا', #5
u'بتلة': u'بَتَلَةً', #4
u'بتلة': u'بَتْلَةً', #8
u'بتلت': u'بَتَلْتُ', #1
u'بتلت': u'بُتِلَتْ', #1
u'بتلت': u'بُتِّلَتْ', #1
u'بتلزمه': u'بِتَلْزَمُهُ', #2
u'بتلعب': u'بِتَلَعُّبِ', #6
u'بتلفقه': u'بِتَلَفُّقِهِ', #1
u'بتلمح': u'بِتَلَمُّحِ', #2
u'بتلمسان': u'بِتِلِمْسَانَ', #1
u'بتلمسان': u'بِتِلْمِسَانَ', #1
u'بتما': u'بِتُّمَا', #1
u'بتمالؤ': u'بِتَمَالُؤٍ', #2
u'بتمت': u'بِتَمُتْ', #1
u'بتمتنع': u'بِتَمْتَنِعْ', #1
u'بتمجس': u'بِتَمَجُّسٍ', #5
u'بتمجسه': u'بِتَمَجُّسِهِ', #1
u'بتمجسها': u'بِتَمَجُّسِهَا', #5
u'بتمحض': u'بِتَمَحُّضِ', #4
u'بتمحضت': u'بِتَمَحَّضَتْ', #1
u'بتمحضه': u'بِتَمَحُّضِهِ', #2
u'بتمحل': u'بِتَمَحُّلٍ', #3
u'بتمرغت': u'بِتَمَرَّغْت', #1
u'بتمرغت': u'بِتَمَرَّغْتُ', #1
u'بتمنى': u'بِتَمَنِّى', #1
u'بتميمي': u'بِتَمِيمِيٍّ', #1
u'بتناط': u'بِتُنَاطُ', #1
u'بتنبكتو': u'بتنبكتو', #1
u'بتنخع': u'بِتَنَخُّعِ', #1
u'بتنضبط': u'بِتَنْضَبِطُ', #3
u'بتنضيض': u'بِتَنْضِيضٍ', #1
u'بتنضيض': u'بِتَنْضِيضِ', #5
u'بتنفذ': u'بِتَنْفُذُ', #1
u'بتنفسخ': u'بِتَنْفَسِخُ', #1
u'بتنقطع': u'بِتَنْقَطِعُ', #1
u'بتنكح': u'بِتَنْكِحَ', #2
u'بتنوفة': u'بِتَنُوفَةٍ', #1
u'بتنوفة': u'بِتَنُوفَةِ', #2
u'بتنيس': u'بِتَنِيسَ', #1
u'بتنيس': u'بِتَنِّيسَ', #1
u'بتنيس': u'بِتِنِّيسَ', #3
u'بتنيس،': u'بِتِنِّيسَ،', #3
u'بتهامة،': u'بتهامة،', #1
u'بتهامة،': u'بِتِهَامَةَ،', #1
u'بتهامة': u'بِتِهَامَةَ', #10
u'بتهوك': u'بِتَهَوُّكِ', #1
u'بتواء': u'بِتَوَاءِ', #1
u'بتواكيد': u'بِتَوَاكِيدَ', #1
u'بتوأمان': u'بِتَوْأَمَانٍ', #1
u'بتوامر': u'بتوامر', #1
u'بتوبخشيدم': u'بتوبخشيدم', #1
u'بتوتسليم': u'بتوتسليم', #1
u'بتوتيا': u'بِتُوتْيَا', #1
u'بتوثن': u'بِتَوَثُّنٍ', #1
u'بتوجيع': u'بِتَوْجِيعٍ', #1
u'بتوحيش': u'بِتَوْحِيشِ', #1
u'بتوحيل': u'بِتَوْحِيلٍ', #1
u'بتوحيلها': u'بِتَوْحِيلِهَا', #1
u'بتودادم': u'بتودادم', #1
u'بتودهم': u'بتودهم', #2
u'بتور': u'بتور', #1
u'بتور': u'بِتَوْرٍ', #29
u'بتور': u'بِتَوْرِ', #3
u'بتورسانيده': u'بتورسانيده', #1
u'بتوسبارمش': u'بتوسبارمش', #1
u'بتوسلا': u'بِتَوَسُّلًا', #1
u'بتوسيرد': u'بتوسيرد', #1
u'بتوضأ': u'بِتَوَضَّأَ', #2
u'بتوقان': u'بِتَوَقَانٍ', #1
u'بتوقان': u'بِتَوَقَانِ', #1
u'بتوقانه': u'بِتَوَقَانِهِ', #7
u'بتوقة': u'بَتُوقَةٌ', #1
u'بتوقت': u'بِتَوَقُّتِ', #3
u'بتوقتها': u'بِتَوَقُّتِهَا', #1
u'بتؤكد': u'بِتُؤَكِّدُ', #1
u'بتوكيلا': u'بِتَوْكِيلًا', #1
u'بتوماندم': u'بتوماندم', #2
u'بتومتين': u'بِتُومَتَيْنِ', #1
u'بتوميدهم': u'بتوميدهم', #1
u'بتونر': u'بتونر', #7
u'بتونيسه': u'بِتَوْنِيسِهِ', #1
u'بتوهيق': u'بِتَوْهِيقٍ', #1
u'بتؤولت': u'بِتُؤُوِّلَتْ', #2
u'بتوى': u'بِتَوًى', #1
u'بتى': u'بتى', #1
u'بتياعها': u'بِتِيَاعِهَا', #2
u'بتير': u'بَتِيرٌ', #1
u'بتيراء': u'بُتَيْرَاءٌ', #1
u'بتيراء': u'بُتَيْرَاءُ', #6
u'بتيرة': u'بُتَيْرَةَ', #2
u'بتيقنا': u'بِتَيَقَّنَّا', #1
u'بتيقنت': u'بِتُيُقِّنَتْ', #1
u'بثبار': u'بِثِبَارٍ', #1
u'بثبار': u'بِثِبَارَ', #1
u'بثجيجه': u'بِثَجِيجِهِ', #1
u'بثخانة': u'بِثَخَانَةِ', #6
u'بثخن': u'بِثِخَنِ', #1
u'بثخن': u'بِثِخَنٍ', #2
u'بثرات': u'بَثَرَاتٌ', #1
u'بثرات': u'بَثَرَاتِ', #1
u'بثرة،': u'بثرة،', #1
u'بثرة': u'بَثَرَةٍ', #1
u'بثرة': u'بَثْرَة', #1
u'بثرة': u'بَثْرَةُ', #1
u'بثرة': u'بَثْرَةٌ', #10
u'بثرة': u'بَثْرَةً', #4
u'بثرة': u'بَثْرَةٍ', #6
u'بثريدة': u'بِثَرِيدَةٍ', #1
u'بثريدة،': u'بِثَرِيدَةٍ،', #1
u'بثفر': u'بِثَفْرِ', #2
u'بثفر': u'بِثُفْرِ', #2
u'بثفر': u'بِثَفَرِ', #4
u'بثق': u'بَثَقَ', #2
u'بثق': u'بَثْقٍ', #4
u'بثقا': u'بَثْقًا', #2
u'بثكلت': u'بِثَكِلَتْ', #1
u'بثلاثه': u'بِثَلَاثِهِ', #3
u'بثلثمائة': u'بِثَلَثِمِائَةِ', #18
u'بثلثمائة': u'بِثَلَثِمِائَةٍ', #28
u'بثلثى': u'بِثُلُثَىِ', #2
u'بثلثى': u'بِثُلُثَىْ', #4
u'بثما': u'بِثُمَّا', #1
u'بثمة': u'بِثَمَّةَ', #1
u'بثمغ،': u'بِثَمْغَ،', #1
u'بثمغ': u'بِثَمْغٍ', #4
u'بثناءات': u'بِثَنَاءَاتٍ', #1
u'بثنة': u'بثنة', #1
u'بثنة': u'بَثْنَةَ', #1
u'بثنة': u'بُثْنَةُ', #1
u'بثنى': u'بِثُنًى', #1
u'بثنيا': u'بِثُنْيَا', #1
u'بثنيان': u'بِثُنْيَانٍ', #2
u'بثنية': u'بَثْنِيَةً', #1
u'بثنية': u'بَثْنِيَّةً', #1
u'بثوبى': u'بِثَوْبِى', #3
u'بثوق': u'بُثُوقٍ', #2
u'بثوقا': u'بُثُوقًا', #1
u'بثى': u'بثى', #1
u'بثى': u'بَثِّى', #1
u'بثيابتها': u'بِثِيَابَتِهَا', #1
u'بثيابى': u'بِثِيَابِى', #1
u'بثير': u'بَثِيرٌ', #3
u'بثين': u'بُثَيْنُ', #1
u'بثينة': u'بُثَيْنَةُ', #3
u'بثينة': u'بُثَيْنَةَ', #8
u'بثيوبتها': u'بِثُيُوبَتِهَا', #21
u'بج': u'بَجِّ', #1
u'بج': u'بج', #70
u'بجاءت': u'بِجَاءَتْ', #1
u'بجادا': u'بِجادًا', #1
u'بجادا': u'بِجَادًا', #2
u'بجارية،': u'بِجَارِيَةً،', #1
u'بجامكية': u'بِجَامِكِيَّةٍ', #1
u'بجامكية': u'بِجَامِكِيَّةِ', #1
u'بجاهيهما': u'بِجَاهَيْهِمَا', #1
u'بجاورة': u'بَجَاوِرَةٌ', #1
u'بجاي': u'بجاي', #1
u'بجاى': u'بجاى', #1
u'بجاية': u'بِجَايَةَ', #6
u'بجبرا': u'بِجَبْرًا', #2
u'بجبرانات': u'بِجُبْرَانَاتِ', #1
u'بجبرانه': u'بِجُبْرَانِهِ', #1
u'بجبرانين': u'بِجُبْرَانَيْنِ', #3
u'بجبلى': u'بِجَبَلَىْ', #1
u'بجبنة': u'بِجُبْنَةٍ', #7
u'بجبهتى': u'بِجَبْهَتِى', #1
u'بجبيرة': u'بِجَبِيرَةٍ', #3
u'بجة': u'بَجَّةٍ', #1
u'بجثومه': u'بِجُثُومِهِ', #1
u'بجحط': u'بجحط', #1
u'بجحفة': u'بِجُحْفَةٍ', #1
u'بجحفة،': u'بِجَحَفَةٍ،', #1
u'بجحيش': u'بِجُحَيْشٍ', #1
u'بجدا': u'بِجِدًّا', #2
u'بجدان': u'بُجْدَانَ', #18
u'بجدان': u'بَجْدَانَ', #2
u'بجدرات': u'بِجَدَرَاتِ', #1
u'بجدرته': u'بِجُدْرَتِهِ', #1
u'بجدى': u'بِجَدْىٍ', #3
u'بجذعة': u'بِجَذَعَةِ', #1
u'بجذعة': u'بِجَذَعَةٍ', #3
u'بجراي': u'بِجَرَّايَ', #1
u'بجرائره': u'بِجَرَائِرِهِ', #4
u'بجرت': u'بِجَرَتْ', #1
u'بجرجان': u'بِجُرْجَانَ', #9
u'بجرجانية': u'بِجُرْجَانِيَّةَ', #1
u'بجرجير': u'بِجِرْجِيرٍ', #1
u'بجرحني': u'بِجَرَحَنِي', #1
u'بجرعاء': u'بِجَرْعَاءِ', #1
u'بجرمانا': u'بِجَرْمَانَا', #1
u'بجرى': u'بَجْرَى', #1
u'بجرى': u'بِجَرَى', #3
u'بجريب': u'بِجَرِيبٍ', #3
u'بجريتها': u'بِجِرْيَتِهَا', #1
u'بجريج': u'بِجُرَيْجٍ', #1
u'بجريش': u'بِجَرِيشِ', #2
u'بجريعة': u'بِجُرَيْعَةِ', #2
u'بجرين': u'بِجَرِينِ', #1
u'بجرين': u'بِجَرِينٍ', #11
u'بجزابشان': u'بجزابشان', #1
u'بجزدوزخ': u'بجزدوزخ', #1
u'بجزرة': u'بِجَزْرَةٍ', #1
u'بجزى': u'بِجَزَى', #2
u'بجعالة': u'بِجَعَالَةٍ', #7
u'بجعرانة': u'بِجِعْرَانَةَ', #1
u'بجعره': u'بِجَعْرِهِ', #2
u'بجعلت': u'بِجَعَلَتْ', #1
u'بجعموسها': u'بِجُعْمُوسِهَا', #3
u'بجفينة': u'بِجُفَيْنَةَ', #1
u'بجكان': u'بجكان', #1
u'بجلا': u'بَجْلًا', #1
u'بجلاب': u'بِجَلَّابٍ', #1
u'بجلاجل': u'بِجَلَاجِلَ', #5
u'بجلالى': u'بِجَلاَلِى', #2
u'بجلبابى': u'بِجِلْبَابِى', #1
u'بجلس': u'بِجَلَسَ', #3
u'بجلوبة': u'بِجَلُوبَةٍ', #2
u'بجلولاء،': u'بجَلُولاء،', #1
u'بجلوى': u'بِجَلْوَى', #1
u'بجمارة': u'بِجُمَّارَةٍ', #1
u'بجمهان': u'بِجُمْهَانَ', #1
u'بجنا': u'بِجَنَا', #1
u'بجنازتى': u'بِجَنَازَتِى', #2
u'بجنبتى': u'بِجَنَبَتَىِ', #1
u'بجنجروذ': u'بِجَنْجَرُّوذَ', #1
u'بجنديسابور،': u'بِجَنَدْيَسَابُورَ،', #1
u'بجنديسابور،': u'بِجُنْدِيسَابُورَ،', #2
u'بجنيبة': u'بِجَنِيبَةٍ', #1
u'بجه': u'بجه', #1
u'بجه': u'بَجّه', #5
u'بجهتا': u'بِجِهَتَا', #2
u'بجهني': u'بِجُهَنِيٍّ', #1
u'بجواثا': u'بِجَوَاثَا', #1
u'بجواثا': u'بِجُوَاثَا', #8
u'بجواثاء': u'بجواثاء', #2
u'بجؤاثى': u'بِجُؤَاثَى', #1
u'بجواثى': u'بجواثى', #1
u'بجواثى': u'بِجُوَاثَى', #9
u'بجوارش': u'بِجَوَارِشَ', #1
u'بجوارش': u'بِجُوَارِشٍ', #1
u'بجوبان': u'بجوبان', #1
u'بجوى': u'بِجَوًى', #1
u'بجويبر': u'بِجُوَيْبِرٍ', #1
u'بجويرية': u'بجويرية', #1
u'بجويرية': u'بِجِوَيْرِيَةَ', #1
u'بجويرية': u'بِجُوَيْرِيَةَ', #2
u'بجيادة': u'بِجِيَادَةِ', #1
u'بجيان': u'بِجَيَّانَ', #2
u'بجيدر': u'بِجَيْدَرٍ', #2
u'بجيرا': u'بجيرا', #1
u'بجيرا': u'بُجَيْرًا', #13
u'بجيرمي': u'بُجَيْرِمِيُّ', #16
u'بجيرمي': u'بُجَيْرِمِيِّ', #2
u'بجيرمي': u'بُجَيْرِمِيٌّ', #992
u'بجيرود': u'بِجَيْرُودَ', #1
u'بجيس': u'بُجَيْسُ', #1
u'بجيلة': u'بجيلة', #1
u'بجيلة': u'بَجِيلَةٌ', #1
u'بجيلة': u'بَجِيلَةٍ', #1
u'بجيلة': u'بُجَيْلَةُ', #1
u'بجيلة': u'بَجِيلَة', #2
u'بجيلة،': u'بَجِيلَةَ،', #3
u'بجيلة': u'بُجَيْلَةَ', #3
u'بجيلة': u'بَجِيلَةُ', #6
u'بجيلة': u'بَجِيلَةَ', #60
u'بجيلتان': u'بَجِيلَتَانِ', #1
u'بجيه': u'بجيه', #1
u'بحاجتى': u'بِحَاجَتِى', #1
u'بحاشا': u'بِحَاشَا', #1
u'بحاضرا': u'بِحَاضِرًا', #2
u'بحاملى': u'بِحَامِلِى', #1
u'بحبحة': u'بَحْبَحَةَ', #2
u'بحبحه': u'بَحْبَحَهُ', #1
u'بحبست': u'بِحَبَسْت', #2
u'بحبست': u'بِحُبِسَتْ', #3
u'بحبست': u'بِحَبَسْتُ', #6
u'بحبلان': u'بِحَبْلَانِ', #1
u'بحبلت': u'بِحَبِلَتْ', #2
u'بحتره': u'بِحِتْرِهِ', #1
u'بحتى': u'بِحَتَّى', #25
u'بحثتقوله': u'بُحِثَتْقَوْلُهُ', #1
u'بحجات': u'بِحَجَّاتٍ', #1
u'بحجبت': u'بِحُجِبَتْ', #1
u'بحجة': u'بِحُجَّةً', #1
u'بحجتى': u'بِحَجَّتِى', #1
u'بحجتى؟': u'بِحَجَّتِى؟', #1
u'بحجفة': u'بِحِجْفَةٍ', #1
u'بحجفة': u'بِحَجَفَةٍ', #2
u'بحجفته': u'بِحَجَفَتِهِ', #1
u'بحجين': u'بِحَجَّيْنِ', #1
u'بحدثان': u'بَحَدَثَانِ', #1
u'بحدثان': u'بِحَدَثَانٍ', #1
u'بحدثان': u'بِحِدْثَانٍ', #1
u'بحدثان': u'بِحَدَثَانِ', #18
u'بحدثان': u'بِحِدْثَانِ', #35
u'بحدثانه': u'بِحَدَثَانِهِ', #3
u'بحدثانه': u'بِحِدْثَانِهِ', #7
u'بحدثني': u'بِحَدَّثَنِي', #1
u'بحدل': u'بَحْدَلِ', #1
u'بحدل،': u'بَحْدَلٍ،', #3
u'بحدل': u'بَحْدَلٍ', #5
u'بحدلية': u'بَحْدَلِيَّةٌ', #1
u'بحدهاى': u'بحدهاى', #1
u'بحدوا': u'بِحَدُّوا', #1
u'بحدودهاى': u'بحدودهاى', #1
u'بحديثى': u'بِحَدِيثِى', #3
u'بحديثيحيى': u'بِحَدِيثِيَحْيَى', #1
u'بحديقتى': u'بِحَدِيقَتِى', #2
u'بحذاها': u'بِحِذَاهَا', #1
u'بحراء،': u'بِحِرَاءَ،', #1
u'بحراء': u'بِحِرَاءٍ', #10
u'بحراء': u'بِحِرَاءَ', #12
u'بحراء': u'بِحِرَاءِ', #2
u'بحراقه': u'بِحُرَاقِهِ', #1
u'بحرت': u'بَحَرْت', #3
u'بحرر': u'بِحَرِرٍ', #1
u'بحرمت': u'بحرمت', #1
u'بحروثنا': u'بِحُرُوثِنَا', #1
u'بحروراء': u'بحَرُوراء', #1
u'بحروراء': u'بِحَرُورَاءَ', #3
u'بحرى': u'بِحِرَى', #1
u'بحرى': u'بِحَرّى', #2
u'بحزء': u'بِحَزْءِ', #1
u'بحزج': u'بحزج', #1
u'بحزج': u'بَحْزَجٌ', #2
u'بحزج': u'بَحْزَجُ', #2
u'بحزوى': u'بِحُزْوَى', #2
u'بحسة': u'بَحْسَةُ', #1
u'بحسما': u'بِحَسْمًا', #1
u'بحسمى،': u'بحِسْمى،', #1
u'بحسمى،': u'بَحَسْمَى،', #1
u'بحسمى': u'بِحِسْمَى', #2
u'بحسين': u'بِحُسَيْنِ', #3
u'بحشل،': u'بحشل،', #1
u'بحشل': u'بِحَشَلَ', #1
u'بحشل': u'بَحْشَلٌ', #2
u'بحشل،': u'بَحْشَلٌ،', #4
u'بحصلا': u'بِحَصَلَا', #1
u'بحصوص': u'بِحُصُوصٍ', #1
u'بحصى': u'بِحَصًى', #10
u'بحضوضى': u'بِحَضَوْضَى', #1
u'بحضير': u'بِحَضِيرٍ', #1
u'بحظير': u'بِحَظِيرٍ', #1
u'بحفش': u'بِحَفْشِ', #1
u'بحقا': u'بِحَقًّا', #1
u'بحقيته': u'بِحَقِّيَّتِهِ', #1
u'بحكرة': u'بِحُكْرَةِ', #1
u'بحكرة': u'بِحُكْرَةٍ', #2
u'بحكمت': u'بِحَكَّمَتْ', #1
u'بحلابى': u'بِحِلاَبِى', #1
u'بحلام': u'بِحُلَّامٍ', #1
u'بحلان': u'بِحُلَّانِ', #2
u'بحلان': u'بِحُلاَّنِ', #2
u'بحلفت': u'بِحَلَفْتُ', #1
u'بحلقتى': u'بِحَلَقَتَىِ', #1
u'بحمران،': u'بِحُمْرَانَ،', #1
u'بحمرةوالوجه': u'بِحُمْرَةٍوَالْوَجْهُ', #1
u'بحمنة': u'بِحَمْنَةَ', #1
u'بحمى': u'بِحِمًى', #2
u'بحميت': u'بِحَمِيتٍ', #1
u'بحميت': u'بِحَمِيتِ', #1
u'بحناتم': u'بِحَنَاتِمِ', #1
u'بحنس': u'بحنس', #1
u'بحنسه': u'بِحَنْسِهِ', #1
u'بحولان': u'بِحَوَلَانِ', #5
u'بحولايا،': u'بِحَوْلايَا،', #1
u'بحى': u'بِحَىٍّ', #7
u'بحيالة': u'بحيالة', #1
u'بحيثما': u'بِحَيْثُمَا', #1
u'بحيدرة': u'بِحَيْدَرَةَ', #4
u'بحيرا،': u'بَحِيرًا،', #1
u'بحيرا،': u'بَحِيرَا،', #1
u'بحيرا': u'بُحَيْرًا', #1
u'بحيرا،': u'بُحَيْرًا،', #1
u'بحيرا': u'بُحَيْرَا', #2
u'بحيرا': u'بَحِيرًا', #3
u'بحيرا': u'بَحِيرَا', #6
u'بحيس': u'بِحَيْسٍ', #4
u'بحيسة': u'بِحَيْسَةٍ', #4
u'بحيفاء': u'بِحَيْفَاءَ', #5
u'بحيلت': u'بِحِيلَتْ', #4
u'بحينة': u'بُحَيْنةُ', #1
u'بحينة': u'بُحَيْنَةَ', #103
u'بحينة،': u'بُحَيْنَةَ،', #12
u'بحينة': u'بُحَيْنَةُ', #2
u'بحينة،': u'بحينة،', #4
u'بحينة': u'بحينة', #5
u'بخاتون': u'بِخَاتُونَ', #1
u'بخاتي': u'بَخَاتِيَّ', #1
u'بخاتي': u'بَخَاتِيُّ', #1
u'بخاتي': u'بَخَاتِيٌّ', #3
u'بخاتيا': u'بَخَاتِيًّا', #1
u'بخارص': u'بِخَارِصٍ', #3
u'بخارم': u'بِخَارِمِ', #3
u'بخارى': u'بخارى', #1
u'بخارى،': u'بُخارى،', #1
u'بخارى،': u'بُخَارَى،', #3
u'بخارى': u'بُخَارَى', #378
u'بخاسق': u'بِخَاسِقٍ', #1
u'بخاطمة': u'بِخَاطِمَةٍ', #1
u'بخاطمة': u'بِخَاطِمَةِ', #1
u'بخاطئا': u'بِخَاطِئًا', #1
u'بخاقان': u'بِخَاقَانَ', #1
u'بخالعت': u'بِخَالَعْتُ', #1
u'بخالفت': u'بِخَالَفَتْ', #2
u'بخامسيتها': u'بِخَامِسِيَّتِهَا', #9
u'بخانقاه': u'بِخَانَقَاهُ', #1
u'بخبت': u'بِخَبْتِ', #5
u'بخبرى': u'بِخَبَرِى', #1
u'بخبزة': u'بِخُبْزَةٍ', #1
u'بختجا': u'بختجا', #1
u'بختجا': u'بَخْتَجًا', #1
u'بخترى': u'بَخْتَرِىٍّ', #1
u'بختمة': u'بِخَتْمَةٍ', #1
u'بختنصر؟': u'بختنصر؟', #1
u'بختنصر': u'بُخْتُنَصَّرُ', #1
u'بختنصر': u'بُخْتِنَصَّرُ', #1
u'بختنصر': u'بختنصر', #10
u'بختنصر': u'بُخْتَنَصّرُ', #2
u'بختنصر': u'بُخْتَنَصّرَ', #5
u'بختنصر': u'بُخْتَنَصَّرَ', #6
u'بختنصر،': u'بختنصر،', #8
u'بختيار': u'بُخْتِيَارَ', #1
u'بختيشوع': u'بَخْتَيَشُوعَ', #2
u'بخدا': u'بخدا', #1
u'بخدادرام': u'بخدادرام', #1
u'بخداوند': u'بخداوند', #1
u'بخداى': u'بخداى', #1
u'بخداي': u'بخداي', #12
u'بخدشة': u'بِخَدْشَةٍ', #1
u'بخذف': u'بِخَذْفِ', #1
u'بخرء': u'بِخَرْءِ', #1
u'بخرء': u'بِخُرْءٍ', #1
u'بخرء': u'بِخُرْءِ', #3
u'بخراء': u'بَخْرَاءَ', #1
u'بخراء': u'بَخْرَاءُ', #1
u'بخرات،': u'بَخِرَاتٌ،', #1
u'بخربى': u'بِخُرْبَى', #3
u'بخرسان': u'بِخُرَسَان', #1
u'بخرصان': u'بِخِرْصَانِ', #1
u'بخرعوبة': u'بِخَرْعُوبَةٍ', #1
u'بخرئها': u'بِخَرْئِهَا', #1
u'بخرئها': u'بِخُرْئِهَا', #1
u'بخريداز': u'بخريداز', #1
u'بخريدم': u'بخريدم', #2
u'بخريدن': u'بخريدن', #2
u'بخزام': u'بِخِزَامٍ', #5
u'بخزامة': u'بِخِزَامَةِ', #2
u'بخزامة': u'بِخِزَامَةٍ', #6
u'بخزيمة': u'بِخُزَيْمَةَ', #1
u'بخسروجرد': u'بَخَسْرُوجَرْدَ', #1
u'بخسروجرد': u'بِخَسْرَوجِرْدَ', #1
u'بخسروجرد': u'بِخَسْرُوجِرْدٍ', #1
u'بخسروجرد': u'بِخُسْرَوْجِرْدَ', #7
u'بخسق': u'بِخَسْقٍ', #1
u'بخشكتانكة': u'بخشكتانكة', #1
u'بخشنام': u'بِخُشْنَامَ', #1
u'بخشى': u'بخشى', #1
u'بخشيدم': u'بخشيدم', #5
u'بخشيدن': u'بخشيدن', #1
u'بخشيذم': u'بخشيذم', #1
u'بخصتها': u'بَخْصَتهَا', #1
u'بخصصيته': u'بِخُصُصِيَّتِهِ', #1
u'بخض': u'بِخَضٍّ', #2
u'بخطمى': u'بِخِطْمِىِّ', #1
u'بخطى': u'بِخُطًى', #1
u'بخظ': u'بِخَظٍّ', #1
u'بخع': u'بَخَعَ', #1
u'بخع': u'بَخْعِ', #2
u'بخعت': u'بَخَعْت', #1
u'بخعت': u'بَخَعْتُ', #1
u'بخفرة': u'بِخَفْرَةِ', #1
u'بخفرة': u'بِخُفْرَةِ', #1
u'بخفرته': u'بِخَفْرَتِهِ', #1
u'بخفرتهم': u'بِخُفْرَتِهِمْ', #1
u'بخقت': u'بُخِقَتْ', #1
u'بخلبة،': u'بِخُلْبَةٍ،', #1
u'بخلبة': u'بِخُلْبَةٍ', #4
u'بخلعان': u'بِخُلْعَانِ', #1
u'بخلقان': u'بِخِلْقَانِ', #1
u'بخلقهقوله': u'بِخَلْقِهِقَوْلُهُ', #1
u'بخليت': u'بِخَلَّيْتُ', #6
u'بخليص': u'بِخَلِيصِ', #1
u'بخليص': u'بِخُلَيْصٍ', #1
u'بخليطين': u'بِخَلِيطَيْنِ', #2
u'بخمسمائه': u'بِخَمْسِمِائَه', #1
u'بخمسى': u'بِخُمُسَىْ', #2
u'بخمسينه': u'بِخَمْسِينِهِ', #4
u'بخميصة': u'بِخَمِيصَةَ', #1
u'بخميصة،': u'بِخَمِيْصَةٍ،', #1
u'بخميصة': u'بِخَمِيصَةٍ', #2
u'بخميصتى': u'بِخَمِيصَتِى', #1
u'بخميصتي': u'بِخَمِيصَتِي', #3
u'بخميصتين': u'بِخَمِيصَتَيْنِ', #2
u'بخناصرة': u'بِخَنَاصِرَةَ', #1
u'بخناطيل': u'بِخَنَاطِيلَ', #2
u'بخنبقاته': u'بخنبقاته', #2
u'بخنجا': u'بخنجا', #1
u'بخنداة': u'بَخَنْدَاةً', #1
u'بخنداة': u'بَخَنْدَاةٍ', #1
u'بخنداة': u'بَخَنْدَاةَ', #1
u'بخندفا': u'بِخِنْدِفَا', #1
u'بخندقا': u'بِخَنْدَقَا', #1
u'بخواريز': u'بخواريز', #1
u'بخواهر': u'بِخُوَاهَرْ', #81
u'بخواهر': u'بخواهر', #9
u'بخواهند': u'بخواهند', #1
u'بخواهي': u'بخواهي', #2
u'بخوردن': u'بخوردن', #1
u'بخورى': u'بخورى', #1
u'بخوصتي': u'بِخُوصَتَيْ', #2
u'بخوصتين': u'بِخُوصَتَيْنِ', #2
u'بخويصة': u'بِخُوَيْصَةِ', #2
u'بخيبر': u'بِخَيْبَر', #1
u'بخيبر،': u'بِخَيْبَرَ،', #10
u'بخيبر': u'بخيبر', #2
u'بخيبر،': u'بخيبر،', #2
u'بخيبر': u'بِخَيْبَرَ', #270
u'بخيبر': u'بِخَيْبَرِ', #48
u'بخيبر': u'بِخَيْبَرٍ', #5
u'بخيبرفقلت': u'بخيبرفَقُلت', #1
u'بخية': u'بِخِيَّةٍ', #3
u'بخية': u'بَخِّيَّةً', #5
u'بخية': u'بَخِّيَّةٍ', #8
u'بخيرت': u'بِخُيِّرَتْ', #1
u'بدء': u'بَدْءً', #2
u'بدءوا': u'بَدَءُوا', #45
u'بدءوكم': u'بَدَءُوكُمْ', #6
u'بدءونا': u'بَدَءُونَا', #4
u'بدءوه': u'بَدَءُوهُ', #4
u'بدأ': u'بَدْأً', #1
u'بداء': u'بَدَاءً', #6
u'بدأبالخطبة': u'بَدَأَبِالْخُطْبَةِ', #1
u'بداد': u'بَدَادٌ', #1
u'بداد': u'بَدَادُ', #1
u'بداد': u'بَدَادِ', #4
u'بدارا،': u'بِدَارًا،', #1
u'بدارا': u'بِدَارًا', #2
u'بدارا': u'بِدَارَا', #2
u'بدارصيني': u'بِدَارَصِينِيٍّ', #1
u'بدارصيني': u'بِدَارَصِينِيِّ', #1
u'بدارههم': u'بِدَارِهِهِمْ', #1
u'بداريا': u'بداريّا', #1
u'بداريا،': u'بداريّا،', #1
u'بداريا،': u'بداريَّا،', #1
u'بداعة': u'بَدَاعَةً', #2
u'بدامنت': u'بدامنت', #1
u'بداند': u'بداند', #1
u'بدانق': u'بِدَانَقٍ', #21
u'بدانق': u'بِدَانِقٍ', #22
u'بدانق': u'بِدَانَقِ', #4
u'بدانق': u'بِدَانِقِ', #5
u'بدانقين': u'بِدَانِقَيْنِ', #10
u'بدانقين': u'بِدَانَقَيْنِ', #7
u'بدانيال': u'بِدَانْيَالَ', #3
u'بدأوا': u'بدأوا', #1
u'بدأونا': u'بَدَأُونَا', #1
u'بدائما': u'بِدَائِمًا', #1
u'بدباء': u'بِدُبَّاءٍ', #1
u'بدبختي': u'بدبختي', #1
u'بدبرت': u'بِدَبَّرْتُ', #2
u'بدتر': u'بدتر', #3
u'بدتراست': u'بدتراست', #1
u'بدجيل': u'بِدُجَيْلٍ', #1
u'بدحناء': u'بِدَحْنَاءِ', #1
u'بدحية': u'بِدِحْيَةَ', #2
u'بدخلت': u'بِدَخَلَت', #1
u'بدخلت': u'بِدَخَلْتِ', #2
u'بدخلت': u'بِدَخَلْت', #3
u'بدخوى': u'بدخوى', #1
u'بدخيس': u'بِدَخِيسِ', #2
u'بدرSذكر': u'بَدْرٍSذِكْرُ', #1
u'بدر': u'بدْرً', #1
u'بدرأبو': u'بَدْرٍأَبُو', #1
u'بدرازروى': u'بدرازروى', #1
u'بدرالقتال': u'بَدْرَالْقِتَالِ', #1
u'بدرالقتال': u'بَدْرُالْقِتَالِ', #1
u'بدرالموعد': u'بَدْرَالْمَوْعِدَ', #1
u'بدرامع': u'بَدْرًامَعَ', #1
u'بدرامن': u'بَدْرًامِنْ', #1
u'بدراولم': u'بَدْرًاوَلَمْ', #1
u'بدربدانكه': u'بدربدانكه', #1
u'بدرة': u'بَدْرَةً', #3
u'بدرتو': u'بدرتو', #1
u'بدرجة': u'بِدَرَجَةً', #1
u'بدرسيد': u'بدرسيد', #1
u'بدرضرب': u'بَدْرٍضَرَبَ', #1
u'بدرعباد': u'بَدْرٍعَبَّادُ', #1
u'بدرعلى': u'بَدْرٍعَلَى', #2
u'بدرعم': u'بِدِرْعَمَ', #2
u'بدرفرجعت': u'بَدْرٍفَرَجَعْت', #1
u'بدرفي': u'بَدْرٍفِي', #2
u'بدرما': u'بَدْرٍمَا', #1
u'بدرنوك': u'بدرنوك', #1
u'بدرهما': u'بِدِرْهَمًا', #1
u'بدرو': u'بدرو', #1
u'بدروروي': u'بَدْرٍوَرُوِيَ', #1
u'بدروغ': u'بدروغ', #1
u'بدرويشان': u'بدرويشان', #1
u'بدرى': u'بَدْرِىٍّ', #4
u'بدريشان': u'بدريشان', #2
u'بدريون': u'بَدْرِيّونَ', #2
u'بدستار': u'بِدِسْتَارِ', #1
u'بدسومة': u'بِدُسُومَةٍ', #1
u'بدسومته': u'بِدُسُومَتِهِ', #1
u'بدفعا': u'بِدَفْعًا', #2
u'بدقوقا': u'بِدَقُوقَا', #1
u'بدقوقاء': u'بِدَقُوقَاءَ', #1
u'بدلاصطدت': u'بَدَّلَاصْطَدْتُ', #1
u'بدلوكا': u'بِدَلُوكَا', #1
u'بدليته': u'بَدَلِيَّتُهُ', #1
u'بدليته': u'بَدَلِيَّتِهِ', #3
u'بدليتها': u'بَدَلِيَّتَهَا', #1
u'بدليتها': u'بَدَلِيَّتِهَا', #2
u'بدليلأن': u'بِدَلِيلِأَنَّ', #1
u'بدمنهور': u'بِدَمَنْهُورَ', #1
u'بدمياط': u'بِدِمْيَاطَ', #5
u'بدها': u'بَدْهًا', #1
u'بدهد': u'بدهد', #1
u'بدهند': u'بدهند', #2
u'بدهه': u'بَدَهَهُ', #1
u'بدوحات': u'بِدَوْحَاتٍ', #1
u'بدوز': u'بدوز', #2
u'بدوزش': u'بدوزش', #2
u'بدوما': u'بدوما', #1
u'بدومة': u'بدُوَمة', #1
u'بدومة': u'بدُومَة', #1
u'بدومة': u'بدومة', #2
u'بدومة': u'بِدَوْمَةِ', #2
u'بدومة': u'بِدُومَةِ', #7
u'بدومى': u'بدُومى', #1
u'بدومى': u'بِدُومَى', #1
u'بدويد': u'بدويد', #1
u'بدويرة': u'بِدُوَيْرَةِ', #1
u'بدى': u'بدى', #2
u'بديء': u'بُديء', #1
u'بديء': u'بُدِيء', #1
u'بدىء': u'بُدِىءَ', #1
u'بدئني': u'بَدِّئْنِي', #1
u'بديا': u'بَدَيَا', #1
u'بديا': u'بَدِيًّا', #3
u'بدياسة': u'بِدِيَاسَةٍ', #1
u'بديعية': u'بَدِيعِيَّةٌ', #1
u'بديعية': u'بَدِيعِيَّةٍ', #1
u'بدينى': u'بِدِينِى', #2
u'بذ': u'بذَّ', #1
u'بذ': u'بَذَ', #1
u'بذ': u'بَذُّ', #1
u'بذ': u'بَذّ', #2
u'بذا': u'بَذًا', #1
u'بذاذة': u'بَذَاذَةً', #1
u'بذاذة': u'بَذَاذَةَ', #2
u'بذاذة': u'بَذَاذَةِ', #2
u'بذاكرا': u'بِذَاكِرًا', #1
u'بذاها': u'بَذَاهَا', #1
u'بذبذبه': u'بِذَبْذَبِهِ', #1
u'بذبرفثم': u'بذبرفثم', #1
u'بذة': u'بَذَّةٍ', #12
u'بذة': u'بَذَّة', #2
u'بذت': u'بَذَّتْ', #1
u'بذت': u'بَذَتْ', #7
u'بذج': u'بَذَجٌ', #1
u'بذج،': u'بَذَجٌ،', #1
u'بذحل': u'بِذَحْلٍ', #2
u'بذحل': u'بِذَحْلِ', #7
u'بذحول': u'بِذُحُولٍ', #1
u'بذحول': u'بِذُحُولِ', #4
u'بذخل': u'بِذَخْلٍ', #1
u'بذدذبه': u'بذدذبه', #1
u'بذرارى': u'بِذَرَارِىِّ', #1
u'بذريرة': u'بِذَرِيرَةٍ', #12
u'بذفر': u'بِذَفَرِ', #1
u'بذكارة': u'بِذِكَارَةِ', #2
u'بذكرالله': u'بِذِكْرِاللَّهِ', #1
u'بذكرناه': u'بِذَكَرْنَاهُ', #1
u'بذكوان': u'بِذَكْوَانَ', #1
u'بذكوان': u'بِذَكْوَانِ', #1
u'بذكوريته': u'بِذُكُورِيَّتِهِ', #2
u'بذلتكه': u'بَذَلْتَكَهُ', #1
u'بذلكا': u'بِذَلِكَا', #1
u'بذلكاليهود': u'بِذَلِكَالْيَهُودَ', #1
u'بذلكأهل': u'بِذَلِكَأَهْلَ', #1
u'بذلكرسول': u'بِذَلِكَرَسُولُ', #1
u'بذلكقالت': u'بِذَلِكَقَالَتْ', #1
u'بذلكقوله': u'بِذَلِكَقَولُهُ', #1
u'بذمتى': u'بِذِمَّتِى', #1
u'بذمرا': u'بذمرا', #1
u'بذناب': u'بِذِنَابِ', #2
u'بذنبى': u'بِذَنْبِى', #3
u'بذهبا': u'بِذَهَبًا', #1
u'بذهم': u'بذَّهُم', #1
u'بذو': u'بِذُو', #1
u'بذو': u'بَذُوَ', #2
u'بذوا': u'بَذْوًا', #1
u'بذؤاب': u'بِذُؤَابٍ', #1
u'بذوت': u'بَذَوْت', #1
u'بذوت': u'بَذَوْتُ', #1
u'بذى': u'بِذِى', #78
u'بذيا': u'بَذِيًّا', #5
u'بذية': u'بَذِيَّةٌ', #1
u'بذية': u'بَذِيَّةً', #2
u'بذية': u'بَذِيَّةَ', #9
u'بذير': u'بذير', #12
u'بذيرفتم': u'بذيرفتم', #7
u'بذيرفثم': u'بذيرفثم', #2
u'بذيرم': u'بذيرم', #1
u'بذيرى': u'بذيرى', #1
u'بذيعة،': u'بَذِيعةَ،', #1
u'بذيعة،': u'بَذِيعَةَ،', #2
u'بذيمة،': u'بذيمة،', #1
u'بذيمة،': u'بَذِيمَةَ،', #12
u'بذيمة': u'بَذِيمَةَ', #18
u'بذيها': u'بذيها', #1
u'برءاء': u'بُرَءَاءُ', #1
u'برءوا': u'بَرَّءُوا', #1
u'برءوا': u'بَرِءُوا', #2
u'برءوا': u'بَرَءُوا', #4
u'برءوس': u'بِرُءُوسَ', #1
u'برءوس': u'بِرُءُوسٍ', #13
u'برءوس': u'بِرُءُوسِ', #55
u'برءوسا': u'بِرُءُوسًا', #3
u'برءوسكم': u'بِرُءُوسِكُمْ', #77
u'برءوسنا': u'بِرُءُوسِنَا', #1
u'برءوسه': u'بِرُءُوسِهِ', #3
u'برءوسها': u'بِرُءُوسِهَا', #5
u'برءوسهم': u'بِرُءُوسِهِمُ', #1
u'برءوسهم': u'بِرُءُوسِهِمْ', #16
u'برءوسهما': u'بِرُءُوسِهِمَا', #3
u'برءوه': u'بَرَّءُوهُ', #1
u'برآء': u'بَرَآء', #1
u'برآء،': u'بُرَآءُ،', #1
u'برآء': u'بُرَآءٌ', #2
u'برآء': u'بُرَآءَ', #2
u'برآء': u'بُرَآءُ', #43
u'براءتى': u'بَرَاءَتِى', #3
u'برابغ': u'بِرَابِغَ', #1
u'برابغ': u'بِرَابِغٍ', #6
u'برابه': u'بِرَابِّهِ', #1
u'برابها': u'برابها', #1
u'برابها': u'بِرَابِهَا', #1
u'براجحية': u'بِرَاجِحِيَّةٍ', #9
u'براجعت': u'بِرَاجَعْتُ', #2
u'برادران': u'برادران', #1
u'براذان': u'براذان', #1
u'براذان؟': u'براذان؟', #1
u'براذان،': u'بِرَاذَانَ،', #1
u'براذان': u'بِرَاذَانَ', #3
u'براذران': u'براذران', #1
u'براذع': u'بَرَاذِعَ', #1
u'برازقيين': u'بِرَازِقِيَّيْنِ', #1
u'برأسى': u'بِرَأْسِى', #4
u'براشته': u'برَاشَتُهُ', #1
u'براعى': u'بِرَاعِى', #8
u'برافعا': u'بِرَافِعًا', #1
u'براكعا': u'بِرَاكِعًا', #1
u'برال': u'برال', #1
u'برآمن': u'برآمن', #2
u'برامهرمز': u'بِرَامَهُرْمُزَ', #2
u'برانكه': u'برانكه', #1
u'براهط،': u'بِرَاهِطٍ،', #1
u'برأوا': u'بِرَأَوْا', #1
u'برائيك': u'بِرَائِيك', #1
u'براية': u'بُرَايَةً', #1
u'برأيت': u'بِرَأَيْت', #1
u'برأيت': u'بِرَأَيْتُ', #1
u'برأيتها': u'بِرَأَيْتُهَا', #1
u'براينهانهم': u'براينهانهم', #1
u'برأيى': u'بِرَأَيِى', #3
u'برأيى': u'بِرَأْيِى', #3
u'بربا': u'بِرِبًا', #28
u'برباريس': u'برباريس', #1
u'بربطا': u'بَرْبَطًا', #12
u'بربن': u'بربن', #1
u'بربويته': u'بِرِبَوِيَّتِهِ', #2
u'بربويتها': u'بِرِبَوِيَّتِهَا', #1
u'برتست': u'برتست', #2
u'برتقاء': u'بِرَتْقَاءَ', #2
u'برتوباد': u'برتوباد', #1
u'برتوة': u'بِرَتْوَةٍ', #1
u'برتوستم': u'برتوستم', #1
u'برتوكفر': u'برتوكفر', #1
u'برتونه': u'برتونه', #1
u'برثملي': u'بَرْثُمْلِي', #2
u'برجاست': u'برجاست', #2
u'برجح': u'بِرَجَّحَ', #1
u'برجح': u'بِرَجْحٍ', #2
u'برجح': u'بِرَجَحَ', #4
u'برجحانيته': u'بِرُجْحَانِيَّتِهِ', #1
u'برجحه': u'بِرَجَّحَهُ', #1
u'برجعا': u'بِرَجَعَا', #2
u'برجعت': u'بِرَجَعَتْ', #1
u'برجعت': u'بِرَجَعْتُ', #4
u'برجعت': u'بِرَجَعْت', #7
u'برجعوا': u'بِرَجَعُوا', #1
u'برجلى': u'بِرِجْلِى', #1
u'برجندي': u'بُرْجُنْدِيٌّ', #12
u'برحاء': u'بَرْحَاءُ', #1
u'برحاء': u'بُرَحَاءُ', #1
u'برحاء': u'بُرَحَاءِ', #1
u'برحق': u'برحق', #1
u'برحمانيته': u'بِرَحْمَانِيَّتِهِ', #3
u'برحى': u'بِرَحًى', #3
u'برخر': u'برخر', #1
u'برخصيتها': u'بِرُخْصِيَّتِهَا', #1
u'برخواند': u'برخواند', #1
u'برخيا': u'برخيا', #1
u'برخيا،': u'بَرْخِيَا،', #1
u'برخيا': u'بَرْخِيَا', #2
u'برخيز': u'برخيز', #2
u'برد': u'بَرْدً', #1
u'برداردش': u'برداردش', #1
u'بردارم': u'بردارم', #1
u'برداشتي': u'برداشتي', #1
u'بردانا': u'بَرْدَانًا', #2
u'بردائى': u'بِرِدَائِى', #2
u'بردتى': u'بُرْدَتِى', #1
u'بردزبه': u'بردزبه', #1
u'بردزية': u'بَرْدَزِيَّةَ', #1
u'بردس': u'بِرَدْسٍ', #1
u'بردست': u'بردست', #3
u'بردل': u'بردل', #1
u'بردمان': u'بِرَدْمَانَ', #11
u'بردند': u'بردند', #1
u'بردو': u'بردو', #1
u'بردوبر': u'بردوبر', #1
u'بردوتستر': u'بردوتستر', #1
u'بردوشما': u'بردوشما', #1
u'برذغة،': u'بَرْذَغَةَ،', #1
u'برذونك': u'بِرْذَوْنَك', #1
u'برذونك': u'بِرْذَوْنُك', #1
u'بررضوان': u'بررضوان', #1
u'برزجمهر': u'بَرْزُجُمَهْرٍ', #1
u'برزلي': u'بَرْزَلِيٌّ', #1
u'برزلي': u'بُرْزُلِيٌّ', #1
u'برسانيدن': u'برسانيدن', #1
u'برسباي': u'بَرْسَبَاي', #1
u'برسباي': u'بِرِسْبَاي', #1
u'برسباي': u'بِرِسْبَايْ', #1
u'برسباي': u'بِرْسِبَايْ', #2
u'برست': u'برست', #1
u'برستاقي': u'بِرُسْتَاقِيٍّ', #1
u'برستند': u'برستند', #3
u'برستيدن': u'برستيدن', #1
u'برسر': u'برسر', #6
u'برسراس': u'بِرَسْرَاسٍ', #2
u'برسلى': u'بِرُسُلِى', #1
u'برسند': u'برسند', #1
u'برسولى': u'بِرَسُولِى', #1
u'برشداء': u'بِرُشَدَاءَ', #2
u'برشدين': u'بِرُشْدَيْنِ', #1
u'برشدين': u'بِرِشْدِينِ', #2
u'برشكاب': u'برشكاب', #1
u'برشيدا': u'بِرَشِيدًا', #2
u'برصيصا': u'بَرْصِيصَا', #1
u'برصيصا': u'بِرْصِيصَا', #1
u'برضا': u'بِرِضًا', #90
u'برضاى': u'بِرِضَاىَ', #1
u'برضم': u'بِرَضْمٍ', #2
u'برضوى': u'بِرَضْوَى', #1
u'برضى': u'بِرِضًى', #9
u'برضيت': u'بِرَضِيتُ', #1
u'برضيت': u'بِرَضِيتْ', #1
u'برضيخ': u'بِرَضِيخِ', #1
u'برطبا': u'بِرَطْبًا', #2
u'برعاث': u'بِرِعَاثٍ', #1
u'برغالي': u'بَرْغَالِيٍّ', #1
u'برغند': u'برغند', #1
u'برغوثة': u'بُرْغُوثَةٌ', #3
u'برفعت': u'بِرَفَعَتْ', #2
u'برقة': u'بَرْقَةً', #4
u'برقوم': u'بِرُقُوم', #1
u'برقومه': u'بِرُقُومِهِ', #1
u'برقومها': u'بِرُقُومِهَا', #2
u'بركاز': u'بِرِكَازٍ', #26
u'بركبان': u'بِرُكْبَانٍ', #1
u'بركبانها': u'بِرُكْبَانِهَا', #2
u'بركبتى': u'بِرُكْبَتَىْ', #1
u'بركرجة': u'بركرجة', #1
u'بركره': u'بركره', #1
u'بركست': u'بركست', #1
u'بركست،': u'بركست،', #1
u'بركعتى': u'بِرَكْعَتَىِ', #2
u'بركند': u'بركند', #3
u'بركنيته': u'بِرُكْنِيَّتِهِ', #4
u'بركنيتها': u'بِرُكْنِيَّتِهَا', #10
u'بركواهي': u'بركواهي', #2
u'برلسي': u'بُرُلُّسِيٌّ', #48
u'برلسيا': u'بُرُلُّسِيًّا', #3
u'برمانداب': u'برمانداب', #1
u'برماوي': u'بَرْمَاوِيٌّ', #18
u'برماوي': u'بِرْمَاوِيٍّ', #2
u'برماوي': u'بِرْمَاوِيٌّ', #314
u'برماوي': u'بِرْمَاوِيُّ', #5
u'برمحى': u'بِرُمْحِى', #3
u'برمكة': u'بِرَمَكَةٍ', #2
u'برمنست': u'برمنست', #1
u'برمهات': u'بَرَمْهَاتُ', #1
u'برمهات': u'بَرَمْهَاتْ', #1
u'برمهات': u'بَرْمَهَاتْ', #1
u'برمهات': u'بَرَمْهَاتَ', #2
u'برمودة': u'بَرْمُودَةَ', #1
u'برمودة': u'بَرْمُودَةُ', #1
u'برموده': u'بَرْمُودَهْ', #1
u'برمى': u'بِرَمْىٍ', #1
u'برمى': u'بِرَمْىِ', #1
u'برميلة': u'بِرُمَيْلَةِ', #1
u'برنار': u'برنار', #1
u'برنجانيدى': u'برنجانيدى', #1
u'برند،': u'بَرَنْدٍ،', #1
u'برنشت': u'برنشت', #1
u'برننشيند': u'برننشيند', #1
u'برنى': u'بَرْنِىٍّ', #1
u'برهاط': u'بُرْهَاطُ', #1
u'برهاط': u'بِرُهَاطٍ', #2
u'برهام': u'بِرْهامٍ', #1
u'برهام': u'بَرْهَامَ', #1
u'برهام': u'بَرْهَامٍ', #2
u'برهام': u'بُرْهَامٌ', #3
u'برهج': u'بِرَهْجٍ', #2
u'برهمان': u'برهمان', #1
u'برهنا': u'بِرَهْنًا', #1
u'برهنيته': u'بِرَهْنِيَّتِهِ', #4
u'برهنيتها': u'بِرَهْنِيَّتِهَا', #4
u'برهنيتهما': u'بِرَهْنِيَّتِهِمَا', #1
u'برهوان': u'برهوان', #1
u'برهوت': u'بَرَهُوتَ', #18
u'برهوت،': u'بَرْهُوتُ،', #2
u'برهوت': u'بَرَهُوتُ', #9
u'برو': u'برو', #1
u'برو': u'بُرَوٌ', #1
u'برو': u'بَرْو', #4
u'برؤا': u'بَرُؤَا', #1
u'بروآب': u'بروآب', #1
u'بروتووبر': u'بروتووبر', #1
u'بروثة': u'بِرَوْثَةٍ', #7
u'برودبيد': u'برودبيد', #1
u'برودس': u'بِرُودِسَ', #3
u'برودس،فمروا': u'برودس،فمروا', #1
u'بروذس': u'بِرُوذَسَ', #1
u'برؤسكم': u'بِرُؤْسِكُمْ', #1
u'برؤسهم': u'بِرُؤْسِهِمْ', #1
u'برؤسهم': u'بِرُؤُسِهِمْ', #3
u'بروشن': u'بِرَوْشَنٍ', #5
u'برومة': u'بِرُومَةَ', #6
u'بروى': u'بِرِوَى', #1
u'بروى': u'بروى', #11
u'برويدا': u'بِرُوَيْدًا', #1
u'برويز': u'بَرَوِيز', #1
u'برويشد': u'بِرُوَيْشِدٍ', #5
u'برىء': u'بَرِىءٌ', #29
u'برئا': u'بُرْئًا', #1
u'برئان': u'بَرِئَانِ', #1
u'بريأ': u'بريأ', #1
u'بريالات': u'بِرِيَالَاتٍ', #1
u'بريحا': u'بَرِيحَا', #3
u'بريحاء': u'بَرِيحَاءَ', #1
u'بريدة': u'بُريدة', #1
u'بريدة،': u'بُريدة،', #1
u'بريدة': u'بُرَيدة', #1
u'بريدة،': u'بُريْدة،', #1
u'بريدة،': u'بُرَيدَةُ،', #1
u'بريدة': u'بُرَيْدَةِ', #1
u'بريدة،': u'بريدة،', #11
u'بريدة،': u'بُرَيْدَةَ،', #197
u'بريدة': u'بُرَيْدة', #3
u'بريدة،': u'بُرَيْدة،', #4
u'بريدة،': u'بُرَيْدَةُ،', #5
u'بريدة': u'بريدة', #7
u'بريدة': u'بُرَيْدَةُ', #77
u'بريدة': u'بُرَيْدَة', #8
u'بريدة': u'بُرَيْدَةَ', #888
u'بريدة،قوله': u'بُرَيْدَةَ،قَوْلُهُ', #1
u'برير': u'بَرِيرٌ', #1
u'برير': u'بَرِيرُ', #2
u'برير': u'برير', #3
u'برير': u'بُرَيْرُ', #3
u'بريرا': u'بَرِيرًا', #1
u'بريرة': u'بريرة', #1
u'بريرة': u'بَرِيرَةٍ', #1
u'بريرة،': u'بُرَيْرَةَ،', #1
u'بريرة،': u'بَرِيرَةَ،', #11
u'بريرة،': u'بَرِيرَةُ،', #2
u'بريرة': u'بَرِيرَة', #3
u'بريرة': u'بَرِيرَةَ', #408
u'بريرة': u'بَرِيرَةُ', #84
u'بريزد': u'بريزد', #1
u'بريشوى': u'بريشوى', #1
u'بريصة': u'بُرَيْصَةٍ', #1
u'بريطة': u'بِرَيْطَةَ', #4
u'بريطتين': u'بِرَيْطَتَيْنِ', #1
u'بريعا': u'بَرِيعًا', #1
u'بريمان': u'بَرِيمَانِ', #1
u'بريهة': u'بُرَيْهَةَ', #1
u'بريهة': u'بُرَيْهَةُ', #1
u'بريهنة': u'بُرَيْهِنَةَ', #2
u'بزا': u'بَزًّا', #43
u'بزاءين': u'بِزَاءَيْنِ', #4
u'بزاخة': u'بُزَاخَةٍ', #1
u'بزاخة': u'بُزَاخَةُ', #1
u'بزاخة،': u'بُزَاخَةَ،', #1
u'بزاخة': u'بُزَاخَةَ', #12
u'بزاع': u'بَزَّاعٍ', #1
u'بزاقرت': u'بِزَاقَرْت', #1
u'بزبرة': u'بِزُبْرَةِ', #1
u'بزبم': u'بزبم', #1
u'بزبيد': u'بِزُبَيْدٍ', #4
u'بزبيد': u'بِزَبِيدَ', #7
u'بزدان': u'بزدان', #1
u'بزدت': u'بِزِدْت', #2
u'بزدهل': u'بزدهل', #1
u'بزدوي': u'بَزْدَوِيٍّ', #1
u'بزدوي': u'بَزْدَوِيٌّ', #2
u'بزرج': u'بَزْرَجٍ', #1
u'بزرج': u'بُزُرْجِ', #1
u'بزرج': u'بُزُرْجَ', #3
u'بزرجمهر': u'بَزَرْجَمْهَر', #1
u'بزرجمهر': u'بَزَرْجَمْهَرَ', #3
u'بزرجمهر': u'بَزَرْجَمْهَرُ', #5
u'بزرجمهر': u'بَزَرْجَمْهَرْ', #6
u'بزركتر': u'بزركتر', #2
u'بزركتراز': u'بزركتراز', #1
u'بزركترازين': u'بزركترازين', #1
u'بزركست': u'بزركست', #4
u'بزكرى': u'بزكَرى', #1
u'بزكى': u'بِزَكَّى', #1
u'بزمرت': u'بزمرت', #1
u'بزمستان': u'بزمستان', #1
u'بزمين': u'بزمين', #1
u'بزنا': u'بِزِنًا', #570
u'بزنأت': u'بِزَنَأْتِ', #4
u'بزنى': u'بِزِنًى', #38
u'بزنيات': u'بِزِنْيَاتٍ', #1
u'بزنية': u'بِزِنْيَةٍ', #2
u'بزنية': u'بِزَنْيَةٍ', #6
u'بزنيت': u'بِزَنَيْت', #1
u'بزنيت': u'بِزَنَيْتِ', #3
u'بزوجني': u'بِزَوِّجْنِي', #2
u'بزوجى': u'بِزَوْجِى', #2
u'بزى': u'بزى', #1
u'بزيافتها': u'بِزِيَافَتِهَا', #1
u'بزيبق': u'بِزِيبَقٍ', #1
u'بزيزة': u'بَزِيزَة', #2
u'بزيزة': u'بَزِيزَةَ', #38
u'بزيزيا': u'بَزَيْزِيّا', #1
u'بزيزية': u'بَزِيزِيَّةً', #1
u'بزيع،': u'بزيع،', #1
u'بزيع': u'بَزِيعَ', #1
u'بزيع،': u'بَزِيعَ،', #1
u'بزيع': u'بُزَيْعِ', #1
u'بزيع،': u'بَزِيعٍ،', #16
u'بزيع': u'بَزِيعٍ', #31
u'بزيع': u'بَزِيعٌ', #7
u'بزيغا': u'بُزَيْغًا', #2
u'بزيون': u'بُزْيُونٌ', #2
u'بزيون': u'بُزْيُونٍ', #9
u'بزيونا': u'بُزْيُونًا', #3
u'بسا': u'بَسّا', #4
u'بسا': u'بَسًّا', #6
u'بساباط': u'بِسَابَاطٍ', #1
u'بسابريين': u'بِسَابِرِيَيْنِ', #1
u'بسابقيته': u'بِسَابِقِيَّتِهِ', #1
u'بسابور،': u'بِسَابُورَ،', #1
u'بسازتا': u'بسازتا', #1
u'بساغين': u'بِسَاغَيْنِ', #2
u'بساف': u'بِسَافٍ', #1
u'بسافرية،': u'بِسَافِرِيَّةَ،', #1
u'بسافرية': u'بِسَافِرِيَّةَ', #2
u'بساقا': u'بُسَاقًا', #1
u'بساقيت': u'بَسَاقَيْتُ', #1
u'بساقيت': u'بِسَاقَيْت', #1
u'بساقيت': u'بِسَاقَيْتُ', #8
u'بسألتني': u'بِسَأَلْتَنِي', #1
u'بسامرا،': u'بِسَامِرَّا،', #1
u'بسامراء': u'بِسَامِرَّاءُ', #1
u'بسامراء،': u'بِسَامَرَّاءَ،', #1
u'بسامراء،': u'بِسَامِرَاءَ،', #1
u'بسامراء،': u'بِسَامِرَّاءَ،', #3
u'بساهيا': u'بِسَاهِيًا', #1
u'بساوة،': u'بِسَاوَةَ،', #1
u'بسائرا': u'بِسَائِرًا', #2
u'بسايد': u'بسايد', #1
u'بسبا': u'بِسَبَا', #1
u'بسباء': u'بِسِبَاءٍ', #11
u'بسباء': u'بِسَبَاءٍ', #5
u'بسباسة': u'بَسْبَاسَةٌ', #1
u'بسباسة': u'بَسْبَاسَةُ', #2
u'بسباه': u'بِسَبَاهُ', #5
u'بسبائب': u'بِسَبَائِبَ', #1
u'بسببان': u'بِسَبَبَانِ', #2
u'بسبتة': u'بِسِبْتَةَ', #2
u'بسبس': u'بَسْبَسٌ', #1
u'بسبس': u'بَسْبَسٍ', #1
u'بسبس': u'بَسْبَسُ', #10
u'بسبس': u'بَسْبَسَ', #3
u'بسبسة': u'بَسْبَسَةُ', #1
u'بسبسة': u'بُسْبَسَةَ', #1
u'بسبسة': u'بُسْبُسَةٌ', #1
u'بسبسة': u'بَسْبَسَةَ', #2
u'بسبلان': u'بِسَبَلاَنَ', #1
u'بسبلت': u'بِسَبَّلْتُ', #1
u'بسبى': u'بِسَبْىٍ', #3
u'بسبيطلة': u'بسُبَيْطِلة', #1
u'بستاسب': u'بستاسب', #1
u'بستانم': u'بستانم', #1
u'بستانهقوله': u'بُسْتَانُهُقَوْلُهُ', #1
u'بستتين': u'بِسِتَّتَيْنِ', #1
u'بستدام': u'بستدام', #1
u'بستدندبنا': u'بستدندبنا', #1
u'بستوقة': u'بِسَتُّوقَةٍ', #4
u'بستيا': u'بُسْتِيًّا', #1
u'بسجام': u'بِسِجَامِ', #1
u'بسجستان': u'بسجستان', #1
u'بسجستان': u'بِسِجِسْتَانَ', #15
u'بسجستان،': u'بسِجِسْتَانَ،', #2
u'بسجستان،': u'بِسِجِسْتَانَ،', #3
u'بسجودى': u'بِسُجُودِى', #2
u'بسحنون': u'بِسَحْنُونٍ', #2
u'بسحيرة': u'بِسُحَيْرَةٍ', #2
u'بسحيم': u'بِسُحَيْمٍ', #1
u'بسخالها': u'بِسِخَالِهَا', #2
u'بسخلة': u'بِسَخْلَةٍ', #3
u'بسخيلة': u'بِسُخَيْلَةَ', #1
u'بسرجة': u'بِسَرْجَةٍ', #1
u'بسردانية': u'بسردانية', #1
u'بسرغ': u'بسرغ', #2
u'بسرغ': u'بِسَرْغَ', #4
u'بسرف': u'بسرف', #1
u'بسرف': u'بسرِف', #1
u'بسرف،': u'بسَرِف،', #1
u'بسرف': u'بِسَرَفِ', #1
u'بسرف': u'بِسَرْفِ', #1
u'بسرف،': u'بِسَرِفٍ،', #1
u'بسرف': u'بسَرِف', #2
u'بسرف': u'بِسَرَفٍ', #26
u'بسرف': u'بِسَرِفِ', #3
u'بسرف،': u'بِسَرِف،', #3
u'بسرف،': u'بِسَرِفَ،', #3
u'بسرف': u'بِسَرِفٍ', #37
u'بسرف': u'بِسَرِفَ', #50
u'بسرقين': u'بِسِرْقِينِ', #2
u'بسرقينها': u'بِسِرْقِينِهَا', #1
u'بسرمرا،': u'بِسُرَّمَرَّا،', #3
u'بسرنتواندبرد': u'بسرنتواندبرد', #1
u'بسرنديب': u'بِسَرَنْدِيبَ', #1
u'بسست': u'بَسَسْت', #1
u'بسطاس': u'بِسْطَاسٍ', #1
u'بسطيح': u'بِسَطِيحِ', #2
u'بسعوط': u'بِسَعُوطٍ', #2
u'بسغالة': u'بسغالة', #1
u'بسغنيا': u'بِسُغُنْيَا', #1
u'بسفاقس': u'بِسَفَاقُسَ', #1
u'بسفوان': u'بسفوان', #1
u'بسفوان': u'بسَفَوَان', #1
u'بسفيان': u'بِسُفْيَانَ', #1
u'بسقب': u'بِسَقَبِ', #1
u'بسقبه': u'بِسَقَبِهِ', #27
u'بسقطت': u'بِسَقَطَتْ', #1
u'بسقى': u'بِسَقْىِ', #1
u'بسقية': u'بِسَقْيَةِ', #1
u'بسقية': u'بِسَقِيَّةٍ', #2
u'بسقيته': u'بِسَقِيَّتِهِ', #1
u'بسكنجبين': u'بِسَكَنْجَبِينٍ', #1
u'بسكنجبين': u'بِسَكَنْجَبِينَ', #1
u'بسلا': u'بَسْلًا', #1
u'بسلافة': u'بِسُلَافَةَ', #2
u'بسلفع': u'بِسَلْفَعِ', #1
u'بسلما': u'بِسَلَمًا', #1
u'بسلمان': u'بسَلْمَان', #1
u'بسلمان': u'بِسَلْمَان', #1
u'بسلمان': u'بِسَلْمَانَ', #7
u'بسلهبة': u'بِسَلْهَبَةَ', #1
u'بسليمانية': u'بِسُلَيْمَانِيَّةٍ', #1
u'بسمعت': u'بِسَمِعْت', #2
u'بسمهه': u'بِسَمْهِهِ', #1
u'بسمى': u'بِسَمَّى', #3
u'بسميساط': u'بسُمَيْساط', #2
u'بسنامين': u'بِسَنَامَيْنِ', #1
u'بسنتى': u'بِسُنَّتِى', #4
u'بسنداد': u'بِسَنْدَادٍ', #1
u'بسنداد': u'بِسِنْدَادَ', #2
u'بسندآمديانيامد': u'بسندآمديانيامد', #1
u'بسندم': u'بسندم', #2
u'بسنديدن': u'بسنديدن', #1
u'بسنمار': u'بِسِنِمّارِ', #1
u'بسنهاء': u'بِسَنْهَاءٍ', #1
u'بسنهاء': u'بِسَنْهَاءَ', #6
u'بسهمان': u'بِسُهْمَانِ', #1
u'بسو': u'بِسُو', #1
u'بسوابغ': u'بِسَوَابِغِ', #1
u'بسواديا': u'بسواديا', #1
u'بسودة': u'بِسَوْدَةَ', #1
u'بسودة': u'بِسَوْدَةِ', #3
u'بسوراء،': u'بِسُورَاءَ،', #1
u'بسوطة': u'بُسُوطَةً', #1
u'بسوطة': u'بُسُوطَةُ', #1
u'بسوطة': u'بُسُوطُةَ', #1
u'بسوطة': u'بِسَوْطَةٍ', #1
u'بسوطة': u'بِسَوْطَةِ', #1
u'بسوطة': u'بُسُوطَةَ', #10
u'بسوف': u'بِسَوْفَ', #11
u'بسولاف': u'بِسُولَافَ', #1
u'بسويبط': u'بِسُوَيْبِطٍ', #2
u'بسويق': u'بِسَوِيقٍ', #26
u'بسويق': u'بِسَوِيقِ', #8
u'بسويقه': u'بِسَوِيقِهِ', #9
u'بسويقها': u'بِسَوِيقِهَا', #3
u'بسيارمى': u'بسيارمى', #1
u'بسيب': u'بِسَيْبِ', #1
u'بسيبهم': u'بِسَيْبِهِمْ', #1
u'بسية': u'بِسِيَةِ', #5
u'بسيتها': u'بِسِيَتِهَا', #1
u'بسيتها،': u'بِسِيَتِهَا،', #1
u'بسيحدث': u'بِسَيَحْدُثُ', #1
u'بسيرمتصل': u'بِسَيْرٍمُتَّصِلٍ', #1
u'بسيسة': u'بَسِيسَةً', #2
u'بسيسة': u'بُسَيْسَةَ', #4
u'بسيفى': u'بِسَيْفِى', #7
u'بسيور': u'بِسُيُورٍ', #2
u'بشاذان': u'بِشَاذَانَ', #1
u'بشاذروانه': u'بِشَاذَرْوَانِهِ', #1
u'بشارا': u'بَشَّارًا', #1
u'بشارك': u'بِشَارَكَ', #1
u'بشاطي': u'بِشَاطَّيْ', #1
u'بشاغور': u'بِشَاغُورَ', #1
u'بشاهبور': u'بِشَاهَبُورَ', #1
u'بشاهدى': u'بِشَاهِدَىْ', #1
u'بشبابة': u'بِشَبَّابَةٍ', #1
u'بشبابته': u'بِشَبَّابَتِهِ', #1
u'بشباش': u'بشباش', #1
u'بشباش': u'بَشْبَاشٍ', #1
u'بشباش': u'بِشْبَاشٌ', #1
u'بشبشة': u'بَشْبَشَةَ', #1
u'بشبيشي': u'بِشْبِيشِيٌّ', #2
u'بشتري': u'بِشَتَرِي', #1
u'بشتواره': u'بُشْتُوارَه', #1
u'بشحته': u'بِشِحَّتِهِ', #3
u'بشخابة': u'بِشِخَابَةٍ', #1
u'بشخانة': u'بُشْخَانَةً', #1
u'بشخانة': u'بُشْخَانَةٍ', #2
u'بشخانة': u'بُشْخَانَةٌ', #3
u'بشخانته': u'بُشْخَانَتِهِ', #1
u'بشدت': u'بشدت', #1
u'بشرSحول': u'بَشَرُSحَوْلَ', #1
u'بشرابة': u'بِشَرَابَةِ', #1
u'بشراحة': u'بِشُرَاحَةَ', #2
u'بشراريبه': u'بِشَرَارِيبِهِ', #3
u'بشرالدولابي': u'بِشْرٍالدُّولَابِيُّ', #1
u'بشرائج': u'بِشَرَائِجَ', #1
u'بشرحبيل': u'بِشُرَحْبِيلَ', #5
u'بشرعا': u'بِشَرْعًا', #4
u'بشرقاء': u'بِشَرْقَاءَ', #2
u'بشرقية': u'بشَرْقِيَّةً', #1
u'بشروج': u'بِشُرُوجٍ', #2
u'بشرى': u'بِشِرًى', #2
u'بشريج': u'بِشَرِيجَ', #1
u'بشريج': u'بِشَرِيجٍ', #2
u'بشسع': u'بِشسْع', #1
u'بشسع': u'بِشِسْعٍ', #1
u'بشسع': u'بِشِسْعِ', #1
u'بشطا': u'بشطا', #1
u'بشطم': u'بِشِطْمٍ', #1
u'بشطنين': u'بِشَطَنَيْنِ', #2
u'بشظاظ': u'بشظاظ', #1
u'بشظاظ': u'بِشِظَاظٍ', #1
u'بشفاعتى': u'بِشَفَاعَتِى', #1
u'بشقص': u'بِشِقْصِ', #4
u'بشقص': u'بِشِقْصٍ', #50
u'بشقفها': u'بِشِقْفِهَا', #1
u'بشكران': u'بِشُكْرَانِ', #1
u'بشكرف': u'بشكرف', #1
u'بشكند': u'بشكند', #2
u'بشكوال': u'بشكوال', #1
u'بشكوال': u'بَشْكُوَالٍ', #1
u'بشكوال': u'بِشْكُوَالَ', #1
u'بشكوال': u'بَشْكُوَالَ', #18
u'بشكوال': u'بَشْكُوَال', #8
u'بشكيرا': u'بَشْكِيرًا', #1
u'بشلاحة': u'بِشِلَاحَةِ', #1
u'بشلكا': u'بشلكا', #2
u'بشما': u'بَشَمًا', #1
u'بشما': u'بَشِمًا', #3
u'بشمت': u'بَشِمَتْ', #1
u'بشموا،': u'بَشِمُوا،', #1
u'بشمين': u'بَشْمِينَ', #1
u'بشنار': u'بِشَنَارِ', #2
u'بشنذة': u'بِشَنَذَةٍ', #1
u'بشنس': u'بَشَنْسُ', #1
u'بشنس': u'بَشَنْسْ', #1
u'بشنس': u'بَشَنْسَ', #9
u'بشنوكة': u'بِشَنُوكَةَ', #1
u'بشنوند': u'بشنوند', #1
u'بشهادتى': u'بِشَهَادَتِى', #1
u'بشهدت': u'بِشَهَدْتُ', #1
u'بشهدت': u'بِشَهِدَتْ', #1
u'بشهدت': u'بِشَهِدْت', #1
u'بشهدت': u'بِشَهِدْتَ', #1
u'بشهرا': u'بِشَهْرًا', #1
u'بشوبق': u'بِشَوْبَقٍ', #1
u'بشوتهم': u'بَشْوَتِهِمْ', #1
u'بشورة': u'بشورة', #1
u'بشورة': u'بِشُورَةِ', #1
u'بشورة': u'بِشَوْرَةِ', #2
u'بشورة': u'بِشَوْرَةٍ', #3
u'بشورة': u'بِشُورَةٍ', #5
u'بشورتها': u'بِشُورَتِهَا', #5
u'بشورتها': u'بِشَوْرَتِهَا', #9
u'بشون': u'بِشُوَنٍ', #1
u'بشىء': u'بِشَىءٍ', #1
u'بشىء': u'بشىء', #2
u'بشئ': u'بِشَئٍ', #3
u'بشىء': u'بِشَىْءٍ', #311
u'بشىء؟': u'بِشَىْءٍ؟', #6
u'بشئت': u'بِشِئْت', #1
u'بشئت': u'بِشِئْتِ', #1
u'بشئت': u'بِشِئْتَ', #5
u'بشيءوالوجه': u'بِشَيْءٍوَالْوَجْهُ', #1
u'بشياع': u'بِشِيَاعِ', #1
u'بشياف': u'بِشِيَافِ', #1
u'بشيراز': u'بِشِيرَازَ', #3
u'بشيرازه': u'بِشِيرَازِهِ', #1
u'بشيزر': u'بِشَيْزَرٍ', #1
u'بشيزر': u'بِشَيْزَرَ', #1
u'بشيىء': u'بشيىء', #1
u'بص': u'بَصَّ', #1
u'بصاحبتى': u'بِصَاحِبَتِى', #1
u'بصاحبى': u'بِصَاحِبِى', #1
u'بصاروج': u'بِصَارُوجٍ', #1
u'بصاعاتهم': u'بِصَاعَاتِهِمْ', #1
u'بصاعى': u'بِصَاعِى', #1
u'بصالحت': u'بِصَالَحْتُ', #1
u'بصالحية': u'بِصَالِحِيَّةِ', #6
u'بصآئر': u'بَصَآئِرُ', #1
u'بصائرا': u'بِصَائِرًا', #1
u'بصبا': u'بِصِبًا', #18
u'بصبهرا': u'بَصْبَهرا', #1
u'بصبى': u'بِصَبًى', #1
u'بصبى': u'بِصَبِىٍّ', #6
u'بصة': u'بَصَّةٌ', #2
u'بصح': u'بِصَحَّ', #8
u'بصحت': u'بِصَحَّتْ', #3
u'بصحح': u'بِصَحَّحَ', #16
u'بصحح': u'بِصُحِّحَ', #3
u'بصحيرات': u'بِصُحَيْرَاتِ', #2
u'بصخيرات': u'بِصُخَيْرَاتِ', #1
u'بصدقا': u'بصدقا', #1
u'بصدقةفجاء': u'بِصَدَقَةٍفَجَاءَ', #1
u'بصدقت': u'بِصَدَقْت', #1
u'بصدقت': u'بِصُدِّقَتْ', #1
u'بصدقت': u'بِصَدَقْتَ', #6
u'بصراد': u'بِصُرّادِ', #1
u'بصراصر': u'بِصَرَاصِرَ', #1
u'بصراصر': u'بِصَرَاصِرٍ', #3
u'بصرائح': u'بِصَرَائِحَ', #1
u'بصرائح': u'بِصَرَائِحِ', #6
u'بصرائحه': u'بِصَرَائِحِهِ', #2
u'بصرتية': u'بَصْرَتِيَّةٌ', #3
u'بصرفت': u'بِصُرِفَتْ', #1
u'بصرورة': u'بِصَرُورَةٍ', #3
u'بصرى': u'بصرى', #1
u'بصرى،': u'بصرى،', #1
u'بصرى': u'بُصْرى', #1
u'بصرى': u'بَصْرَى', #1
u'بصرى': u'بَصْرِىُّ', #1
u'بصرى': u'بِصْرِىٌّ', #1
u'بصرى': u'بَصْرِىٌّ', #12
u'بصرى': u'بِصَرَى', #2
u'بصرى': u'بَصَرِى', #26
u'بصرى': u'بُصْرَى', #52
u'بصرى،': u'بُصْرَى،', #8
u'بصص': u'بَصّصَ', #2
u'بصفاقس': u'بِصَفَاقِس', #1
u'بصفتان': u'بِصِفَتَانِ', #1
u'بصقبه': u'بِصَقِبِهِ', #1
u'بصقبه': u'بِصَقَبِهِ', #16
u'بصقبه': u'بِصَقْبِهِ', #2
u'بصقفي': u'بَصَقَفِي', #1
u'بصكاك': u'بِصِكَاكٍ', #2
u'بصلاء': u'بِصَلَاءِ', #1
u'بصلاب': u'بِصَلَابِ', #1
u'بصلاب': u'بِصِلَابِ', #1
u'بصلاتى': u'بِصَلاَتِى', #5
u'بصلاتية': u'بِصَلَاتِيَّةٍ', #22
u'بصلحت': u'بِصَلَحَتْ', #1
u'بصلق': u'بِصَلْقِ', #1
u'بصلقه': u'بِصَلْقِهِ', #5
u'بصلوا': u'بِصَلُّوا', #1
u'بصليت': u'بِصَلَّيْتُ', #2
u'بصنجات': u'بِصَنَجَاتِ', #2
u'بصنجة': u'بِصَنْجَةٍ', #22
u'بصنجة': u'بِصَنْجَةِ', #8
u'بصنجته': u'بِصَنْجَتِهِ', #1
u'بصنفة': u'بِصَنِفَةِ', #7
u'بصنين': u'بِصِنّينَ', #1
u'بصهوبته': u'بِصُهُوبَتِهِ', #1
u'بصواحباتها': u'بِصَوَاحِبَاتِهَا', #2
u'بصواع': u'بِصُوَاعِ', #5
u'بصواعك': u'بِصُوَاعِكَ', #1
u'بصياله': u'بِصِيَالِهِ', #11
u'بصيدا': u'بِصَيْدَا', #1
u'بصيدا،': u'بِصَيْدَا،', #3
u'بصيدين': u'بِصَيْدَيْنِ', #2
u'بصيروا': u'بِصَيِّرُوا', #1
u'بصيود': u'بِصُيُودٍ', #18
u'بصيود': u'بِصَيُودٍ', #3
u'بضآرين': u'بِضَآرِّينَ', #1
u'بضاع': u'بِضَاعَ', #2
u'بضاعت': u'بضاعت', #2
u'بضاعه': u'بِضَاعَهْ', #4
u'بضاق': u'بِضَاقَ', #1
u'بضائر': u'بِضَائِرِ', #1
u'بضائر': u'بِضَائِرٍ', #6
u'بضائرة': u'بِضَائِرَةٍ', #1
u'بضائري': u'بِضَائِرِي', #1
u'بضباعة': u'بِضُبَاعَةَ', #8
u'بضبطيه': u'بِضَبْطَيْهِ', #1
u'بضبعى': u'بِضَبْعَىَّ', #1
u'بضبعى': u'بِضَبْعَىْ', #1
u'بضجعان': u'بضجعان', #1
u'بضجنان': u'بِضَجِنَانَ', #1
u'بضجنان': u'بِضَجْنَانَ', #15
u'بضجنان،': u'بِضَجْنَانَ،', #2
u'بضجنان': u'بِضَجَنَانَ', #6
u'بضحضاح': u'بضحضاح', #1
u'بضحى': u'بِضُحًى', #1
u'بضرارتهم': u'بِضَرَارَتِهِمْ', #1
u'بضربت': u'بِضَرَبْتَ', #1
u'بضربت': u'بِضَرَبْتُ', #1
u'بضربت': u'بِضَرَبْت', #2
u'بضروان': u'بِضَرْوَانَ', #1
u'بضريانها': u'بِضَرَيَانِهَا', #1
u'بضعث': u'بِضِعْثٍ', #1
u'بضمنت': u'بِضَمِنْتُ', #4
u'بضنة': u'بِضِنَّةِ', #1
u'بضوج': u'بِضَوْجِ', #2
u'بضوعا': u'بُضُوعًا', #1
u'بضيفان': u'بِضِيفَانٍ', #3
u'بضيفانه': u'بِضِيفَانِهِ', #1
u'بضيقت': u'بِضَيَّقْتُ', #1
u'بضيمران': u'بِضَيْمُرَانَ', #1
u'بطابة،': u'بِطَابَةَ،', #1
u'بطابو': u'بِطَابُو', #1
u'بطارخه': u'بَطَارِخِهِ', #2
u'بطاطيخ': u'بطاطيخ', #1
u'بطالبوه': u'بِطَالَبُوهُ', #2
u'بطالقا': u'بِطَالِقًا', #1
u'بطبرستان': u'بِطَبَرِسْتَانَ', #23
u'بطبرستان،': u'بِطَبَرِسْتَانَ،', #3
u'بطبرية': u'بِطَبَرِيَّةَ', #6
u'بطبعا': u'بِطَبْعًا', #3
u'بطت': u'بُطَّتْ', #2
u'بطحينة': u'بِطَحِينَةٍ', #2
u'بطخاء': u'بِطَخَاءِ', #2
u'بطخفة': u'بِطِخْفَةَ', #3
u'بطرأ': u'بِطَرَأَ', #1
u'بطربة': u'بِطَرْبَةٍ', #1
u'بطرة': u'بَطِرَةً', #1
u'بطرديته': u'بِطَرْدِيَّتِهِ', #3
u'بطرسوس': u'بِطَرَسُوسَ', #6
u'بطرسوس،': u'بِطَرَسُوسَ،', #6
u'بطرطا': u'بطرطا', #1
u'بطرفان': u'بِطَرَفَانِ', #2
u'بطرو': u'بِطُرُوِّ', #104
u'بطرو': u'بِطُرُوٍّ', #2
u'بطريان': u'بِطَرَيَانِ', #28
u'بطريانها': u'بِطَرَيَانِهَا', #1
u'بطط': u'بِطَطٍ', #1
u'بطغواها': u'بِطَغْوَاهَا', #1
u'بطفيتين': u'بِطُفْيَتَيْنِ', #1
u'بطلاقا': u'بِطَلَاقًا', #2
u'بطلاقى': u'بِطَلاَقِى', #2
u'بطلان': u'بُطْلَانً', #1
u'بطلبت': u'بِطَلَبَتْ', #1
u'بطلقا': u'بِطَلَّقَا', #1
u'بطلقت': u'بِطَلُقَتْ', #1
u'بطلقت': u'بِطُلِّقْتِ', #1
u'بطلقت': u'بِطَلَّقْتُ', #6
u'بطلقتم': u'بِطَلَّقْتُمْ', #2
u'بطمة': u'بُطْمَةٌ', #1
u'بطنكمو': u'بَطْنِكُمُو', #1
u'بطنى': u'بَطْنِى', #15
u'بطهرت': u'بِطَهُرَتْ', #2
u'بطهرين': u'بِطُهْرَيْنِ', #5
u'بطهورا': u'بِطَهُورًا', #1
u'بطوا': u'بُطُّوا', #2
u'بطورون': u'بِطُورُونَ', #1
u'بطوفة': u'بِطَوْفَةٍ', #5
u'بطوفته': u'بِطَوْفَتِهِ', #2
u'بطولا': u'بُطُولًا', #2
u'بطوله': u'بِطُولِهًًًًِ', #1
u'بطونس': u'بِطُونُسَ', #1
u'بطوى': u'بِطُوًى', #6
u'بطوى': u'بِطَوًى', #8
u'بطويلا': u'بِطَوِيلًا', #1
u'بطيابها': u'بِطِيَابِهَا', #1
u'بظاهرا': u'بِظَاهِرًا', #1
u'بظرفا': u'بِظَرْفًا', #1
u'بظفرى': u'بِظُفُرِى', #2
u'بظنيته': u'بِظَنِّيَّتِهِ', #1
u'بظنيتها': u'بِظَنِّيَّتِهَا', #2
u'بظئره': u'بِظِئْرِهِ', #1
u'بعابه': u'بِعَابِهِ', #1
u'بعاجلا': u'بِعَاجِلًا', #3
u'بعادوا': u'بِعَادُوا', #3
u'بعاريت': u'بعاريت', #2
u'بعاقا': u'بُعَاقًا', #1
u'بعاملت': u'بِعَامَلْت', #1
u'بعبادان': u'بِعَبَّادَانَ', #1
u'بعبادان،': u'بِعَبَّادَانَ،', #1
u'بعبالة': u'بِعَبَالَةِ', #1
u'بعبايا': u'بِعُبَايَا', #1
u'بعبدا': u'بِعَبْدًا', #1
u'بعبدوس': u'بِعَبْدُوسٍ', #1
u'بعبدى': u'بِعَبْدِى', #1
u'بعبديته': u'بِعَبْدِيَّتِهِ', #1
u'بعبوق': u'بِعُبُوقِ', #1
u'بعتاقتى': u'بِعَتَاقَتِى', #1
u'بعتقا': u'بِعَتَقَا', #1
u'بعتقائه': u'بِعُتَقَائِهِ', #2
u'بعتقت': u'بِعَتَقْتُ', #2
u'بعتكا': u'بِعْتُكَا', #1
u'بعتكه': u'بِعْتُكَهُ', #223
u'بعتكها': u'بِعْتُكَهَا', #51
u'بعتكها': u'بِعْتُكهَا', #96
u'بعتكهما': u'بِعْتُكَهُمَا', #1
u'بعتمانيه': u'بِعْتُمَانِيهِ', #1
u'بعتنى': u'بِعْتَنِى', #1
u'بعتنيه': u'بِعْتَنِيهِ', #11
u'بعتنيه': u'بِعْتنِيهِ', #16
u'بعتنيها': u'بِعْتنِيهَا', #10
u'بعتنيها': u'بِعْتَنِيهَا', #6
u'بعثامنة': u'بِعَثَامِنَةٍ', #1
u'بعثتنى': u'بَعَثْتَنِى', #1
u'بعثكال': u'بِعِثْكَالَ', #1
u'بعثكال': u'بِعِثْكَالٍ', #26
u'بعثنى': u'بَعَثَنِىَ', #1
u'بعثنى': u'بَعَثَنِى', #77
u'بعثونى': u'بَعَثُونِى', #1
u'بعجت': u'بَعَجْتُ', #1
u'بعجزوا': u'بِعَجَزُوا', #1
u'بعجوا': u'بَعَجُوا', #1
u'بعدSحب': u'بَعْدُSحُبّ', #1
u'بعد': u'بُعْدً', #2
u'بعد': u'بَعْدً', #6
u'بعداز': u'بعداز', #1
u'بعدأن': u'بَعْدَأَنْ', #2
u'بعدب،': u'بِعَدْبٍ،', #1
u'بعدتمام': u'بَعْدَتَمَامِ', #1
u'بعدلا': u'بِعَدْلًا', #1
u'بعدميتها': u'بِعَدَمِيَّتِهَا', #1
u'بعدمين': u'بِعَدِمَيْنِ', #1
u'بعدوانا': u'بِعُدْوَانًا', #1
u'بعديته': u'بُعْدِيَّتَهُ', #1
u'بعديته': u'بَعْدِيَّتِهِ', #2
u'بعديته': u'بُعْدِيَّتِهِ', #2
u'بعديته': u'بَعْدِيَّتَهُ', #7
u'بعديتها': u'بُعْدِيَّتَهَا', #1
u'بعديتهما': u'بَعْدِيَّتَهُمَا', #2
u'بعديتهما': u'بَعْدِيَّتِهِمَا', #6
u'بعذيب': u'بِعُذَيْبٍ', #1
u'بعرجته': u'بِعَرْجَتِهِ', #1
u'بعرجتى': u'بِعُرْجَتِى', #1
u'بعرجتي': u'بِعَرْجَتِي', #3
u'بعرقبا': u'بِعَرْقَبَا', #1
u'بعرقبته': u'بِعَرْقَبَتِهِ', #1
u'بعرقصة': u'بِعَرْقَصَةٍ', #1
u'بعرما': u'بُعُرْمًا', #1
u'بعرنة': u'بِعَرَنَةْ', #1
u'بعرنة،': u'بِعُرَنَةَ،', #1
u'بعرنة': u'بِعُرَنَةَ', #15
u'بعرى': u'بِعُرًى', #3
u'بعزجة': u'بَعْزَجَةَ', #2
u'بعزجة': u'بَعْزَجَةُ', #4
u'بعزرة': u'بِعَزْرَةَ', #1
u'بعزق': u'بِعَزْقٍ', #1
u'بعزلان': u'بِعَزَلَانِ', #1
u'بعزيتهم': u'بِعِزِّيَّتِهِمْ', #1
u'بعسب': u'بِعَسْبِ', #1
u'بعسجر': u'بِعَسْجَرَ', #1
u'بعسفان،': u'بعسفان،', #1
u'بعسفان': u'بعُسْفان', #1
u'بعسفان،': u'بعُسْفان،', #1
u'بعسفان': u'بِعُسْفَان', #1
u'بعسفان،': u'بِعَسْفَانَ،', #1
u'بعسفان': u'بِعْسْفَانَ', #2
u'بعسفان': u'بِعُسْفَانَ', #79
u'بعسفان،': u'بِعُسْفَانَ،', #8
u'بعسقلان': u'بعَسْقلان', #1
u'بعسقلان': u'بِعَسْقَلاَنَ', #2
u'بعسقلان،': u'بِعَسْقَلانَ،', #4
u'بعسقلان': u'بِعَسْقَلَانَ', #7
u'بعسى': u'بِعَسَى', #6
u'بعسيب': u'بِعَسِيبِ', #1
u'بعسيب': u'بِعَسِيبٍ', #8
u'بعشرينه': u'بِعِشْرِينِهِ', #1
u'بعشوان': u'بِعَشَوَانٍ', #1
u'بعشى': u'بِعَشِىٍّ', #3
u'بعصا': u'بَعْصًا', #1
u'بعصا': u'بِعْصًا', #1
u'بعصا،': u'بِعَصًا،', #1
u'بعصا': u'بِعَصًا', #182
u'بعصاتين': u'بِعَصَاتَيْنِ', #1
u'بعصاى': u'بِعَصَاىَ', #1
u'بعصبت': u'بِعُصِبَتْ', #1
u'بعصفر': u'بِعُصْفُرِ', #6
u'بعصفر': u'بِعُصْفُرٍ', #67
u'بعصلبي': u'بِعَصْلَبي', #1
u'بعصلبي': u'بِعَصْلَبِيِّ', #1
u'بعصوبة': u'بِعُصُوبَةٍ', #7
u'بعصوبة': u'بِعُصُوبَةِ', #7
u'بعصوبتين': u'بِعُصُوبَتَيْنِ', #1
u'بعصى': u'بِعَصًى', #1
u'بعصى': u'بِعَصَى', #3
u'بعضادتى': u'بِعِضَادَتَىِ', #1
u'بعضاوالوجه': u'بَعْضًاوَالْوَجْهُ', #1
u'بعضب': u'بِعَضْبِ', #4
u'بعضباء': u'بِعَضْبَاءِ', #4
u'بعضناها': u'بَعَّضْنَاهَا', #4
u'بعضه': u'بَعْضَهًًًًُ', #1
u'بعضوالوجه': u'بَعْضٍوَالْوَجْهُ', #1
u'بعضى؟': u'بَعْضِى؟', #1
u'بعضى': u'بَعْضِى', #3
u'بعضيتها': u'بَعْضِيَّتَهَا', #2
u'بعضيتهما': u'بَعْضِيَّتُهُمَا', #1
u'بعطن': u'بِعَطَنٍِِِِ', #1
u'بعطن': u'بِعَطَنٍ', #13
u'بعطن': u'بعطن', #2
u'بعطن': u'بِعَطَنِ', #2
u'بعطنها': u'بِعَطَنِهَا', #1
u'بعفا': u'بِعَفَا', #3
u'بعفاصها': u'بِعِفَاصِهَا', #2
u'بعفى': u'بِعَفَى', #1
u'بعكاء': u'بِعَكَّاءَ', #1
u'بعكبرا،': u'بعكبرا،', #1
u'بعكبرا': u'بِعُكْبَرَا', #1
u'بعكبرا،': u'بِعُكْبَرَا،', #1
u'بعكة': u'بِعُكّةَ', #1
u'بعكة': u'بِعُكّةِ', #1
u'بعكة': u'بِعُكَّةٍ', #1
u'بعلابط': u'بِعُلَابِطَ', #1
u'بعلس': u'بِعَلَسٍ', #1
u'بعلفت': u'بِعُلِفَتْ', #2
u'بعلقمة': u'بِعَلْقَمَةَ', #13
u'بعلوفتها': u'بِعُلُوفَتِهَا', #1
u'بعليفه': u'بِعَلِيفِهِ', #1
u'بعمارت': u'بعمارت', #1
u'بعمامتى': u'بِعِمَامَتِى', #1
u'بعمدا': u'بِعَمْدًا', #1
u'بعمرى': u'بِعُمْرَى', #15
u'بعمن': u'بِعَمَّنْ', #1
u'بعمواس': u'بِعَمْوَاسٍ', #1
u'بعمواس': u'بِعِمْوَاسَ', #1
u'بعمورية': u'بِعَمّورِيَةَ', #2
u'بعمورية': u'بِعَمُّورِيَّةَ', #2
u'بعمورية': u'بِعَمُورِيّةَ', #4
u'بعمى': u'بِعَمًى', #2
u'بعناكه': u'بِعْنَاكَهُ', #1
u'بعناكها': u'بِعْنَاكَهَا', #5
u'بعنبسة': u'بِعَنْبَسَةَ', #1
u'بعنة': u'بِعُنَّةِ', #2
u'بعنة': u'بِعُنَّةٍ', #7
u'بعنقى': u'بعنقى', #1
u'بعنيزتين': u'بِعُنَيْزَتَيْنِ', #1
u'بعنين': u'بِعِنِّينٍ', #17
u'بعهدت': u'بِعَهِدْتُ', #1
u'بعوس': u'بِعَوْسَ', #1
u'بعياش': u'بِعَيّاشٍ', #1
u'بعياش': u'بِعَيّاشِ', #2
u'بعيالاتهم': u'بِعَيَّالَاتِهِمْ', #2
u'بعيالتهم': u'بِعِيَالَتِهِمْ', #1
u'بعيبة': u'بِعَيْبَةِ', #1
u'بعيبتك': u'بِعَيْبَتِك', #1
u'بعيبتك،': u'بِعَيْبَتِكَ،', #1
u'بعيبتك': u'بِعَيْبَتِكَ', #2
u'بعيثا': u'بَعِيثًا', #1
u'بعيذ': u'بعيذ', #1
u'بعيرى': u'بَعِيرِىَ', #1
u'بعيرى': u'بَعِيرِى', #11
u'بعيس': u'بِعِيسِ', #1
u'بعيسوي': u'بِعِيسَوِيٍّ', #1
u'بعينى': u'بِعَيْنَىَّ', #4
u'بعيينة': u'بِعُيَيْنَةَ', #1
u'بغ': u'بغ', #1
u'بغاثة': u'بِغَاثَةَ', #1
u'بغاثة': u'بُغَاثَةٍ', #2
u'بغاجه': u'بُغَاجَهْ', #1
u'بغاسلا': u'بِغَاسِلًا', #2
u'بغاضة': u'بَغَاضَةً', #3
u'بغاكه': u'بغاكه', #1
u'بغالبا': u'بِغَالِبًا', #17
u'بغبغ': u'بُغْبُغٌ', #1
u'بغدادى': u'بَغْدَادَىُّ', #1
u'بغدادى': u'بَغْدَادِىٌّ', #1
u'بغدان': u'بَغْدَانَ', #1
u'بغدان': u'بَغْدَانُ', #1
u'بغرا': u'بَغِرًا', #1
u'بغرامل': u'بِغَرَامِلَ', #1
u'بغرقناه': u'بِغَرَّقْنَاهُ', #1
u'بغزات': u'بِغَزّاتِ', #2
u'بغزاتين': u'بِغَزَاتَيْنِ', #2
u'بغزر': u'بِغَزِرِ', #1
u'بغزر': u'بِغُزْرِ', #1
u'بغشوشهم': u'بِغُشُوشِهِمْ', #1
u'بغصبت': u'بِغُصِبَتْ', #1
u'بغصبين': u'بِغَصْبَيْنِ', #3
u'بغضاشديدا': u'بُغْضًاشَدِيدًا', #1
u'بغضة': u'بَغْضَةً', #1
u'بغضة': u'بِغْضَةٍ', #1
u'بغضة': u'بِغْضَةً', #6
u'بغلبوا': u'بِغَلَّبُوا', #1
u'بغلث': u'بِغَلْثٍ', #1
u'بغلطاق': u'بَغْلِطَاقَ', #1
u'بغلطاقا': u'بَغْلِطَاقًا', #1
u'بغلوة': u'بِغَلْوَةٍ', #14
u'بغلوة': u'بِغَلْوَةِ', #4
u'بغلى': u'بَغْلِى', #2
u'بغموس': u'بِغَمُوسٍ', #3
u'بغنى': u'بِغِنًى', #13
u'بغوطة': u'بِغَوْطَةِ', #1
u'بغئور': u'بِغُئُورِ', #1
u'بغيبغ': u'بُغَيْبِغٌ', #1
u'بغيرطهارة': u'بِغَيْرِطَهَارَةٍ', #1
u'بغيش': u'بُغَيْشٌ', #1
u'بغيطانهم': u'بِغِيطَانِهِمْ', #1
u'بغيظهمو': u'بِغَيْظِهِمُو', #1
u'بغيقة،': u'بِغَيْقَةٍ،', #1
u'بغيقة': u'بِغَيْقَةَ', #2
u'بف': u'بف', #1
u'بف': u'بِفَ', #1
u'بفا': u'بِفَا', #1
u'بفاتت': u'بِفَاتَتْ', #2
u'بفاتته': u'بِفَاتَتْهُ', #2
u'بفاته': u'بِفَاتَهُ', #1
u'بفاثور': u'بِفَاثُورَ', #2
u'بفاختة': u'بِفَاخِتَةَ', #4
u'بفاديت': u'بِفَادَيْت', #1
u'بفارقت': u'بِفَارَقَتْ', #1
u'بفارقينها': u'بِفَارِقِينَهَا', #3
u'بفاسدا': u'بِفَاسِدًا', #1
u'بفاقتى': u'بِفَاقَتِى', #1
u'بفإن': u'بِفَإِنْ', #1
u'بفتراك': u'بفتراك', #1
u'بفتوى': u'بِفَتْوًى', #2
u'بفتى': u'بِفَتًى', #5
u'بفتيا': u'بفُتيا', #1
u'بفتيا': u'بِفُتْيَا', #15
u'بفتياك': u'بِفُتْيَاكِ', #1
u'بفتياك': u'بِفُتْيَاك', #2
u'بفتياك': u'بِفُتْيَاكَ', #3
u'بفتياكم': u'بِفُتْيَاكُمْ', #1
u'بفتياه': u'بِفُتْيَاهُ', #7
u'بفجء': u'بِفَجْءِ', #17
u'بفجأ': u'بِفَجْأِ', #2
u'بفجئ': u'بِفَجْئِ', #5
u'بفدا': u'بِفِدَا', #2
u'بفدفد': u'بِفَدْفَدٍ', #1
u'بفدفد': u'بِفَدْفَدِ', #2
u'بفدفدة': u'بِفَدْفَدَةٍ', #1
u'بفدفدة': u'بِفَدْفَدَةِ', #1
u'بفدك': u'بَفَدَكَ', #1
u'بفدك': u'بِفَدَكِ', #1
u'بفدك،': u'بِفَدَكٍ،', #1
u'بفدك،': u'بِفَدَكَ،', #1
u'بفدك': u'بِفَدَكٍ', #2
u'بفدك': u'بِفَدَكَ', #4
u'بفراشيتها': u'بِفِرَاشِيَّتِهَا', #1
u'بفراهيته': u'بفراهيته', #1
u'بفرتب': u'بِفَرَتَّبَ', #1
u'بفرزندان': u'بفرزندان', #1
u'بفرست': u'بفرست', #1
u'بفرضتم': u'بِفَرَضْتُمْ', #1
u'بفرغانة': u'بِفَرْغَانَةَ', #16
u'بفرمان': u'بِفَرَمَانٍ', #1
u'بفروشم': u'بفروشم', #1
u'بفروغ': u'بِفُرُوغِ', #1
u'بفزارة': u'بِفَزَارَةَ', #1
u'بفزارة': u'بِفَزَارَةِ', #1
u'بفزعا': u'بِفَزَعًا', #2
u'بفسخت': u'بِفَسَخْتُ', #1
u'بفسخت': u'بِفَسَخْت', #3
u'بفسد': u'بِفَسَدَ', #1
u'بفسدت': u'بِفَسَدَتْ', #4
u'بفشا': u'بِفَشَا', #1
u'بفضا': u'بِفَضَا', #1
u'بفضيخ': u'بِفَضِيخٍ', #1
u'بفعلت': u'بِفَعَلْت', #1
u'بفعلت': u'بِفَعَلْتُ', #2
u'بفعيل': u'بِفَعِيلٍ', #4
u'بفقء': u'بِفَقْءٍ', #1
u'بفقء': u'بِفَقْءِ', #20
u'بفقط': u'بِفَقَطْ', #8
u'بفقميه': u'بِفُقْمَيْهِ', #2
u'بفهر': u'بِفِهْرِ', #1
u'بفهر': u'بِفِهْرٍ', #4
u'بفوائت': u'بِفَوَائِتَ', #2
u'بفوريته': u'بِفَوْرِيَّتِهِ', #9
u'بفوريتها': u'بِفَوْرِيَّتِهَا', #1
u'بفوزان': u'بِفَوْزَانِ', #1
u'بفوض': u'بِفَوَّضَ', #5
u'بفوقيتها': u'بِفَوْقِيَّتِهَا', #2
u'بفئوسهم': u'بِفُئُوسِهِمْ', #3
u'بفيد': u'بِفَيْدٍ', #1
u'بفيروزج': u'بِفَيْرُوزَجَ', #1
u'بفيفا': u'بِفَيْفَا', #1
u'بفيما': u'بِفِيمَا', #1
u'بقاءالوجه': u'بَقَاءٍالْوَجْهُ', #1
u'بقاتلى': u'بِقَاتِلِى', #1
u'بقارا': u'بَقَّارًا', #1
u'بقارون': u'بِقَارُونَ', #2
u'بقارئا': u'بِقَارِئًا', #1
u'بقاسيون،': u'بِقَاسِيُونَ،', #1
u'بقاطا': u'بقاطا', #1
u'بقاطاجانس': u'بقاطاجانس', #1
u'بقافة': u'بِقَافَةٍ', #4
u'بقالت': u'بِقَالَتْ', #1
u'بقالوا': u'بِقَالُوا', #2
u'بقام': u'بَقَامَ', #1
u'بقام': u'بِقَامَ', #11
u'بقامت': u'بِقَامَتْ', #1
u'بقامه': u'بِقَامَهُ', #1
u'بقائبة': u'بقائبة', #1
u'بقائف': u'بِقَائِفٍ', #20
u'بقائما': u'بِقَائِمًا', #1
u'بقبرس': u'بقُبْرس', #1
u'بقبرس،': u'بِقُبْرُسَ،', #1
u'بقبرى': u'بِقَبْرِى', #2
u'بقبص': u'بِقَبْصِ', #1
u'بقبصات': u'بِقَبَصَاتٍ', #1
u'بقبلت': u'بِقَبِلْت', #2
u'بقبلت': u'بِقَبِلْتُ', #25
u'بقبيس': u'بِقُبَيْسِ', #1
u'بقتب': u'بِقَتَبِ', #2
u'بقتح': u'بقتح', #1
u'بقتلني': u'بِقَتَلَنِي', #1
u'بقتله6334id': u'بقتله6334id', #1
u'بقجة': u'بقجة', #1
u'بقجة': u'بُقْجَةَ', #1
u'بقدحى': u'بِقَدَحِى', #2
u'بقدف': u'بِقَدْفٍ', #1
u'بقذفين': u'بِقَذْفَيْنِ', #1
u'بقرءان': u'بِقُرْءَانٍ', #1
u'بقراءتى': u'بِقِرَاءَتِى', #1
u'بقرابتى': u'بِقَرَابَتِى', #2
u'بقرازها': u'بِقَرَازِهَا', #1
u'بقرافة': u'بِقَرَافَةِ', #7
u'بقرافتها': u'بِقَرَافَتِهَا', #2
u'بقرام': u'بِقِرَامٍ', #15
u'بقرامل': u'بِقَرَامِلَ', #4
u'بقرأين': u'بِقَرْأَيْنِ', #11
u'بقرأين': u'بِقُرْأَيْنِ', #67
u'بقرظ': u'بِقَرَظٍ', #1
u'بقرقر': u'بِقَرْقَرٍ', #1
u'بقرقر': u'بِقَرْقَرِ', #2
u'بقرقور': u'بِقُرْقُورٍ', #1
u'بقرقيسياء،': u'بِقَرْقِيسِيَاءَ،', #1
u'بقرقيسية': u'بِقَرْقِيسِيَةَ', #1
u'بقرنى': u'بِقَرْنَىْ', #2
u'بقرونى': u'بِقُرُونِى', #1
u'بقرى': u'بقرًى', #1
u'بقرى': u'بِقِرًى', #2
u'بقريرا،': u'بِقَرِيرَا،', #1
u'بقزع': u'بِقَزَعِ', #2
u'بقصدا': u'بِقَصْدًا', #2
u'بقصدين': u'بِقَصْدَيْنِ', #1
u'بقصعتى': u'بِقَصْعَتِى', #1
u'بقضقاض': u'بِقَضْقَاضٍ', #1
u'بقضى': u'بِقَضَى', #6
u'بقطعا': u'بِقَطْعًا', #1
u'بقطوراء': u'بِقَطُورَاءَ', #2
u'بقعاء': u'بَقْعَاءُ', #5
u'بقعب': u'بِقَعْبٍ', #6
u'بقعبة': u'بِقَعْبَةٍ', #1
u'بقعددهم': u'بِقُعْدُدِهِمْ', #1
u'بقعطها': u'بِقَعْطِهَا', #1
u'بقعيقعان': u'بِقُعَيْقِعَانَ', #5
u'بقفارين': u'بِقُفَّارَيْنِ', #1
u'بقفاى': u'بِقَفَاىَ', #1
u'بقفصة': u'بِقَفْصَةِ', #1
u'بقفصة': u'بِقَفْصَةَ', #2
u'بقفصة': u'بِقَفِصَةٍ', #3
u'بقفصة': u'بِقَفِصَةِ', #3
u'بقفير': u'بِقَفِيرِ', #1
u'بقفيز': u'بِقَفِيزِ', #46
u'بقفيز': u'بِقَفِيزٍ', #96
u'بقفيزي': u'بِقَفِيزَيْ', #21
u'بقفيزين': u'بِقَفِيزَيْنِ', #15
u'بقلاص': u'بِقِلَاصِ', #1
u'بقلائص': u'بِقَلَائِصَ', #1
u'بقلبى': u'بِقَلْبِى', #1
u'بقلت': u'بِقُلْتُ', #3
u'بقلتا': u'بِقُلَّتَا', #2
u'بقلقشندة': u'بِقَلْقَشَنْدَةَ', #1
u'بقلما': u'بِقَلَّمَا', #2
u'بقلن': u'بِقُلْنَ', #1
u'بقلنسية': u'بِقُلَنْسِيَةٍ', #1
u'بقلهى': u'بِقَلَهَى', #1
u'بقليب': u'بِقَلِيبِ', #2
u'بقليلا': u'بِقَلِيلًا', #1
u'بقم': u'بَقَّمٍ', #1
u'بقم': u'بُقَّمٌ', #1
u'بقم': u'بِقَمٍّ', #1
u'بقناةوسألته': u'بِقَنَاةَوَسَأَلَتْهُ', #1
u'بقنسرين': u'بِقِنَّسْرِينَ', #1
u'بقهرمانة': u'بِقَهْرَمَانَةٍ', #1
u'بقوتلوا': u'بِقُوتِلُوا', #1
u'بقوسان': u'بقوسان', #1
u'بقوسى': u'بِقَوْسِى', #6
u'بقوص': u'بِقُوصٍ', #1
u'بقوص': u'بِقُوصَ', #1
u'بقوصرة': u'بِقَوْصَرَّةِ', #3
u'بقولان': u'بِقَوْلَانِ', #6
u'بقولى': u'بِقَوْلِى', #1
u'بقوهي': u'بِقُوهِيٍّ', #1
u'بقويلة': u'بِقُوَيْلَةٍ', #1
u'بقويلة': u'بِقُوَيْلَةِ', #1
u'بقىء': u'بقىء', #1
u'بقيامت': u'بقيامت', #1
u'بقير': u'بِقِيرٍ', #1
u'بقيرا': u'بَقِيرًا', #1
u'بقيرا': u'بُقَيْرًا', #1
u'بقيرة': u'بقيرة', #1
u'بقيرة': u'بَقِيرَةَ', #1
u'بقيرة': u'بُقَيْرَةُ', #1
u'بقيرة': u'بُقَيْرَةٍ', #2
u'بقيرة': u'بُقَيْرَةَ', #3
u'بقيعة': u'بِقِيعَةٍ', #19
u'بقيلة،': u'بُقَيْلَةَ،', #1
u'بقيلة': u'بُقَيْلَةَ', #6
u'بقيمان': u'بِقِيمَانِ', #1
u'بقيئة': u'بِقَيْئَةٍ', #1
u'بكا': u'بكا', #1
u'بكا': u'بَكّاً', #1
u'بكا': u'بُكًا', #1
u'بكا،': u'بَكَا،', #1
u'بكا': u'بِكَا', #2
u'بكا': u'بُكَا', #4
u'بكابن': u'بِكَابِنِ', #1
u'بكابن': u'بِكَابْنِ', #1
u'بكإحرام': u'بِكَإِحْرَامٍ', #8
u'بكأختها': u'بِكَأُخْتِهَا', #1
u'بكأخضر': u'بِكَأَخْضَرَ', #1
u'بكاد': u'بِكَادَ', #1
u'بكارا': u'بَكَّارًا', #3
u'بكإرث': u'بِكَإِرْثٍ', #2
u'بكإرثه': u'بِكَإِرْثِهِ', #3
u'بكارند': u'بكارند', #1
u'بكاز': u'بِكَازٍ', #1
u'بكازرداد': u'بكازرداد', #1
u'بكاست': u'بكاست', #1
u'بكاستغفروا': u'بِكَاسْتَغْفِرُوا', #1
u'بكاستيلاد': u'بِكَاسْتِيلَادٍ', #2
u'بكاسقني': u'بِكَاسْقِنِي', #4
u'بكاسه': u'بكاسه', #1
u'بكاشتباه': u'بِكَاشْتِبَاهٍ', #10
u'بكأشنان': u'بِكَأُشْنَانٍ', #1
u'بكاعتراض': u'بِكَاعْتِرَاضٍ', #10
u'بكافران': u'بكافران', #1
u'بكإفلاس': u'بِكَإِفْلَاسِ', #1
u'بكأكله': u'بِكَأَكْلِهِ', #1
u'بكإلا': u'بِكَإِلَّا', #8
u'بكالاصفرار': u'بِكَالِاصْفِرَارِ', #1
u'بكالإنفاق': u'بِكَالْإِنْفَاقِ', #1
u'بكالآية': u'بِكَالْآيَةِ', #1
u'بكالخصي': u'بِكَالْخَصِيِّ', #1
u'بكالسابعة': u'بِكَالسَّابِعَةِ', #1
u'بكالسوق': u'بِكَالسُّوقِ', #7
u'بكالسيف': u'بِكَالسَّيْفِ', #1
u'بكالصداقة': u'بِكَالصَّدَاقَةِ', #1
u'بكالصفين': u'بِكَالصَّفَّيْنِ', #2
u'بكالصلاة': u'بِكَالصَّلَاةِ', #1
u'بكالعتق': u'بِكَالْعِتْقِ', #2
u'بكالعزى': u'بَكَالْعُزَّى', #1
u'بكالعزى': u'بِكَالْعُزَّى', #7
u'بكالكراء': u'بِكَالْكِرَاءِ', #1
u'بكالمسجد': u'بِكَالْمَسْجِدِ', #2
u'بكالموت': u'بِكَالْمَوْتِ', #1
u'بكالنوم': u'بِكَالنَّوْمِ', #1
u'بكالئ': u'بِكَالِئِ', #1
u'بكالئ': u'بِكَالِئٍ', #24
u'بكالئها': u'بِكَالِئِهَا', #5
u'بكاليمن': u'بِكَالْيَمَنِ', #1
u'بكاليومين': u'بِكَالْيَوْمَيْنِ', #7
u'بكأم': u'بِكَأُمٍّ', #1
u'بكأن': u'بِكَأَنْ', #2
u'بكان': u'بَكَانِ', #5
u'بكأن': u'بِكَأَنَّ', #7
u'بكان': u'بِكَانَ', #8
u'بكإنبات': u'بِكَإِنْبَاتٍ', #3
u'بكانوا': u'بِكَانُوا', #2
u'بكأهله': u'بِكَأَهْلِهِ', #1
u'بكائى': u'بُكَائِى', #1
u'بكآية': u'بِكَآيَةٍ', #13
u'بكبائس': u'بِكَبَائِسَ', #1
u'بكبخ': u'بكبخ', #1
u'بكبدى': u'بِكَبِدِى', #2
u'بكبيع': u'بِكَبَيْعٍ', #1
u'بكبيعه': u'بِكَبَيْعِهِ', #1
u'بكتد': u'بِكَتَدِ', #1
u'بكتد': u'بِكَتَدٍ', #6
u'بكتراب': u'بِكَتُرَابٍ', #14
u'بكتقديم': u'بِكَتَقْدِيمِ', #2
u'بكتقويم': u'بِكَتَقْوِيمِ', #13
u'بكتقويم': u'بِكَتَقْوِيمٍ', #3
u'بكتوب': u'بَكْتُوبٍ', #1
u'بكتوت': u'بَكْتُوتُ', #1
u'بكتوت': u'بَكْتُوتِ', #1
u'بكتوه': u'بَكِّتُوهُ', #4
u'بكثوب': u'بِكَثَوْبٍ', #2
u'بكثيرا': u'بِكَثِيرًا', #4
u'بكجبه': u'بِكَجَبِّهِ', #1
u'بكجعل': u'بِكَجُعْلٍ', #2
u'بكحرقه': u'بِكَحَرْقِهِ', #11
u'بكحصى': u'بِكَحَصًى', #1
u'بكحفرة': u'بِكَحُفْرَةٍ', #2
u'بكحلق': u'بِكَحَلَقَ', #1
u'بكحلق': u'بِكَحَلْقٍ', #1
u'بكحلق': u'بِكَحِلَقٍ', #5
u'بكحمام': u'بِكَحَمَامٍ', #2
u'بكحناء': u'بِكَحِنَّاءَ', #1
u'بكحناء': u'بِكَحِنَّاءٍ', #8
u'بكحيض': u'بِكَحَيْضٍ', #5
u'بكخرقة': u'بِكَخِرْقَةٍ', #2
u'بكخس': u'بِكَخَسٍّ', #1
u'بكخل': u'بِكَخَلٍّ', #6
u'بكخلع': u'بِكَخُلْعٍ', #1
u'بكخمر': u'بَكَخَمْرٍ', #1
u'بكخمر': u'بِكَخَمْرٍ', #7
u'بكخنزير': u'بِكَخِنْزِيرٍ', #6
u'بكداء': u'بِكَدَاءٍ', #1
u'بكداء': u'بِكَدَاءَ', #1
u'بكدباء': u'بكدباء', #1
u'بكدباء': u'بِكَدُبَّاءَ', #1
u'بكدباء': u'بِكَدُبَّاءٍ', #6
u'بكدخول': u'بِكَدُخُولٍ', #1
u'بكدف': u'بِكَدُفٍّ', #1
u'بكدينه': u'بِكَدَيْنِهِ', #3
u'بكديوري': u'بكديوري', #1
u'بكديون': u'بِكَدْيَوْنٍ', #1
u'بكذ': u'بكذ', #1
u'بكذبت': u'بِكَذَبْتُ', #1
u'بكذبت': u'بِكَذَّبَتْ', #2
u'بكر': u'بَكْرً', #3
u'بكرابيس': u'بِكَرَابِيسِ', #2
u'بكرايد': u'بكرايد', #1
u'بكرباس': u'بِكِرْبَاسَ', #1
u'بكرباس': u'بِكِرْبَاسِ', #1
u'بكربن': u'بَكْرِبْنُ', #1
u'بكرحين': u'بَكْرٍحِينَ', #1
u'بكردوى': u'بكردوى', #1
u'بكرر': u'بِكَرَّرَ', #1
u'بكرس': u'بِكِرْسٍ', #1
u'بكرسف': u'بِكُرْسُفِ', #1
u'بكرسف': u'بِكُرْسُفٍ', #2
u'بكرسى': u'بِكُرْسِىٍّ', #3
u'بكرصاص': u'بِكَرَصَاصٍ', #6
u'بكرعاف': u'بِكَرُعَافٍ', #9
u'بكرفت': u'بكرفت', #2
u'بكرقال': u'بَكْرٍقَالَ', #1
u'بكركاز': u'بِكَرِكَازٍ', #5
u'بكرمان': u'بِكَرْمَانَ', #1
u'بكرمان،': u'بِكِرْمَانَ،', #1
u'بكرمحمد': u'بَكْرمُحَمّدُ', #1
u'بكرمحمد': u'بَكْرِمُحَمَّدُ', #1
u'بكرنافة': u'بِكُرْنَافَةٍ', #1
u'بكرها': u'بِكَرْهًا', #2
u'بكروس': u'بَكْرُوسٍ', #40
u'بكروعمر': u'بَكْرٍوَعُمَرَ', #1
u'بكرى': u'بِكَرًى', #1
u'بكرياس': u'بِكِرْيَاس', #1
u'بكريح': u'بِكَرِيحٍ', #1
u'بكريح': u'بِكَرِيحِ', #1
u'بكسابعة': u'بِكَسَابِعَةٍ', #6
u'بكساوى': u'بِكَسَاوَى', #1
u'بكسبح': u'بِكَسَبِّحْ', #8
u'بكسراويل': u'بِكَسَرَاوِيلَ', #1
u'بكسرقة': u'بِكَسَرِقَةٍ', #1
u'بكسعال': u'بِكَسُعَالٍ', #1
u'بكسفر': u'بِكَسَفَرٍ', #7
u'بكسلا': u'بِكَسَلًا', #1
u'بكسنة': u'بِكَسَنَةٍ', #1
u'بكشائي': u'بِكَشَائِي', #1
u'بكشايد': u'بكشايد', #1
u'بكشايي': u'بكشايي', #1
u'بكشبر': u'بِكَشِبْرٍ', #9
u'بكشبكة': u'بِكَشَبَكَةٍ', #1
u'بكشجرة': u'بِكَشَجَرَةٍ', #2
u'بكشخان': u'بِكَشْخَانَ', #2
u'بكشهر': u'بِكَشَهْرٍ', #38
u'بكصبغ': u'بِكَصَبْغٍ', #4
u'بكصبغ': u'بِكَصِبْغٍ', #9
u'بكصمات': u'بُكْصُمَاتٌ', #1
u'بكصمات': u'بِكِصْمَاتٍ', #1
u'بكصوم': u'بِكُصُومِ', #1
u'بكصوم': u'بِكَصَوْمِ', #6
u'بكضرب': u'بِكَضَرَبَ', #1
u'بكضرب': u'بِكَضَرْبٍ', #1
u'بكضربة': u'بِكَضَرْبَةٍ', #14
u'بكطحن': u'بِكَطَحْنِ', #2
u'بكطعام': u'بِكَطَعَامٍ', #6
u'بكطين': u'بِكَطِينٍ', #2
u'بكظهر': u'بِكَظَهْرِ', #20
u'بكع': u'بكع', #1
u'بكعا': u'بَكْعًا', #1
u'بكعت': u'بَكَعْت', #1
u'بكعتق': u'بِكَعِتْقٍ', #19
u'بكعظم': u'بِكَعَظْمِ', #1
u'بكعلف': u'بِكَعَلَفٍ', #1
u'بكعود': u'بِكَعُودٍ', #2
u'بكعيب': u'بِكَعَيْبٍ', #2
u'بكغبار': u'بِكَغُبَارٍ', #2
u'بكغزو': u'بِكَغَزْوِ', #1
u'بكغيبة': u'بِكَغَيْبَةٍ', #1
u'بكفاه': u'بِكُفَاهُ', #1
u'بكفاه': u'بِكَفَاهُ', #11
u'بكفت': u'بِكَفْتٍ', #1
u'بكفتن': u'بكفتن', #1
u'بكفرسخ': u'بِكَفَرْسَخٍ', #20
u'بكفلت': u'بِكَفَلْتُ', #11
u'بكفلت': u'بِكَفَلْت', #8
u'بكفو': u'بِكُفُوٍ', #1
u'بكفى': u'بِكَفَى', #5
u'بكقراءة': u'بِكَقِرَاءَةِ', #7
u'بكقرط': u'بِكَقُرْطٍ', #1
u'بكقصاص': u'بِكَقِصَاصٍ', #1
u'بكقضيب': u'بِكَقَضِيبٍ', #2
u'بككتابة': u'بِكَكِتَابَةٍ', #1
u'بكلا': u'بِكُلًّا', #1
u'بكلاباذ': u'بِكَلَابَاذَ', #1
u'بكلامين': u'بِكَلَامَيْنِ', #35
u'بكلاميهما': u'بِكَلَامَيْهِمَا', #3
u'بكلبس': u'بِكَلُبْسِ', #1
u'بكلبى': u'بِكَلْبِىَ', #2
u'بكلبى': u'بِكَلْبِى', #3
u'بكلطمة': u'بِكَلَطْمَةٍ', #1
u'بكلما': u'بِكُلَّمَا', #89
u'بكلوب': u'بِكَلُّوبٍ', #2
u'بكلوثة': u'بِكُلُوثَةٍ', #1
u'بكليداني': u'بكليداني', #1
u'بكليون': u'بِكَلْيُونٍ', #1
u'بكمالة': u'بِكِمَالَةِ', #1
u'بكمرض': u'بِكَمَرَضٍ', #12
u'بكمسمار': u'بِكَمِسْمَارٍ', #4
u'بكمشيئتها': u'بِكَمَشِيئَتِهَا', #6
u'بكمغصوب': u'بِكَمَغْصُوبٍ', #1
u'بكمل': u'بِكَمُلَ', #2
u'بكموت': u'بِكَمَوْتِ', #5
u'بكميراث': u'بِكَمِيرَاثٍ', #2
u'بكنار': u'بِكُنَارِ', #1
u'بكنت': u'بِكُنْتُ', #1
u'بكندزنش': u'بكندزنش', #1
u'بكنسج': u'بِكَنَسْجٍ', #1
u'بكنعال': u'بِكَنِعَالٍ', #1
u'بكنم': u'بكنم', #4
u'بكنى': u'بِكُنًى', #1
u'بكنيتى': u'بِكُنْيَتِى', #15
u'بكه': u'بَكّهُ', #1
u'بكه': u'بَكَّهْ', #1
u'بكه': u'بَكّهْ', #2
u'بكهبة': u'بِكَهِبَةٍ', #6
u'بكهدم': u'بِكَهَدْمٍ', #5
u'بكهوة': u'بِكَهُوَّةٍ', #6
u'بكوارته': u'بِكِوَارَتِهِ', #1
u'بكواهي': u'بكواهي', #1
u'بكوبة': u'بِكُوبَةٍ', #1
u'بكوثا': u'بكُوثا', #1
u'بكوثى': u'بِكُوثَى', #1
u'بكوثى،': u'بِكُوثَى،', #1
u'بكوجة': u'بكوجة', #1
u'بكوديعة': u'بِكَوَدِيعَةٍ', #1
u'بكورس': u'بكورس', #1
u'بكورس': u'بِكَوَرْسٍ', #3
u'بكورس': u'بِكَوْرَسٍ', #7
u'بكورستان': u'بكورستان', #1
u'بكوسج': u'بِكَوْسَجٍ', #12
u'بكوطء': u'بِكَوَطْءٍ', #1
u'بكوفه': u'بِكُوفَهْ', #1
u'بكولد': u'بِكَوَلَدٍ', #10
u'بكوم': u'بِكَوْمِ', #1
u'بكويد': u'بكويد', #1
u'بكويم': u'بكويم', #1
u'بكويند': u'بكويند', #1
u'بكى': u'بُكًى', #10
u'بكيء،': u'بَكِيءٍ،', #1
u'بكيا': u'بُكِيًّا', #2
u'بكيتلة': u'بِكَيْتَلَةَ', #1
u'بكيتن': u'بَكَيْتُنَّ', #1
u'بكيرا،': u'بُكَيْرًا،', #1
u'بكيرا': u'بُكَيْرًا', #47
u'بكيراين': u'بكيراين', #1
u'بكيرد': u'بكيرد', #2
u'بكيرش': u'بكيرش', #2
u'بكيرم': u'بكيرم', #1
u'بكيرى': u'بكيرى', #1
u'بكيزان': u'بِكِيزَانٍ', #1
u'بكيفيه': u'بِكَيْفَيْهِ', #1
u'بكيلون': u'بِكِيلُونَ', #1
u'بكيم': u'بَكِيمٌ', #3
u'بكيول': u'بِكَيّولِ', #1
u'بكيومين': u'بِكَيَوْمَيْنِ', #7
u'بلادح': u'بَلَادِحُ', #1
u'بلادح': u'بَلَادِحْ', #5
u'بلادكا': u'بِلَادُكَا', #1
u'بلار': u'بَلَّارٍ', #1
u'بلآس': u'بِلْآسِ', #1
u'بلاس': u'بَلَاس', #2
u'بلاساغون': u'بَلَاسَاغُونَ', #1
u'بلأضربن': u'بِلَأَضْرِبَنَّ', #1
u'بلاع': u'بَلَّاعُ', #3
u'بلاعي': u'بِلَاعِي', #1
u'بلأفعلن': u'بِلَأَفْعَلَن', #1
u'بلأفعلن': u'بِلَأَفْعَلَنَّ', #9
u'بلاقع،': u'بَلاقِعَ،', #1
u'بلاقع': u'بَلَاقِعَ', #15
u'بلاقع': u'بَلاَقِعَ', #3
u'بلاقع': u'بَلَاقِعُ', #6
u'بلأمته': u'بِلأْمَتِهِ', #1
u'بلأمته': u'بِلَأْمَتِهِ', #1
u'بلأمتي': u'بِلَأْمَتِي', #1
u'بلانة': u'بَلَّانَةً', #3
u'بلأنه': u'بِلَأَنَّهُ', #1
u'بلائى': u'بَلاَئِى', #1
u'بلاية': u'بلاية', #3
u'بلبأ': u'بِلِبَأٍ', #1
u'بلبإ': u'بِلِبَإٍ', #3
u'بلتاته': u'بِلُتَاتِهِ', #4
u'بلتعة': u'بلتعة', #3
u'بلتعة': u'بَلْتَعَة', #3
u'بلتعة،': u'بَلْتَعَةَ،', #3
u'بلتعة': u'بُلْتُعَةَ', #5
u'بلتعة': u'بَلْتَعَةَ', #77
u'بلتعه': u'بَلْتَعَه', #1
u'بلجمتي': u'بِلُجْمَتَيِ', #1
u'بلحاج': u'بِلْحَاجٍّ', #1
u'بلحارث': u'بَلْحَارِث', #1
u'بلحارث': u'بَلْحَارِثٍ', #1
u'بلحارث': u'بَلْحارثِ', #2
u'بلحارث': u'بِلْحَارِث', #2
u'بلحارث': u'بَلْحَارِثِ', #46
u'بلحاقة': u'بِلِحَاقَةِ', #2
u'بلحبلى': u'بَلْحُبْلَى', #1
u'بلحة': u'بَلَحَةٌ', #1
u'بلحت': u'بَلَحَتْ', #1
u'بلحرث': u'بَلّحَرث', #1
u'بلحسنه': u'بِلِحُسْنِهِ', #1
u'بلحمان': u'بلحمان', #1
u'بلحمان': u'بِلُحْمَانٍ', #8
u'بلحوا': u'بلّحُوا', #1
u'بلحوا': u'بَلّحُوا', #1
u'بلحوا': u'بَلَّحُوا', #1
u'بلحون': u'بِلُحُونِ', #3
u'بلحيى': u'بِلَحْيَىْ', #1
u'بلخا': u'بَلْخًا', #3
u'بلخدرة': u'بَلْخُدْرَةَ', #2
u'بلخزرج': u'بَلْخَزْرَج', #1
u'بلخزرج': u'بَلْخَزْرَجِ', #5
u'بلخش': u'بلخش', #1
u'بلخش': u'بَلْخَشٍ', #1
u'بلخش': u'بَلَخْشٍ', #2
u'بلخشان': u'بلخشان', #1
u'بلخيا': u'بَلْخِيًّا', #2
u'بلدانية': u'بُلْدَانِيَّةً', #1
u'بلدجي': u'بَلَدْجِيٍّ', #1
u'بلدح': u'بَلْدَحٍ', #7
u'بلدح': u'بَلْدَحَ', #9
u'بلدمة': u'بَلْدَمَةَ', #5
u'بلدوكي': u'بلدوكي', #1
u'بلديغ': u'بِلَدِيغٍ', #1
u'بلذمة': u'بلذمة', #1
u'بلذمة': u'بَلْذَمَةَ', #1
u'بلذمة': u'بُلْذُمَةُ', #2
u'بلزم': u'بِلَزِمَ', #2
u'بلزمانها': u'بِلُزْمَانِهَا', #1
u'بلزمه': u'بِلَزِمَهُ', #1
u'بلزمها': u'بِلَزِمَهَا', #1
u'بلزيق': u'بِلَزِيقِ', #1
u'بلسانى': u'بِلِسَانِى', #4
u'بلست': u'بِلَسْتِ', #3
u'بلست': u'بِلَسْتَ', #4
u'بلطفهقوله': u'بِلُطْفِهِقَوْلُهُ', #1
u'بلعاء': u'بَلْعَاءَ', #1
u'بلعاء': u'بَلْعَاءُ', #1
u'بلعام،': u'بَلْعَامَ،', #1
u'بلعام': u'بَلْعَامٍ', #2
u'بلعام': u'بَلْعَامَ', #2
u'بلعام': u'بَلْعَامُ', #4
u'بلعجلان،': u'بَلْعَجْلانَ،', #1
u'بلعجلان': u'بِلْعَجَلَان', #1
u'بلعجلان': u'بَلْعِجْلَانَ', #2
u'بلعجلان': u'بَلْعَجْلَانَ', #3
u'بلعدوية،': u'بَلْعَدَوِيَّةِ،', #1
u'بلعل': u'بِلَعَلّ', #1
u'بلعل': u'بِلَعَلَّ', #10
u'بلعلك': u'بِلَعَلَّكَ', #1
u'بلعلك': u'بِلَعَلَّك', #3
u'بلعله': u'بِلَعَلَّهُ', #3
u'بلعنبر': u'بَلْعَنْبَرٍ', #1
u'بلعنبر': u'بَلْعَنْبَرَ', #1
u'بلعنبر': u'بَلْعَنْبَرُ', #1
u'بلغما': u'بَلْغَمًا', #29
u'بلغمية': u'بَلْغَمِيَّةً', #1
u'بلغنى': u'بَلَغَنِى', #146
u'بلغنى': u'بلغنى', #2
u'بلغنيأن': u'بَلَغَنِيأَنَّ', #1
u'بلفاء': u'بِلَفَاءِ', #1
u'بلفاء': u'بِلِفَاءِ', #1
u'بلقائل': u'بِلِقَائِلٍ', #1
u'بلقته': u'بِلْقَتَهُ', #1
u'بلقحة': u'بِلِقْحَةٍ', #1
u'بلقحة': u'بِلَقْحَةٍ', #2
u'بلقحته': u'بِلِقْحَتِهِ', #2
u'بلقرن': u'بلقرن', #1
u'بلقع': u'بَلْقَعٍ', #1
u'بلقعا': u'بَلْقَعًا', #1
u'بلقعة': u'بَلْقَعَةٍ', #2
u'بلقوح': u'بِلَقُوحٍ', #4
u'بلقيمات': u'بِلُقَيْمَاتٍ', #1
u'بلقين': u'بُلْقِينٍ', #1
u'بلقين': u'بَلْقَيْنِ', #1
u'بلقين': u'بَلْقَيْنَ', #4
u'بلقين': u'بُلْقِينَ', #9
u'بلقينة': u'بُلْقِينَةَ', #1
u'بلكزة': u'بِلَكْزَةٍ', #1
u'بلمصطلق': u'بَلْمُصْطَلِقِ', #1
u'بلمصطلق': u'بَلْمُصْطَلِقَ', #3
u'بلمن': u'بِلِمَنْ', #1
u'بلنجر،': u'بِلَنْجَرٍ،', #1
u'بلنسية': u'بَلَنْسِيَةَ', #3
u'بلنك': u'بلنك', #1
u'بلنياس': u'بلنياس', #1
u'بلهجيم': u'بَلْهُجَيْمَ', #1
u'بلهجيم،': u'بَلْهُجَيْمَ،', #1
u'بلهجيم': u'بَلْهُجَيْمٍ', #4
u'بلهز': u'بلهز', #1
u'بلهيث': u'بِلْهِيثُ', #1
u'بلهيث': u'بِلْهَيْثٍ', #1
u'بلوعهم': u'بلوعهم', #1
u'بلولة': u'بُلُولَةٌ', #1
u'بلولة': u'بُلُولَةُ', #2
u'بلولتهما': u'بُلُولَتِهِمَا', #1
u'بلوى': u'بَلْوًى', #8
u'بلى': u'بِلًى', #8
u'بلئلا': u'بِلِئَلَّا', #2
u'بليالها': u'بِلِيَالِهَا', #1
u'بليالهن': u'بِلَيَالِهِنَّ', #1
u'بليإلى،': u'بِلَيَإلى،', #4
u'بليامين': u'بليامين', #1
u'بليجا': u'بَلِيجًا', #1
u'بليدع': u'بِلِيَدْعُ', #1
u'بليس': u'بِلِيسِ', #1
u'بليس': u'بِلَيْسَ', #6
u'بليست': u'بِلَيْسَتْ', #1
u'بليطة': u'بُلَيْطَةِ', #1
u'بليطة': u'بِلِيطَةِ', #3
u'بليطة': u'بِلِيطَةٍ', #5
u'بلىقوله': u'بَلَىقَوْلُهُ', #1
u'بليلة': u'بَلِيلَةً', #3
u'بليناس،': u'بَلِينَاسٍ،', #1
u'بماأوصى': u'بِمَاأَوْصَى', #1
u'بمات': u'بِمَاتَ', #5
u'بماتت': u'بِمَاتَتْ', #4
u'بماديانه': u'بماديانه', #1
u'بمأذونيته': u'بِمَأْذُونِيَّتِهِ', #1
u'بماذيانات': u'بِمَاذِيَانَاتِ', #1
u'بماذيانه': u'بماذيانه', #1
u'بمارساة': u'بِمَارَسَاةٍ', #1
u'بمازه': u'بِمَازَهْ', #2
u'بماشرته': u'بِمَاشِرَتِهِ', #1
u'بماغد': u'بِمَاغِدٍ', #1
u'بماكد': u'بِمَاكِدِ', #1
u'بماكد': u'بِمَاكِدٍ', #2
u'بمالكا': u'بِمَالِكَا', #1
u'بمالى': u'بِمَالِى', #12
u'بمأمونا': u'بِمَأْمُونًا', #2
u'بمانش': u'بمانش', #1
u'بمائتى': u'بِمِائَتَىْ', #2
u'بمائى': u'بِمَائِى', #1
u'بمبارأتها': u'بِمُبَارَأَتِهَا', #1
u'بمباضعة': u'بِمُبَاضَعَةِ', #6
u'بمباضعته': u'بِمُبَاضَعَتِهِ', #1
u'بمبانته': u'بِمُبَانَتِهِ', #2
u'بمباين': u'بِمُبَايَنٍ', #1
u'بمباين': u'بِمُبَايِنٍ', #2
u'بمباينة': u'بِمُبَايِنَةِ', #1
u'بمباينة': u'بِمُبَايَنَةِ', #8
u'بمباينه': u'بِمُبَايِنِهِ', #1
u'بمباينهما': u'بِمُبَايِنِهِمَا', #1
u'بمبتلى': u'بِمُبْتَلًى', #2
u'بمبعض': u'بِمُبَعَّضٍ', #5
u'بمبقاة': u'بِمُبْقَاةٍ', #1
u'بمبكرا': u'بِمُبَكِّرًا', #1
u'بمبهما': u'بِمُبْهَمًا', #1
u'بمبينان': u'بِمُبَيِّنَانِ', #1
u'بمتاركة': u'بِمُتَارَكَةُ', #2
u'بمتاركة': u'بِمُتَارَكَةٍ', #3
u'بمتاركة': u'بِمُتَارَكَةِ', #7
u'بمتاركتهم': u'بِمُتَارَكَتِهِمْ', #1
u'بمتاعة': u'بِمَتَاعَةِ', #1
u'بمتبدع،': u'بِمُتَبَدِّعٍ،', #1
u'بمتبعض': u'بِمُتَبَعِّضٍ', #1
u'بمتبعى': u'بِمُتَّبِعِىَّ', #1
u'بمتجز': u'بِمُتَجَزٍّ', #2
u'بمتصلا': u'بِمُتَّصِلًا', #2
u'بمتعبدون': u'بِمُتَعَبِّدُونَ', #1
u'بمتعديا': u'بِمُتَعَدِّيًا', #2
u'بمتعوهن': u'بِمَتِّعُوهُنَّ', #2
u'بمتفاحش': u'بِمُتَفَاحِشٍ', #1
u'بمتفاحشة': u'بِمُتَفَاحِشَةٍ', #1
u'بمتمحض': u'بِمُتَمَحِّضٍ', #1
u'بمتناضلين': u'بِمُتَنَاضِلَيْنِ', #1
u'بمتناولا': u'بِمُتَنَاوَلًا', #1
u'بمتهجى': u'بِمُتَهَجًّى', #1
u'بمتى': u'بِمَتَى', #35
u'بمثافنتهم': u'بِمُثَافَنَتِهِمْ', #1
u'بمثبوت': u'بِمَثْبُوتٍ', #3
u'بمثغور': u'بِمَثْغُورٍ', #1
u'بمثلا': u'بمثلا', #1
u'بمثلا': u'بِمَثَلًا', #1
u'بمثلة': u'بِمُثْلَةٍ', #18
u'بمثلة': u'بِمُثْلَةِ', #2
u'بمثلهإلا': u'بِمِثْلِهِإِلا', #1
u'بمثلهأن': u'بِمِثْلِهِأَنْ', #1
u'بمثلهفإنه': u'بِمِثْلِهِفَإِنَّهُ', #1
u'بمثلهومن': u'بِمِثْلِهِوَمَنْ', #1
u'بمثمون': u'بِمَثْمُونِ', #1
u'بمثمون': u'بِمَثْمُونٍ', #13
u'بمثمونة': u'بِمَثْمُونَةٍ', #1
u'بمثناتين': u'بِمُثَنَّاتَيْنِ', #5
u'بمثنى': u'بِمَثْنًى', #2
u'بمثنى': u'بِمُثَنًّى', #2
u'بمجاديح': u'بِمَجَادِيحَ', #1
u'بمجاديح': u'بِمَجَادِيحِ', #6
u'بمجاعلة': u'بِمُجَاعَلَةِ', #4
u'بمجانا': u'بِمَجَّانًا', #3
u'بمجبوب': u'بِمَجْبُوبٍ', #7
u'بمجرى': u'بِمَجْرًى', #2
u'بمجرى': u'بِمُجْرًى', #6
u'بمجزز': u'بِمُجَزِّزٍ', #2
u'بمجلسى': u'بِمَجْلِسِى', #1
u'بمجىء': u'بِمَجِىءِ', #1
u'بمجيدل': u'بِمُجَيْدَلِ', #2
u'بمحاباه': u'بِمُحَابَاهُ', #1
u'بمحاجيره': u'بِمَحَاجِيرِهِ', #1
u'بمحاز': u'بِمُحَازٍ', #1
u'بمحاس': u'بِمَحَاسِّ', #1
u'بمحاسدته': u'بِمُحَاسَدَتِهِ', #1
u'بمحاصة': u'بِمُحَاصَّةِ', #3
u'بمحالا': u'بِمَحَالًّا', #1
u'بمحترما': u'بِمُحْتَرَمًا', #1
u'بمحتوش': u'بِمُحْتَوِشٍ', #1
u'بمحجن': u'بِمِحْجَنٍ', #28
u'بمحجن': u'بِمِحْجَنِ', #4
u'بمحجنه': u'بِمِحْجَنِهِ', #41
u'بمحجنه،': u'بِمِحْجَنِهِ،', #5
u'بمحجني،': u'بِمِحْجَنِي،', #1
u'بمحجنى': u'بِمِحْجَنِى', #2
u'بمحجني': u'بِمِحْجَنِي', #5
u'بمحرس': u'بِمَحْرِسٍ', #1
u'بمحرس': u'بِمُحْرِسٍ', #1
u'بمحرما': u'بِمُحْرِمًا', #1
u'بمحصر': u'بِمُحْصَرٍ', #21
u'بمحصرة': u'بِمُحْصَرَةٍ', #3
u'بمحمودية': u'بِمَحْمُودِيَّةِ', #1
u'بمحيصة': u'بِمُحَيِّصَةَ', #1
u'بمخامر': u'بِمُخَامِرٍ', #1
u'بمخثقه': u'بِمُخَثّقِهِ', #1
u'بمخرش': u'بِمِخْرَشٍ', #1
u'بمخرش': u'بِمِخْرَشِ', #1
u'بمخرق': u'بِمُخَرَّقٍ', #1
u'بمخرق': u'بِمُخْرَقٍ', #1
u'بمخرقة': u'بِمُخْرِقَةٍ', #1
u'بمخرمة': u'بِمَخْرَمَةَ', #1
u'بمخروصها': u'بِمَخْرُوصِهَا', #1
u'بمخصوصية': u'بِمَخْصُوصِيَّةٍ', #1
u'بمخمصة': u'بِمَخْمَصَةٍ', #2
u'بمخياط': u'بِمِخْيَاطٍ', #1
u'بمدرى': u'بِمِدْرَى', #1
u'بمدعى': u'بِمُدَّعًى', #3
u'بمدهامتان': u'بِمُدْهَامَّتَانِ', #1
u'بمدى': u'بِمَدًى', #1
u'بمذبة': u'بِمِذَبَّةٍ', #1
u'بمذفف': u'بِمُذَفِّفٍ', #6
u'بمذكاة': u'بِمُذَكَّاةٍ', #16
u'بمذكاة': u'بِمُذَكَّاةِ', #3
u'بمذكاته': u'بِمُذَكَّاتِهِ', #1
u'بمذكى': u'بِمُذَكًّى', #1
u'بمذهوبا': u'بِمَذْهُوبًا', #2
u'بمذي': u'بِمَذْيٍ', #5
u'بمرأة': u'بِمَرْأَةٍ', #2
u'بمراعات': u'بِمُرَاعَاتِ', #2
u'بمراعى': u'بِمُرَاعًى', #3
u'بمراغمة': u'بِمُرَاغَمَةِ', #1
u'بمران': u'بِمُرَّانَ', #1
u'بمرآه': u'بِمَرْآهُ', #2
u'بمرأى': u'بِمَرْأًى', #35
u'بمرتبا': u'بِمُرَتَّبًا', #2
u'بمرتث': u'بِمُرْتَثٍّ', #2
u'بمرجة': u'بِمَرْجَةِ', #1
u'بمرجوحية': u'بِمَرْجُوحِيَّةِ', #1
u'بمرجوحية': u'بِمَرْجُوحِيَّةٍ', #7
u'بمرجوحيته': u'بِمَرْجُوحِيَّتِهِ', #2
u'بمرحبا': u'بِمَرْحَبًا', #2
u'بمردا': u'بِمَرْدَا', #1
u'بمردبيش': u'بمردبيش', #1
u'بمردوازوي': u'بمردوازوي', #1
u'بمردى': u'بمردى', #1
u'بمرسولها': u'بِمَرْسُولِهَا', #1
u'بمرط': u'بِمُرْطِ', #1
u'بمرط': u'بِمِرْطٍ', #1
u'بمرعوش': u'بِمَرْعُوشٍ', #2
u'بمرعى': u'بِمَرْعًى', #7
u'بمرغينان': u'بِمَرْغِينَانَ', #2
u'بمرقناة': u'بِمَرِّقَنَاةَ', #1
u'بمرقوق': u'بِمَرْقُوقٍ', #1
u'بمركد': u'بِمَرْكَدِ', #2
u'بمرماة': u'بِمِرْمَاةٍ', #1
u'بمروآته': u'بِمُرُوآتِهِ', #1
u'بمروان': u'بمروان', #2
u'بمروان': u'بِمَرْوَانَ', #4
u'بمروط': u'بِمُرُوطٍ', #1
u'بمروطها': u'بِمُرُوطِهَا', #1
u'بمروطهن،': u'بِمُرُوطِهِنَّ،', #2
u'بمروطهن': u'بِمُرُوطِهِنَّ', #29
u'بمريضا': u'بِمَرِيضًا', #2
u'بمزحة': u'بِمَزْحَةٍ', #1
u'بمزد': u'بمزد', #2
u'بمزدلف': u'بِمُزْدَلِفْ', #1
u'بمزراق': u'بِمِزْرَاقٍ', #1
u'بمزراقه': u'بِمِزْرَاقِهِ', #1
u'بمزراقي': u'بِمِزْرَاقِي', #1
u'بمزعفر': u'بِمُزَعْفَرٍ', #3
u'بمزفوفة': u'بِمَزْفُوفَةٍ', #1
u'بمزهق': u'بِمُزْهِقٍ', #6
u'بمسامتتها': u'بِمُسَامَتَتِهَا', #2
u'بمسبلة': u'بِمُسَبَّلَةٍ', #4
u'بمسبوقيته': u'بِمَسْبُوقِيَّتِهِ', #1
u'بمسبوكا': u'بِمَسْبُوكًا', #1
u'بمسبيا': u'بِمَسْبِيًّا', #1
u'بمستثنى': u'بِمُسْتَثْنًى', #4
u'بمستحاضة': u'بِمُسْتَحَاضَةٍ', #1
u'بمستحشفة': u'بِمُسْتَحْشِفَةٍ', #2
u'بمستحقا': u'بِمُسْتَحَقًّا', #3
u'بمستغنى': u'بِمُسْتَغْنًى', #25
u'بمستفعلن': u'بِمُسْتَفْعِلُنْ', #1
u'بمستقذر': u'بِمُسْتَقْذَرٍ', #2
u'بمستقذرة': u'بِمُسْتَقْذَرَةٍ', #3
u'بمستقرضه': u'بِمُسْتَقْرِضِهِ', #1
u'بمستلحقه': u'بِمُسْتَلْحِقِهِ', #2
u'بمستندا': u'بِمُسْتَنِدًا', #4
u'بمستنكح': u'بِمُسْتَنْكَحٍ', #4
u'بمستنكح': u'بِمُسْتَنْكِحٍ', #6
u'بمستوعبا': u'بِمُسْتَوْعِبًا', #3
u'بمستوى': u'بِمُسْتَوًى', #5
u'بمسجدى': u'بِمَسْجِدَىْ', #1
u'بمسجدى': u'بِمَسْجِدِى', #1
u'بمسجديته': u'بِمَسْجِدِيَّتِهِ', #2
u'بمسحين': u'بِمِسْحَيْنِ', #2
u'بمسعط': u'بِمِسْعَطٍ', #4
u'بمسقى': u'بِمَسْقًى', #1
u'بمسمى': u'بِمُسَمًّى', #15
u'بمسناة': u'بِمُسَنَّاةٍ', #3
u'بمسئر': u'بِمُسْئِرٍ', #2
u'بمشاقص،': u'بِمَشَاقِصَ،', #1
u'بمشاقص': u'بِمَشَاقِصَ', #17
u'بمشتراه': u'بِمُشْتَرَاهُ', #3
u'بمشتركا': u'بِمُشْتَرَكًا', #1
u'بمشترى': u'بِمُشْتَرًى', #3
u'بمشترى': u'بِمُشْتَرَى', #6
u'بمشتهى': u'بِمُشْتَهًى', #2
u'بمشد': u'بِمِشَدِّ', #5
u'بمشرى': u'بِمُشْرَى', #1
u'بمشريه': u'بِمُشْرِيهِ', #4
u'بمشريه': u'بِمَشْرِيِّهِ', #6
u'بمشعور': u'بِمَشْعُورٍ', #1
u'بمشغولية': u'بِمَشْغُولِيَّةِ', #1
u'بمشقص،': u'بمِشْقَصٍ،', #1
u'بمشقص': u'بِمِشْقَصِ', #1
u'بمشقص،': u'بِمِشْقَصٍ،', #1
u'بمشقص': u'بِمِشْقَصٍ', #50
u'بمشهورية': u'بِمَشْهُورِيَّةِ', #9
u'بمشهوريته': u'بِمَشْهُورِيَّتِهِ', #33
u'بمشى': u'بِمَشْىِ', #1
u'بمشية': u'بِمِشْيَةِ', #3
u'بمشيرا': u'بِمُشِيرًا', #1
u'بمشيئتان': u'بِمَشِيئَتَانِ', #1
u'بمصاري': u'بِمَصَارِيّ', #1
u'بمصاري': u'بِمَصَارِيِّ', #1
u'بمصدان': u'بِمُصْدَانَ', #1
u'بمصدان': u'بِمُصْدَانِ', #1
u'بمصراة': u'بِمُصَرَّاةٍ', #1
u'بمصرخكم': u'بِمُصْرِخِكُمْ', #2
u'بمصرخي': u'بِمُصْرِخِيَّ', #7
u'بمصلوقه': u'بِمَصْلُوقِهِ', #1
u'بمصلى': u'بِمُصَلًّى', #17
u'بمصيبتى': u'بِمُصِيبَتِى', #3
u'بمصيطر': u'بِمُصَيْطِرٍ', #5
u'بمصيع': u'بِمَصْيَعِ', #1
u'بمضبع': u'بِمَضْبَعِ', #1
u'بمضت': u'بِمَضَتْ', #2
u'بمضفر': u'بِمُضَفَّرٍ', #1
u'بمضمونا': u'بِمَضْمُونًا', #1
u'بمضى': u'بِمُضِىِّ', #1
u'بمطلقا': u'بِمُطْلَقًا', #7
u'بمطلوبية': u'بَمَطْلُوبِيَّةِ', #1
u'بمطلوبية': u'بِمَطْلُوبِيَّةِ', #3
u'بمطموع': u'بِمَطْمُوعٍ', #3
u'بمطمئنا': u'بِمُطْمَئِنًّا', #2
u'بمظعن': u'بِمُظْعِنٍ', #1
u'بمعابل': u'بِمَعَابِلَ', #2
u'بمعاجرهن': u'بِمَعَاجِرِهِنَّ', #1
u'بمعاطاة': u'بِمُعَاطَاةِ', #1
u'بمعاطاة': u'بِمُعَاطَاةٍ', #28
u'بمعاقد': u'بِمُعَاقَدِ', #1
u'بمعاقد': u'بِمَعَاقِدِ', #4
u'بمعاقر': u'بِمُعَاقِرٍ', #4
u'بمعبلة': u'بِمَعْبَلَةٍ', #1
u'بمعتلج': u'ِبِمُعْتَلَجِ', #1
u'بمعتلج': u'بِمُعْتَلَجِ', #6
u'بمعتمل': u'بِمُعْتَمِلٍ', #1
u'بمعراض': u'بِمِعْرَاضٍ', #4
u'بمعزلة': u'بِمَعْزِلَةٍ', #2
u'بمعصفر': u'بِمُعَصْفَرٍ', #2
u'بمعطن': u'بِمَعْطَنٍ', #1
u'بمعطن': u'بِمَعْطِنٍ', #4
u'بمعطن': u'بِمَعْطِنِ', #7
u'بمعقر': u'بِمُعْقِرِ', #1
u'بمعلولية': u'بِمَعْلُولِيَّةِ', #1
u'بمعلوميته': u'بِمَعْلُومِيَّتِهِ', #1
u'بمعمولية': u'بِمَعْمُولِيَّةِ', #1
u'بمعنى': u'بِمَعْنًى', #797
u'بمغابنة': u'بِمُغَابَنَةٍ', #1
u'بمغث': u'بِمَغْثِ', #1
u'بمغدى': u'بِمَغْدَى', #4
u'بمغرة': u'بِمِغْرَةٍ', #1
u'بمغرة': u'بِمَغْرَةٍ', #9
u'بمغرف': u'بِمُغْرِفِ', #1
u'بمغلوث': u'بِمَغْلُوثٍ', #2
u'بمغمى': u'بِمُغْمًى', #1
u'بمفاخذة': u'بِمُفَاخَذَةٍ', #8
u'بمفتات': u'بِمُفْتَاتٍ', #1
u'بمفتصد': u'بِمُفْتَصِدٍ', #1
u'بمفصلا': u'بِمُفَصَّلًا', #1
u'بمفصلا': u'بِمُفَصِّلًا', #1
u'بمفضولا': u'بِمَفْضُولًا', #2
u'بمفضوليته': u'بِمَفْضُولِيَّتِهِ', #2
u'بمفضى': u'بِمُفْضَى', #4
u'بمفلت': u'بمُفْلِتٍ', #1
u'بمفلت': u'بِمُفْلِتٍ', #3
u'بمفيت': u'بِمُفِيتٍ', #9
u'بمفيتة': u'بِمُفِيتَةٍ', #1
u'بمقاعدته': u'بِمُقَاعَدَتِهِ', #2
u'بمقتضى': u'بِمُقْتَضًى', #4
u'بمقتفى': u'بِمُقْتَفَى', #1
u'بمقصرSأم': u'بِمُقَصّرِSأُمّ', #1
u'بمقفى': u'بِمُقَفًّى', #1
u'بمقمع': u'بمقمع', #1
u'بمقمع': u'بِمِقْمَعٍ', #1
u'بمقمع': u'بِمِقْمَعِ', #1
u'بمقيس': u'بِمِقْيَسِ', #3
u'بمقيس': u'بِمَقِيسٍ', #4
u'بمقيما': u'بِمُقِيمًا', #1
u'بمكاتبتى': u'بِمُكَاتَبَتِى', #1
u'بمكاتلهم': u'بِمَكَاتِلِهِمْ', #1
u'بمكافئا': u'بِمُكَافِئًا', #1
u'بمكايسة': u'بِمُكَايَسَةٍ', #1
u'بمكترى': u'بِمُكْتَرًى', #1
u'بمكترى': u'بِمُكْتَرَى', #1
u'بمكتها': u'بِمَكّتِهَا', #2
u'بمكرز': u'بِمِكْرَزٍ', #1
u'بمكرهمو': u'بِمَكْرِهِمُو', #1
u'بمكفرا': u'بِمُكَفَّرًا', #1
u'بمكلب،': u'بِمُكَلَّبٍ،', #1
u'بمكلب': u'بِمُكَلَّبٍ', #4
u'بمكلفا': u'بِمُكَلَّفًا', #1
u'بمكيدة،': u'بِمَكِيدَةً،', #1
u'بمكيلا': u'بِمَكِيلًا', #3
u'بملأة': u'بِمِلْأَةٍ', #1
u'بملاغات': u'بِمُلَاغَاتٍ', #1
u'بملاغات': u'بِمِلَاغَاتِ', #1
u'بملحوب': u'بِمَلْحُوبِ', #3
u'بملزوم': u'بِمَلْزُومٍ', #1
u'بملزوم': u'بِمَلْزُومِ', #1
u'بملزومه': u'بِمَلْزُومِهِ', #2
u'بملزومها': u'بِمَلْزُومِهَا', #1
u'بملكا': u'بِمَلَكَا', #3
u'بملهكة': u'بملهكة', #1
u'بمما': u'بِمِمَّا', #1
u'بمماتة': u'بِمُمَاتَةٍ', #1
u'بمملوسة': u'بِمَمْلُوسَةٍ', #1
u'بمن': u'بِمِنً', #1
u'بمنابة': u'بِمُنَابَةِ', #1
u'بمناكرته': u'بِمُنَاكَرَتِهِ', #2
u'بمنبج،': u'بِمَنْبِجٍ،', #1
u'بمنبج،': u'بِمَنْبِجَ،', #2
u'بمنبج': u'بِمَنْبِجَ', #3
u'بمنبها': u'بِمُنَبِّهًا', #1
u'بمنبوبة': u'بمنبوبة', #1
u'بمنتفل': u'بِمُنْتَفِلٍ', #1
u'بمنتقبة': u'بِمُنْتَقِبَةٍ', #1
u'بمنجرد': u'بِمُنْجَرَدٍ', #1
u'بمنجرد': u'بِمُنْجَرِدِ', #2
u'بمنجزم': u'بِمُنْجَزِمٍ', #1
u'بمنذ': u'بِمُنْذُ', #1
u'بمنزلتى': u'بِمَنْزِلَتِى', #2
u'بمنسوخية': u'بِمَنْسُوخِيَّةِ', #2
u'بمنسوخيته': u'بِمَنْسُوخِيَّتِهِ', #1
u'بمنصلي': u'بِمُنْصُلِي', #1
u'بمنقاش': u'بِمِنْقَاشٍ', #6
u'بمنقش': u'بِمُنَقَّشٍ', #2
u'بمنقود': u'بِمَنْقُودٍ', #1
u'بمنكبى': u'بِمَنْكِبِى', #2
u'بمنلا': u'بِمُنْلَا', #1
u'بمنهمة': u'بِمَنْهَمَةِ', #3
u'بمنى': u'بِمنًى', #1
u'بمنى': u'بمِنًى', #1
u'بمنى': u'بِمِنًىٍٍٍٍ', #1
u'بمنى': u'بِمِنًّى', #1
u'بمنى؟': u'بِمِنًى؟', #1
u'بمنى': u'بِمِنًى', #1335
u'بمنى،': u'بِمِنًى،', #23
u'بمني': u'بِمِنًي', #6
u'بمهايأة': u'بِمُهَايَأَةٍ', #13
u'بمهايئات': u'بِمُهَايَئَاتٍ', #1
u'بمهروي': u'بمهروي', #2
u'بمهرويه': u'بِمَهْرَوَيْهِ', #2
u'بمهما': u'بِمَهْمَا', #3
u'بمهيعة': u'بِمَهْيَعَة', #1
u'بمهيعة': u'بِمَهْيَعَةَ', #3
u'بمواجب': u'بِمَوَاجِبِ', #1
u'بمواجب': u'بِمُوَاجِبِ', #2
u'بمواجبه': u'بِمَوَاجِبِهِ', #1
u'بمواجبه': u'بِمُوَاجِبِهِ', #1
u'بمواجبهن': u'بِمُوَاجَبِهِنَّ', #1
u'بمواخاته': u'بِمُوَاخَاتِهِ', #1
u'بمواخيك': u'بِمُوَاخِيك', #1
u'بمؤاذاة': u'بِمُؤَاذَاةِ', #2
u'بمؤازاة': u'بِمُؤَازَاةِ', #2
u'بمواضح': u'بِمَوَاضِحَ', #1
u'بمواضعات': u'بِمُوَاضَعَاتِ', #1
u'بمواضعة': u'بِمُوَاضَعَةٍ', #6
u'بمواضعتها': u'بِمُوَاضَعَتِهَا', #1
u'بمؤالف': u'بِمُؤَالِفٍ', #1
u'بمؤبرة': u'بِمُؤَبَّرَةٍ', #1
u'بمؤتة': u'بمُؤتة', #1
u'بمؤتة': u'بمؤْتة', #1
u'بمؤتة': u'بِمُؤْتَةِ', #13
u'بمؤتة': u'بِمُؤْتَةَ', #3
u'بمؤتة': u'بِمُؤْتَة', #8
u'بمؤتلي': u'بِمُؤْتَلِي', #2
u'بمؤتم': u'بِمُؤْتَمٍ', #1
u'بمؤتم': u'بِمُؤْتَمٍّ', #1
u'بموتين': u'بِمَوْتَيْنِ', #7
u'بموثبان': u'بِمَوْثَبَانَ', #1
u'بموجبيته': u'بِمُوجِبِيَّتِهِ', #1
u'بموجد': u'بِمُوجِدٍ', #1
u'بمورود': u'بِمَوْرُودٍ', #1
u'بموصى': u'بِمُوصًى', #2
u'بموضعمدة': u'بِمَوْضِعٍمُدَّةَ', #1
u'بموضعهينتظر': u'بِمَوْضِعِهِيَنْتَظِرُ', #1
u'بموطوء': u'بِمَوْطُوءٍ', #1
u'بموطوءة': u'بِمَوْطُوءَةِ', #1
u'بموطوءة': u'بِمَوْطُوءَةٍ', #18
u'بموطوءته': u'بِمَوْطُوءَتِهِ', #5
u'بموعى': u'بِمُوعًى', #2
u'بمؤل': u'بِمُؤْلٍ', #13
u'بمولاى': u'بِمَوْلاَىَ', #1
u'بمولى': u'بِمُوَلًّى', #1
u'بمولى': u'بِمَوْلًى', #8
u'بموم': u'بِمُومٍ', #3
u'بموماة': u'بِمَوْمَاةِ', #3
u'بمومئ': u'بِمُومِئٍ', #9
u'بمؤناته': u'بِمُؤْنَاتِهِ', #1
u'بمؤنة': u'بِمُؤْنَةٍ', #42
u'بمؤنة': u'بِمُؤْنَةِ', #77
u'بمؤنته': u'بِمُؤْنَتِهِ', #36
u'بمؤنتها': u'بِمُؤْنَتِهَا', #13
u'بمؤنتهم': u'بِمُؤْنَتِهِمْ', #1
u'بمؤنتهما': u'بِمُؤْنَتِهِمَا', #3
u'بمئلات': u'بِمِئْلَاتٍ', #1
u'بمئونة': u'بِمَئُونَةِ', #1
u'بميا': u'بميا', #1
u'بميافارقين': u'بِمَيَّافارِقِينَ', #1
u'بميتا': u'بِمَيِّتًا', #1
u'بميتا': u'بِمَيْتًا', #1
u'بميرة': u'بِمِيرَةٍ', #2
u'بميرم': u'بميرم', #1
u'بميضاة': u'بِمِيضَاةٍ', #1
u'بميضأة': u'بِمِيضَأَةٍ', #9
u'بميفعة': u'بِمَيْفَعَةٍ', #1
u'بميفعة': u'بِمَيْفَعَةَ', #3
u'بميكائيل': u'بِمِيكَائِيلَ', #1
u'بميلهإلى': u'بِمَيْلِهِإِلَى', #1
u'بنSعدنان': u'بْنِSعَدْنَانُ', #1
u'بنSعود': u'بْنِSعَوْدٌ', #1
u'بنSنزار': u'بْنِSنِزَارٌ', #1
u'بن': u'بْنً', #1
u'بنآء': u'بِنَآءً', #1
u'بناتى': u'بَنَاتِى', #3
u'بناجزا': u'بِنَاجِزًا', #1
u'بناجش': u'بِنَاجِشٍ', #1
u'بناجون': u'بِنَاجُونَ', #1
u'بناحق': u'بناحق', #3
u'بنادقة': u'بَنَادِقَةً', #1
u'بنادقة': u'بَنَادِقَةٌ', #3
u'بنادقة': u'بَنَادِقَةٍ', #3
u'بنازعى': u'بِنَازِعِى', #1
u'بناسوت': u'بِنَاسُوتِ', #2
u'بناسيا': u'بِنَاسِيًا', #1
u'بنافعى': u'بِنَافِعِى', #1
u'بناقتى': u'بِنَاقَتِى', #2
u'بنالحارث': u'بْنِالْحَارِثُ', #1
u'بنالماجشون': u'بْنِالْمَاجِشُونِ', #1
u'بنانة': u'بَنَانَةٌ', #1
u'بنانة': u'بَنَانَةُ', #1
u'بنانة': u'بُنَانَةَ', #2
u'بنانة': u'بُنَانَةُ', #7
u'بناوله': u'بِنَاوَلَهُ', #2
u'بناوليني': u'بِنَاوِلِينِي', #1
u'بنبحينة،': u'بْنُبُحَيْنَةَ،', #1
u'بنبشتن': u'بنبشتن', #1
u'بنبطى': u'بِنَبَطِىٍّ', #1
u'بنبى': u'بِنَبِىِّ', #6
u'بنتاء': u'بِنِتَاءِ', #1
u'بنتى': u'بِنْتِى', #1
u'بنجاز': u'بِنَجَازِ', #1
u'بنجازه': u'بِنِجَازِهِ', #1
u'بنجح': u'بِنُجْحٍ', #1
u'بنجشه': u'بِنَجْشِهِ', #3
u'بنجلوس': u'بنجلوس', #1
u'بنحن': u'بِنَحْنُ', #1
u'بنخرج': u'بِنُخْرِجُ', #1
u'بنداد': u'بنداد', #1
u'بندار': u'بُنْدَار', #1
u'بندار': u'بِنَدَارٌ', #1
u'بندار،': u'بُنْدَارُ،', #1
u'بندار': u'بُنْدَارَ', #2
u'بندار': u'بِنْدَارٌ', #2
u'بندار،': u'بندار،', #27
u'بندار': u'بندار', #3
u'بندار': u'بُنْدَارُ', #3
u'بندار': u'بُنْدَارِ', #4
u'بندار': u'بُنْدار', #5
u'بندار': u'بِنْدَارٍ', #5
u'بندار': u'بُنْدَارٍ', #59
u'بندار': u'بُنْدَارٌ', #67
u'بندار،': u'بُنْدَارٌ،', #87
u'بندار،': u'بُنْدَارٍ،', #94
u'بندبا': u'بِنَدْبًا', #2
u'بندبيتها': u'بِنَدْبِيَّتِهَا', #1
u'بندة': u'بندة', #1
u'بندتها': u'بِنِدَّتِهَا', #1
u'بندد': u'بندد', #1
u'بندقانيا': u'بُنْدُقَانِيًّا', #1
u'بندن': u'بندن', #1
u'بندند': u'بندند', #1
u'بندنيجين': u'بَنْدَنِيجَيْنِ', #1
u'بنرم': u'بنرم', #1
u'بنزديك': u'بنزديك', #3
u'بنزعت': u'بِنُزِعَتْ', #2
u'بنزلا': u'بِنَزَلَا', #1
u'بنسراقة،': u'بْنُسُرَاقَةَ،', #1
u'بنسع': u'بِنِسْعِ', #2
u'بنسعة،': u'بِنِسْعَةٍ،', #1
u'بنسعة': u'بِنِسْعَةٍ', #7
u'بنسعته،': u'بِنِسْعَتِهِ،', #1
u'بنسعته': u'بِنِسْعَتِهِ', #7
u'بنشا': u'بِنَشًا', #1
u'بنصحا': u'بِنُصْحًا', #1
u'بنصرانى': u'بِنَصْرَانِىٍّ', #1
u'بنصوا': u'بِنَصُّوا', #1
u'بنصيبا': u'بِنَصِيبًا', #1
u'بنصيبى': u'بِنَصِيبِى', #2
u'بنضوض': u'بِنُضُوضِ', #3
u'بنضوض': u'بِنَضُوضِ', #6
u'بنضوضه': u'بِنَضُوضِهِ', #1
u'بنطاة': u'بِنَطَاةَ', #2
u'بنظرا': u'بِنَظَرًا', #1
u'بنظروا': u'بِنَظَرُوا', #1
u'بنعثل،': u'بِنَعْثَلٍ،', #1
u'بنعف': u'بِنَعْفِ', #1
u'بنعفان': u'بْنِعَفَّانَ', #1
u'بنعفها': u'بِنَعْفِهَا', #1
u'بنعلى': u'بِنَعْلَىَّ', #1
u'بنعمت': u'بنعمت', #1
u'بنعمل': u'بِنَعْمَلُ', #1
u'بنعيمان': u'بِنُعَيْمَانَ', #1
u'بنغاشي': u'بِنُغَاشِي', #1
u'بنفاه': u'بِنَفَاهُ', #1
u'بنفضالةالأنصاري،': u'بْنِفَضَالَةَالأَنْصَارِيُّ،', #1
u'بنفضتين': u'بِنَفْضَتَيْنِ', #1
u'بنفطويه': u'بِنَفْطَوَيْهِ', #1
u'بنفعا': u'بِنَفْعًا', #1
u'بنفعين': u'بِنَفْعَيْنِ', #1
u'بنفى': u'بِنَفَى', #1
u'بنفى': u'بِنَفْىِ', #2
u'بنفيع': u'بِنُفَيْع', #1
u'بنقاضه': u'بِنِقَاضِهِ', #1
u'بنقصت': u'بِنَقَصَتْ', #2
u'بنكحت': u'بِنَكَحْت', #1
u'بنماز': u'بنماز', #1
u'بنهاح': u'بْنِهاحٍ', #1
u'بنهارا': u'بِنَهَارًا', #1
u'بنهاوند': u'بنَهاوَنْد', #1
u'بنهاوند،': u'بِنَهَاوَنْدَ،', #1
u'بنهاوند': u'بنهاوند', #2
u'بنهاوند': u'بِنَهَاوَنْدَ', #4
u'بنهشة': u'بِنَهْشَةِ', #2
u'بنوإسرائيل': u'بَنُوَإِسْرَائِيلَ', #1
u'بنواصى': u'بِنَوَاصِى', #5
u'بنواقض': u'بِنَوَاقِضِ', #3
u'بنواقضه': u'بِنَوَاقِضِهِ', #1
u'بنورة': u'بِنُورَةِ', #1
u'بنورة': u'بِنَوْرَةٍ', #12
u'بنورة': u'بِنُورَةٍ', #32
u'بنوسيده': u'بنوسيده', #1
u'بنوشتن': u'بنوشتن', #1
u'بنوغفار': u'بَنُوغِفَارٍ', #1
u'بنوغفار،': u'بَنَوْغِفَارٍ،', #1
u'بنوفر': u'بنوفر', #1
u'بنوم29358id': u'بنوم29358id', #1
u'بنوى': u'بِنَوًى', #2
u'بنويت': u'بِنَوَيْت', #2
u'بنويت': u'بِنَوَيْتُ', #3
u'بنياحة': u'بِنِيَاحَةٍ', #2
u'بنياحة': u'بِنِيَاحَةِ', #3
u'بنياحته': u'بِنِيَاحَتِهِ', #1
u'بنيإسرائيل': u'بَنِيإِسْرَائِيلَ', #1
u'بنيتة': u'بِنِيتَةِ', #1
u'بنيتى': u'بُنَيَّتِى', #2
u'بنيخامر': u'بْنُيَخَامِرَ', #1
u'بنيرمايه': u'بنيرمايه', #2
u'بنيسابور،': u'بِنَيْسَابُورَ،', #1
u'بنيسابور': u'بِنَيْسَابُورَ', #91
u'بنيسابوري،': u'بنيسابوري،', #1
u'بنيق': u'بِنِيقِ', #4
u'بنيلة': u'بِنِيلَةٍ', #4
u'بنيم': u'بنيم', #1
u'بنيم': u'بِنِيمِ', #2
u'بنينوى': u'بنِينُوَى', #1
u'بنيئة': u'بِنِيئَةٍ', #1
u'بهSجميل': u'بِهِSجَمِيلُ', #1
u'بهاSكداء': u'بِهَاSكَدَاءُ', #1
u'بهاالنبي': u'بِهَاالنَّبِيُّ', #1
u'بهابيل': u'بِهَابِيلَ', #1
u'بهأت': u'بَهَأْتُ', #1
u'بهاحاجتك': u'بِهَاََََحَاجَتَكَ', #1
u'بهادرآص': u'بَهَادِرْآصْ', #5
u'بهارى': u'بهارى', #1
u'بهاعكاشة': u'بِهَاعُكَّاشَةُ', #1
u'بهاعليكم': u'بِهَاعَلَيْكُمْ', #1
u'بهافلعمر': u'بِهَافَلَعَمْرُ', #1
u'بهالوجه': u'بِهِالْوَجْهُ', #1
u'بهإلى': u'بِهِإِلَى', #1
u'بهامشة': u'بِهَامِشَةِ', #1
u'بهان،': u'بَهَانٍ،', #1
u'بهان،': u'بِهَانَ،', #1
u'بهان،': u'بَهَانَ،', #2
u'بهاوالوجه': u'بِهَاوَالْوَجْهُ', #1
u'بهاوبهذا': u'بِهَاوَبِهَذَا', #1
u'بهاي': u'بهاي', #1
u'بهبار': u'بِهَبّارٍ', #1
u'بهبار': u'بِهَبّارِ', #3
u'بهبهتم': u'بِهِبَهِتِمْ', #1
u'بهبيرة': u'بهُبَيْرَةَ', #1
u'بهبيرة': u'بِهُبَيْرَةَ', #1
u'بهتة': u'بَهْتَةَ', #1
u'بهترا': u'بهترا', #1
u'بهثة': u'بُهْثَةُ', #1
u'بهثة': u'بُهْثَةَ', #18
u'بهجرتى': u'بِهِجْرَتِى', #1
u'بهداوة': u'بِهَدَاوَةٍ', #1
u'بهداى': u'بِهُدَاىَ', #2
u'بهديى': u'بِهَدْيِى', #2
u'بهذاالنبي': u'بِهَذَاالنَّبِيِّ', #1
u'بهذانكلوا': u'بِهَذَانَكَلُوا', #1
u'بهراة،': u'بِهَرَاةَ،', #2
u'بهراة': u'بِهَرَاةَ', #24
u'بهرام،': u'بهرام،', #1
u'بهرام': u'بَهْرامَ', #1
u'بهرام': u'بِهْرَامَ', #1
u'بهرام': u'بَهْرَامٌ', #10
u'بهرام،': u'بَهْرَامَ،', #22
u'بهرام': u'بَهْرَامُ', #292
u'بهرام': u'بَهْرَامَ', #329
u'بهرام': u'بَهْرَام', #5
u'بهرام': u'بَهْرَامٍ', #5
u'بهرجاء': u'بَهْرَجَاءَ', #1
u'بهرسير،': u'بُهرَسِير،', #1
u'بهرسير': u'بَهُرَسِير', #1
u'بهرمز': u'بِهُرْمُزَ', #1
u'بهزاردم': u'بهزاردم', #2
u'بهزينة': u'بهزينة', #1
u'بهسترم': u'بهسترم', #1
u'بهستمت': u'بهستمت', #3
u'بهشت': u'بَهَشْتُ', #2
u'بهشتم': u'بِهَشْتَم', #2
u'بهشتم': u'بِهِشْتَمٌ', #2
u'بهشتم': u'بهشتم', #21
u'بهشتم': u'بَهَشْتُمْ', #3
u'بهشتم': u'بِهِشْتَمْ', #3
u'بهصل': u'بُهْصُلِ', #1
u'بهصل': u'بُهْصُلٍ', #3
u'بهق': u'بَهَقٍ', #2
u'بهق': u'بَهَقٌ', #4
u'بهقا': u'بَهَقًا', #2
u'بهكذا': u'بِهَكَذَا', #3
u'بهكنة': u'بَهْكَنَةٍ', #1
u'بهكنة': u'بَهْكَنَةٌ', #2
u'بهلا': u'بُهّلًا', #1
u'بهلا': u'بُهْلًا', #1
u'بهماء': u'بَهْمَاءُ', #1
u'بهمان،': u'بَهْمَانَ،', #1
u'بهمان': u'بَهْمَانَ', #3
u'بهماوذكر': u'بِهِمَاوَذَكَرَ', #1
u'بهمدان،': u'بهمدان،', #1
u'بهمدان،': u'بِهَمَدَانَ،', #1
u'بهمدان': u'بِهَمَدَانَ', #2
u'بهمدان،': u'بِهَمْدَانَ،', #5
u'بهمدانية': u'بِهَمَدَانِيَّةٍ', #2
u'بهملاج': u'بِهِمْلَاجٍ', #1
u'بهمن': u'بهمن', #6
u'بهمنيار': u'بَهْمَنْيَارَ', #2
u'بهموالوجه': u'بِهِمْوَالْوَجْهُ', #1
u'بهمؤمني': u'بِهِمُؤْمِنِي', #2
u'بهميان': u'بِهِمْيَانٍ', #1
u'بهميانها': u'بِهِمْيَانِهَا', #2
u'بهنا': u'بِهِنَا', #1
u'بهنا': u'بِهُنَا', #12
u'بهنسي': u'بَهْنَسِيٌّ', #5
u'بهوازن': u'بِهَوَازِنَ', #5
u'بهوالوجه': u'بِهِوَالْوَجْهُ', #4
u'بهواهمو': u'بِهَوَاهُمُو', #1
u'بهوذة': u'بِهَوْذَةَ', #1
u'بهولا': u'بِهِوَلَا', #1
u'بهوى': u'بِهَوًى', #10
u'بهير': u'بُهَيْرِ', #1
u'بهير': u'بَهِيرُ', #2
u'بهيسة': u'بُهَيْسَةُ', #1
u'بهيسة': u'بُهَيْسَةَ', #6
u'بهيش': u'بُهَيْش', #1
u'بهيعة': u'بِهَيْعَةٍ', #2
u'بهيقا': u'بِهَيْقَا', #2
u'بهيمتى': u'بَهِيمَتِى', #1
u'بو': u'بَوّ', #1
u'بو': u'َبُو', #16
u'بو': u'بَوٍّ', #2
u'بو': u'بُو', #2
u'بو': u'بو', #3
u'بو': u'بِوَ', #4
u'بوا': u'بِوَا', #1
u'بواجيه': u'بِوَاجِيهٍ', #1
u'بواحا': u'بَوَاحًاٍٍٍٍ', #1
u'بواحا': u'بَوَاحًا', #6
u'بواحداا': u'بِوَاحِدٍاا', #1
u'بوادداست': u'بوادداست', #1
u'بوادى': u'بِوَادِى', #14
u'بواديكا': u'بوادِيكا', #1
u'بواديكا': u'بِوَادِيكَا', #1
u'بواردية': u'بَوَارِدِيَّةٍ', #2
u'بوازل': u'بَوَازِلَ', #2
u'بواسر': u'بَوَاسِرُ', #1
u'بواسر': u'بَوَاسِرٍ', #2
u'بواطا': u'بُوَاطًا', #2
u'بواطان': u'بُوَاطَانِ', #1
u'بواطيل': u'بَوَاطِيلُ', #1
u'بواقد': u'بِوَاقِدِ', #1
u'بواقعت': u'بِوَاقَعْتُ', #1
u'بواكبها': u'بِوَاكِبِهَا', #1
u'بواكى': u'بَوَاكِى', #2
u'بواكى': u'بَوَاكِىَ', #2
u'بوالدى': u'بِوَالِدَىَّ', #1
u'بوالله': u'بِوَاللَّهِ', #2
u'بوانة': u'بُوَانَةُ', #2
u'بوانة': u'بُوَانَةَ', #5
u'بوانية': u'بَوَانِيَةً', #1
u'بوائح': u'بوائح', #1
u'بوائق': u'بَوائِقُ', #1
u'بوائق': u'بَوَائِقَ', #1
u'بوائق': u'بَوَائِقِ', #2
u'بوائقنا': u'بَوَائِقِنَا', #1
u'بوائقه': u'بَوَائِقِهِ', #1
u'بوائقه': u'بَوَائِقُهُ', #12
u'بوائقه': u'بَوَائِقَهُ', #35
u'بوائلSوقوله': u'بِوَائِلِSوَقَوْلُهُ', #1
u'بوائل': u'بِوَائِلِ', #1
u'بؤبشسع': u'بُؤْبِشِسْعِ', #1
u'بوتران': u'بِوِتْرَانِ', #1
u'بوجاء': u'بِوِجَاءِ', #2
u'بوجبت': u'بِوَجَبَتْ', #1
u'بوحشى': u'بِوَحْشِىٍّ', #1
u'بوحوده': u'بِوُحُودِهِ', #1
u'بوحى': u'بِوَحْىٍ', #1
u'بوحى': u'بِوَحْىِ', #1
u'بوخت': u'بوخت', #1
u'بوخت': u'بُوخْتُ', #1
u'بوخش': u'بِوَخْشٍ', #1
u'بودازدين': u'بودازدين', #1
u'بودآن': u'بودآن', #1
u'بوداندرين': u'بوداندرين', #1
u'بوداه': u'بِوَدَّاهُ', #2
u'بودبا': u'بودبا', #1
u'بودبسه': u'بودبسه', #1
u'بودبشهر': u'بودبشهر', #1
u'بودبوي': u'بودبوي', #1
u'بودم': u'بودم', #5
u'بودند': u'بودند', #2
u'بودو': u'بودو', #2
u'بودوآن': u'بودوآن', #1
u'بودواين': u'بودواين', #1
u'بودودر': u'بودودر', #1
u'بودى': u'بودى', #2
u'بوذائله': u'بِوَذَائِلِهِ', #1
u'بوذويه،': u'بُوذَوَيْهِ،', #1
u'بوذويه': u'بُوذَوَيْهِ', #3
u'بورقان': u'بِوَرِقَانَ', #1
u'بوزاوالوجه': u'بُوزَاوَالْوَجْهُ', #1
u'بوزة': u'بُوزَةٍ', #1
u'بوست': u'بوست', #2
u'بوسوزي': u'بوسوزي', #1
u'بؤسى': u'بُؤْسَى', #1
u'بوسى': u'بُوسَى', #2
u'بوش': u'بوش', #11
u'بوشنج': u'بُوشَنْجَ', #1
u'بوشيدن': u'بوشيدن', #2
u'بوشيده': u'بوشيده', #1
u'بوشيئي': u'بوشيئي', #1
u'بوصا': u'بُوصًا', #1
u'بوضوءه': u'بِوَضُوءِهِ', #1
u'بوضوءين': u'بِوُضُوءَيْنِ', #7
u'بوضوآت': u'بِوُضُوآتٍ', #2
u'بوطأين': u'بِوَطْأَيْنِ', #1
u'بوغاء': u'بَوْغَاءُ', #2
u'بوقاصرة': u'بوقاصرة', #1
u'بوقذ': u'بِوَقْذٍ', #1
u'بوقص': u'بِوَقَصٍ', #3
u'بوقص': u'بِوَقَصِ', #3
u'بوقص': u'بِوَقْصٍ', #3
u'بوقفا': u'بِوَقَفَا', #1
u'بوقفت': u'بِوَقَفْت', #1
u'بوقفت': u'بِوُقِفَتْ', #1
u'بوقفت': u'بِوَقَفْتُ', #2
u'بوقفيته': u'بِوَقْفِيَّتِهِ', #23
u'بوقفيتها': u'بِوَقْفِيَّتِهَا', #26
u'بوكابهاي': u'بوكابهاي', #1
u'بوكان': u'بِوَكَانَ', #1
u'بوكردم': u'بوكردم', #2
u'بوكلت': u'بِوَكَّلْتُ', #1
u'بوكيع': u'بِوَكِيعٍ', #1
u'بول': u'بَوْلً', #1
u'بولاد': u'بِوَلَّادٍ', #1
u'بولاد': u'بِوِلَادٍ', #2
u'بولادها': u'بِوِلَادِهَا', #2
u'بولاق': u'بُولَاقُ', #1
u'بولاق': u'بُولَاقَ', #28
u'بولاق': u'بُولَاقِ', #3
u'بولانية': u'بَوْلاَنِيَّةٌ', #1
u'بولة': u'بَوْلَةٍ', #1
u'بولة': u'بَوْلَةً', #5
u'بولدت': u'بِوَلَدَتْ', #8
u'بولس': u'بُولَسٌ', #1
u'بولس': u'بُولَسَ', #1
u'بولس': u'بُولُسُ', #4
u'بولس': u'بُولَسُ', #5
u'بولص': u'بولص', #1
u'بولص': u'بُولِصُ', #1
u'بولصة': u'بولصة', #1
u'بولنديغي': u'بولنديغي', #1
u'بولى': u'بِوَلِىٍّ', #46
u'بؤنة': u'بؤنة', #1
u'بؤنة': u'بَؤُنَةَ', #1
u'بوهب': u'بِوَهَبَ', #1
u'بوهبت': u'بِوَهَبْت', #1
u'بوهبت': u'بِوَهَبْتُ', #4
u'بوهبوه': u'بِوَهَبُوهُ', #1
u'بوهق': u'بِوَهْقٍ', #2
u'بوهق': u'بِوَهَقٍ', #3
u'بوهقه': u'بِوَهْقِهِ', #1
u'بؤونة': u'بَؤُونَةُ', #1
u'بؤونة': u'بَؤُونَةَ', #2
u'بوى': u'بوى', #3
u'بوي': u'بوي', #4
u'بويتات': u'بُوَيْتَاتٌ', #1
u'بوير': u'بِوَيْرَ', #1
u'بويرة': u'بُوَيْرَةَ', #1
u'بويط': u'بُوَيْطَ', #3
u'بويط': u'بُوَيْطٍ', #4
u'بويه': u'بُوَيْهِ', #1
u'ـبى': u'ـبَى', #1
u'بى': u'بِى', #289
u'بى': u'بِىَ', #38
u'بئار': u'بِئَارَ', #1
u'بئار': u'بِئَارُ', #1
u'بئار': u'بِئَارِ', #2
u'بئارا': u'بِئَارًا', #5
u'بئاره،': u'بِئَارَهُ،', #1
u'بئارها': u'بِئَارِهَا', #1
u'بئده': u'بئده', #1
u'بئرى': u'بِئْرِى', #1
u'بئوب': u'بِئَوْب', #1
u'بئونة': u'بَئُونَةَ', #3
u'بئونه': u'بَئُونَهْ', #1
u'بيا': u'بيا', #1
u'بيا': u'بَيَا', #1
u'بيا': u'بِيَا', #77
u'بيابد': u'بيابد', #1
u'بيابي': u'بيابي', #1
u'بيابييد': u'بيابييد', #1
u'بياتانماز': u'بياتانماز', #1
u'بيأتي': u'بِيَأْتِي', #6
u'بيأجج': u'بِيَأْجَجَ', #2
u'بيأجج،': u'بِيَأْجَجَ،', #2
u'بيأجوج': u'بِيَأْجُوجَ', #2
u'بيأخذه': u'بِيَأْخُذَهُ', #1
u'بيادخانه': u'بيادخانه', #1
u'بياده': u'بياده', #1
u'بيأذن': u'بِيَأْذَنُ', #1
u'بيأذنا': u'بِيَأْذَنَا', #2
u'بيار': u'بِيَارِ', #1
u'بيار': u'بيار', #4
u'بيارة': u'بَيَّارَةٌ', #1
u'بيارد': u'بيارد', #1
u'بيارها': u'بِيَارُهَا', #1
u'بيارها': u'بِيَارِهَا', #1
u'بياري': u'بياري', #1
u'بيازارم': u'بيازارم', #1
u'بياسة': u'بِيَاسَةَ', #1
u'بيأكلون': u'بِيَأْكُلُونَ', #1
u'بياكند': u'بياكند', #1
u'بيام': u'بيام', #1
u'بيامد': u'بيامد', #1
u'بيأمر': u'بِيَأْمُرُ', #1
u'بيانيته': u'بَيَانِيَّتِهِ', #1
u'بياه': u'بَيَّاهُ', #5
u'بيائيد': u'بيائيد', #1
u'بيايد': u'بيايد', #1
u'بيايدبوي': u'بيايدبوي', #1
u'بيبا': u'بَيْبًا', #2
u'بيباسته': u'بيباسته', #1
u'بيبة': u'َبِيبَةَ', #1
u'بيبتاع': u'بِيَبْتَاعُ', #1
u'بيبحث': u'بِيَبْحَثُ', #1
u'بيبدأ': u'بِيَبْدَأَ', #1
u'بيبدأ': u'بِيُبْدَأُ', #1
u'بيبدأ': u'بِيَبْدَأُ', #2
u'بيبدل': u'بِيُبْدِلُ', #1
u'بيبرس': u'بِيبَرْس', #1
u'بيبرس': u'بِيبَرْسُ', #2
u'بيبرس': u'بِيبَرْسَ', #5
u'بيبصر': u'بِيُبْصِرُ', #1
u'بيبطلها': u'بِيُبْطِلُهَا', #1
u'بيبقى': u'بِيَبْقَى', #4
u'بيبلغ': u'بِيَبْلُغُ', #1
u'بيبي': u'بِيبِي', #1
u'بيتأبر': u'بِيَتَأَبَّرُ', #2
u'بيتبرع': u'بِيَتَبَرَّعُ', #1
u'بيتبع': u'بِيَتَّبِعُ', #1
u'بيتجر': u'بِيَتَّجِرُ', #1
u'بيتحاصان': u'بِيَتَحَاصَّانِ', #1
u'بيتحد': u'بِيَتَّحِدُ', #1
u'بيتخرج': u'بِيَتَخَرَّجُ', #2
u'بيترتب': u'بِيَتَرَتَّبُ', #1
u'بيتصور': u'بِيُتَصَوَّرُ', #1
u'بيتضمنه': u'بِيَتَضَمَّنَهُ', #1
u'بيتعين': u'بِيَتَعَيَّنُ', #1
u'بيتقيد': u'بِيَتَقَيَّد', #1
u'بيتلطف': u'بِيَتَلَطَّفُ', #1
u'بيتلقاه': u'بِيَتَلَقَّاهُ', #1
u'بيتمحل': u'بِيَتَمَحَّلُ', #1
u'بيتميز': u'بِيَتَمَيَّزُ', #1
u'بيتنفس': u'بِيَتَنَفَّسُ', #1
u'بيتوتة': u'بَيْتُوتَةِ', #2
u'بيتوتة': u'بَيْتُوتَةً', #5
u'بيتوتته': u'بَيْتُوتَتُهُ', #6
u'بيتوتتهما': u'بَيْتُوتَتَهُمَا', #1
u'بيتوصل': u'بِيُتَوَصَّلُ', #1
u'بيتولاه': u'بِيَتَوَلَّاهُ', #2
u'بيتى': u'بِيتِى', #1
u'بيتى': u'بَيْتَىَّ', #1
u'بيتى': u'بَيْتَىْ', #1
u'بيتى': u'بَيْتِىَ', #1
u'بيتى؟': u'بَيْتِى؟', #2
u'بيتى': u'بَيْتِى', #92
u'بيتيمم': u'بِيَتَيَمَّمَ', #4
u'بيثبت': u'بِيَثْبُتَ', #1
u'بيثبت': u'بِيَثْبُتُ', #3
u'بيثرب،': u'بِيَثْرِبَ،', #1
u'بيثرب': u'بِيَثْرِبَ', #43
u'بيثني': u'بِيَثْنِي', #1
u'بيجاب': u'بِيُجَابُ', #1
u'بيجب': u'بِيَجِبْ', #2
u'بيجب': u'بِيَجِبُ', #28
u'بيجبر': u'بِيَجْبُرُ', #3
u'بيجتنب': u'بِيَجْتَنِبُ', #1
u'بيجد': u'بِيَجِدْ', #1
u'بيجعل': u'بِيَجْعَلَ', #2
u'بيجكان': u'بيجكان', #1
u'بيجمع': u'بِيَجْمَع', #1
u'بيجمع': u'بِيَجْمَعُ', #2
u'بيجوبان': u'بيجوبان', #1
u'بيجوز': u'بِيَجُوزُ', #22
u'بيجيء': u'بِيَجِيءُ', #2
u'بيجيئ': u'بِيَجِيئُ', #1
u'بيحابيه': u'بِيُحَابِيَهُ', #1
u'بيحاذي': u'بِيُحَاذِي', #1
u'بيحان': u'بَيْحَانَ', #4
u'بيحب': u'بِيُحَبُّ', #1
u'بيحج': u'بِيَحُجُّ', #1
u'بيحجبه': u'بِيَحْجُبُهُ', #1
u'بيحد': u'بِيُحَدُّ', #2
u'بيحذف': u'بِيُحْذَفُ', #1
u'بيحرة': u'بَيْحَرَةَ', #1
u'بيحرة': u'بَيْحَرَةُ', #3
u'بيحرم': u'بِيَحْرُمُ', #2
u'بيحز': u'بِيَحُزْ', #2
u'بيحسب': u'بِيُحْسَبُ', #1
u'بيحصل': u'بِيَحْصُلُ', #6
u'بيحضر': u'بِيَحْضُرَ', #1
u'بيحفر': u'بِيَحْفِرُ', #2
u'بيحكم': u'بِيَحْكُمُ', #2
u'بيحل': u'بِيَحِلُّ', #6
u'بيحمل': u'بِيُحْمَلُ', #1
u'بيحملون': u'بِيَحْمِلُونَ', #1
u'بيحنث': u'بِيَحْنَثُ', #1
u'بيحيى،': u'بيحيى،', #1
u'بيحيى': u'بِيَحْيَى', #21
u'بيختبر': u'بِيُخْتَبَرُ', #1
u'بيختص': u'بِيَخْتَصُّ', #2
u'بيخرج': u'بِيَخْرُجْ', #1
u'بيخرج': u'بِيُخْرِجُ', #1
u'بيخرج': u'بِيَخْرُجُ', #3
u'بيخلص': u'بِيَخْلُصُ', #1
u'بيخلصه': u'بِيُخَلِّصُهُ', #1
u'بيخلع': u'بِيَخْلَعُ', #1
u'بيخيط': u'بِيَخِيطُ', #1
u'بيخيطه': u'بِيَخِيطَهُ', #2
u'بيداكردم': u'بيداكردم', #1
u'بيدخل': u'بِيَدْخُلُ', #2
u'بيدخلوا': u'بِيَدْخُلُوا', #1
u'بيدرة': u'بَيْدَرَةِ', #1
u'بيدستور': u'بيدستور', #3
u'بيدعي': u'بِيَدَّعِي', #1
u'بيدعى': u'بِيُدْعَى', #2
u'بيدفع': u'بِيَدْفَعَ', #1
u'بيدفعون': u'بِيَدْفَعُونَ', #1
u'بيدقة': u'بَيْدَقَةٌ', #1
u'بيدهاإلى': u'بِيَدِهَاإِلَى', #1
u'بيدهقوله': u'بِيَدِهِقَوْلُهُ', #1
u'بيدوالوجه': u'بِيَدٍوَالْوَجْهُ', #1
u'بيذر': u'بِيُذَرُّ', #1
u'بيراد': u'بِيُرَادُ', #1
u'بيرادسته': u'بيرادسته', #1
u'بيرتجع': u'بِيَرْتَجِعُ', #2
u'بيرث': u'بِيَرِثُ', #2
u'بيرجح': u'بِيَرْجَحُ', #1
u'بيرجحون': u'بِيُرَجَّحُونَ', #1
u'بيرجع': u'بِيَرْجِعُ', #4
u'بيرجم': u'بِيُرْجَمُ', #1
u'بيرح': u'بَيْرَحُ', #3
u'بيرحا': u'بِيرَحَا', #1
u'بيرحا': u'بَيْرَحًا', #2
u'بيرحا': u'بَيْرَحَا', #2
u'بيرحا': u'بَيْرُحَا', #7
u'بيرحاء': u'بِيرُحَاءٍ', #1
u'بيرحاء': u'بَيْرَحَاءَ', #1
u'بيرحاء،': u'بَيْرَحَاءَ،', #1
u'بيرحاء،': u'بَيْرَحَاءُ،', #1
u'بيرحاء': u'بَيْرُحَاءَ', #20
u'بيرحاء': u'بِيرَحَاءٍ', #4
u'بيرحاء': u'بَيْرُحَاءُ', #8
u'بيرحمك': u'بِيَرْحَمُك', #7
u'بيرحمك': u'بِيَرْحَمُكَ', #7
u'بيرحى': u'بَيْرَحَى', #2
u'بيرخت': u'بيرخت', #1
u'بيرد': u'بِيَرُدُّ', #2
u'بيرشيبع': u'بِيرْشِيبَعْ', #1
u'بيرضعن': u'بِيُرْضِعْنَ', #1
u'بيرفع': u'بِيَرْفَعَ', #1
u'بيرق': u'بَيْرَقٍ', #1
u'بيركب': u'بِيَرْكَبَ', #1
u'بيركب': u'بِيَرْكَبُ', #1
u'بيروزة': u'بيروزة', #1
u'بيروزه': u'بيروزه', #1
u'بيرون': u'بيرون', #2
u'بيرون': u'بِيَرُونِ', #2
u'بيري': u'بِيرِيّ', #12
u'بيري': u'بِيرِيٌّ', #60
u'بيرين،': u'بِيرِينَ،', #1
u'بيزا': u'بَيْزًا', #1
u'بيزادن': u'بيزادن', #1
u'بيزار': u'بيزار', #1
u'بيزار': u'بَيْزَار', #2
u'بيزاراست': u'بيزاراست', #1
u'بيزارشدم': u'بيزارشدم', #2
u'بيزارم': u'بيزارم', #6
u'بيزام': u'بيزام', #1
u'بيزدان': u'بيزدان', #1
u'بيزدجرد': u'بِيَزْدَجْرِدُ', #1
u'بيزكيه': u'بِيُزَكِّيهِ', #1
u'بيزنن': u'بِيَزَنَنَ', #1
u'بيزوجها': u'بِيُزَوِّجُهَا', #1
u'بيزيد،': u'بِيَزِيدَ،', #1
u'بيزيد': u'بِيَزِيدَ', #18
u'بيسان،': u'بيسان،', #1
u'بيسان': u'بيْسان', #1
u'بيسان': u'بَيْسَانُ', #2
u'بيسان': u'بَيْسَانِ', #2
u'بيسان': u'بَيْسَانَ', #9
u'بيستبرئ': u'بِيَسْتَبْرِئُ', #1
u'بيستثنى': u'بِيُسْتَثْنَى', #2
u'بيستحب': u'بِيُسْتَحَبُّ', #2
u'بيستظهر': u'بِيُسْتَظْهَرَ', #1
u'بيستغني': u'بِيَسْتَغْنِي', #1
u'بيستفيد': u'بِيَسْتَفِيدُ', #2
u'بيستنقذ': u'بِيَسْتَنْقِذُ', #1
u'بيسرع': u'بِيُسْرِعُ', #1
u'بيسعها': u'بِيَسَعُهَا', #2
u'بيسقط': u'بِيَسْقُطُ', #1
u'بيسقط': u'بِيُسْقِطُ', #2
u'بيسكنها': u'بِيَسْكُنُهَا', #1
u'بيسم': u'بِيَسِمُ', #1
u'بيسمع': u'بِيَسْمَعُ', #1
u'بيسمى': u'بِيُسَمَّى', #2
u'بيسن': u'بِيُسَنُّ', #2
u'بيسوس': u'بِيسُوسُ', #1
u'بيسوغ': u'بِيَسُوغُ', #1
u'بيسيل': u'بِيَسِيلُ', #1
u'بيش': u'بِيشَ', #3
u'بيش': u'بيش', #8
u'بيشاركه': u'بِيُشَارِكُهُ', #3
u'بيشاور': u'بِيُشَاوِرَ', #1
u'بيشب': u'بِيَشْبٍ', #1
u'بيشة': u'بِيشَةَ', #11
u'بيشة': u'بِيشَةٍ', #3
u'بيشة': u'بِيشَةُ', #4
u'بيشتد': u'بِيَشْتَدُّ', #1
u'بيشترط': u'بِيَشْتَرِطُ', #1
u'بيشترط': u'بِيُشْتَرَطُ', #6
u'بيشترك': u'بِيَشْتَرِكُ', #2
u'بيشتري': u'بِيَشْتَرِي', #2
u'بيشتريها': u'بِيَشْتَرِيهَا', #1
u'بيشتغل': u'بِيَشْتَغِلُ', #1
u'بيشرطا': u'بِيَشْرِطَا', #1
u'بيشرع': u'بِيَشْرَعُ', #1
u'بيشرعان': u'بِيُشْرَعَانِ', #1
u'بيشريانه': u'بِيَشْرِيَانِهِ', #1
u'بيشعر': u'بِيَشْعُرُ', #2
u'بيشكل': u'بِيُشْكِلُ', #4
u'بيشمل': u'بِيَشْمَلُ', #1
u'بيشهد': u'بِيُشْهِدُ', #1
u'بيشهد': u'بِيَشْهَدُ', #6
u'بيشي': u'بيشي', #2
u'بيشير': u'بِيُشِيرُ', #1
u'بيصان': u'بِيُصَانُ', #1
u'بيصح': u'بِيَصِحَّ', #1
u'بيصح': u'بِيَصِحُّ', #14
u'بيصحب': u'بِيَصْحَبُ', #1
u'بيصد': u'بِيَصُدُّ', #1
u'بيصدق': u'بِيَصْدُقُ', #2
u'بيصر': u'بِيُصِر', #1
u'بيصر': u'بَيْصَرَ', #2
u'بيصر': u'بَيْصَرِ', #2
u'بيصرف': u'بِيُصْرَفُ', #1
u'بيصعد': u'بِيَصْعَدُ', #1
u'بيصغى': u'بِيَصْغَى', #1
u'بيصلي': u'بِيُصَلِّي', #1
u'بيصلى': u'بِيُصَلَّى', #2
u'بيصوم': u'بِيَصُومُ', #1
u'بيصيرون': u'بِيَصِيرُونَ', #1
u'بيضاوتان': u'بَيْضَاوَتَانِ', #1
u'بيضربه': u'بِيَضْرِبَهُ', #1
u'بيضربه': u'بِيَضْرِبُهُ', #1
u'بيضره': u'بِيَضُرُّهُ', #2
u'بيضع': u'بِيَضَعَ', #1
u'بيضمن': u'بِيَضْمَنُ', #8
u'بيطأ': u'بِيَطَأُ', #1
u'بيطاء': u'بَيْطَاءَ', #1
u'بيطاء': u'بِيَطَاءَ', #2
u'بيطالب': u'بِيُطَالَبُ', #1
u'بيطلب': u'بِيُطْلَبُ', #1
u'بيطلع': u'بِيَطَّلِعُ', #1
u'بيطلق': u'بِيُطْلَقُ', #1
u'بيطمئن': u'بِيَطْمَئِنُّ', #2
u'بيطهر': u'بِيَطْهُرُ', #8
u'بيطور': u'بيطور', #1
u'بيظن': u'بِيَظُنُّ', #1
u'بيظنها': u'بِيَظُنُّهَا', #3
u'بيظهر': u'بِيَظْهَرُ', #3
u'بيع': u'بَيْعً', #1
u'بيعامل': u'بِيُعَامِلَ', #1
u'بيعبدون': u'بِيَعْبُدُونَ', #2
u'بيعبق': u'بِيَعْبَقُ', #1
u'بيعتبر': u'بِيُعْتَبَرُ', #1
u'بيعتزلون': u'بِيَعْتَزِلُونَ', #1
u'بيعتضد': u'بِيُعْتَضَدُ', #1
u'بيعتق': u'بِيَعْتِقْ', #1
u'بيعتى': u'بَيْعَتِى', #5
u'بيعد': u'بِيُعِدْ', #1
u'بيعذبون': u'بِيُعَذَّبُونَ', #2
u'بيعرف': u'بِيَعْرِفُ', #2
u'بيعصم': u'بِيَعْصِمُ', #1
u'بيعطلهن': u'بِيُعَطِّلَهُنَّ', #2
u'بيعطي': u'بِيُعْطِيَ', #1
u'بيعطى': u'بِيُعْطَى', #2
u'بيعطيهم': u'بِيُعْطِيهِمْ', #1
u'بيعظم': u'بِيُعَظِّمُ', #1
u'بيعفر': u'بِيَعْفُرٍ', #1
u'بيعفو': u'بِيَعْفُو', #1
u'بيعقد': u'بِيَعْقِدُ', #1
u'بيعلق': u'بِيَعْلَقُ', #1
u'بيعلم': u'بِيُعَلِّمُ', #1
u'بيعلم': u'بِيُعْلَمُ', #2
u'بيعلمون': u'بِيَعْلَمُونَ', #1
u'بيعلى': u'بِيَعْلَى', #2
u'بيعمل': u'بِيَعْمَلُ', #4
u'بيعني': u'بِيَعْنِي', #13
u'بيعونيه،': u'بِيعُونِيهِ،', #1
u'بيعونيه': u'بِيعُونِيهِ', #2
u'بيعى': u'بَيْعِى', #3
u'بيعيد': u'بِيُعِيدُ', #5
u'بيعيدها': u'بِيُعِيدُهَا', #2
u'بيغام': u'بيغام', #1
u'بيغرم': u'بِيَغْرَمُ', #1
u'بيغسل': u'بِيُغْسَلُ', #1
u'بيغفر': u'بِيَغْفِرُ', #7
u'بيغلب': u'بِيَغْلِبُ', #2
u'بيغمبر': u'بيغمبر', #9
u'بيغمبراست': u'بيغمبراست', #2
u'بيغمبرد': u'بيغمبرد', #1
u'بيغمبرم': u'بيغمبرم', #1
u'بيغني': u'بِيُغْنِي', #1
u'بيفتادا': u'بيفتادا', #1
u'بيفتاداز': u'بيفتاداز', #3
u'بيفتادو': u'بيفتادو', #1
u'بيفتتح': u'بِيَفْتَتِحُ', #1
u'بيفتى': u'بِيُفْتَى', #1
u'بيفجرك': u'بِيَفْجُرُكَ', #1
u'بيفرض': u'بِيُفْرَضُ', #1
u'بيفرغه': u'بِيُفْرِغُهُ', #1
u'بيفرق': u'بِيُفَرَّقُ', #1
u'بيفرق': u'بِيُفَرِّقْ', #1
u'بيفرق': u'بِيُفَرِّقُ', #3
u'بيفض': u'بِيُفْضِ', #1
u'بيفعل': u'بِيَفْعِلْ', #1
u'بيفكندم': u'بيفكندم', #6
u'بيفوت': u'بِيَفُوتَ', #1
u'بيفوت': u'بِيَفُوتُ', #2
u'بيقال': u'بِيُقَالَ', #1
u'بيقال': u'بِيُقَالُ', #4
u'بيقبضه': u'بِيَقْبِضُهُ', #3
u'بيقبل': u'بِيَقْبَلُ', #1
u'بيقبل': u'بِيُقْبَلُ', #1
u'بيقتص': u'بِيَقْتَصُّ', #1
u'بيقتضي': u'بِيَقْتَضِي', #4
u'بيقتضيه': u'بِيَقْتَضِيهِ', #3
u'بيقتل': u'بِيُقْتَلُ', #2
u'بيقدر': u'بِيَقْدِرُ', #1
u'بيقدم': u'بِيُقَدِّمَ', #1
u'بيقرأ': u'بِيَقْرَأُ', #2
u'بيقرب': u'بِيَقْرُبُ', #1
u'بيقسم': u'بِيُقْسِمُ', #2
u'بيقصد': u'بِيُقْصَدُ', #2
u'بيقض': u'بِيَقْضِ', #1
u'بيقضى': u'بِيُقْضَى', #2
u'بيقضي': u'بِيَقْضِي', #6
u'بيقطع': u'بِيَقْطَعَ', #1
u'بيقع': u'بِيَقَعُ', #3
u'بيقف': u'بِيَقِفُ', #1
u'بيقم': u'بِيَقُمْ', #1
u'بيقول': u'بِيَقُولَ', #2
u'بيقول': u'بِيَقُولُ', #4
u'بيقوم': u'بِيُقَوَّمُ', #1
u'بيقوم': u'بِيُقَوِّمَ', #1
u'بيقينا': u'بِيَقِينًا', #1
u'بيك': u'بيك', #1
u'بيك': u'بِيكْ', #1
u'بيك': u'بُيَّك', #6
u'بيكتسبه': u'بِيَكْتَسِبُهُ', #1
u'بيكدست': u'بيكدست', #1
u'بيكره': u'بِيُكْرَهْ', #1
u'بيكره': u'بِيُكْرَهُ', #5
u'بيكسوى': u'بيكسوى', #2
u'بيكطلاق': u'بيكطلاق', #1
u'بيكف': u'بِيَكْفِ', #1
u'بيكفر': u'بِيَكْفُرُ', #1
u'بيكفي': u'بِيَكْفِي', #3
u'بيكفيه': u'بِيَكْفِيهِ', #1
u'بيكلف': u'بِيُكَلَّفُ', #1
u'بيكمل': u'بِيَكْمُلُ', #1
u'بيكن': u'بِيَكُنْ', #3
u'بيكناه': u'بيكناه', #1
u'بيكند،': u'بيْكند،', #1
u'بيكند': u'بِيكَنْدَ', #1
u'بيكون': u'بِيَكُونُ', #4
u'بيلتزم': u'بِيَلْتَزِمُ', #2
u'بيلتفت': u'بِيَلْتَفِتُ', #1
u'بيلحق': u'بِيَلْحَقُ', #1
u'بيلحق': u'بِيُلْحَقُ', #1
u'بيلحقه': u'بِيَلْحَقُهُ', #1
u'بيلزم': u'بِيُلْزَمُ', #1
u'بيلزم': u'بِيَلْزَمُ', #3
u'بيلقن': u'بِيُلَقَّنُ', #1
u'بيلقيه': u'بِيُلْقِيهِ', #1
u'بيلملم': u'بِيَلَمْلَمَ', #3
u'بيلوزة': u'بيلوزة', #1
u'بيمابي': u'بيمابي', #1
u'بيمارى': u'بيمارى', #2
u'بيمتد': u'بِيَمْتَدُّ', #3
u'بيمتنع': u'بِيَمْتَنِعُ', #2
u'بيمد': u'بِيَمُدُّ', #1
u'بيمر': u'بِيَمُرُّ', #1
u'بيمضي': u'بِيُمْضِي', #1
u'بيملك': u'بِيَمْلِكُ', #1
u'بيملك': u'بِيُمْلَكُ', #1
u'بيملكه': u'بِيُمَلِّكَهُ', #1
u'بيمنع': u'بِيَمْنَعَ', #1
u'بيمهل': u'بِيُمْهَلُ', #1
u'بيمون': u'بِيَمُونُ', #1
u'بيمونه': u'بِيَمُونُهُ', #2
u'بيميز': u'بِيُمَيِّزُ', #1
u'بيمينى': u'بِيَمِينِى', #3
u'بين': u'بَيْنً', #2
u'بينافس': u'بِيُنَافِسْ', #1
u'بينأهل': u'بَيْنَأَهْلِ', #1
u'بينأيديهن': u'بَيْنَأَيْدِيهِنَّ', #1
u'بينبت': u'بِيَنْبُتُ', #1
u'بينبع،': u'بيَنْبُع،', #1
u'بينبع': u'بِيَنْبُعَ', #2
u'بينبغي': u'بِيَنْبَغِي', #12
u'بينبئ': u'بِيُنْبِئُ', #1
u'بينتظر': u'بِيَنْتَظِرُ', #1
u'بينتظر': u'بِيُنْتَظَرُ', #1
u'بينتفع': u'بِيُنْتَفَعُ', #1
u'بينتفي': u'بِيَنْتَفِي', #1
u'بينتهي': u'بِيَنْتَهِي', #1
u'بينتى': u'بَيِّنَتِى', #1
u'بينج': u'بينج', #2
u'بينجو': u'بِيَنْجُو', #1
u'بيند': u'بيند', #1
u'بيندا': u'بيندا', #1
u'بيندب': u'بِيُنْدَبُ', #3
u'بينصرف': u'بِيَنْصَرِفُ', #1
u'بينطبع': u'بِيَنْطَبِعُ', #1
u'بينطق': u'بِيَنْطِق', #1
u'بينظر': u'بِيَنْظُرَ', #1
u'بينظر': u'بِيَنْظُرُ', #2
u'بينعزل': u'بِيَنْعَزِلُ', #1
u'بينعقد': u'بِيَنْعَقِدُ', #3
u'بينفذ': u'بِيَنْفُذُ', #2
u'بينفرد': u'بِيَنْفَرِدُ', #1
u'بينفع': u'بِيَنْفَعُ', #1
u'بينفعه': u'بِيَنْفَعُهُ', #1
u'بينفق': u'بِيُنْفِقُ', #1
u'بينفقهاء': u'بَيْنَفُقَهَاءِ', #1
u'بينقسم': u'بِيَنْقَسِمُ', #1
u'بينكمقوله': u'بَيْنَكُمْقَوْلُهُ', #1
u'بينم': u'بينم', #3
u'بينه': u'بَيِّنَهً', #1
u'بينهماأسمعت': u'بَيْنَهُمَاأَسَمِعْتَ', #1
u'بينهماسئل': u'بَيْنَهُمَاسُئِلَ', #1
u'بينهمو': u'بَيْنَهُمُو', #1
u'بينهنه': u'بَيْنَهُنَّهْ', #2
u'بينو': u'بيَنْوِ', #1
u'بينون': u'بَيْنُونَ', #10
u'بينون': u'بَيْنَونَ', #2
u'بينون': u'بَيْنُون', #2
u'بينون': u'بَيْنُونُ', #6
u'بينى': u'بِيْنِى', #1
u'بينى': u'بَيْنِى', #142
u'بينيد': u'بينيد', #1
u'بينيديه': u'بَيْنَيَدَيْهِ', #1
u'بينير': u'بينير', #1
u'بينين': u'بَيْنِينَ', #2
u'بيه': u'بِيه', #2
u'بيه': u'بيه', #4
u'بيهان،': u'بَيْهَانَ،', #1
u'بيهديك': u'بِيَهْدِيك', #3
u'بيهديكم': u'بِيَهْدِيكُمْ', #2
u'بيهس': u'بَيْهَسٌ', #1
u'بيهس': u'بَيْهَسُ', #1
u'بيهس،': u'بَيْهَسٍ،', #1
u'بيهق،': u'بَيْهَق،', #1
u'بيهق': u'بَيْهَقَ', #3
u'بيهقي': u'بَيْهَقِيٌّ', #1
u'بيهودى': u'بِيَهُودِىٍّ', #6
u'بيهيأ': u'بِيُهَيَّأُ', #1
u'بيهيئ': u'بِيُهَيِّئُ', #3
u'بيؤاخذ': u'بِيُؤَاخِذُ', #1
u'بيوافي': u'بِيُوَافِي', #1
u'بيؤتى': u'بِيُؤْتَى', #1
u'بيؤثر': u'بِيُؤَثِّرُ', #1
u'بيوجب': u'بِيُوجِبُ', #3
u'بيوجد': u'بِيُوجَدَ', #2
u'بيوجد': u'بِيُوجَدُ', #3
u'بيؤجل': u'بِيُؤَجِّلُ', #1
u'بيوجه': u'بِيُوَجَّهُ', #1
u'بيؤخذ': u'بِيُؤْخَذُ', #1
u'بيؤخذ': u'بِيُؤْخَذْ', #1
u'بيؤخرا': u'بِيُؤَخَّرَا', #1
u'بيؤدي': u'بِيُؤَدِّي', #3
u'بيؤذن': u'بِيُؤَذِّنُ', #1
u'بيؤذي': u'بِيُؤْذِي', #1
u'بيوراسب': u'بيوراسب', #2
u'بيورث': u'بِيُورَثُ', #1
u'بيوسته': u'بيوسته', #2
u'بيوشم': u'بيوشم', #2
u'بيوصي': u'بِيُوصِي', #1
u'بيوعات': u'بُيُوعَاتِ', #4
u'بيوقع': u'بِيُوقِعُ', #1
u'بيوك': u'بيوك', #4
u'بيولد': u'بِيُولَدُ', #1
u'بيؤمر': u'بِيُؤْمَرُ', #1
u'بيوهمه': u'بِيُوهِمُهُ', #1
u'بيؤيده': u'بِيُؤَيِّدُهُ', #1
u'بيية': u'بُيَيّةٌ', #1
u'بييه': u'بَييّه', #1
u'ة': u'ةً', #1
u'ة،': u'ةً،', #2
u'ةنا': u'ةنا', #1
u'تاءات': u'تَاءَاتٍ', #1
u'تااب': u'تااب', #1
u'تاآزاد': u'تاآزاد', #1
u'تاباي': u'تَابَّايَ', #2
u'تابخانة': u'تابخانة', #2
u'تابخانه': u'تابخانه', #1
u'تابخانه': u'تَابَخَانَهْ', #1
u'تابد': u'تابد', #1
u'تأبر': u'تَأَبُّرَ', #1
u'تأبر': u'تَأَبُّرٌ', #2
u'تأبر': u'تَأَبَّرَ', #29
u'تأبر': u'تَأَبُّرُ', #3
u'تأبر': u'تَأَبُّرِ', #6
u'تأبرت': u'تَأَبَّرَتْ', #16
u'تابرف': u'تابرف', #1
u'تأبره': u'تَأَبُّرِهِ', #2
u'تابروم': u'تابروم', #2
u'تابسب': u'تابسب', #1
u'تابستان': u'تابستان', #1
u'تابعنى': u'تَابَعَنِى', #1
u'تابعى': u'تَابِعِىٌّ', #1
u'تابعى': u'تَابِعِى', #5
u'تابعيون': u'تَابِعِيُّونَ', #2
u'تأبق': u'تَأْبَقْ', #1
u'تابقوله': u'تَابَقَوْلُهُ', #1
u'تابكيرم': u'تابكَيرم', #1
u'تابها': u'تَابَهَا', #20
u'تابوة': u'تَابُوةٌ', #1
u'تابوه': u'تابُوه', #1
u'تابوه': u'تَابُوهُ', #2
u'تأبيت': u'تَأَبَّيْت', #1
u'تآبيته': u'تَآبَيْتِهِ', #1
u'تابيرون': u'تابيرون', #1
u'تأتاء': u'تَأْتَاءَ', #1
u'تأتاء': u'تَأْتَاءٍ', #2
u'تأتس': u'تَأْتَسِ', #1
u'تأتسي': u'تَأْتَسِي', #1
u'تأتصل': u'تَأْتَصِلْ', #1
u'تأتفق': u'تَأَتَفِقُ', #1
u'تأتنابه': u'تَأْتِنَابِهِ', #1
u'تأتنف': u'تَأْتَنِفَ', #1
u'تأتنف': u'تَأْتَنِفُ', #7
u'تأتنى؟': u'تَأْتِنِى؟', #1
u'تأتنى': u'تَأْتِنِى', #9
u'تأتو': u'تَأْتُو', #1
u'تاتو': u'تاتو', #1
u'تاتوبه': u'تاتوبه', #1
u'تأتونى': u'تَأْتُونِى', #1
u'تاتي': u'تَاتِي', #1
u'تأتيانى': u'تَأْتِيَانِى', #2
u'تأتيتي': u'تَأْتِيَتِي', #1
u'تأتينى': u'تَأْتِيَنِى', #11
u'تأتينى': u'تَأْتِينِى', #7
u'تأثق': u'تَأَثَّقَ', #1
u'تأثل': u'تأثل', #1
u'تأثل': u'تَأَثّلْ', #2
u'تأثلته': u'تَأَثّلْته', #1
u'تأثلته': u'تَأثَّلْتُهُ', #1
u'تأثلته': u'تَأَثَّلْتُهُ', #9
u'تآجر': u'تَآجُرِ', #1
u'تأجرنى': u'تَأْجُرَنِى', #1
u'تآجره': u'تَآجُرِهِ', #2
u'تاجيزي': u'تاجيزي', #1
u'تاح': u'تَاحَ', #2
u'تاحلاوت': u'تاحلاوت', #2
u'تاخار': u'تاخار', #2
u'تاخداي': u'تاخداي', #1
u'تأخذنى': u'تَأْخُذُنِى', #1
u'تاخذه': u'تاخذه', #1
u'تأخذى': u'تَأْخُذِى', #1
u'تأخرأبي': u'تَأَخُّرُأَبِي', #1
u'تأخرالإمام': u'تَأَخُّرُالْإِمَامِ', #1
u'تأخرون': u'تَأْخِرُونَ', #2
u'تأخرونا': u'تَأْخِرُونَا', #1
u'تأخيرهللصلاتين': u'تَأْخِيرُهُلِلصَّلَاتَيْنِ', #1
u'تأد': u'تَأَدٍّ', #1
u'تأداه': u'تَأَدَّاهُ', #2
u'تادة،': u'تَادَةَ،', #1
u'تأدت': u'تَأَدَّتْ', #12
u'تادر': u'تادر', #1
u'تادرباغ': u'تادرباغ', #1
u'تادرخت': u'تادرخت', #1
u'تادلة': u'تَادَلَةَ', #2
u'تأدم': u'تَأَدُّمٌ', #2
u'تأدما': u'تَأَدُّمًا', #7
u'تأدمه': u'تَأْدُمُهُ', #1
u'تأدمه': u'تَأْدِمُهُ', #3
u'تأدموا': u'تَأْدِمُوا', #2
u'تأدى': u'تَأَدِّى', #1
u'تأدي': u'تَأَدِّيَ', #2
u'تأدي': u'تَأْدِي', #3
u'تأدي': u'تَأَدِّي', #30
u'تأدى': u'تَأَدَّى', #82
u'تأديا': u'تَأَدِّيًا', #2
u'تأديه': u'تَأَدِّيَهُ', #1
u'تأديه': u'تَأْدِيَهْ', #1
u'تأديه': u'تَأَدِّيهِ', #6
u'تأديها': u'تَأَدِّيَهَا', #1
u'تأديها': u'تَأَدِّيهَا', #10
u'تأديهما': u'تَأْدِيهِمَا', #1
u'تأذت': u'تَأَذّتْ', #1
u'تأذت': u'تَأَذَّتْ', #29
u'تأذنى': u'تَأْذَنِى', #2
u'تأذيا': u'تَأَذِّيًا', #37
u'تأذيت': u'تَأَذَّيْت', #1
u'تأذيت': u'تَأَذَّيْتُ', #1
u'تأذيه': u'تَأَذِّيهِ', #12
u'تأذيه': u'تَأَذِّيه', #8
u'تأذيها': u'تَأَذِّيها', #1
u'تأذيهم': u'تَأَذِّيهُمْ', #1
u'تأذيهم': u'تَأَذِّيهِمْ', #3
u'تأذيهم': u'تَأَذِّيهمْ', #4
u'تأذيهما': u'تَأَذِّيهمَا', #2
u'تار': u'تَارّ', #1
u'تارا': u'تَارَا', #2
u'تارا': u'تَارًّا', #2
u'تاراء': u'تَارَاءَ', #1
u'تاران': u'تَارَانَ', #1
u'تارح': u'تَارِحِ', #1
u'تارح،': u'تَارَحُ،', #1
u'تارح': u'تَارَحَ', #2
u'تارح': u'تَارِحٍ', #2
u'تارح،': u'تَارَحَ،', #2
u'تارح': u'تارِح', #4
u'تارح': u'تَارَحُ', #6
u'تأردف': u'تَأَرْدَفَ', #1
u'تارز': u'تَارِز', #1
u'تأرز': u'تَأْرِزُ', #17
u'تارزة': u'تَارِزَة', #1
u'تارزة': u'تَارِزَةً', #2
u'تاركني': u'تَارِكْنِي', #1
u'تاركوا': u'تَارِكُوا', #1
u'تأرى': u'تَأَرَّى', #1
u'تاريان': u'تاريان', #1
u'تأريب': u'تَأْرِيبُ', #1
u'تأريت': u'تَأَرّيْتُ', #1
u'تأريشا': u'تَأْرِيشًا', #2
u'تأريفا': u'تَأْرِيفًا', #1
u'تازه': u'تازه', #1
u'تأزيجا': u'تَأْزِيجًا', #1
u'تأزيرا': u'تَأْزِيرًا', #3
u'تأزيره': u'تَأْزِيرَهُ', #1
u'تازيره': u'تَازِيرُهُ', #1
u'تأزيره': u'تَأْزِيرِهِ', #2
u'تاسه': u'تاسه', #1
u'تاسومة': u'تَاسُومَةَ', #1
u'تاسومة': u'تَاسُومَةُ', #1
u'تاسومة': u'تَاسُومَةً', #2
u'تأسوني': u'تَأْسُونِي', #1
u'تأسية': u'تَأْسِيَةً', #1
u'تاشبا': u'تاشبا', #2
u'تأشبوا': u'تَأَشَّبُوا', #1
u'تأشبوه': u'تَأْشِبُوهُ', #2
u'تاشفين': u'تَاشِفِينَ', #1
u'تأشيوا': u'تَأَشَّيُوا', #1
u'تاصاليت': u'تاصاليت', #2
u'تاطشت': u'تاطشت', #1
u'تافرا': u'تَافَرَا', #1
u'تافلاني': u'تَافِلَانِيٌّ', #1
u'تأقت': u'تَأَقُّتُ', #1
u'تأقت': u'تَأَقَّتَ', #3
u'تاقيامت': u'تاقيامت', #4
u'تأقيت': u'تَأْقِيتَ', #12
u'تأقيت': u'تَأْقِيتٌ', #13
u'تأقيت': u'تَأْقِيتٍ', #13
u'تأقيت': u'تَأْقِيتُ', #18
u'تأقيت': u'تَأْقِيتِ', #9
u'تأقيتا': u'تَأْقِيتًا', #8
u'تأقيته': u'تَأْقِيتِهِ', #10
u'تأقيته': u'تَأْقِيتَهُ', #2
u'تأقيته': u'تَأْقِيتُهُ', #5
u'تأقيتها': u'تَأْقِيتَهَا', #1
u'تأقيتها': u'تَأْقِيتُهَا', #10
u'تأقيتها': u'تَأْقِيتِهَا', #2
u'تاكواهان': u'تاكواهان', #1
u'تأكيفا': u'تَأْكِيفًا', #1
u'تالة': u'تَالَةَ', #1
u'تالة': u'تَالَّةً', #19
u'تالة': u'تَالَّةَ', #2
u'تالة': u'تَالَةً', #4
u'تالرحمن': u'تَالرَّحْمَنِ', #11
u'تالرحيم': u'تَالرَّحِيمِ', #5
u'تالسان': u'تَالِسَانٌ', #1
u'تالف': u'تَالِفَ', #1
u'تالف': u'تَالِفٍ', #32
u'تالف': u'تَالِفٌ', #52
u'تالفا': u'تَالِفًا', #249
u'تالفة': u'تَالِفَةٌ', #11
u'تالفة': u'تَالِفَةٍ', #3
u'تالفة': u'تَالِفَةً', #55
u'تألفتهما': u'تَأَلّفْتهمَا', #3
u'تالفه': u'تَالِفَهُ', #1
u'تالفه': u'تَالِفِهِ', #1
u'تالفين': u'تَالِفَيْنِ', #1
u'تالق': u'تَالِقٌ', #17
u'تالق': u'تَالِقٍ', #9
u'تالقا': u'تَالِقًا', #2
u'تالك': u'تَالِكٍ', #2
u'تالك': u'تَالِكٌ', #8
u'تأليفني': u'تأليفني', #1
u'تأليلها': u'تَأْلِيلُهَا', #1
u'تام': u'تَامًّ', #1
u'تامادر': u'تامادر', #1
u'تامامي': u'تامامي', #1
u'تأمرنى': u'تأمرنى', #1
u'تأمرنى': u'تَأْمُرَنِى', #1
u'تأمرنى': u'تَأْمُرُنِى', #23
u'تأمرنى؟': u'تَأْمُرُنِى؟', #3
u'تأمرونى': u'تَأْمُرُونِى', #2
u'تامن': u'تامن', #1
u'تأمنونى': u'تَأْمَنُونِى', #5
u'تأمهت': u'تَأَمَّهَتْ', #2
u'تأميت': u'تَأَمّيْتُ', #1
u'تأنامك': u'تَأْنَامَكَ', #1
u'تانتواند': u'تانتواند', #1
u'تانكى': u'تانكى', #2
u'تانئ': u'تَانِئٍ', #4
u'تاهرجه': u'تاهرجه', #2
u'تاوان': u'تاوان', #2
u'تأوبا': u'تَأَوُّبًا', #1
u'تأوبني': u'تَأَوَّبَنِي', #1
u'تأوبني': u'تَأَوّبَنِي', #5
u'تأوبها': u'تَأَوّبَهَا', #2
u'تاودي': u'تَاوَدِيٌّ', #1
u'تأولون': u'تُأَوِّلُونَ', #1
u'تأوى': u'تَأَوَّى', #1
u'تأوى': u'تَأْوِى', #3
u'تأويا': u'تَأَوِّيًا', #1
u'تأويها': u'تَأْوِيهًا', #1
u'تائف': u'تَائِفُ', #1
u'تائيته': u'تَائِيَّتِهِ', #2
u'تايك': u'تايك', #1
u'تايكسال': u'تايكسال', #1
u'تايكى': u'تايكى', #1
u'تأيم': u'تَأَيُّمٍ', #1
u'تأيما': u'تَأَيَّمَا', #1
u'تأيما': u'تَأَيُّمًا', #1
u'تأيمت': u'تَأَيَّمْتُ', #1
u'تأيمت': u'تَأَيَّمَتْ', #77
u'تأيمها': u'تَأَيُّمِهَا', #4
u'تباءس': u'تَبَاءَسُ', #1
u'تباب': u'تَبَابِ', #1
u'تباب': u'تَبَابٍ', #2
u'تبارأ': u'تَبَارَأْ', #1
u'تبارا': u'تَبَارًا', #1
u'تبارأ': u'تَبَارَأَ', #2
u'تبارآ': u'تَبَارَآ', #3
u'تبارؤ': u'تَبَارُؤٌ', #2
u'تبارئ': u'تُبَارِئَ', #1
u'تبارئ': u'تُبَارِئُ', #1
u'تبازى': u'تَبَازَى', #1
u'تباطنه': u'تَبَاطُنِهِ', #1
u'تباعة': u'تَبَاعَةٌ', #1
u'تباعة': u'تَبَاعَةِ', #1
u'تباعة': u'تِبَاعَةِ', #1
u'تباعة،': u'تَبَاعَةٌ،', #1
u'تباعة': u'تَبَاعَةَ', #14
u'تباعة': u'تِبَاعَةَ', #14
u'تباعة': u'تَبَاعَةً', #2
u'تباعة': u'تِبَاعَةً', #2
u'تباعة': u'تِبَاعَةٌ', #2
u'تباعته': u'تَبَاعَتِهِ', #2
u'تباعته': u'تِبَاعَتُهُ', #2
u'تباعته': u'تَبَاعَتُهُ', #4
u'تباعته': u'تِبَاعَتِهِ', #6
u'تباعتي': u'تَبَاعَتِي', #1
u'تباعدى': u'تَبَاعَدِى', #1
u'تباعر': u'تَبَاعَرَ', #4
u'تباغي': u'تُبَاغِي', #1
u'تباغيكم': u'تَبَاغِيكُمْ', #3
u'تبالة': u'تَبَالَةٍ', #1
u'تبالة': u'تَبّالَةٍ', #1
u'تبالة': u'تُبَالَةَ', #1
u'تبالة': u'تَبَالَةُ', #2
u'تبالة': u'تَبَالَةَ', #7
u'تباهله': u'تُبَاهِلُهُ', #1
u'تبائع': u'تَبَائِعَ', #1
u'تبايعتهم': u'تَبَايَعَتْهُمْ', #1
u'تبايعنى': u'تُبَايِعُنِى', #1
u'تبايعونى': u'تُبَايِعُونِى', #4
u'تبتدر': u'تَبْتَدِرَ', #1
u'تبتدر': u'تُبْتَدَرْ', #1
u'تبتدر': u'تَبْتَدِرُ', #2
u'تبتدره': u'تَبْتَدِرَهُ', #2
u'تبتديها': u'تَبْتَدِيهَا', #1
u'تبتيت': u'تَبْتِيتِ', #1
u'تبتيل': u'تَبْتِيلٌ', #1
u'تبتيل': u'تَبْتِيلَ', #1
u'تبتيل': u'تَبْتِيلِ', #1
u'تبتيل': u'تَبْتِيلٍ', #2
u'تبتيلا': u'تَبْتِيلًا', #10
u'تبتيله': u'تَبْتِيلِهِ', #1
u'تبتيلها': u'تَبْتِيلِهَا', #2
u'تبتيلها': u'تَبْتِيلَهَا', #3
u'تبثيثا': u'تَبْثِيثًا', #1
u'تبجست': u'تَبَجّسْت', #3
u'تبجع': u'تَبْجَعُ', #1
u'تبجعن': u'تَبْجَعَنَّ', #1
u'تبحبحن': u'تُبَحْبِحْنَ', #2
u'تبخق': u'تَبْخَقُّ', #1
u'تبخق': u'تُبْخَقُ', #1
u'تبخلوني': u'تُبَخِّلُونِي', #1
u'تبدءان': u'تَبْدَءَانِ', #1
u'تبدءوا': u'تَبْدَءُوا', #16
u'تبدءون': u'تَبْدَءُونَ', #1
u'تبدءون': u'تُبْدَءُونَ', #1
u'تبدءون؟': u'تَبْدَءُونَ؟', #1
u'تبدءوهم': u'تَبْدَءُوهُمْ', #25
u'تبدا': u'تَبْدَا', #1
u'تبدا': u'تَبَدَّا', #2
u'تبدآن': u'تَبْدَآنِ', #2
u'تبدأوهم': u'تَبْدَأُوهُمْ', #1
u'تبدلواالخبيث': u'تبدلُواالْخَبِيثَ', #1
u'تبدؤه': u'تَبْدَؤُهُ', #1
u'تبدؤهم': u'تَبْدَؤُهُمْ', #2
u'تبدئة': u'تَبْدِئَةٍ', #1
u'تبدئة': u'تَبْدِئَةَ', #17
u'تبدئة': u'تَبْدِئَةُ', #17
u'تبدئة': u'تَبْدِئَةِ', #30
u'تبدئة': u'تَبْدِئَةً', #4
u'تبدئة': u'تَبْدِئَةٌ', #5
u'تبدئتها': u'تَبْدِئَتَهَا', #1
u'تبدئتهم': u'تَبْدِئَتِهِمْ', #1
u'تبدية': u'تَبْدِيَةِ', #3
u'تبديع': u'تَبْدِيعٍ', #1
u'تبديع': u'تَبْدِيعِ', #1
u'تبذو': u'تَبْذُوَ', #5
u'تبذو': u'تَبْذُو', #6
u'تبذوا': u'تَبْذُوا', #1
u'تبذيله': u'تَبْذِيلِهِ', #1
u'تبذيله': u'تَبْذِيلُهُ', #3
u'تبذيلي': u'تَبْذِيلِي', #1
u'تبرءوا': u'تبرءوا', #1
u'تبرءوا': u'تَبْرَءُوا', #1
u'تبرءوا': u'تَبَرَّءُوا', #4
u'تبرأتني': u'تَبَرَّأْتَنِي', #1
u'تبرآن': u'تَبْرَآنِ', #1
u'تبرأوا': u'تَبَرَّأُوا', #1
u'تبرأوا': u'تَبْرَأُوا', #1
u'تبررد': u'تبررد', #1
u'تبرزد': u'تبرزد', #1
u'تبرستان': u'تَبَرِسْتَانُ', #2
u'تبرضا،': u'تبرُّضًا،', #1
u'تبرضا': u'تَبَرّضًا', #2
u'تبرضا': u'تَبَرُّضًا', #2
u'تبرئا': u'تَبَرُّئًا', #1
u'تبريص': u'تَبْرِيصِ', #1
u'تبريصه': u'تَبْرِيصُهُ', #2
u'تبريصه': u'تَبْرِيصِهِ', #6
u'تبريئا': u'تَبْرِيئًا', #2
u'تبسي': u'تَبُسِّي', #2
u'تبشبش': u'تَبَشْبَشَ', #5
u'تبص': u'تَبِصُّ', #1
u'تبصرة': u'تبصرة', #1
u'تبصرة': u'تَبْصِرَةٍ', #1
u'تبصرة': u'تَبْصِرَةَ', #2
u'تبصرة': u'تَبْصِرَةً', #3
u'تبصرة': u'تَبْصِرَةِ', #66
u'تبطخت': u'تَبَطَّخَتْ', #1
u'تبطيل': u'تَبْطِيلُ', #1
u'تبطيل': u'تَبْطِيلِ', #1
u'تبطيله': u'تَبْطِيلِهِ', #1
u'تبطيلها': u'تَبْطِيلِهَا', #2
u'تبطيلهم': u'تَبْطِيلُهُمْ', #1
u'تبعاء': u'تُبَعَاءَ', #1
u'تبعثنى': u'تَبْعَثُنِى', #5
u'تبعج': u'تُبْعَجُ', #1
u'تبعدا': u'تَبَعُّدًا', #3
u'تبعدت': u'تَبَعَّدْت', #2
u'تبعض': u'تَبَعُّضُ', #1
u'تبعض': u'تُبَعِّضَ', #1
u'تبعض': u'تَبَعَّضَ', #10
u'تبعض': u'تَبَعُّضَ', #2
u'تبعض': u'تَبَعُّضِ', #2
u'تبعض': u'تُبَعَّضَ', #2
u'تبعض': u'تُبَعَّضُ', #3
u'تبعض': u'تُبَعِّضُ', #4
u'تبعض': u'تُبَعَّضْ', #7
u'تبعضا': u'تَبَعَّضَا', #1
u'تبعضت': u'تَبَعَّضَتْ', #19
u'تبعضه': u'تَبَعُّضِهِ', #2
u'تبعكني': u'تَبْعَكَنِي', #1
u'تبعنى': u'تَبِعَنِى', #2
u'تبعنيه؟،': u'تَبِعْنِيهِ؟،', #1
u'تبقل': u'تَبَقُّلٍ', #1
u'تبكعني': u'تَبْكَعَنِي', #1
u'تبكعني': u'تَبْكَعنِي', #2
u'تبكعنى': u'تَبْكَعَنِى', #3
u'تبكيان،': u'تَبْكِيَانِ،', #1
u'تبكيان': u'تَبْكِيَانِ', #2
u'تبلت': u'تَبَّلَتْ', #1
u'تبلت': u'تَبَلَتْ', #4
u'تبلتع': u'تَبَلْتَعَ', #1
u'تبلغنى': u'تَبْلُغْنِى', #1
u'تبلغنيه': u'تُبَلِّغُنِيه', #1
u'تبلغى': u'تَبْلُغِى', #1
u'تبلناهم': u'تَبَلْنَاهُمْ', #2
u'تبنة': u'تبنة', #1
u'تبنة': u'تَبِنَةٍ', #1
u'تبنة': u'تِبْنَةً', #1
u'تبنتين': u'تَبِنَتَيْنِ', #1
u'تبهنس': u'تَبَهْنَسَ', #1
u'تبوءوا': u'تَبَوَّءُوا', #23
u'تبوءوا': u'تَبُوءُوا', #3
u'تبوءوا': u'تَبَوّءُوا', #4
u'تبورت': u'تبورت', #1
u'تبورت': u'تَبَوَّرَتْ', #1
u'تبوغ': u'تَبَوَّغَ', #1
u'تبوكا': u'تبوكًا', #1
u'تبوكا،': u'تبوكًا،', #1
u'تبوكا،': u'تَبُوكَاً،', #1
u'تبوكا،': u'تَبُوكًا،', #2
u'تبوكا': u'تَبُوكًا', #4
u'تبوكانها': u'تَبُوكَانِهَا', #1
u'تبوئة': u'تَبْوِئَةٍ', #1
u'تبوئة': u'تَبْوِئَةِ', #1
u'تبوئة': u'تَبْوِئَةٌ', #3
u'تبوئة': u'تَبْوِئَةً', #5
u'تبوئتها': u'تَبْوِئَتهَا', #1
u'تبوئتها': u'تَبْوِئَتَهَا', #1
u'تبوئتها': u'تَبْوِئَتِهَا', #1
u'تبوئتها': u'تَبْوِئَتُهَا', #9
u'تبيعا': u'تَبِيعًا', #100
u'تبيعة،': u'تبيعة،', #1
u'تبيعة': u'تَبِيعَةٍ', #1
u'تبيعة': u'تَبِيعَةِ', #1
u'تبيعة،': u'تَبِيعَةً،', #1
u'تبيعة': u'تَبِيعَةً', #25
u'تبيعة': u'تَبِيعَةٌ', #43
u'تبيعتان': u'تَبِيعَتَانِ', #5
u'تبيعنى': u'تَبِيعَنِى', #1
u'تبيعنيه': u'تَبِيعَنِيهِ', #1
u'تبيعونى': u'تَبِيعُونِى', #1
u'تبيغ': u'تَبَيَّغَ', #1
u'تبيهان': u'تَبِيهَانِ', #1
u'تت': u'تت', #2326
u'تتأبر': u'تَتَأَبَّرْ', #4
u'تتأتيان': u'تَتَأَتَّيَانِ', #1
u'تتأد': u'تَتَأَدَّ', #4
u'تتأدم': u'تَتَأَدَّمُ', #1
u'تتأدى': u'تَتَأَدَّى', #261
u'تتأذ': u'تَتَأَذَّ', #8
u'تتأذى': u'تَتَأَذّى', #3
u'تتأذى': u'تَتَأَذَّى', #78
u'تتارخان': u'تَتَارْخَانْ', #5
u'تتارخانية': u'تَتَارْخَانِيَّةٍ', #1
u'تتارخانية': u'تَتَارْخَانِيَّةْ', #1
u'تتارخانية': u'تَتَارْخَانِيَّةٌ', #220
u'تتارخانية': u'تَتَارْخَانِيَّةُ', #7
u'تتاركا': u'تَتَارَكَا', #13
u'تتاركوا': u'تَتَارَكُوا', #1
u'تتأقت': u'تَتَأَقَّت', #1
u'تتأقت': u'تَتَأَقَّتْ', #3
u'تتأقت': u'تَتَأَقَّتُ', #6
u'تتام': u'تتامّ', #1
u'تتام': u'تَتَامّ', #4
u'تتام': u'تَتَامَّ', #4
u'تتامت': u'تَتَامَّتْ', #1
u'تتاموا': u'تَتَامّوا', #1
u'تتاموا': u'تَتَامُّوا', #2
u'تتأنف': u'تَتَأَنَّفُ', #1
u'تتايع': u'تتايع', #1
u'تتايع': u'تَتَايَعَ', #2
u'تتايعوا': u'تَتَايَعُوا', #1
u'تتأيم': u'تَتَأَيَّمَ', #2
u'تتأيم': u'تَتَأَيَّمْ', #7
u'تتأيمي': u'تَتَأَيَّمِي', #7
u'تتباله': u'تَتَبَالَه', #1
u'تتبرقع': u'تَتَبَرْقَعُ', #2
u'تتبعض': u'تَتَبَعّضُ', #1
u'تتبعض': u'تَتَبَعَّضَ', #13
u'تتبعض': u'تَتَبَعَّضُ', #137
u'تتبعض': u'تَتَبَعَّضْ', #3
u'تتبعونى': u'تُتْبِعُونِى', #1
u'تتبعونى': u'تَتْبَعُونِى', #2
u'تتبعى': u'تَتْبَعِى', #1
u'تتبعى': u'تَتَبَّعِى', #4
u'تتبوءوا': u'تَتَبَوَءُوا', #1
u'تتبيب': u'تَتْبِيبٍ', #6
u'تتبيعا': u'تَتْبِيعًا', #1
u'تتترس': u'تَتَتَرَّسْ', #1
u'تتثور': u'تَتَثَوَّرَ', #1
u'تتجارى': u'تَتَجَارَى', #7
u'تتجانف': u'تَتَجَانَفُ', #1
u'تتجز': u'تَتَجَزَّ', #1
u'تتجزى': u'تَتَجَزَّى', #4
u'تتجلجل': u'تَتَجَلْجَلُ', #2
u'تتحاص': u'تَتَحَاصُّ', #1
u'تتحاصص': u'تَتَحَاصَصُ', #1
u'تتحاكى': u'تَتَحَاكَى', #1
u'تتحتم': u'تَتَحَتَّمْ', #1
u'تتحتم': u'تَتَحَتَّمُ', #8
u'تتحذر': u'تَتَحَذَّرْ', #1
u'تتحرم': u'تَتَحَرَّمَ', #1
u'تتحرم': u'تَتَحَرَّمُ', #1
u'تتحريوا': u'تَتَحَرَيُوا', #1
u'تتحق': u'تَتَحَقَّ', #1
u'تتحيض': u'تَتَحَيَّض', #1
u'تتحيض': u'تَتَحَيَّضَ', #2
u'تتحيف': u'تَتَحَيَّفُ', #1
u'تتختم': u'تَتَخَتَّمْ', #1
u'تتختم': u'تَتَخَتَّمُ', #2
u'تتخدر': u'تَتَخَدَّرَ', #1
u'تتخطط': u'تَتَخَطَّطْ', #2
u'تتخلد': u'تَتَخَلَّدُ', #1
u'تتدابرون': u'تَتَدَابَرُونَ', #1
u'تتدانى': u'تَتَدَانَى', #2
u'تترخص': u'تَتَرَخَّصُ', #3
u'تترس': u'تُتُرِّسَ', #2
u'تترس': u'تَتَرَّسَ', #43
u'تترس': u'تَتَرُّسِ', #7
u'تترسهم': u'تَتَرُّسِهِمْ', #6
u'تترسوا': u'تَتَرَّسُوا', #103
u'تتركنى': u'تَتْرُكُنِى', #1
u'تترمد': u'تَتَرَمَّدُ', #1
u'تتروج': u'تَتَرَوَّجُ', #1
u'تترى،': u'تترى،', #1
u'تترى': u'تَتْرَى', #38
u'تتريب': u'تَتْرِيبِ', #12
u'تتريب': u'تَتْرِيبٍ', #16
u'تتريب': u'تَتْرِيبَ', #2
u'تتريب': u'تَتْرِيبُ', #9
u'تتريبا': u'تَتْرِيبًا', #6
u'تتريبه': u'تَتْرِيبِهِ', #10
u'تتريبه': u'تَتْرِيبُهُ', #13
u'تتريبها': u'تَتْرِيبِهَا', #1
u'تتريبهما': u'تَتْرِيبِهِمَا', #2
u'تتزيه': u'تَتْزِيهٍ', #1
u'تتساويان': u'تَتَسَاوَيَانِ', #5
u'تتسر': u'تَتَّسِرُ', #1
u'تتسرى': u'تَتَسَرَّى', #1
u'تتسلت': u'تَتَسَلَّتْ', #1
u'تتشرب': u'تَتَشَرَّبُ', #11
u'تتشرب': u'تَتَشَرَّبْ', #2
u'تتشرب': u'تَتَشَرَّبَ', #3
u'تتشربه': u'تَتَشَرَّبهُ', #1
u'تتشربه': u'تَتَشَرَّبُهُ', #2
u'تتشرق': u'تَتَشَرّقُ', #2
u'تتشطر': u'تَتَشَطَّرُ', #10
u'تتشطران': u'تَتَشَطَّرَانِ', #1
u'تتشقص': u'تَتَشَقَّصْ', #1
u'تتشور': u'تتشور', #2
u'تتشور': u'تَتَشَوَّرُ', #3
u'تتصعد': u'تَتَصَعَّدُ', #1
u'تتضع': u'تُتَّضَعُ', #1
u'تتضيف': u'تَتَضَيَّف', #1
u'تتضيف': u'تَتَضَيَّفُ', #7
u'تتطلق': u'تُتَطَلَّقْ', #1
u'تتظالم': u'تَتَظَالَمُ', #1
u'تتعاقبانه': u'تَتَعَاقَبَانِهِ', #1
u'تتعامله': u'تَتَعَامَلُهُ', #1
u'تتعدل': u'تَتَعَدَّلُ', #2
u'تتعزم': u'تَتَعَزَّم', #1
u'تتعمر': u'تَتَعَمَّرَ', #1
u'تتعمر': u'تَتَعَمَّرُ', #5
u'تتعيب': u'تَتَعَيَّبَ', #3
u'تتعيب': u'تَتَعَيَّبْ', #3
u'تتعيب': u'تَتَعَيَّبُ', #9
u'تتعير': u'تَتَعَيَّرُ', #9
u'تتغلظ': u'تَتَغَلَّظْ', #10
u'تتغلظ': u'تَتَغَلَّظَ', #2
u'تتغلظ': u'تَتَغَلَّظُ', #22
u'تتفتى': u'تَتَفَتَّى', #1
u'تتفقى': u'تَتَفَقَّى', #2
u'تتقاصى': u'تَتَقَاصَى', #2
u'تتقامس': u'تَتَقَامَسُ', #1
u'تتقايأه': u'تتقايأه', #1
u'تتقرى': u'تَتَقَرَّى', #44
u'تتقسط': u'تَتَقَسَّطُ', #5
u'تتقعقع': u'تَتَقَعْقَع', #1
u'تتقعقع': u'تَتَقَعْقَعُ', #2
u'تتقفا': u'تُتَقَفَّا', #1
u'تتقلل': u'تَتَقَلَّلُ', #2
u'تتقلل': u'تَتَقَلَّلَ', #6
u'تتقوب': u'تَتَقَوّبُ', #1
u'تتقوله': u'تَتَقَوّلُهُ', #1
u'تتقوله': u'تَتَقَوَّلُهُ', #1
u'تتكارى': u'تُتَكَارَى', #2
u'تتكايس': u'تَتَكَايَسُ', #1
u'تتكفأ': u'تَتَكَفَّأُ', #1
u'تتلازم': u'تَتَلَازَمَ', #1
u'تتلازم': u'تَتَلَازَمْ', #1
u'تتلاقيان': u'تَتَلَاقَيَانِ', #1
u'تتلجم': u'تَتَلَجَّمُ', #2
u'تتلجم': u'تَتَلَجَّمْ', #2
u'تتلخلخ': u'تَتَلَخْلَخُ', #1
u'تتلفق': u'تَتَلَفَّقْ', #4
u'تتلوان': u'تَتْلُوَانِ', #1
u'تتلئب': u'تَتْلَئِبّ', #4
u'تتمحض': u'تَتَمَحَّضُّ', #1
u'تتمحض': u'تَتَمَحَّضُ', #14
u'تتمحض': u'تَتَمَحَّضْ', #29
u'تتمحض': u'تَتَمَحَّضَ', #3
u'تتمدح': u'تَتَمَدَّحُ', #1
u'تتمشطي': u'تَتَمَشَّطِي', #1
u'تتمعك': u'تَتَمَعَّكُ', #4
u'تتناتج': u'تَتَنَاتَجُ', #3
u'تتناخس': u'تَتَنَاخَسُ', #1
u'تتنافذ': u'تَتَنَافَذْ', #2
u'تتنافيان': u'تَتَنَافَيَانِ', #1
u'تتهاور': u'تَتَهَاوَرُ', #1
u'تتهايل': u'تَتَهَايَلُ', #2
u'تتهمونى؟': u'تَتَّهِمُونِى؟', #1
u'تتهنى': u'تَتَهَنَّى', #2
u'تتهيل': u'تَتَهَيَّلُ', #3
u'تتواليان': u'تَتَوَالَيَانِ', #3
u'تتوضئوا': u'تَتَوَضّئُوا', #3
u'تتوضئوا': u'تَتَوَضَّئُوا', #9
u'تتوفانى': u'تَتَوَفَّانِى', #1
u'تتيما': u'تَتَيُّمًا', #1
u'تثاوب': u'تَثَاوَبَ', #14
u'تثاوب': u'تَثَاوُبٌ', #2
u'تثاوبا': u'تَثَاوُبًا', #1
u'تثاوبت': u'تَثَاوَبْت', #2
u'تثاوبت': u'تَثَاوَبْتُ', #2
u'تثعب': u'تَثْعَبُ', #1
u'تثفو': u'تثفوُ', #1
u'تثلط': u'تَثْلِط', #1
u'تثلط': u'تَثْلِطَ', #1
u'تثلطون': u'تَثْلِطُونَ', #8
u'تثوج': u'تَثُوجُ', #1
u'تثيبت': u'تَثَيَّبَتْ', #1
u'تج': u'تُجْ', #1
u'تجاحد': u'تَجَاحُدٍ', #1
u'تجاحد': u'تَجَاحُدَ', #1
u'تجاحد': u'تَجَاحَدَ', #2
u'تجاحد': u'تَجَاحُدِ', #2
u'تجاحد': u'تَجَاحُدٌ', #5
u'تجاحدا': u'تَجَاحَدَا', #19
u'تجاحدهما': u'تَجَاحُدُهُمَا', #2
u'تجاحفت': u'تَجَاحَفَتْ', #4
u'تجاذينا': u'تَجَاذَيْنَا', #2
u'تجارت': u'تَجَارَتْ', #2
u'تجارح': u'تَجَارَحَ', #6
u'تجارحا': u'تَجَارَحَا', #6
u'تجارحوا': u'تَجَارَحُوا', #3
u'تجارؤ': u'تَجَارُؤٌ', #1
u'تجاريب': u'تَجَارِيبِ', #1
u'تجاعله': u'تُجَاعِلَهُ', #1
u'تجافاه': u'تَجَافَاهُ', #1
u'تجافيف': u'تجافيف', #1
u'تجافيف': u'تَجَافِيفَ', #3
u'تجانفا': u'تَجَانُفًا', #1
u'تجانفنا': u'تَجَانَفْنَا', #9
u'تجاننت': u'تَجَانَنْت', #1
u'تجاهيزهم': u'تَجَاهِيزَهُمْ', #1
u'تجاهين': u'تُجَاهِينَ', #1
u'تجبلت': u'تَجَبَّلَتْ', #2
u'تجبنى': u'تُجِبْنِى', #1
u'تجتزئ': u'تَجْتَزِئَ', #2
u'تجتزئ': u'تَجْتَزِئُ', #2
u'تجتلد': u'تَجْتَلِدُ', #1
u'تجتلي': u'تَجْتَلِي', #3
u'تجتهر': u'تَجْتَهِرَ', #1
u'تجحر': u'تُجْحِرُ', #2
u'تجدنى': u'تَجِدُنِى', #1
u'تجدونى': u'تَجِدُونِى', #2
u'تجدينى': u'تَجِدِينِى', #2
u'تجذمت': u'تَجَذَّمَتْ', #2
u'تجذو': u'تَجْذُو', #4
u'تجذيم': u'تَجْذِيمِ', #1
u'تجذيمه': u'تَجْذِيمُهُ', #3
u'تجذيمه': u'تَجْذِيمِهِ', #6
u'تجرءوا': u'تَجَرَّءُوا', #1
u'تجرءوا': u'تَجْرُءُوا', #1
u'تجراة': u'تجراة', #1
u'تجراة': u'تَجْرَاةٍ', #1
u'تجراة': u'تِجْرَاةَ', #3
u'تجراة': u'تَجْرَاةَ', #8
u'تجرجم': u'تَجَرْجُمُ', #1
u'تجرجم': u'تَجْرَجَمُ', #1
u'تجرجما': u'تَجَرْجُمَا', #1
u'تجرجما': u'تَجَرْجَمَا', #2
u'تجرحت': u'تَجَرَّحَتْ', #1
u'تجرمته': u'تَجَرَّمْته', #1
u'تجرنى': u'تُجِرْنِى', #1
u'تجرئة': u'تَجْرِئَةُ', #1
u'تجريا': u'تَجَرِّيًا', #1
u'تجريان': u'تجريان', #1
u'تجريان': u'تَجْرِيَانِ', #4
u'تجزأة': u'تُجْزَأَةُ', #1
u'تجزأة': u'تُجْزَأَةَ', #7
u'تجزئان': u'تُجْزِئَانِ', #2
u'تجزيان': u'تُجْزِيَانِ', #2
u'تجزيان': u'تَجْزِيَانِ', #4
u'تجزينى': u'تُجْزِينِى', #1
u'تجسيس': u'تَجْسِيسِ', #1
u'تجسيس': u'تَجْسِيسٍ', #2
u'تجسيس': u'تَجْسِيسٌ', #3
u'تجشى': u'تَجَشَّى', #2
u'تجض': u'تُجَضّ', #1
u'تجعلت': u'تَجَعَّلَتِ', #1
u'تجعلنى': u'تَجْعَلَنِى', #1
u'تجعلنى': u'تَجْعَلْنِى', #4
u'تجلانى': u'تَجَلاَّنِى', #2
u'تجلة': u'تَجِلَّةً', #1
u'تجلدنى': u'تَجْلِدُنِى', #1
u'تجلدونى': u'تَجْلِدُونِى', #1
u'تجمير': u'تَجْمِيرٌ', #2
u'تجمير': u'تَجْمِيرِ', #9
u'تجميره': u'تَجْمِيرِهِ', #1
u'تجميرها': u'تَجْمِيرَهَا', #1
u'تجميرها': u'تَجْمِيرِهَا', #5
u'تجهيزة': u'تَجْهِيزَةِ', #1
u'تجوير': u'تَجْوِيرَ', #1
u'تجويره': u'تَجْوِيرِهِ', #1
u'تجي': u'تَجِي', #5
u'تجىء': u'تَجِىءَ', #10
u'تجىء': u'تَجِىءُ', #11
u'تجىء': u'تجىء', #2
u'تجيبنى': u'تُجِيبَنِى', #3
u'تجيبونى': u'تُجِيبُونِى', #1
u'تجيرى': u'تُجِيرِى', #1
u'تجيني': u'تَجِينِي', #1
u'تجييء': u'تَجْيِيءُ', #1
u'تجيئنا': u'تَجِيئُنَا', #1
u'تجيئني': u'تَجِيئنِي', #1
u'تجيئنى': u'تَجِيئَنِى', #1
u'تجيئني': u'تَجِيئَنِي', #6
u'تجيئه': u'تَجِيئُهُ', #4
u'تحاجز': u'تَحَاجَزَ', #2
u'تحاجزنا': u'تَحَاجَزْنَا', #1
u'تحاجزوا،': u'تَحَاجَزُوا،', #1
u'تحاجزوا': u'تَحَاجَزُوا', #3
u'تحآجون': u'تُحَآجُّونَ', #2
u'تحادر': u'تَحَادُرِ', #1
u'تحاص': u'تَحَاصٌّ', #1
u'تحاص': u'تُحَاصُّ', #11
u'تحاص': u'تَحَاصَّ', #19
u'تحاص': u'تَحَاصُّ', #2
u'تحاص': u'تُحَاصَّ', #2
u'تحاصا': u'تَحَاصًّا', #5
u'تحاصا': u'تَحَاصَّا', #68
u'تحاصبوا': u'تحاصبوا', #2
u'تحاصص': u'تَحَاصُصَ', #1
u'تحاصص': u'تُحَاصَصْ', #1
u'تحاصص': u'تُحَاصِصَ', #1
u'تحاصص': u'تُحَاصِصْ', #1
u'تحاصص': u'تُحَاصِصُ', #41
u'تحاصص': u'تَحَاصَصَ', #5
u'تحاصص': u'تُحَاصَصُ', #7
u'تحاصصا': u'تَحَاصَصَا', #1
u'تحاصصه': u'تُحَاصِصُهُ', #1
u'تحاصصهم': u'تُحَاصِصُهُمْ', #1
u'تحاصصهم': u'تَحَاصُصِهِمْ', #2
u'تحاصصوا': u'تَحَاصَصُوا', #2
u'تحاصهما': u'تَحَاصُّهُمَا', #1
u'تحاصوا': u'تَحَاصُّوا', #20
u'تحاصوا': u'تَحَاصَّوْا', #6
u'تحافظه': u'تُحَافِظَهُ', #1
u'تحاقرون': u'تُحَاقِرُونَ', #1
u'تحاوز': u'تَحَاوُزِ', #1
u'تحاوزا': u'تَحَاوَزَا', #1
u'تحاوزوا': u'تَحَاوَزُوا', #1
u'تحبة': u'تَحِبّةُ', #1
u'تحبسنى': u'تَحْبِسَنِى', #1
u'تحبسنى': u'تَحْبِسْنِى', #1
u'تحبسنى': u'تَحْبِسُنِى', #3
u'تحبسى': u'تَحْبِسِى', #3
u'تحبشوا': u'تَحَبّشُوا', #1
u'تحتاجه': u'تَحْتَاجُهُ', #28
u'تحتاح': u'تِحْتَاحُ', #2
u'تحتاز': u'تُحْتَازُ', #3
u'تحتبك': u'تَحْتَبِكُ', #1
u'تحتثه': u'تَحْتَثّهُ', #3
u'تحتجبى': u'تَحْتَجِبِى', #2
u'تحتجر': u'تَحْتَجِر', #1
u'تحتجر': u'تُحْتَجَرُ', #1
u'تحتجم،': u'تَحْتَجِمَ،', #1
u'تحتجم': u'تَحْتَجِمُ', #2
u'تحتجم': u'تَحْتَجِمْ', #2
u'تحتجم': u'تَحْتَجِمَ', #6
u'تحتجمون': u'تَحْتَجِمُونَ', #3
u'تحتزم': u'تَحْتَزِمُ', #1
u'تحتشه': u'تَحْتَشَّهُ', #1
u'تحتشي': u'تَحْتَشِي', #1
u'تحتشى': u'تحتشى', #1
u'تحتشى': u'تَحْتَشِى', #2
u'تحتصد': u'تُحْتَصَدَ', #1
u'تحتفر': u'تُحْتَفَرُ', #2
u'تحتفئوا': u'تَحْتَفِئُوا', #7
u'تحتقب': u'تَحْتَقِبُ', #1
u'تحتقب': u'تَحْتَقِبَ', #2
u'تحتمت': u'تَحَتَّمَتْ', #3
u'تحتويان': u'تَحْتَوِيَانِ', #4
u'تحتى': u'تَحْتِى', #5
u'تحتيم': u'تَحْتِيمُ', #1
u'تحتيما': u'تَحْتِيمًا', #1
u'تحتيمه': u'تَحْتِيمِهِ', #1
u'تحجرته': u'تَحَجَّرْته', #1
u'تحجرته': u'تَحَجَّرْتَهُ', #1
u'تحجف': u'تَحَجَّفَ', #1
u'تحجيرة': u'تَحْجِيرَةُ', #2
u'تحجيز': u'تَحْجِيزٍ', #1
u'تحجيزا': u'تَحْجِيزًا', #1
u'تحدثة': u'تَحْدِثَةُ', #1
u'تحدثناه': u'تَحَدَّثْنَاهُ', #1
u'تحدثناه': u'تُحَدِّثُنَاهُ', #4
u'تحدثنى': u'تُحَدِّثُنِى', #5
u'تحدثنيه': u'تُحَدِّثُنِيهِ', #1
u'تحدثنيه': u'تُحَدِّثْنِيهِ', #1
u'تحدثينى': u'تُحَدِّثِينِى', #4
u'تحذيف': u'تَحْذِيفٌ', #4
u'تحذيفا': u'تَحْذِيفًا', #2
u'تحرفا': u'تَحَرُّفًا', #9
u'تحرفت': u'تَحَرَّفَتْ', #2
u'تحرما': u'تَحَرُّمًا', #2
u'تحرمت': u'تَحَرَّمَتْ', #2
u'تحرمت': u'تَحَرَّمْتَ', #2
u'تحرمنى': u'تَحْرِمْنِى', #1
u'تحرمى': u'تَحْرُمِى', #2
u'تحريكة': u'تَحْرِيكَةٍ', #1
u'تحزنا': u'تَحَزُّنًا', #3
u'تحزيق': u'تَحْزِيقُ', #1
u'تحسيم': u'تَحْسِيمُ', #1
u'تحشرنى': u'تَحْشُرْنِى', #1
u'تحشؤه': u'تَحُشُّؤُهُ', #1
u'تحشيم': u'تَحْشِيمٌ', #1
u'تحصير': u'تَحْصِيرُ', #1
u'تحصيلة': u'تَحْصِيلَةِ', #1
u'تحظلا': u'تُحْظَلَا', #1
u'تحفلت': u'تَحَفَّلَتْ', #13
u'تحفيكم': u'تُحْفِيكُمْ', #1
u'تحفينى': u'تُحْفِينِى', #1
u'تحقلت': u'تَحَقَّلَتْ', #1
u'تحقيقة': u'تَحْقِيقَةٍ', #3
u'تحككت': u'تَحَكَّكَتْ', #1
u'تحكير': u'تَحْكِيرِ', #1
u'تحلفو': u'تَحْلِفُو', #2
u'تحمار،': u'تَحْمَارَّ،', #1
u'تحمار': u'تحمار', #2
u'تحمار': u'تَحْمَارَّ', #2
u'تحمار': u'تَحْمَارُّ', #9
u'تحملانى': u'تَحْمِلاَنِى', #1
u'تحملنى': u'تَحْمِلَنِى', #1
u'تحميدة': u'تَحْمِيدَةً', #11
u'تحميدة': u'تَحْمِيدَةٍ', #17
u'تحميدة،': u'تَحْمِيدَةً،', #2
u'تحميدة': u'تَحْمِيدَةٌ', #9
u'تحميده': u'تَحْمِيدَهً', #1
u'تحنفت': u'تَحَنَّفْتُ', #1
u'تحنقا': u'تَحَنُّقًا', #1
u'تحننا': u'تَحَنُّنًا', #1
u'تحننت': u'تَحَنَّنْت', #1
u'تحنئة': u'تَحْنِئَةِ', #1
u'تحنيث': u'تَحْنِيثٌ', #1
u'تحنيث': u'تَحْنِيثُ', #13
u'تحنيث': u'تَحْنِيثِ', #6
u'تحنيثه': u'تَحْنِيثِهِ', #17
u'تحنيثه': u'تَحْنِيثَهُ', #6
u'تحنيثه': u'تَحْنِيثُهُ', #8
u'تحوسك': u'تَحُوسُكَ', #1
u'تحولمه': u'تَحَوْلُمِهِ', #1
u'تحياة': u'تَحَيَاةِ', #1
u'تحيضت': u'تَحَيَّضَتْ', #3
u'تحيف': u'تُحِيفَ', #1
u'تحيف': u'تَحَيُّفٌ', #2
u'تحيفة': u'تُحِيفَةٌ', #1
u'تحيفة': u'تُحَيْفَةُ', #3
u'تحيفه': u'تَحَيَّفَهُ', #1
u'تحيلا': u'تَحَيُّلًا', #23
u'تحيلات': u'تَحَيُّلَاتٌ', #1
u'تحيلت': u'تَحَيَّلْت', #1
u'تحيى': u'تَحْيَى', #1
u'تحيى،': u'تِحْيَى،', #1
u'تحيى': u'تحيى', #2
u'تحيى': u'تُحْيِى', #2
u'تحيى': u'تِحْيَى', #2
u'تخارج': u'تَخَارَجَ', #1
u'تخارج': u'تُخَارَجَ', #1
u'تخارجوا': u'تَخَارَجُوا', #1
u'تخارجون': u'تَخَارَجُونَ', #1
u'تخاسس': u'تَخَاسَسَ', #1
u'تخافنى': u'تَخَافُنِى', #1
u'تخافى': u'تَخَافِى', #1
u'تخالجت': u'تَخَالَجَتْ', #1
u'تخالعت': u'تَخَالَعَتْ', #2
u'تخالل': u'تُخَالِلُ', #1
u'تخالل': u'تُخَالِلْ', #1
u'تخالني': u'تَخَالُنِي', #1
u'تخاله': u'تَخَالُهُ', #3
u'تخالهم': u'تَخَالُهُمْ', #2
u'تخاليط': u'تَخَالِيطُ', #1
u'تخاليط': u'تَخَالِيطِ', #1
u'تخاور': u'تَخَاوَرُ', #1
u'تخاور': u'تُخَاوِرُ', #1
u'تخاوفوا': u'تَخَاوَفُوا', #1
u'تخاييل': u'تَخَايِيلُ', #2
u'تخبرناوروي': u'تُخْبِرُنَاوَرُوِيَ', #1
u'تخبرنى': u'تُخْبِرَنِى', #2
u'تخبرنى': u'تُخْبِرُنِى', #2
u'تخبرى': u'تُخْبِرِى', #3
u'تخبيب': u'تَخْبِيبُ', #1
u'تخبيبهم': u'تَخْبِيبُهُمْ', #1
u'تخبيبهم': u'تَخْبِيبِهِمْ', #1
u'تخبيط': u'تَخْبِيطَ', #1
u'تخبيط': u'تَخْبِيطٌ', #4
u'تخبيطا': u'تَخْبِيطًا', #1
u'تخبيطهم': u'تَخْبِيطِهِمْ', #1
u'تختارنى': u'تَخْتَارَنِى', #2
u'تختبط': u'تَخْتَبِطُ', #1
u'تختدم': u'تُخْتَدَمُ', #1
u'تختدمه': u'تَخْتَدِمُهُ', #1
u'تخترف': u'تُخْتَرَفُ', #1
u'تخترم': u'تَخْتَرِمُ', #1
u'تخترمني': u'تَخْتَرِمَنِي', #1
u'تخترمه': u'تَخْتَرِمْهُ', #1
u'تخترمه': u'تَخْتَرِمُهُ', #9
u'تختصبها': u'تَخْتَصُّبِهَا', #1
u'تختفق': u'تَخْتَفقُ', #1
u'تختفق': u'تَخْتَفِقُ', #4
u'تختلع': u'تَخْتَلِع', #1
u'تختلع': u'تَخْتَلِعُ', #16
u'تختلع': u'تَخْتَلِعَ', #18
u'تختمت': u'تَخَتَّمَتْ', #1
u'تخثعموا': u'تَخَثْعَمُوا', #2
u'تخدرت': u'تَخَدَّرَتْ', #3
u'تخذت': u'تخذت', #2
u'تخذت': u'تَخِذْت', #2
u'تخذف': u'تَخْذِفْ', #3
u'تخذف،': u'تَخْذِفُ،', #4
u'تخذف': u'تَخْذِفُ', #6
u'تخربت': u'تَخَرَّبَتْ', #2
u'تخردل': u'تُخَرْدِلُ', #1
u'تخرصا': u'تَخَرّصًا', #1
u'تخرصا': u'تَخَرُّصًا', #2
u'تخرقة': u'تَخْرِقَةُ', #1
u'تخرقة': u'تَخْرِقَةِ', #1
u'تخريص': u'تَخْرِيصٍ', #1
u'تخريص': u'تَخْرِيصِ', #14
u'تخريص': u'تَخْرِيصُ', #4
u'تخريص': u'تَخْرِيصَ', #5
u'تخريصه': u'تَخْرِيصُهُ', #1
u'تخريصه': u'تَخْرِيصِهِ', #3
u'تخريصهم': u'تَخْرِيصِهِمْ', #1
u'تخريصهما': u'تَخْرِيصِهِمَا', #7
u'تخزعت': u'تَخَزَّعَتْ', #1
u'تخزعت': u'تَخَزّعَتْ', #2
u'تخزعوا': u'تَخَزّعُوا', #2
u'تخطبنى': u'تَخْطُبُنِى', #1
u'تخطىء': u'تخطىء', #1
u'تخففا': u'تَخَفُّفًا', #1
u'تخلج': u'تَخَلَّجَ', #3
u'تخلعت': u'تَخَلَّعَتْ', #1
u'تخلفعن': u'تَخَلَّفَعَنْ', #1
u'تخلفنى': u'تُخَلِّفُنِى', #1
u'تخلفنيه': u'تَخْلُفَنِيهِ', #1
u'تخلفنيه': u'تُخْلِفْنِيهِ', #1
u'تخلفنيه،': u'تُخْلِفْنِيهِ،', #1
u'تخلفنيه': u'تُخْلِفَنِيهِ', #11
u'تخلفنيه': u'تُخْلَفَنِيهِ', #3
u'تخلوان': u'تَخْلُوَانِ', #1
u'تخليس': u'تُخَلِّيَس', #1
u'تخمرى': u'تُخَمِّرِى', #1
u'تخمع': u'تَخْمَع', #2
u'تخمين': u'تَخْمِينً', #1
u'تخندف': u'تُخَنْدِفُ', #1
u'تخندفين': u'تُخَنْدِفِينَ', #2
u'تخورم': u'تخورم', #1
u'تخولت': u'تَخَوّلْت', #1
u'تخومة': u'تَخُومَةٍ', #1
u'تخونا': u'تَخَوُّنًا', #1
u'تخيرونى': u'تُخَيِّرُونِى', #1
u'تخيس': u'تُخَيَّسُ', #1
u'تخيس': u'تُخَيّسُ', #3
u'تخييسا': u'تَخْيِيسًا', #1
u'تداخن': u'تَدَّاخَنُ', #1
u'تدأدأ': u'تَدَأْدَأَ', #4
u'تدارءا': u'تَدَارَءَا', #1
u'تدارءوا': u'تَدَارَءُوا', #1
u'تدارأت': u'تَدَارَأَتْ', #1
u'تدارأتم': u'تَدَارَأْتُمْ', #1
u'تداعيتا': u'تَدَاعَيَتَا', #1
u'تدافنتم': u'تَدَافَنْتُمْ', #1
u'تدافنوا،': u'تَدَافَنُوا،', #1
u'تدافنوا': u'تَدَافَنُوِا', #1
u'تدافنوا': u'تَدَافَنُوا', #16
u'تدالكت': u'تَدَالَكَتْ', #2
u'تدالون': u'تُدَالُونَ', #1
u'تدانت': u'تَدَانَتْ', #2
u'تدانيتم': u'تَدَانَيْتُمْ', #1
u'تداينته': u'تَدَايَنَتْهُ', #4
u'تداينتها': u'تَدَايَنَتْهَا', #1
u'تدحل': u'تَدْحَلْ', #1
u'تدخلى': u'تَدْخُلِى', #1
u'تدخلى': u'تُدْخِلِى', #4
u'تدرإ': u'تُدْرَإِ', #1
u'تدرإ': u'تُدْرَإٍ', #4
u'تدركت': u'تَدَرَّكْتَ', #1
u'تدركنى': u'تُدْرِكُنِى', #4
u'تدركونى': u'تُدْرِكُونِى', #2
u'تدرؤه': u'تَدْرَؤُهُ', #2
u'تدريان': u'تَدْرِيَانِ', #3
u'تدعنى': u'تَدَعُنِى', #1
u'تدعوان': u'تُدْعَوَانِ', #1
u'تدعوان': u'تَدْعُوَانِ', #4
u'تدعونى': u'تَدْعُونِى', #4
u'تدعيان،': u'تَدَّعِيَانِ،', #1
u'تدعيان': u'تَدَّعِيَانِ', #7
u'تدفعنى': u'تَدْفَعُنِى', #1
u'تدفية': u'تَدْفِيَةِ', #1
u'تدلسا': u'تَدَلُّسًا', #1
u'تدهده': u'تَدَهْدَهَ', #1
u'تدهل': u'تَدْهَلْ', #1
u'تدودت': u'تَدَوَّدَتْ', #3
u'تدورت': u'تَدَوَّرَتْ', #1
u'تديل': u'تُدِيلُ', #1
u'تذامروا': u'تَذَامَرُوا', #2
u'تذبخ': u'تَذَبُّخَ', #1
u'تذبيخا': u'تَذْبِيخًا', #1
u'تذكرنيه': u'تُذَكّرُنِيهِ', #1
u'تذكرنيه': u'تُذَكّرْنِيهِ', #1
u'تذكرنيه': u'تُذَكِّرُنِيهِ', #1
u'تذكرهاقوله': u'تُذَكِّرُهَاقَوْلُهُ', #1
u'تذكرونى': u'تَذْكُرُونِى', #1
u'تذمهSموته': u'تَذُمّهُSمَوْتُهُ', #1
u'تذنوبه،': u'تَذْنُوبِهِ،', #1
u'تذوقى': u'تَذُوقِى', #4
u'تراءلهم': u'تَرَاءَلهم', #1
u'تراءون': u'تَرَاءَوْنَ', #6
u'تراءون': u'تُرَاءُونَ', #8
u'ترآب': u'تَرْآبُ', #1
u'ترابة': u'تُرَابَةً', #1
u'ترابة': u'تُرَابَةٌ', #9
u'ترابحل': u'ترابحل', #2
u'ترابخانة': u'ترابخانة', #1
u'ترابخشيدم': u'ترابخشيدم', #2
u'ترابخشيذم': u'ترابخشيذم', #1
u'ترابخون': u'ترابخون', #1
u'ترابدعاء': u'ترابدعاء', #1
u'ترابر': u'ترابر', #5
u'ترابرفلان': u'ترابرفلان', #1
u'ترابروي': u'ترابروي', #1
u'ترابروى': u'ترابروى', #1
u'ترابزني': u'ترابزني', #1
u'ترابشهر': u'ترابشهر', #1
u'ترابص': u'تَرَابُصٌ', #1
u'ترابهمسايه': u'ترابهمسايه', #1
u'ترابيوشا': u'ترابيوشا', #1
u'تراتايك': u'تراتايك', #1
u'تراجزازين': u'تراجزازين', #1
u'تراجعنى': u'تُرَاجِعَنِى', #3
u'تراجعنى': u'تُرَاجِعُنِى', #4
u'تراجعى': u'تُرَاجِعِى', #2
u'تراجه': u'تراجه', #1
u'تراجيح': u'تَرَاجِيحِ', #2
u'تراحق': u'تراحق', #2
u'تراحمون': u'تَرَاحَمُونَ', #1
u'ترادادم': u'ترادادم', #1
u'ترادبد': u'ترادبد', #1
u'ترادر': u'ترادر', #1
u'تراراست': u'تراراست', #1
u'ترازادو': u'ترازادو', #1
u'ترازمان': u'ترازمان', #1
u'ترازيان': u'ترازيان', #1
u'تراست': u'تراست', #6
u'تراضخوا': u'تَرَاضَخُوا', #1
u'تراطل': u'تُرَاطَلُ', #6
u'تراعة': u'تَرَّاعَة', #1
u'تراقد': u'تَرَاقَدَ', #1
u'تراكردم': u'تراكردم', #2
u'تراكشت': u'تراكشت', #1
u'تراكهما': u'تَرَاكَهُمَا', #1
u'تراكين': u'تراكين', #2
u'ترامحت': u'تَرَامَحَتْ', #1
u'تراميدانم': u'تراميدانم', #1
u'تراندار': u'تراندار', #1
u'ترانى': u'تُرَانِى', #1
u'ترانى': u'تَرَانِى', #4
u'تراهزار': u'تراهزار', #1
u'تراوضا': u'تَرَاوَضَا', #2
u'تراوضان': u'تَرَاوَضَانِ', #1
u'تراوضهما': u'تَرَاوُضَهُمَا', #1
u'تراوضهما': u'تَرَاوُضُهُمَا', #1
u'تراويه': u'تَرَاوِيهِ', #1
u'ترآى': u'تَرَآى', #2
u'ترائى': u'تَرَائِى', #1
u'ترائى': u'تُرَائَى', #1
u'ترايا': u'تَرَايَا', #4
u'تراياهم': u'تَرَايَاهُمْ', #1
u'تراير': u'تراير', #1
u'ترايع': u'تُرَايِعُ', #1
u'ترايك': u'ترايك', #4
u'ترايكي': u'ترايكي', #1
u'تربعلبنت': u'تَرَبْعَلْبَنْت', #1
u'تربيل': u'تَرْبِيلُ', #1
u'ترة': u'تِرَةٍ', #1
u'ترة': u'تِرَةً', #15
u'ترة': u'تِرَة', #2
u'ترة': u'تِرَةٌ', #5
u'ترتجز': u'تَرْتَجِزُ', #3
u'ترتجع': u'تَرْتَجِعْ', #2
u'ترتجع': u'تُرْتَجَعُ', #2
u'ترتجع': u'تَرْتَجِعُ', #3
u'ترتجع': u'تَرْتَجِعَ', #4
u'ترتجعه': u'تَرْتَجِعْهُ', #1
u'ترتدف': u'تَرْتَدِفُ', #2
u'ترتدف': u'تُرْتَدَفُ', #2
u'ترتروه': u'تَرْتَرُوهُ', #1
u'ترتروه': u'تَرْتِرُوهُ', #4
u'ترتضع': u'تَرْتَضِعَ', #1
u'ترتضع': u'تَرْتَضِعُ', #1
u'ترتفض': u'تَرْتَفِضَ', #1
u'ترتفض': u'تُرْتَفَضْ', #1
u'ترتفض': u'تُرْتَفَضُ', #6
u'ترتفض': u'تَرْتَفِضُ', #7
u'ترتفق': u'تَرْتَفِقُ', #2
u'ترتقع': u'تُرْتَقَعُ', #1
u'ترتيلاق': u'تَرْتِيلاق', #1
u'ترتيلاوكانت': u'تَرْتِيلًاوَكَانَتْ', #1
u'ترثنى': u'تَرِثْنِى', #1
u'ترثنى': u'تَرِثُنِى', #4
u'ترثية': u'تَرْثِيَةُ', #1
u'ترثيته': u'تَرْثِيَتُهُ', #2
u'ترجعوابعدي': u'تَرْجِعُوابَعْدِي', #1
u'ترجعى': u'تَرْجِعِى', #5
u'ترجئة': u'تَرْجِئَةِ', #1
u'ترجينى': u'تُرَجِّينِى', #1
u'ترحبت': u'تَرَحّبَتْ', #1
u'ترحة': u'تَرْحَةٌ', #1
u'ترحض': u'تَرْحَضُ', #1
u'ترحلت': u'تَرَحَّلَتْ', #2
u'ترحنث': u'ترحنث', #1
u'ترخصا': u'تَرَخُّصًا', #19
u'ترخصت': u'تَرَخَّصْتُ', #2
u'ترخصتا': u'تَرَخَّصَتَا', #4
u'ترددنى': u'تَرْدُدْنِى', #1
u'ترددنى': u'تُرْدِّدْنِى', #1
u'ترددنى': u'تُرَدِّدَنِى', #3
u'ترددى': u'تَرَدُّدِى', #1
u'تردنى': u'تَرُدُّنِى', #2
u'تردنى': u'تَرُدَّنِى', #3
u'ترزءون': u'تُرْزَءُونَ', #2
u'ترزءون': u'تَرْزَءُونَ', #6
u'ترست': u'ترست', #1
u'ترسلنى': u'تُرْسِلُنِى', #1
u'ترسلنى': u'تُرْسِلْنِى', #1
u'ترشدت': u'تَرَشَّدَتْ', #1
u'ترشرش': u'تَرَشْرَشَ', #1
u'ترشرش': u'تُرَشْرِشُ', #1
u'ترشيش': u'تَرْشِيشُ', #1
u'ترشيش': u'تَرْشِيشِ', #3
u'ترشيف': u'تَرْشِيفِ', #1
u'ترضيض': u'تَرْضِيضٍ', #1
u'ترضيض': u'تَرْضِيضَ', #1
u'ترعات': u'تُرُعَاتِ', #1
u'ترعويها': u'تَرْعَوِيَهَا', #1
u'ترعيل': u'تَرْعِيلُ', #2
u'ترغيمتان': u'تَرْغِيمَتَانِ', #1
u'ترفيقهم': u'تَرْفِيقِهِمْ', #1
u'ترقأ': u'تَرْقَأُ', #3
u'ترقوين': u'تَرْقُوَيْنِ', #1
u'ترقيح': u'تَرْقِيحٌ', #1
u'ترقيحا': u'تَرْقِيحًا', #2
u'تركاش': u'تركاش', #1
u'تركاش': u'تِرْكَاشُ', #2
u'تركتنى': u'تَرَكْتِنِى', #1
u'تركتى': u'تَرِكَتِى', #1
u'تركتينى': u'تَرَكْتِينِى', #1
u'تركست': u'تَرَكَّسْت', #2
u'تركنى': u'تَرَكَنِى', #1
u'تركهااااا': u'تَرَكَهَااااا', #1
u'ترمذ': u'ترمذ', #1
u'ترمذ': u'تِرْمِذَ', #19
u'ترمسة': u'تُرْمُسَةٌ', #1
u'ترمص': u'تَرْمُصُ', #2
u'ترمص': u'تُرْمَصُ', #2
u'ترمصان': u'تَرْمَصَانِ', #1
u'ترمصت': u'تَرَمَّصَتْ', #1
u'ترميضا': u'تَرْمِيضًا', #1
u'ترنجة': u'تُرُنْجَةٌ', #1
u'ترهبونى': u'تُرْهِبُونِى', #1
u'ترهقنى': u'تُرْهِقْنِى', #2
u'ترهننى': u'تَرْهَنُنِى', #2
u'ترهننيه': u'تَرْهَنَنِيهِ', #2
u'ترهننيه': u'تُرْهِنَنِيهِ', #2
u'ترهنونى؟': u'تَرْهَنُونِى؟', #1
u'ترهنونى': u'تَرْهَنُونِى', #2
u'تروث': u'تَرُوثُ', #3
u'تروكها': u'تُرُوكِهَا', #1
u'ترونى': u'تَرَوْنِى', #9
u'تروئة': u'تَرْوِئَةً', #2
u'تريان؟': u'تَرَيَانِ؟', #4
u'تريان': u'تَرَيَانِ', #9
u'ترية': u'تِرْيَةٌ', #1
u'ترية': u'تَرِيَّةٌ', #3
u'تريحنى': u'تُرِيحَنِى', #2
u'تريحنى': u'تُرِيحُنِى', #2
u'تريدى': u'تُرِيدِى', #1
u'تريعة': u'تَرِيعَةٍ', #1
u'ترينى': u'تُرِيَنِى', #1
u'تريئة': u'تَرِيئَةٌ', #1
u'تزابن': u'تَزَابُنٌ', #2
u'تزاقى': u'تَزَاقى', #1
u'تزاقى': u'تَزَاقَى', #1
u'تزانوهم': u'تُزَانُوهُمْ', #1
u'تزانى': u'تُزَانِىَ', #5
u'تزاويق': u'تزاويق', #1
u'تزرموا': u'تَزْرِمُوا', #2
u'تزرموه': u'تزرموه', #1
u'تزرموه': u'تُزْرِمُوهُ', #12
u'تزرموه،': u'تُزْرِمُوهُ،', #3
u'تزرموه': u'تَزْرِمُوهُ', #5
u'تزرير': u'تَزْرِيرُ', #1
u'تزريره': u'تَزْرِيرُهُ', #1
u'تزقما،': u'تزقماً،', #1
u'تزقما': u'تَزَقّمًا', #2
u'تزقمت': u'تَزَقّمْتُ', #1
u'تزكينى': u'تُزَكِّيَنِى', #1
u'تزليعه': u'تَزْلِيعُهُ', #1
u'تزليعه': u'تَزْلِيعِهِ', #1
u'تزنيان': u'تزنيان', #1
u'تزنيان،': u'تزنيان،', #1
u'تزنيان': u'تَزْنِيَانِ', #93
u'تزوا': u'تُزْوُا', #1
u'تزوجتيني': u'تَزَوَّجْتِينِي', #1
u'تزوجنى': u'تَزَوَّجَنِى', #13
u'تزوجنيها': u'تُزَوِّجَنِيهَا', #17
u'تزوجنيها': u'تُزَوِّجُنِيهَا', #2
u'تزوجنيها': u'تُزَوِّجْنِيهَا', #7
u'تزوجى': u'تَزَوَّجِى', #1
u'تزوع': u'تِزْوَعُ', #1
u'تزويراست': u'تزويراست', #1
u'تزويرى': u'تَزْوِيرِى', #1
u'تزييفة': u'تَزْيِيفَةِ', #1
u'تساحب': u'تَسَاحَبَ', #1
u'تساحقت': u'تَسَاحَقَتْ', #2
u'تساحقتا': u'تَسَاحَقَتَا', #7
u'تسارفوا،': u'تَسَارَفُوا،', #1
u'تساعا': u'تِسَاعًا', #1
u'تساعل': u'تَسَاعَلَ', #2
u'تسافوا': u'تَسَافَوْا', #1
u'تسآل': u'تَسْآلَ', #1
u'تسألنى': u'تَسْأَلُنِى', #26
u'تسألنى': u'تَسْأَلَنِى', #4
u'تسألنى': u'تَسْأَلْنِى', #4
u'تسألنيه': u'تَسْأَلَنِيهِ', #2
u'تسألنيها،': u'تَسْأَلُنِيهَا،', #1
u'تسألنيها': u'تَسْأَلُنِيهَا', #4
u'تسألوننى': u'تَسْأَلُونَنِى', #1
u'تسألونى': u'تَسْأَلُونِّى', #1
u'تسألونى': u'تَسْأَلُونِى', #8
u'تسألى': u'تَسْأَلِى', #2
u'تسامتها': u'تُسَامِتُهَا', #1
u'تسامتهم': u'تُسَامِتُهُمْ', #1
u'تسامتهم': u'تُسَامِتْهُمْ', #2
u'تسامتهما': u'تُسَامِتُهُمَا', #1
u'تسامينى': u'تُسَامِينِى', #3
u'تساورت': u'تساورت', #1
u'تساوق': u'تُسَاوِقُ', #1
u'تساوق': u'تَسَاوَقَ', #3
u'تساوقا': u'تَسَاوَقَا', #2
u'تسبتسمكت': u'تَسَبْتَسْمَكْت', #1
u'تسبغة': u'تَسْبَغَةَ', #1
u'تسبقنى': u'تُسْبِقْنِى', #1
u'تسبقنى؟': u'تُسْبِقْنِى؟', #1
u'تسبقنى': u'تَسْبِقْنِى', #9
u'تسبقونى': u'تَسْبِقُونِى', #4
u'تسبقينى': u'تَسْبِقِينِى', #3
u'تسبيح': u'تسبيحً', #1
u'تسبيد': u'تَسْبِيدَ', #1
u'تستاك؟': u'تَسْتَاكُ؟', #2
u'تستاك': u'تَسْتَاكُ', #6
u'تستأكل': u'تُسْتَأْكَلُ', #1
u'تستاكوا': u'تَسْتَاكُوا', #8
u'تستاكون،': u'تستاكون،', #1
u'تستأمرى': u'تَسْتَأْمِرِى', #5
u'تستأمن': u'تَسْتَأْمِنُ', #1
u'تستأمى': u'تَسْتَأْمِى', #2
u'تستأميها': u'تَسْتَأْمِيهَا', #1
u'تستأنوا': u'تَسْتَأْنُوا', #2
u'تستأني': u'تَسْتَأْنِي', #1
u'تستأني': u'تَسْتَأْنِيَ', #1
u'تستبرا': u'تُسْتَبَرَا', #1
u'تستبرا': u'تُسْتَبْرَا', #1
u'تستبرآن': u'تُسْتَبْرَآنِ', #2
u'تستبري': u'تَسْتَبِرِي', #1
u'تستبضع': u'تَسْتَبْضِعُ', #1
u'تستبضع': u'تُسْتَبْضَعُ', #1
u'تستبعها': u'تَسْتَبْعِهَا', #1
u'تستبوا': u'تَسْتَبُّوا', #1
u'تستبي': u'تَسْتَبِي', #2
u'تستبيث': u'تَسْتَبِيثُ', #2
u'تستبيع': u'تَسْتَبِيعَ', #1
u'تستتاب': u'تُسْتَتَابَ', #5
u'تستتاب': u'تُسْتَتَابُ', #5
u'تستتم': u'تَسْتَتِمَّ', #1
u'تستتم': u'تَسْتَتِمُّ', #1
u'تستتم': u'تَسْتَتِمْ', #1
u'تستتيبهم': u'تَسْتَتِيبَهُمْ', #4
u'تستثفر': u'تَسْتَثْفِرَ', #1
u'تستثفر': u'تَسْتَثْفِرُ', #1
u'تستثفر': u'تَسْتَثْفِرْ', #3
u'تستجز': u'تَسْتَجِزْ', #1
u'تستح': u'تَسْتَحِ', #22
u'تستحاض،': u'تُسْتَحَاضُ،', #1
u'تستحاض': u'تُسْتَحَاض', #2
u'تستحاض': u'تُسْتَحَاضُ', #35
u'تستحاضان': u'تُسْتَحَاضَانِ', #1
u'تستحد': u'تَسْتَحِدُّ', #1
u'تستحد': u'تَسْتَحِدَّ', #11
u'تستحرب': u'تَسْتَحْرِبُ', #1
u'تستحون': u'تَسْتَحُونَ', #1
u'تستحى': u'تَسْتَحِى', #3
u'تستحيان،': u'تستحيان،', #1
u'تستحيان': u'تَسْتَحِيَانِ', #1
u'تستحيى': u'تَسْتَحْيِى', #11
u'تستخبث': u'تَسْتَخْبِثُ', #2
u'تستخبثه': u'تَسْتَخْبِثُهُ', #23
u'تستخبثها': u'تَسْتَخْبِثُهَا', #3
u'تستخبثونه': u'تَسْتَخْبِثُونَهُ', #1
u'تستخر': u'تَسْتَخِرْ', #1
u'تستخل': u'تُسْتَخَلّ', #1
u'تستخلقي': u'تَسْتَخْلِقِي', #1
u'تستد': u'تَسْتَدُّ', #1
u'تستدخل': u'تَسْتَدْخِلْ', #10
u'تستدخل': u'تَسْتَدْخِلُ', #2
u'تستدخل': u'تَسْتَدْخِلَ', #8
u'تستدخلها': u'تَسْتَدْخِلْهَا', #3
u'تستذفر': u'تَسْتَذْفِرْ', #1
u'تستراب': u'تُسْتَرَابَ', #1
u'تستراب': u'تُسْتَرَابُ', #3
u'تسترب': u'تَسْتَرِبْ', #8
u'تستربح': u'تُسْتَرْبَحَ', #1
u'تسترقى': u'تَسْتَرْقِىَ', #1
u'تسترم': u'تَسْتَرِمُّ', #1
u'تسترم': u'تُسْتَرَمُّ', #2
u'تستريب': u'تَسْتَرِيبَ', #1
u'تستريد': u'تَسْتَرِيدُ', #2
u'تستسبب': u'تَسْتَسْبِبْ', #2
u'تستسع': u'تُسْتَسْعَ', #1
u'تستسعي': u'تَسْتَسْعِي', #1
u'تستسعى': u'تُسْتَسْعَى', #4
u'تستشعلوا': u'تَسْتَشْعِلُوا', #1
u'تستشنع': u'تُسْتَشْنَعُ', #1
u'تستشيرى': u'تَسْتَشِيرِى', #2
u'تستصنع': u'تُسْتَصْنَعُ', #1
u'تستصنع': u'تُسْتَصْنَعْ', #1
u'تستضر': u'تَسْتَضِرَّ', #1
u'تستضر': u'تُسْتَضَرَّ', #1
u'تستضر': u'تُسْتَضَرُّ', #1
u'تستضر': u'تَسْتَضِرُّ', #31
u'تستطف': u'تَسْتَطِفَّ', #1
u'تستعجلى': u'تَسْتَعْجِلِى', #1
u'تستعصوني': u'تَسْتَعْصُونِي', #1
u'تستعقب': u'تَسْتَعْقِبَ', #1
u'تستعقب': u'تَسْتَعْقِبُ', #20
u'تستعقبها': u'تَسْتَعْقِبُهَا', #2
u'تستعملنى': u'تَسْتَعْمِلْنِى', #1
u'تستعملنى': u'تَسْتَعْمِلُنِى', #2
u'تستعيننى': u'تَسْتَعِينُنِى', #1
u'تستغدر': u'تَسْتَغْدِرُ', #1
u'تستغنم': u'تُسْتَغْنَمُ', #1
u'تستفتيان': u'تَسْتَفْتِيَانِ', #11
u'تستفيده': u'تَسْتَفِيدُهُ', #1
u'تستفيدها': u'تَسْتَفِيدُهَا', #1
u'تستقذر': u'تُسْتَقْذَرُ', #4
u'تستقذره': u'تَسْتَقْذِرُهُ', #4
u'تستقذرها': u'تَسْتَقْذِرُهَا', #1
u'تستقرض': u'تُسْتَقْرَضُ', #2
u'تستقرض': u'تَسْتَقْرِضُ', #3
u'تستقرض': u'تَسْتَقْرِضْ', #6
u'تستقرض': u'تَسْتَقْرِضَ', #9
u'تستقضي': u'تَسْتَقْضِيَ', #2
u'تستقضى': u'تَسْتَقْضِىَ', #2
u'تستقضين': u'تَسْتَقْضِيَنَّ', #1
u'تستقيد': u'تَسْتَقِيدَ', #1
u'تستك': u'تَسْتَكْ', #1
u'تستكرى': u'تُسْتَكْرَى', #2
u'تستكسيك': u'تَسْتَكْسِيك', #1
u'تستكفي': u'تَسْتَكْفِي', #1
u'تستلحق': u'تَسْتَلْحِقُ', #2
u'تستمسكهما': u'تَسْتَمْسِكهُمَا', #1
u'تستمشين': u'تَسْتَمْشِينَ', #1
u'تستمشين؟': u'تَسْتَمْشِينَ؟', #1
u'تستمطر': u'تَسْتَمْطِرُ', #2
u'تستمنى': u'تُسْتَمْنَى', #1
u'تستن': u'تَسْتَنَّ', #2
u'تستن': u'تَسْتَنُّ', #9
u'تستنبت': u'تَسْتَنْبِتُ', #1
u'تستنبت': u'تُسْتَنْبَتُ', #4
u'تستنبيث': u'تَسْتَنْبِيثُ', #1
u'تستنسج': u'تُسْتَنْسَجُ', #1
u'تستنظره': u'تَسْتَنْظِرْهُ', #1
u'تستنظروه': u'تَسْتَنْظِرُوهُ', #1
u'تستنظف': u'تَسْتَنْظِف', #1
u'تستنظف': u'تَسْتَنْظِفُ', #2
u'تستنفع': u'تَسْتَنْفِعَ', #1
u'تستنفق': u'تَسْتَنْفِقُ', #1
u'تستنمي': u'تَسْتَنِمِي', #1
u'تستنمى': u'تُسْتَنْمَى', #10
u'تستنون،': u'تَسْتَنُّونَ،', #1
u'تستنون': u'تَسْتَنُّونَ', #2
u'تستنيب': u'تَسْتَنِيبَ', #4
u'تستهزءون': u'تَسْتَهْزِءُونَ', #1
u'تستوحشى': u'تَسْتَوْحِشِى', #1
u'تستوشئوا': u'تَسْتَوْشِئُوا', #1
u'تستوهب': u'تَسْتَوْهِبُ', #1
u'تستويان': u'تَسْتَوِيَانِ', #1
u'تستير': u'تَسْتِيرِ', #1
u'تستيرها': u'تَسْتِيرِهَا', #1
u'تسجده': u'تَسْجُدْهُ', #1
u'تسجدها': u'تَسْجُدُهَا', #2
u'تسجدهما': u'تَسْجُدْهُمَا', #1
u'تسجنونى': u'تَسْجِنُونِّى', #1
u'تسحرا': u'تَسَحُّرًا', #3
u'تسحرت': u'تَسَحَّرْتَ', #1
u'تسحرت': u'تَسَحَّرْتُ', #1
u'تسحرت': u'تَسَحَّرْت', #3
u'تسحرتم': u'تَسَحَّرْتُمْ', #1
u'تسخطا': u'تَسَخُّطًا', #2
u'تسخيم': u'تَسْخِيمَ', #1
u'تسخيم': u'تَسْخِيمِ', #5
u'تسخيمه': u'تَسْخِيمِهِ', #2
u'تسرحى': u'تُسَرِّحِى', #1
u'تسررا': u'تَسَرُّرًا', #1
u'تسررت': u'تَسَرَّرْتُ', #1
u'تسرقى': u'تَسْرِقِى', #1
u'تسرولقمت': u'تَسَرْوَلْقَمْت', #1
u'تسريا': u'تَسَرِّيًا', #18
u'تسريت': u'تُسُرِّيت', #3
u'تسريت': u'تَسَرَّيْت', #40
u'تسريت': u'تَسَرَّيْتُ', #5
u'تسعدنى': u'تُسْعِدَنِى', #2
u'تسعطه': u'تُسْعِطَهُ', #1
u'تسفحSشعر': u'تُسْفَحُSشِعْرُ', #1
u'تسفى': u'تَسْفَى', #1
u'تسقنى': u'تَسْقِنِى', #1
u'تسقيان': u'تُسْقَيَانِ', #1
u'تسقيان': u'تَسْقِيَانِ', #3
u'تسلبى': u'تَسَلَّبِى', #1
u'تسلعوها': u'تُسْلِعُوهَا', #1
u'تسلفنى': u'تُسْلِفَنِى', #1
u'تسلمى': u'تَسْلَمِى', #1
u'تسليمة': u'تَسْلِيمَةَ', #15
u'تسليمة': u'تَسْلِيمَة', #2
u'تسليمة': u'تَسْلِيمَةِ', #20
u'تسليمة': u'تَسْلِيمَةٌ', #29
u'تسليمة': u'تسليمة', #4
u'تسليمة': u'تَسْلِيمَةُ', #4
u'تسليمة': u'تَسْلِيمَةٍ', #67
u'تسليمة': u'تَسْلِيمَةً', #95
u'تسليمتان': u'تَسْلِيمَتَانِ', #8
u'تسليمتاه': u'تَسْلِيمَتَاهُ', #3
u'تسليمته': u'تَسْلِيمَتِهِ', #1
u'تسليمتي': u'تَسْلِيمَتَيْ', #27
u'تسليمتين': u'تسليمتين', #2
u'تسليمتين،': u'تسليمتين،', #2
u'تسليمتين،': u'تَسْلِيمَتَيْنِ،', #2
u'تسليمتين': u'تَسْلِيمَتَيْنِ', #83
u'تسليمتيه': u'تَسْلِيمَتَيْهِ', #13
u'تسمحا': u'تَسَمُّحًا', #22
u'تسمحت': u'تَسَمَّحَتْ', #1
u'تسمعننيه': u'تُسْمِعْنَنِيهِ', #1
u'تسمعنى': u'تَسْمَعُنِى', #1
u'تسمعنى': u'تُسْمِعْنِى', #1
u'تسمعى': u'تَسْمَعِى', #4
u'تسمننى': u'تُسَمِّنَنِى', #2
u'تسميتة': u'تَسْمِيتَةُ', #1
u'تسميتة': u'تَسْمِيتَةِ', #2
u'تسميعة': u'تَسْمِيعَةٍ', #9
u'تسميعتين': u'تَسْمِيعَتَيْنِ', #2
u'تسوغت': u'تَسَوّغْتَ', #1
u'تسوكوا': u'تَسَوَّكُوا', #1
u'تسوكون': u'تَسَوَّكُونَ', #1
u'تسومت': u'تَسَوَّمَتْ', #2
u'تسويكا': u'تَسْوِيكًا', #1
u'تسويكه': u'تَسْوِيكُهُ', #1
u'تسويكه': u'تَسْوِيكِهِ', #1
u'تسئل': u'تُسْئَلَ', #1
u'تسئل': u'تُسْئَلُ', #7
u'تسيخ': u'تَسِيخُ', #2
u'تسيدوني': u'تُسَيِّدُونِي', #8
u'تسيرت': u'تَسَيّرْت', #2
u'تسيئها': u'تُسِيئُهَا', #1
u'تشا': u'تَشَا', #4
u'تشابب': u'تَشَابُبٌ', #1
u'تشاجب': u'تَشَاجَبَ', #1
u'تشافع': u'تَشَافُعِ', #3
u'تشافهنى': u'تُشَافِهَنِى', #2
u'تشأمت': u'تَشَأَمَتْ', #1
u'تشأمت': u'تَشَأَّمَتْ', #1
u'تشاؤه': u'تَشَاؤُهُ', #10
u'تشائى': u'تَشَائِى', #1
u'تشبه': u'تَشَبُّهً', #1
u'تشبهما': u'تُشْبِهُمَا', #1
u'تشتال': u'تَشْتَالُ', #1
u'تشتجر': u'تَشْتَجِرُ', #4
u'تشترطى': u'تَشْتَرِطِى', #1
u'تشتكيه': u'تَشْتَكِيهِ', #3
u'تشحيذ': u'تَشْحِيذُ', #2
u'تشحيذ': u'تَشْحِيذَ', #3
u'تشحيذ': u'تَشْحِيذِ', #5
u'تشحيذا': u'تَشْحِيذًا', #2
u'تشحيذها': u'تَشْحِيذِهَا', #1
u'تشحينا': u'تَشْحِينًا', #2
u'تشديخها': u'تَشْدِيخِهَا', #1
u'تشديدة': u'تَشْدِيدَةِ', #1
u'تشديدة': u'تَشْدِيدَةً', #11
u'تشديدة': u'تَشْدِيدَةٍ', #12
u'تشديدتا': u'تَشْدِيدَتَا', #2
u'تشربت': u'تَشَرَّبَتْ', #7
u'تشربته': u'تَشَرَّبَتْهُ', #4
u'تشربتها': u'تَشَرَّبَتْهَا', #1
u'تشرفة': u'تَشْرِفَةً', #1
u'تشرفة،': u'تَشْرِفَةً،', #1
u'تشرمت': u'تَشَرَّمَتْ', #1
u'تشريجه': u'تَشْرِيجِهِ', #2
u'تشزن': u'تَشَزَّنَ', #1
u'تشزنا': u'تَشَزَّنَّا', #2
u'تشزنتم': u'تَشَزَّنْتُمْ', #4
u'تشطرت': u'تَشَطَّرَتْ', #5
u'تشغبت': u'تشغبت', #1
u'تشغبت': u'تَشَغَّبَتْ', #2
u'تشغفت': u'تشغفت', #1
u'تشغفت': u'تَشَغَّفَتْ', #3
u'تشغلنى': u'تَشْغَلُنِى', #1
u'تشقح': u'تشقح', #1
u'تشقح': u'تُشْقَحَ', #1
u'تشقح': u'تُشْقَحُ', #1
u'تشقح': u'تُشْقِحُ', #1
u'تشقح؟': u'تُشْقِحُ؟', #1
u'تشقح': u'تُشَقِّحُ', #3
u'تشقح': u'تُشْقِحَ', #3
u'تشقح': u'تُشَقِّحَ', #4
u'تشقص': u'تَشَقَّصَ', #1
u'تشقيص': u'تَشْقِيصُ', #1
u'تشقيص': u'تَشْقِيصِ', #10
u'تشقيص': u'تَشْقِيصَ', #18
u'تشقيص': u'تَشْقِيصٌ', #7
u'تشقيص': u'تَشْقِيصٍ', #8
u'تشقيصا': u'تَشْقِيصًا', #1
u'تشقيصه': u'تَشْقِيصُهُ', #1
u'تشقيصه': u'تَشْقِيصِهِ', #9
u'تشمتنى': u'تُشَمِّتْنِى', #1
u'تشميرة': u'تَشْمِيرَةِ', #1
u'تشنؤني': u'تَشْنَؤُنِي', #1
u'تشهدنى': u'تُشْهِدْنِى', #4
u'تشوبها': u'تَشُوبَهَا', #1
u'تشوبها': u'تَشُوبُهَا', #4
u'تشوبوا': u'تَشُوبُوا', #1
u'تشول': u'تَشُولُ', #3
u'تشويف': u'تَشْوِيف', #1
u'تشئيما': u'تَشْئِيمًا', #1
u'تشيين': u'تَشْيِينٍ', #1
u'تصابأت': u'تَصَابَأَتْ', #2
u'تصاحبنى': u'تُصَاحِبْنِى', #2
u'تصادم': u'تَصَادُمً', #1
u'تصارعنى': u'تُصَارِعَنِى', #1
u'تصاممت': u'تَصَامَمْتَ', #1
u'تصبئه': u'تُصْبِئْهُ', #1
u'تصحبنى': u'تَصْحَبْنِى', #2
u'تصحفت': u'تَصَحَّفْت', #1
u'تصحفت': u'تَصَحَّفَتْ', #6
u'تصدقو': u'تَصَدَّقُو', #1
u'تصدقواوروي': u'تَصَدَّقُواوَرُوِيَ', #1
u'تصدقونى': u'تُصَدِّقُونِى', #2
u'تصدقى': u'تَصَدَّقِى', #3
u'تصديقى': u'تَصْدِيقِى', #2
u'تصرت': u'تَصَرَّتْ', #7
u'تصرعنى': u'تَصْرَعَنِى', #1
u'تصرعنى': u'تَصْرَعُنِى', #1
u'تصرية': u'تَصْرِيَةً', #1
u'تصرية': u'تَصْرِيَةٌ', #2
u'تصرية': u'تَصْرِيَةٍ', #2
u'تصرية': u'تَصْرِيَةِ', #3
u'تصريتها': u'تَصْرِيَتَهَا', #2
u'تصريتها': u'تَصْرِيَتِهَا', #4
u'تصطبحوا': u'تَصْطَبِحُوا', #7
u'تصطلما': u'تُصْطَلَمَا', #1
u'تصطلما': u'تَصْطَلِمَا', #3
u'تصعر': u'تُصَعِّرْ', #6
u'تصفار': u'تصفار', #1
u'تصفار': u'تَصْفَارَّ', #1
u'تصفار': u'تَصْفَارُّ', #5
u'تصفت': u'تَصَفَّتْ', #1
u'تصفيقة': u'تَصْفِيقَةً', #1
u'تصقيل': u'تَصْقِيلِ', #1
u'تصلفت': u'تَصَلَّفَتْ', #1
u'تصلق': u'تُصْلَقَ', #1
u'تصلقها': u'تَصْلِقُهَا', #1
u'تصليان؟': u'تصليان؟', #1
u'تصليان': u'تُصَلِّيَانِ', #11
u'تصليان': u'تُصَلَّيَانِ', #2
u'تصليان؟': u'تُصَلِّيَانِ؟', #2
u'تصنعى': u'تَصْنَعِى', #1
u'تصوبت': u'تَصَوَّبَتِ', #1
u'تصوبت': u'تَصَوَّبَتْ', #2
u'تصوبت': u'تَصَوّبَتْ', #3
u'تصويغ': u'تَصْوِيغَ', #1
u'تصيبنى': u'تصيبنى', #3
u'تصيبنى': u'تُصِيبُنِى', #3
u'تصيبهوروي': u'تُصِيبُهُوَرُوِيَ', #1
u'تصيرت': u'تَصَيَّرَتْ', #1
u'تصيرت': u'تَصَيّرَتْ', #3
u'تضآر': u'تُضَآرَّ', #1
u'تضاغيهم': u'تَضَاغِيَهُمْ', #1
u'تضبيب': u'تَضْبِيبٌ', #1
u'تضبيب': u'تَضْبِيبٍ', #2
u'تضبيب': u'تَضْبِيبُ', #4
u'تضبيب': u'تَضْبِيبِ', #5
u'تضبيبه': u'تَضْبِيبُهُ', #1
u'تضبيبه': u'تَضْبِيبِهِ', #23
u'تضبيبها': u'تَضْبِيبِهَا', #1
u'تضراب': u'تِضْرَابٌ', #1
u'تضرة': u'تَضِرَّةٍ', #1
u'تضطبع': u'تَضْطَبِعُ', #11
u'تضطني': u'تَضْطَنِي', #4
u'تضعفت': u'تضعفت', #1
u'تضعى': u'تَضَعِى', #5
u'تضلنى': u'تُضِلَّنِى', #1
u'تضمننى': u'تُضَمِّنُنِى', #1
u'تضمير': u'تَضْمِير', #1
u'تضىء': u'تضىء', #1
u'تضىء': u'تُضِىءُ', #3
u'تضير': u'تَضِيرُ', #7
u'تضيعا': u'تَضَيُّعًا', #1
u'تضيفت': u'تَضَيَّفَتْ', #3
u'تضيفت': u'تَضَيَّفْتُ', #4
u'تطارشت': u'تَطَارَشَتْ', #1
u'تطارق': u'تُطَارَقْ', #1
u'تطارق': u'تُطَارِقُ', #1
u'تطالعت': u'تَطَالَعَتْ', #1
u'تطام': u'تَطَامِّ', #2
u'تطامن': u'تَطَامَنَ', #1
u'تطامن': u'تَطَامُنٌ', #1
u'تطردا': u'تَطَرُّدًا', #1
u'تطرية': u'تَطْرِيَةٍ', #1
u'تطعما': u'تَطَعُّمًا', #1
u'تطعمت': u'تَطَعَّمْت', #1
u'تطعمنى': u'تُطْعِمَنِى', #1
u'تطعمنى': u'تُطْعِمْنِى', #1
u'تطعمنى': u'تُطْعِمُنِى', #2
u'تطعموناه': u'تُطْعِمُونَاهُ', #1
u'تطعمونى': u'تُطْعِمُونِى', #2
u'تطعمونيه': u'تُطْعِمُونِيهِ', #1
u'تطعمينيه': u'تُطْعِمِينِيهِ', #1
u'تطفيء': u'تَطْفِيءُ', #1
u'تطفئة': u'تُطْفِئُةُ', #1
u'تطفيل': u'تَطْفِيلٍ', #1
u'تطلاب': u'تِطْلَابِ', #1
u'تطلابها': u'تَطْلَابِهَا', #1
u'تطلقت': u'تَطَلَّقَتْ', #1
u'تطلقت': u'تَطَلَّقْت', #2
u'تطلقنى': u'تُطَلِّقْنِى', #5
u'تطليقة': u'تطليقة', #1
u'تطليقة': u'تَطْلِيقَةَ', #1
u'تطليقة،': u'تَطْلِيقَةٌ،', #1
u'تطليقة': u'تَطْلِيقَة', #2
u'تطليقة': u'تَطْلِيقَةٍ', #285
u'تطليقة': u'تَطْلِيقَةُ', #3
u'تطليقة،': u'تَطْلِيقَةً،', #3
u'تطليقة': u'تَطْلِيقَةٌ', #306
u'تطليقة': u'تَطْلِيقَةً', #606
u'تطليقةالوجه': u'تَطْلِيقَةٌالْوَجْهُ', #1
u'تطليقتان': u'تَطْلِيقَتَانِ', #112
u'تطليقتاه': u'تَطْلِيقَتَاهُ', #1
u'تطليقتين': u'تطليقتين', #1
u'تطليقتين': u'تَطَلِيقَتَيْنِ', #1
u'تطليقتين': u'تَطْلِيقَتَيْنِ', #260
u'تطليقتين،': u'تَطْلِيقَتَيْنِ،', #5
u'تطمعت': u'تَطَمَّعْت', #2
u'تطهرنى': u'تُطَهِّرَنِى', #4
u'تطهرى': u'تَطْهُرِى', #3
u'تطهرى': u'تَطَهَّرِى', #5
u'تطوفى': u'تَطُوفِى', #7
u'تطوقت': u'تَطَوَّقَتْ', #1
u'تطولا': u'تَطَوُّلاً', #1
u'تطولا': u'تَطَوُّلًا', #1
u'تطؤه': u'تَطَؤُهُ', #24
u'تطؤها': u'تَطَؤُهَا', #5
u'تطؤهم': u'تَطَؤُهُمْ', #1
u'تطويشه': u'تَطْوِيشِهِ', #1
u'تطويقة': u'تَطْوِيقَةُ', #1
u'تطئوا': u'تَطَئُوا', #2
u'تطئوها': u'تَطَئُوهَا', #3
u'تطئوهم': u'تَطَئُوهُمْ', #8
u'تطيقي23281id': u'تطيقي23281id', #1
u'تطيلس': u'تَطَيْلَسَ', #1
u'تظلمنى': u'تَظْلِمْنِى', #2
u'تظلنى': u'تُظِلُّنِى', #2
u'تظننت': u'تَظَنَّنْت', #3
u'تظنيت': u'تَظَنّيْتُ', #1
u'تظنيت': u'تَظَنَّيْتُ', #3
u'تظهرت': u'تَظَهَّرْتَ', #1
u'تظهرت': u'تَظَهَّرْت', #2
u'تعاتع': u'تَعَاتِعُ', #1
u'تعاجبهم': u'تَعَاجُبِهِمْ', #2
u'تعاجيب': u'تَعَاجِيبِ', #1
u'تعادنى': u'تُعَادُّنِى', #1
u'تعاذله': u'تُعَاذِلُهْ', #1
u'تعارضتنا': u'تَعَارَضَتْنَا', #1
u'تعارفته': u'تَعَارَفَتْهُ', #1
u'تعارفونه': u'تَعَارَفُونَهُ', #1
u'تعارفوه': u'تَعَارَفُوهُ', #54
u'تعارفوها': u'تَعَارَفُوهَا', #2
u'تعارى': u'تُعَارَى', #1
u'تعازير': u'تَعَازِيرِ', #3
u'تعازيره': u'تَعَازِيرُهُ', #1
u'تعاسيف': u'تَعَاسِيفٍ', #1
u'تعاسيف': u'تَعَاسِيفَ', #2
u'تعاطا': u'تَعَاطَا', #1
u'تعاطس': u'تَعَاطُسِ', #1
u'تعاقدتموها': u'تَعَاقَدْتُمُوهَا', #1
u'تعاقدناه': u'تَعَاقَدْنَاهُ', #1
u'تعالب': u'تَعَالِبِ', #1
u'تعالجنى': u'تُعَالِجُنِى', #1
u'تعالىأحل': u'تَعَالَىأُحِلَّ', #1
u'تعالىأقم': u'تَعَالَىأَقِمْ', #1
u'تعالىألم': u'تَعَالَىأَلَمْ', #1
u'تعالىإن': u'تَعَالَىإِنَّ', #1
u'تعالىأو': u'تَعَالَىأَوْ', #2
u'تعالىثم': u'تَعَالَىثُمَّ', #1
u'تعالىرحمة': u'تَعَالَىرَحْمَةُ', #1
u'تعالىفاغسلوا': u'تَعَالَىفَاغْسِلُوا', #1
u'تعالىفلم': u'تَعَالَىفَلَمْ', #1
u'تعالىفمن': u'تَعَالَىفَمَنْ', #1
u'تعالىقتل': u'تَعَالَىقُتِلَ', #1
u'تعالىلئن': u'تَعَالَىلَئِنْ', #1
u'تعالينقوله': u'تَعَالَينَقَوْلُهُ', #1
u'تعالىوإذا': u'تَعَالَىوَإِذَا', #1
u'تعالىوالله': u'تَعَالَىوَاَللَّهُ', #1
u'تعالىوامسحوا': u'تَعَالَىوَامْسَحُوا', #1
u'تعالىوأنزلنا': u'تَعَالَىوَأَنْزَلْنَا', #1
u'تعالىوثيابك': u'تَعَالَىوَثِيَابَك', #1
u'تعالىوفيه': u'تَعَالَىوَفِيهِ', #1
u'تعالىولا': u'تَعَالَىوَلَا', #1
u'تعالىولتأت': u'تَعَالَىوَلْتَأْتِ', #1
u'تعالىيا': u'تَعَالَىيَا', #2
u'تعاهدنى': u'تُعَاهِدْنِى', #2
u'تعاهدونى': u'تُعَاهِدُونِى', #1
u'تعاوضا': u'تَعَاوُضًا', #1
u'تعاويذات': u'تَعَاوِيذَاتٍ', #1
u'تعايا': u'تَعَايَا', #5
u'تعبانة': u'تَعْبَانَةً', #1
u'تعة': u'تَعَّةً', #1
u'تعترق': u'تَعْتَرِقُ', #2
u'تعتسف': u'تَعْتَسِفُ', #1
u'تعتضد': u'تَعْتَضِدُ', #1
u'تعتضد': u'تَعْتَضِدْ', #2
u'تعتفر': u'تُعْتَفَرُ', #1
u'تعتقى': u'تُعْتَقِى', #1
u'تعتلج': u'تَعْتَلِجُ', #2
u'تعتلف': u'تَعْتَلِفْ', #1
u'تعتلف': u'تُعْتَلَفْ', #1
u'تعتلف': u'تَعْتَلِفُ', #21
u'تعتلف': u'تَعْتَلِفَ', #4
u'تعتلف': u'تُعْتَلَفُ', #9
u'تعتمل': u'تَعْتَمِلْ', #1
u'تعتمل': u'تُعْتَمَلُ', #1
u'تعتور': u'تَعْتَوِرُ', #3
u'تعتوره': u'تَعْتَوِرُهُ', #5
u'تعتورهم': u'تَعْتَوِرَهُمْ', #1
u'تعتورهم': u'تَعْتَوِرُهُمْ', #2
u'تعجبنى': u'تُعْجِبُنِى', #1
u'تعجلى': u'تَعْجَلِى', #6
u'تعجلينى': u'تَعْجَلِينِى', #1
u'تعدلت': u'تَعَدَّلَتْ', #1
u'تعدنى': u'تَعُدْنِى', #1
u'تعدنى': u'تُعِدْنِى', #1
u'تعدنى': u'تَعِدْنِى', #2
u'تعذاله': u'تَعْذَالِهِ', #1
u'تعرفبه': u'تَعْرِفُبِهِ', #1
u'تعرفنى؟': u'تَعْرِفُنِى؟', #2
u'تعرفونى': u'تَعْرِفُونِى', #1
u'تعرقب': u'تُعَرْقَبَ', #4
u'تعرقب': u'تُعَرْقَبُ', #5
u'تعريدا': u'تَعْرِيدًا', #1
u'تعريص': u'تَعْرِيصٌ', #1
u'تعزرنى': u'تُعَزِّرُنِى', #2
u'تعزيل': u'تَعْزِيلِ', #3
u'تعزيله': u'تَعْزِيلِهِ', #1
u'تعسكرهم': u'تَعَسْكُرُهُمْ', #2
u'تعصبة': u'تَعَصُّبَةٍ', #1
u'تعصبة': u'تَعْصِبَةَ', #1
u'تعصية': u'تَعْصِيَةَ', #1
u'تعصية': u'تَعْصِيَةُ', #1
u'تعصية': u'تَعْصِيَةِ', #4
u'تعصيته': u'تَعْصِيَتَهُ', #1
u'تعصيته': u'تَعْصِيَتِهِ', #2
u'تعضوض': u'تَعْضُوضٍ', #2
u'تعضية': u'تَعْضِيَةَ', #5
u'تعطلتها': u'تَعَطَّلَتْهَا', #1
u'تعطنى': u'تُعْطِنِى', #2
u'تعطنيه': u'تُعْطِنِيهِ', #8
u'تعطونيها': u'تُعْطُونِيهَا', #2
u'تعطوهاأولادكم': u'تُعْطُوهَاأَوْلادَكُمْ', #1
u'تعطيان': u'تُعْطَيَانِ', #3
u'تعطيمها': u'تعطيمها', #1
u'تعطينى': u'تُعْطِينِى', #2
u'تعطينى': u'تُعْطِيَنِى', #5
u'تعطينيه': u'تُعْطِينِيهِ', #1
u'تعطينيها': u'تُعْطِينِيهَا', #1
u'تعطينيها': u'تُعْطِيَنِيهَا', #2
u'تعطينيهن': u'تُعِطِيَنِيهُنَّ', #1
u'تعفيش': u'تَعْفِيشُ', #1
u'تعفيش': u'تَعْفِيشٌ', #2
u'تعفيشه': u'تَعْفِيشِهِ', #1
u'تعقى': u'تَعُقِّى', #1
u'تعكت': u'تَعَكَّتْ', #1
u'تعلمنى': u'تَعْلَمُنِى', #1
u'تعلمنى': u'تُعَلِّمَنِى', #1
u'تعلمنى': u'تُعَلِّمُنِى', #1
u'تعلمونوالوجه': u'تَعْلَمُونَوَالْوَجْهُ', #1
u'تعلمونى': u'تُعْلِمُونِى', #2
u'تعلمى': u'تَعْلَمِى', #4
u'تعلونى': u'تَعْلُوَنِى', #1
u'تعليق': u'تَعْلِيقً', #1
u'تعليلة': u'تَعْلِيلَةً', #2
u'تعليلة': u'تَعْلِيلَةٌ', #3
u'تعمت': u'تَعَمَّتْ', #1
u'تعمرت': u'تَعَمَّرَتْ', #7
u'تعمقعددت': u'تَعَمْقَعْدَدْت', #1
u'تعملا': u'تَعَمُّلًا', #1
u'تعميرة': u'تَعْمِيرَةٍ', #1
u'تعنج': u'تُعْنَجْ', #2
u'تعنيزوجي': u'تَعْنِيزَوْجِي', #1
u'تعوذبالله': u'تَعَوَّذَبِاللَّهِ', #1
u'تعوذتان': u'تَعَوُّذَتَانِ', #1
u'تعيبا': u'تَعَيُّبًا', #3
u'تعيبت': u'تَعَيَّبَتْ', #195
u'تعيت': u'تَعَيّتْ', #2
u'تعيرنى': u'تُعَيِّرَنِى', #1
u'تعيننى': u'تُعِينَنِى', #2
u'تغاررا': u'تَغَارَرَا', #1
u'تغارسا': u'تَغَارَسَا', #1
u'تغاريت': u'تغاريت', #1
u'تغاش': u'تَغَاشٌ', #1
u'تغاشيت': u'تَغَاشَيْتَ', #1
u'تغاطسوا': u'تَغَاطَسُوا', #1
u'تغاطى': u'تَغَاطَى', #1
u'تغالظوا': u'تَغَالَظُوا', #1
u'تغبط': u'تَغَبَّطَ', #1
u'تغبطا': u'تَغَبُّطَا', #2
u'تغبطني': u'تَغْبِطنِي', #2
u'تغبنن': u'تَغْبِنَنَّ', #1
u'تغبنن': u'تَغْبِنَنْ', #1
u'تغبنن': u'تُغْبَنَن', #1
u'تغبير': u'تَغْبِيرٍ', #1
u'تغبير': u'تَغْبِيرُ', #1
u'تغبير': u'تَغْبِيرِ', #1
u'تغبيرا': u'تَغْبِيرًا', #1
u'تغبيطهم': u'تَغْبِيطُهُمْ', #1
u'تغتبقوا': u'تَغْتَبِقُوا', #7
u'تغتته': u'تَغْتُتْهُ', #1
u'تغترق': u'تُغْتَرَقُ', #1
u'تغترق': u'تَغْتَرِقُ', #5
u'تغتسلى': u'تَغْتَسِلِى', #3
u'تغتشه': u'تَغْتَشُّهُ', #1
u'تغتلي': u'تَغْتَلِي', #3
u'تغتمض': u'تَغْتَمِضْ', #3
u'تغثية': u'تغثية', #1
u'تغحند': u'تغحند', #1
u'تغذاله': u'تَغْذَالِهِ', #1
u'تغربة': u'تَغْرُبَةٍ', #1
u'تغربة': u'تَغْرُبَةِ', #1
u'تغربة': u'تَغْرِبَةٍ', #3
u'تغربتها': u'تَغْرِبَتِهَا', #1
u'تغرة': u'تَغِرّةً', #2
u'تغرة': u'تَغِرَّةً', #2
u'تغزيرهم': u'تَغْزِيرِهِمْ', #1
u'تغشرمت': u'تَغَشْرَمَتْ', #1
u'تغشمرت': u'تَغَشْمَرَتْ', #2
u'تغشمره': u'تَغَشْمَرَهُ', #1
u'تغطمطت': u'تَغَطمطت', #1
u'تغطمطت': u'تَغَطْمَطَتِ', #1
u'تغطمطت': u'تَغَطْمَطَتْ', #3
u'تغلظت': u'تَغَلَّظَتْ', #9
u'تغلقت': u'تَغَلَّقَتْ', #1
u'تغلمين': u'تَغْلَمَيْنِ', #2
u'تغمى': u'تُغْمَى', #2
u'تغميز': u'تَغْمِيزُ', #2
u'تغننت': u'تَغَنّنَتْ', #1
u'تغولت': u'تَغَوّلَتْ', #1
u'تغولت': u'تَغَوَّلَتْ', #9
u'تغويرهما': u'تَغْوِيرَهُمَا', #1
u'تغيا': u'تُغَيَّا', #1
u'تغيرى': u'تُغَيِّرِى', #1
u'تغييرة': u'تَغْيِيرَةِ', #1
u'تفاتيح': u'تَفَاتِيحُ', #2
u'تفارص': u'تَفَارَصَ', #1
u'تفارقنى': u'تُفَارِقُنِى', #1
u'تفارقنى': u'تُفَارِقْنِى', #1
u'تفاريع': u'تَفَارِيعُ', #15
u'تفاريع': u'تَفَارِيعِ', #28
u'تفاريع': u'تَفَارِيعَ', #9
u'تفاريعه': u'تَفَارِيعِهِ', #10
u'تفاريعه': u'تَفَارِيعَهُ', #3
u'تفاريعه': u'تَفَارِيعُهُ', #6
u'تفاريعها': u'تَفَارِيعُهَا', #1
u'تفاريعها': u'تَفَارِيعِهَا', #4
u'تفاريعها': u'تَفَارِيعَهَا', #5
u'تفاريعهم': u'تَفَارِيعِهِمْ', #3
u'تفاريعهما': u'تَفَارِيعِهِمَا', #1
u'تفاريقا': u'تَفَارِيقًا', #1
u'تفاشى': u'تَفَاشَى', #1
u'تفاصلت': u'تَفَاصَلَتْ', #5
u'تفالس': u'تَفَالَسَ', #14
u'تفألنا': u'تَفَأَّلْنَا', #1
u'تفأم': u'تُفْأَمُ', #3
u'تفتات': u'تَفْتَاتَ', #4
u'تفتاتن': u'تَفْتَاتِنَّ', #3
u'تفتاتوا': u'تَفْتَاتُوا', #2
u'تفترعها': u'تَفْتَرِعْهَا', #1
u'تفتض': u'تفتض', #1
u'تفتض': u'تَفْتَضُّ', #10
u'تفتضها': u'تَفْتَضُّهَا', #1
u'تفتنى': u'تَفْتِنِّى', #2
u'تفتؤ': u'تَفْتَؤ', #1
u'تفتؤ': u'تَفْتَؤُ', #5
u'تفث': u'تَفِثَ', #1
u'تفث': u'تَفَثٍ', #3
u'تفث': u'تَفَثِ', #5
u'تفثا': u'تَفَثًا', #1
u'تفثة': u'تَفِثَةٌ', #1
u'تفثه': u'تَفَثِهِ', #1
u'تفثه': u'تَفَثه', #2
u'تفثه': u'تَفَثَهُ', #23
u'تفثهم': u'تَفَثَهُمْ', #23
u'تفجؤه': u'تَفْجَؤُهُ', #2
u'تفجؤهم': u'تَفْجَؤُهُمْ', #1
u'تفخند': u'تفخند', #1
u'تفراحين': u'تفراحين', #1
u'تفرخت': u'تَفَرَّخَتْ', #2
u'تفرغى': u'تُفْرِغِى', #1
u'تفروقها': u'تُفْرُوقُهَا', #1
u'تفروقها': u'تَفْرُوقُهَا', #3
u'تفسدقال': u'تُفْسِدَقَالَ', #1
u'تفسيرهقوله': u'تَفْسِيرَهُقَوْلُهُ', #1
u'تفشعت': u'تَفَشَّعَتْ', #1
u'تفشغ': u'تفشغ', #1
u'تفشغ': u'تَفَشَّغَ', #7
u'تفشغت': u'تَفَشَّغَتْ', #1
u'تفشيلة': u'تَفْشِيلَةَ', #1
u'تفصيت': u'تَفَصَّيْت', #1
u'تفصيلة': u'تَفْصِيلَةُ', #1
u'تفضحنى': u'تَفْضَحْنِى', #2
u'تفضلته': u'تَفَضَّلْتَهُ', #1
u'تفطرى؟': u'تُفْطِرِى؟', #1
u'تفعال': u'تِفْعَالٌ', #2
u'تفعال': u'تِفْعَالٍ', #3
u'تفعالا': u'تَفْعَالًا', #1
u'تفعالا': u'تَفْعَالَا', #1
u'تفعلا': u'تَفَعُّلًا', #1
u'تفعلة': u'تَفْعِلَة', #1
u'تفعلة': u'تَفْعِلَةً', #4
u'تفعلة': u'تَفْعِلَةٌ', #8
u'تفعلل': u'تَفَعْلَلْ', #1
u'تفعلى': u'تَفْعَلِى', #11
u'تفكرته': u'تَفَكَّرْتَهُ', #1
u'تفلات': u'تَفِلاتٍ', #1
u'تفلات': u'تَفِلَاتٍََََ', #1
u'تفلات': u'تَفِلاَتٍ', #2
u'تفلات': u'تَفِلَاتٍ', #25
u'تفلات': u'تَفِلَاتٌ', #3
u'تفلة': u'تَفِلَةٍ', #1
u'تفلة': u'تَفِلَةً', #4
u'تفليسة': u'تَفْلِيسَةٍ', #1
u'تفنيان': u'تَفْنَيَانِ', #2
u'تفهق': u'تَفْهَقُ', #3
u'تفوتهالركعة': u'تَفُوتَهُالرَّكْعَةُ', #1
u'تفوح': u'تَفُوح', #2
u'تفوح': u'تَفُوحَ', #2
u'تفوح': u'تفوح', #3
u'تفوح': u'تَفُوحُ', #8
u'تفوضت': u'تَفَوَّضَتْ', #1
u'تفوقته': u'تَفَوَّقَتْهُ', #1
u'تفى': u'تفى', #1
u'تفى': u'تَفِى', #2
u'تفىء': u'تَفِىءَ', #7
u'تفئا': u'تَفْئًا', #1
u'تفئة': u'تَفِئَةِ', #5
u'تفيت': u'تُفِيتُ', #16
u'تفيته': u'تُفِيتُهُ', #14
u'تفيتها': u'تُفِيتُهَا', #4
u'تفيتهم': u'تُفِيتَهُمْ', #1
u'تفيضى': u'تُفِيضِى', #1
u'تفيظ': u'تَفِيظَ', #1
u'تقاءها': u'تِقَاءَهَا', #1
u'تقاحم': u'تَقَاحُمَ', #2
u'تقاحمون': u'تُقَاحِمُونَ', #1
u'تقادحت': u'تَقَادَحَتْ', #1
u'تقادع': u'تَقَادُعَ', #1
u'تقادير': u'تَقَادِيرَ', #1
u'تقادير': u'تَقَادِيرُ', #1
u'تقاديره': u'تَقَادِيرِهِ', #2
u'تقارا': u'تَقَارًّا', #1
u'تقارت': u'تَقَارَّتْ', #1
u'تقاررا': u'تَقَارَرَا', #7
u'تقاررتم': u'تَقَارَرْتُمْ', #1
u'تقارروا': u'تَقَارَرُوا', #1
u'تقاريع': u'تَقَارِيعِ', #1
u'تقاصا': u'تَقَاصًّا', #20
u'تقاصصا': u'تَقَاصَصَا', #1
u'تقالوها': u'تَقَالُّوهَا', #5
u'تقايا': u'تَقَايَا', #1
u'تقايأ': u'تَقَايَأَ', #6
u'تقايأه': u'تقايأه', #1
u'تقايأه': u'تَقَايَأَهُ', #9
u'تقايأها': u'تَقَايَأَهَا', #3
u'تقايؤ': u'تَقَايُؤِ', #1
u'تقايؤه': u'تَقَايُؤُهُ', #2
u'تقايئه': u'تقايئه', #1
u'تقايئه': u'تَقَايُئِهِ', #2
u'تقاييد': u'تَقَايِيدَ', #1
u'تقاييد': u'تَقَايِيدِ', #1
u'تقاييده': u'تَقَايِيدِهِ', #1
u'تقبحا': u'تَقَبُّحًا', #1
u'تقبضنيه': u'تُقْبِضنِيهِ', #2
u'تقبضنيه': u'تُقْبِضْنِيهِ', #4
u'تقترا': u'تَقَتُّرًا', #1
u'تقتضيان': u'تَقْتَضِيَانِ', #7
u'تقتلنى': u'تَقْتُلْنِى', #3
u'تقتلى': u'تُقْتَلِى', #1
u'تقدرعلى': u'تَقْدِرْعَلَى', #1
u'تقدع': u'تُقْدَعُ', #5
u'تقدمهايييي': u'تَقَدَّمَهَايييي', #1
u'تقديمة': u'تَقْدِيمَةِ', #1
u'تقذت': u'تَقَذَّتْ', #1
u'تقرءوا': u'تَقْرَءُوا', #4
u'تقرءون': u'تَقْرَءُونَ', #82
u'تقرءونه': u'تَقْرَءُونَهُ', #4
u'تقرءونها': u'تَقْرَءُونَهَا', #5
u'تقرءوه': u'تَقْرَءُوهُ', #1
u'تقرإ': u'تَقْرَإِ', #1
u'تقرآن': u'تَقْرَآنِ', #1
u'تقرآن': u'تَقْرَآَنِ', #1
u'تقرأون': u'تقرأون', #1
u'تقربنى': u'تُقَرِّبْنِى', #1
u'تقربى': u'تَقَرَّبِى', #1
u'تقرت': u'تَقَرَّتْ', #3
u'تقررناه': u'تَقَرَّرْنَاهُ', #1
u'تقرضت': u'تَقَرَّضْتُ', #1
u'تقرنى': u'تَقَرَّنِى', #1
u'تقرؤه،': u'تَقْرَؤُهُ،', #2
u'تقرؤه': u'تَقْرَؤُهُ', #8
u'تقرؤها': u'تَقْرَؤُهَا', #11
u'تقرؤها؟': u'تقرؤها؟', #2
u'تقرؤها،': u'تَقْرَؤُهَا،', #2
u'تقرؤها؟': u'تَقْرَؤُهَا؟', #2
u'تقرؤهن': u'تَقْرَؤُهُنَّ', #1
u'تقرئنى': u'تُقْرِئْنِى', #1
u'تقرئنيها،': u'تُقْرِئْنِيهَا،', #1
u'تقرئنيها': u'تُقْرِئْنِيهَا', #6
u'تقرئين،': u'تَقْرَئِينَ،', #1
u'تقريرة': u'تَقْرِيرَةِ', #1
u'تقسطت': u'تَقَسَّطَتْ', #3
u'تقسمة': u'تَقْسِمَةُ', #2
u'تقسيمة': u'تَقْسِيمَةٍ', #1
u'تقصيع': u'تَقْصِيعِ', #2
u'تقضضوا': u'تُقَضِّضُوا', #1
u'تقضينيه': u'تَقْضِينِيهِ', #1
u'تقطعناها': u'تُقْطِعَنَاهَا', #2
u'تقعص': u'تُقْعَصُ', #1
u'تقعصون': u'تُقْعَصُونَ', #1
u'تقعقعت': u'تَقَعْقَعَتْ', #2
u'تقفزت': u'تَقَفَّزَتْ', #1
u'تقلسون': u'تُقَلِّسُونَ', #3
u'تقللت': u'تَقَلَّلَتْ', #1
u'تقلنس': u'تَقَلْنَسَ', #1
u'تقلنى': u'تُقِلُّنِى', #2
u'تقوال': u'تَقْوَالَ', #1
u'تقوال': u'تِقْوَال', #1
u'تقولإنما': u'تَقُولُإِنَّمَا', #1
u'تقولوالله': u'تَقُولُوَاللَّهِ', #1
u'تقولى': u'تَقُولِى', #2
u'تقوى': u'تَقْوًى', #5
u'تقويمتين': u'تَقْوِيمَتَيْنِ', #1
u'تقي': u'تُقيً', #1
u'تقىء': u'تَقِىءُ', #1
u'تقيأه': u'تَقَيَّأَهُ', #4
u'تقيأها': u'تُقَيَّأهَا', #1
u'تقيأها': u'تَقَيَّأَهَا', #14
u'تقيت': u'تَقَيْتُ', #1
u'تقيلوك': u'تَقَيَّلُوكَ', #1
u'تقييدة': u'تَقْيِيدَةِ', #1
u'تقييس': u'تَقْيِيسِ', #1
u'تك': u'تك', #1
u'تك': u'تَكُ', #148
u'تكابوا،': u'تَكَابُّوا،', #1
u'تكابوا': u'تَكَابُّوا', #2
u'تكارا': u'تَكَارَا', #1
u'تكاراه': u'تَكَارَاهُ', #5
u'تكاراها': u'تَكَارَاهَا', #64
u'تكارسا': u'تَكَارُسَا', #1
u'تكاريت': u'تَكَارَيْتِ', #2
u'تكاريت': u'تَكَارَيْتُ', #40
u'تكاريتها': u'تَكَارِيَتُهَا', #1
u'تكاريتها': u'تَكَارَيْتُهَا', #3
u'تكافت': u'تَكَافَّتْ', #1
u'تكافيا': u'تَكَافِيًا', #1
u'تكافيش': u'تَكَافِيشِ', #1
u'تكاميش': u'تَكَامِيشُ', #1
u'تكاميش': u'تَكَامِيشَ', #2
u'تكاميش': u'تَكَامِيشِ', #2
u'تكاميشه': u'تكاميشه', #1
u'تكاميشها': u'تَكَامِيشُهَا', #1
u'تكاه': u'تكاه', #1
u'تكتبت': u'تَكَتَّبَتْ', #3
u'تكتنوا': u'تَكَتْنُوا', #1
u'تكتنوا': u'تَكْتَنُوا', #20
u'تكتنين': u'تَكْتَنِينَ', #1
u'تكتوك': u'تكتوك', #1
u'تكذابك': u'تَكْذَابَكَ', #1
u'تكذبينى': u'تَكْذِبِينِى', #1
u'تكذبينى': u'تُكَذِّبِينِى', #1
u'تكذيبى': u'تَكْذِيبِى', #1
u'تكريب': u'تَكْرِيبٍ', #1
u'تكريب': u'تَكْرِيبِ', #5
u'تكريبها': u'تَكْرِيبَهَا', #1
u'تكريت': u'تكريت', #1
u'تكريت': u'تِكْريت', #1
u'تكريت': u'تِكْرِيتَ', #1
u'تكريت': u'تَكْرِيتَ', #4
u'تكسع': u'تُكْسَعُ', #1
u'تكسيتهم': u'تَكْسِيَتِهِمْ', #1
u'تكسيله': u'تَكْسِيلِهِ', #1
u'تكشفتها': u'تَكَشَّفْتُهَا', #3
u'تكشيخا': u'تَكْشِيخًا', #1
u'تكعكع': u'تَكَعْكَعَ', #1
u'تكعكعت': u'تكعكعت', #1
u'تكعكعت': u'تَكَعْكَعْت', #1
u'تكعكعت': u'تَكَعْكَعْتَ', #8
u'تكعكعه': u'تَكَعْكُعِهِ', #1
u'تكفت': u'تَكَفّتَ', #2
u'تكفته': u'تكفته', #1
u'تكفتها': u'تَكْفِتُهَا', #1
u'تكفرى': u'تُكَفِّرِى', #1
u'تكفرى': u'تَكْفُرِى', #3
u'تكفننى': u'تُكَفِّنُنِى', #1
u'تكفؤ': u'تَكَفُّؤَ', #1
u'تكفؤا': u'تَكَفّؤًا', #1
u'تكفؤا': u'تَكَفُّؤًا', #4
u'تكفور': u'تكفور', #4
u'تكفؤه': u'تَكْفَؤُهُ', #2
u'تكفيء': u'تَكْفِيءُ', #1
u'تكفيا،': u'تَكَفِّيًا،', #1
u'تكفيان': u'تَكْفِيَانِ', #2
u'تكفيت': u'تَكْفِيتُ', #1
u'تكفيكهم': u'تَكْفِيكَهُمُ', #3
u'تكفينى': u'تَكْفِينِى', #2
u'تكلام': u'تِكْلَامٌ', #1
u'تكلبت': u'تَكَلَّبَتْ', #1
u'تكلثما': u'تَكَلْثُمًا', #1
u'تكلفونيه': u'تُكَلِّفُونِيهِ', #2
u'تكلمنى': u'تُكَلِّمْنِى', #2
u'تكلمى': u'تَكَلَّمِى', #1
u'تكلنى': u'تَكِلُنِى', #3
u'تكنينى': u'تُكَنِّينِى', #1
u'تكهر': u'تَكْهَرْ', #3
u'تكهلت': u'تَكَهَّلَتْ', #1
u'تكوسج': u'تَكَوْسَجَ', #1
u'تكونى': u'تَكُونِى', #14
u'تكيد': u'تَكِيدُ', #1
u'تكيدكم': u'تَكِيدُكُمْ', #1
u'تكيده': u'تَكِيدُهُ', #3
u'تكيدها': u'تكِيدها', #1
u'تكيدها': u'تَكِيدُهَا', #3
u'تكيدوا': u'تَكِيدُوا', #1
u'تلاء': u'تَلَّاءً', #2
u'تلاتله': u'تَلَاتِلُهُ', #1
u'تلاتله': u'تَلَاتِلِهِ', #1
u'تلادا': u'تِلاَدًا', #1
u'تلادة': u'تلادة', #1
u'تلادكا': u'تِلَادُكَا', #1
u'تلازقت': u'تَلَازَقَتْ', #1
u'تلازمت': u'تَلَازَمَتْ', #2
u'تلاقاه': u'تَلَاقَاهُ', #1
u'تلاقته': u'تَلَاقَتْهُ', #2
u'تلبينة': u'تَلْبِينَةٍ', #5
u'تلتدم': u'تَلْتَدِمُ', #1
u'تلتدم،': u'تَلْتَدِمُ،', #1
u'تلتلة': u'تَلْتَلَةٍ', #1
u'تلتلوه': u'تَلْتِلُوهُ', #4
u'تلتم': u'تَلْتَمّ', #1
u'تلتمع': u'تَلْتَمِع', #1
u'تلتمع': u'تَلْتَمِعُ', #1
u'تلجما': u'تَلَجُّمًا', #1
u'تلجمت': u'تَلَجَّمَتْ', #2
u'تلجيء': u'تَلْجِيءُ', #1
u'تلحلح': u'تَلَحْلَحَ', #1
u'تلحلحت': u'تَلَحْلَحَتْ', #2
u'تلحيده': u'تَلْحِيدِهِ', #2
u'تلدغنى': u'تَلْدَغُنِى', #2
u'تلدونى': u'تَلُدُّونِى', #1
u'تلدى': u'تَلِدِى', #3
u'تلطفة': u'تلطفة', #1
u'تلعبا': u'تَلَعّبًا', #1
u'تلعفر': u'تلعفر', #1
u'تلفظته': u'تَلَفَّظْته', #2
u'تلفعت': u'تَلَفّعَتْ', #1
u'تلفعت': u'تَلَفَّعَتْ', #4
u'تلفقت': u'تَلَفَّقَتْ', #1
u'تلقانى': u'تَلَقَّانِى', #3
u'تلقانى': u'تَلْقَانِى', #4
u'تلقونى': u'تَلْقَوْنِى', #10
u'تلقينة': u'تَلْقِينَةٍ', #1
u'تلمحت': u'تَلَمَّحْتَ', #2
u'تلمحته': u'تَلْمِحَتُهُ', #1
u'تلمط': u'تَلَمَّطُ', #1
u'تلمظ': u'تَلَمّظَ', #1
u'تلمنى': u'تَلُمْنِى', #1
u'تلومنى': u'تَلُومُنِى', #1
u'تلوموننى': u'تلوموننى', #1
u'تليس': u'تَلِّيسٍ', #2
u'تليسه': u'تُلَيِّسُهُ', #1
u'تليط': u'تُلِيطُ', #1
u'تليعة': u'تَلِيعَةً', #1
u'تليق': u'تُلِيقُ', #2
u'تليق': u'تَلِيقُ', #245
u'تليق': u'تَلِيقَ', #3
u'تليق': u'تَلِيق', #4
u'تلينى': u'تَلِينِى', #1
u'تلييس': u'تَلْيِيسِ', #1
u'تماضر': u'تماضر', #1
u'تماضر': u'تَمَاضُرُ', #1
u'تماضر،': u'تُمَاضِرَ،', #1
u'تماضر': u'تُمَاضِرَ', #20
u'تماضر': u'تَمَاضُرَ', #4
u'تماضر': u'تُمَاضِرُ', #5
u'تمالأتما': u'تَمَالَأْتُمَا', #1
u'تمالت': u'تَمَالَتْ', #1
u'تمالؤ': u'تَمَالُؤَ', #1
u'تمالؤ': u'تَمَالُؤٍ', #17
u'تمالؤ': u'تَمَالُؤٌ', #9
u'تمالؤا': u'تَمَالُؤًا', #1
u'تماهل': u'تَمَاهَلَ', #1
u'تماينا': u'تَمَايُنًا', #1
u'تمتحق': u'تَمْتَحِقُ', #2
u'تمتشطى': u'تَمْتَشِطِى', #1
u'تمتلىء': u'تمتلىء', #1
u'تمجس': u'تَمَجَّسْ', #1
u'تمجس': u'تَمَجُّسُ', #1
u'تمجس': u'تُمَجَّسُ', #1
u'تمجس': u'تَمَجُّسٍ', #18
u'تمجس': u'تَمَجُّسَ', #3
u'تمجس': u'تَمَجُّسِ', #3
u'تمجس': u'تَمَجَّسَ', #51
u'تمجسا': u'تَمَجَّسَا', #6
u'تمجست': u'تَمَجَّسْتِ', #1
u'تمجست': u'تَمَجَّسَتْ', #24
u'تمجسها': u'تَمَجُّسَهَا', #2
u'تمجسوا': u'تُمَجِّسُوا', #1
u'تمحضت': u'تَمَحَضَّتْ', #5
u'تمحضت': u'تَمَحَّضَتْ', #54
u'تمحلا': u'تَمَحُّلًا', #3
u'تمحلات': u'تَمَحُّلَاتٌ', #1
u'تمحلات': u'تَمَحُّلَاتٍ', #2
u'تمحيض': u'تَمْحِيضِ', #2
u'تمحيضه': u'تَمْحِيضُهُ', #2
u'تمحيقا': u'تَمْحِيقًا', #1
u'تمخيا': u'تَمَخِّيًا', #6
u'تمخيت': u'تَمَخَّيْتُ', #1
u'تمدحا': u'تَمَدّحًا', #2
u'تمذ': u'تُمْذِ', #1
u'تمراتى': u'تَمَرَاتِى', #3
u'تمرإن': u'تَمْرٍإِنْ', #1
u'تمرتاش': u'تُمُرْتَاشٍ', #1
u'تمرتاش': u'تُمُرْتَاشَ', #2
u'تمرتاشي': u'تُمُرْتَاشِيٌّ', #1
u'تمرتاشي': u'تُمُرْتَاشِيٍّ', #2
u'تمرضنى': u'تُمْرِضُنِى', #1
u'تمرط': u'تمرط', #2
u'تمرط': u'تَمَرَّطَ', #2
u'تمرى': u'تُمْرَى', #3
u'تمريج': u'تَمْرِيجٌ', #1
u'تمزاح': u'تِمْزَاحٌ', #1
u'تمزع': u'تَمَزُّعُ', #7
u'تمست': u'تَمَسَّتْ', #1
u'تمسكى': u'تمسكى', #1
u'تمشطنى': u'تَمْشُطُنِى', #1
u'تمطأ': u'تَمَطَّأَ', #1
u'تمطأت': u'تَمَطَّأْتُ', #1
u'تمعج': u'تَمْعَجُ', #2
u'تمعدد': u'تَمَعْدَدَ', #1
u'تمعدد': u'تَمَعْدَدْ', #2
u'تمعددوا': u'تَمَعْدَدُوا', #9
u'تمعر': u'تَمَعَّرَ', #1
u'تمعر': u'تُمَعِّرُ', #1
u'تمعرا': u'تَمَعُّرًا', #1
u'تمعززوا': u'تَمَعْزَزُوا', #1
u'تمعس': u'تمعس', #1
u'تمعس': u'تَمْعَسُ', #6
u'تمعش': u'تَمَعُّشُ', #1
u'تمعشه': u'تَمَعُّشِهِ', #2
u'تمعشها': u'تَمَعُّشِهَا', #1
u'تمعضت': u'تَمَعَّضَتْ', #1
u'تمعط': u'تَمَعَّطَ', #14
u'تمعط': u'تَمَعُّطُ', #4
u'تمعطت': u'تَمَعَّطَتْ', #1
u'تمعكت': u'تمعكت', #1
u'تمعكت': u'تَمَعَّكْت', #2
u'تمعكت': u'تَمَعَّكْتُ', #4
u'تمغ': u'تمغ', #1
u'تمغا': u'تَمْغًا', #1
u'تمككا': u'تَمَكُّكًا', #1
u'تمككت': u'تَمَكّكْت', #1
u'تمككت': u'تَمَكَّكْتُ', #1
u'تملاق': u'تِمْلَاقٍ', #1
u'تملآن': u'تَمْلآنِ', #1
u'تملآن': u'تُمْلَآنِ', #1
u'تملئوا': u'تَمْلَئُوا', #1
u'تملئوه': u'تَمْلئُوهُ', #1
u'تملئوه': u'تَمْلَئُوهُ', #5
u'تملية': u'تَمْلِيَةُ', #1
u'تمليقا': u'تَمْلِيقًا', #1
u'تمنعوننى': u'تَمْنَعُونَنِى', #2
u'تمنعى': u'تَمْنَعِى', #1
u'تموتت': u'تُمُوِّتَتْ', #1
u'تموتى': u'تَمُوتِى', #1
u'تميرا': u'تميرا', #1
u'تميرات': u'تُمَيْرَاتٌ', #4
u'تميرات': u'تُمَيْرَاتٍ', #7
u'تميلة': u'تُمَيْلة', #1
u'تميلة،': u'تُمَيْلَةَ،', #22
u'تميلة': u'تُمَيْلَةَ', #28
u'تميما': u'تَمِيمًا', #39
u'تميما': u'تميمًا', #5
u'تميمى': u'تَمِيمِىٌّ', #1
u'تميميا': u'تَمِيمِيًّا', #1
u'تميمية': u'تَمِيمِيَّةً', #3
u'تمييزة': u'تَمْيِيزَةِ', #1
u'تنابلة': u'تَنَابِلَةٍ', #7
u'تناتج': u'تناتج', #1
u'تناتج': u'تُنَاتَجُ', #1
u'تناتج': u'تَنَاتَجُ', #8
u'تناتجت': u'تَنَاتَجَتْ', #6
u'تناتيف': u'تَنَاتِيفٍ', #1
u'تناجشوا،': u'تَنَاجَشُوا،', #4
u'تناجشوا': u'تَنَاجَشُوا', #59
u'تناحا': u'تَنَاحًا', #1
u'تناخس': u'تَنَاخَسُ', #1
u'تناخى': u'تَنَاخَى', #1
u'تناخى': u'تُنَاخَى', #1
u'تناصيني': u'تُنَاصِينِي', #4
u'تناطقت': u'تَنَاطَقَتْ', #1
u'تنافذا': u'تَنَافُذًا', #1
u'تنافيذ': u'تَنَافِيذَ', #1
u'تناكلا': u'تَنَاكَلَا', #4
u'تناكلهما': u'تَنَاكُلِهِمَا', #1
u'تناهقوا': u'تَنَاهَقُوا', #1
u'تناوح': u'تَنَاوُحُ', #1
u'تناوحت': u'تَنَاوَحَتْ', #2
u'تناوف': u'تَنَاوُفَ', #1
u'تنائف': u'تَنَائِفُ', #1
u'تنبال': u'تِنْبَالٍ', #2
u'تنبال': u'تِنْبَالٌ', #3
u'تنبغى': u'تَنْبَغِى', #5
u'تنبنيان': u'تَنْبَنِيَانِ', #1
u'تنبىء': u'تنبىء', #1
u'تنبيك': u'تُنْبِيكَ', #1
u'تنتتف': u'تُنْتَتَف', #1
u'تنتثر': u'تَنْتَثِرُ', #1
u'تنتثلون': u'تنتثلون', #1
u'تنتثلونها،': u'تَنْتَثِلُونَهَا،', #1
u'تنتثلونها': u'تَنْتَثِلُونَهَا', #6
u'تنتجز': u'تَنْتَجِزُ', #1
u'تنتحت': u'تَنْتَحِتُ', #1
u'تنترق': u'تَنْتَرِقُ', #1
u'تنتضي': u'تَنْتَضِي', #1
u'تنتطق': u'تَنْتَطِقْ', #1
u'تنتفس': u'تَنْتَفِس', #1
u'تنتقب': u'تَنْتَقِب', #1
u'تنتقب': u'تَنْتَقِبَ', #1
u'تنتقب': u'تَنْتَقِبِ', #2
u'تنتقب': u'تَنْتَقِبْ', #2
u'تنتقب': u'تَنْتَقِبُ', #40
u'تنتوي': u'تَنْتَوِي', #6
u'تنثعب': u'تَنْثَعِبُ', #2
u'تنثوي': u'تنثوي', #2
u'تنجرح': u'تَنْجَرِحَ', #3
u'تنجيرا': u'تَنْجِيرًا', #1
u'تنحبط': u'تَنْحَبِطُ', #1
u'تنحجر': u'تَنْحَجِرُ', #5
u'تنحرى': u'تَنْحَرِى', #1
u'تنحوم': u'تَنْحوم', #3
u'تندرأ': u'تُنْدَرَأُ', #1
u'تندرئ': u'تَنْدَرِئُ', #105
u'تندلت': u'تَنَدَّلْت', #2
u'تنديم': u'تَنْدِيمٍ', #1
u'تنزوه': u'تَنْزُوهُ', #1
u'تنزية': u'تَنْزِيَةُ', #1
u'تنزية': u'تَنْزِيَةً', #2
u'تنزية': u'تَنْزِيَةٍ', #3
u'تنسواقوله': u'تَنْسَوْاقَوْلُهُ', #1
u'تنسئها': u'تُنْسِئَهَا', #1
u'تنشآن': u'تَنْشِآنِ', #1
u'تنشقص': u'تَنْشَقِصْ', #1
u'تنشيقه': u'تَنْشِيقُهُ', #1
u'تنصدم': u'تَنْصَدِمْ', #1
u'تنصرونى': u'تَنْصُرُونِى', #2
u'تنضبة': u'تَنْضُبَةٌ', #1
u'تنضبة': u'تَنْضُبَةٍ', #1
u'تنضبت': u'تَنَضّبَتْ', #1
u'تنضيض': u'تنضيض', #1
u'تنضيض': u'تَنْضِيضٍ', #1
u'تنضيض': u'تَنْضِيضُ', #11
u'تنضيض': u'تَنْضِيضِ', #13
u'تنضيض': u'تَنْضِيضٌ', #2
u'تنضيضه': u'تَنْضِيضَه', #1
u'تنضيضه': u'تَنْضِيضَهُ', #2
u'تنضيضه': u'تَنْضِيضِهِ', #4
u'تنضيضه': u'تَنْضِيضُهُ', #7
u'تنظرنى': u'تَنْظُرُنِى', #2
u'تنعة': u'تِنْعَةَ', #1
u'تنعقر': u'تَنْعَقِرُ', #1
u'تنعمر': u'تَنْعَمِرُ', #1
u'تنعيل': u'تَنْعِيلٍ', #2
u'تنعيل': u'تَنْعِيلُ', #2
u'تنغرا': u'تَنَغُّرًا', #1
u'تنغرف': u'تَنْغَرِفُ', #1
u'تنفرا': u'تَنَفُّرًا', #1
u'تنفقى': u'تُنْفِقِى', #1
u'تنفلة': u'تَنْفِلَةٍ', #1
u'تنفيان': u'تَنْفِيَانِ', #1
u'تنقث': u'تَنْقُثُ', #1
u'تنقث': u'تُنَقِّثُ', #1
u'تنقث': u'تنقث', #2
u'تنقدح': u'تَنْقَدِحْ', #1
u'تنقدح': u'تَنْقَدِحُ', #5
u'تنقصى': u'تُنْقِصِى', #1
u'تنقمع': u'تَنْقَمِعْ', #1
u'تنقيثا': u'تَنْقِيثًا', #2
u'تنقيعا': u'تَنْقِيعًا', #1
u'تنكحى': u'تَنْكِحِى', #2
u'تنكمن': u'تَنْكَمِنُ', #1
u'تنمعك': u'تَنْمَعِكُ', #1
u'تنهانى': u'تَنْهَانِى', #1
u'تنهدر': u'تَنْهَدِرَ', #1
u'تنهس': u'تَنْهَسُ', #1
u'تنهسه': u'تَنْهَسهُ', #1
u'تنهكى': u'تَنْهَكِى', #4
u'تنوخ': u'تَنُوخ', #1
u'تنوخ،': u'تَنُوخَ،', #1
u'تنوخ': u'تَنُوخُ', #3
u'تنوخ': u'تَنُوخِ', #3
u'تنوخ': u'تَنُوخٍ', #4
u'تنوخ': u'تَنُوخَ', #6
u'تنوخا': u'تُنُوخًا', #1
u'تنوفة': u'تَنُوفَةٍ', #1
u'تنوفة': u'تُنُوفَةٌ', #1
u'تنومة': u'تَنُّومَةٌ', #3
u'تنى': u'تَنَى', #1
u'تنيس': u'تُنِيس', #1
u'تها': u'تُهَا', #1
u'تهابك': u'تَهَابُكَ', #1
u'تهابنا': u'تَهَابُنَا', #1
u'تهابه': u'تهابه', #1
u'تهابه': u'تَهَابهُ', #1
u'تهابه': u'تَهَابُهُ', #3
u'تهابهم': u'تَهَابُهُمْ', #1
u'تهابوني': u'تَهَابُونِي', #1
u'تهادرنا': u'تَهَادَرْنَا', #1
u'تهارج': u'تَهَارُجِ', #1
u'تهارج': u'تَهَارُجَ', #5
u'تهامة،': u'تهامة،', #1
u'تهامة': u'تِهامة', #1
u'تهامة': u'تِهَامة', #1
u'تهامة': u'تُهَامَةَ', #1
u'تهامة': u'تِهَامَة', #1
u'تهامة،': u'تِهَامَةَ،', #11
u'تهامة': u'تِهَامَةُ', #13
u'تهامة': u'تِهَامَةَ', #168
u'تهامة': u'تِهَامَةٌ', #2
u'تهامة': u'تِهَامَةٍ', #3
u'تهامة': u'تِهَامَةِ', #7
u'تهامته': u'تِهَامَتِهِ', #1
u'تهامي': u'تهامي', #1
u'تهامي': u'تَهَامِيّ', #1
u'تهامي': u'تِهَامِيّ', #3
u'تهامية': u'تِهَامِيَّةٌ', #4
u'تهانؤ': u'تَهَانُؤ', #1
u'تهايآ': u'تَهَايَآ', #100
u'تهايأ': u'تَهَايَأَ', #22
u'تهايأه': u'تَهَايَأَهُ', #3
u'تهايآه': u'تَهَايَآهُ', #4
u'تهايلها': u'تَهَايُلُهَا', #1
u'تهايؤ': u'تَهَايُؤَ', #3
u'تهايؤ': u'تَهَايُؤٌ', #9
u'تهايؤا': u'تَهَايُؤًا', #2
u'تهايؤها': u'تَهَايُؤُهَا', #2
u'تهايئا': u'تَهَايَئَا', #21
u'تهايئهما': u'تَهَايُئِهِمَا', #2
u'تهايئوا': u'تَهَايَئُوا', #10
u'تهايئوها': u'تهايئوها', #1
u'تهة': u'تَهَّةً', #1
u'تهتش': u'تهتش', #1
u'تهتش': u'تَهْتَشَّ', #4
u'تهجيس': u'تَهْجِيسِ', #1
u'تهراق': u'تُهَرَاقَ', #1
u'تهراق': u'تُهْرَاقُ', #15
u'تهراق': u'تُهَرَاقُ', #16
u'تهراق': u'تُهْرَاقَ', #2
u'تهراق': u'تُهْرَاق', #5
u'تهراقان': u'تُهَرَاقَانِ', #1
u'تهراقان،': u'تُهْرِاقَانِ،', #1
u'تهراقان': u'تُهْرَاقَانِ', #2
u'تهرى': u'تَهَرَّى', #16
u'تهرية': u'تَهْرِيَةٌ', #1
u'تهرية': u'تَهْرِيَةٍ', #1
u'تهزيا': u'تَهَزِّيًّا', #1
u'تهليلة': u'تَهْلِيلَةً', #1
u'تهليلة': u'تَهْلَيْلَةٍ', #1
u'تهليلة': u'تَهْلِيلَةٍ', #14
u'تهليلة': u'تَهْلِيلَةٌ', #6
u'تهمت': u'تهمت', #1
u'تهنية': u'تهنية', #1
u'تهوكت': u'تَهَوَّكَتْ', #1
u'تهى': u'تَهْىٌ', #1
u'تهيع': u'تَهِيعُ', #2
u'تهيكاه': u'تهيكاه', #1
u'تهيىء': u'تهيىء', #1
u'تواء': u'تَوَاءِ', #3
u'تواتينا': u'تُوَاتِينَا', #1
u'تواتيهم': u'تُوَاتِيهِمْ', #1
u'تؤاجر': u'تُؤَاجِرَ', #14
u'تؤاجر': u'تُؤَاجَرُ', #29
u'تؤاجر': u'تُؤَاجِرُ', #3
u'تؤاجر': u'تُؤَاجَرَ', #5
u'تؤاجره': u'تُؤَاجِرُهُ', #1
u'تؤاجره': u'تُؤَاجِرْهُ', #2
u'تؤاجره': u'تُؤَاجِرَهُ', #4
u'تؤاجرها': u'تُؤَاجِرَهَا', #1
u'تؤاجرها': u'تُؤَاجِرُهَا', #5
u'تؤاجروا،': u'تُؤَاجِرُوا،', #1
u'تؤاجريني': u'تُؤَاجِرِينِي', #1
u'تؤاخ': u'تُؤَاخِ', #1
u'تواخ': u'تُوَاخِ', #2
u'تواخدى': u'تواخدى', #1
u'تؤاخذ': u'تُؤَاخِذْ', #2
u'تؤاخذ': u'تُؤَاخَذُ', #24
u'تؤاخذ': u'تُؤَاخَذَ', #4
u'تؤاخذ': u'تُؤَاخَذْ', #4
u'تؤاخذان': u'تُؤَاخَذَانِ', #2
u'تؤاخذنا': u'تُؤَاخِذْنَا', #53
u'تؤاخذني': u'تُؤَاخِذُنِي', #1
u'تؤاخذني': u'تُؤَاخِذْنِي', #19
u'تؤاخذنى': u'تُؤَاخِذْنِى', #2
u'تؤاخذه': u'تُؤَاخِذَهُ', #1
u'تؤاخذه،': u'تُؤَاخِذْهُ،', #1
u'تؤاخذه': u'تُؤَاخِذْهُ', #2
u'تؤاخذهم': u'تُؤَاخِذْهُمْ', #1
u'تؤاخذون': u'تُؤَاخَذُونَ', #3
u'تؤاخذونى': u'تُؤَاخِذُونِى', #1
u'تؤاخذوني': u'تُؤَاخِذُونِي', #3
u'تواخي': u'تَوَاخِيَ', #1
u'تؤاخي': u'تُؤَاخِي', #2
u'تؤاخين': u'تُؤَاخِيَنَّ', #1
u'توآزا': u'توآزا', #1
u'توازاذي': u'توازاذي', #2
u'تواست': u'تواست', #1
u'تواضعوه': u'تُوَاضِعُوهُ', #3
u'تواضعوها': u'تَوَاضَعُوهَا', #1
u'تواطت': u'تَوَاطَتْ', #1
u'تواطيهم': u'تَوَاطِيهِمْ', #1
u'توافت': u'تَوَافَتِ', #1
u'توافت': u'تَوَافَتْ', #1
u'توافونى': u'تُوَافُونِى', #2
u'تواقصت': u'تواقصت', #1
u'تواقصت': u'تَوَاقَصْتُ', #2
u'تواكر': u'تُوَاكَرُ', #1
u'تؤاكل': u'تُؤَاكَلَ', #1
u'تؤاكل': u'تُؤَاكَلُ', #1
u'تؤاكل': u'تُؤَاكِلْ', #1
u'تؤاكله': u'تُؤَاكِلُهُ', #2
u'تؤاكلوه': u'تُؤَاكِلُوهُ', #1
u'تؤاكلوهم': u'تُؤَاكِلُوهُمْ', #1
u'تواكى': u'تَوَاكَى', #2
u'توالبها': u'تَوَالِبُهَا', #2
u'توالعك': u'تَوَالُعُكَ', #1
u'تواليف': u'تَوَالِيفَ', #1
u'تواليفهم': u'تَوَالِيفِهِمْ', #1
u'تؤامر': u'تُؤَامِرَ', #2
u'تؤامرني،': u'تُؤَامِرْنِي،', #1
u'تؤامرنى': u'تُؤَامِرَنِى', #1
u'تؤامرها': u'تُؤَامِرْهَا', #1
u'توامشب': u'توامشب', #1
u'تواند': u'تواند', #12
u'تواندجه': u'تواندجه', #1
u'تواندر': u'تواندر', #1
u'تواندرم': u'تواندرم', #1
u'تواندكه': u'تواندكه', #1
u'تواندوا': u'تواندوا', #1
u'تؤانس': u'تُؤَانِسُ', #1
u'توانم': u'توانم', #1
u'تواهق': u'تُوَاهِقُ', #2
u'تواؤه': u'تَوَاؤُهُ', #1
u'تواين': u'تواين', #1
u'توباد': u'توباد', #3
u'توباشد': u'توباشد', #2
u'توباكسي': u'توباكسي', #1
u'توباي': u'توباي', #1
u'توبت': u'تُوَبْتِ', #1
u'توبتى': u'تَوْبَتِى', #7
u'توبخريدى': u'توبخريدى', #1
u'توبخورم': u'توبخورم', #1
u'توبدست': u'توبدست', #2
u'تؤبر': u'تؤبر', #1
u'تؤبر': u'تُؤَبِّرْ', #1
u'تؤبر': u'تُؤْبَرُ', #1
u'تؤبر': u'تُؤَبَّرَ', #14
u'تؤبر': u'تُؤْبَرْ', #3
u'تؤبر،': u'تُؤَبَّرَ،', #4
u'تؤبر': u'تُؤَبَّرْ', #69
u'تؤبر': u'تُؤَبَّرُ', #8
u'توبرداري': u'توبرداري', #1
u'توبركت': u'توبركت', #1
u'توبره': u'تُوَبِّرهُ', #1
u'توبروم': u'توبروم', #1
u'توبسودزيان': u'توبسودزيان', #1
u'توبكار': u'توبكار', #3
u'توبكافري': u'توبكافري', #1
u'توبوده': u'توبوده', #2
u'توبيخشايا': u'توبيخشايا', #1
u'توبيره': u'تَوْبِيرِهِ', #1
u'توبيل': u'توبيل', #1
u'توبيوست': u'توبيوست', #1
u'تؤتنف': u'تُؤْتَنَفْ', #1
u'تؤتنف': u'تُؤْتَنَفُ', #5
u'تؤتنيه': u'تُؤْتِنِيهِ', #1
u'توثبة': u'تَوَثُّبَةً', #1
u'توثقة': u'تَوْثِقَةِ', #1
u'توثقة': u'تَوْثِقَةً', #12
u'توثقة': u'تَوْثِقَةٌ', #18
u'توثقة': u'تَوْثِقَةٍ', #4
u'توثقة': u'تَوْثِقَةُ', #7
u'توثقته': u'تَوْثِقَته', #1
u'توثقته': u'تَوْثِقَتُهُ', #2
u'توثنت': u'تَوَثَّنَتْ', #2
u'توجأ': u'تُوجَأ', #1
u'توجأ': u'تُوجَأُ', #1
u'توجأ': u'تُوجَأَ', #2
u'توجره': u'تُوجِرَهُ', #2
u'توجره': u'تُوجِرُهُ', #2
u'توجرهما': u'تُوجِرَهُمَا', #1
u'توحرام': u'توحرام', #1
u'توحيد': u'تَوْحِيدً', #1
u'توحيله': u'توحيله', #1
u'توحيلها': u'تَوْحِيلُهَا', #1
u'تؤخرى': u'تُؤَخِّرِى', #1
u'توخريدي': u'توخريدي', #1
u'توخواسته': u'توخواسته', #1
u'توخواهي': u'توخواهي', #1
u'توخيانت': u'توخيانت', #1
u'توداده': u'توداده', #2
u'تودران': u'تودران', #1
u'تؤديان': u'تُؤَدَّيَانِ', #2
u'تؤديان': u'تُؤَدِّيَانِ', #3
u'تؤذنونى': u'تُؤْذِنُونِى', #1
u'تؤذينى': u'تُؤْذِينِى', #1
u'تورا': u'تَوْرًا', #22
u'توران': u'تُورَانَ', #1
u'توران': u'تَوْرَانَ', #1
u'تورخ': u'تُوَرَّخْ', #1
u'تورخا': u'تُوَرَّخَا', #1
u'توروي': u'توروي', #1
u'توريخ': u'تَوْرِيخِ', #1
u'توزيادت': u'توزيادت', #1
u'توسطة': u'تَوْسِطَةِ', #1
u'توسه': u'تُوسِهِ', #2
u'توضا': u'توضا', #1
u'توضا': u'تَوَضَّا', #1
u'توضأه': u'تُوَضَّأْهُ', #1
u'توضأه': u'تَوَضَّأَهُ', #2
u'توضيء': u'تَوْضِيء', #2
u'توضئى': u'تَوَضَّئِى', #3
u'توضيئه': u'تَوْضِيئُهُ', #1
u'توضيئه': u'تَوْضِيئِهِ', #1
u'توطآن': u'تُوطَآَنِ', #1
u'توطآن': u'تُوطَآنِ', #2
u'توعيد': u'تَوْعِيدِ', #1
u'توفنى': u'تَوَفَّنِى', #1
u'توفنيه': u'تُوفِنِيهِ', #1
u'توفيتنى': u'تَوَفَّيْتَنِى', #1
u'توفيقة': u'تَوْفِيقَةَ', #1
u'توفينيه': u'تُوفِينِيهِ', #1
u'توفينيه': u'تُوَفِّينِيهِ', #1
u'توفينيه': u'تُوَفِّيَنِيهِ', #1
u'توفينيها': u'تُوَفِّيَنِيهَا', #1
u'توقانا': u'تَوَقَانًا', #4
u'توقة': u'توقة', #1
u'توقة': u'تُوقَةَ', #1
u'تؤقت': u'تُؤَقِّتَ', #2
u'تؤقت': u'تُؤَقَّتَ', #5
u'تؤقت': u'تُؤَقَّتُ', #6
u'تؤقت': u'تُؤَقِّتْ', #8
u'تؤقت': u'تُؤَقَّتْ', #9
u'تؤقتا': u'تُؤَقِّتَا', #1
u'توقتت': u'تَوَقَّتَتْ', #3
u'توقل': u'تَوَقّلَ', #1
u'توكذبانو': u'توكذبانو', #1
u'توكردم': u'توكردم', #3
u'توكردو': u'توكردو', #1
u'توكه': u'توكه', #3
u'توكي': u'تُوكِي', #6
u'تولاء': u'تَوْلَاءُ', #1
u'تولم': u'تُولِمَ', #4
u'تولينى': u'تُوَلِّينِى', #1
u'تولينى': u'تُوَلِّيَنِى', #1
u'توما': u'توما', #1
u'توما،': u'توما،', #1
u'توما': u'تُومَا', #1
u'توما،': u'تَوْمًا،', #1
u'توما': u'تُوِّمَا', #2
u'تومبيرى': u'تومبيرى', #1
u'تومتها': u'تُومَتَهَا', #2
u'تومر': u'تومر', #1
u'تومرانداري': u'تومرانداري', #1
u'تومرت،': u'تُومَرْتَ،', #1
u'تومكن': u'تومكن', #1
u'تومه': u'تُومه', #1
u'تومه': u'تُوَمَهُ', #1
u'توميكنى': u'توميكنى', #1
u'توميكوئى': u'توميكوئى', #1
u'تونبرداشته': u'تونبرداشته', #1
u'تونر': u'تونر', #1
u'تونكذارد': u'تونكذارد', #1
u'تونماز': u'تونماز', #1
u'تونهادم': u'تونهادم', #8
u'تونيارم': u'تونيارم', #1
u'تونيز': u'تونيز', #1
u'تونيس': u'تَوْنِيسِ', #1
u'تونيست': u'تونيست', #2
u'توهق': u'تُوهَقُ', #1
u'توهق': u'تَوَهَّقَ', #3
u'توهقه': u'تَوَهَّقَهُ', #3
u'توهيج': u'توهيج', #1
u'تووكيل': u'تووكيل', #1
u'توونه': u'توونه', #1
u'توئد': u'تُوئَدِ', #1
u'توئى': u'توئى', #1
u'تويرادبه': u'تويرادبه', #1
u'تويرة': u'تُوَيْرَةِ', #1
u'تويلة': u'تويلة', #1
u'تويلة': u'تَوِيلَةَ', #1
u'تويلة': u'تُوَيْلَةَ', #2
u'تئط،': u'تَئِطَّ،', #2
u'تئط': u'تَئِطَّ', #8
u'تئفة': u'تَئِفَةِ', #1
u'تئوب': u'تَئُوبَ', #3
u'تئول': u'تَئُول', #1
u'تئول': u'تَئُولَ', #1
u'تئول': u'تَئُولُ', #73
u'تئويه': u'تُئْوِيهِ', #1
u'تئيط،': u'تَئِيطَّ،', #1
u'تئيم': u'تَئِيمَ', #1
u'تئيم': u'تَئِيمُ', #5
u'تيأب': u'تَيْأَبَ', #1
u'تيأب': u'تَيْأَبُ', #1
u'تياذوق': u'تَيَاذُوقُ', #1
u'تيام': u'تيام', #1
u'تيام': u'تَيَامُ', #1
u'تيأم': u'تَيْأَمُ', #2
u'تيبة': u'ُتَيْبَةَ', #1
u'تية': u'تَيَّةُ', #1
u'تيت': u'تَيَّتُ', #2
u'تيثم': u'تِيثَمِ', #1
u'تيثم': u'تَيْثَمِ', #1
u'تير': u'تِيَر', #1
u'تيرازين': u'تيرازين', #1
u'تيرح': u'تَيْرَحَ', #1
u'تيرح': u'تَيْرَحِ', #1
u'تيرح': u'تَيْرَح', #7
u'تيركشتي': u'تيركشتي', #1
u'تيرويه': u'تِيرَوَيْهِ', #2
u'تيري': u'تِيرِي', #1
u'تيرى،': u'تِيرَى،', #2
u'تيزين': u'تِيزِينَ', #1
u'تيشل': u'تيشل', #1
u'تيعر': u'تَيْعَرُ', #12
u'تيعر': u'تيعر', #2
u'تيعر': u'تَيْعِرُ', #2
u'تيعر،': u'تَيْعَرُ،', #5
u'تيكم': u'تِيكُمْ', #13
u'تيكم؟': u'تِيكُمْ؟', #6
u'تيلسان': u'تَيْلَسَانَ', #1
u'تيلسان': u'تَيْلَسَانِ', #1
u'تيماءووادي': u'تَيْمَاءَوَوَادِي', #1
u'تيمار': u'تَيْمَارٍ', #2
u'تيمار': u'تَيْمَارٌ', #4
u'تيمار': u'تَيْمَارِ', #6
u'تيمارا': u'تَيْمَارًا', #1
u'تيماردا': u'تيماردا', #1
u'تيماره': u'تَيْمَارِهِ', #6
u'تيمارها': u'تَيْمَارِهَا', #1
u'تيمارهم': u'تَيْمَارِهِمْ', #2
u'تيماري': u'تَيْمَارِيٌّ', #2
u'تيماري': u'تَيْمَارِيٍّ', #4
u'تيماريا': u'تيماريا', #1
u'تيماريا': u'تَيْمَارِيَّا', #1
u'تيمارية': u'تَيْمَارِيَّةٍ', #11
u'تيمارية': u'تَيْمَارِيَّةً', #2
u'تيماريها': u'تَيْمَارِيُّهَا', #1
u'تيماريها': u'تَيْمَارِيِّهَا', #1
u'تيماريين': u'تَيْمَارِيِّينَ', #1
u'تيمبان': u'تيمبان', #2
u'تيمورلنك': u'تَيْمُورْلَنْكْ', #1
u'تيمى': u'تَيْمِىٌّ', #1
u'تيمياء': u'تَيْمِيَاءَ', #1
u'تيهب': u'تَيَّهِبُ', #1
u'تيئفة': u'تَيْئِفَةِ', #1
u'تيئم': u'تَيْئَمِ', #1
u'ثا': u'ثا', #10
u'ثابت': u'ثَابِتً', #1
u'ثابث': u'ثَابِثٌ', #1
u'ثابث': u'ثَابِثٍ', #1
u'ثابث': u'ثَابِثِ', #1
u'ثأجوا': u'ثَأَجُوا', #3
u'ثاره': u'ثَارَهُ', #1
u'ثاري': u'ثَارِي', #1
u'ثاعب': u'ثَاعِبُ', #2
u'ثاعب': u'ثَاعِبٌ', #3
u'ثألا': u'ثَأْلًا', #1
u'ثألاء': u'ثَأْلَاءُ', #1
u'ثالق': u'ثَالِقٌ', #1
u'ثألولة': u'ثَأْلُولَةٍ', #1
u'ثامنوني': u'ثَامِنُونِي', #16
u'ثامنونى': u'ثَامِنُونِى', #2
u'ثانى': u'ثَانِى', #1
u'ثاو': u'ثَاوٍ', #1
u'ثاورا': u'ثاورا', #1
u'ثاوره': u'ثَاوَرَهُ', #1
u'ثاورونا': u'ثَاوَرُونَا', #1
u'ثاويا': u'ثَاوِيًا', #30
u'ثاويا': u'ثَاوِيَا', #6
u'ثاوية': u'ثَاوِيَةٌ', #1
u'ثبار': u'ثِبار', #1
u'ثبار': u'ثِبَارٍ', #1
u'ثبارا': u'ثِبَارًا', #1
u'ثبة': u'ثُبَةٌ', #1
u'ثبج': u'ثَبَج', #1
u'ثبج': u'ثَبَجٌ', #1
u'ثبج': u'ثَبَجٍ', #1
u'ثبج': u'ثَبَجُ', #1
u'ثبج': u'ثَبَجَ', #13
u'ثبج': u'ثَبَجِ', #5
u'ثبطة': u'ثبطة', #1
u'ثبطة': u'ثَبِطَةً', #17
u'ثبطة': u'ثَبِطَة', #3
u'ثبطة': u'ثَبْطَةً', #5
u'ثبون': u'ثِبُونَ', #1
u'ثبى': u'ثُبًى', #1
u'ثبية': u'ثُبَيَّةٌ', #1
u'ثبيت': u'ثَبَّيْتُ', #1
u'ثبيت': u'ثُبَيْتٍ', #1
u'ثبيت،': u'ثُبَيْتٍ،', #1
u'ثبيت': u'ثَبِيتُ', #2
u'ثبيت': u'ثُبَيْتُ', #2
u'ثبيتة': u'ثُبَيْتَةَ', #3
u'ثبيتة': u'ثُبَيْتَةُ', #7
u'ثبير،': u'ثبير،', #1
u'ثبير': u'ثَبيرْ', #1
u'ثبير،': u'ثَبِيرٌ،', #1
u'ثبير،': u'ثَبِيرٍ،', #1
u'ثبير': u'ثَبِيرْ', #2
u'ثبير': u'ثَبِيرُ', #20
u'ثبير': u'ثَبِيرٍ', #27
u'ثبير': u'ثَبِير', #3
u'ثبير': u'ثَبِيرَ', #3
u'ثبير': u'ثَبِيرٌ', #9
u'ثبيرا': u'ثَبِيرًا', #8
u'ثبين': u'ثِبِينَ', #1
u'ثجلة،': u'ثَجْلَةٌ،', #1
u'ثجيج': u'ثَجِيجِ', #1
u'ثجيره': u'ثَجِيرَهُ', #1
u'ثخان': u'ثِخَانٌ', #1
u'ثخانة': u'ثخانة', #1
u'ثخانة': u'ثَخَانَةً', #1
u'ثخانة': u'ثَخَانَةٌ', #1
u'ثخانة': u'ثَخَانَةٍ', #1
u'ثخانة': u'ثَخَانَةَ', #1
u'ثخانة': u'ثَخَانَةُ', #1
u'ثخانة': u'ثَخَانَةِ', #5
u'ثخانته': u'ثَخَانَتَهُ', #3
u'ثخانته': u'ثَخَانَتُهُ', #3
u'ثخانته': u'ثَخَانَتِهِ', #3
u'ثخانتها': u'ثَخَانَتُهَا', #1
u'ثخنا': u'ثَخِنًا', #1
u'ثخنا': u'ثِخَنًا', #3
u'ثخنه': u'ثَخَنِهِ', #1
u'ثخنه': u'ثِخَنِهِ', #1
u'ثخنه': u'ثِخَنُهُ', #2
u'ثخنها': u'ثِخَنُهَا', #1
u'ثخية': u'ثَخِيَّةً', #1
u'ثداء': u'ثِدَاءٍ', #1
u'ثدى': u'ثَدْىٍ', #2
u'ثدى': u'ثَدْىِ', #6
u'ثدية': u'ثُدَيَّةٍ', #1
u'ثديى': u'ثَدْيَىِ', #1
u'ثديى': u'ثَدْيَىَّ', #6
u'ثراة': u'ثُرَاةٍ', #1
u'ثرارة': u'ثَرَّارَةً', #1
u'ثرة': u'ثَرَّةٍ', #1
u'ثرة': u'ثَرّةٍ', #2
u'ثرماء': u'ثَرْمَاءَ', #2
u'ثرملة': u'ثَرْمَلَةَ', #1
u'ثرملة': u'ثَرْمُلَةَ', #1
u'ثرملة': u'ثُرْمُلَةَ', #4
u'ثروان': u'ثروان', #1
u'ثروان': u'ثَرْوَانَ', #16
u'ثروان،': u'ثَرْوَانَ،', #2
u'ثروان،': u'ثروان،', #3
u'ثريدة': u'ثَرِيدَةً', #3
u'ثرير': u'ثُرَيْرٌ', #3
u'ثريناه': u'ثَرَيْنَاهُ', #1
u'ثريناه': u'ثَرَّيْنَاهُ', #1
u'ثريوا': u'ثُرَيْوَا', #1
u'ثط': u'ثَطّ', #1
u'ثط': u'ثَطُّ', #1
u'ثط': u'ثَطٌّ', #3
u'ثظا': u'ثُظَا', #1
u'ثعالة': u'ثُعَالَةٌ', #1
u'ثعالة': u'ثُعَالَةُ', #1
u'ثعالة': u'ثُعَالَةٍ', #2
u'ثعة': u'ثَعَّةً', #2
u'ثعرور': u'ثُعْرُورٌ', #1
u'ثعل': u'ثَعْلُ', #1
u'ثعل': u'ثُعَلَ', #2
u'ثعول': u'ثَعُولٌ', #3
u'ثغار': u'ثَغَارٍ', #1
u'ثغال': u'ثِغَالٌ', #2
u'ثغامة': u'ثُغَامَةً', #1
u'ثغامة': u'ثَغَامَة', #2
u'ثغامة': u'ثَغَامَةً', #3
u'ثغامة': u'ثَغَامَةٌ', #4
u'ثغروا': u'ثَغَرُوا', #1
u'ثغماته': u'ثَغَمَاتِهِ', #1
u'ثغوتها': u'ثَغَوْتهَا', #1
u'ثغول': u'ثَغُولٌ', #1
u'ثغى': u'ثَغَى', #2
u'ثفال': u'ثَفَالٍ', #1
u'ثفال': u'ثُفَالٍ', #1
u'ثفال': u'ثِفِالٍ', #1
u'ثفال': u'ثِفَالٍ', #24
u'ثفال،': u'ثِفَالٍ،', #3
u'ثفالي': u'ثِفَالِي', #1
u'ثفالي،': u'ثِفَالِي،', #1
u'ثفالى': u'ثِفَالِى', #1
u'ثفر': u'ثَفْرَ', #1
u'ثفر': u'ثُفْر', #1
u'ثفر': u'ثَفَرَ', #2
u'ثفر': u'ثَفَرُ', #2
u'ثفر': u'ثُفْرَ', #3
u'ثفره': u'ثَفَرُهُ', #1
u'ثفرها': u'ثَفَّرَهَا', #1
u'ثفروقها': u'ثُفْرُوقُهَا', #6
u'ثفنات': u'ثَفِنَات', #1
u'ثفنات': u'ثَفِنَاتِ', #4
u'ثفنة': u'ثَفَنَةَ', #1
u'ثفنة': u'ثَفِنَة', #1
u'ثفنة': u'ثَفِنَةِ', #1
u'ثفنة': u'ثَفِنَةَ', #5
u'ثقاة': u'ثِقَاةً', #1
u'ثقاة': u'ثِقَاةٌ', #1
u'ثقاة': u'ثِقَاةٍ', #1
u'ثقاة': u'ثِقَاةِ', #1
u'ثقتى': u'ثِقَتِى', #1
u'ثقفى': u'ثَقَفِىٍّ', #1
u'ثقفى': u'ثَقَفِىٌّ', #2
u'ثقفيا': u'ثَقَفِيًّا', #1
u'ثقفيان': u'ثَقَفِيَّانِ', #4
u'ثقفية،': u'ثَقَفِيَّةٌ،', #1
u'ثقلة': u'ثَقَلَةِ', #1
u'ثقلة': u'ثَقْلَةٍ', #1
u'ثقلة': u'ثَقْلَةِ', #1
u'ثقيب': u'ثُقَيْبٍ', #1
u'ثقيفا': u'ثقيفا', #1
u'ثقيفا،': u'ثقيفًا،', #1
u'ثقيفا،': u'ثَقِيفًا،', #1
u'ثقيفا': u'ثَقِيفَا', #2
u'ثقيفا': u'ثَقِيفًا', #56
u'ثقيفة': u'ثَقِيفَةَ', #1
u'ثقيفيا': u'ثَقِيفِيّا', #1
u'ثلاب': u'ثَلَّابَ', #1
u'ثلات': u'ثُلَّاتُ', #1
u'ثلاث': u'ثَلَاثً', #4
u'ثلاثةى': u'ثَلَاثَةٍى', #1
u'ثلاثه': u'ثَلَاثُهُ', #16
u'ثلاثه': u'ثَلَاثِهِ', #17
u'ثلاثه': u'ثلاثه', #2
u'ثلاثه': u'ثَلَاثَهُ', #3
u'ثلاثه': u'ثَلَاثَهْ', #4
u'ثلاثها': u'ثَلَاثِهَا', #2
u'ثلاثين': u'ثَلاَثِينً', #2
u'ثلاثينها': u'ثَلَاثِينِهَا', #1
u'ثلثمائة': u'ثُلْثِمِائَةٍ', #1
u'ثلثمائة': u'ثَلَثَمِائَةٍ', #130
u'ثلثمائة': u'ثلثمائة', #2
u'ثلثمائة': u'ثُلْثَمِائَةٍ', #2
u'ثلثمائة': u'ثَلَثُمِائَةٍ', #247
u'ثلثمائة': u'ثُلْثُمِائَةٍ', #3
u'ثلثمائة': u'ثَلَثمِائَةِ', #4
u'ثلثمائة': u'ثَلَثَمِائَةِ', #40
u'ثلثمائة': u'ثَلَثُمِائَةِ', #63
u'ثلثمائة': u'ثَلَثِمِائَةِ', #77
u'ثلثمائة': u'ثَلَثِمِائَةٍ', #81
u'ثلثى': u'ثُلْثَىْ', #1
u'ثلثى': u'ثُلُثَىْ', #5
u'ثلثى': u'ثُلُثَىِ', #6
u'ثلجم': u'ثَلْجَمَ', #1
u'ثلط': u'ثلط', #3
u'ثلطا': u'ثَلَطًا', #1
u'ثلطا': u'ثَلْطًا', #11
u'ثلطت': u'ثَلَطَتْ', #2
u'ثلماء': u'ثَلْمَاءَ', #2
u'ثم': u'ثُمًّ', #20
u'ثماد': u'ثِمَادِ', #1
u'ثمار': u'ثِمَارً', #1
u'ثمام': u'ثُمَامِ', #1
u'ثمام': u'ثُمَامَ', #2
u'ثمام': u'ثُمَامُ', #2
u'ثمام؟': u'ثُمَامَ؟', #2
u'ثمامه': u'ثُمَامِهِ', #1
u'ثمامها': u'ثُمَامُهَا', #2
u'ثمان': u'ثَمَانً', #1
u'ثمانى': u'ثمانى', #1
u'ثمانى': u'ثَمَانِىَ', #8
u'ثمة': u'ثِمَّةً', #1
u'ثمد': u'ثمد', #1
u'ثمد': u'ثَمَدٍ', #3
u'ثمدخل': u'ثُمَّدَخَلَ', #1
u'ثمرأيناك': u'ثُمَّرَأَيْنَاكَ', #1
u'ثمرد': u'ثَمْرُدُ', #1
u'ثمرستان': u'ثَمَرِسْتَانَ', #1
u'ثمرهاوأشرب': u'ثَمَرِهَاوَأَشْرَبَ', #1
u'ثمعلم': u'ثُمَّعَلِمَ', #1
u'ثمغ': u'ثَمَغٌ', #1
u'ثمغ': u'ثَمْغُ', #1
u'ثمغ': u'ثَمْغٍ', #3
u'ثمغ': u'ثَمْغَ', #4
u'ثمغ': u'ثَمْغٌ', #5
u'ثمغا': u'ثَمَغًا', #2
u'ثمغا': u'ثَمْغًا', #7
u'ثمنة': u'ثَمَنَةَ', #2
u'ثمنة': u'ثَمْنَةَ', #2
u'ثمنيته': u'ثَمَنِيَّتِهِ', #1
u'ثمنيتها': u'ثَمَنِيَّتُهَا', #11
u'ثمنيتها': u'ثَمَنِيَّتِهَا', #11
u'ثمنيتها': u'ثُمْنِيَّتَهَا', #3
u'ثمنيتها': u'ثَمَنِيَّتَهَا', #8
u'ثمنيتهما': u'ثَمَنِيَّتَهُمَا', #2
u'ثمودا': u'ثَمْودَاً', #1
u'ثمودا،': u'ثَمُودَاً،', #1
u'ثميلة،': u'ثمَيْلَةَ،', #1
u'ثميلة': u'ثُمَيْلَةَ', #1
u'ثناهشام': u'ثناهِشَامُ', #1
u'ثناهمام،': u'ثَنَاهمام،', #1
u'ثنتى': u'ثِنْتَىْ', #20
u'ثندوة': u'ثُنْدُوَةٌ', #2
u'ثندوة': u'ثُنْدُوَةِ', #4
u'ثندوته': u'ثُنْدُوَتُهُ', #2
u'ثندوته': u'ثُنْدُوَتِهِ', #3
u'ثندوته': u'ثَنْدُوَتِهِ', #4
u'ثندوتها': u'ثَنْدُوَتِهَا', #2
u'ثندوتها': u'ثُنْدُوَتِهَا', #4
u'ثندوتهم': u'ثَنْدُوَتِهِمْ', #1
u'ثندوتي': u'ثَنْدُوَتِي', #1
u'ثندوتي': u'ثُنْدُوَتَيّ', #1
u'ثندوتي': u'ثَنْدُوَتَيْ', #2
u'ثندوتيه': u'ثَنْدُوَتَيْهِ', #3
u'ثنى': u'ثُنًى', #1
u'ثنى': u'ثِنًى', #5
u'ثنيات': u'ثَنِيَّاتٍ', #1
u'ثنيات': u'ثِنْيَاتُ', #1
u'ثنيات': u'ثَنِيَّاتِ', #4
u'ثوابهالوجه': u'ثَوَابُهُالْوَجْهُ', #1
u'ثؤاج': u'ثُؤَاجٌ', #2
u'ثواليل': u'ثَوَالِيلَ', #1
u'ثوبة': u'ثوبة', #1
u'ثوبة': u'ثَوْبَةَ', #4
u'ثوبى': u'ثَوْبِى', #23
u'ثوبى': u'ثَوْبَىَّ', #6
u'ثوبى': u'ثَوْبَىْ', #6
u'ثؤثر': u'ثُؤْثَرُ', #1
u'ثؤرة': u'ثُؤْرَةً', #1
u'ثؤرتي': u'ثؤرتي', #1
u'ثؤرتي': u'ثُؤْرَتِي', #4
u'ثورى': u'ثُورَى', #1
u'ثؤل': u'ثُؤُلُ', #1
u'ثولاء': u'ثَوْلَاءُ', #1
u'ثويب': u'ثُوَيْبِ', #1
u'ثويب': u'ثُوَيْبٍ', #3
u'ثويبة،': u'ثُوَيْبَةَ،', #1
u'ثويبة': u'ثُوَيْبَةَ', #10
u'ثويبة': u'ثُوَيْبَةُ', #27
u'ثويبة': u'ثُوَيْبَة', #4
u'ثويبة،': u'ثُوَيْبَةُ،', #6
u'ثوير': u'ثوير', #1
u'ثوير': u'ثُوَيْر', #2
u'ثوير': u'ثُوَيْرُ', #2
u'ثوير،': u'ثُوَيْرٌ،', #2
u'ثوير': u'ثُوَيْرٌ', #4
u'ثوير': u'ثُوَيْرٍ', #7
u'ثوير،': u'ثُوَيْرٍ،', #7
u'ثوير': u'ثُوَيْرِ', #8
u'ثويلة': u'ثويلة', #2
u'ثئل': u'ثَئِلَ', #1
u'ثئوب': u'ثُئُوبٌ', #1
u'ثياب': u'ثِيَابً', #1
u'ثيابة': u'ثِيَابَةِ', #1
u'ثيابتها': u'ثِيَابَتِهَا', #1
u'ثيابى': u'ثِيَابِى', #18
u'ثيب': u'ثَيِّبً', #1
u'ثيبة': u'ثِيبَةً', #1
u'ثيبة': u'ثِيبَةٌ', #1
u'ثيبة': u'ثَيِّبَةٌ', #1
u'ثيبة': u'ثَيِّبَةٍ', #1
u'ثيبة': u'ثَيِّبَةً', #2
u'ثيبتين': u'ثِيبَتَيْنِ', #1
u'ثيبتين': u'ثَيِّبَتَيْنِ', #1
u'ثيتل': u'ثيتل', #1
u'ثيوبة': u'ثُيُوبَةً', #1
u'ثيوبة': u'ثُيُوبَةُ', #1
u'ثيوبة': u'ثُيُوبَةٍ', #14
u'ثيوبة': u'ثُيُوبَةَ', #2
u'ثيوبة': u'ثُيُوبَةِ', #5
u'ثيوبته': u'ثُيُوبَتَهُ', #1
u'ثيوبتها': u'ثُيُوبَتُهَا', #17
u'ثيوبتها': u'ثُيُوبَتِهَا', #5
u'ثيوبتها': u'ثُيُوبَتَهَا', #9
u'جا': u'جا', #847
u'جا': u'جَا', #9
u'جاءالنبي': u'جَاءَالنَّبِيَّ', #1
u'جاءتنى': u'جَاءَتْنِى', #5
u'جاءجرحه': u'جَاءَجُرْحَهُ', #1
u'جآءكم': u'جَآءكُمْ', #1
u'جاءنى': u'جَاءَنِى', #32
u'جاءوا': u'جاءوا', #4
u'جاءوا': u'جَاءُوا', #589
u'جاءوك،': u'جَاءُوكَ،', #1
u'جاءوك': u'جَاءُوك', #18
u'جاءوك': u'جاءوك', #2
u'جاءوك': u'جَاءُوكَ', #43
u'جاءوكم': u'جَاءُوكُمْ', #24
u'جاءونا': u'جَاءُونَا', #8
u'جاءونى': u'جَاءُونِى', #1
u'جاءوني': u'جَاءُونِي', #8
u'جاءوه': u'جَاءُوهُ', #26
u'جاءوها': u'جَاءُوهَا', #11
u'جاءوهم': u'جاءوهم', #1
u'جاءوهم': u'جَاءُوهُمْ', #10
u'جأب': u'جَأْبُ', #2
u'جابان،': u'جابان،', #1
u'جابان،': u'جَابَانُ،', #1
u'جابان': u'جَابَانَ', #14
u'جابان': u'جابان', #3
u'جابان،': u'جَابَانَ،', #5
u'جابة': u'جَابَةً', #1
u'جابذني': u'جَابَذَنِي', #1
u'جابرأنه': u'جَابِرٍأَنَّهُ', #1
u'جابرس': u'جَابَرْسَ', #1
u'جابرس': u'جَابَرْسُ', #1
u'جابلسا': u'جَابْلَسَا', #1
u'جابلسا': u'جَابَلْسَا', #2
u'جابلصا': u'جَابَلْصَا', #1
u'جابلق': u'جَابَلْقَ', #1
u'جابلقا': u'جَابْلَقَا', #1
u'جابلقا': u'جَابَلْقَا', #3
u'جابى': u'جَابَى', #1
u'جاحة': u'جَاحَةَ', #1
u'جاحم': u'جَاحِمِ', #1
u'جاحمة': u'جَاحِمَةً', #2
u'جاديا': u'جَادِيًا', #1
u'جاديا': u'جَادِيّا', #2
u'جاذما': u'جَاذِمًا', #1
u'جارSمعنى': u'جَارٍSمَعْنَى', #1
u'جاراستها': u'جَارَاسْتِهَا', #1
u'جارست': u'جَارَسْتَ', #1
u'جارود': u'جَارُودِ', #1
u'جارود': u'جَارُودٍ', #2
u'جارود': u'جَارُودُ', #2
u'جارودا': u'جارودًا', #1
u'جاريةبه': u'جَارِيَةٌبِهِ', #1
u'جاريتى': u'جَارِيَتِى', #8
u'جازع': u'جَازِعٌ', #1
u'جازع': u'جَازِعٍ', #1
u'جاسوم': u'جَاسُومَ', #1
u'جاسوم': u'جَاسُومٌ', #2
u'جاسوم': u'جَاسُومٍ', #2
u'جاسوما': u'جَاسُومًا', #1
u'جاشم': u'جَاشِم', #1
u'جاشم': u'جَاشِمٍ', #1
u'جاشم': u'جَاشِمٌ', #2
u'جاشم': u'جَاشِمُ', #3
u'جاشه': u'جَاشَهُ', #1
u'جاض': u'جَاضَ', #2
u'جاعرتي': u'جَاعِرَتَيَّ', #1
u'جاعرتي': u'جَاعِرَتَيْ', #1
u'جاعرتيه': u'جَاعِرَتَيْهِ', #4
u'جالوتقال': u'جَالُوتَقَالَ', #1
u'جاليا': u'جَالِيًا', #1
u'جالينوس،': u'جالينوس،', #1
u'جالينوس': u'جَالِينُوسُ', #19
u'جالينوس': u'جالينوس', #2
u'جالينوس': u'جَالِينُوسَ', #8
u'جامسا': u'جَامِسًا', #2
u'جامكياتهم': u'جَامِكِيَّاتِهِمْ', #2
u'جامكية': u'جَامَكِيَّةٍ', #15
u'جامكية': u'جَامَكِيَّةَ', #2
u'جامكية': u'جَامَكِيَّةً', #3
u'جامكية': u'جَامَكِيَّةٌ', #8
u'جامكيتك': u'جَامِكِيَّتَك', #1
u'جامكيته': u'جَامَكِيَّتَهُ', #1
u'جامكيته': u'جَامَكِيَّتُهُ', #1
u'جامكيته': u'جَامَكِيَّتِهِ', #1
u'جامكيته': u'جَامِكِيَّتِهِ', #11
u'جامكيتهم': u'جَامِكِيَّتِهِمْ', #1
u'جامكيتهم': u'جَامِكِيَّتَهُمْ', #2
u'جامهء': u'جامهء', #1
u'جامون': u'جَامّونَ', #1
u'جانأ': u'جَانَأَ', #1
u'جأنبأ': u'جَأنِبًأ', #1
u'جانبى': u'جانبى', #1
u'جانبى': u'جَانَبِى', #1
u'جانبى': u'جَانِبَىِ', #1
u'جاهاتهم': u'جَاهَاتِهِمْ', #1
u'جاهان': u'جَاهَانِ', #1
u'جاهمة': u'جاهمة', #1
u'جاهمة': u'جَاهِمَةَ', #15
u'جاهمة': u'جَاهِمَةُ', #3
u'جاؤا': u'جَاؤُا', #3
u'جأواء': u'جَأْوَاء', #1
u'جأواء': u'جَأْوَاءَ', #1
u'جأواء': u'جَأْوَاءُ', #1
u'جاوان': u'جاوان', #1
u'جاوان،': u'جاوان،', #1
u'جاوان': u'جَاوَانَ', #2
u'جاوان،': u'جَاوَانَ،', #2
u'جاوته': u'جَاوَتْهُ', #1
u'جاوزتبه': u'جَاوَزْتَبِهِ', #1
u'جاؤك': u'جَاؤُكَ', #1
u'جآؤوا': u'جَآؤُوا', #1
u'جآؤوك': u'جَآؤُوكَ', #4
u'جآؤوكم': u'جَآؤُوكُمْ', #2
u'جأوى': u'جَأْوَى', #3
u'جاويش': u'جَاوِيشٍ', #2
u'جائز': u'جَائِزً', #3
u'جائزو': u'جَائِزُو', #1
u'جايكاه': u'جايكاه', #2
u'جايئة،': u'جَاِيَئةٌ،', #1
u'جبأت': u'جَبَأَتْ', #1
u'جباحها': u'جباحها', #1
u'جباليا': u'جباليا', #1
u'جبجاب': u'جِبْجَابٌ', #1
u'جبجاب': u'جَبْجَابِ', #3
u'جبجب': u'جَبْجَبٍ', #1
u'جبجبة': u'جَبْجَبَةً', #1
u'جبجبة': u'جَبْجَبَةٌ', #1
u'جبجبة': u'جُبْجُبَةٌ', #1
u'جبذة': u'جَبْذَةٌ', #1
u'جبذة': u'جَبْذَةً', #10
u'جبرانا': u'جُبْرَانًا', #71
u'جبرانات': u'جُبْرَانَات', #1
u'جبرانات': u'جُبْرَانَاتُ', #1
u'جبرانات': u'جُبْرَانَاتِ', #2
u'جبرانات': u'جُبْرَانَاتٍ', #79
u'جبرانان': u'جُبْرَانَانِ', #2
u'جبرانين': u'جُبْرَانَيْنِ', #38
u'جبرائيل': u'جبرائيل', #1
u'جبرائيل': u'جِبْرَائِيلَ', #1
u'جبرائيل': u'جَبْرَائِيلَ', #45
u'جبرائيل': u'جَبْرَائِيلُ', #72
u'جبربل': u'جِبْرِبلُ', #1
u'جبرتين': u'جَبْرَتَيْنِ', #1
u'جبرعبد،': u'جِبْرِعَبْدٌ،', #1
u'جبرون': u'جَبْرُونٍ', #1
u'جبرون': u'جَبْرُونَ', #1
u'جبرئيل': u'جبرئيل', #1
u'جبرئيل': u'جَبْرَئِيلَ', #1
u'جبرئيل': u'جِبْرَئِيلَ', #1
u'جبرئيل': u'جَبْرَئِيلُ', #2
u'جبريلتلا': u'جِبْرِيلُتَلا', #1
u'جبرين': u'جبرين', #1
u'جبرين': u'جَبْرِينَ', #1
u'جبرين': u'جِبْرِينُ', #1
u'جبرين،': u'جِبْرِينَ،', #1
u'جبرين': u'جِبْرِينَ', #2
u'جبص': u'جَبْصِ', #1
u'جبص': u'جبص', #2
u'جبلعن': u'جَبَلٍعَنْ', #1
u'جبلنى': u'جَبَلَنِى', #2
u'جبلى': u'جَبَلَىْ', #3
u'جبنة': u'جُبْنَةً', #3
u'جبنة': u'جُبْنَةٌ', #3
u'جبنيته': u'جُبْنِيَّتِهِ', #1
u'جبهتى': u'جَبْهَتِى', #1
u'جبوب': u'جَبُوبِ', #1
u'جبوب': u'جَبُوبٌ', #2
u'جبوبة': u'جَبُوبَةً', #1
u'جبوبة': u'جَبُوبَةٌ', #1
u'جبوت': u'جُبُوتٌ', #2
u'جبير،': u'جُبير،', #1
u'جبير،': u'جَبِيرٍ،', #1
u'جبير،': u'جُبَيرٍ،', #1
u'جبير،': u'جُبَيْرَ،', #1
u'جبير،': u'جُبَيْرِ،', #1
u'جبير؟': u'جُبَيْرٍ؟', #1
u'جبير،': u'جُبَيْرٍ،', #1606
u'جبير': u'جُبير', #2
u'جبير،': u'جُبَيْرٌ،', #2
u'جبير،': u'جبير،', #20
u'جبير': u'جُبَيْرٌ', #21
u'جبير': u'جُبَيْر', #25
u'جبير': u'جُبَيْرٍ', #2700
u'جبير،': u'جُبَير،', #3
u'جبير': u'جُبَيْرَ', #38
u'جبير،': u'جُبَيْر،', #4
u'جبير': u'جبير', #47
u'جبير': u'جُبَيْرِ', #658
u'جبير': u'جُبَيْرُ', #67
u'جبير': u'جُبَير', #9
u'جبيرا،': u'جُبَيْرًا،', #1
u'جبيرا': u'جُبَيْرًا', #2
u'جبير،أن': u'جُبَيْرٍ،أَنَّ', #2
u'جبيرأيرى': u'جُبَيْرٍأَيَرَى', #1
u'جبيربجمع': u'جُبَيْرٍبِجَمْعٍ', #1
u'جبيرة': u'جَبِيرَةُ', #1
u'جبيرة': u'جُبَيْرَةُ', #1
u'جبيرة،': u'جُبَيْرَةَ،', #1
u'جبيرة': u'جُبَيْرَةَ', #16
u'جبيرة،': u'جَبِيرَةَ،', #2
u'جبيرة': u'جَبِيرَةً', #26
u'جبيرة': u'جَبِيرَةٌ', #26
u'جبيرة': u'جَبِيرَةَ', #28
u'جبيرة': u'جبيرة', #3
u'جبيرة': u'جَبِيرَةِ', #7
u'جبيرة': u'جَبِيرَةٍ', #71
u'جبيرتان': u'جَبِيرَتَانِ', #7
u'جبيرته': u'جَبِيرَتُهُ', #15
u'جبيرته': u'جَبِيرَتِهِ', #18
u'جبيرته': u'جَبِيرَتَهُ', #6
u'جبيرتها': u'جَبِيرَتِهَا', #3
u'جبيرثم': u'جُبَيْرٍثُمَّ', #1
u'جبير،ثم': u'جُبَيْرٍ،ثُمَّ', #1
u'جبيرعظيما': u'جُبَيْرٍعَظِيمًا', #1
u'جبيرعن': u'جُبَيْرٍعَنْ', #1
u'جبير،عن': u'جُبَيْرٍ،عَنْ', #1
u'جبيرفلما': u'جُبَيْرٍفَلَمَّا', #2
u'جبيرفي': u'جُبَيْرٍفِي', #1
u'جبير،في': u'جُبَيْرٍ،فِي', #175
u'جبيرقال': u'جُبَيْرٍقَالَ', #1
u'جبير،قال': u'جُبَيْرٍ،قَالَ', #1
u'جبير،قوله': u'جُبَيْرٍ،قوله', #1
u'جبير،قوله': u'جُبَيْرٍ،قَوْلُهُ', #7
u'جبيرما': u'جُبَيْرٍمَا', #1
u'جبير،وأن': u'جُبَيْرٍ،وأَنَّ', #1
u'جبير،يعني': u'جُبَيْرٍ،يَعْنِي', #1
u'جبيريعنى': u'جُبَيْرٍيَعْنِى', #1
u'جبيل': u'جُبَيْلٌ', #1
u'جبيل': u'جُبَيْلٍ', #1
u'جبيلا': u'جُبَيْلًا', #1
u'جبيلات': u'جُبَيْلَاتِ', #1
u'جبيلة': u'جُبَيْلَةَ', #4
u'جبيلة': u'جُبَيْلَة', #5
u'جبينة': u'جَبِينَةً', #1
u'جة': u'ُجَّةٌ', #1
u'جثاء': u'جُثَاءُ', #1
u'جثاء': u'جُثَاءِ', #1
u'جثامة': u'جثامة', #1
u'جثامة': u'جَثَّامة', #1
u'جثامة': u'جَثَّامَةَ', #146
u'جثامة': u'جَثّامَةَ', #27
u'جثامة': u'جَثَّامَة', #3
u'جثامة،': u'جَثَّامَةَ،', #5
u'جثجاث': u'جَثْجَاثٌ', #1
u'جثل': u'جَثْلِ', #1
u'جثوما': u'جُثُومًا', #1
u'جثومه': u'جُثُومِهِ', #1
u'جثى': u'جَثَى', #1
u'جثى': u'جُثًى', #1
u'جثى': u'جُثَى', #1
u'جثيل': u'جَثِيلِ', #1
u'جج': u'جج', #2
u'جحاجح': u'جَحَاجِحِ', #1
u'جحاجح': u'جَحَاجِحْ', #2
u'جحادة': u'جحادة', #2
u'جحادة،': u'جَحَادَةَ،', #2
u'جحادة،': u'جحادة،', #3
u'جحادة،': u'جُحَادَةَ،', #32
u'جحادة': u'جُحَادَةَ', #64
u'جحاف': u'جَحَّافُ', #1
u'جحجاح': u'جَحْجَاحٍ', #2
u'جحجبا': u'جحجبا', #2
u'جحجبا،': u'جَحْجَبَا،', #2
u'جحجبا': u'جَحْجَبَا', #3
u'جحجبي': u'جَحْجَبِي', #1
u'جحجبى': u'جَحْجَبِىّ', #1
u'جحجبى': u'جَحْجَبَى', #12
u'جحجبي': u'جَحْجَبِيّ', #3
u'جحدب': u'جحدب', #1
u'جحدب،': u'جَحْدَبٍ،', #1
u'جحدر': u'جَحْدَرٌ', #1
u'جحدر': u'جُحْدَرٍ', #1
u'جحدر': u'جُحْدُرٍ', #1
u'جحدر': u'جَحْدَرٍ', #2
u'جحدر': u'جَحْدَرِ', #2
u'جحدر،': u'جَحْدَرٌ،', #5
u'جحدرة': u'جَحْدَرَةَ', #1
u'جحدم': u'جَحْدَم', #1
u'جحدم،': u'جَحْدَم،', #1
u'جحدم،': u'جَحْدَمٍ،', #2
u'جحدم': u'جَحْدَمِ', #3
u'جحدم': u'جَحْدَمٌ', #4
u'جحدم': u'جَحْدَمُ', #4
u'جحدم': u'جَحْدَمٍ', #8
u'جحدنيها': u'جَحَدَنِيهَا', #5
u'جحرة': u'جُحْرَةِ', #1
u'جحرى': u'جُحْرَىْ', #1
u'جحط': u'جحط', #10
u'جحظ': u'جَحْظِ', #1
u'جحظت': u'جَحَظَتْ', #1
u'جحف': u'جَحَفَ', #3
u'جحفة': u'جُحْفَةٍ', #1
u'جحفة': u'جَحْفَةَ', #2
u'جحفة': u'جُحْفَةً', #2
u'جحفة': u'جُحْفَةٌ', #2
u'جحفة،': u'جَحَفَةً،', #2
u'جحفة': u'جُحْفَةَ', #3
u'جحفة': u'جُحْفَةُ', #4
u'جحفتك؟': u'جَحَفَتُكَ؟', #1
u'جحل': u'جَحْلُ', #1
u'جحل،': u'جَحْلٍ،', #1
u'جحل': u'جَحْلٌ', #2
u'جحل': u'جَحْلٍ', #3
u'جحلا': u'جَحْلًا', #1
u'جحم': u'جحم', #1
u'جحم': u'جَحْمَ', #1
u'جحم': u'جَحْمُ', #1
u'جحونا': u'جَحُونَا', #2
u'جحية': u'جَحْيَةَ', #1
u'جحير،': u'جُحَيْرٍ،', #1
u'جحير': u'جُحَيْرِ', #2
u'جحيفة': u'جُحَيفة', #1
u'جحيفة': u'جُحَيْفة', #1
u'جحيفة،': u'جُحَيْفة،', #1
u'جحيفة': u'جُحَيْفَةَ', #195
u'جحيفة': u'جحيفة', #2
u'جحيفة،': u'جُحَيْفَةَ،', #31
u'جخ': u'جَخَّ', #9
u'جخا': u'جَخًّا', #1
u'جخا': u'جَخَّا', #1
u'جخى': u'جَخَّى', #4
u'جخيفه': u'جَخِيفَهُ', #1
u'جد': u'جَدًّ', #1
u'جدابته': u'جَدَابَتُهُ', #1
u'جدامة': u'جُدّامَةُ', #1
u'جدامة،': u'جُدَامَةَ،', #1
u'جدامة': u'جُدَامَةَ', #22
u'جدامة': u'جُدَامَة', #5
u'جدامة': u'جُدَامَةُ', #6
u'جداية': u'جِدَايَةٌ', #1
u'جداية': u'جِدَايَةُ', #1
u'جداية': u'جَدَايَةُ', #3
u'جدبة،': u'جدبة،', #1
u'جدبة،': u'جَدْبَةٍ،', #1
u'جدبة': u'جَدْبَةً', #4
u'جدبة': u'جَدْبَةٌ', #8
u'جدتاى': u'جَدَّتَاىَ', #2
u'جدتى': u'جَدَّتِى', #15
u'جدحه': u'جَدَحَهُ', #1
u'جددتيه': u'جَدَّدْتِيهِ', #1
u'جددتيه': u'جَدَدْتِيهِ', #5
u'جدرات': u'جَدَرَاتٍ', #1
u'جدرات': u'جَدَرَاتِ', #1
u'جدرات': u'جُدُرَاتِ', #1
u'جدراته': u'جُدْرَاتُهُ', #1
u'جدرة': u'جَدَرَةُ', #1
u'جدرى': u'جُدَرِىٍّ', #1
u'جدرى': u'جُدُرِى', #2
u'جدعة': u'جَدْعَةً', #1
u'جدعة،': u'جَدِعَةً،', #1
u'جدكا': u'جَدَكًا', #1
u'جدكه': u'جَدَكِهِ', #1
u'جدلاء': u'جَدْلَاءُ', #1
u'جدلاء': u'جَدْلَاءَ', #4
u'جدوبة': u'جُدُوبَةٌ', #2
u'جدودة': u'جُدُودَةٌ', #4
u'جدور': u'جُدُورٍ', #1
u'جدورها': u'جَدُورُهَا', #2
u'جدورها': u'جُدُورُهَا', #2
u'جدوى': u'جَدْوًى', #1
u'جدى': u'جدى', #1
u'جدى': u'جَدِّىَ', #1
u'جدى': u'جَدْىٌ', #1
u'جدى': u'جَدْىُّ', #1
u'جدى': u'جِدِّى', #1
u'جدى': u'جَدَّى', #2
u'جدى': u'جَدِّى', #358
u'جديب': u'جَدِيبُ', #2
u'جديبة': u'جَدِيبَةً', #1
u'جديبة': u'جَدِيبَةٍ', #1
u'جديس': u'جُدَيْسُ', #1
u'جديس': u'جَدِيسٍ', #2
u'جديسا': u'جَدِيسًا', #1
u'جديمة': u'جَدِيمة', #1
u'جدين': u'جَدَّيْنِ', #6
u'جذامة': u'جُذَامَة', #1
u'جذامة': u'جُذَامَةُ', #3
u'جذامة': u'جُذَامَةَ', #6
u'جذة': u'جَذَّةٌ', #1
u'جذة': u'جَذَّةٍ', #2
u'جذذتيه': u'جَذَذْتِيهِ', #4
u'جذعاء': u'جَذْعَاء', #1
u'جذعات': u'جَذَعَاتٍ', #10
u'جذعات': u'جَذَعَاتٌ', #7
u'جذعة': u'جَذَعةٍ', #1
u'جذعة': u'جَذَعَةًََََ', #1
u'جذعة': u'جَذْعَةٍ', #1
u'جذعة': u'جَذَعَة', #10
u'جذعة': u'جَذَعَةِ', #10
u'جذعة': u'جَذَعَةَ', #11
u'جذعة': u'جَذَعَةُ', #13
u'جذعة': u'جذعة', #2
u'جذعة،': u'جَذَعَةً،', #2
u'جذعة،': u'جَذَعَةٍ،', #2
u'جذعة': u'جَذَعَةٌ', #205
u'جذعة': u'جَذَعَةً', #216
u'جذعة': u'جَذَعَةٍ', #54
u'جذعة،': u'جَذَعَةٌ،', #8
u'جذعتان': u'جَذَعَتَانِ', #3
u'جذعتين': u'جَذَعَتَيْنِ', #10
u'جذيتيه': u'جَذَيْتِيهِ', #1
u'جذيعة': u'جُذَيْعَة', #1
u'جذيلها': u'جُذَيْلها', #1
u'جذيلها': u'جُذَيْلُهَا', #8
u'جرءاء': u'جُرَءَاءُ', #3
u'جرءوك': u'جَرَّءُوكَ', #1
u'جرآء': u'جُرَآءُ', #1
u'جرأتى': u'جُرْأَتِى', #1
u'جراخيانت': u'جراخيانت', #1
u'جرادات': u'جَرَادَاتٍ', #7
u'جراز': u'جُرَازٌ', #1
u'جراش': u'جِرَاشِ', #1
u'جرامكة': u'جَرَامِكَةٍ', #1
u'جرامون': u'جَرّامُونَ', #2
u'جراى': u'جَرَّاىَ', #1
u'جراي': u'جَرَّايَ', #6
u'جرائره': u'جَرَائِرَهُ', #2
u'جرائرهم': u'جَرَائِرُهُمْ', #2
u'جرايات': u'جِرَايَاتٍ', #1
u'جرايتهم': u'جِرَايَتَهُمْ', #2
u'جرباش': u'جُرُبَاشٍ', #1
u'جرباش': u'جُرُبَاشَ', #3
u'جرباش': u'جِرْبَاشٍ', #3
u'جرباش': u'جِرْبَاشَ', #4
u'جربز': u'جَرْبَزَ', #1
u'جربز': u'جُرْبُزٌ', #1
u'جربزة': u'جَرْبَزَةٌ', #1
u'جرتبه': u'جَرَتْبِهِ', #1
u'جرجان،': u'جُرْجان،', #1
u'جرجان': u'جُرْجَان', #1
u'جرجان': u'جُرْجَانِ', #1
u'جرجان،': u'جُرْجَان،', #1
u'جرجان': u'جُرْجَانَ', #12
u'جرجانى': u'جُرْجَانِىٌّ', #1
u'جرجمت': u'جُرْجِمَتْ', #1
u'جرجمت': u'جَرْجَمَتْ', #3
u'جرجير': u'جرجير', #1
u'جرجير': u'جُرجير', #1
u'جرجير': u'جُرْجِيرٌ', #1
u'جرجير': u'جُرْجِيرٍ', #1
u'جرجير': u'جِرْجِيرٌ', #1
u'جرجير': u'جِرْجِيرٍ', #2
u'جرجير': u'جُرْجير', #3
u'جرجيرا': u'جِرْجِيرًا', #1
u'جرجيريا': u'جَرْجِيرِيًّا', #1
u'جرجيس': u'جُرْجَيْسُ', #1
u'جرحتين': u'جَرْحَتَيْنِ', #1
u'جرحنى': u'جَرَحَنِى', #1
u'جرخ': u'جرخ', #1
u'جرخ': u'جَرْخٍ', #1
u'جردحل': u'جِرْدَحْلٍ', #2
u'جردقة': u'جَرْدَقَةً', #1
u'جردل': u'جَرْدَلٍ', #1
u'جرشع': u'جُرْشُعٍ', #1
u'جرشينهاهم': u'جُرَشٍيَنْهَاهُمْ', #1
u'جرصن': u'جرصن', #1
u'جرصن': u'جَرْصَنٍ', #2
u'جرصنا': u'جُرْصُنًا', #10
u'جرضا': u'جَرْضًا', #1
u'جرمة': u'جَرِمَةٍ', #1
u'جرمة': u'جَرْمَةَ', #1
u'جرمة': u'جُرْمَةٌ', #1
u'جرمعد': u'جرمعد', #1
u'جرمقاني': u'جُرْمقَانِيّ', #1
u'جرمقاني': u'جُرْمُقَانِيّ', #1
u'جرمقاني': u'جُرْمُقَانِيٌّ', #1
u'جرمقانيان': u'جُرْمُقَانِيَّانِ', #1
u'جرموز': u'جَرْمُوزٍ', #1
u'جرموز،': u'جُرْمُوز،', #1
u'جرموز،': u'جُرْمُوزٍ،', #1
u'جرموز،': u'جُرْمُوزَ،', #2
u'جرموز': u'جُرْمُوزَ', #3
u'جرموز': u'جرموز', #4
u'جرموز': u'جُرْمُوز', #7
u'جرموز': u'جُرْمُوزٍ', #8
u'جرموزا': u'جَرْمُوزًا', #1
u'جرموق': u'جُرْمُوقَ', #1
u'جرموق': u'جُرْمُوقٍ', #10
u'جرموق': u'جُرْمُوقٌ', #8
u'جرموقا': u'جُرْمُوقًا', #5
u'جرموقان': u'جُرْمُوقَانِ', #7
u'جرموقه': u'جُرْمُوقَهُ', #1
u'جرموقين': u'جُرْمُوقَيْنِ', #2
u'جرموقيه': u'جُرْمُوقَيْهِ', #5
u'جرهد': u'جرهد', #1
u'جرهد،': u'جَرْهَدَ،', #1
u'جرهد': u'جَرْهَدٌ', #2
u'جرهد': u'جَرْهَدٍ', #35
u'جرهد': u'جَرْهَدُ', #4
u'جرهد،': u'جَرْهَدٍ،', #8
u'جرهدا،': u'جَرْهَدًا،', #1
u'جرهدا': u'جَرْهَدًا', #4
u'جرهزي': u'جَرْهَزِيٌّ', #1
u'جرهم': u'جُرْهُمً', #3
u'جرهما': u'جُرْهُمًا', #15
u'جرهمي': u'جُرْهُمِيُّ', #1
u'جرهمي': u'جُرْهُمِيٌّ', #9
u'جرهميا': u'جُرْهُمِيّا', #1
u'جرهمية': u'جُرْهُمِيّةٌ', #2
u'جروب': u'جُرُوبٌ', #1
u'جروة': u'جِرْوَةُ', #1
u'جروة': u'جِرْوَةِ', #1
u'جروة': u'جَرْوَةَ', #7
u'جروحاته': u'جُرُوحَاتِهِ', #1
u'جرول': u'جرول', #1
u'جرول،': u'جرول،', #1
u'جرول': u'جَرْوَل', #1
u'جرول': u'جَرْوَلٌ', #1
u'جرول': u'جَرْوَلُ', #1
u'جرول': u'جِرْوَلٍ', #1
u'جرول': u'جَرْوَلَ', #6
u'جرول': u'جَرْوَلٍ', #7
u'جرون': u'جُرُونُ', #1
u'جرون': u'جُرُونٌ', #2
u'جرون': u'جُرُونِ', #2
u'جرىء': u'جَرِىءٌ', #2
u'جرياته': u'جَرْيَاتُهُ', #1
u'جريال': u'جِرْيَالِ', #1
u'جريب': u'جَرِيب', #1
u'جريب،': u'جَرِيب،', #1
u'جريب': u'جَرِيبٌ', #11
u'جريب': u'جَرِيبَ', #5
u'جريب': u'جَرِيبُ', #8
u'جريب': u'جَرِيبٍ', #97
u'جريب': u'جَرِيبِ', #98
u'جريبا': u'جَرِيبًا', #38
u'جريبان': u'جَرِيبَانِ', #5
u'جريبك': u'جَرِيبَكَ', #1
u'جريبهم': u'جَرِيبِهِمْ', #3
u'جريبين': u'جَرِيبَيْنِ', #10
u'جريثا': u'جِرِّيثًا', #1
u'جريثة': u'جِرِّيثَةً', #2
u'جريج': u'جُرَيجٍ', #1
u'جريج': u'جُريْج', #1
u'جريج،': u'جُرَيج،', #1
u'جريج،': u'جُريْج،', #1
u'جريج،': u'جُرَيْج،', #1
u'جريج،': u'جُرَيْجِ،', #1
u'جريج،،': u'جُرَيْجٍ،،', #1
u'جريج،': u'جُرَيْجٍ،', #1298
u'جريج': u'جريج', #16
u'جريج': u'جُرَيْج', #2
u'جريج،': u'جريج،', #20
u'جريج': u'جُرَيْجٌ', #20
u'جريج': u'جُرَيْجُ', #22
u'جريج؟': u'جُرَيْجٍ؟', #3
u'جريج': u'جُرَيْجٍ', #3579
u'جريجا': u'جُرَيْجًا', #6
u'جريج،أن': u'جُرَيْجٍ،أَنَّ', #1
u'جريجفي': u'جُرَيْجٍفِي', #1
u'جريج،في': u'جُرَيْجٍ،فِي', #8
u'جريج،قوله': u'جُرَيْجٍ،قَوْلُهُ', #4
u'جريداء': u'جُرَيْدَاءِ', #2
u'جريش': u'جريش', #1
u'جريشا': u'جَرِيشًا', #3
u'جريشها': u'جَرِيشُهَا', #1
u'جريضا': u'جَرِيضًا', #1
u'جرينا': u'جَرِينًا', #4
u'جزء': u'جُزْءً', #2
u'جزءاوالوجه': u'جُزْءًاوَالْوَجْهُ', #2
u'جزءه': u'جُزْءَهُ', #1
u'جزءها': u'جُزْءَهَا', #1
u'جزءوا': u'جَزّءُوا', #1
u'جزءوها': u'جَزَّءُوهَا', #1
u'جزءين': u'جُزْءَيْنِ', #3
u'جزأ': u'جُزَأً', #2
u'جزاءة': u'جَزَاءَةِ', #1
u'جزاءة': u'جَزَاءَةَ', #2
u'جزارى': u'جُزَارَى', #1
u'جزافان': u'جِزَافَانِ', #1
u'جزافان': u'جُزَافَانِ', #10
u'جزافين': u'جُزَافَيْنِ', #5
u'جزآن': u'جُزْآنِ', #4
u'جزاه': u'جًزًاهُ', #1
u'جزآؤهم': u'جَزَآؤُهُم', #1
u'جزآؤهم': u'جَزَآؤُهُمْ', #1
u'جزرة،': u'جزرة،', #1
u'جزرة': u'جَزَرَةٌ', #1
u'جزرة': u'جَزَرَةً', #2
u'جزرة': u'جَزْرَةٌ', #2
u'جزرة': u'جَزَرَةَ', #5
u'جزرة': u'جَزَرَةُ', #7
u'جزرف': u'جَزْرَفَ', #1
u'جزعى': u'جَزَعِى', #1
u'جزماء': u'جَزْمَاءَ', #1
u'جزورة': u'جَزُورَةً', #1
u'جزى': u'جِزَىً', #1
u'جزى': u'جِزًى', #5
u'جزئين': u'جُزْئَيْنِ', #1
u'جزيات': u'جِزْيَاتٌ', #1
u'جزيزة،': u'جزيزةٍ،', #1
u'جزيعة': u'جُزَيْعَة', #1
u'جزيعة': u'جُزَيْعَةٍ', #1
u'جسأ': u'جَسَأَ', #1
u'جسأتها': u'جُسْأَتَهَا', #1
u'جساما': u'جُسَامًا', #1
u'جساوة': u'جَسَاوَةٍ', #3
u'جسة': u'جسة', #1
u'جسة': u'جِسَةً', #1
u'جسة': u'جَسَّةٍ', #2
u'جستاس': u'جَسْتَاسٍ', #2
u'جسسه': u'جَسَّسَهُ', #1
u'جسق': u'جسق', #1
u'جسق': u'جَسَقٌ', #1
u'جسمى': u'جِسْمِى', #1
u'جسوس': u'جَسُّوسُ', #2
u'جسيدهما': u'جَسِيدُهُمَا', #2
u'جسير،': u'جَسِيرٍ،', #1
u'جشب': u'جَشِبَ', #1
u'جشر': u'جَشَرَ', #3
u'جشرته': u'جَشْرَته', #1
u'جشره': u'جُشُره', #1
u'جشره': u'جَشْرِهِ', #1
u'جشره،': u'جَشَرِهِ،', #2
u'جشره': u'جَشَرِهِ', #4
u'جشعم': u'جَشْعَمٍ', #1
u'جشكا': u'جُشْكًا', #1
u'جشنس': u'جِشْنِسَ', #1
u'جشيب': u'جشيب', #1
u'جشيب': u'جَشِيبٌ', #1
u'جشيب،': u'جَشِيبٍ،', #1
u'جشيب': u'جُشَيْبٍ', #1
u'جشيب': u'جَشِيبٍ', #5
u'جشيش': u'جُشَيْشُ', #1
u'جشيشة': u'جَشِيشَةٍ', #2
u'جشيشتك': u'جَشِيشَتِكَ', #1
u'جشيشتك': u'جُشَيْشَتك', #1
u'جشيشتك': u'جَشِيشَتِك', #2
u'جعار': u'جِعَارٍ', #1
u'جعال': u'جُعَالٍ', #1
u'جعال': u'جِعَالُ', #1
u'جعال': u'جُعَالَ', #2
u'جعال': u'جُعَالِ', #2
u'جعال': u'جُعَالُ', #4
u'جعال': u'جِعَالٍ', #7
u'جعالة': u'جَعَالَةُ', #1
u'جعالة': u'جِعَالَةُ', #1
u'جعالة': u'جِعَالَةِ', #1
u'جعالة': u'جِعَالَةً', #16
u'جعالة': u'جِعَالَةٍ', #22
u'جعالة': u'جِعَالَةٌ', #26
u'جعالة': u'جِعَالَة', #4
u'جعالة': u'جَعَالَةً', #74
u'جعالة': u'جَعَالَةٌ', #81
u'جعالة': u'جَعَالَةٍ', #90
u'جعالته': u'جَعَالَتَهُ', #1
u'جعالته': u'جَعَالَتِهِ', #3
u'جعالتها': u'جَعَالَتِهَا', #1
u'جعائل': u'جَعَائِلُ', #2
u'جعثل': u'جُعْثُلٌ', #1
u'جعثل': u'جُعْثُلٍ', #2
u'جعثمة': u'جِعْثِمَةَ', #1
u'جعثمة': u'جُعْثُمَةَ', #13
u'جعثمة': u'جُعْثُمَةُ', #6
u'جعداء': u'جَعْدَاءُ', #3
u'جعدبة،': u'جُعْدُبَةَ،', #1
u'جعدبة': u'جَعْدَبَةَ', #2
u'جعدبة': u'جُعْدُبَةَ', #3
u'جعدر': u'جَعْدِرْ', #1
u'جعران': u'جُعْرَانَ', #1
u'جعران': u'جِعْرَانٍ', #1
u'جعران': u'جِعْرَانَ', #2
u'جعرانة': u'جِعْرَانَةٌ', #2
u'جعرانة': u'جِعْرَانَةَ', #3
u'جعرانة': u'جِعْرَانَةُ', #3
u'جعرانة': u'جِعِرَّانَةَ', #6
u'جعرانه': u'جِعْرَانُهُ', #1
u'جعرانه': u'جِعْرَانَهْ', #12
u'جعرور': u'جُعْرُورٍ', #1
u'جعرورا': u'جُعْرُورًا', #4
u'جعشم،': u'جَعْشم،', #1
u'جعشم': u'جُعْشُمَ', #1
u'جعشم': u'جُعْشُمِ', #1
u'جعشم،': u'جُعْشُمٍ،', #10
u'جعشم': u'جُعشُم', #2
u'جعشم': u'جَعْشَمٍ', #2
u'جعشم،': u'جُعْشُمَ،', #3
u'جعشم': u'جُعْشُمٍ', #88
u'جعظري،': u'جَعْظَرِيٌّ،', #1
u'جعظرى': u'جَعْظَرِىٍّ', #1
u'جعظري': u'جَعْظَرِيٍّ', #13
u'جعفرا': u'جعفرا', #1
u'جعفرا': u'جعفرًا', #1
u'جعفرا،': u'جَعْفَرًا،', #1
u'جعفرا': u'جَعْفَرًا', #64
u'جعفرهذا': u'جَعْفَرٍهَذَا', #1
u'جعفرولا': u'جَعْفَرٍوَلَا', #1
u'جعفي': u'جعفي', #1
u'جعفي': u'جُعْفِيٌّ', #1
u'جعفي،': u'جُعْفِيٍّ،', #1
u'جعفي': u'جُعْفِيٍّ', #11
u'جعفى': u'جُعْفَى', #2
u'جعفي': u'جُعْفِيّ', #3
u'جعفى': u'جُعْفِىٍّ', #3
u'جعفيا': u'جُعْفِيًّا', #1
u'جعلة': u'جُعْلَةً', #1
u'جعلتلي': u'جُعِلَتْلِيَ', #1
u'جعلتنى': u'جَعَلَتْنِى', #1
u'جعلتيه': u'جَعَلْتِيهِ', #1
u'جعلنى': u'جَعَلَنِى', #15
u'جعلونى': u'جَعَلُونِى', #1
u'جعوان': u'جِعْوَانِ', #1
u'جعوان': u'جِعْوَانَ', #3
u'جعور': u'جَعْوَر', #1
u'جعونة': u'جَعُونَةَ', #1
u'جعونة': u'جَعْوَنَةُ', #1
u'جعونة': u'جَعُونَةُ', #2
u'جعونة': u'جَعْوَنَةَ', #3
u'جعيد': u'جُعَيْدٌ', #1
u'جعيد': u'جُعَيْدِ', #1
u'جعيل': u'جعيل', #1
u'جعيل': u'جُعَيْلِ', #1
u'جعيل': u'جُعَيْلُ', #3
u'جعيل': u'جُعَيْلٌ', #5
u'جعيل': u'جُعَيْلٍ', #8
u'جعيل': u'جُعَيْلَ', #9
u'جعيلا': u'جُعَيْلًا', #1
u'جعيلة': u'جَعِيلَةٌ', #1
u'جعيلة': u'جَعِيلَةِ', #1
u'جعيلة': u'جَعِيلَةٍ', #3
u'جغد': u'جغد', #1
u'جغرات': u'جغرات', #1
u'جغزباره': u'جغزباره', #1
u'جفة': u'جُفَّةً', #1
u'جفراء': u'جَفْرَاءُ', #1
u'جفى': u'جَفَى', #1
u'جفير': u'جَفِيرٍ', #2
u'جفيره': u'جَفِيرِهِ', #2
u'جفينة': u'جُفَيْنَة', #1
u'جفينة': u'جُفَيْنَةُ', #1
u'جفينة،': u'جُفَيْنَة،', #1
u'جفينة،': u'جُفَيْنَةَ،', #1
u'جفينة': u'جُفَيْنَةَ', #2
u'جقص': u'جَقْصٌ', #1
u'جقمق': u'جَقْمَقَ', #2
u'جكار': u'جكار', #1
u'جكمجه': u'جكمجه', #6
u'جكنم': u'جكنم', #1
u'جكونه': u'جكونه', #2
u'جلاب': u'جَلاَّبُ', #1
u'جلاب': u'جُلَّابِ', #1
u'جلاب': u'جُلَّابٍ', #3
u'جلابا': u'جُلَّابًا', #4
u'جلابه': u'جلابه', #1
u'جلابي': u'جَلَّابِي', #1
u'جلابي': u'جَلَّابِيٌّ', #1
u'جلابية': u'جَلابِية', #1
u'جلاجل': u'جَلاجِلُ', #1
u'جلاجل': u'جُلَاجِلٌ', #1
u'جلاجل': u'جُلَاجِلٍ', #1
u'جلاجل': u'جَلَاجِلُ', #17
u'جلاجل': u'جَلَاجِل', #2
u'جلاجل': u'جَلَاجِلَ', #7
u'جلاجلها': u'جَلَاجِلَهَا', #1
u'جلاح': u'جَلاحَ', #1
u'جلاهق': u'جُلَاهِقَ', #4
u'جلاهه': u'جُلَاهَهْ', #1
u'جلاهه': u'جِلَاهُهُ', #4
u'جلبس،': u'جَلْبَسَ،', #1
u'جلجبيتنا': u'جَلْجَبِيَّتِنَا', #1
u'جلجلا': u'جُلْجُلًا', #2
u'جلجنا': u'جَلَجِنَا', #1
u'جلجون': u'جُلْجُونَ', #1
u'جلح': u'جُلِحَ', #1
u'جلحاء': u'جَلْحَاءَ', #1
u'جلحاء': u'جَلْحَاءُ', #11
u'جلدات': u'جَلَدَاتٌ', #1
u'جلدات': u'جَلْدَاتٍ', #13
u'جلدات': u'جَلَدَاتِ', #2
u'جلدات': u'جَلَدَاتٍ', #27
u'جلدتمونى؟': u'جَلَدْتُمُونِى؟', #1
u'جلدنى': u'جَلَدَنِى', #1
u'جلدى': u'جِلْدِى', #1
u'جلدى': u'جِلْدِىَ', #1
u'جلز،': u'جلز،', #1
u'جلزهما': u'جَلْزُهُمَا', #1
u'جلسا': u'جِلْسًا', #1
u'جلسه': u'جَلْسِهِ', #1
u'جلسه': u'جِلْسُهُ', #1
u'جلسه': u'جَلَسَهُ', #7
u'جلسها': u'جَلَسَهَا', #1
u'جلسيها': u'جَلْسِيُّهَا', #1
u'جلسيها': u'جِلْسِيَّهَا', #1
u'جلسيها': u'جِلْسِيِّهَا', #2
u'جلسيها': u'جَلْسِيَّهَا', #4
u'جلعته': u'جَلَعْته', #1
u'جلعها': u'جَلَعَهَا', #1
u'جلق': u'جِلّقٌ', #1
u'جلق': u'جِلَّقٍ', #1
u'جلق': u'جِلِّقِ', #1
u'جلمات': u'جَلَمات', #1
u'جلمات': u'جَلَمَاتُ', #2
u'جلمان': u'جَلَمَانِ', #1
u'جلمت': u'جَلَمْت', #1
u'جلندا': u'جَلَنْدَا', #4
u'جلندى': u'جُلَنْدَى', #1
u'جلنزيز': u'جَلْنَزِيزٍ', #1
u'جلهاء': u'جَلْهَاءَ', #1
u'جلهات': u'جَلَهَاتِ', #1
u'جلهات': u'جَلْهَاتِ', #2
u'جلهة': u'جلهة', #1
u'جلهس': u'جَلْهَسَ', #1
u'جلهس،': u'جَلْهَسَ،', #1
u'جلهمة': u'جلهمة', #2
u'جلهمة': u'جُلْهُمَةُ', #2
u'جلواز': u'جِلْوَازٌ', #1
u'جلوبة': u'جَلُوبَةً', #1
u'جلولاء': u'جَلولاء', #1
u'جلولاء': u'جلُولاء', #1
u'جلولاء': u'جَلُولاءِ', #1
u'جلولاء،': u'جَلُولاءَ،', #1
u'جلولاء': u'جَلُولَاءِ', #1
u'جلولاء': u'جلولاء', #2
u'جلولاء،': u'جلولاء،', #2
u'جلولاء،': u'جَلُولاء،', #2
u'جلولاء': u'جَلُولَاءَ', #21
u'جلولاء': u'جَلُولاء', #4
u'جلولاوي': u'جَلُولَاوِيٌّ', #1
u'جلوى': u'جَلْوَى', #2
u'جليبا': u'جَلِيبًا', #6
u'جليبيب': u'جُلَيْبِيبٌ', #3
u'جليبيب': u'جُلَيْبِيبٍ', #3
u'جليبيبا': u'جُلَيْبِيبًا', #16
u'جليبيبا،': u'جُلَيْبِيبًا،', #2
u'جليبين': u'جَلِيبَيْنِ', #1
u'جليح': u'جُلَيْحُ', #1
u'جليح': u'جُلَيْحٌ', #2
u'جليح،': u'جَلِيحُ،', #3
u'جليحة': u'جَلِيحَةَ', #1
u'جليحة': u'جُلَيْحَةٌ', #1
u'جليحة': u'جُلَيْحَةُ', #3
u'جليسى': u'جَلِيسَىْ', #2
u'جماء': u'جَمّاءُ', #1
u'جماء': u'جَمَّاءٌ', #1
u'جماء': u'جَمَّاءَ', #13
u'جماء': u'جَمَّاءُ', #13
u'جماء': u'جَمَّاء', #2
u'جمارة': u'جُمّارَةً', #1
u'جمارة،': u'جُمَّارَةٌ،', #1
u'جمارة': u'جُمَّارَةٌ', #2
u'جمارة': u'جُمّارَةٌ', #3
u'جماعةثم': u'جَمَاعَةٍثُمَّ', #1
u'جماعةقال': u'جَمَاعَةٍقَالَ', #1
u'جمالت': u'جِمَالَتٌ', #3
u'جمامة': u'جَمَامَةٌ', #1
u'جمانة': u'جُمَانَةَ', #1
u'جمانة': u'جُمَانَةُ', #2
u'جمانتين': u'جُمَانَتَيْنِ', #1
u'جماهر': u'جَمَاهِرَ', #1
u'جماوات': u'جَمَّاوَاتٍ', #1
u'جمحى': u'جُمَحِىّ', #1
u'جمداء': u'جَمَدَاءَ', #2
u'جمراء': u'جَمْرَاءَ', #2
u'جمزة': u'جَمْزَةَ', #1
u'جمشيد': u'جَمْشِيدُ', #1
u'جمعناة': u'جَمْعَنَاة', #1
u'جملاء': u'جَمْلاءَ', #1
u'جملاء': u'جَمْلاَءُ', #2
u'جملكي': u'جملكي', #1
u'جملون': u'جَمَلُونٍ', #1
u'جملونات': u'جَمَلُونَاتٌ', #1
u'جملونات': u'جَمَلُونَاتٍ', #1
u'جمنة': u'جَمْنة', #1
u'جمهان،': u'جُمْهان،', #1
u'جمهان': u'جُمْهَانٍَ', #1
u'جمهان': u'جُمْهَانُ', #1
u'جمهان،': u'جُمْهَانُ،', #1
u'جمهان،': u'جُمْهَانَ،', #12
u'جمهان': u'جُمْهَان', #2
u'جمهان': u'جُمْهَانَ', #43
u'جمو': u'جَمَوْ', #1
u'جمو': u'جُمُو', #1
u'جميح': u'جُمَيْحٍ', #1
u'جمير،': u'جُمَيْرٍ،', #1
u'جميراوات': u'جُمَيْرَاوَاتِ', #1
u'جميرة': u'جُمَيْرَةَ', #2
u'جميعاوروي': u'جَمِيعًاوَرُوِيَ', #1
u'جميعهإلا': u'جَمِيعِهِإِلَّا', #1
u'جميمة': u'جُمَيْمَةٌ', #1
u'جميمة،': u'جُمَيْمَةَ،', #1
u'جميمة': u'جُمَيْمَةً', #5
u'جنأ': u'جَنَأ', #1
u'جنأ': u'جَنَأَ', #3
u'جناء': u'جِنَاءً', #1
u'جناء': u'جِنَاءٍ', #1
u'جنابةوالوجه': u'جَنَابَةٍوَالْوَجْهُ', #1
u'جنابذ': u'جَنَابِذُ', #5
u'جناد': u'جناد', #1
u'جناد،': u'جناد،', #1
u'جناد': u'جَنّاد', #1
u'جناد': u'جَنّادٍ', #1
u'جناد': u'جَنَّادٍ', #17
u'جناد': u'جَنَادٍ', #2
u'جناد،': u'جُنَادٍ،', #2
u'جناد': u'جُنَادٍ', #4
u'جناد،': u'جَنَّادٍ،', #6
u'جنادة،': u'جُنَادة،', #1
u'جنادة،': u'جُنَادَةُ،', #1
u'جنادة': u'جُنَادَةَ', #108
u'جنادة،': u'جنادة،', #12
u'جنادة': u'جُنادة', #2
u'جنادة': u'جُنَادَةُ', #37
u'جنادة': u'جنادة', #8
u'جنادة،': u'جُنَادَةَ،', #85
u'جنادرة': u'جَنَادِرَةَ', #1
u'جنادعه': u'جَنَادِعَهُ', #2
u'جناذ': u'جِنَاذُ', #1
u'جنار': u'جنار', #1
u'جنامكه': u'جنامكه', #1
u'جنانكه': u'جنانكه', #8
u'جنايت': u'جنايت', #2
u'جنبتى': u'جَنَبَتَىِ', #1
u'جنبش': u'جنبش', #1
u'جنبنى': u'جَنِّبْنِى', #1
u'جنبى': u'جَنْبِى', #14
u'جنتى': u'جَنَّتِى', #3
u'جندار': u'جِنْدَارٍ', #1
u'جندازين': u'جندازين', #1
u'جندة': u'جُنْدَةَ', #1
u'جندرة': u'جندرة', #1
u'جندرة': u'جَنْدَرة', #1
u'جندرة،': u'جَنْدَرَةَ،', #1
u'جندرة': u'جَنْدَرَةُ', #2
u'جندع': u'جَنْدَعُ', #1
u'جندع': u'جُنْدَعُ', #2
u'جندل': u'جَنْدَلً', #1
u'جنديسابور،': u'جُنْدِيسَابُورَ،', #1
u'جنز': u'جَنِزَ', #1
u'جنز': u'جُنِزَ', #1
u'جنز': u'جَنَزَ', #7
u'جنزة': u'جَنْزَةَ', #1
u'جنزت': u'جَنَزْت', #2
u'جنزه': u'جَنَّزَهُ', #2
u'جنزه': u'جَنَزَهُ', #9
u'جنسة': u'جِنْسَةِ', #1
u'جنف': u'جَنَفٌ', #1
u'جنف': u'جَنَفَ', #1
u'جنف': u'جَنِفَ', #1
u'جنفا': u'جَنَفًا', #16
u'جنفاء': u'جنفاء', #1
u'جنفاء': u'جَنَفَاء', #1
u'جنكال': u'جنكال', #1
u'جنوء': u'جُنُوءَ', #2
u'جنوس': u'جُنُوسٌ', #1
u'جنوس': u'جُنُوسِ', #2
u'جنوسا': u'جُنُوسًا', #1
u'جنول': u'جنول', #1
u'جنيب': u'جَنِيبُ', #1
u'جنيب': u'جَنِيب', #2
u'جنيب': u'جَنِيبٌ', #2
u'جنيب،': u'جَنِيبٍ،', #2
u'جنيب': u'جَنِيبٍ', #23
u'جنيبا،': u'جَنِيبا،', #1
u'جنيبا': u'جَنِيبًا', #26
u'جنيبة': u'جَنِيبَةِ', #1
u'جنيبة': u'جَنِيبَةً', #10
u'جنيبة': u'جَنِيبَةٍ', #2
u'جنيبة': u'جَنِيبَةُ', #2
u'جنيبة': u'جَنِيبَةٌ', #4
u'جنيبه': u'جَنِيبَهُ', #1
u'جنيبه': u'جَنِيبُهُ', #1
u'جنيد': u'جُنَيْدِ', #1
u'جنيد،': u'جُنَيْدٌ،', #1
u'جنيد،': u'جُنَيْدٍ،', #1
u'جنيد': u'جُنَيْدٌ', #2
u'جنيد': u'جُنَيْدٍ', #3
u'جنيد': u'جُنَيْدُ', #3
u'جنيدا': u'جُنَيْدًا', #2
u'جنيدب': u'جُنَيْدَبُ', #1
u'جنيدب': u'جُنَيْدِبُ', #8
u'جنيدة': u'جنيدة', #1
u'جنيدة': u'جُنَيْدَةَ', #1
u'جنيدل': u'جُنَيْدِلٍ', #1
u'جنينم': u'جنينم', #3
u'جهابذة': u'جَهَابِذَةً', #1
u'جهارزن': u'جهارزن', #1
u'جهارم': u'جهارم', #1
u'جهازى': u'جَهَازِى', #2
u'جهام': u'جَهَامٌ', #1
u'جهام': u'جِهَامٌ', #1
u'جهةالقياس': u'جِهَةِالْقِيَاسِ', #1
u'جهجا': u'جَهْجَا', #10
u'جهجاه': u'جهجاه', #1
u'جهجاه،': u'جهجاه،', #1
u'جهجاه': u'جَهْجَاهٌ', #10
u'جهجاه': u'جَهْجاه', #3
u'جهجاه': u'جَهْجَاه', #4
u'جهجاه': u'جَهْجَاهٍ', #5
u'جهجاه': u'جَهْجَاهُ', #9
u'جهزتينى': u'جَهَّزْتِينِى', #1
u'جهزونى': u'جَهِّزُونِى', #3
u'جهض،': u'جَهْضٍ،', #1
u'جهضت': u'جَهَضَتْ', #1
u'جهضم': u'جهضم', #1
u'جهضم': u'جَهْضَمِ', #1
u'جهضم،': u'جَهْضَمٍ،', #20
u'جهضم': u'جَهْضَمٍ', #24
u'جهضم': u'جَهْضَمٌ', #4
u'جهضم': u'جَهْضَمُ', #4
u'جهضم،': u'جَهْضَمٌ،', #4
u'جهلين': u'جَهْلَيْنِ', #1
u'جهمان': u'جَهْمَانَ', #1
u'جهمة': u'جَهْمَةَ', #5
u'جهنام': u'جِهْنَامٍ', #1
u'جهنموروي': u'جَهَنَّمَوَرُوِيَ', #1
u'جهنميون': u'جَهَنَّمِيُّونَ', #1
u'جهيد': u'جَهِيدٍ', #1
u'جهيزا': u'جَهِيزًا', #2
u'جهيزة': u'جَهِيزَةُ', #1
u'جهيزة': u'جَهِيزَةَ', #2
u'جهيشا': u'جَهِيشًا', #1
u'جهينة': u'جُهَيْنَة', #1
u'جهينة،': u'جُهَيْنَةُ،', #1
u'جهينة،': u'جُهَيْنَةَ،', #13
u'جهينة': u'جُهَينة', #2
u'جهينة': u'جُهَيْنَةُ', #20
u'جهينة': u'جُهَيْنَةَ', #220
u'جهينة': u'جهينة', #8
u'جواثا': u'جواثا', #1
u'جواثا': u'جُوَاثَا', #5
u'جؤاثى': u'جُؤَاثَى', #1
u'جؤار': u'جُؤَارٌ', #8
u'جؤارا': u'جُؤَارًا', #2
u'جوارزم': u'جُوَارِزْمَ', #1
u'جوارش': u'جوارش', #1
u'جوارشا': u'جَوَارِشًا', #1
u'جوارى': u'جِوَارِى', #1
u'جوارى': u'جَوَارِى', #6
u'جؤاز': u'جُؤَازٌ', #1
u'جواز': u'جَوَازً', #1
u'جوازالنافلة': u'جَوَازُالنَّافِلَةِ', #1
u'جواظ': u'جَوّاظٍ', #1
u'جواظ': u'جَوَّاظ', #1
u'جواظ': u'جَوَّاظٌ', #1
u'جواظ،': u'جَوَاظٌ،', #1
u'جواظ': u'جَوَّاظٍ', #20
u'جوالب': u'جَوَالِبِ', #6
u'جوالقى': u'جُوَالِقِى', #2
u'جوالى': u'جَوَالِىِّ', #1
u'جوالى': u'جوالى', #4
u'جوامك': u'جَوَامِكِ', #1
u'جوامك': u'جَوَامِكُ', #2
u'جوامك': u'جَوَامِكَ', #3
u'جوامكهم': u'جَوَامِكَهُمْ', #1
u'جوامكهم': u'جَوَامِكِهِمْ', #2
u'جوانك': u'جوانك', #1
u'جؤائي': u'جِؤَائِي', #1
u'جوبة': u'جَوْبَةٍ', #1
u'جوبر': u'جَوْبَرَ', #1
u'جوبير،': u'جُوَبيرٍ،', #1
u'جوتى،': u'جُوتَى،', #1
u'جوجري': u'جَوْجَرِيٌّ', #1
u'جودره': u'جودره', #1
u'جوذابا': u'جُوذَابًا', #1
u'جوذابه': u'جُوذَابِهِ', #1
u'جوذان': u'جُوذَانَ', #2
u'جورة': u'جُوَرَةً', #1
u'جورني': u'جورني', #1
u'جوزتكها': u'جَوَّزْتُكَهَا', #1
u'جوزجانيات': u'جُوزَجَانِيَّاتٍ', #2
u'جوزقة': u'جوزقة', #1
u'جوزقه': u'جَوْزَقِهِ', #1
u'جوزل': u'جَوْزَلٍ', #1
u'جوزينجا': u'جوزينجا', #1
u'جوزينجا': u'جُوزَيَنْجًا', #1
u'جوشن': u'جَوْشَن', #1
u'جوشن': u'جَوْشَنَ', #1
u'جوشن،': u'جَوْشَنٍ،', #1
u'جوشن،': u'جَوْشَنَ،', #1
u'جوشن': u'جَوْشَنٍ', #16
u'جوشنا': u'جَوْشَنًا', #6
u'جوشنه': u'جَوْشَنِهِ', #1
u'جوصا': u'جَوْصا', #1
u'جوصا،': u'جَوْصا،', #1
u'جوصا': u'جَوْصَا', #1
u'جوصا،': u'جَوْصَا،', #1
u'جوصاء،': u'جَوْصَاءَ،', #2
u'جوعل': u'جُوعِلَ', #27
u'جوفة': u'جوفة', #1
u'جولاهه': u'جولاهه', #1
u'جولق': u'جَوْلَقِ', #1
u'جولق': u'جَوْلَقٍ', #5
u'جولقا': u'جَوْلَقًا', #3
u'جولقين': u'جَوْلَقَيْنِ', #2
u'جؤنة': u'جُؤْنَةِ', #1
u'جويبر،': u'جُوَيبرٍ،', #1
u'جويبر': u'جُوَيْبر', #1
u'جويبر،': u'جُوَيْبرٍ،', #1
u'جويبر': u'جَوَيْبِرٍ', #1
u'جويبر': u'جُوَيْبِر', #1
u'جويبر': u'جُوَيْبِرَ', #1
u'جويبر،': u'جَوَيْبِرٍ،', #1
u'جويبر،': u'جُوَيْبَرٍ،', #1
u'جويبر،': u'جُوَيْبِرٍ،', #147
u'جويبر': u'جُوَيْبِرِ', #2
u'جويبر،': u'جُوَيْبِرٌ،', #35
u'جويبر': u'جُوَيْبِرٍ', #41
u'جويبر': u'جُوَيْبِرٌ', #9
u'جويبر،في': u'جُوَيْبِرٌ،فِي', #1
u'جويبر،في': u'جُوَيْبِرٍ،فِي', #1
u'جؤية': u'جُؤَيَةَ', #1
u'جؤية': u'جُؤَيّةَ', #1
u'جؤية': u'جُؤْيَةَ', #2
u'جوير': u'جُوَيْرٌ', #1
u'جويرة': u'جُوَيْرَةُ', #1
u'جويرة': u'جُوَيْرَةَ', #6
u'جويريات': u'جُوَيْرِيَاتٌ', #1
u'جويريات': u'جُوَيْرِيَّاتٍ', #2
u'جويرية،': u'جويرية،', #1
u'جويرية': u'جُوَيْرِية', #1
u'جويرية': u'جُوَيَرِيَةُ', #1
u'جويرية': u'جُوَيْرِيَةً', #1
u'جويرية': u'جُوَيْرِيّةُ', #1
u'جويرية': u'جُوَيْرِيَةُ', #115
u'جويرية': u'جُوَيْرِيَةَ', #178
u'جويرية': u'جُوَيرية', #2
u'جويرية،': u'جُوَيْرِيَةٌ،', #2
u'جويرية،': u'جُوَيْرِيَةُ،', #23
u'جويرية،': u'جُوَيْرِيَةَ،', #27
u'جويرية': u'جُوَيْرية', #3
u'جويرية': u'جُوَيْرِيَةٌ', #3
u'جويرية': u'جَوَيْرِيَةَ', #7
u'جويرية': u'جويرية', #8
u'جويز': u'جُوَيْزَ', #1
u'جويش': u'جويش', #1
u'جيـ': u'جيـ', #1
u'جي': u'جَيٍّ', #1
u'جي،': u'جَيٌّ،', #1
u'جي،': u'جَيٍّ،', #1
u'جي': u'جَيّ', #2
u'جي': u'جَيٌّ', #2
u'جى': u'جى', #2
u'جىء': u'جىء', #1
u'جىء': u'َجِىءُ', #1
u'جىء': u'جِىءَ', #32
u'جئتمانى': u'جِئْتُمَانِى', #4
u'جئتنى': u'جِئْتَنِى', #7
u'جئثت': u'جُئِثْتُ', #1
u'جئثت': u'جئثت', #2
u'جياب': u'جياب', #1
u'جيادة': u'جِيَادَةً', #1
u'جيان': u'جَيَّانُ', #1
u'جيان': u'جَيَّانَ', #6
u'جيحون': u'جَيْحُونُ', #1
u'جيحون': u'جَيْحُونَ', #17
u'جيحون': u'جَيْحُونٍ', #3
u'جيرانى': u'جِيرَانِى', #2
u'جيرانين': u'جِيرَانَيْنِ', #2
u'جيرون': u'جَيُرونِ', #1
u'جيرون،': u'جَيْرُونَ،', #1
u'جيرون': u'جَيْرُونُ', #2
u'جيرون': u'جَيْرُونِ', #2
u'جيرون': u'جَيْرُونَ', #5
u'جيزادادنى': u'جيزادادنى', #1
u'جيزآن': u'جيزآن', #2
u'جيزتخورم': u'جيزتخورم', #1
u'جيزترا': u'جيزترا', #1
u'جيزثرا': u'جيزثرا', #1
u'جيزدادني': u'جيزدادني', #2
u'جيزراز': u'جيزراز', #1
u'جيزنباشد': u'جيزنباشد', #1
u'جيزي': u'جِيزِي', #1
u'جيزي': u'جيزي', #4
u'جيزى': u'جيزى', #4
u'جيسور': u'جَيْسُورُ', #1
u'جيسور': u'جيسور', #2
u'جيضة': u'جَيْضَةً', #4
u'جيعان': u'جَيْعَانَ', #1
u'جيفر': u'جَيْفَرَ', #1
u'جيفر': u'جَيْفَرٍ', #4
u'جينري': u'جينري', #1
u'جيومرت': u'جيومرت', #1
u'جيومرث': u'جيومرث', #1
u'جيؤوني': u'جِيؤُونِي', #1
u'جيئك،': u'جَيْئَكَ،', #1
u'حا': u'حَا', #1
u'حا': u'حا', #2
u'حابرل': u'حابرل', #1
u'حاتك': u'حَاتِكٌ', #1
u'حاتما': u'حَاتِمًا', #8
u'حاتمي': u'حَاتِمِيٍّ', #1
u'حآج': u'حَآجَّ', #1
u'حاجتكيهده': u'حَاجَتَكَيَهْدِهِ', #1
u'حاجتى': u'حَاجَتِى', #10
u'حاجزوا': u'حَاجَزُوا', #2
u'حآجك': u'حَآجَّكَ', #1
u'حآجوك': u'حَآجُّوكَ', #1
u'حاذا': u'حَاذًا', #1
u'حاذا': u'حَاذَا', #1
u'حاذة': u'حَاذَّةَ', #1
u'حاذرون': u'حَاذِرُونَ', #1
u'حاذم': u'حَاذِمٍ', #1
u'حارثةرضى': u'حَارِثَةَرَضِىَ', #1
u'حارثيا': u'حَارِثِيًا', #1
u'حارثيا': u'حَارِثِيًّا', #1
u'حارثية': u'حارثية', #1
u'حارصة': u'حَارِصَةً', #1
u'حارصة': u'حَارِصَةٍ', #2
u'حارصة': u'حَارِصَةٌ', #8
u'حازميحدث،': u'حَازِمٍيُحَدِّثُ،', #1
u'حازى': u'حَازَى', #1
u'حازيا': u'حَازِيًا', #1
u'حاسه': u'حَاسِّهِ', #1
u'حاصا': u'حَاصَّا', #1
u'حاصت': u'حَاصَّتْ', #10
u'حاصت': u'حَاصَتْ', #3
u'حاصص': u'حَاصَصَ', #33
u'حاصصت': u'حَاصَصَتْ', #1
u'حاصصهم': u'حَاصَصَهُمْ', #3
u'حاصه': u'حَاصَّهُ', #2
u'حاصهم': u'حَاصَّهُمْ', #4
u'حاصوا': u'حَاصُّوا', #2
u'حاضرى': u'حَاضِرِى', #1
u'حاظر': u'حَاظِرٍ', #2
u'حاظر': u'حَاظِرَ', #3
u'حاظر': u'حَاظِرٌ', #4
u'حاظرا': u'حَاظِرًا', #4
u'حاظرة': u'حَاظِرَةٌ', #1
u'حافتى': u'حافتى', #2
u'حافتى': u'حَافَتَىِ', #2
u'حافنتي': u'حَافِنَتِي', #1
u'حاقف': u'حَاقِف', #2
u'حاقف': u'حَاقِفٍ', #4
u'حاقف': u'حَاقِفٌ', #7
u'حاقم': u'حَاقِمٌ', #1
u'حاقما': u'حَاقِمًا', #4
u'حاكم': u'حَاكِمً', #1
u'حالتى': u'حَالَتَىْ', #1
u'حالتئذ': u'حَالَتَئِذْ', #2
u'حالتئذ': u'حَالَتَئِذٍ', #8
u'حاللتك': u'حَالَلْتُكَ', #1
u'حاللني': u'حَالِلْنِي', #1
u'حالله': u'حَالَلَهُ', #1
u'حالوم': u'حَالُومٌ', #1
u'حالوم': u'حَالُومٍ', #1
u'حالى': u'حَالِى', #4
u'حامدية': u'حَامِدِيَّةٍ', #1
u'حامدية': u'حَامِدِيَّةٌ', #18
u'حامدية': u'حَامِدِيَّةً', #3
u'حامشا': u'حَامِشًا', #1
u'حامقته': u'حَامَقْتُهُ', #1
u'حامول': u'حَامُولٍ', #1
u'حامئة': u'حَامِئَةٍ', #1
u'حانه': u'حانه', #1
u'حانوت': u'حَانُوتً', #1
u'حاوياء': u'حَاوِيَاءُ', #1
u'حائش': u'حَائِش', #1
u'حائش': u'حَائِشَ', #1
u'حائش': u'حَائِشِ', #1
u'حائش': u'حَائِشُ', #10
u'حائش': u'حَائِشٍ', #2
u'حائطة': u'حَائِطَةً', #1
u'حائطى': u'حَائِطِى', #7
u'حائك': u'حَائِكً', #1
u'حايل': u'حَايِلٌ', #1
u'حب': u'حُبًّ', #1
u'حباس': u'حُبّاسٌ', #1
u'حباشة': u'حُبَاشَةُ', #1
u'حباشة': u'حُبَاشَةَ', #5
u'حباكا': u'حَبَاكَا', #1
u'حبالات': u'حِبَالَاتٍ', #3
u'حبائرها': u'حَبَائِرُهَا', #1
u'حببة': u'حِبَبَةٌ', #1
u'حبتة': u'حَبْتَةُ', #1
u'حبتة': u'حَبْتَةَ', #2
u'حبتر،': u'حَبْتَرٍ،', #1
u'حبتر': u'حَبْتَرٍ', #16
u'حبحاب': u'حَبْحَابٍ', #1
u'حبحاب': u'حَبْحَابٌ', #4
u'حبحبا': u'حَبْحَبًا', #1
u'حبرى': u'حَبْرَى', #1
u'حبستنى': u'حَبَسْتَنِى', #16
u'حبسنى': u'حَبَسَنِى', #4
u'حبسهموروي': u'حَبَسَهُمْوَرُوِيَ', #1
u'حبشى': u'حَبَشِىٍّ', #2
u'حبشى': u'حَبَشِىُّ', #2
u'حبشى': u'حُبْشِىٍّ', #7
u'حبشى': u'حَبَشِىٌّ', #9
u'حبلات': u'حَبَلاتٍ', #1
u'حبلات': u'حَبَلَاتٍ', #1
u'حبلات': u'حَبَلَاتِ', #1
u'حبلات': u'حَبَلاَتٍ', #1
u'حبلاوي': u'حُبْلَاوِيّ', #1
u'حبلة': u'حَبَلَةً', #1
u'حبلة': u'حَبْلَةً', #3
u'حبنا': u'حَبَنًا', #2
u'حبوبة': u'حَبُّوبَةَ', #1
u'حبوطة': u'حُبُوطَةَ', #1
u'حبولها': u'حُبُولُهَا', #1
u'حبويه': u'حِبَوَيْهِ', #1
u'حبيبأن': u'حَبِيبٍأَنَّ', #2
u'حبيبعن': u'حَبِيبٍعَنْ', #1
u'حبيبلا': u'حَبِيبٍلَا', #1
u'حبيبى': u'حَبِيبِى', #3
u'حبيبية': u'حُبَيْبِيَّة', #1
u'حبيتني': u'حَبَّيْتَنِي', #1
u'حبير،': u'حبير،', #1
u'حبير': u'حَبِيرٍ', #1
u'حبير': u'حُبَيْرِ', #1
u'حبيرة': u'حُبَيْرَةَ', #1
u'حبيش،': u'حَبيَشٍ،', #1
u'حبيش،': u'حُبَيْشٌ،', #1
u'حبيش': u'حُبَيْشُ', #11
u'حبيش': u'حُبَيْشِ', #17
u'حبيش،': u'حبيش،', #2
u'حبيش': u'حُبَيْشٍ', #315
u'حبيش': u'حُبَيْش', #4
u'حبيش،': u'حُبَيْشٍ،', #41
u'حبيش': u'حُبَيْشٌ', #6
u'حبيش،': u'حُبَيْش،', #6
u'حبيش': u'حبيش', #8
u'حبيشة': u'حَبِيشَةَ', #1
u'حبيشة': u'حُبَيْشَةَ', #2
u'حبيق': u'حُبَيْق', #2
u'حبيق': u'حُبَيْقٍ', #4
u'حبينة': u'حُبَيْنَةَ', #1
u'حثحاث': u'حَثْحَاثٌ', #1
u'حثحث': u'حُثْحِثَ', #1
u'حثرا': u'حَثَرًا', #2
u'حثمة': u'حثَمة', #1
u'حثمة': u'حَثَمَةَ', #1
u'حثمة': u'حَثْمَةٌ', #1
u'حثمة،': u'حَثَمَةَ،', #1
u'حثمة': u'حثمة', #11
u'حثمة': u'حُثْمَةَ', #2
u'حثمة': u'حَثْمَةَ', #255
u'حثمة،': u'حَثْمَةَ،', #27
u'حثمه': u'حَثْمَهْ', #1
u'حثوات': u'حَثَوَاتٍ', #1
u'حثى': u'حَثَى', #14
u'حثيا': u'حَثْيًا', #16
u'حثيات': u'حَثَيَات', #1
u'حثيات،': u'حَثَيَاتٍ،', #2
u'حثيات': u'حَثَيَاتٍ', #61
u'حثيات': u'حَثَيَاتِ', #7
u'حثيان': u'حَثَيَانِ', #1
u'حثيان': u'حَثَيَانُ', #3
u'حثية': u'حَثْيَة', #1
u'حثية': u'حَثْيَةٍ', #1
u'حثية': u'حَثْيَةً', #4
u'حثيثى': u'حِثِّيثَى', #1
u'حج': u'حَجًّ', #1
u'حجات': u'حَجَّاتٍ', #18
u'حجات': u'حَجّاتٍ', #2
u'حجات': u'حَجَّاتٌ', #2
u'حجاته': u'حَجّاتُهُ', #1
u'حجاته': u'حَجَّاتِهِ', #1
u'حجاج،': u'حَجَّاجً،', #1
u'حجاح': u'حَجَّاحٍ', #1
u'حجاح': u'حَجَّاحُ', #1
u'حجاح': u'حَجَّاحٌ', #4
u'حجادة': u'حجادة', #1
u'حجارةوروي': u'حِجَارَةًوَرُوِيَ', #1
u'حجارةيييي': u'حِجَارَةٍيييي', #1
u'حجبنى': u'حَجَبَنِى', #2
u'حجةوروي': u'حُجَّةٌوَرُوِيَ', #1
u'حجتى': u'حَجَّتِى', #7
u'حجد': u'حَجَدَ', #1
u'حجرإتحاف': u'حجرإتحاف', #1
u'حجرتى': u'حُجْرَتِى', #12
u'حجرى،': u'حجْرى،', #1
u'حجرى؟': u'حِجْرِى؟', #1
u'حجرى': u'حَجْرِى', #17
u'حجرى': u'حِجْرِى', #4
u'حجزاء': u'حَجْزَاءَ', #1
u'حجزتيني': u'حَجَزْتِينِي', #1
u'حجط': u'حجط', #2
u'حجف': u'حَجَفُ', #1
u'حجفة': u'حَجَفَةٌ', #1
u'حجفة': u'حَجَفَةً', #3
u'حجفة': u'حَجَفَة', #4
u'حجفة': u'حَجَفَةٍ', #8
u'حجفتك': u'حَجَفَتُكَ', #3
u'حجفته': u'حَجَفَتِهِ', #2
u'حجنة': u'حَجْنَةٌ', #1
u'حجنة': u'حَجَنَةٌ', #2
u'حجنة': u'حُجْنَةٌ', #6
u'حجنت': u'حَجَنْت', #1
u'حجوان': u'حَجْوَانَ', #1
u'حجوة': u'حَجْوَةُ', #1
u'حجوة': u'حَجْوَةَ', #2
u'حجوز': u'حُجُوزٍ', #1
u'حجوز': u'حُجُوزِ', #1
u'حجى': u'حُجِّى', #18
u'حجيجة': u'حُجَيْجَةَ', #1
u'حجير': u'حُجَيْرٌ', #1
u'حجير': u'حُجَيْرُ', #11
u'حجير': u'حجير', #3
u'حجير': u'حُجَيْرٍ', #30
u'حجير': u'حُجَيْرَ', #5
u'حجير،': u'حُجَيْرٍ،', #5
u'حجير': u'حُجَيْرِ', #8
u'حجيرة،': u'حجيرة،', #1
u'حجيرة': u'حُجَيْرَةً', #2
u'حجيرة': u'حُجَيْرَةُ', #2
u'حجيرة': u'حُجَيْرَةَ', #23
u'حجيرة،': u'حُجَيْرَةَ،', #6
u'حجيفة': u'حجيفة', #1
u'حجيفة': u'حُجَيْفَةَ', #2
u'ححا': u'ححا', #1
u'حدتتني': u'حَدّتْتِنِي', #1
u'حدثاء': u'حُدَثَاءَ', #1
u'حدثاء': u'حُدَثَاءُ', #2
u'حدثاته': u'حَدَثَاتِهِ', #1
u'حدثأخاك': u'حَدِّثْأَخَاكَ', #1
u'حدثأنهم': u'حَدَّثَأَنَّهُمْ', #2
u'حدثة': u'حَدَثَةٌ', #1
u'حدثة': u'حَدَثَةُ', #1
u'حدثة': u'حَدَثَةً', #3
u'حدثتكموه': u'حَدَّثْتُكُمُوهُ', #12
u'حدثتكموه': u'حدثتكموه', #2
u'حدثتكموه،': u'حَدَّثْتُكُمُوهُ،', #4
u'حدثتكه': u'حَدَّثْتُكَهُ', #1
u'حدثتلم': u'حَدَّثَتَلَّمَ', #1
u'حدثتنى': u'حَدَّثْتِنِى', #1
u'حدثتنى': u'حَدَّثَتْنِى', #105
u'حدثتنى': u'حَدَّثْتَنِى', #6
u'حدثتنيه': u'حَدّثَتْنِيهِ', #2
u'حدثتنيه': u'حَدَّثَتْنِيهِ', #2
u'حدثكه': u'حَدَّثَكَهُ', #2
u'حدثكهن': u'حَدَّثَكَهُنَّ', #1
u'حدثناأبو': u'حَدَّثَنَاأَبُو', #1
u'حدثناأن': u'حَدَّثَنَاأَنُّ', #1
u'حدثنى': u'حَدَّثَنى', #1
u'حدثنى': u'حَدَّثَنَّى', #1
u'حدثنى': u'حَدَّثِنِى', #1
u'حدثنى': u'حَدِّثَنِى', #1
u'حدثنى': u'حَدَّثَنَى', #10
u'حدثنى': u'حدثنى', #20
u'حدثنى': u'حَدِّثْنِى', #21
u'حدثنى': u'حَدَّثَنِى', #5394
u'حدثنيبه': u'حَدَّثَنِيبِهِ', #1
u'حدثنيه،': u'حَدَّثَنِيهِ،', #1
u'حدثنيه': u'حَدَّثَنِيهِ', #102
u'حدثنيه': u'حدثنيه', #2
u'حدثنيه؟': u'حَدَّثَنِيهِ؟', #2
u'حدثنيه': u'حَدّثَنِيهِ', #4
u'حدثنيها': u'حَدَّثَنِيهَا', #3
u'حدثهأن': u'حَدَّثَهُأَنَّ', #2
u'حدثوناه': u'حَدَّثُونَاهُ', #1
u'حدثونى': u'حَدِّثُونِى', #1
u'حدثينى': u'حَدِّثِينِى', #2
u'حدجة': u'حَدَجَةٌ', #1
u'حدجة': u'حَدَجَةٍ', #1
u'حدجة': u'حَدَجَةً', #2
u'حدرة': u'حَدْرَةَ', #1
u'حدرد': u'حَدْرَدِ', #1
u'حدرد': u'حَدْرَدٍ', #123
u'حدرد': u'حَدْرَد', #2
u'حدرد؟': u'حَدْرَدٍ؟', #2
u'حدرد': u'حَدْرَدَ', #3
u'حدرد': u'حدرد', #4
u'حدرد،': u'حَدْرَدٍ،', #6
u'حدمج': u'حدمج', #1
u'حدنثا': u'حَدَّنَثَا', #3
u'حدهاى': u'حدهاى', #1
u'حدهق': u'حدهق', #1
u'حدوبته': u'حُدُوبَتِهِ', #1
u'حدوبته': u'حُدُوبَتُهُ', #5
u'حدودرا': u'حدودرا', #1
u'حدودوى': u'حدودوى', #1
u'حدياة': u'حُدَيَّاةٌ', #1
u'حديثأبي': u'حَدِيثِأَبِي', #1
u'حديثأنس': u'حَدِيثِأَنَسٍ', #1
u'حديثزيد': u'حَدِيثِزَيْدِ', #1
u'حديثعبد': u'حَدِيثِعَبْدِ', #1
u'حديثى': u'حَدِيثِىٌّ', #2
u'حديثى': u'حَدِيثِى', #8
u'حديثيته': u'حَدِيثِيَّتُهُ', #1
u'حديثيته': u'حَدِيثِيَّتِهِ', #1
u'حديج': u'حُدَيج', #1
u'حديج،': u'حُديْجٍ،', #1
u'حديج': u'حَدِيجٍ', #2
u'حديج،': u'حُدَيْج،', #2
u'حديج': u'حُدَيْجٍ', #29
u'حديج': u'حديج', #3
u'حديج': u'حُدَيْجٌ', #3
u'حديج،': u'حُدَيْجٍ،', #4
u'حديج': u'حُدَيْج', #5
u'حديج': u'حُدَيْجُ', #6
u'حديجا': u'حديجا', #1
u'حديجا': u'حُدَيْجًا', #1
u'حدير': u'حدير', #1
u'حدير،': u'حديرٍ،', #1
u'حدير': u'حُدَير', #1
u'حدير،': u'حَدِيرٍ،', #1
u'حدير،': u'حُدَير،', #1
u'حدير': u'حُدَيْرِ', #1
u'حدير،': u'حُدَيْر،', #1
u'حدير،': u'حُدَيْرٌ،', #1
u'حدير،': u'حُدَيْرٍ،', #17
u'حدير': u'حُدَيْرٍ', #49
u'حدير': u'حُدَيْرُ', #5
u'حديرة': u'حُدَيْرَةَ', #2
u'حديس': u'حُدَيْسٌ', #1
u'حديلة': u'حُدَيْلَةَ', #10
u'حديلة': u'حُدَيْلَةُ', #4
u'حذافةوكان': u'حُذَافَةُوَكَانَ', #1
u'حذافه': u'حذافه', #2
u'حذام': u'حِذَامٍ', #1
u'حذام': u'حَذَامِ', #7
u'حذركموهم،': u'حَذَّرَكُمُوهُمْ،', #1
u'حذفة': u'حَذَفَة', #1
u'حذفة': u'حَذَفَةً', #1
u'حذفة': u'حَذْفَةً', #1
u'حذفيا': u'حَذْفِيًّا', #1
u'حذفين': u'حَذْفَيْنِ', #1
u'حذلاء': u'حَذْلَاءُ', #1
u'حذلم': u'حذْلَم', #1
u'حذلم': u'حَذْلَمَ', #1
u'حذلم': u'حَذْلَمٍ', #2
u'حذلم،': u'حَذْلَمٍ،', #3
u'حذم': u'حَذْمِ', #3
u'حذمة': u'حذمة', #1
u'حذوة': u'حِذْوَة', #1
u'حذية': u'حُذْيَةً', #1
u'حذية': u'حِذْيَة', #1
u'حذية': u'حِذْيَةً', #1
u'حذية،': u'حِذْيَةً،', #1
u'حذير،': u'حَذِيرٍ،', #1
u'حذيفةذهب': u'حُذَيْفَةُذَهَبَ', #1
u'حذيفةلما': u'حُذَيْفَةُلَمَّا', #1
u'حذيفه': u'حذيفه', #1
u'حذيقة': u'حَذِيقَةُ', #1
u'حذيم': u'حذيم', #1
u'حذيم': u'حِذيَم', #1
u'حذيم': u'حُذَيْمٍ', #1
u'حذيم': u'حِذْيَمَ', #1
u'حذيم،': u'حُذَيْم،', #1
u'حذيم،': u'حِذْيَمٍ،', #1
u'حذيم': u'حِذْيَمٍ', #10
u'حذيم،': u'حذيم،', #2
u'حذيم': u'حِذْيَمِ', #2
u'حذيم': u'حِذْيَمٌ', #3
u'حر': u'حُرًّ', #1
u'حراء': u'حَرَّاءُ', #1
u'حراء': u'حِرَاء', #1
u'حراء': u'حِرَاءً', #1
u'حراء،': u'حِرَاءٌ،', #1
u'حراء': u'حَرَّاءَ', #10
u'حراء': u'حِرَاءٌ', #10
u'حراء': u'حِرَاءُ', #17
u'حراء': u'حراء', #2
u'حراء،': u'حِرَاءٍ،', #2
u'حراء،': u'حِرَاءُ،', #3
u'حراء،': u'حِرَاءَ،', #4
u'حراء': u'حِرَاءٍ', #50
u'حراء': u'حِرَاءَ', #53
u'حراجيج': u'حَراجِيجُ', #2
u'حرار': u'حَرَارً', #1
u'حراص': u'حِرَاصٌ', #2
u'حراض': u'حُرَاضٍ', #1
u'حراق': u'حُرَّاقٍ', #1
u'حراق': u'حِرَاقٍ', #1
u'حراق': u'حُرَاقٍ', #2
u'حراق': u'حِرَاقٌ', #2
u'حراقا': u'حِرَاقًا', #1
u'حراقه': u'حُرَاقُهُ', #2
u'حرام': u'حَرَامً', #1
u'حرائبكم': u'حَرَائِبُكُمْ', #1
u'حرائبهم': u'حَرَائِبَهُمْ', #5
u'حرائز': u'حَرَائِزَ', #4
u'حرباة': u'حِرْبَاةٌ', #2
u'حربتى': u'حَرْبَتِى', #4
u'حربويه': u'حَرْبَوَيْه', #1
u'حربويه': u'حَرْبَوَيْهِ', #12
u'حرتى': u'حَرَّتَىِ', #1
u'حرثات': u'حرثات', #1
u'حرثات': u'حَرْثَاتٍ', #2
u'حرثان': u'حُرْثَانَ', #21
u'حرثان': u'حَرْثَانَ', #5
u'حرثان': u'حُرْثَانُ', #5
u'حرثتين': u'حرثتين', #1
u'حرثتين': u'حَرْثَتَيْنِ', #2
u'حرزات': u'حَرَزَاتِ', #1
u'حرزة': u'حَرْزَةَ', #1
u'حرزة،': u'حَرْزَةَ،', #1
u'حرزة،': u'حِرْزَةَ،', #1
u'حرزتيه': u'حَرَزْتِيهِ', #1
u'حرزيته': u'حِرْزِيَّتُهُ', #1
u'حرزيته': u'حِرْزِيَّتِهِ', #1
u'حرزيتها': u'حِرْزِيَّتِهَا', #1
u'حرسى': u'حَرَسِىٍّ', #2
u'حرسيكم': u'حَرَسِيُّكُمْ', #3
u'حرسيه': u'حَرَسِيُّهُ', #1
u'حرضهمرسول': u'حَرَّضَهُمْرَسُولُ', #1
u'حرفتى': u'حِرْفَتِى', #2
u'حرقانية': u'حَرْقَانِيَّةٌ', #1
u'حرقانية': u'حَرْقَانِيَّة', #2
u'حرقوص،': u'حُرْقُوصٌ،', #1
u'حرقوص': u'حُرْقُوص', #2
u'حرقوص': u'حُرْقُوصٌ', #2
u'حرقوص': u'حُرْقُوصُ', #3
u'حرقوصا': u'حُرْقُوصًا', #1
u'حركنى': u'حَرَّكَنِى', #2
u'حرمتقال': u'حُرِّمَتْقَالَ', #1
u'حرمد': u'حرمد', #1
u'حرمد،': u'حرمد،', #1
u'حرمد': u'حَرْمَدِ', #3
u'حرملة،': u'حَرْمَلةَ،', #1
u'حرملة': u'حَرْمَلَةٌ', #1
u'حرملة': u'حَرْمَلَةِ', #1
u'حرملة،': u'حَرْمَلَة،', #1
u'حرملة': u'حرملة', #18
u'حرملة': u'حَرْمَلَة', #2
u'حرملة': u'حَرْمَلَةٍ', #3
u'حرملة': u'حَرْمَلَةَ', #367
u'حرملة': u'حَرْمَلَةُ', #369
u'حرملة،': u'حرملة،', #4
u'حرملة،': u'حَرْمَلَةَ،', #53
u'حرملة،': u'حَرْمَلَةُ،', #63
u'حرملة،عن': u'حَرْمَلَةُ،عَنِ', #1
u'حرمهمقوله': u'حَرَمِهِمْقَوْلُهُ', #1
u'حرمى': u'حَرَمِىٌّ', #1
u'حرمى': u'حَرْمَى', #1
u'حرمى': u'حَرَمِىُّ', #17
u'حرمى': u'حَرَمِىِّ', #2
u'حرنفش': u'حَرَنْفَشٍ', #1
u'حروث': u'حُرُوثٍ', #2
u'حروثهم': u'حروثهم', #1
u'حروثهم': u'حُرُوثِهِمْ', #7
u'حروجا': u'حَرُوجًا', #1
u'حروراء': u'حروراء', #1
u'حروراء': u'حَرُوراء', #2
u'حروراء': u'حَرُورَاء', #3
u'حروراء': u'حَرُورَاءَ', #31
u'حروراء': u'حَرُورَاءُ', #5
u'حروز': u'حُرُوزٍ', #1
u'حرى': u'حَرًى', #2
u'حريب': u'حُرَيْبٍ', #1
u'حريبته': u'حَرِيبَتِهِ', #1
u'حريث': u'حُريث', #1
u'حريث،': u'حُرَيث،', #1
u'حريث': u'حُرَيْثَ', #1
u'حريث،': u'حُرَيْث،', #1
u'حريث،': u'حُرَيْثٌ،', #1
u'حريث،': u'حُرَيْثِ،', #1
u'حريث': u'حُرَيْثِ', #10
u'حريث': u'حريث', #12
u'حريث': u'حُرَيْثٍ', #230
u'حريث،': u'حريث،', #4
u'حريث': u'حُرَيْثٌ', #5
u'حريث': u'حُرَيْثُ', #7
u'حريث،': u'حُرَيْثٍ،', #72
u'حريث': u'حُرَيْث', #8
u'حريثا': u'حُرَيْثًا', #4
u'حريدم': u'حريدم', #2
u'حريس': u'حَرِيسٌ', #1
u'حريس': u'حَرِيسِ', #3
u'حريسة': u'حَرِيسَةٍ', #1
u'حريسة': u'حَرِيسَةُ', #1
u'حريسة': u'حَرِيسَة', #2
u'حريسة': u'حَرِيسَةِ', #21
u'حريش': u'حُرَيش', #1
u'حريش': u'حَرِيشٍ', #14
u'حريش': u'حَرِيشُ', #2
u'حريش': u'حريش', #3
u'حريش': u'حَرِيشِ', #3
u'حريش': u'حُرَيْشٍ', #4
u'حريضا': u'حَرِيضًا', #1
u'حريمته': u'حَرِيمَتِهِ', #1
u'حريمته': u'حَرِيمَتَهُ', #2
u'حريملة،': u'حُرَيْمِلَةَ،', #1
u'حريملة': u'حُرَيْمِلَةَ', #24
u'حزابة': u'حزابة', #1
u'حزابة': u'حُزَابَةُ', #2
u'حزابة': u'حُزَابَةَ', #3
u'حزارا': u'حَزَّارًا', #1
u'حزامة': u'حَزَامَةِ', #1
u'حزامة': u'حَزَامَةً', #2
u'حزاورة': u'حَزَاوِرَة', #1
u'حزاورة': u'حَزَاوِرَةً', #2
u'حزة': u'حُزَّةِ', #1
u'حزة،': u'حُزَّةً،', #1
u'حزة': u'حُزَّةً', #6
u'حزتيه': u'حُزْتِيهِ', #10
u'حزرات': u'حَزَرَاتِ', #14
u'حزرة': u'حَزرَةَ', #1
u'حزرة': u'حَزَرَةٍ', #1
u'حزرة': u'حَزَرَةَ', #1
u'حزرة': u'حَزْرَةٌ', #1
u'حزرة': u'حِزْرَةَ', #1
u'حزرة،': u'حِزْرَةَ،', #1
u'حزرة': u'حَزْرَةٍ', #2
u'حزرة': u'حَزْرَةَ', #22
u'حزرة،': u'حَزْرَةَ،', #3
u'حزرم': u'حَزْرَمٍ', #6
u'حزقان': u'حِزْقَانِ', #2
u'حزقل': u'حِزْقِلُ', #1
u'حزقل،': u'حِزْقِلٌ،', #2
u'حزقيل': u'حَزْقِيلُ', #1
u'حزقيل': u'حِزْقِيلُ', #2
u'حزنى': u'حزنى', #1
u'حزوة': u'حَزْوَةُ', #3
u'حزوت': u'حَزَوْت', #3
u'حزوز': u'حُزُوزٌ', #3
u'حزوم': u'حُزُومٍ', #1
u'حزون': u'حُزُونِ', #1
u'حزونة': u'حَزُونَةٍ', #1
u'حزونة': u'حُزُونَةٌ', #3
u'حزونة': u'حُزُونَةٍ', #3
u'حزونة': u'حُزُونَةً', #4
u'حزونها': u'حُزُونِهَا', #1
u'حزى': u'حَزَى', #1
u'حزية': u'حُزِّيَّةِ', #1
u'حزيمة': u'حزيمة', #1
u'حزيمة': u'حَزِيمَةَ', #1
u'حساءات': u'حِسَاءَاتٍ', #1
u'حسانة': u'حُسَانَةٌ', #1
u'حسبتهمو': u'حَسِبْتُهُمُو', #1
u'حسبى': u'حَسْبِى', #1
u'حسبى': u'حَسْبِىَ', #6
u'حسدان': u'حَسَدَانِ', #1
u'حسرانا': u'حَسْرَانًا', #1
u'حسرتى': u'حَسْرَتَى', #6
u'حسل': u'حَسَلٍ', #1
u'حسل': u'حَسَلِ', #1
u'حسل،': u'حِسْلٌ،', #1
u'حسل': u'حِسْلَ', #2
u'حسل': u'حِسْلٍ', #22
u'حسل': u'حسل', #5
u'حسل': u'حِسْلِ', #57
u'حسمى،': u'حِسْمى،', #1
u'حسمى': u'حَسْمَى', #1
u'حسمى،': u'حَسْمَى،', #1
u'حسمى،': u'حِسْمَى،', #1
u'حسمى': u'حِسْمَى', #4
u'حسناتى': u'حَسَنَاتِى', #1
u'حسنةثم': u'حَسَنَةٍثُمَّ', #1
u'حسنون': u'حَسْنُونُ', #1
u'حسنون': u'حُسْنُونُ', #1
u'حسنويه': u'حَسْنُوَيْهِ', #1
u'حسنويه': u'حَسْنَوَيْهِ', #4
u'حسوسا': u'حَسُوسا', #1
u'حسوسا': u'حَسُوسَا', #1
u'حسى': u'حُسًى', #1
u'حسيل': u'حَسِيلَ', #1
u'حسيل': u'حُسَيْلَ', #1
u'حسيل': u'حُسِيْلٍ', #1
u'حسيل،': u'حُسَيْلٌ،', #1
u'حسيل؟': u'حُسَيْلُ؟', #1
u'حسيل': u'حُسَيْلُ', #15
u'حسيل': u'حَسِيلُ', #2
u'حسيل': u'حُسَيْلٍ', #2
u'حسيل': u'حُسَيْلٌ', #6
u'حسيم': u'حُسَيْم', #1
u'حسينا،': u'حُسَيْنًا،', #3
u'حسينا': u'حُسَيْنًا', #40
u'حشاوي': u'حَشَاوِي', #1
u'حشائي': u'حِشَائِي', #1
u'حشوشا': u'حُشُوشًا', #3
u'حشوشكم': u'حُشُوشُكُمْ', #1
u'حشوشهم': u'حُشُوشُهُمْ', #1
u'حشوشهم': u'حُشُوشِهِمْ', #7
u'حشوشهن': u'حُشُوشِهِنَّ', #2
u'حشياء': u'حَشْيَاءَ', #1
u'حشير': u'حُشَيْرٍ', #1
u'حصاصة': u'حُصَاصَةً', #1
u'حصاصة': u'حُصَاصَةٌ', #1
u'حصاصة': u'حُصَاصَةِ', #1
u'حصنة': u'حِصَنَةٌ', #1
u'حصوليا': u'حُصُولِيًّا', #2
u'حصيب': u'حَصِيبُ', #1
u'حصيب': u'حَصِيبٍ', #2
u'حصيب': u'حُصَيْبٍ', #9
u'حصيننزلت': u'حُصَيْنٍنَزَلَتْ', #1
u'حضأة': u'حَضَأْةُ', #1
u'حضأة': u'حَضْأَةِ', #1
u'حضأت': u'حَضَأْت', #1
u'حضأت': u'حَضَأْتُ', #1
u'حضأتها': u'حَضَأْتهَا', #1
u'حضاجر': u'حَضَاجِرَ', #1
u'حضب': u'حَضَبُ', #1
u'حضبت': u'حَضَبَتْ', #1
u'حضجت': u'حَضَجَتْ', #2
u'حضرمى': u'حَضْرَمِىُّ', #1
u'حضرنى': u'حَضَرَنِى', #3
u'حضرويه': u'حَضْرَوَيْهِ', #2
u'حضوض': u'حُضُوضُ', #1
u'حضيابصة': u'حُضَيابِصَةُ', #1
u'حضير': u'حَضِير', #1
u'حضير': u'حُضَيْرَ', #1
u'حضير،': u'حُضَيْرٍ،', #18
u'حضير': u'حُضَيْرٍ', #188
u'حضير': u'حُضَيْرٌ', #2
u'حضير': u'حُضَيْرُ', #2
u'حضير': u'حضير', #5
u'حضير': u'حُضَيْر', #5
u'حضير': u'حُضَيْرِ', #6
u'حضير': u'حَضِيرٌ', #7
u'حضين': u'حُضَيْنٌ', #1
u'حضين': u'حُضَيْن', #3
u'حضين': u'حُضَيْنِ', #7
u'حضين': u'حُضَيْنُ', #8
u'حضين': u'حُضَيْنٍ', #9
u'حضينا': u'حُضَيْنًا', #1
u'حطأة': u'حَطْأَةً', #5
u'حطأنى': u'حَطَأَنِى', #1
u'حطة': u'حطة', #1
u'حطة': u'حِطَّةُ', #1
u'حطة': u'حِطَّةً', #2
u'حطة': u'حِطّةٌ', #3
u'حطة': u'حِطَّةٌ', #38
u'حطة': u'حِطَّةٍ', #7
u'حطوط': u'حَطُوطٍ', #3
u'حطوم': u'حَطُومٌ', #1
u'حطيب': u'حُطَيْبٌ', #1
u'حطيط': u'حَطِيط', #1
u'حطيط': u'حَطِيطِ', #1
u'حطيط': u'حُطَيْطٍ', #3
u'حطيط': u'حُطَيْطِ', #3
u'حطيم': u'حَطِيمُ', #1
u'حطيم': u'حُطَيْم', #1
u'حطيم': u'حُطَيْمٌ', #1
u'حطيم': u'حَطِيمَ', #10
u'حطيم': u'حَطِيمِ', #11
u'حطيم': u'حَطِيمٌ', #3
u'حطيم': u'حَطِيمٍ', #3
u'حطيما': u'حَطِيمًا', #4
u'حطيمه': u'حَطِيمِهِ', #1
u'حطيمها': u'حَطِيمِهَا', #2
u'حظريته': u'حَظْرِيَّتِهِ', #1
u'حظل': u'حَظِلٌ', #1
u'حظني': u'حَظَّنِي', #1
u'حظوت': u'حَظَوْت', #1
u'حظى': u'حَظِّىَ', #1
u'حظى': u'حَظِّى', #4
u'حظير': u'حَظِيرٍ', #1
u'حفاش': u'حُفَاشَ', #1
u'حفاش': u'حِفَاشٌ', #1
u'حفالة': u'حُفَالَةٌ', #1
u'حفالة': u'حُفَالَةِ', #1
u'حفد': u'حَفَدَ', #8
u'حفدا': u'حَفَدًا', #1
u'حفدا': u'حَفْدًا', #1
u'حفدك': u'حفدك', #1
u'حفدك': u'حَفَدَك', #2
u'حفزانا': u'حَفَزَانًا', #1
u'حفزنى': u'حَفَزَنِى', #1
u'حفش': u'حَفْشِ', #1
u'حفش': u'حِفْشٌ', #2
u'حفش': u'حِفْشٍ', #2
u'حفش': u'حِفْشِ', #2
u'حفشا': u'حِفْشًا', #8
u'حفشها،': u'حَفْشَهَا،', #1
u'حفصة': u'حَفْصَةً', #2
u'حفصويه': u'حَفْصُوَيْهِ', #1
u'حفظون': u'حَفْظُونٍ', #1
u'حفظى': u'حِفْظِى', #7
u'حفناوي': u'حِفْنَاوِيٌّ', #1
u'حفوا': u'حَفْوًا', #1
u'حفوة': u'حَفْوَةً', #1
u'حفور': u'حُفُورٌ', #1
u'حفى': u'حفى', #1
u'حفى': u'حَفًى', #3
u'حفياء': u'حَفْيَاءَ', #2
u'حفيدة': u'حُفَيْدَةُ', #4
u'حفيدته': u'حَفِيدَتُهُ', #1
u'حفيدته': u'حَفِيدَتِهِ', #2
u'حفيدتها': u'حَفِيدَتِهَا', #1
u'حفيص': u'حُفَيْصٍ', #1
u'حفيفة': u'حَفِيفَةٍ', #1
u'حفيلة': u'حَفِيلَةٍ', #1
u'حق': u'حَقًّ', #4
u'حقاف': u'حِقَافٍ', #2
u'حقاوالوجه': u'حَقًّاوَالْوَجْهُ', #1
u'حقائقا': u'حَقَائِقًا', #3
u'حقرة': u'حُقْرَةً', #1
u'حقرة': u'حُقْرَةُ', #3
u'حقرة': u'حُقْرَةٌ', #4
u'حقف': u'حُقْف', #1
u'حقكا': u'حَقَّكَا', #1
u'حقهقوله': u'حَقِّهِقَوْلُهُ', #1
u'حقيته': u'حَقِّيَّتُهُ', #1
u'حقيته': u'حَقِيَتُهُ', #3
u'حقيته': u'حَقِّيَّتَهُ', #4
u'حقيته': u'حَقِّيَّتِهِ', #6
u'حقيتها': u'حَقِّيَّتِهَا', #2
u'حقيقون': u'حَقِيقُونَ', #1
u'حكاهماالواقدي،': u'حكاهماالواقديّ،', #1
u'حكرة': u'حُكْرَةً', #2
u'حكرة': u'حُكْرَةَ', #3
u'حكرة': u'حُكْرَةٌ', #4
u'حكمةوالوجه': u'حِكْمَةٍوَالْوَجْهُ', #1
u'حكمهأن': u'حُكْمِهِأَنْ', #1
u'حكميته': u'حُكْمِيَّتِهِ', #1
u'حكواتي': u'حَكَوَاتِيٍّ', #1
u'حكومه': u'حُكُومَهْ', #1
u'حلأ': u'حلأ', #1
u'حلابس': u'حُلَابِسٌ', #1
u'حلأتهم': u'حَلأْتُهُمْ', #1
u'حلاحل': u'حُلَاحِلِ', #4
u'حلاس': u'حُلَاسِ', #1
u'حلافى': u'حلافى', #1
u'حلام': u'حُلَّامِ', #2
u'حلاوه': u'حَلَاوَهْ', #1
u'حلبس،': u'حَلْبَسَ،', #1
u'حلبس': u'حلبس', #4
u'حلبس،': u'حَلْبَسٍ،', #5
u'حلبس': u'حَلْبَسٍ', #9
u'حلبياته': u'حَلَبِيَّاتِهِ', #5
u'حلبين': u'حَلْبَيْنِ', #4
u'حلتى': u'حُلَّتِى', #1
u'حلز': u'حِلِّزٌ', #1
u'حلزة': u'حِلّزَةَ', #4
u'حلقلة': u'حلقلة', #1
u'حلمالحديث': u'حَلُمَالْحَدِيثُ', #1
u'حلمتى': u'حَلَمَتَىِ', #1
u'حلمى': u'حُلْمِى', #1
u'حلواة': u'حَلْوَاةً', #1
u'حلولو': u'حُلُولُو', #43
u'حليس': u'حُلَيْس', #1
u'حليس': u'حُلَيْسٍ', #1
u'حليس': u'حُلَيْسُ', #2
u'حليفاء': u'حُلَيْفَاءَ', #1
u'حماتى': u'حَمَاتِى', #1
u'حمارى': u'حِمَارِى', #2
u'حماز': u'حَمَّازٍ', #1
u'حماز': u'حِمَازٍ', #1
u'حماش': u'حِمَاشٍ', #1
u'حماليا': u'حَمَالِيًا', #1
u'حماليق': u'حَمَالِيقِ', #5
u'حمدنى': u'حَمِدَنِى', #6
u'حمدوس': u'حَمْدُوسٌ', #1
u'حمدون': u'حمدونَ', #1
u'حمدون،': u'حَمْدُونٍ،', #1
u'حمدون': u'حَمْدُونَ', #11
u'حمدون': u'حَمْدُونُ', #14
u'حمدون': u'حَمْدُونٍ', #17
u'حمدون': u'حَمْدُونِ', #5
u'حمدويه': u'حمدويه', #1
u'حمدويه': u'حَمْدَوَيْهَ', #1
u'حمدويه': u'حَمْدَوَيْهِ', #11
u'حمدويه': u'حَمْدُوَيْهِ', #21
u'حمديس': u'حَمْدِيسٌ', #17
u'حمديس': u'حَمْدِيسُ', #2
u'حمديس': u'حَمْدِيسٍ', #9
u'حمدين': u'حَمْدِينَ', #3
u'حمرانا': u'حُمْرَانًا', #5
u'حمز': u'حَمْزُ', #6
u'حمز': u'حَمْزَ', #8
u'حمزية': u'حَمْزِيَّةً', #2
u'حمش': u'حمش', #1
u'حمش': u'حَمَشَ', #1
u'حمش': u'حَمِشَ', #1
u'حمش': u'حَمْشٌ', #1
u'حمش': u'حَمْشِ', #1
u'حمش': u'حَمْش', #3
u'حمش': u'حَمْشَ', #30
u'حمش': u'حَمْشُ', #4
u'حمشا': u'حَمْشًا', #3
u'حمشاد': u'حَمْشَادٍ', #2
u'حمشاذ': u'حَمْشَاذُ', #1
u'حمشاذ': u'حَمْشَّاذَ', #1
u'حمشاذ،': u'حُمْشَاذٍ،', #1
u'حمشاذ،': u'حَمْشَاذَ،', #121
u'حمشاذ': u'حمشاذ', #2
u'حمشاذ،': u'حمشاذ،', #27
u'حمشاذ': u'حَمْشَاذٍ', #46
u'حمشاذ،': u'حَمْشَاذٍ،', #5
u'حمشاذ': u'حَمْشَاذَ', #97
u'حمشت': u'حَمَشْت', #1
u'حمشتها': u'حَمَشَتْهَا', #3
u'حمشتهم': u'حَمَشَتْهُمْ', #1
u'حمصى': u'حِمْصِىُّ', #1
u'حمكنا': u'حَمَكْنَا', #1
u'حملاء': u'حُمَلَاءَ', #38
u'حملاء': u'حُمَلَاءُ', #57
u'حملتنى': u'حَمَلَتْنِى', #1
u'حملتنى': u'حَمَلْتَنِى', #1
u'حملنى': u'حَمَلَنِى', #10
u'حملى': u'حَمْلِى', #2
u'حمنانة': u'حَمْنَانَةٌ', #1
u'حمنانة': u'حَمْنَانَةٍ', #1
u'حمنة،': u'حمنة،', #1
u'حمنة': u'حمْنَة', #1
u'حمنة': u'حَمْنَة', #2
u'حمنة': u'حَمْنَةُ', #26
u'حمنة': u'حمنة', #4
u'حمنة': u'حَمْنَةَ', #48
u'حموتها': u'حَمْوَتَهَا', #2
u'حمود': u'حَمُّودٍ', #1
u'حمور': u'حمور', #1
u'حموشة،': u'حُمُوشَةٌ،', #1
u'حموشة': u'حُمُوشَةٌ', #3
u'حموشة': u'حُمُوشَةِ', #3
u'حموقة': u'حَمُوقَةً', #1
u'حمئة': u'حمئة', #1
u'حمئة': u'حَمِئَةً', #1
u'حمئة': u'حَمِئَةِ', #1
u'حمئة': u'حَمِئَةٍ', #22
u'حميدإنما': u'حُمَيْدٍإِنَّمَا', #1
u'حميرات': u'حَمِيرَاتٌ', #1
u'حميرات': u'حُمَيْرَاتٍ', #2
u'حميرات': u'حُمَيْرَاتٌ', #4
u'حميرة': u'حميرة', #1
u'حميرة': u'حُمَيّرَةَ', #1
u'حميرة': u'حُمَيْرَةُ', #1
u'حميرة': u'حُمَيْرَةَ', #5
u'حميرية': u'حِمْيَرِيَّةٌ', #2
u'حميرية': u'حِمْيَرِيَّةً', #6
u'حميصة': u'حميصة', #1
u'حميضة': u'حُمَيْضَةُ', #1
u'حميضة': u'حُمَيْضَةَ', #11
u'حميق': u'حُمَيْقٍ', #1
u'حمينة': u'حَمِينَةٌ', #1
u'حنأ': u'حَنَأَ', #1
u'حناءة': u'حِنَّاءَةٌ', #4
u'حناة': u'حِنَّاةٌ', #1
u'حنأت': u'حَنَّأْتُ', #1
u'حنات': u'حِنَاتٌ', #1
u'حناتم': u'حَنَاتِمَ', #1
u'حناد،': u'حَنَّادٍ،', #1
u'حنادسه': u'حَنَادِسُهُ', #1
u'حناذ': u'حَنَاذٍ', #1
u'حنبلوغيرهم': u'حَنْبَلٍوَغَيْرُهُمْ', #1
u'حنبليفتتح': u'حَنْبَلٍيَفْتَتِحُ', #1
u'حنتما': u'حَنْتَمًا', #1
u'حنتمة': u'حنتمة', #1
u'حنتمة': u'حَنْتَمَة', #1
u'حنتمة': u'حَنْتَمَةُ', #1
u'حنتمة': u'حَنْتَمَةٌ', #3
u'حنتمة': u'حَنْتَمَةٍ', #3
u'حنجت': u'حَنَجْت', #1
u'حندج': u'حُنْدُجٌ', #1
u'حندج': u'حُنْدُجٍ', #2
u'حندجا': u'حُنْدُجًا', #1
u'حندس،': u'حِنْدِسٌ،', #1
u'حندس،': u'حِنْدِسٍ،', #1
u'حندس': u'حِنْدِسِ', #2
u'حندس': u'حِنْدِسٍ', #4
u'حنزابة': u'حِنْزَابَةَ', #1
u'حنس': u'حَنَسِ', #2
u'حنطب': u'حنطب', #1
u'حنطب': u'حَنْطَب', #1
u'حنطب': u'حَنْطَبَ', #1
u'حنطب،': u'حَنْطَبٌ،', #1
u'حنطب،': u'حَنْطَبٍ،', #15
u'حنطب': u'حَنْطَبٍ', #53
u'حنطب': u'حَنْطَبِ', #7
u'حنطونى': u'حَنِّطُونِى', #1
u'حنظلةابن': u'حَنْظَلَةُابْنُ', #1
u'حنفآء': u'حُنَفَآءَ', #1
u'حنفل،': u'حَنْفَلٍ،', #1
u'حنفيون': u'حَنَفِيُّونَ', #1
u'حنيذ': u'حَنِيذٍ', #12
u'حنيس،': u'حنيس،', #9
u'حنيفةوالشافعي': u'حَنِيفَةَوَالشَّافِعِيُّ', #1
u'حنيفةوروى': u'حَنِيفَةَوَرَوَى', #1
u'حنيفةيكبر': u'حَنِيفَةَيُكَبِّرُ', #1
u'حنيقة': u'حَنِيقَة', #1
u'حنيقة': u'حَنِيقَةَ', #1
u'حواء،': u'حَوَّاءً،', #1
u'حواء،': u'حِوَاءً،', #1
u'حواء': u'حِوَاءً', #28
u'حوابه': u'حَوَابُّهُ', #1
u'حوابي': u'حَوَابِّي', #1
u'حوابي': u'حَوَابِي', #2
u'حوارى': u'حَوارِىَّ', #1
u'حوارى': u'حَوَارِىٌّ', #4
u'حوارى': u'حُوَّارَى', #7
u'حواريى': u'حَوَارِيَّى', #1
u'حواز': u'حُوَازُّ', #1
u'حواز': u'حُوَّازُ', #1
u'حواز': u'حَوَّازُ', #3
u'حواسر': u'حَوَاسِرَ', #2
u'حواسرا': u'حَوَاسِرًا', #2
u'حواسره': u'حَوَاسِرُهْ', #2
u'حواشى': u'حواشى', #1
u'حواشى': u'حَوَاشِى', #4
u'حواصة': u'حِوَاصَةٌ', #1
u'حوافده': u'حَوَافِدِهِ', #1
u'حوافدها': u'حَوَافِدُهَا', #1
u'حوائنا،': u'حِوَائِنَا،', #1
u'حوائنا': u'حِوَائِنَا', #5
u'حوايا': u'حَوَايَا', #2
u'حوبا': u'حُوبًا', #12
u'حوبا': u'حَوْبًا', #2
u'حوبا': u'حُوباً', #5
u'حوبائه': u'حَوْبَائِهِ', #1
u'حوبته': u'حَوْبَتِهِ', #1
u'حوبتي': u'حَوْبَتِي', #2
u'حوبنا': u'حَوْبَنَا', #2
u'حوتكة': u'حَوْتَكَةَ', #1
u'حوتكة': u'حَوْتَكَةُ', #1
u'حوتكية': u'حَوْتَكِيَّةٌ', #1
u'حوثرة': u'حوثرة', #1
u'حوثرة،': u'حَوْثَرَةُ،', #1
u'حوثرة': u'حَوْثَرَةُ', #10
u'حورانى': u'حَوْرَانِىٍّ', #1
u'حورانية': u'حَوْرَانِيَّةً', #1
u'حورة': u'حَوْرَةً', #1
u'حورة': u'حَوْرَةَ', #1
u'حوشب،': u'حَوْشب،', #1
u'حوشب،': u'حَوْشبْ،', #1
u'حوشب': u'حَوْشَب', #1
u'حوشب': u'حَوْشَبَ', #1
u'حوشب،': u'حوشب،', #14
u'حوشب': u'حَوْشَبٌ', #2
u'حوشب': u'حَوْشَبِ', #2
u'حوشب،': u'حَوْشَبٌ،', #2
u'حوشب': u'حَوْشَبٍ', #334
u'حوشب': u'حوشب', #4
u'حوشب،': u'حَوْشَب،', #4
u'حوشب': u'حَوْشَبُ', #8
u'حوشب،': u'حَوْشَبٍ،', #94
u'حوشبا': u'حَوْشَبًا', #1
u'حوصة': u'حَوْصَة', #1
u'حوصص': u'حُوصِصَ', #2
u'حوصصوا': u'حُوصِصُوا', #1
u'حوضى': u'حَوْضِىَ', #1
u'حوضى': u'حَوْضِى', #19
u'حوضى': u'حَوْضَى', #4
u'حوعامر': u'حوَعَامِرُ', #1
u'حؤلا': u'حُؤَلًا', #1
u'حولانا': u'حَوَلَانًا', #1
u'حولة': u'حولة', #1
u'حولق': u'حَوْلَقَ', #2
u'حولل': u'حُولَلٌ', #1
u'حولهالوجه': u'حَوْلَهُالْوَجْهُ', #1
u'حومطرف،': u'حوَمُطَرِّفٌ،', #1
u'حومل': u'حَوْمَلٍ', #1
u'حووي': u'حَوَوِيٌّ', #1
u'حويرث': u'حويرث', #1
u'حويرث': u'حُوَيْرِثٍ', #3
u'حويسة': u'حُوَيْسَةُ', #1
u'حويص': u'حُوَيَصٍ', #1
u'حويص': u'حُوَيْصٍ', #1
u'حويصة،': u'حويصة،', #1
u'حويصة،': u'حُوَيصة،', #1
u'حويصة': u'حُوَيَّصَةُ', #1
u'حويصة': u'حُوَيّصَة', #13
u'حويصة': u'حُوَيِّصَةَ', #19
u'حويصة،': u'حُوَيِّصَةُ،', #3
u'حويصة': u'حُوَيِّصَةُ', #46
u'حويصة': u'حُوَيّصَةَ', #6
u'حويصة': u'حُوَيّصَةُ', #9
u'حويض': u'حُوَيْضٌ', #1
u'حويطب': u'حُوَيطب', #1
u'حويطب،': u'حُوَيْطِبٍ،', #1
u'حويطب': u'حُوَيْطِبَ', #10
u'حويطب': u'حُوَيْطِبٍ', #15
u'حويطب': u'حُوَيْطِبُ', #17
u'حويطب': u'حويطب', #2
u'حويطب': u'حُوَيْطب', #2
u'حويطب': u'حُوَيْطِب', #3
u'حويطب': u'حُوَيْطِبٌ', #4
u'حويطب': u'حُوَيْطِبِ', #6
u'حويطبا': u'حُوَيْطِبًا', #2
u'حويطبون': u'حُوَيْطِبُونَ', #1
u'حويل': u'حَوِيلُ', #1
u'حويل': u'حَوِيلٌ', #8
u'حويله': u'حَوِيلِهِ', #1
u'حويوية': u'حُوَيْوِيَةَ', #1
u'حى': u'حى', #1
u'حى': u'حَى', #1
u'حى': u'حِىٍّ', #1
u'حى؟': u'حَىٌّ؟', #1
u'حى': u'حَىَّ', #111
u'حى': u'حَىٍّ', #19
u'حى': u'حِىٌّ', #2
u'حى': u'حَىٌّ', #34
u'حى': u'حَىِّ', #4
u'حياتكا': u'حَيَاتَكَا', #1
u'حياتى': u'حَيَاتِى', #2
u'حياطة': u'حِيَاطَةُ', #2
u'حياطة': u'حِيَاطَةِ', #2
u'حياطتكم': u'حِيَاطَتِكُمْ', #5
u'حياطته': u'حِيَاطَتُهُ', #1
u'حياطته': u'حِيَاطَتِهِ', #1
u'حياطتها': u'حِيَاطَتُهَا', #1
u'حيانأنه': u'حَيَّانَأَنَّهُ', #1
u'حيانوأما': u'حَيَّانَوَأَمَّا', #1
u'حيائى': u'حَيَائِى', #1
u'حيايا': u'حَيَايَا', #1
u'حيبة': u'حِيبَةٍ', #1
u'حيبة،': u'حِيبَةٍ،', #1
u'حيثمة': u'حَيْثَمَةَ', #1
u'حيثي': u'حَيْثِيّ', #2
u'حيدرة': u'حَيْدَرَةُ', #2
u'حيدرة': u'حَيْدَرَةَ', #5
u'حيدون': u'حَيْدُونُ', #1
u'حيس': u'حَيْسٌ', #18
u'حيس،': u'حَيْسٌ،', #3
u'حيس': u'حَيْسٍ', #4
u'حيسا': u'حَيْسًا', #40
u'حيسا،': u'حَيْسًا،', #5
u'حيسة': u'حَيْسَة', #1
u'حيسة': u'حَيْسَةً', #2
u'حيصة': u'حَيْصَةَ', #1
u'حيصة،': u'حَيْصَةً،', #2
u'حيصة': u'حَيْصَةً', #5
u'حيضتى': u'حِيْضَتِى', #1
u'حيضتى': u'حَيْضَتِى', #5
u'حيضين': u'حَيْضَيْنِ', #4
u'حيطه': u'حَيْطَهُ', #1
u'حيفاء': u'حَيْفَاءَ', #3
u'حيفة': u'حيفة', #1
u'حين': u'حِينً', #1
u'حينأشرت': u'حِينَأَشَرْتُ', #1
u'حينذ': u'حِينَذٍ', #1
u'حينئذالوجه': u'حِينَئِذٍالْوَجْهُ', #1
u'حيوة': u'حَيوَةُ', #1
u'حيوة': u'حيَوَةُ', #1
u'حيوة': u'حَيَوَةُ', #1
u'حيوة': u'حَيْوَةٌ', #1
u'حيوة': u'حَيْوَةَ', #151
u'حيوة': u'حَيْوَةُ', #291
u'حيوة،': u'حيوة،', #3
u'حيوة،': u'حَيَوَةَ،', #3
u'حيوة': u'حَيَوَةَ', #4
u'حيوة،': u'حَيْوَةَ،', #57
u'حيوة،': u'حَيْوَةُ،', #75
u'حيوة': u'حيوة', #8
u'حيوة،في': u'حَيْوَةَ،فِي', #1
u'حيوئيل': u'حَيْوَئِيلَ', #1
u'حيوئيل،': u'حَيْوَئِيلَ،', #1
u'حيويل': u'حَيْوِيلَ', #1
u'حيى': u'حُيَىِ', #1
u'حيى': u'حُيَىَّ', #2
u'حيى': u'حُيَىٍّ', #27
u'حيى': u'حُيَىٌّ', #3
u'حيى': u'حَيِىٌّ', #4
u'حيى': u'حُيَىُّ', #6
u'حيى': u'حُيَىِّ', #8
u'حييتSمن': u'حَيِيتSمِنْ', #1
u'خابا': u'خَابًّا', #2
u'خابئة': u'خَابِئَةٍ', #2
u'خاتمى': u'خَاتِمِى', #1
u'خاتمى': u'خَاتَمِى', #3
u'خاتون': u'خَاتُونُ', #1
u'خاتون': u'خَاتُونَ', #16
u'خاتيام': u'خَاتِيَامُ', #1
u'خاخ': u'خَاخٍ', #15
u'خادبود': u'خادبود', #1
u'خادمى': u'خَادِمِى', #1
u'خاذفا': u'خَاذِفًا', #1
u'خارب': u'خَارَبَ', #1
u'خاربا': u'خَارِبًا', #1
u'خاربة': u'خَارِبَةً', #2
u'خاربة': u'خَارِبَةٌ', #4
u'خارص': u'خَارَصَ', #1
u'خارص': u'خَارِصٍ', #11
u'خارص': u'خَارِصَ', #3
u'خارص': u'خَارِصٌ', #37
u'خارصا': u'خارصًا', #2
u'خارصا': u'خَارِصًا', #31
u'خارصان': u'خَارِصَانِ', #7
u'خارصين': u'خَارِصَيْنِ', #1
u'خارف': u'خَارِفَ', #1
u'خارف': u'خَارِفِ', #1
u'خارف': u'خَارِفُ', #2
u'خارف': u'خَارِفٍ', #7
u'خارم': u'خَارِمٍ', #2
u'خارم': u'خَارِمِ', #29
u'خارم': u'خَارِمٌ', #4
u'خارم': u'خَارِمُ', #5
u'خارم': u'خَارِمَ', #6
u'خارما': u'خَارِمًا', #9
u'خارمة': u'خَارِمَةٌ', #1
u'خارمة': u'خَارِمَةٍ', #1
u'خارمها': u'خَارِمُهَا', #5
u'خازم': u'خَازُمٍ', #1
u'خازم': u'خَازِم', #1
u'خازم': u'خازم', #2
u'خازم،': u'خازم،', #2
u'خازم': u'خَازِمِ', #2
u'خازم': u'خَازِمٍ', #57
u'خازم،': u'خَازِمٍ،', #9
u'خازنى': u'خَازِنِى', #6
u'خاس': u'خَاسَ', #5
u'خاسقا': u'خَاسِقًا', #1
u'خاسكية': u'خَاسِكِيَّةُ', #1
u'خاسكية': u'خَاسِكِيَّةَ', #2
u'خاسوا': u'خَاسُوا', #1
u'خاصتى': u'خاصتى', #1
u'خاصرتى': u'خَاصِرَتِى', #4
u'خاصف': u'خَاصِفُ', #3
u'خاضرتاها': u'خَاضِرَتَاهَا', #1
u'خاطمها': u'خَاطِمَهَا', #1
u'خاظي': u'خَاظِي', #2
u'خاقان': u'خَاقَان', #1
u'خاقان،': u'خَاقَانَ،', #1
u'خاقان': u'خَاقَانَ', #7
u'خاقاني': u'خَاقَانِيٍّ', #2
u'خاقاني': u'خَاقَانِي', #4
u'خاقانيا': u'خاقانيا', #2
u'خاقانية': u'خاقانية', #1
u'خاقانية': u'خَاقَانِيَّةٍ', #1
u'خاك': u'خاك', #1
u'خاك': u'خَاكَ', #1
u'خاكرا': u'خاكرا', #1
u'خالاى': u'خَالاَىَ', #2
u'خالتهوروى': u'خَالَتِهِوَرُوِِىِ', #1
u'خالتى': u'خَالَتِى', #30
u'خالجنيها': u'خالجنيها', #1
u'خالجنيها،': u'خَالَجَنِيهَا،', #1
u'خالجنيها': u'خَالَجَنِيهَا', #13
u'خالدالمعافري،': u'خَالِدٍالْمَعَافِرِيِّ،', #1
u'خالقهاوالوجه': u'خَالِقِهَاوَالْوَجْهُ', #1
u'خالويه': u'خَالُوَيْهِ', #1
u'خالويه': u'خَالَوَيْهِ', #16
u'خالويه،': u'خَالَوَيْهِ،', #54
u'خالى': u'خَالِى', #22
u'خامدون': u'خَامِدُونَ', #3
u'خامسية': u'خَامِسِيَّةٍ', #1
u'خامسيتها': u'خَامِسِيَّتَهَا', #2
u'خامسيه': u'خَامِسِيهِ', #1
u'خامسيه،': u'خَامِسِيهِ،', #1
u'خاموا': u'خَامُوا', #4
u'خانان': u'خَانَانِ', #1
u'خانكاة': u'خَانْكَاةُ', #1
u'خانكاه': u'خانكاه', #2
u'خانكاه': u'خَانِكَاهْ', #2
u'خاننى': u'خَانَنِى', #1
u'خانين': u'خَانَيْنِ', #2
u'خآئبين': u'خَآئِبِينَ', #1
u'خآئفين': u'خَآئِفِينَ', #1
u'خباثة': u'خَبَاثَةِ', #1
u'خباثته': u'خَبَاثَتِهِ', #1
u'خبأوا': u'خَبَّأُوا', #1
u'خبة': u'خَبَّةٌ', #1
u'خبرداد': u'خبرداد', #1
u'خبرنى': u'خَبَّرَنِى', #1
u'خبرنيه': u'خَبّرَنِيهِ', #1
u'خبرى': u'خُبْرَى', #1
u'خبرى': u'خَبَرِى', #6
u'خبريته': u'خَبَرِيَّتُهُ', #1
u'خبريته': u'خَبَرِيَّتِهِ', #8
u'خبريتها': u'خَبَرِيَّتِهَا', #5
u'خبزة': u'خَبْزَةِ', #1
u'خبزة': u'خُبْزَةَ', #1
u'خبزة': u'خُبْزَةً', #11
u'خبزة': u'خَبْزَةً', #2
u'خبزة': u'خُبْزَةٍ', #2
u'خبزة': u'خُبْزَةٌ', #3
u'خبزيهما': u'خُبْزَيْهِمَا', #1
u'خبلهSقوم': u'خَبَلَهُSقَوْمُ', #1
u'خبنة': u'خَبْنَةً', #1
u'خبنة': u'خُبْنَةً', #29
u'خبنة': u'خُبْنَة', #4
u'خبيزى': u'خُبَّيْزَى', #1
u'خبيئا': u'خبيئا', #1
u'خبيئا': u'خَبِيئًا', #9
u'ختانان': u'خِتَانَانِ', #1
u'ختانين': u'خِتَانَيْنِ', #1
u'ختانيهما': u'خِتَانَيْهِمَا', #1
u'ختف': u'ختف', #1
u'ختمات': u'خَتْمَاتٍ', #1
u'ختمات،': u'خَتْمَاتٍ،', #1
u'ختمات': u'خِتْمَاتٍ', #3
u'ختمات': u'خَتَمَاتٍ', #4
u'ختمة': u'خَتْمَةَ', #2
u'ختمة': u'خِتْمَةً', #2
u'ختمة': u'خِتْمَةِ', #2
u'ختمة': u'خَتْمَةً', #23
u'ختمة': u'خَتْمَةِ', #3
u'ختمة': u'خِتْمَةٍ', #3
u'ختمة': u'خَتْمَةٍ', #30
u'ختمة': u'خَتْمَةٌ', #4
u'ختمتان': u'خَتْمَتَانِ', #1
u'ختمتين': u'خَتْمَتَيْنِ', #5
u'ختنى': u'خَتَنِى', #1
u'ختيمة': u'خَتِيمَةً', #1
u'خثاء': u'خَثَاءِ', #1
u'خثرمة': u'خَثْرَمَةٌ', #1
u'خثعم': u'خَثْعَم', #1
u'خثعم': u'خَثْعَمِ', #1
u'خثعم': u'خَثْعَمَ', #101
u'خثعم': u'خَثْعَمُ', #16
u'خثعم': u'خَثْعَمٍ', #27
u'خثعم': u'خثعم', #3
u'خثعم': u'خَثْعَمٌ', #4
u'خثعم،': u'خَثْعَمٍ،', #4
u'خثعما': u'خَثْعَمًا', #1
u'خثعمة': u'خَثْعَمَةَ', #1
u'خثعمية': u'خَثْعَمِيَّةٌ', #1
u'خثمة': u'خَثْمَةَ', #3
u'خثوره': u'خُثُورِهِ', #1
u'خثوري': u'خُثُورِي', #1
u'خثى': u'خِثًى', #1
u'خثى': u'خَثَى', #5
u'خثيل': u'خُثَيْلِ', #1
u'خثيل': u'خُثَيْلٍ', #3
u'خثيم': u'خَثَيمٍ', #1
u'خثيم': u'خَثِيم', #1
u'خثيم': u'خُثَيمٍ', #1
u'خثيم': u'خَثْيَمٍ', #1
u'خثيم': u'خُثَيْمٌ', #1
u'خثيم': u'خُثَيْمَ', #1
u'خثيم،': u'خَثْيَمٍ،', #1
u'خثيم،': u'ِخُثَيْمٍ،', #1
u'خثيم،': u'خثيم،', #10
u'خثيم': u'خُثَيْمِ', #13
u'خثيم': u'خُثَيْم', #2
u'خثيم': u'خُثَيْمٍ', #257
u'خثيم': u'خثيم', #5
u'خثيم': u'خُثَيْمُ', #8
u'خثيم،': u'خُثَيْمٍ،', #98
u'خثيمة،': u'خثيمة،', #1
u'خثيمة،': u'خَثْيَمَةَ،', #1
u'خثيمة': u'خثيمة', #2
u'خثيمة،': u'خُثَيْمَةَ،', #2
u'خثيمة': u'خُثَيْمَةَ', #5
u'خجا': u'خجا', #1
u'خجتها': u'خَجّتْهَا', #3
u'خجند': u'خُجَنْدَ', #2
u'خجندة': u'خُجَنْدَةَ', #1
u'خجوج،': u'خَجُوجٌ،', #1
u'خدابة': u'خِدَابَةَ', #1
u'خدابدست': u'خدابدست', #1
u'خداج،': u'خِدَاجً،', #1
u'خداج': u'خِدَاجَ', #2
u'خداج،': u'خِدَاجٌ،', #2
u'خداج': u'خِدَاج', #5
u'خداج': u'خِدَاجٌ', #98
u'خداجا': u'خِدَاجًا', #6
u'خداداندتا': u'خداداندتا', #1
u'خدادند': u'خدادند', #1
u'خدارة': u'خدارة', #1
u'خدارة': u'خَدَارَةٌ', #1
u'خدارة': u'خَدَارَةَ', #1
u'خدارة': u'خُدَارَةَ', #3
u'خداش': u'خِدَاش', #1
u'خداش': u'خِدَاشُ', #1
u'خداش،': u'خِدَاشٍ،', #23
u'خداش': u'خِدَاشٍ', #58
u'خداش': u'خِدَاشِ', #6
u'خداوند': u'خداوند', #8
u'خداونديا': u'خداونديا', #1
u'خدايت': u'خدايت', #2
u'خداير': u'خداير', #3
u'خدايرا': u'خدايرا', #3
u'خدايم': u'خدايم', #3
u'خدايى': u'خدايى', #1
u'خدب': u'خَدَبٌ', #3
u'خدبا': u'خَدْبًا', #1
u'خدباء': u'خَدْبَاءُ', #2
u'خدبه': u'خِدَبَّهْ', #1
u'خدجت': u'خَدَجَتْ', #2
u'خدشة': u'خَدْشَةً', #1
u'خدشة': u'خَدْشَةٍ', #1
u'خدعتنى': u'خَدَعَتْنِى', #1
u'خدلاء': u'خَدْلَاءُ', #3
u'خدلج': u'خَدَلَّج', #1
u'خدلج': u'خَدَلَّجُ', #2
u'خدلج': u'خَدَلَّجَ', #20
u'خدلجا': u'خَدْلَجًا', #1
u'خدوجا': u'خَدُوجًا', #1
u'خدى': u'خَدَّىْ', #1
u'خدى': u'خَدِّى', #3
u'خديج،': u'خديج،', #1
u'خديج': u'خَدِيجٍُُُُ', #1
u'خديج': u'خُدَيجٍ', #1
u'خديج،': u'خُدَيْج،', #1
u'خديج': u'خَدِيجِ', #10
u'خديج': u'خَدِيجٌ', #2
u'خديج': u'خَدِيج', #3
u'خديج': u'خَدِيجَ', #3
u'خديج': u'خَدِيجُ', #4
u'خديج': u'خديج', #5
u'خديج': u'خَدِيجٍ', #600
u'خديج،': u'خَدِيجٍ،', #72
u'خديجا': u'خَدِيجًا', #1
u'خديجا': u'خَدِيجَا', #2
u'خديجةاااا----': u'خَدِيجَةُاااا----', #1
u'خديح': u'خَدِيحٍ', #3
u'خذابة': u'خِذَابَةَ', #5
u'خذام': u'خِذام', #1
u'خذام': u'خِذَام', #1
u'خذام،': u'خِذَامٍ،', #1
u'خذام': u'خِذَامٍ', #16
u'خذام': u'خِذَامِ', #3
u'خذام': u'خِذَامُ', #5
u'خذاما': u'خِذَامًا', #4
u'خذامة': u'خِذَامَةُ', #1
u'خذف': u'خَذَفٍ', #1
u'خذف': u'خَذْفٌ', #1
u'خذف': u'خَذْفٍ', #1
u'خذف': u'خَذْفَ', #1
u'خذف': u'خذف', #3
u'خذف': u'خَذَفَ', #7
u'خذفا': u'خَذْفًا', #4
u'خذفت': u'خَذَفَتِ', #1
u'خذفت': u'خَذَفْتَ', #1
u'خذفته': u'خَذَفْته', #1
u'خذم': u'خَذِمْ', #2
u'خذم': u'خِذَمْ', #2
u'خذم': u'خَذْمٌ', #3
u'خذما': u'خَذِمًا', #2
u'خذمة': u'خَذْمَةَ', #1
u'خذى': u'خُذِى', #15
u'خذيفة': u'خُذَيْفَةَ', #1
u'خرء': u'خَرْءُ', #13
u'خرء': u'خُرْءِ', #23
u'خرء': u'خُرْءُ', #29
u'خرء': u'خَرْءَ', #7
u'خرء': u'خَرْءِ', #9
u'خرء': u'خُرْءَ', #9
u'خراءة': u'خِرَاءَة', #1
u'خرأت': u'خَرَأَتْ', #1
u'خراجة': u'خَرَاجَةٍ', #1
u'خراجيته': u'خَرَاجِيَّتُهُ', #1
u'خراجيتها': u'خَرَاجِيَّتَهَا', #1
u'خرادش،': u'خِرَادشٍ،', #1
u'خراديل': u'خَرَادِيلُ', #2
u'خرارة': u'خَرَّارَةٌ', #1
u'خرارة': u'خَرَّارَةٍ', #1
u'خراس': u'خِرَاس', #1
u'خراس': u'خِرَاسُ', #1
u'خراسا': u'خِرَاسًا', #1
u'خراسانى': u'خُرَاسَانِىٌّ', #1
u'خراسانى': u'خُرَاسَانِىُّ', #1
u'خراسي': u'خُرَاسِيٌّ', #1
u'خراسيا': u'خُرَاسِيًّا', #1
u'خراش،': u'خراش،', #1
u'خراش': u'خرَاشُ', #1
u'خراش': u'خَرَاشٍ', #1
u'خراش': u'خِرَاش', #1
u'خراش': u'خِرَاشُ', #21
u'خراش،': u'خِرَاشٍ،', #21
u'خراش': u'خِراش', #3
u'خراش': u'خِرَاشٌ', #4
u'خراش': u'خراش', #5
u'خراش': u'خِرَاشَ', #8
u'خراش': u'خِرَاشِ', #8
u'خراش': u'خِرَاشٍ', #80
u'خراشا': u'خِرَاشًا', #4
u'خراندر': u'خراندر', #1
u'خرانيب': u'خَرَانِيبَ', #6
u'خرأه': u'خَرْأَهُ', #2
u'خرأها': u'خَرْأَهَا', #2
u'خرأها': u'خُرْأَهَا', #4
u'خرأهما': u'خَرْأَهُمَا', #1
u'خرائي': u'خرائي', #1
u'خرباز': u'خرباز', #1
u'خرباق': u'خرباق', #1
u'خرباق': u'خِرْبَاق', #1
u'خرباق': u'خِرْبَاقَ', #1
u'خرباق': u'خِرْبَاقُ', #1
u'خربةوروى': u'خَرِبَةًوَرُوِِىِ', #1
u'خربدرم': u'خربدرم', #1
u'خربر': u'خربر', #1
u'خربوذ،': u'خَرْبُوذَ،', #1
u'خربوذ،': u'خَرَّبُوذَ،', #3
u'خربوذ': u'خَرَّبُوذَ', #5
u'خربوش': u'خَرَبُوشَ', #1
u'خربى': u'خُرْبَى', #3
u'خربيار': u'خربيار', #1
u'خرثي': u'خُرْثِيَّ', #1
u'خرثي': u'خُرْثِيّ', #2
u'خرثى': u'خُرْثِىَّ', #2
u'خرثي': u'خُرْثِيٍّ', #3
u'خرثى': u'خُرْثِىِّ', #3
u'خرثي': u'خُرْثِيِّ', #8
u'خرديابزرك': u'خرديابزرك', #1
u'خررا': u'خررا', #1
u'خررة': u'خِرَرَةٌ', #1
u'خرزاد': u'خُرَّزَادَ', #1
u'خرزاد': u'خِرْزَادَ', #1
u'خرزاد،': u'خُرَّزَادَ،', #4
u'خرزاذ': u'خرزاذ', #1
u'خرزاذ': u'خُرَّزاذ', #1
u'خرزاذ': u'خَرَّزَاذَ', #1
u'خرزاذ': u'خَرْزَاذَ', #1
u'خرزاذ،': u'خرزاذ،', #2
u'خرزاذ': u'خُرَّزَاذ', #2
u'خرزاذ': u'خُرَّزَاذَ', #20
u'خرزاذ': u'خُرّزاذ', #6
u'خرزاذ،': u'خُرَّزَاذَ،', #82
u'خرزبه': u'خَرَزَبِهِ', #1
u'خرسانا': u'خُرْسَانًا', #1
u'خرشة': u'خَرَشَةُ', #1
u'خرشة': u'خَرْشَةَ', #1
u'خرشة،': u'خَرَشَةَ،', #3
u'خرشة': u'خرشة', #4
u'خرشة': u'خَرَشَةَ', #89
u'خرطمانيا': u'خُرْطُمَانِيّا', #1
u'خرعبة': u'خَرْعَبَة', #1
u'خرعبة': u'خَرْعَبَةٍ', #1
u'خرقات': u'خِرَقَاتٍ', #1
u'خرقات': u'خِرْقَاتٍ', #3
u'خرقانية،': u'خُرْقَانِيَّةٌ،', #1
u'خرقانية،': u'خُرْقَانِيَّةٍ،', #1
u'خركاة': u'خَرِكَاةٍ', #1
u'خركاه': u'خركاه', #4
u'خرمة': u'خَرْمَةِ', #1
u'خرمة': u'خُرْمِة', #1
u'خرمة': u'خُرْمَةِ', #2
u'خرمرد': u'خرمرد', #1
u'خرمى': u'خَرْمَى', #1
u'خرمى': u'خرمى', #2
u'خرنبور': u'خرنبور', #1
u'خرنده': u'خرنده', #2
u'خرنوبة': u'خَرْنُوبَةً', #3
u'خرنوبة': u'خَرْنُوبَةٍ', #3
u'خرهرمز،': u'خرهرمز،', #1
u'خروبة': u'خَرُّوبَةٌ', #1
u'خروبة': u'خَرُّوبَةٍ', #11
u'خروبة': u'خَرُّوبَةً', #15
u'خروز': u'خُرُوزٌ', #1
u'خرؤه': u'خُرْؤُهُ', #3
u'خرؤه': u'خَرْؤُهُ', #5
u'خرؤها': u'خَرْؤُهَا', #3
u'خرى': u'خرى', #1
u'خرئ': u'خَرِئَ', #1
u'خرئت': u'خَرِئَتْ', #1
u'خرئه': u'خُرْئِهِ', #1
u'خرئها': u'خَرْئِهَا', #3
u'خرئها': u'خُرْئِهَا', #6
u'خريت': u'خِرّيتٍ', #1
u'خريت': u'خِرِّيتٍ', #8
u'خريت،': u'خِرِّيتٍ،', #9
u'خريتا،': u'خِرِّيتًا،', #1
u'خريتا': u'خِرّيتًا', #3
u'خريتا': u'خِرِّيتًا', #9
u'خريتة': u'خِرِّيتَةً', #1
u'خريث،': u'خُرَيْثٍ،', #1
u'خريدم': u'خريدم', #15
u'خريدن': u'خريدن', #1
u'خريدند': u'خريدند', #1
u'خريدني': u'خريدني', #1
u'خريزا': u'خَرِيزًا', #2
u'خريش': u'خَرِيشٍ', #1
u'خريش': u'خُرَيْش', #1
u'خريفة': u'خَرِيفَةٌ', #1
u'خريق': u'خُرَيْقٍ', #6
u'خريقة': u'خَرِيقَةٌ', #1
u'خريقة': u'خُرَيْقَةٌ', #1
u'خريم': u'خُرَيْمٍ', #18
u'خريم': u'خُرَيْمَ', #2
u'خريم': u'خُرَيْمِ', #25
u'خريم': u'خريم', #3
u'خريم،': u'خُرَيْمٍ،', #4
u'خريم': u'خُرَيْمٌ', #6
u'خريم': u'خُرَيْمُ', #6
u'خريما': u'خُرَيْمًا', #4
u'خرينق': u'خُرَيْنِقَ', #1
u'خزازا': u'خَزَّازًا', #1
u'خزاعى': u'خُزَاعِىٍّ', #3
u'خزام': u'خِزَامٍ', #1
u'خزامة،': u'خُزَامَةَ،', #1
u'خزامة': u'خِزَامَةَ', #5
u'خزامة': u'خُزَامَةَ', #9
u'خزامته': u'خِزَامَتِهِ', #3
u'خزآئن': u'خَزَآئِنُ', #1
u'خزايا': u'خَزَايَا', #15
u'خزفان': u'خَزَفَانَ', #1
u'خزفة': u'خَزَفَةٍ', #2
u'خزفة': u'خَزَفَةٌ', #3
u'خزقة': u'خُزُقَةٍ', #1
u'خزم': u'خَزَمَ', #1
u'خزماء': u'خَزْمَاءَ', #1
u'خزمة': u'خَزَمَة', #1
u'خزمة': u'خَزَمَةُ', #1
u'خزمة': u'خَزْمَةَ', #10
u'خزمة': u'خزمة', #2
u'خزمة': u'خَزَمَةَ', #9
u'خزيم': u'خُزَيْمٍ', #2
u'خزيمة': u'خُزَيمة', #1
u'خزيمة': u'خُزَيمَةُ', #1
u'خزيمة،': u'خُزَيْمة،', #1
u'خزيمة،': u'خُزيْمَةَ،', #1
u'خزيمة،': u'خُزَيْمَة،', #1
u'خزيمة،': u'خُزَيْمَةُ،', #1
u'خزيمة': u'خُزَيْمَةَ', #1492
u'خزيمة': u'خُزيمة', #2
u'خزيمة': u'خُزَيْمَة', #2
u'خزيمة': u'خزيمة', #27
u'خزيمة،': u'خُزَيْمَةَ،', #303
u'خزيمة،': u'خزيمة،', #31
u'خزيمة': u'خُزَيْمَةُ', #48
u'خزيمة': u'خُزَيْمة', #8
u'خزيمي': u'خُزَيْمِيٌّ', #2
u'خسب': u'خسب', #1
u'خسب': u'خَسَبٌ', #1
u'خسبم': u'خسبم', #1
u'خسرو': u'خُسْرُو', #1
u'خسرو': u'خُسْرو', #114
u'خسروانى': u'خُسْرُوَانِىٍّ', #1
u'خسرواني': u'خُسْرَوَانِيٍّ', #2
u'خسروجرد': u'خُسْرَوْجِرْدَ', #1
u'خسق': u'خَسَقَ', #3
u'خسق': u'خَسْقٍ', #6
u'خسق': u'خَسْقٌ', #8
u'خسقا': u'خَسْقًا', #4
u'خسيد': u'خسيد', #1
u'خشار': u'خُشَار', #1
u'خشاراتها': u'خُشَارَاتِهَا', #1
u'خشاشة': u'خَشَاشَة', #8
u'خشاف': u'خَشَّافٌ', #1
u'خشاف،': u'خَشَّافٍ،', #1
u'خشبانها': u'خُشْبَانُهَا', #1
u'خشخاشة': u'خَشْخَاشَةٌ', #1
u'خشرمة': u'خَشْرَمَةٌ', #1
u'خششاءه': u'خُشَشَاءَهُ', #1
u'خشكار': u'خشكار', #1
u'خشكار': u'خَشْكَارٍ', #1
u'خشكار': u'خَشْكَارَ', #1
u'خشكارا': u'خُشْكَارًا', #1
u'خشكارا': u'خشكارا', #2
u'خشكاره': u'خشكاره', #1
u'خشكريشة': u'خشكريشة', #1
u'خشكنان': u'خُشْكَنَانَ', #1
u'خشكنانة': u'خُشْكُنَانَةُ', #1
u'خشكنانيا': u'خُشْكَنَانِيًّا', #1
u'خشنام': u'خَشْنَامُ', #1
u'خشنام': u'خُشْنَامُ', #2
u'خشيب': u'خَشِيب', #1
u'خشيب': u'خَشِيبٍ', #1
u'خشيبته': u'خَشِيبَتُهُ', #1
u'خشينة': u'خُشَيْنة', #1
u'خشينة،': u'خُشَيْنَةَ،', #2
u'خشينة': u'خُشَيْنَةَ', #5
u'خصابة': u'خَصَابَةِ', #1
u'خصمون': u'خَصِمُونَ', #16
u'خصمى': u'خَصْمِى', #4
u'خصوبا': u'خَصُوبًا', #1
u'خصيانا': u'خُصْيَانًا', #1
u'خصيصى': u'خِصِّيصَى', #1
u'خصيصية': u'خَصِيصِيَّةٍ', #1
u'خصيصية': u'خَصِيصِيَّةُ', #1
u'خصيصية': u'خَصِيصِيَّةِ', #1
u'خصيفأن': u'خُصَيْفٍأَنَّ', #1
u'خصيفعن': u'خُصَيْفٌعَنْ', #1
u'خضابة': u'خِضَابَةً', #1
u'خضارمة': u'خَضَارِمَةٌ', #3
u'خضارمة': u'خَضَارِمَةٍ', #3
u'خضب': u'خَضْبً', #1
u'خضخاض': u'خِضْخَاضٍ', #2
u'خضخاض': u'خَضْخَاضٍ', #9
u'خضخاضا': u'خَضْخَاضًا', #1
u'خضخض': u'خَضْخَضَ', #1
u'خضخضة': u'خَضْخَضَةَ', #3
u'خضخضة': u'خَضْخَضَةُ', #3
u'خضخضته': u'خَضْخَضَتِهِ', #1
u'خضخضته': u'خَضْخَضْتُهُ', #1
u'خضخضه': u'خَضْخَضَهُ', #3
u'خضد': u'خَضَدَ', #4
u'خضرم': u'خَضْرَمُ', #1
u'خضرم': u'خِضْرِمُ', #1
u'خضرم': u'خِضْرِمِ', #1
u'خضرم': u'خَضْرَمَ', #2
u'خضرمنا': u'خَضْرَمْنَا', #2
u'خضرويه': u'خِضْرَوَيْهِ', #2
u'خضفا': u'خَضَفًا', #1
u'خضل': u'خَضِلٍ', #3
u'خضلاء': u'خَضْلاء', #1
u'خضمة': u'خَضِمَةٍ', #1
u'خط': u'خَطًّ', #1
u'خطامة': u'خُطَامَة', #1
u'خطاى': u'خُطَاىَ', #3
u'خطائيا': u'خَطَائِيَا', #4
u'خطاياى؟': u'خَطَايَاىَ؟', #1
u'خطاياى': u'خَطَايَاىَ', #12
u'خطبانى': u'خَطَبَانِى', #5
u'خطبتهبعد': u'خُطْبَتِهِبَعْدَ', #1
u'خطبتى': u'خُطْبَتَىِ', #1
u'خطبنى': u'خَطَبَنِى', #6
u'خطفى': u'خَطَفَى', #1
u'خطمة': u'خطمة', #1
u'خطمة،': u'خَطْمَةَ،', #1
u'خطمة': u'خَطْمَةَ', #40
u'خطئة': u'خَطِئَةٍ', #1
u'خطيط': u'خطيط', #1
u'خطيطه': u'خَطِيطَهُ', #6
u'خطيم،': u'خَطِيمٍ،', #1
u'خطيم': u'خُطَيْمٌ', #2
u'خطيما': u'خَطِيمًا', #1
u'خطيئتى': u'خَطِيئَتِى', #3
u'خفاجة': u'خَفَاجَةُ', #2
u'خفاجة': u'خَفَاجَةَ', #3
u'خفافته': u'خُفَافَتِهِ', #1
u'خفافية': u'خُفَافِيَّةٌ', #1
u'خفافية': u'خُفَافِيّةٌ', #2
u'خفرة': u'خَفَرَةٍ', #1
u'خفرة': u'خَفِرَةٍ', #1
u'خفرة': u'خُفْرَةً', #1
u'خفرة': u'خَفِرَةً', #3
u'خفرة': u'خَفِرَةٌ', #3
u'خفرتي': u'خُفْرَتِي', #1
u'خفشاء': u'خَفْشَاءَ', #1
u'خلابون': u'خَلاَّبُونَ', #1
u'خلأت': u'خَلأت', #1
u'خلأت': u'خَلأَتْ', #1
u'خلات': u'خَلَّاتٍ', #1
u'خلأت': u'خَلَأَتْ', #10
u'خلأت': u'خلأت', #2
u'خلات': u'خُلَّاتٍ', #2
u'خلأت': u'خَلأَتِ', #3
u'خلاف': u'خِلَافً', #1
u'خلاف،': u'خِلًافٌ،', #1
u'خلاوة': u'خَلاوَةٍ', #1
u'خلاوة': u'خُلَاوَةَ', #1
u'خلاوة': u'خَلَاوَةَ', #4
u'خلاوي': u'خَلَاوِي', #1
u'خلائقا': u'خَلَائِقًا', #1
u'خلبة': u'خُلْبَة', #1
u'خلبة': u'خُلْبَةٌ', #6
u'خلشها': u'خلشها', #1
u'خلط': u'خَلْطً', #1
u'خلطو': u'خَلَطُو', #1
u'خلفتنى': u'خَلَّفْتَنِى', #1
u'خلفقوله': u'خَلَفٍقَوْلُهُ', #1
u'خلفى': u'خَلَفِى', #1
u'خلفى؟': u'خَلْفِى؟', #1
u'خلفى': u'خَلْفِى', #22
u'خلقات': u'خَلِقَاتٍ', #1
u'خلقتنى': u'خَلَّقَتْنِى', #1
u'خلقق': u'خَلَقَق', #1
u'خلقى': u'خُلُقِى', #1
u'خلقى': u'خَلْقِى', #2
u'خلكان': u'خَلِّكان', #1
u'خلكان': u'خِلِّكَان', #1
u'خلكان': u'خِلِّكَانِ', #1
u'خلكان': u'خِلِّكَانَ', #10
u'خلكان': u'خَلِّكَانَ', #21
u'خللى': u'خَلِّلِى', #1
u'خلنى': u'خَلِّنِى', #1
u'خلوقة': u'خُلُوقَةً', #2
u'خلوقته': u'خَلْوَقَتِهِ', #1
u'خلى': u'خَلًى', #2
u'خليد': u'خليد', #1
u'خليد،': u'خليد،', #1
u'خليد': u'خُلَيْدٍ', #12
u'خليد': u'خُلَيْدِ', #16
u'خليد،': u'خُلَيْدٌ،', #19
u'خليد': u'خُلَيْدُ', #23
u'خليد،': u'خُلَيْدٍ،', #4
u'خليد': u'خُلَيْدٌ', #6
u'خليدا': u'خُلَيْدًا', #2
u'خليدة': u'خليدة', #1
u'خليدة': u'خُلَيْدَةَ', #6
u'خليص': u'خَلِيصَ', #1
u'خليص': u'خُلَيْصٍ', #12
u'خليص': u'خَلِيصٍ', #3
u'خليص': u'خُلَيْصٌ', #3
u'خليصا': u'خُلَيْصًا', #1
u'خليطان': u'خَلِيطَانِ', #11
u'خليطة': u'خَلِيطَةٌ', #1
u'خليطة': u'خَلِيطَةٍ', #1
u'خليطين': u'خَلِيطِينَ', #3
u'خليطين': u'خَلِيطَيْنِ', #73
u'خليطيه': u'خَلِيطَيْهِ', #4
u'خليفتى': u'خَلِيفَتِى', #1
u'خليفى': u'خِلِّيفَى', #1
u'خليلكوالوجه': u'خَلِيلُكَوَالْوَجْهُ', #1
u'خليلى': u'خَلِيلِى', #26
u'خليليون': u'خَلِيلِيُّونَ', #1
u'خمارى': u'خِمَارِى', #1
u'خماسا': u'خُمَاسًا', #2
u'خماص': u'خِمَاصَ', #1
u'خماصا': u'خِمَاصًا', #15
u'خمانة': u'خَمّانَة', #1
u'خمانة': u'خَمّانَةً', #1
u'خمائص': u'خَمَائِصُ', #1
u'خمائص': u'خَمَائِصَ', #2
u'خمدان': u'خمدان', #2
u'خمدية': u'خَمْدِيَّةٌ', #1
u'خمرقوله': u'خَمْرٍقَوْلُهُ', #1
u'خمس': u'خَمْسً', #1
u'خمسات': u'خَمْسَاتِ', #1
u'خمستان': u'خَمْسَتَانِ', #2
u'خمسمائه': u'خمسمائه', #1
u'خمسمئ': u'خَمْسُمِئ', #1
u'خمسمئي': u'خَمْسِمِئْيٍ', #1
u'خمسينا': u'خَمْسِينًا', #1
u'خمسينه': u'خَمْسِينِهِ', #11
u'خمصاء': u'خَمْصَاءُ', #3
u'خمصان': u'خُمَصَانُ', #1
u'خمصان': u'خُمْصَانُ', #1
u'خمصانة': u'خَمْصَانَةٌ', #1
u'خمصة': u'خَمْصَةَ', #1
u'خمضها': u'خَمْضِهَا', #1
u'خمط': u'خَمْطٍ', #7
u'خميرويه': u'خَمِيرُويْهِ', #1
u'خميرويه': u'خَمِيْرُوَيْهِ', #1
u'خميرويه': u'خَمِيرُوَيْهِ', #178
u'خميرويه': u'خَمِيرَوَيْهِ', #7
u'خميسيا': u'خَمِيسِيًّا', #1
u'خميسية': u'خَمِيسِيَّةٍ', #1
u'خميسيون': u'خَمِيسِيُّونَ', #1
u'خميص': u'خَمِيص', #1
u'خميص،': u'خَمِيصٌ،', #1
u'خميص': u'خَمِيصٍ', #2
u'خميص': u'خَمِيصَ', #2
u'خميص': u'خَمِيصُ', #2
u'خميصا': u'خَمِيصًا', #1
u'خميصة،': u'خَمِيصَةٌ،', #1
u'خميصة،': u'خَمِيصَةٍ،', #1
u'خميصة': u'خُمَيْصَةَ', #1
u'خميصة': u'خميصة', #2
u'خميصة': u'خَمِيصَةٍ', #27
u'خميصة': u'خَمِيصَةَ', #3
u'خميصة': u'خَمِيصَةُ', #3
u'خميصة': u'خَمِيصَةً', #30
u'خميصة': u'خَمِيصَة', #4
u'خميصة': u'خَمِيصَةٌ', #45
u'خميصته': u'خَمِيصَتَهُ', #2
u'خميصته': u'خَمِيصَتِهِ', #2
u'خميصتي': u'خَمِيصَتِي', #1
u'خميل،': u'خَمِيلٍ،', #1
u'خميل': u'خُمَيْلٌ', #1
u'خميل': u'خَمِيل', #2
u'خميل': u'خَمِيلٍ', #2
u'خناء': u'خَنَاءً', #1
u'خناب': u'خَنّابِ', #2
u'خناب': u'خِنّابِ', #3
u'خناث': u'خِنَاثٌ', #1
u'خناثة': u'خُنَاثَةً', #1
u'خنافة،': u'خنافة،', #1
u'خنافة،': u'خَنَافَةَ،', #1
u'خنافة': u'خُنَافَةَ', #3
u'خنب': u'خَنْبٍ', #39
u'خنبرة': u'خنبرة', #1
u'خنبش': u'خَنْبَشٍ', #16
u'خنبش': u'خَنْبَشَ', #2
u'خنبش': u'خنبش', #5
u'خنبق': u'خنبق', #2
u'خنبقات': u'خنبقات', #1
u'خنبقان': u'خنبقان', #1
u'خنبه': u'خَنَبِهِ', #1
u'خنتيني': u'خُنْتِينِي', #1
u'خنجرة': u'خَنْجَرَةَ', #1
u'خندف': u'خندف', #1
u'خندف': u'خَنْدَفٍ', #1
u'خندف': u'خِنْدَف', #1
u'خندف،': u'خِنْدِفٍ،', #1
u'خندف': u'خِنْدِفَ', #13
u'خندف': u'خِنْدِفٍ', #6
u'خندف': u'خِنْدِفُ', #6
u'خندم': u'خندم', #1
u'خندمه': u'خَنْدَمَهْ', #1
u'خنزب': u'خنزب', #1
u'خنزب': u'خَنْزَبٍ', #1
u'خنزب': u'خِنْزِبٌ', #1
u'خنزب': u'خَنْزَبٌ', #11
u'خنش': u'خَنَشٌ', #1
u'خنش': u'خَنْشٍ', #1
u'خنفساءة': u'خُنْفَسَاءَةٌ', #1
u'خنفساة': u'خُنْفُسَاةٌ', #1
u'خنفساة': u'خُنْفُسَاةُ', #1
u'خنفسة': u'خُنْفُسَةٌ', #2
u'خنوب': u'خنوب', #1
u'خنوخ': u'خنوخ', #1
u'خنوخ': u'خَنُوخَ', #1
u'خنوخ،': u'خَنُوخَ،', #2
u'خنور': u'خَنْوَرٍ', #2
u'خنيث': u'خَنِيثُ', #4
u'خنيس': u'خُنَيْسٌ', #10
u'خنيس': u'خُنَيْسُ', #17
u'خنيس': u'خُنَيْسَ', #2
u'خنيس': u'خُنَيْسِ', #23
u'خنيس': u'خنيس', #3
u'خنيس': u'خُنَيْس', #3
u'خنيس': u'خُنَيْسٍ', #46
u'خنيس،': u'خُنَيْسٍ،', #6
u'خنيسا': u'خُنَيْسًا', #2
u'خنيش': u'خُنَيْشٍ', #1
u'خوابس': u'خوابس', #1
u'خوابس': u'خََوابِسُ', #1
u'خوابس': u'خَوَابِسَ', #1
u'خوابس': u'خَوَابِسُ', #4
u'خواتيما،': u'خَوَاتِيمَاً،', #1
u'خواتيما': u'خَوَاتِيمَاً', #3
u'خواجا': u'خَوَاجَا', #4
u'خواجه': u'خواجه', #1
u'خواجه': u'خَوَاجَهْ', #5
u'خوارة': u'خَوَّارَةٌ', #1
u'خوارة': u'خَوَّارَةٍ', #6
u'خوارة': u'خَوَّارَةً', #7
u'خوارديكرغى': u'خوارديكرغى', #1
u'خواركى': u'خواركى', #2
u'خوارم': u'خَوَارِمَ', #1
u'خوارم': u'خَوَارِمُ', #1
u'خوارم': u'خَوَارِمِ', #8
u'خوارماندزن': u'خوارماندزن', #1
u'خواز': u'خواز', #1
u'خوازق': u'خَوَازِقَ', #2
u'خوازه': u'خوازه', #1
u'خواست': u'خواست', #6
u'خواستم': u'خواستم', #3
u'خواستن': u'خواستن', #1
u'خواستني': u'خواستني', #1
u'خواسته': u'خواسته', #1
u'خواسق': u'خَوَاسِقُ', #4
u'خواسق': u'خَوَاسِقَ', #6
u'خواش': u'خَوَاشٍ', #1
u'خواصرا': u'خَوَاصِرًا', #1
u'خواصل': u'خواصل', #2
u'خواصل': u'خَوَاصِلُ', #3
u'خواصل': u'خَوَاصِلَ', #9
u'خواقند': u'خُوَاقَنْدَ', #4
u'خواند': u'خواند', #3
u'خوانس': u'خَوَانِسُ', #1
u'خوانيد': u'خوانيد', #2
u'خواهد': u'خواهد', #5
u'خواهر': u'خُوَاهَرْ', #318
u'خواهر': u'خواهر', #50
u'خواهرت': u'خواهرت', #1
u'خواهررا': u'خواهررا', #1
u'خواهرزاده': u'خُوَاهَرْزَادَهْ', #38
u'خواهي': u'خواهي', #14
u'خواهى': u'خواهى', #2
u'خوبةوالوجه': u'خَوْبَةٌوَالْوَجْهُ', #1
u'خوبشتن': u'خوبشتن', #1
u'خوبشته': u'خَوْبَشَتِهِ', #1
u'خود': u'خُودٍ', #1
u'خود': u'خَوْدٍ', #1
u'خود': u'خَوْد', #29
u'خودا': u'خودا', #1
u'خودآزاداست': u'خودآزاداست', #1
u'خودائم': u'خودائم', #1
u'خودباي': u'خودباي', #1
u'خودبدهم': u'خودبدهم', #1
u'خودبر': u'خودبر', #1
u'خودبيار': u'خودبيار', #1
u'خودرا': u'خودرا', #8
u'خودرابتوار': u'خودرابتوار', #1
u'خودرابحل': u'خودرابحل', #1
u'خودرازيان': u'خودرازيان', #1
u'خودش': u'خودش', #1
u'خودماند': u'خودماند', #1
u'خودنهاد': u'خودنهاد', #1
u'خورات': u'خَوْرَاتٍ', #1
u'خورة': u'خَوْرَةً', #1
u'خورج': u'خُورِجَ', #1
u'خورد': u'خورد', #3
u'خوردن': u'خوردن', #1
u'خورده': u'خورده', #2
u'خوردود': u'خوردود', #1
u'خوردي': u'خوردي', #1
u'خورديم': u'خورديم', #1
u'خورش': u'خورش', #1
u'خوركه': u'خوركه', #2
u'خورم': u'خورم', #18
u'خورم': u'خُورِمَ', #2
u'خورمي': u'خورمي', #1
u'خورند': u'خورند', #1
u'خورنق': u'خَوَرْنَقُ', #1
u'خوز': u'خُوزُ', #1
u'خوز': u'خَوْزٍ', #1
u'خوز': u'خُوزَ', #7
u'خوزا': u'خُوزًا', #1
u'خوزا': u'خَوْزًا', #1
u'خوزستان': u'خُوزِسْتَانَ', #3
u'خوزي': u'خُوزِيٌّ', #1
u'خوش': u'خَوْش', #2
u'خوش': u'خوش', #6
u'خوشتين': u'خوشتين', #1
u'خوشه': u'خُوشَه', #1
u'خوشين': u'خوشين', #3
u'خوصات،': u'خُوصاتٌ،', #1
u'خوصات': u'خُوصَاتٌ', #2
u'خوصة': u'خُوصَة', #1
u'خوصة': u'خُوصَةُ', #4
u'خوصتين': u'خُوصَتَيْنِ', #1
u'خوط': u'خُوطُ', #1
u'خوطا': u'خُوطًا', #2
u'خوطان': u'خُوْطَانِ', #1
u'خوفاء': u'خَوْفَاءَ', #1
u'خوفقوله': u'خُوْفٍقَوْلُهُ', #1
u'خوفين': u'خَوْفَيْنِ', #6
u'خوك': u'خوك', #2
u'خولانان': u'خَوْلَانَانِ', #1
u'خولانى': u'خَوْلاَنِىِّ', #1
u'خولانى': u'خَوْلاَنِىٍّ', #2
u'خولتنى': u'خَوَّلْتَنِى', #2
u'خولى': u'خَوْلَى', #1
u'خوندة': u'خُونْدَةُ', #1
u'خوندة': u'خُونْدَةَ', #5
u'خويدم': u'خُوَيْدِم', #1
u'خويدمك': u'خُوَيْدِمُك', #1
u'خويدمك': u'خُوَيْدِمُكَ', #8
u'خويز': u'خُوَيْزَ', #1
u'خويز': u'خُوَيْزٍ', #4
u'خويز': u'خُوَيْزِ', #65
u'خويش': u'خويش', #33
u'خويشان': u'خويشان', #1
u'خويشتن': u'خويشتن', #35
u'خويصة': u'خُوَيْصَةً', #1
u'خويصة،': u'خُوَيْصَةٌ،', #1
u'خويصة': u'خُوَيْصَّةً', #3
u'خويصرة': u'خُوَيْصِرَةُ', #1
u'خويلة': u'خويلة', #1
u'خويلة': u'خُوَيْلَة', #1
u'خويلة': u'خُوَيْلَةَ', #15
u'خويلة': u'خُوَيْلَةُ', #15
u'خويلدا': u'خُوَيْلِدًا', #2
u'خويلدة': u'خُوَيْلِدَةَ', #1
u'خئولة': u'خُئُولَةً', #1
u'خئولة': u'خُئُولَةَ', #1
u'خئون': u'خَئُونٌ', #1
u'خئونا': u'خَئُونًا', #1
u'خئونا': u'خَئُونَا', #1
u'خيابة': u'خِيَابَةَ', #5
u'خيابر': u'خَيَابِرُ', #2
u'خيابر': u'خَيَابِرَ', #3
u'خيانت': u'خيانت', #2
u'خيانتى': u'خِيَانَتِى', #1
u'خيبر،': u'خيبرَ،', #1
u'خيبر': u'خيَبْرَ', #1
u'خيبر': u'خيْبَرَ', #1
u'خيبر': u'خَيْبَرٌ', #1
u'خيبر؟': u'خَيْبَرَ؟', #1
u'خيبر؟،': u'خَيْبَرَ؟،', #1
u'خيبر،': u'خَيْبَرَ،', #129
u'خيبر،': u'خيبر،', #13
u'خيبر': u'خَيْبَرُ', #139
u'خيبر': u'خَيبِرَ', #2
u'خيبر،': u'خَيْبر،', #2
u'خيبر': u'خَيْبَرْ', #2
u'خيبر،': u'خَيْبَر،', #2
u'خيبر': u'خَيْبَرَ', #2110
u'خيبر': u'خيبر', #30
u'خيبر': u'خَيْبَر', #31
u'خيبر': u'خَيْبَرِ', #4
u'خيبر،': u'خَيْبَرُ،', #5
u'خيبر': u'خَيْبَرٍ', #8
u'خيبراSمن': u'خَيْبَرَاSمِنْ', #1
u'خيبرا': u'خَيْبَرًا', #2
u'خيبرا': u'خَيْبَرَا', #2
u'خيبرجلوس': u'خَيْبَرَجُلُوسٌ', #1
u'خيبرظاهر': u'خَيْبَرَظَاهِرُ', #1
u'خيبري': u'خَيْبَرِيٌّ', #1
u'خيبري': u'خَيْبَرِيٍّ', #1
u'خيبرى': u'خَيْبَرِىٍّ', #1
u'خيبري': u'خَيْبَرِيّ', #2
u'خيبريا': u'خَيْبَرِيًّا', #2
u'خيبرية': u'خَيْبَرِيَّةً', #1
u'خيتام': u'خَيْتَامٌ', #1
u'خيتام': u'خَيْتَامَ', #1
u'خيتوم': u'خَيْتُومٌ', #1
u'خيثة': u'خَيْثَةَ', #1
u'خيثم': u'خيثم', #1
u'خيثم': u'خَيْثَمُ', #1
u'خيثم،': u'خُيَثْمٍ،', #1
u'خيثم،': u'خُيْثَمٍ،', #1
u'خيثم،': u'خيثمٍ،', #2
u'خيثم': u'خَيْثَم', #2
u'خيثم،': u'خَيْثَمٍ،', #3
u'خيثم': u'خَيْثَمَ', #6
u'خيثم': u'خَيْثَمٍ', #8
u'خيثمة': u'خَيْثَمْةَ', #1
u'خيثمة': u'خَيْثُمَةُ', #1
u'خيثمة': u'خَيْثْمَةَ', #1
u'خيثمة،': u'خَيْثَمَة،', #1
u'خيثمة': u'خيثمة', #12
u'خيثمة': u'خَيْثَمَةُ', #16
u'خيثمة،': u'خَيْثَمَةَ،', #248
u'خيثمة': u'خَيْثَمَة', #3
u'خيثمة،': u'خَيْثَمَةُ،', #3
u'خيثمة،': u'خيثمة،', #40
u'خيثمة': u'خَيْثَمَةَ', #560
u'خيثمة': u'خَيْثمةَ', #6
u'خير': u'خَيْرً', #1
u'خيراSحول': u'خَيْرًاSحَوْلَ', #1
u'خيراSمن': u'خَيْرًاSمِنْ', #1
u'خيرزان': u'خِيرَزَانٍ', #1
u'خيرزانات': u'خِيرَزَانَاتٌ', #1
u'خيرزو': u'خيرزو', #1
u'خيرله': u'خَيْرٌلَهُ', #1
u'خيرمن': u'خيرمن', #1
u'خيرنى': u'خَيَّرَنِىَ', #1
u'خيرنى': u'خَيِّرْنِى', #1
u'خيرنى': u'خَيَّرَنِى', #5
u'خيروروي': u'خَيْرٍوَرُوِيَ', #1
u'خيرونى': u'خَيَّرُونِى', #1
u'خيزاخز': u'خَيْزَاخَزَ', #1
u'خيس': u'خيس', #1
u'خيسه': u'خِيسَهُ', #1
u'خيسه': u'خَيَّسَهُ', #1
u'خيشتين،': u'خيشتين،', #1
u'خيشتين': u'خَيْشَتَيْنِ', #3
u'خيشنة': u'خيشنة', #1
u'خيشنة': u'خَيْشَنَة', #1
u'خيشنة': u'خَيْشَنَةَ', #2
u'خيطف': u'خَيْطَفٌ', #1
u'خيطفا': u'خَيْطَفَا', #1
u'خيلاء': u'خُيَلاءً', #1
u'خيلاء': u'خُيَلاَءً', #1
u'خيلة': u'خيلة', #1
u'خيلخان': u'خَيْلَخَانَ', #1
u'خيوان': u'خَيْوَانُ', #1
u'خيوان،': u'خَيْوَانَ،', #1
u'خيوان': u'خَيْوَانَ', #9
u'خيور': u'خُيُورٌ', #1
u'خيور': u'خُيُورٍ', #1
u'خيور': u'خُيُورُ', #1
u'خيور': u'خُيُورِ', #4
u'خيية': u'خُيَيّةٌ', #1
u'دءوب': u'دَءُوبِ', #1
u'دآب،': u'دَآبٍ،', #1
u'دأبة': u'دَأْبَةً', #1
u'دآبة': u'دَآبَّةٍ', #2
u'دأبة': u'دَأْبَةٌ', #2
u'دابةأبيض': u'دَابَّةٌأَبْيَضُ', #1
u'دابةوروي': u'دَابَّةٍوَرُوِيَ', #1
u'دابتى': u'دَابَّتِى', #6
u'دأبى': u'دَأْبِى', #1
u'داتشمند': u'داتشمند', #1
u'داحس': u'دَاحِسً', #1
u'داخرة': u'دَاخِرَةَ', #1
u'داخرون': u'دَاخِرُونَ', #1
u'داخرين': u'دَاخِرِينَ', #14
u'دادبس': u'دادبس', #1
u'دادبيش': u'دادبيش', #1
u'دادش': u'دادش', #1
u'دادكه': u'دادكه', #3
u'دادم': u'دادم', #37
u'دادمت': u'دادمت', #8
u'دادمش': u'دادمش', #3
u'دادند': u'دادند', #4
u'دادني': u'دادني', #6
u'دادنى': u'دادنى', #7
u'داده': u'دَادَهْ', #1
u'داده': u'داده', #28
u'دادوما،': u'دَادُومًا،', #1
u'دادويه': u'دادَوَيْه', #1
u'دادويه': u'دَادَوَيْهِ', #1
u'دادى': u'دادى', #1
u'دادى': u'دَادَى', #1
u'دادئى': u'دادئى', #1
u'داذه': u'داذه', #8
u'داذوى': u'دَاذُوَىَّ', #1
u'داذويه': u'دَاذَوَيْهِ', #2
u'دار': u'دَارً', #2
u'دارء': u'دَارِءٍ', #1
u'داراء': u'داراء', #1
u'داراء': u'دَارَاءَ', #1
u'دارابجرد': u'دارابْجِرْد', #1
u'داراز': u'داراز', #1
u'دارد': u'دارد', #5
u'دارشود': u'دارشود', #1
u'دارقطني': u'دَارَقُطْنِيٌّ', #1
u'داز': u'داز', #1
u'داشت': u'دَاشَتْ', #1
u'داشت': u'داشت', #3
u'داشتم': u'داشتم', #17
u'داشتمت': u'داشتمت', #3
u'داشتمش': u'داشتمش', #1
u'داشتن': u'داشتن', #2
u'داشته': u'داشته', #2
u'داشتى': u'داشتى', #1
u'داشتي': u'داشتي', #4
u'داغستاني': u'دَاغِسْتَانِيٌّ', #1
u'دافة': u'دَافَّة', #1
u'دافة': u'دَافّةٌ', #2
u'دافة': u'دَافَّةٌ', #6
u'دافر': u'دَافِرٌ', #1
u'دافرة': u'دَافِرَةٍ', #2
u'دافعSقصيدة': u'دَافِعُSقَصِيدَةُ', #1
u'دالح': u'دَالِحٍ', #2
u'دالحة': u'دَالِحَةٍ', #1
u'داماد': u'دَامَادْ', #2
u'دامر': u'دَامِرَ', #1
u'دامر': u'دَامِرُ', #1
u'دامر': u'دَامِرِ', #3
u'دامرينا': u'دَامِرِينَا', #2
u'دامشق': u'دَامِشْقُ', #2
u'داناهمو': u'دَانَاهُمُو', #1
u'داندكه': u'داندكه', #1
u'دانست': u'دانست', #1
u'دانشمند': u'دانشمند', #2
u'دانشمندان': u'دانشمندان', #1
u'دانشمندك': u'دانشمندك', #1
u'دانشمندي': u'دانشمندي', #1
u'دانق': u'دَانِقً', #1
u'دانق،': u'دَانِقٌ،', #1
u'دانق': u'دَانِقٌ', #16
u'دانق': u'دَانَقَ', #2
u'دانق': u'دَانَقِ', #2
u'دانق': u'دَانِقِ', #2
u'دانق': u'دَانَقٍ', #22
u'دانق': u'دَانِقٍ', #27
u'دانق': u'دَانِقَ', #3
u'دانق': u'دَانَقٌ', #9
u'دانقا': u'دَانَقًا', #28
u'دانقا': u'دَانِقًا', #36
u'دانقان': u'دَانِقَانِ', #3
u'دانقان': u'دَانَقَانِ', #7
u'دانقه': u'دَانَقِهِ', #1
u'دانقين': u'دَانِقَيْنِ', #13
u'دانقين': u'دَانَقَيْنِ', #9
u'دانم': u'دانم', #3
u'دانند': u'دانند', #1
u'دانندوا': u'دانندوا', #1
u'دانيال': u'دانيال', #1
u'دانيال': u'دَانِيَالَ', #1
u'دانيال': u'دَانِيَالُ', #1
u'دانيال،': u'دَانْيَالَ،', #1
u'دانيال،': u'دَانْيَالُ،', #1
u'دانيال': u'دَانْيَالُ', #15
u'دانيال': u'دَانْيَالَ', #19
u'دانيم': u'دانيم', #1
u'داوة': u'دَاوَةً', #1
u'داوة': u'دَاوَةٍ', #1
u'داودالحديث': u'دَاوُدَالْحَدِيثُ', #1
u'داودهو': u'دَاوُدَهَوُ', #1
u'داودي': u'دَاوُدِيِّ', #2
u'داوردان،': u'دَاوِرْدَانُ،', #1
u'داوردان': u'دَاوِرْدَانُ', #2
u'دائد': u'دَائِدٌ', #1
u'دآئرة': u'دَآئِرَةٌ', #1
u'دائف': u'دَائِفٍ', #1
u'دائلة': u'دَائِلَةٌ', #2
u'دائميا': u'دَائِمِيًّا', #4
u'دايم': u'دايم', #1
u'دايموا': u'دَايَمُوا', #1
u'دباء': u'دَبَاءَ', #1
u'دباء': u'دُبَّاءٌ', #18
u'دباء': u'دُبَّاءُ', #3
u'دباء،': u'دُبَّاءٌ،', #3
u'دباء': u'دُبَّاءَ', #4
u'دباء': u'دُبَّاءٍ', #5
u'دباءة': u'دُبَّاءَةٌ', #1
u'دباءة،': u'دُبَّاءَةٍ،', #1
u'دباءة': u'دُبَّاءَةٍ', #7
u'دبأة': u'دَبْأَةٌ', #1
u'دبائج': u'دَبَائِج', #1
u'دبايج': u'دَبَايِجُ', #1
u'دبرانا': u'دَبَرَانًا', #2
u'دبردل': u'دبردل', #1
u'دبرهاالوجه': u'دُبُرِهَاالْوَجْهُ', #1
u'دبز': u'دبز', #1
u'دبز': u'دَبَزْ', #1
u'دبسى': u'دُبْسِىٌّ', #1
u'دبشوهرى': u'دبشوهرى', #1
u'دبغتيها': u'دَبَغْتِيهَا', #1
u'دبنزديك': u'دبنزديك', #1
u'دبوطا': u'دبوطا', #1
u'دبى': u'دَبًى', #2
u'دبيانته': u'دِبيَانَتِهِ', #1
u'دبير': u'دُبَيْرٍ', #2
u'دبير': u'دَبِيرٍ', #4
u'دبيرستان': u'دبيرستان', #1
u'دبيره': u'دَبِيرِهِ', #1
u'دبيس': u'دُبَيْسٌ', #1
u'دبيس': u'دُبَيْسِ', #1
u'دبيس،': u'دُبَيْسُ،', #1
u'دبيس،': u'دُبَيْسٍ،', #3
u'دبيل': u'دَبِيلٌ', #1
u'دبيل': u'دَبِيلَ', #1
u'دبيل': u'دَبِيلٍ', #6
u'دبيلي': u'دَبِيلِيٌّ', #2
u'دة': u'دَةُ', #1
u'دت': u'دت', #8
u'دتراز': u'دتراز', #1
u'دثرونى': u'دَثِّرُونِى', #1
u'دثرونى': u'دثرونى', #2
u'دثنة': u'دَثْنَة', #3
u'دجانة': u'دجانة', #1
u'دجانة،': u'دُجَانة،', #1
u'دجانة': u'دُجَانَةَ', #152
u'دجانة': u'دُجَانَة', #2
u'دجانة،': u'دُجَانَةَ،', #5
u'دجيل': u'دُجَيْلٌ', #1
u'دجيل': u'دُجَيْلٍ', #1
u'دجيل،': u'دُجَيْلَ،', #1
u'دجيل،': u'دُجَيْلٍ،', #2
u'دجيل': u'دُجَيْلَ', #6
u'دحاء': u'دِحَاءٌ', #1
u'دحد': u'دحد', #1
u'دحداح': u'دَحْدَاحٍ', #1
u'دحداح': u'دَحْدَاحٌ', #2
u'دحداحا': u'دحداحا', #1
u'دحداحا': u'دَحْداحًا', #1
u'دحداحا': u'دَحْدَاحًا', #1
u'دحداحا': u'دحداحًا', #3
u'دحدحا': u'دَحْدَحًا', #1
u'دحضات': u'دَحَضَاتٍ', #1
u'دحمسة،': u'دِحْمَسَةٍ،', #1
u'دحمون': u'دَحْمُونٍ', #1
u'دحورا': u'دُحُورًا', #7
u'دحيبة': u'دُحَيْبَةُ', #1
u'دحية': u'دحية', #1
u'دحية': u'دِحيةَ', #1
u'دحية': u'دِحْية', #1
u'دحية': u'دِحْيةَ', #1
u'دحية': u'دِحْيةُ', #1
u'دحية': u'دِحيَةُ', #1
u'دحية': u'دِحْيَةِ', #1
u'دحية': u'دِحْيَةَ', #139
u'دحية': u'دِحْيَة', #16
u'دحية،': u'دِحْيَةُ،', #2
u'دحية': u'دِحْيَةٍ', #4
u'دحية': u'دِحْيَةُ', #53
u'دحية': u'دَحْيَةَ', #7
u'دحيم': u'دُحَيْمٌ', #103
u'دحيم،': u'دُحَيْمٍ،', #18
u'دحيم': u'دُحَيْمٍ', #195
u'دحيم': u'دحيم', #21
u'دحيم': u'دُحَيْم', #3
u'دحيم': u'دُحَيْمِ', #3
u'دحيم،': u'دُحَيْمٌ،', #37
u'دحيم': u'دُحَيْمُ', #6
u'دحيم،': u'دحيم،', #8
u'دحيما': u'دُحَيْماً', #1
u'دحيما': u'دُحَيْمًا', #1
u'دحينا': u'دُحَيْنًا', #1
u'دخ': u'دُخٌّ', #3
u'دخارص': u'دَخَارِصُ', #1
u'دخاريص': u'دَخَارِيص', #1
u'دخاريص': u'دَخَارِيصَ', #3
u'دخاريصه': u'دَخَارِيصُهُ', #1
u'دخاريصه': u'دَخَارِيصَهُ', #4
u'دختر': u'دختر', #8
u'دخترر': u'دخترر', #1
u'دخر': u'دَخِرَ', #1
u'دخر': u'دَخْرٌ', #1
u'دخر': u'دَخَرَ', #2
u'دخريص': u'دِخْرِيصٍ', #4
u'دخريصه': u'دِخْرِيصِهِ', #1
u'دخش': u'دخش', #1
u'دخشم': u'دُخْشُمٍ', #2
u'دخلالمسجد': u'دَخَلَالْمَسْجِدَ', #1
u'دخولكها': u'دُخُولُكَهَا', #2
u'دخولهإلا': u'دُخُولِهِإِلَّا', #1
u'دخي': u'دخي', #2
u'دخيشم': u'دُخَيْشَمٍ', #1
u'دخين': u'دخين', #1
u'دخين': u'دُخَيْنٌ', #3
u'دخين': u'دُخَيْنٍ', #5
u'دداردو': u'دداردو', #1
u'ددزبرد': u'ددزبرد', #1
u'دده': u'دده', #2
u'دده': u'دَدَهْ', #7
u'ددهى': u'ددهى', #1
u'ددوازده': u'ددوازده', #1
u'ددى': u'دَدَى', #1
u'درء': u'دَرْءً', #3
u'درءة': u'دَرْءَةً', #2
u'دراءة': u'دَرَاءَةً', #1
u'درابزين': u'دَرَابِزِينٍ', #1
u'درابزين': u'دَرَابْزِينَ', #1
u'دراريب': u'دَرَارِيبِ', #1
u'دراريب': u'دَرَارِيبَ', #2
u'درازست': u'درازست', #1
u'دراكا': u'دِرَاكًا', #2
u'درام': u'دِرَامٍ', #1
u'درآمد': u'درآمد', #1
u'دراند': u'دراند', #1
u'دراهما': u'دَرَاهِمًا', #4
u'دراهمى': u'دَرَاهِمِى', #2
u'دراورد': u'دراورد', #1
u'دراوردي': u'دَرَاوَرْدِيُّ', #1
u'درآيد': u'درآيد', #1
u'درايه': u'دِرَايَهْ', #3
u'درباس': u'دِرْبَاسٌ', #1
u'درباس': u'دِرْبَاسُ', #1
u'درباس': u'دِرْبَاسٍ', #3
u'درباسا': u'دِرْبَاسًا', #1
u'درباشي': u'درباشي', #1
u'درباغ': u'درباغ', #6
u'درباغها': u'درباغها', #2
u'دربنده': u'دَرَبَنْدِهِ', #2
u'دربهشت': u'دربهشت', #1
u'دربيش': u'دربيش', #1
u'درتست': u'درتست', #1
u'درجندين': u'درجندين', #1
u'درجوار': u'درجوار', #1
u'درحدود': u'درحدود', #1
u'درحق': u'درحق', #1
u'درحواستني': u'درحواستني', #1
u'درخانة': u'دَرَخَانَةَ', #1
u'درخانة': u'درخانة', #2
u'درخانه': u'درخانه', #2
u'درختان': u'درختان', #1
u'درد': u'دَرِدَ', #2
u'درد': u'دَرْدْ', #2
u'دردا': u'دَرَدًا', #1
u'دردست': u'دردست', #10
u'دردشت': u'دردشت', #1
u'درده': u'درده', #1
u'دردهان': u'دردهان', #1
u'دردى': u'دُرْدِىٌّ', #1
u'درديهي': u'درديهي', #1
u'درراه': u'دِرَرَاه', #1
u'دررمان': u'دررمان', #1
u'درستويه،': u'درستويه،', #1
u'درستويه،': u'دَرَسْتَوَيْهِ،', #1
u'درستويه،': u'دُرُسْتُوَيْهِ،', #1
u'درستويه': u'دَرَسْتُوَيْهِ', #11
u'درستويه': u'دُرُسْتُوَيْهِ', #141
u'درستويه': u'دُرُسْتَوَيْهِ', #25
u'درستويه': u'دَرَسْتَوَيْهِ', #34
u'درشكيبد': u'درشكيبد', #1
u'درضمانم': u'درضمانم', #1
u'درعى': u'دِرْعِى', #6
u'درغم': u'دِرْغَمٍ', #2
u'درفش': u'درفش', #1
u'دركاه': u'دَرَكَاهُ', #1
u'دركردم': u'دركردم', #1
u'درمال': u'درمال', #2
u'درمكة': u'دَرْمَكَةٌ', #9
u'درنوك': u'دَرِنُوك', #1
u'درنوك': u'دَرْنُوكٍ', #1
u'درنوكا': u'دُرْنُوكًا', #5
u'درهمSحول': u'دِرْهَمٍSحَوْلَ', #1
u'درهماقوله': u'دِرْهَمًاقَوْلُهُ', #1
u'درهمسا': u'درهمسا', #1
u'درهمى': u'دِرْهَمِى', #1
u'درههم': u'دَرْهِهِمْ', #1
u'درو': u'درو', #1
u'دروت': u'دروت', #1
u'درود': u'درود', #1
u'دروروزا': u'دروروزا', #1
u'دروغ': u'دروغ', #9
u'دروغست': u'دروغست', #1
u'دروكر': u'دروكر', #1
u'درويدن': u'درويدن', #1
u'دريء': u'دِرِّيءٌ', #1
u'درياق': u'دِرْيَاقٌ', #1
u'درياق': u'دِرْيَاقٍ', #1
u'دريد': u'دُريد', #1
u'دريد': u'دُرَيد', #1
u'دريد': u'دُرَيْدٍ', #121
u'دريد': u'دُرَيْدٌ', #19
u'دريد': u'دريد', #2
u'دريد،': u'دُرَيْدٌ،', #2
u'دريد': u'دُرَيْدُ', #22
u'دريد': u'دُرَيْدَ', #25
u'دريد': u'دُرَيْد', #4
u'دريد': u'دُرَيْدِ', #8
u'دريدا': u'دُرَيْدًا', #6
u'دريده': u'دريده', #1
u'دريع': u'دُرَيْعٍ', #1
u'دريعة': u'دُرَيْعَةٌ', #1
u'دريغ': u'دريغ', #2
u'درينة': u'دُرَيْنَةُ', #1
u'دز': u'دز', #1
u'دزدبردبافندة': u'دزدبردبافندة', #1
u'دزن': u'دزن', #2
u'دساكره': u'دَسَاكِرُهُ', #1
u'دستار': u'دستار', #1
u'دستتين': u'دَسْتَتَيْنِ', #1
u'دستجات': u'دُسْتُجَاتِ', #1
u'دستجات': u'دَسْتَجَاتٍ', #2
u'دستجة': u'دَسْتَجَةٌ', #1
u'دستره': u'دستره', #3
u'دستهء': u'دستهء', #1
u'دستيمان': u'دستيمان', #6
u'دسعة': u'دَسْعَةٌ', #2
u'دسعة': u'دَسْعَةٍ', #3
u'دسعة': u'دَسْعَةً', #4
u'دسكرة': u'دَسْكَرةٍ', #1
u'دسكرة': u'دَسْكَرَةِ', #2
u'دسكرة': u'دَسْكَرَةً', #3
u'دسكرة': u'دَسْكَرَةٍ', #3
u'دسورة': u'دسورة', #1
u'دسوماتها': u'دُسُومَاتِهَا', #1
u'دسومة': u'دُسُومَةِ', #1
u'دسومة': u'دُسُومَةٌ', #18
u'دسومة': u'دُسُومَةٍ', #4
u'دسومة': u'دُسُومَةً', #5
u'دسومة': u'دُسُومَةَ', #7
u'دسومتها': u'دُسُومَتِهَا', #1
u'دسومتها': u'دُسُومَتَهَا', #2
u'دشار': u'دِشَارٍ', #1
u'دشتا': u'دَشْتًا', #5
u'دشمن': u'دشمن', #4
u'دعاس': u'دَعَّاسٍ', #1
u'دعامةحدثه،': u'دِعَامَةَحَدَّثَهُ،', #1
u'دعاميص': u'دَعَامِيصُ', #8
u'دعانى': u'دَعَانِى', #21
u'دعاوة': u'دَعَاوَةَ', #1
u'دعاوة': u'دِعَاوَةَ', #1
u'دعائى': u'دُعَائِى', #2
u'دعثور': u'دُعْثُور', #1
u'دعثور': u'دُعْثُورَ', #1
u'دعج': u'دَعَجٌ', #1
u'دعج،': u'دَعَجٌ،', #1
u'دعجا': u'دَعَجًا', #1
u'دعجا': u'دَعِجًا', #1
u'دعجاء': u'دَعْجَاءُ', #4
u'دعدا': u'دَعْدَا', #1
u'دعدا': u'دَعْدًا', #3
u'دعداع': u'دَعْدَاعِ', #2
u'دعلج': u'دَعْلَجٌ', #1
u'دعلج،': u'دِعْلِجٍ،', #1
u'دعلج': u'دَعْلَجٍ', #11
u'دعلج،': u'دَعْلَجٍ،', #13
u'دعلج،': u'دعلج،', #2
u'دعلج': u'دَعْلَجَ', #2
u'دعلج،': u'دَعْلَجٌ،', #4
u'دعلج': u'دَعْلَجُ', #65
u'دعلج': u'دعلج', #8
u'دعلج': u'دَعْلَجِ', #8
u'دعموص': u'دعموص', #1
u'دعموص': u'دُعَمُوصٍ', #1
u'دعموص': u'دُعْمُوص', #1
u'دعموص': u'دُعْمُوصٍ', #2
u'دعموص': u'دَعْمُوصٍ', #3
u'دعموص': u'دُعْمُوصُ', #4
u'دعمى': u'دعمى', #1
u'دعمى': u'دُعْمّى', #1
u'دعنى': u'دَعْنِى', #12
u'دعوتى': u'دَعْوَتِى', #12
u'دعوتيات': u'دَعْوَتِيَّاتٍ', #1
u'دعوتية': u'دَعْوَتِيَّةً', #1
u'دعوتية': u'دَعْوَتِيَّةٍ', #1
u'دعوتيني': u'دَعَوْتِينِي', #5
u'دعونى': u'دَعُونِى', #7
u'دعويهما': u'دَعْوَيْهُمَا', #1
u'دعويهما': u'دَعْوَيْهِمَا', #1
u'دعى': u'دعى', #3
u'دعى': u'دَعِى', #5
u'دعى': u'دَعَّى', #5
u'دعى': u'دُعِىَ', #54
u'دعى': u'دَعَى', #6
u'دعيبات': u'دُعَيْبَاتِ', #1
u'دعيناهما': u'دَعَيْنَاهُمَا', #1
u'دعيوة': u'دُعَيْوَةً', #1
u'دغاول': u'دَغَاوِلِ', #2
u'دغفقة': u'دَغْفَقَةً', #2
u'دغفل': u'دَغْفَل', #1
u'دغفل،': u'دَغْفَلٍ،', #1
u'دغفل': u'دَغْفَلٌ', #2
u'دغفل': u'دَغْفَلُ', #2
u'دغفل': u'دَغْفَلِ', #3
u'دغفل': u'دغفل', #6
u'دغفل': u'دَغْفَلٍ', #6
u'دغفلا': u'دَغْفَلًا', #1
u'دغن': u'دَغَنَ', #1
u'دغنة': u'دُغُنَّةٍ', #1
u'دغهم': u'دِغْهَمْ', #1
u'دغيبات': u'دغيبات', #1
u'دفار': u'دِفَارِ', #1
u'دفار': u'دَفَارُ', #10
u'دفار': u'دَفَارِ', #9
u'دفاق': u'دِفَاقَ', #1
u'دفتى': u'دَفَّتَىْ', #2
u'دفر': u'دَفَرَ', #1
u'دفر': u'دَفَرُ', #1
u'دفر': u'دَفْرٌ', #1
u'دفر': u'دَفْرُ', #1
u'دفر': u'دَفْرٍ', #2
u'دفر': u'دَفْرَ', #2
u'دفرا': u'دَفْرًا', #1
u'دفراء': u'دَفْرَاءُ', #4
u'دفراه': u'دَفْرَاه', #1
u'دفره': u'دَفْرُهُ', #1
u'دفعان': u'دَفْعَانِ', #1
u'دفعتنى؟': u'دَفَعْتَنِى؟', #1
u'دفعه': u'دُفْعَهً', #2
u'دفنتمونى': u'دَفَنْتُمُونِى', #2
u'دفيء': u'دَفِيءَ', #2
u'دفيترات': u'دُفَيْتِرَاتٍ', #2
u'دق': u'دَقًّ', #1
u'دقرة': u'دِقْرَةُ', #1
u'دقرة': u'دِقْرَةَ', #2
u'دقعاء': u'دَقْعَاءَ', #5
u'دقل،': u'دَقْلٌ،', #1
u'دقل': u'دَقَلٍ', #14
u'دقلا': u'دَقَلاً', #1
u'دقلا': u'دَقَلًا', #4
u'دقوقاء': u'دَقُوقَاءَ', #1
u'دقيانوس': u'دِقْيَانُوسَ', #1
u'دقيوس،': u'دقيوس،', #1
u'دكاء': u'دَكَّاءَ', #5
u'دكادك': u'دَكَادكٍ', #1
u'دكادك': u'دَكادِكٍ', #1
u'دكادك': u'دَكَادِكٍ', #1
u'دكادك': u'دَكَادِكَ', #1
u'دكانة': u'دكانة', #3
u'دكرده': u'دكرده', #1
u'دكل': u'دكل', #1
u'دلاص': u'دِلَاصٌ', #3
u'دلاليلها': u'دَلَالِيلَهَا', #1
u'دلامة': u'دَلامَةَ', #1
u'دلامة': u'دُلامَةُ', #1
u'دلامة': u'دُلَامَةَ', #1
u'دلامة': u'دُلامَةَ', #2
u'دلبر': u'دلبر', #3
u'دلتنك': u'دلتنك', #1
u'دلجة': u'دُلَجَةَ', #1
u'دلجة': u'دُلْجَةً', #1
u'دلجة،': u'دُلْجَةَ،', #1
u'دلجة؟': u'دُلْجَةً؟', #1
u'دلجة': u'دُلْجَةَ', #6
u'دلحة': u'دَلَحَةَ', #1
u'دلدلا': u'دُلْدُلًا', #1
u'دلسة': u'دَلْسَةٍ', #1
u'دلسة': u'دُلْسَةٌ', #1
u'دلسة': u'دُلْسَةَ', #1
u'دلسة': u'دُلْسَةٍ', #18
u'دلسة': u'دُلْسَةً', #4
u'دلستموني': u'دَلَّسْتُمُونِي', #1
u'دلسته': u'دُلْسَتِهِ', #1
u'دلسته': u'دَلَّسَتْهُ', #3
u'دلنى': u'دَلَّنِى', #1
u'دلنى': u'دُلَّنِى', #6
u'دلهة': u'دَلْهَةُ', #1
u'دلونى': u'دُلُّونِى', #5
u'دلوى': u'دَلْوَى', #1
u'دليج': u'دُلَيْجٍ', #3
u'دلير': u'دلير', #1
u'دليم': u'دُليم', #1
u'دليم': u'دُلَيم', #1
u'دليم': u'دُلَيْمُ', #1
u'دليم': u'دليم', #2
u'دليم': u'دُلَيْمِ', #5
u'دليم': u'دُلَيْمٍ', #7
u'دماث': u'دِمَاثٍ', #1
u'دماث،': u'دَماثٍ،', #2
u'دمادم': u'دُمَادِم', #1
u'دماركست': u'دماركست', #1
u'دماس': u'دِمَاسٌ', #1
u'دماغة': u'دماغة', #1
u'دماميني': u'دَمَامِينِيٌّ', #1
u'دمة': u'دَمَةٌ', #1
u'دمد': u'دمد', #1
u'دمشاق': u'دِمْشَاقُ', #1
u'دمشقا': u'دِمَشْقًا', #2
u'دمشقش': u'دِمَشْقَشُ', #1
u'دمشقى': u'دِمَشْقِىٌّ', #1
u'دمعى': u'دَمْعِى', #1
u'دمكا': u'دَمْكًا', #1
u'دمكه': u'دَمَكَهُ', #1
u'دمنهي': u'دمنهي', #1
u'دمهوجي': u'دَمْهُوجِيٌّ', #2
u'دموالوجه': u'دَمٌوَالْوَجْهُ', #1
u'دموعابك': u'دُمُوعًابِكَ', #4
u'دمون': u'دَمّونَ', #1
u'دمون': u'دَمّونُ', #8
u'دمياط': u'دِمْيَاطُ', #1
u'دمياط': u'دِمْيَاطَ', #15
u'دميدارم': u'دميدارم', #1
u'دميري': u'دَمِيرِي', #1
u'دميري': u'دَمِيرِيٌّ', #106
u'دميري': u'دُمَيْرِيٌّ', #2
u'دميكا': u'دميكا', #1
u'دميكين': u'دميكين', #1
u'دناء': u'دَنَاءَ', #1
u'دناء': u'دَنّاءُ', #1
u'دنار': u'دَنَارٌ', #1
u'دنباوند': u'دَنْبَاوَنْدَ', #1
u'دنق': u'دَنَقَ', #1
u'دنق': u'دَنَّقَ', #1
u'دنقز': u'دُنْقُزَ', #1
u'دنقلة': u'دُنْقُلَةَ', #2
u'دنل': u'دنل', #1
u'دنوقا،': u'دُنُوقَا،', #1
u'دنوقا،': u'دَنُوقَا،', #5
u'دنوقا': u'دَنُوقَا', #8
u'دنوى': u'دُنْوَى', #1
u'دنيال': u'دنيال', #1
u'دنياهق': u'دنياهق', #1
u'دنياى': u'دُنْيَاىَ', #1
u'دنير': u'دُنَيْرٍ', #1
u'دنيرات': u'دُنَيْرَاتٍ', #1
u'دنيم': u'دنيم', #1
u'دنينير': u'دُنَيْنِيرٌ', #4
u'دنينيرات': u'دُنَيْنِيرَاتٍ', #1
u'دهاد': u'دهاد', #2
u'دهارير': u'دَهَارِيرُ', #1
u'دهاس،': u'دَهَاس،', #1
u'دهاسا': u'دَهَاسًا', #2
u'دهانة': u'دَهَّانَة', #1
u'دهبل': u'دَهْبَلَ', #1
u'دهبل': u'دَهْبَلٍ', #3
u'دهثم': u'دَهْثَمٌ', #1
u'دهثم': u'دهثم', #2
u'دهثم': u'دَهْثَمٍ', #3
u'دهثم': u'دَهْثَمِ', #5
u'دهثم': u'دَهْثَمُ', #6
u'دهد': u'دهد', #1
u'دهدجون': u'دهدجون', #1
u'دهدفا': u'دهدفا', #1
u'دهدهي': u'دهدهي', #1
u'دهرى': u'دَهْرِى', #2
u'دهقانة': u'دُهْقَانَةَ', #1
u'دهقانة': u'دِهْقَانَةً', #1
u'دهقانة،': u'دُهْقَانَةَ،', #1
u'دهقانة': u'دِهْقَانَةَ', #2
u'دهقانة': u'دِهْقَانَةُ', #2
u'دهقل': u'دَهْقَلٍ', #1
u'دهل': u'دُهْلِ', #1
u'دهند': u'دهند', #1
u'دهير': u'دهير', #1
u'دهيم': u'دهيم', #2
u'دؤاب': u'دُؤَابُ', #1
u'دوات': u'دَوَات', #1
u'دواجب': u'دواجب', #2
u'دؤاد': u'دؤاد', #1
u'دؤاد': u'دُؤَادَ', #1
u'دواد': u'دوَّادُ', #1
u'دواد': u'دَوَّادُ', #1
u'دواد': u'دَواُدَ', #1
u'دواد': u'دُوَادٍ', #1
u'دواد،': u'دَوَّادٍ،', #1
u'دواد': u'دَوُادُ', #3
u'دواد': u'دُوَاد', #3
u'دواد': u'دُوَادَ', #3
u'دؤاد': u'دُؤَادٍ', #8
u'دواد': u'دَوُادَ', #9
u'دواريق': u'دَوَارِيقَ', #5
u'دواز': u'دُوَازْ', #1
u'دوازده': u'دُوَازْدَهْ', #2
u'دوازده': u'دوازده', #28
u'دواس': u'دَوَّاسُ', #1
u'دواست': u'دواست', #1
u'دواف': u'دَوَافٍ', #1
u'دواف': u'دَوَافٌّ', #1
u'دوالح': u'دَوَالِحُ', #1
u'دوانق': u'دَوَانِقُ', #3
u'دوانق': u'دَوَانِقِ', #3
u'دوانق': u'دَوَانِقَ', #93
u'دوانيق': u'دَوَانِيقُ', #2
u'دوانيق': u'دَوَانِيقِ', #2
u'دوانيق': u'دَوَانِيقَ', #34
u'دوايزده': u'دوايزده', #1
u'دوباره': u'دُوبَاره', #1
u'دوبست': u'دوبست', #1
u'دوبناوند': u'دوبناوند', #1
u'دوتن': u'دوتن', #1
u'دوتيرازسه': u'دوتيرازسه', #1
u'دوجهان': u'دوجهان', #1
u'دوختر': u'دوختر', #1
u'دوخلة': u'دَوْخَلَّةٌ', #1
u'دوداشت': u'دوداشت', #1
u'دودانية': u'دُودَانِيَّةٌ', #1
u'دورقة': u'دَوْرَقَةِ', #1
u'دوروز': u'دوروز', #2
u'دوروزويمن': u'دوروزويمن', #1
u'دوز': u'دوز', #1
u'دوزاده': u'دوزاده', #2
u'دوزخ': u'دوزخ', #1
u'دوستانرا': u'دوستانرا', #1
u'دوسى': u'دَوْسِىٍّ', #1
u'دوسيا': u'دَوْسِيًّا', #1
u'دوسيا': u'دَوْسِيٍّا', #1
u'دوغ': u'دوغ', #2
u'دوغا': u'دُوغًا', #2
u'دوقته': u'دَوْقَتَهُ', #1
u'دوكانمهر': u'دوكانمهر', #1
u'دوكس': u'دوكس', #1
u'دوكلان': u'دوكلان', #1
u'دولات': u'دَوْلَاتٌ', #1
u'دؤلي': u'دُؤَلِيّ', #1
u'دوماوند': u'دُومَاوَنْدَ', #1
u'دومة؟': u'دُومَةَ؟', #1
u'دومة،': u'دَوْمَةٍ،', #1
u'دومة': u'دُومَةِ', #14
u'دومة': u'دَوْمَةِ', #16
u'دومة': u'دَوْمَةَ', #18
u'دومة': u'دُومة', #2
u'دومة': u'دُومَة', #2
u'دومة': u'دُومَةٍ', #2
u'دومة': u'دُومَةُ', #3
u'دومة': u'دُومَةَ', #31
u'دومة،': u'دُومَةَ،', #4
u'دومة': u'دَوْمَةٍ', #4
u'دومة': u'دَوْمَةُ', #5
u'دومع': u'دومع', #1
u'دومى': u'دَوَمَى', #1
u'دومين،': u'دُومِينَ،', #1
u'دومين': u'دَوْمِينُ', #2
u'دون': u'دُونً', #1
u'دونكا': u'دُونَكَا', #5
u'دونكها': u'دُوَنَكَهَا', #1
u'دونكها': u'دُونَكَهَا', #3
u'دونمات': u'دُونَمَاتٌ', #2
u'دونمات': u'دُونَمَاتٍ', #5
u'دونماته': u'دُونَمَاتِهِ', #2
u'دونماتها': u'دُونَمَاتِهَا', #2
u'دونمين': u'دُونَمَيْنِ', #2
u'دونى': u'دُونِى', #7
u'دووان': u'دِوْوَانٌ', #1
u'دووديعت': u'دووديعت', #1
u'دووى': u'دُووِىَ', #1
u'دويد،': u'دُوَيْدٌ،', #1
u'دويد،': u'دُوَيْدٍ،', #1
u'دويد': u'دُوَيْدِ', #3
u'دويد': u'دُوَيْدٌ', #4
u'دويد': u'دُوَيْدٍ', #4
u'دويرات': u'دُوَيْرَاتٍ', #1
u'دويرة': u'دُوَيْرَةَ', #1
u'دويرة': u'دُوَيْرَةِ', #137
u'دويرة': u'دُوَيْرَةٍ', #9
u'دويكا': u'دُوَيْكًا', #3
u'دويهية': u'دُوَيْهِيَةٌ', #1
u'دويوين': u'دُوَيْوِينٌ', #1
u'دى': u'دى', #3
u'دياب،': u'دِيَابٍ،', #1
u'دياس': u'دِيَاسَ', #3
u'دياس': u'دِيَاسِ', #4
u'دياس': u'دِيَاسٍ', #5
u'دياسة': u'دِيَاسَةً', #1
u'دياسة': u'دِيَاسَةِ', #1
u'دياسته': u'دِيَاسَتِهِ', #1
u'دياسه': u'دِيَاسِهِ', #1
u'دياف': u'دِيَافَ', #1
u'دياوين': u'دَيَاوِينَ', #1
u'دياوين': u'دَيَاوِينُ', #1
u'ديباه': u'ديباه', #1
u'ديباه': u'دِيبَاهْ', #1
u'ديباه': u'دِيبَاهٌ', #4
u'ديبة': u'دِيبَةُ', #1
u'ديبة': u'دِيبَةَ', #2
u'ديبقي': u'ديبقي', #1
u'ديبل': u'دَيْبَلٍ', #1
u'ديبل': u'دَيْبُلُ', #1
u'ديتى': u'دِيَتِى', #1
u'ديجاة': u'دَيْجَاةٌ', #1
u'ديدا': u'ديدا', #1
u'ديدار': u'ديدار', #1
u'ديديم': u'ديديم', #1
u'ديراست': u'ديراست', #1
u'ديربي': u'دَيْرَبِيٌ', #2
u'ديربي': u'دَيْرَبِيٌّ', #8
u'ديرزور': u'دَيْرِزُورَ', #1
u'ديرزورية': u'دَيْرُزُورِيَّةٌ', #1
u'ديرمانده': u'ديرمانده', #1
u'ديزا': u'دَيْزًا', #1
u'ديزج': u'ديزج', #1
u'ديزيل،': u'دَيْزِيلَ،', #2
u'ديزيل،': u'دِيزِيلَ،', #21
u'ديزيل': u'دِيزِيلَ', #5
u'ديزيل': u'دَيْزِيلَ', #6
u'ديسقوريدوس': u'دِيسْقُورِيدُوس', #1
u'ديقانوس': u'ديقانوس', #1
u'ديكر': u'ديكر', #9
u'ديكردادتا': u'ديكردادتا', #1
u'ديكررفت': u'ديكررفت', #1
u'ديكرهست': u'ديكرهست', #1
u'ديكري': u'ديكري', #1
u'ديكرى': u'ديكرى', #5
u'دينار': u'دِينَارً', #2
u'دينارزر': u'دينارزر', #1
u'دينارلا': u'دِينَارٍلا', #1
u'دينارلو': u'دِينَارٍلَوِ', #1
u'ديناروالوجه': u'دِينَارٍوَالْوَجْهُ', #3
u'دينسز': u'دينسز', #2
u'دينناSشرح': u'دِينِنَاSشَرْحُ', #1
u'دينورية': u'دِينَوَرِيَّةٌ', #3
u'دينى': u'دينى', #1
u'دينى': u'دِينِىَ', #1
u'دينى': u'دِينِى', #17
u'دينى': u'دَيْنِى', #3
u'ديهى': u'ديهى', #1
u'ديهي': u'ديهي', #5
u'ديوار': u'ديوار', #3
u'ديواشد': u'ديواشد', #1
u'ذابا': u'ذَابًّا', #1
u'ذارئ': u'ذَارِئٌ', #1
u'ذاشريا': u'ذَاشَرِيًّا', #1
u'ذافران': u'ذَافِرَانَ', #1
u'ذاكا': u'ذَاكَا', #3
u'ذآئب': u'ذَآئِبَ', #1
u'ذآئقة': u'ذَآئِقَةُ', #1
u'ذائم': u'ذَائِمٌ', #3
u'ذاية،': u'ذَايَةَ،', #1
u'ذباذب': u'ذَبَاذِبٌ', #1
u'ذباذب': u'ذَبَاذِبُ', #1
u'ذباذبي': u'ذَبَاذِبِي', #1
u'ذبحاء': u'ذبحاء', #1
u'ذبخ': u'ذَبَخَ', #1
u'ذبى': u'ذَبَى', #2
u'ذبيبا': u'ذَبِيبًا', #1
u'ذبيلة': u'ذُبَيْلَةٌ', #1
u'ذحلا': u'ذَحْلًا', #6
u'ذحله': u'ذَحْلَهُ', #4
u'ذر،': u'ذَرًّ،', #1
u'ذرارى': u'ذَرَارِىِّ', #5
u'ذراع': u'ذِرَاعً', #2
u'ذراعاوقد': u'ذِرَاعًاوَقَدْ', #1
u'ذراعى': u'ذِرَاعَىْ', #1
u'ذراعى': u'ذِرَاعَىِ', #2
u'ذراعى': u'ذِرَاعِى', #4
u'ذرعى': u'ذَرْعَى', #1
u'ذرنى': u'ذَرْنِى', #3
u'ذروان': u'ذَرْوَانَ', #20
u'ذرورة': u'ذَرُورَةٍ', #1
u'ذرونى': u'ذَرُونِى', #8
u'ذريتى': u'ذُرِّيَّتِى', #1
u'ذريح': u'ذَرِيحْ', #1
u'ذريح؟': u'ذَرِيحٍ؟', #1
u'ذريح': u'ذَرِيحٍ', #12
u'ذريح': u'ذريح', #2
u'ذريح': u'ذَرِيحُ', #3
u'ذريح،': u'ذَرِيحٍ،', #4
u'ذريح،': u'ذُرَيْحٍ،', #5
u'ذريح': u'ذُرَيْحٍ', #6
u'ذريحي': u'ذَرِيحِيّ', #1
u'ذريرة': u'ذَرِيرَة', #1
u'ذريرة': u'ذَرِيرَةً', #1
u'ذريرة': u'ذَرِيرَةٍ', #1
u'ذريرة': u'ذَرِيرَةٌ', #3
u'ذريم': u'ذُرَيْمِ', #1
u'ذعلوق،': u'ذعلوق،', #1
u'ذعلوق': u'ذُعْلُوقٍ', #1
u'ذعلوق،': u'ذُعْلُوقٍ،', #3
u'ذفار': u'ذَفَارُ', #1
u'ذفر': u'ذَفَرٍ', #1
u'ذفر': u'ذَفَرَ', #1
u'ذفر': u'ذَفَرُ', #1
u'ذفر': u'ذَفِرِ', #1
u'ذفر': u'ذَفْرٌ', #1
u'ذفر': u'ذَفْرٍ', #1
u'ذفر': u'ذَفْرِ', #1
u'ذفر': u'ذَفَرٌ', #2
u'ذفر': u'ذَفَرِ', #2
u'ذفر': u'ذَفِرٌ', #2
u'ذفر': u'ذَفِرَ', #2
u'ذفر': u'ذَفِرُ', #2
u'ذفرا': u'ذَفَرًا', #1
u'ذفراء': u'ذَفْرَاءُ', #1
u'ذفرات': u'ذَفِرَاتٌ', #1
u'ذفران': u'ذَفْرَانُ', #1
u'ذفران': u'ذَفِرَانُ', #3
u'ذفران': u'ذَفِرَانَ', #5
u'ذفرة': u'ذَفِرَةٌ', #3
u'ذفرة': u'ذَفْرَةٌ', #3
u'ذفره': u'ذَفَرُهُ', #2
u'ذفره': u'ذَفِرَهْ', #3
u'ذفرها': u'ذِفْرَهَا', #1
u'ذفريه': u'ذِفْرَيْهِ', #1
u'ذفريها': u'ذِفْرَيْهَا', #2
u'ذكبار': u'ذُكْبَارٍ', #1
u'ذكذذره': u'ذَكذذَرَهُ', #1
u'ذكر': u'ذِكْرً', #1
u'ذكر': u'ذَكَرً', #3
u'ذكرأحمد،': u'ذَكَرَأَحْمَدُ،', #1
u'ذكرالديباج': u'ذِكْرُالدِّيبَاجِ', #1
u'ذكرتنى': u'ذَكَّرْتَنِى', #4
u'ذكرتنيها': u'ذَكَّرْتَنِيهَا', #1
u'ذكرقوله': u'ذُكِرَقَوْلُهُ', #1
u'ذكرمن': u'ذكرمن', #1
u'ذكرنى': u'ذَكَّرَنِى', #3
u'ذكرنى': u'ذَكَرَنِى', #5
u'ذكرنيه': u'ذَكِّرْنِيهِ', #1
u'ذكرنيه': u'ذَكَّرَنِيهِ', #3
u'ذكرنيها': u'ذَكَّرَنِيهَا', #1
u'ذكرنيها': u'ذَكَّرْنِيهَا', #1
u'ذكوانا': u'ذَكْوَانًا', #1
u'ذكوريته': u'ذُكُورِيَّتُهُ', #19
u'ذكوريته': u'ذُكُورِيَّتِهِ', #21
u'ذكوريته': u'ذُكُورِيَّتَهُ', #4
u'ذكوريتهما': u'ذُكُورِيَّتِهِمَا', #1
u'ذلفة': u'ذُلْفَة', #1
u'ذلقة': u'ذَلِقَةٌ', #3
u'ذلكS': u'ذَلِكَS', #1
u'ذلكSما': u'ذَلِكَSمَا', #1
u'ذلكا': u'ذَلِكَا', #8
u'ذلكابن': u'ذَلِكَابْنُ', #1
u'ذلكإلا': u'ذَلِكَإِلَّا', #1
u'ذلكإلى': u'ذَلِكَإِلَى', #2
u'ذلكأن': u'ذَلِكَأَنَّ', #1
u'ذلكأنه': u'ذلكأنه', #1
u'ذلكبذي': u'ذَلِكَبِذِي', #1
u'ذلكعليك': u'ذَلِكَعَلَيْكَ', #1
u'ذلكقوله': u'ذَلِكَقَوْلُهُ', #3
u'ذلكلأن': u'ذَلِكَلِأَنَّ', #1
u'ذلكوقد': u'ذَلِكَوَقَدْ', #1
u'ذمة30333id': u'ذمة30333id', #1
u'ذناب': u'ذُنَابِ', #1
u'ذنبى': u'ذَنْبِى', #8
u'ذنن': u'ذَنَنٌ', #2
u'ذنهوبهم': u'ذنهوبهم', #1
u'ذنوبان': u'ذَنُوبَانِ', #1
u'ذنوبى': u'ذُنُوبِى', #3
u'ذنوبين': u'ذَنُوبَيْنِ', #19
u'ذنين': u'ذَنِينٌ', #1
u'ذهب': u'ذَهَبً', #2
u'ذهباإليه': u'ذَهَبَاإِلَيْهِ', #1
u'ذهبإليه': u'ذَهَبَإِلَيْهِ', #2
u'ذهيل': u'ذُهَيْل', #1
u'ذهيل': u'ذُهَيْلٍ', #1
u'ذهيل': u'ذُهَيْلِ', #2
u'ذؤآبتان': u'ذُؤَآبتان', #1
u'ذؤاد': u'ذُؤَادُ', #1
u'ذواري': u'ذَوَارِي', #2
u'ذوالنور،': u'ذُوالنُّورِ،', #1
u'ذوران': u'ذَوْرَانُ', #1
u'ذوروان': u'ذَوْرَوَانُ', #1
u'ذويب': u'ذُوَيْبٌ', #2
u'ذؤيبا': u'ذُؤَيْبًا', #14
u'ذويد': u'ذُوَيْدُ', #1
u'ذويد': u'ذُوَيْدِ', #1
u'ذويد،': u'ذُوَيْدٍ،', #1
u'ذويد': u'ذُوَيْدٌ', #2
u'ذويلة': u'ذُوَيْلَةُ', #1
u'ذى،': u'ذَى،', #1
u'ذى': u'ذِى', #311
u'ذى': u'ذى', #4
u'ذئر': u'ذَئِرَ', #4
u'ذئرن': u'ذَئِرْنَ', #1
u'ذئروا': u'ذَئِرُوا', #3
u'ذياك': u'ذَيَّاكِ', #1
u'ذيال': u'ذَيّالٍ', #1
u'ذيال': u'ذَيَّالَ', #1
u'ذيال': u'ذَيَّالٌ', #2
u'ذيال': u'ذَيَّالُ', #2
u'ذيالك': u'ذَيَّالِكِ', #1
u'ذيبان': u'ذيبان', #1
u'ذيبة': u'ذِيبَةٌ', #1
u'ذيحة': u'ذِيحَةٌ', #1
u'ذيخ': u'ذَيْخٍ', #1
u'ذيلى': u'ذَيْلِى', #1
u'رءاس': u'رءاس', #1
u'رءاها': u'رَءَاهَا', #1
u'رءوا': u'رُءُوا', #6
u'رءوس': u'رُءوسِ', #1
u'رءوس': u'رُءُوسَ', #119
u'رءوس': u'رُءُوسِ', #1205
u'رءوس': u'رُءُوس', #16
u'رءوس': u'رُءُوسُ', #176
u'رءوس': u'رُءُوسٌ', #19
u'رءوس': u'رءوس', #2
u'رءوس': u'رُءُوسٍ', #49
u'رءوسا': u'رءوسا', #1
u'رءوسا': u'رُءُوسًا', #55
u'رءوسكم': u'رُءُوسَكُمْ', #148
u'رءوسكم': u'رُءُوسكُمْ', #2
u'رءوسكم': u'رُءُوسِكُمْ', #21
u'رءوسكما': u'رُءُوسكُمَا', #1
u'رءوسكما': u'رُءُوسَكُمَا', #4
u'رءوسكما': u'رُءُوسُكُمَا', #4
u'رءوسكن': u'رُءُوسَكُنَّ', #10
u'رءوسنا،': u'رُءُوسِنَا،', #1
u'رءوسنا': u'رُءُوسِنَا', #16
u'رءوسنا': u'رُءُوسنَا', #3
u'رءوسنا،': u'رُءُوسَنَا،', #3
u'رءوسنا': u'رُءُوسَنَا', #5
u'رءوسه': u'رُءُوسَهُ', #1
u'رءوسه': u'رُءُوسِهِ', #16
u'رءوسه': u'رُءُوسُهُ', #6
u'رءوسها': u'رءوسها', #1
u'رءوسها': u'رُءُوَسَهَا', #1
u'رءوسها': u'رُءُوسَهَا', #17
u'رءوسها': u'رُءُوسُهَا', #25
u'رءوسها': u'رُءُوسهَا', #4
u'رءوسها': u'رُءُوسِهَا', #40
u'رءوسهم': u'رءوسهم', #1
u'رءوسهم': u'رُءٌوسَهُمْ', #1
u'رءوسهم': u'رُءُوسِهُمُ', #1
u'رءوسهم،': u'رُءُوسُهُمْ،', #1
u'رءوسهم': u'رُءُوسِهِمُ', #12
u'رءوسهم': u'رُءُوسَهُمْ', #145
u'رءوسهم،': u'رءوسهم،', #2
u'رءوسهم،': u'رُءُوسَهُمْ،', #4
u'رءوسهم': u'رُءُوسِهِمْ', #418
u'رءوسهم': u'رُءُوسهمْ', #5
u'رءوسهم،': u'رُءُوسِهِمْ،', #6
u'رءوسهم': u'رُءُوسُهُمْ', #61
u'رءوسهما': u'رُءُوسهمَا', #1
u'رءوسهما،': u'رُءُوسَهُمَا،', #1
u'رءوسهما': u'رُءُوسِهِمَا', #29
u'رءوسهما': u'رُءُوسَهُمَا', #33
u'رءوسهما': u'رُءُوسُهُمَا', #5
u'رءوسهن،': u'رُءُوسَهُنَّ،', #1
u'رءوسهن،': u'رُءُوسِهِنَّ،', #1
u'رءوسهن': u'رُءُوسُهُنَّ', #12
u'رءوسهن': u'رُءُوسَهُنَّ', #18
u'رءوسهن': u'رُءُوسهنَّ', #2
u'رءوسهن': u'رَءُوسَهُنَّ', #2
u'رءوسهن': u'رُءُوسَهُنّ', #4
u'رءوسهن': u'رُءُوسِهِنَّ', #70
u'رءوف': u'رَءُوف', #1
u'رءوف': u'رَءُوفُ', #1
u'رءوف': u'رَءُوفٌ', #68
u'رءوفا': u'رَءُوفًا', #24
u'رءوفا': u'رَءُوفَا', #4
u'را': u'رَا', #1
u'را': u'رًا', #2
u'را': u'را', #38
u'راءون': u'رَاءُونَ', #3
u'رااب': u'رااب', #1
u'راازجهت': u'راازجهت', #1
u'راازغله': u'راازغله', #1
u'راازهمسايه': u'راازهمسايه', #2
u'رااكراينكاركنم': u'رااكراينكاركنم', #1
u'رااولاغي': u'رااولاغي', #1
u'راباين': u'راباين', #2
u'رابب': u'رَابَبَ', #1
u'راببا': u'راببا', #1
u'رابتو': u'رابتو', #1
u'رابخانة': u'رابخانة', #1
u'رابخم': u'رابخم', #2
u'رابخواهم': u'رابخواهم', #1
u'رابر': u'رابر', #2
u'رابربام': u'رابربام', #1
u'رابربرا': u'رابربرا', #1
u'رابرتايدروازه': u'رابرتايدروازه', #1
u'رابركند': u'رابركند', #1
u'رابرين': u'رابرين', #2
u'رابزد': u'رابزد', #1
u'رابزني': u'رابزني', #1
u'رابستانم': u'رابستانم', #1
u'رابعد': u'رابعد', #1
u'رابغ،': u'رابغ،', #1
u'رابغ': u'رَابِغٌ', #1
u'رابغ،': u'رَابِغٍ،', #1
u'رابغ': u'رَابِغَ', #4
u'رابغ': u'رَابِغٍ', #56
u'رابغا': u'رَابِغًا', #1
u'رابغلام': u'رابغلام', #1
u'رابغله': u'رابغله', #1
u'رابفلان': u'رابفلان', #2
u'رابك': u'رَابَكِ', #1
u'رابك': u'رَابَك', #4
u'رابك': u'رَابَكَ', #6
u'رابكاسه': u'رابكاسه', #2
u'رابكم': u'رَابَكُمْ', #7
u'رابله': u'رَابِلُهُ', #1
u'رابما': u'رابما', #1
u'رابمن': u'رابمن', #4
u'رابهز': u'رابهز', #1
u'رابهزاردرم': u'رابهزاردرم', #1
u'رابوست': u'رابوست', #1
u'رابئة': u'رَابِئَةً', #2
u'رابيرون': u'رابيرون', #2
u'رابيسر': u'رابيسر', #2
u'راتاشش': u'راتاشش', #1
u'راتبون': u'رَاتِبُونَ', #2
u'راتج': u'رَاتِجَ', #1
u'راتج': u'رَاتِجٍ', #14
u'راتخارج': u'راتخارج', #1
u'راتركستان': u'راتركستان', #1
u'راتق': u'رَاتِقٌ', #3
u'راتن': u'راتن', #1
u'رأتنى': u'رَأَتْنِى', #1
u'راتو': u'راتو', #1
u'راتونا': u'رَاتُونَا', #1
u'راجام': u'راجام', #1
u'راجامه': u'راجامه', #2
u'راجحية': u'رَاجِحِيَّةٌ', #1
u'راجحية': u'رَاجِحِيَّةً', #3
u'راجحية': u'رَاجِحِيَّةٍ', #4
u'راجحية': u'رَاجِحِيَّةِ', #8
u'راجدا': u'رَاجِدًا', #1
u'راجرادشته': u'راجرادشته', #1
u'راجع': u'رَاجِعً', #1
u'راجكلن': u'راجكلن', #1
u'راجكنم': u'راجكنم', #1
u'راجيزى': u'راجيزى', #1
u'راحاضرنتوانم': u'راحاضرنتوانم', #1
u'راحلتى': u'رَاحِلَتِى', #10
u'راحلتى': u'رَاحِلَتَى', #3
u'راحيل': u'رَاحِيلُ', #1
u'راحيل،': u'رَاحِيلَ،', #1
u'راحيل': u'رَاحِيلَ', #2
u'راخورد': u'راخورد', #1
u'رأد': u'رَأْدَ', #1
u'رادر': u'رادر', #3
u'رادرد': u'رادرد', #2
u'رادركار': u'رادركار', #1
u'رادست': u'رادست', #2
u'رادشنام': u'رادشنام', #1
u'رادود': u'رادود', #1
u'رادئا': u'رَادِئًا', #1
u'رار': u'رَارِ', #1
u'رازبون': u'رازبون', #1
u'رازدزن': u'رازدزن', #1
u'رازقية': u'رَازِقِيَّةٍ', #1
u'رازقيتين': u'رَازِقِيَّتَيْنِ', #3
u'رازقيين': u'رَازِقِيَّيْنِ', #1
u'رازي': u'رَازِيٍّ', #1
u'رازي': u'رَازِيُّ', #1
u'رازي': u'رَازِيٌّ', #109
u'رازيان': u'رازيان', #1
u'رآس': u'رَآَّسٌ', #1
u'رآس': u'رَآَّسٍ', #1
u'رآسا': u'رَآَّسًا', #1
u'رآسة': u'رِآسَةٌ', #1
u'راسث': u'راسث', #1
u'راسجده': u'راسجده', #1
u'راسخت': u'راسخت', #1
u'راسعيني': u'رَاسَعَيْنِيٌّ', #1
u'راسو': u'راسو', #1
u'رأسى': u'رَأْسِىَ', #1
u'رأسى؟': u'رَأْسِى؟', #1
u'رأسى': u'رَأْسِى', #106
u'راششصدي': u'راششصدي', #1
u'راصوا': u'رَاصُّوا', #3
u'راضايع': u'راضايع', #1
u'راضمان': u'راضمان', #1
u'رأضيم': u'رأضيم', #1
u'راطلني': u'رَاطِلْنِي', #1
u'راعوفة': u'رَاعُوفَةِ', #2
u'راعوفة': u'رَاعُوفَةٍ', #3
u'راعوفتها': u'رَاعُوفَتِهَا', #1
u'راعيل،': u'رَاعِيلَ،', #1
u'راعيل': u'رَاعِيلُ', #2
u'راعينى': u'راعينى', #1
u'راغو': u'رَاغُو', #1
u'راغية': u'رَاغِيَةَ', #1
u'رافا': u'رَافًّا', #1
u'رافروش': u'رافروش', #1
u'رافعى': u'رَافِعِىْ', #1
u'رافعى': u'رَافِعِى', #3
u'رافقال': u'رافقال', #1
u'رافلا': u'رَافِلًا', #1
u'رافلة': u'رَافِلَةٌ', #1
u'رافلة': u'رَافِلَةَ', #4
u'راقبض': u'راقبض', #1
u'راقما': u'رَاقِمًا', #10
u'راقوت': u'راقوت', #1
u'رآك': u'رآك', #1
u'رآك،': u'رَآكَ،', #1
u'رآك': u'رَآكَ', #11
u'رآك': u'رَآك', #3
u'راكاتونكند': u'راكاتونكند', #1
u'راكر': u'راكر', #1
u'راكعافخاف': u'رَاكِعًافَخَافَ', #1
u'راكفت': u'راكفت', #8
u'رآكم': u'رَآكُمْ', #8
u'راكه': u'راكه', #15
u'راكواه': u'راكواه', #5
u'راكويد': u'راكويد', #2
u'راكويند': u'راكويند', #3
u'راكية': u'رَاكِيَةَ', #1
u'رأم': u'رَأَمَ', #1
u'رامال': u'رامال', #1
u'راماندبدست': u'راماندبدست', #1
u'رامة': u'رَامَةٌ', #1
u'رامة': u'رَامَةَ', #2
u'رأمت': u'رَأَمَتْ', #1
u'رامخا': u'رَامِخًا', #1
u'رامشايعت': u'رامشايعت', #1
u'رامنع': u'رامنع', #1
u'رامنكرم': u'رامنكرم', #1
u'رامهرمز،': u'رامَهُرْمُز،', #2
u'رامهرمز': u'رَامَهُرْمُزَ', #3
u'رامهرمز،': u'رَامَهُرْمُزَ،', #5
u'رانابر': u'رانابر', #1
u'رانبيذدهم': u'رانبيذدهم', #1
u'رانتواند': u'رانتواند', #1
u'رانج': u'رَانِجٌ', #3
u'رانج': u'رَانِجٍ', #4
u'راندجر': u'راندجر', #1
u'راندن': u'راندن', #1
u'رانده': u'رانده', #1
u'رانشايد': u'رانشايد', #1
u'رانمي': u'رانمي', #1
u'رانوناء': u'رَانُونَاءُ', #1
u'رانوناء': u'رَانُونَاءَ', #4
u'رآنى': u'رَآنِى', #46
u'راه': u'راه', #1
u'راه': u'رَاهَ', #6
u'رآهاأنها': u'رَآهَاأَنَّهَا', #1
u'راهط': u'رَاهِطَ', #1
u'راهط': u'رَاهِطٍ', #11
u'راهط': u'راهط', #3
u'راهط،': u'رَاهِطٍ،', #6
u'راهقه': u'رَاهَقَهُ', #1
u'رآهنى': u'رآهنى', #1
u'راهوية،': u'راهوية،', #1
u'راهوية': u'رَاهَوَيْةِ', #1
u'راهويه': u'رَاهُويَهْ', #1
u'راهويه،': u'رَاهَوَيْهِ،', #18
u'راهويه': u'راهويه', #2
u'راهويه،': u'راهويه،', #2
u'راهويه،': u'رَاهُوَيْهِ،', #2
u'راهويه': u'رَاهْوَيْهِ', #236
u'راهويه': u'رَاهُوَيْهِ', #3
u'راهويه': u'رَاهَوَيْهِ', #40
u'رأو': u'رَأَوْ', #1
u'راوان': u'رَاوَانَ', #1
u'راواين': u'راواين', #1
u'راوبيغمبر': u'راوبيغمبر', #1
u'راوضه': u'رَاوَضَهُ', #1
u'راوفرشتكان': u'راوفرشتكان', #1
u'راوند': u'رَاوَنْدَ', #1
u'راوند': u'رَاوَنْدُ', #1
u'راوه،': u'رَاوَهُ،', #1
u'راوه': u'رَاوَهُ', #11
u'راوه': u'رَاوَه', #7
u'راوى': u'رَاوِى', #4
u'راي': u'راي', #1
u'راي': u'رَايٌ', #1
u'رآى': u'رَآى', #2
u'رآى': u'رآى', #3
u'رائث': u'رَائِث', #1
u'رائث،': u'رَائِثٍ،', #1
u'رائث': u'رَائِثِ', #2
u'رائث': u'رَائِثٍ', #6
u'رائسهم': u'رَائِسُهُمْ', #1
u'رائض': u'رَائِضُ', #1
u'رائض': u'رَائِضٌ', #2
u'رائض': u'رَائِضٍ', #2
u'رائضها': u'رَائِضُهَا', #1
u'رائضها': u'رَائِضِهَا', #1
u'رائطة': u'رَائِطَةَ', #15
u'رائغ': u'رَائِغٌ', #1
u'رائن': u'رَائِنٌ', #1
u'رائين': u'رَائِينَ', #1
u'رائينا': u'رَائِينَا', #4
u'رائيه': u'رَائِيهِ', #2
u'رايا': u'رايا', #2
u'رايا': u'رَايَا', #4
u'رأيتمالكا': u'رَأَيْتمَالِكًا', #1
u'رأيتمونى': u'رَأَيْتُمُونِى', #18
u'رأيتن': u'رَأَيْتُنِ', #1
u'رأيتن': u'رَأَيْتُنَّ', #34
u'رأيتنى': u'رَأَيْتِنِى', #1
u'رأيتنى': u'رَأَيْتُنِى', #49
u'رأيتنى': u'رَأَيْتَنِى', #8
u'رايتى': u'رَايَتِى', #1
u'رأيتيني': u'رَأَيْتِينِي', #1
u'رأيتيه': u'رَأَيْتِيهِ', #5
u'رأيتيها': u'رَأَيْتِيهَا', #1
u'رايث': u'رَايِثٍ', #1
u'رايح': u'رَايِحٌ', #1
u'رايذبرفتم': u'رايذبرفتم', #1
u'رايطة': u'رَايِطَةً', #1
u'رايعا': u'رَايِعًا', #1
u'رأيى': u'رَأْيِى', #12
u'رب': u'رَبًّ', #1
u'رباعقوله': u'رِبَاعٍقَوْلُهُ', #1
u'رباعيتى': u'رَبَاعِيَتِى', #1
u'ربال': u'رَبَال', #1
u'رباوة': u'رِبَاوَةٌ', #1
u'ربايتهم': u'رِبَايَتُهُمْ', #1
u'ربحلة': u'رِبْحِلَةٌ', #2
u'ربحى': u'رِبْحِىَ', #1
u'ربداء': u'رَبْدَاءُ', #1
u'ربدان': u'ربدان', #1
u'ربعى': u'رِبْعِىٌّ', #1
u'ربعى': u'رِبْعِىَّ', #1
u'ربعى': u'رِبْعِىٍّ', #26
u'ربعى': u'رِبْعِىِّ', #38
u'ربعى': u'رِبْعِىُّ', #7
u'ربعيون': u'رِبْعِيّونْ', #1
u'ربغ': u'ربغ', #1
u'ربمناك': u'ربمناك', #1
u'ربنا23811id': u'ربنا23811id', #1
u'ربهشت': u'ربهشت', #1
u'ربهقوله': u'رَبَّهُقَوْلُهُ', #1
u'ربهقوله': u'رَبُّهُقَوْلُهُ', #1
u'ربوالوجه': u'رَبِّوَالْوَجْهُ', #2
u'ربودن': u'ربودن', #1
u'ربويته': u'رِبَوِيَّتَهُ', #1
u'ربويته': u'رِبَوِيَّتِهِ', #11
u'ربويتها': u'رِبَوِيَّتِهَا', #5
u'ربيبتى': u'رَبِيبَتَىْ', #2
u'ربيبتى': u'رَبِيبَتِى', #6
u'ربيثا': u'رِبِّيثًا', #1
u'ربيح': u'رَبِيح', #1
u'ربيح': u'رَبِيحٌ', #1
u'ربيح': u'رَبِيحٍ', #1
u'ربيح،': u'رَبِيحٌ،', #1
u'ربيح': u'رُبَيْحَ', #1
u'ربيح': u'رُبَيْحِ', #13
u'ربيح': u'رَبِيحُ', #2
u'ربيح': u'رَبِيحِ', #3
u'ربيح': u'رُبَيْحٌ', #3
u'ربيح': u'رُبَيْحٍ', #3
u'ربيح': u'رُبَيْحُ', #6
u'ربيحا': u'رَبِيحًا', #1
u'ربيراهن': u'ربيراهن', #1
u'ربيضة': u'رُبَيْضَةَ', #1
u'ربيضين': u'رَبِيضَيْنِ', #1
u'ربيعةوالمستضعفين': u'رَبِيعَةَوَالْمُسْتَضْعَفِينَ', #1
u'رة': u'رَةِ', #1
u'رتائم': u'رَتَائِمُ', #1
u'رتباييل': u'رَتَبَايِيلُ', #2
u'رتبيل': u'رتبيل', #1
u'رتبيل،': u'رُتْبِيلُ،', #1
u'رتبيل': u'رُتْبِيلُ', #2
u'رتبيل،': u'رُتْبِيلَ،', #6
u'رتبيل': u'رُتْبِيلَ', #8
u'رتفا': u'رتفا', #1
u'رتقاء': u'رَتْقَاءَ', #168
u'رتقاء': u'رَتْقَاءُ', #65
u'رتقة': u'رَتْقَةٍ', #1
u'رتقة': u'رِتْقَةً', #1
u'رتم': u'رَتَمٌ', #3
u'رتما': u'رَتْمًا', #1
u'رتوة': u'رتوة', #1
u'رتوة': u'رَتْوَةٌ', #1
u'رتوة': u'رَتْوَةً', #4
u'رتيمة': u'رَتِيمَةٍ', #1
u'رثيثا': u'رَثِيثًا', #4
u'رجاءة': u'رَجَاءَةَ', #1
u'رجالكمقوله': u'رِجَالِكُمْقَوْلُهُ', #1
u'رجاليه': u'رِجَاليهْ', #1
u'رجاليه': u'رِجَالِيَهْ', #1
u'رجحانيته': u'رُجْحَانِيَّتِهِ', #1
u'رجحيته': u'رُجْحِيَّتِهِ', #1
u'رجزى': u'رَجَزِى', #1
u'رجععمر': u'رَجَعَعُمَرُ', #1
u'رجعيم': u'رجعيم', #1
u'رجل': u'رَجُلً', #3
u'رجلاصلت': u'رَجُلًاصَلَّتْ', #2
u'رجلعن': u'رَجُلٌعَنِ', #1
u'رجلى': u'رِجْلِىَّ', #1
u'رجلى': u'رِجْلَىَّ', #17
u'رجلى': u'رِجْلَىِ', #4
u'رجلى': u'رِجْلِى', #9
u'رجليهقوله': u'رِجْلَيْهِقَوْلُهُ', #1
u'رجوا': u'رُجُوًّا', #2
u'رجوعى': u'رُجُوعِى', #1
u'رجيح': u'رَجِيحٍ', #1
u'رجيح': u'رَجِيحُ', #1
u'رجيفا': u'رَجِيفَا', #3
u'رحا': u'رَحًا', #38
u'رحاء': u'رَحَاءٌ', #1
u'رحاء': u'رَحَّاءُ', #2
u'رحاة': u'رَحَاةٍ', #1
u'رحاح': u'رَحَاحْ', #1
u'رحارح': u'رَحَارِحْ', #1
u'رحائل': u'رَحَائِلُ', #1
u'رحبين': u'رَحْبَيْنِ', #1
u'رحج': u'رحج', #1
u'رحراح،': u'رَحْرَاحٍ،', #1
u'رحراح': u'رَحْرَاحٍ', #4
u'رحراحا': u'رَحْرَاحًا', #2
u'رحرحان': u'رَحْرَحَانُ', #2
u'رحرحان': u'رَحْرَحَانَ', #8
u'رحض': u'رَحْضِ', #2
u'رحضا': u'رَحْضًا', #1
u'رحضة': u'رُحْضَةُ', #1
u'رحضة': u'رَحَضَةَ', #14
u'رحضة': u'رَحْضَةَ', #14
u'رحقان': u'رَحْقَانَ', #1
u'رحقان': u'رَحْقَانُ', #2
u'رحقان': u'رُحْقَانُ', #2
u'رحلى': u'رَحْلِى', #4
u'رحم،': u'رَحِمً،', #1
u'رحمانا': u'رَحْمَانًا', #3
u'رحمانيته': u'رَحْمَانِيَّتِهِ', #1
u'رحمتى': u'رَحْمَتِى', #6
u'رحمتيني': u'رَحِمْتِينِي', #1
u'رحمو': u'رَحْمُو', #1
u'رحمون': u'رَحْمُونٌ', #1
u'رحمويه': u'رَحْمَوَيْهِ', #7
u'رحى': u'رَحًى', #165
u'رحى': u'رحًى', #2
u'رحيات': u'رَحَيَاتٍ', #1
u'رحيمية': u'رَحِيمِيَّةٌ', #1
u'رخساره': u'رخساره', #1
u'رخلة': u'رِخْلَةً', #1
u'رخلى': u'رِخْلَى', #1
u'رخيلة': u'رُخَيلة', #1
u'رخيلة،': u'رُخَيْلة،', #1
u'رخيلة': u'رُخَيْلَةُ', #4
u'رخيلة': u'رُخَيْلَةَ', #6
u'رد': u'رَدًّ', #1
u'ردء': u'رَدْءٌ', #1
u'ردء': u'رَدْءَ', #1
u'ردء': u'رَدْءِ', #1
u'ردء': u'رِدْءً', #1
u'ردء': u'رِدْءِ', #1
u'ردء': u'رِدْءٌ', #12
u'ردء': u'رِدْءُ', #3
u'ردءا': u'ردءًا', #1
u'ردءا،': u'ردءًا،', #1
u'ردءا': u'رَدْءًا', #1
u'ردءا': u'رِدْءًا', #45
u'ردأ': u'رَدَأَ', #1
u'ردأ': u'رَدُأَ', #1
u'ردآب': u'ردآب', #1
u'ردأت': u'رَدَأَتْ', #2
u'رداح': u'رَدَاحٌ', #1
u'رداح': u'رَدَاحٍ', #2
u'رداد': u'رَدَّادٍ', #1
u'رداد': u'رداد', #2
u'ردافى': u'رُدَافَى', #2
u'ردائى': u'رِدَائِى', #14
u'ردتنى': u'رَدَّتْنِى', #1
u'رددتكها': u'رَدَدْتُكَهَا', #1
u'رددتنى': u'رَدَدْتَنِى', #1
u'ردرم': u'ردرم', #1
u'ردست': u'ردست', #1
u'ردست': u'رُدِسْتُ', #1
u'ردغ': u'رَدَغٍ', #1
u'ردغ': u'رَدْغُ', #1
u'ردغ،': u'رَدْغٍ،', #1
u'ردغ': u'رَدْغٍ', #3
u'ردغ': u'رَدْغٌ', #6
u'ردغا': u'رَدْغًا', #1
u'ردغة': u'رَدِغَةٍ', #1
u'ردغة': u'رَدْغَة', #2
u'ردغة': u'رَدْغَةُ', #2
u'ردغة': u'رَدْغَةٍ', #4
u'ردغة': u'رَدْغَةَ', #5
u'ردغة': u'رَدْغَةِ', #6
u'ردغها': u'رَدْغَهَا', #1
u'ردمان': u'رَدْمَانُ', #1
u'ردمان': u'رَدْمَانِ', #1
u'ردمان': u'رَدْمَانَ', #2
u'ردنة': u'رُدْنَةَ', #1
u'ردؤ': u'رَدُؤَ', #1
u'ردومر': u'ردومر', #1
u'ردونى': u'رُدُّونِى', #2
u'ردؤها': u'رِدْؤُهَا', #1
u'ردىء': u'رَدِىءٌ', #1
u'ردئ': u'رَدِئَ', #1
u'ردئ': u'رُدِئَ', #1
u'ردىء': u'ردىء', #2
u'ردئت': u'رَدُئَتْ', #1
u'ردئهما': u'رِدْئِهِمَا', #1
u'رديح،': u'رُدَيْحٍ،', #1
u'رديح': u'رُدَيْحٍ', #2
u'رديح': u'رُدَيْحُ', #2
u'رديد': u'رَدِيدٌ', #1
u'رديد': u'رَدِيدُ', #1
u'رديدى': u'رِدِّيدَى', #1
u'ردينة': u'رُدَيْنَةٍ', #1
u'ردينة': u'رُدَيْنَةَ', #3
u'ردينة': u'رُدَيْنَةُ', #4
u'ردينية': u'رُدَيْنِيّةٌ', #1
u'رذح': u'رذح', #1
u'رذلة': u'رَذِلَةٍ', #1
u'رذلة': u'رَذْلَةٍ', #1
u'رذيا': u'رَذِيّا', #2
u'رروزاين': u'رروزاين', #2
u'رروزمدا': u'رروزمدا', #1
u'رروزمدار': u'رروزمدار', #1
u'رزغ': u'رَزْغٍ', #1
u'رزغة': u'رَزْغَةٍ', #1
u'رزقة،': u'رزقة،', #1
u'رزقة': u'رَزْقَةً', #1
u'رزقة': u'رِزْقَةً', #1
u'رزقة': u'رِزْقَةٌ', #1
u'رزقة': u'رِزْقَةٍ', #1
u'رزقة': u'رَزْقَةٌ', #2
u'رزقكموه': u'رَزَقَكُمُوهُ', #2
u'رزقنيه': u'رَزَقَنِيهِ', #4
u'رزقويه': u'رِزْقَوَيْهِ', #1
u'رزقى': u'رِزْقِى', #1
u'رزكه': u'رزكه', #1
u'رزمويه': u'رَزْمُوَيْهِ', #1
u'رزمويه': u'رِزْمُوَيْهِ', #2
u'رزمى': u'رَزْمَى', #1
u'رزوي': u'رزوي', #1
u'رزئتهم': u'رَزِئْتهمْ', #1
u'رزئناكم': u'رَزَئْنَاكُمْ', #1
u'رزيت': u'رزيت', #1
u'رزيتم': u'رُزِيتُمْ', #1
u'رزيع،': u'رُزَيْع،', #1
u'رزيق': u'رُزيق', #1
u'رزيق': u'رُزَيق', #1
u'رزيق': u'رُزَيْق', #1
u'رزيق': u'رُزَيْقَ', #1
u'رزيق،': u'رزيق،', #3
u'رزيق': u'رُزَيْقُ', #3
u'رزيق،': u'رُزَيْقٍ،', #39
u'رزيق': u'رزيق', #5
u'رزيق': u'رُزَيْقِ', #5
u'رزيق': u'رُزَيْقٍ', #85
u'رزيق': u'رُزَيْقٌ', #9
u'رزينت': u'رُزَيْنَتِ', #1
u'رساتيق': u'رساتيق', #1
u'رساتيق': u'رَسَاتِيقَ', #1
u'رساتيق': u'رَسَاتِيقِ', #5
u'رساتيق': u'رَسَاتِيقُ', #7
u'رساتيقنا': u'رساتيقنا', #1
u'رساتيقهم': u'رَسَاتِيقِهِمْ', #1
u'رسال': u'رِسَال', #1
u'رسانت': u'رسانت', #1
u'رسانيده': u'رسانيده', #3
u'رستاق': u'رُسْتَاقٌ', #1
u'رستاق': u'رُسْتَاقٍ', #37
u'رستاق': u'رُسْتَاقَ', #8
u'رستاق': u'رُسْتَاقِ', #9
u'رستاقا': u'رُسْتَاقًا', #1
u'رستاقي': u'رُسْتَاقِيّ', #1
u'رستاقي': u'رُسْتَاقِيٌّ', #4
u'رستاقي': u'رُسْتَاقِيُّ', #9
u'رستاقيا': u'رُسْتَاقِيًّا', #1
u'رستة': u'رَسْتَةَ', #1
u'رستة': u'رُسْتَةُ', #1
u'رستة،': u'رُسْتَةَ،', #2
u'رستة،': u'رُسْتَةُ،', #2
u'رستة': u'رُسْتَةَ', #6
u'رستقباذ': u'رُسْتَقُبَاذَ', #1
u'رستى': u'رستى', #2
u'رسحاء': u'رَسْحَاءَ', #1
u'رسد': u'رسد', #2
u'رسراس': u'رسراس', #1
u'رسراس': u'رَسْرَاسٍ', #4
u'رسعت': u'رَسَعَتْ', #1
u'رسعت': u'رَسِعَتْ', #1
u'رسماء': u'رَسْمَاءَ', #1
u'رسوذل': u'رَسُوذلَ', #1
u'رسولالله': u'رَسُولُالله', #1
u'رسولى': u'رَسُولَىْ', #1
u'رسولى': u'رَسُولِى', #3
u'رسيد': u'رسيد', #3
u'رسيدا': u'رسيدا', #1
u'رسيل': u'رَسِيلْ', #1
u'رسيلا': u'رَسِيلَا', #2
u'رشانى': u'رَشَانِى', #1
u'رشة': u'رَشَّةً', #4
u'رشحاء': u'رَشْحَاءَ', #1
u'رشحات': u'رَشَحَاتٌ', #5
u'رشداء': u'رُشَدَاء', #1
u'رشداء': u'رُشَدَاءُ', #10
u'رشداء': u'رُشَدَاءَ', #25
u'رشديم': u'رشديم', #1
u'رشدين،': u'رِشْدِينُ،', #14
u'رشدين': u'رِشْدِينٍ', #2
u'رشدين،': u'رِشْدِينٌ،', #2
u'رشدين،': u'رِشْدِينَ،', #20
u'رشدين': u'رِشْدِينَ', #28
u'رشدين،': u'رشدين،', #3
u'رشدين': u'رِشْدِينُ', #90
u'رشرش': u'رَشْرَشَ', #1
u'رشيته': u'رَشَيْتَهُ', #1
u'رضاخان': u'رِضَاخَانْ', #1
u'رضاضة': u'رُضَاضَةً', #2
u'رضاكا': u'رَضَاكَا', #1
u'رضاكا': u'رِضَاكَا', #2
u'رضام': u'رِضَامٌ', #2
u'رضاى': u'رِضَاىَ', #2
u'رضح': u'رَضَحَ', #1
u'رضح': u'رَضْحَ', #1
u'رضراض': u'رَضْرَاضَ', #1
u'رضراض': u'رَضْرَاضٍ', #3
u'رضراضه': u'رَضْرَاضُهُ', #1
u'رضراضهم': u'رَضْرَاضُهُمُ', #1
u'رضعات': u'رضعات', #1
u'رضعات،': u'رضعات،', #1
u'رضعات': u'رَضَعَاتٌ', #2
u'رضعات': u'رَضَعَاتِ', #2
u'رضعات': u'رَضَعَاتٍ', #236
u'رضعات': u'رَضْعَاتٍ', #3
u'رضعات،': u'رَضَعَاتٍ،', #3
u'رضعاتهن': u'رَضَعَاتِهِنَّ', #3
u'رضعتان،': u'رَضْعَتَانِ،', #1
u'رضعتان': u'رَضْعَتَانِ', #5
u'رضعتين': u'رَضْعَتَيْنِ', #31
u'رضعيهما': u'رَضِعِيهِمَا', #1
u'رضم': u'رضْمٍ', #1
u'رضم': u'رَضْمٌ', #2
u'رضم': u'رَضْمٍ', #2
u'رضما': u'رَضْمًا', #4
u'رضمة': u'رَضْمَةً', #1
u'رضمة': u'رَضْمَةٍ', #3
u'رضموا': u'رَضَمُوا', #3
u'رضنى': u'رَضِّنِى', #2
u'رضوانى': u'رِضْوَانِى', #1
u'رضوى': u'رضوى', #1
u'رضوى،': u'رَضْوَى،', #2
u'رضوى': u'رَضْوَى', #21
u'رطة': u'رَطَّةٍ', #1
u'رطيل': u'رُطَيْلٌ', #1
u'رعاء،': u'رِعَاءً،', #1
u'رعاء': u'رِعَاءً', #3
u'رعابيب': u'رَعَابِيبِ', #1
u'رعابيل': u'رَعَابِيلُ', #4
u'رعاثا': u'رِعَاثًا', #3
u'رعال': u'رَعَالٍ', #1
u'رعامها': u'رُعَامَهَا', #1
u'رعائيل': u'رَعَائِيلَ', #1
u'رعثة': u'رَعَثَةٌ', #1
u'رعل': u'رِعْل', #1
u'رعل': u'رِعْلَ', #1
u'رعل،': u'رِعْلٌ،', #1
u'رعل،': u'رِعْلٍ،', #1
u'رعل': u'رَعْلٌ', #2
u'رعل': u'رِعْلٍ', #25
u'رعل': u'رِعْلٌ', #3
u'رعل،': u'رَعْلٍ،', #5
u'رعل': u'رَعْلٍ', #9
u'رعلا': u'رَعْلا', #1
u'رعلا': u'رِعْلا', #1
u'رعلا،': u'رَعْلا،', #1
u'رعلا': u'رِعْلًا', #11
u'رعلا': u'رَعْلًا', #2
u'رعلا': u'رِعْلاً', #4
u'رعلة': u'رَعْلَةُ', #1
u'رعمي،': u'رِعْمِيٌّ،', #1
u'رعين9961id': u'رعين9961id', #1
u'رغاة': u'رُغَاةً', #3
u'رغال': u'رِغَال', #1
u'رغال': u'رِغَالٌ', #1
u'رغال': u'رِغَالُ', #1
u'رغال': u'رِغَالِ', #1
u'رغال،': u'رِغَالِ،', #1
u'رغال؟': u'رِغَالٍ؟', #1
u'رغال': u'رِغَالَ', #2
u'رغال،': u'رِغَالٍ،', #3
u'رغال': u'رِغَالٍ', #33
u'رغرثا،': u'رغرثا،', #1
u'رغس': u'رغس', #1
u'رغسه': u'رَغَسَهُ', #5
u'رغشه': u'رَغَشَهُ', #2
u'رغفان': u'رُغْفَانٌ', #1
u'رغفانا': u'رُغْفَانًا', #1
u'رغمة': u'رَغْمَةً', #2
u'رغوان': u'رَغْوَانَ', #3
u'رغوثا': u'رَغُوثًا', #1
u'رفافي': u'رِفَافِي', #2
u'رفة': u'رِفةٌ', #1
u'رفة': u'رَفَةِ', #1
u'رفة': u'رَفَّةِ', #1
u'رفة': u'رِفَةٌ', #1
u'رفتى': u'رفتى', #1
u'رفرزندان': u'رفرزندان', #1
u'رفصت': u'رَفَصَتْ', #1
u'رفعاء': u'رُفَعَاءَ', #1
u'رفعاء': u'رُفَعَاءِ', #2
u'رفعصوت': u'رَفْعِصَوْتٍ', #1
u'رفعهإن': u'رفعهإِنَّ', #1
u'رفغ': u'رَفْغ', #1
u'رفغ': u'رَفْغٍ', #2
u'رفغه': u'رَفْغِهِ', #2
u'رفغه': u'رُفْغَهُ', #2
u'رفغيه': u'رُفْغَيْهِ', #9
u'رفوسا': u'رُفُوسًا', #1
u'رفوسا': u'رَفُوسًا', #4
u'رفى': u'رَفِّى', #1
u'رفيده،': u'رُفَيْده،', #1
u'رفيقى': u'رَفِيقِى', #4
u'رقأ': u'رَقَأَ', #12
u'رقأت': u'رَقَأْتُ', #1
u'رقادرين': u'رقادرين', #1
u'رقاش': u'رَقَاش', #1
u'رقاش': u'رَقَاشُ', #2
u'رقاش': u'رَقَاشِ', #2
u'رقانى': u'رَقَانِى', #1
u'رقبتهوغلته': u'رَقَبَتُهُوَغَلَّتُهُ', #1
u'رقبتى': u'رَقَبَتِى', #2
u'رقبى': u'رُقْبَى', #59
u'رقح': u'رَقَحَ', #2
u'رقح': u'رَقَّحَ', #2
u'رقل': u'رَقْلٌ', #1
u'رقمة': u'رَقْمَةً', #1
u'رقمتين': u'رَقْمَتَيْنِ', #1
u'رقوقين': u'رقوقين', #1
u'رقوقين': u'رَقُوقَيْنُ', #1
u'رقوقين': u'رَقُوقَيْنِ', #1
u'رقوقين': u'رَقُوقَيْنَ', #2
u'رقوم': u'رُقُومٍ', #1
u'رقئا': u'رَقْئًا', #1
u'رقيدة': u'رُقَيْدَةَ', #1
u'رقيس': u'رُقَيْسِ', #1
u'رقيش': u'رُقَيْشٍ', #21
u'رقيش': u'رقيش', #3
u'رقيش': u'رُقَيْشِ', #3
u'رقيع': u'رَقِيعٍ', #1
u'رقيع': u'رَقِيعُ', #1
u'ركابات': u'رِكَابَاتٍ', #1
u'ركار': u'رَكَّارُ', #1
u'ركاز': u'رِكَاز', #1
u'ركاز': u'رِكَازِ', #1
u'ركاز،': u'رِكَازٌ،', #1
u'ركاز': u'رِكَازُ', #3
u'ركاز': u'رِكَازٍ', #41
u'ركاز': u'رِكَازَ', #6
u'ركاز': u'رِكَازٌ', #64
u'ركازا': u'رِكَازًا', #103
u'ركبانا': u'رُكْبَانًا', #160
u'ركباناومن': u'رُكْبَانًاوَمِنْ', #1
u'ركبتهSشرح': u'رَكِبْتهSشَرْحُ', #1
u'ركبتى': u'رُكْبَتَىِ', #1
u'ركبتى': u'رُكْبَتَىْ', #1
u'ركبتى': u'رُكْبَتَىَّ', #4
u'ركبتى': u'رُكْبَتِى', #5
u'ركردتا': u'ركردتا', #1
u'ركزة': u'رِكْزَةً', #2
u'ركس': u'رَكَسَ', #1
u'ركس': u'رِكْسٌ', #43
u'ركس': u'رِكْس', #5
u'ركسا': u'رَكْسًا', #2
u'ركسا': u'رِكْسًا', #6
u'ركسة': u'رَكْسَةً', #1
u'ركسة': u'رِكْسَةٌ', #2
u'ركست': u'رَكَسْت', #1
u'ركضات': u'رَكَضَات', #2
u'ركضات': u'رَكَضَاتِ', #4
u'ركضاته': u'رَكَضَاته', #1
u'ركضة': u'رَكْضَةٌ', #14
u'ركضة': u'رَكْضَةً', #4
u'ركضة': u'رَكْضَة', #5
u'ركضتنى': u'رَكَضَتْنِى', #4
u'ركعةSصلاة': u'رَكْعَةًSصَلَاةُ', #1
u'ركعةمن': u'رَكْعَةًمِنْ', #1
u'ركعتى': u'رَكْعَتَىْ', #1
u'ركعتى': u'رَكْعَتَىِ', #57
u'ركعتيالمسجد': u'رَكْعَتَيْالْمَسْجِدِ', #1
u'ركنيته': u'رُكْنِيَّتُهُ', #1
u'ركنيته': u'رُكْنِيَّتِهِ', #18
u'ركنيته': u'رُكْنِيَّتَهُ', #4
u'ركنيتها': u'رُكْنِيَّتِهَا', #15
u'ركنيتها': u'رُكْنِيَّتَهَا', #3
u'ركنيتها': u'رُكْنِيَّتُهَا', #4
u'ركنيتهما': u'رُكْنِيَّتِهِمَا', #6
u'ركورنيست': u'ركورنيست', #1
u'ركوسيا': u'رَكُوسِيًّا', #1
u'ركوسيا': u'رُكُوسِيًّا', #1
u'ركوسيا؟': u'رَكُوسِيًّا؟', #1
u'ركوسيا': u'رَكُوسِيّا', #2
u'ركى': u'رَكِىٍّ', #1
u'ركيا': u'رَكِيًّا', #1
u'ركية': u'رَكِيّةَ', #1
u'ركية': u'رَكِيَّةً', #1
u'ركية': u'رَكِيَّةُ', #1
u'ركية': u'رَكِيَّةٌ', #2
u'ركية': u'رَكِيَّةٍ', #7
u'ركيح': u'رُكَيْحِ', #1
u'ركيس': u'رَكِيس', #1
u'ركيعات': u'رُكَيْعَاتٌ', #1
u'رماص': u'رَمَاصٌ', #1
u'رماص': u'رَمَاصٍ', #4
u'رماض': u'رِمَاضٌ', #1
u'رمانى': u'رَمَانِى', #4
u'رمثة': u'رَمَثَةَ', #2
u'رمثة': u'رَمْثَةَ', #2
u'رمثة،': u'رِمْثَةَ،', #4
u'رمثة': u'رِمْثَةَ', #50
u'رمثة': u'رمثة', #7
u'رمحى': u'رُمْحِى', #3
u'رمددا': u'رِمْدِدًا', #2
u'رمص': u'رَمَصٍ', #1
u'رمص': u'رَمْصٍ', #1
u'رمص': u'رَمْصٌ', #2
u'رمص': u'رَمَصٌ', #6
u'رمصا': u'رَمَصًا', #1
u'رمصا': u'رُمْصًا', #2
u'رمصت': u'رَمَصَتْ', #1
u'رمصها': u'رَمَصُهَا', #1
u'رمضانا': u'رمضانًا', #1
u'رمضانا': u'رَمَضَانَا', #1
u'رمضانان': u'رَمَضَانَانِ', #4
u'رمضانه': u'رَمَضَانِهِ', #1
u'رمضانها': u'رَمَضَانُهَا', #1
u'رمضانها': u'رَمَضَانِهَا', #7
u'رمضانيته': u'رَمَضَانِيَّتُهُ', #10
u'رمضانين': u'رَمَضَانَيْنِ', #88
u'رمضته': u'رَمَضْتُهُ', #1
u'رمع': u'رِمَعٌ', #1
u'رمعرفته،': u'رمعرفته،', #1
u'رمكا': u'رَمَكًا', #2
u'رمكة': u'رُمْكَةٌ', #1
u'رمكة': u'رَمْكَةً', #3
u'رمكة': u'رَمَكَةٍ', #7
u'رمكة': u'رَمَكَةً', #9
u'رموح': u'رَمُوحٌ', #4
u'رموحا': u'رَمُوحًا', #12
u'رميثة': u'رميثة', #1
u'رميثة': u'رُمَيْثَة', #1
u'رميثة': u'رُمَيْثَةُ', #1
u'رميثة،': u'رُمَيْثَةَ،', #1
u'رميثة': u'رُمَيْثَةَ', #14
u'رميح،': u'رميح،', #1
u'رميح': u'رُمَيْحٍ', #1
u'رميلة': u'رُمَيْلَة', #1
u'رميلة': u'رُمَيْلَةٍ', #1
u'رميلة': u'رُمَيْلَةَ', #3
u'رميلة': u'رُمَيْلَةُ', #3
u'رمييهما': u'رَمْيَيْهِمَا', #2
u'رنج': u'رنج', #1
u'رنز': u'رَنْزٌ', #1
u'رنز': u'رُنْزٌ', #3
u'رنكند': u'رنكند', #1
u'رنكنم': u'رنكنم', #1
u'رهاء': u'رهاء', #1
u'رهاط': u'رُهَاطِ', #1
u'رهاط': u'رُهَاطٍ', #2
u'رهاط': u'رُهَاطٌ', #6
u'رهاكردم': u'رهاكردم', #1
u'رهج': u'رهج', #1
u'رهج': u'رَهْجِ', #1
u'رهج': u'رَهَجٌ', #2
u'رهج': u'رَهَجُ', #2
u'رهج': u'رَهَجِ', #2
u'رهجة': u'رَهْجَةُ', #4
u'رهد': u'رَهَدَ', #1
u'رهرهة': u'رَهْرَهَةٌ', #1
u'رهطامن': u'رَهْطًامِنْ', #1
u'رهكزار': u'رهكزار', #1
u'رهناء': u'رُهَنَاءُ', #1
u'رهنتكه': u'رَهَنْتَكَهُ', #1
u'رهنتكه': u'رَهَنْتُكَهُ', #3
u'رهنتكها': u'رَهَنْتُكَهَا', #1
u'رهنتنيه': u'رَهَنْتَنِيهِ', #14
u'رهنتنيها': u'رَهَنْتَنِيهَا', #2
u'رهننته': u'رَهْنِنَّتُهُ', #1
u'رهننته': u'رَهْنِنَّتِهِ', #1
u'رهننيه': u'رَهَنَنِيهِ', #1
u'رهنيته': u'رَهْنِيَّتُهُ', #1
u'رهنيته': u'رَهْنِيَّتِهِ', #10
u'رهنيتها': u'رَهْنِيَّتُهَا', #1
u'رهنيتها': u'رَهْنِيَّتِهَا', #2
u'رهى': u'رهى', #1
u'رهيزم': u'رهيزم', #2
u'رهيص': u'رَهِيصٍ', #15
u'روأ': u'رَوَّأَ', #1
u'رواباشد': u'رواباشد', #2
u'روأت': u'رَوَّأْت', #1
u'روأت': u'رَوَّأْتُ', #1
u'رواتع': u'رَوَاتِعُ', #1
u'رواداشتي': u'رواداشتي', #2
u'روازن': u'رَوَازِنُ', #3
u'رؤاس': u'رؤاس', #1
u'رؤاس': u'رُؤَاسُ', #1
u'رؤاس': u'رُؤَاسٍ', #4
u'رواسا': u'رَوَاسًا', #1
u'رواسا': u'رَوَاسَا', #1
u'رواسا': u'رَوَّاسًا', #1
u'رواسح': u'رَوُاسِحْ', #1
u'رواسية': u'رَوَاسِيَّةٍ', #1
u'رواشن': u'رَوَاشِنَ', #2
u'رواقات': u'رِوَاقَاتٌ', #1
u'رواله': u'رُوَالَهُ', #1
u'روان': u'روان', #1
u'روان': u'رَوَانِ', #1
u'روانبود': u'روانبود', #1
u'روانبورد': u'روانبورد', #1
u'رواند': u'رواند', #1
u'روانشد': u'روانشد', #1
u'رواهابن': u'رَوَاهُابْنُ', #1
u'رواهسلمة،': u'رَوَاهُسَلَمَةُ،', #1
u'رواهش': u'رَوَاهِشَ', #2
u'رواى': u'رواى', #1
u'روايةابن': u'رِوَايَةِابْنِ', #1
u'روايةمالك': u'رِوَايَةُمَالِكٍ', #1
u'روباخدا': u'روباخدا', #1
u'روباروى': u'روباروى', #1
u'رؤبة،': u'رؤبة،', #1
u'رؤبة': u'رُؤبَةُ', #1
u'رؤبة': u'رُؤْبَةٌ', #1
u'رؤبة،': u'رُؤْبَةَ،', #2
u'رؤبة': u'رُؤْبَةَ', #41
u'رؤبة': u'رُؤْبَةُ', #46
u'روبرو': u'روبرو', #1
u'روبكوكه': u'روبكوكه', #1
u'روبيل': u'رُوبِيلَ', #2
u'روبيل،': u'رُوبِيلُ،', #5
u'روبيل': u'رُوبِيلُ', #7
u'روثة': u'رَوْثَةٍ', #10
u'روثة': u'رَوْثَةً', #12
u'روثة': u'روثة', #2
u'روثة': u'رَوْثَة', #2
u'روثة': u'رَوْثَةٌ', #2
u'روثة': u'رَوْثَةَ', #2
u'روجوعه': u'روجوعه', #1
u'روح،': u'رَوْحً،', #1
u'روحنة': u'رَوْحَنَةً', #1
u'روحى': u'رُوحِى', #2
u'رودبجاي': u'رودبجاي', #1
u'رودس': u'رُودِسَ', #2
u'روذي': u'رُوذِيٍّ', #1
u'رورداشت': u'رورداشت', #1
u'رورغيكذر': u'رورغيكذر', #1
u'روزازتو': u'روزازتو', #1
u'روزبة': u'رُوزَبَةَ', #1
u'روزبة،': u'رَوْزَبَةَ،', #1
u'روزبه': u'روزبه', #2
u'روزتاهزا': u'روزتاهزا', #1
u'روزجارا': u'روزجارا', #1
u'روزداشت': u'روزداشت', #1
u'روزراضا': u'روزراضا', #1
u'روزسنت': u'روزسنت', #1
u'روزكه': u'روزكه', #1
u'روزمانج': u'روزمانج', #1
u'روزنامجه': u'روزنامجه', #1
u'روزنة': u'رَوْزَنَةَ', #1
u'روزنة': u'رَوْزَنَةٌ', #2
u'روزنة': u'رَوْزَنَةٍ', #4
u'روزنة': u'رَوْزَنَةً', #7
u'روزور': u'روزور', #1
u'روزى': u'روزى', #2
u'روسبي': u'روسبي', #1
u'روسبي': u'رُوسْبِيٌّ', #1
u'روسبي': u'رُوسْبِيَّ', #1
u'روسبي': u'رُوسْبِيُّ', #1
u'روسبى': u'روسبى', #1
u'روسبيج': u'روسبيج', #1
u'روشنا': u'رَوْشَنًا', #14
u'روشنك': u'رَوْشَنك', #2
u'روشني': u'رَوْشَنِي', #1
u'روصاست': u'روصاست', #1
u'روعات': u'رَوْعَاتٍ', #1
u'روعات': u'رَوْعَاتُ', #2
u'روعات': u'رَوْعَاتِ', #6
u'روعاتكم': u'رَوْعَاتِكُمْ', #1
u'روعاتنا،': u'رَوْعَاتِنَا،', #1
u'روعاتنا': u'رَوْعَاتِنَا', #2
u'روعاتهم': u'رَوْعَاتِهِمْ', #1
u'روعاتي': u'رَوْعَاتِي', #5
u'روعهاأنه': u'رَوْعِهَاأَنَّهُ', #1
u'روعى': u'رُوعِىَ', #1
u'روماد': u'روماد', #1
u'رومة': u'رُومة', #1
u'رومة': u'رُومَةٍ', #1
u'رومة،': u'رُومَةُ،', #1
u'رومة': u'رُومَة', #2
u'رومة،': u'رومة،', #3
u'رومة': u'رُومَةٌ', #3
u'رومة': u'رُومَةُ', #3
u'رومة': u'رُومَةَ', #48
u'رومى': u'رومى', #1
u'رومى': u'رُومِىٍّ', #1
u'رونبوشي': u'رونبوشي', #1
u'روواورا': u'روواورا', #1
u'رووسه': u'رووسه', #1
u'روؤسهم،': u'روؤسهم،', #1
u'رووى': u'رووى', #1
u'رؤي': u'رُؤي', #1
u'رؤي': u'رُؤيَ', #1
u'رؤي': u'رُؤْيَ', #1
u'رؤي،': u'رُؤِيَ،', #1
u'رؤي': u'رُؤِيَ', #18
u'رؤي': u'رؤي', #3
u'رؤيا': u'رُؤْيًا', #1
u'رؤياى': u'رُؤْيَاىَ', #1
u'رويبة،': u'رويبة،', #1
u'رويبة': u'رُوَيْبِةَ', #2
u'رويبة،': u'رُوَيْبَةَ،', #2
u'رويبة': u'رُوَيْبَةَ', #36
u'رويبة': u'رويبة', #4
u'رؤيبة': u'رُؤَيْبَةَ', #7
u'رؤيت': u'رُؤِيَتْ', #1
u'رويجل': u'رُوَيْجل', #1
u'رويجل': u'رُوَيْجِلٌ', #1
u'رويجلا': u'رُوَيْجِلا', #2
u'رويحة': u'رُوَيْحة', #1
u'رويحة': u'رُوَيْحَةَ', #9
u'رويحك': u'رُوَيْحُكَ', #1
u'رويدية': u'رُوَيْدِيَّةٌ', #1
u'رويشد': u'رُوَيْشِدُ', #1
u'رويشد': u'رُوَيْشِدٌ', #3
u'رويشد': u'رُوَيْشِدٍ', #6
u'رويشدا': u'رُوَيْشِدًا', #1
u'رويعي': u'رُوَيْعِيَ', #1
u'رويعي': u'رُوَيْعِيَّ', #1
u'رويعي': u'رُوَيْعِيِّ', #1
u'رويعي': u'رُوَيْعِي', #4
u'رويعينا': u'رُوَيْعِينَا', #1
u'رويعينا': u'رُوَيْعِيَنَا', #1
u'رويفع': u'رُوِيَفع', #1
u'رويفع،': u'رُوَيْفِعٍ،', #1
u'رويفع': u'رُوَيْفِعُ', #19
u'رويفع': u'رويفع', #2
u'رويفع': u'رُوَيْفِع', #2
u'رويفع': u'رُوَيْفِعٌ', #2
u'رويفع': u'رُوَيْفِعِ', #30
u'رويفع': u'رُوَيْفِعَ', #6
u'رويفع': u'رُوَيْفِعٍ', #7
u'رويكبا': u'رُوَيْكِبًا', #1
u'رويم': u'رويم', #1
u'رويم،': u'رويم،', #1
u'رويم': u'رُوَيْم', #1
u'رويم': u'رُوَيْمُ', #1
u'رويم،': u'رُوَيْمٍ،', #11
u'رويم': u'رُوَيْمٍ', #12
u'رويم': u'رُوَيْمٌ', #5
u'رى': u'رى', #1
u'رى': u'رِىِّ', #2
u'رئاء': u'رِئَاءٌ', #1
u'رئاء': u'رِئَاءَ', #11
u'رئاء': u'رِئَاء', #2
u'رئاء': u'رِئَاءً', #3
u'رئاب': u'رِئَابَ', #1
u'رئاب': u'رِئَاب', #2
u'رئاب،': u'رِئَابٍ،', #2
u'رئاب': u'رِئَابِ', #29
u'رئاب': u'رئاب', #4
u'رئاب': u'رِئَابٍ', #58
u'رئام': u'رئَامٌ', #1
u'رئام': u'رِئَامٍ', #1
u'رئام': u'رِئَامٌ', #8
u'رئاما': u'رِئَامًا', #1
u'رئدا': u'رِئْدًا', #1
u'رئم': u'رِئْمٌ', #2
u'رئم': u'رِئْمٍ', #6
u'رئما': u'رِئْمًا', #1
u'رئمان': u'رِئْمَانُ', #1
u'رئمت': u'رَئِمَتْ', #1
u'رئى': u'رُئِىَ', #13
u'رئيك': u'رَئِيَّكَ', #1
u'رئيك': u'رَئِيُّكَ', #1
u'رياب': u'رِيَابٍ', #1
u'رياب': u'رِيَابِ', #1
u'رياب،': u'رِيَابٍ،', #1
u'رياب': u'رياب', #3
u'رياط': u'رِيَاط', #1
u'رياط': u'رِيَاطٍ', #1
u'رياط': u'رِيَاطِ', #1
u'ريالات': u'رِيَالَاتٍ', #36
u'ريالين': u'رِيَالَيْنِ', #1
u'ريام': u'رِيَامٌ', #1
u'ريانا': u'رَيَّانًا', #10
u'ريانة': u'رَيَّانَةٌ', #1
u'ريانة': u'رَيَّانَةً', #2
u'ريبوس،': u'ريبوس،', #1
u'رية': u'رِيّةً', #1
u'رية': u'رّيّةُ', #1
u'ريت': u'رَيْتَ', #2
u'ريخته': u'ريخته', #3
u'ريداززدن': u'ريداززدن', #1
u'ريدة': u'رَيْدَةَ', #3
u'ريدعن': u'ريَدَعْنَ', #1
u'ريزه': u'ريزه', #1
u'ريسمان': u'ريسمان', #5
u'ريش': u'رِيشً', #1
u'ريضة': u'َرِيضَةً', #1
u'ريطا': u'رَيْطًا', #2
u'ريطار': u'رَيْطَارٌ', #1
u'ريطار': u'رَيْطَارٍ', #6
u'ريطة': u'ريطةٍ', #1
u'ريطة': u'رِيطَةً', #1
u'ريطة': u'رَيْطَةٍ', #1
u'ريطة': u'رَيْطَةُ', #18
u'ريطة': u'رَيْطَة', #2
u'ريطة': u'ريطة', #3
u'ريطة': u'رَيْطَةً', #5
u'ريطة': u'رَيْطَةٌ', #5
u'ريطة': u'رَيْطَةَ', #5
u'ريطتي': u'ريطتي', #1
u'ريطتين': u'ريطتين', #1
u'ريقى': u'رِيقِى', #1
u'ريكستان': u'ريكستان', #1
u'رينكوكيرنا': u'رينكوكيرنا', #1
u'ريئات': u'ريئات', #1
u'ريئت': u'رِيئَتْ', #9
u'زاء': u'زَاءُ', #1
u'زاء': u'زَاءِ', #1
u'زادة': u'زادة', #1
u'زادة': u'زَادَةْ', #7
u'زادن': u'زادن', #1
u'زادنى': u'زَادَنِى', #4
u'زادنيه': u'زَادَنِيهِ', #1
u'زاذان،': u'زَاذانَ،', #1
u'زاذان': u'زَاذَان', #1
u'زاذان': u'زَاذَانُ', #10
u'زاذان': u'زَاذَانَ', #148
u'زاذان،': u'زَاذَانَ،', #45
u'زاذان': u'زاذان', #6
u'زاذويه': u'زَاذَوَيْهِ', #1
u'زاذى': u'زَاذَى', #1
u'زارة': u'زَارَةَ', #2
u'زارحا': u'زَارِحًا', #1
u'زارم': u'زارم', #2
u'زارم': u'زَارِمٍ', #2
u'زارم': u'زَارِمَ', #5
u'زارنى': u'زَارَنِى', #3
u'زارين': u'زَارَّيْنِ', #1
u'زاطيا': u'زَاطِيَا', #2
u'زافلة': u'زَافِلَةَ', #6
u'زاقرت': u'زَاقَرْت', #2
u'زاقرتك': u'زَاقَرْتك', #2
u'زالق،': u'زالق،', #1
u'زام': u'زَامَ', #1
u'زام': u'زَامّ', #2
u'زامين': u'زامين', #1
u'زأن': u'زَأْنَ', #1
u'زانى': u'زَانَى', #2
u'زانئ': u'زَانِئ', #1
u'زانئ': u'زَانِئٌ', #1
u'زانئ': u'زَانِئُ', #8
u'زاون': u'زَاوُنٍ', #1
u'زائعة': u'زَائِعَةٌ', #2
u'زائل9894id': u'زائل9894id', #1
u'زايدا': u'زَايِدًا', #1
u'زايدة،': u'زَايِدَةَ،', #2
u'زاين': u'زاين', #1
u'زبا': u'زُبًّا', #1
u'زباء': u'زَبّاءُ', #1
u'زباء،': u'زَبَّاءَ،', #1
u'زباتو': u'زباتو', #1
u'زبار،': u'زَبَّارٍ،', #2
u'زبار': u'زَبَّارٍ', #7
u'زبانيه4827id': u'زبانيه4827id', #1
u'زبانيه': u'زَبَانِيَهْ', #3
u'زبدانست': u'زبدانست', #1
u'زبراء': u'زَبْرَاءَ', #4
u'زبراء': u'زَبْرَاءُ', #5
u'زبرة': u'زَبْرَةِ', #1
u'زبرة': u'زُبْرَةً', #1
u'زبرة': u'زُبْرَةِ', #14
u'زبرة': u'زُبْرَةَ', #2
u'زبرة': u'زُبْرَةُ', #2
u'زبرة': u'زُبْرَةٍ', #7
u'زبرجدة': u'زَبَرْجَدَةٍ', #1
u'زبرجدة': u'زَبَرْجَدَةٌ', #2
u'زبرقت': u'زَبْرَقْت', #1
u'زبريق': u'زِبْرِيقَ', #1
u'زبريق،': u'زِبْرِيقٍ،', #1
u'زبريق،': u'زِبْرِيقَ،', #1
u'زبريق': u'زِبْرِيقٍ', #2
u'زبعراة': u'زِبَعْرَاةَ', #1
u'زبعرى': u'زِبَعْرَى', #1
u'زبيد،': u'زُبَيْدُ،', #1
u'زبيد': u'زَبِيدٍ', #10
u'زبيد': u'زُبَيْدُ', #11
u'زبيد': u'زُبَيْدٍ', #142
u'زبيد،': u'زبيد،', #16
u'زبيد': u'زُبَيْدٌ', #31
u'زبيد': u'زُبَيْدِ', #4
u'زبيد،': u'زُبَيْدٍ،', #41
u'زبيد،': u'زُبَيْدٌ،', #5
u'زبيد': u'زبيد', #6
u'زبيد': u'زَبِيدَ', #6
u'زبيدا': u'زُبَيْدًا', #3
u'زبيدي': u'زُبَيْدِيٌّ', #1
u'زبيرا': u'زُبَيْرًا', #1
u'زبيل': u'زَبِيلٌ', #2
u'زبيل': u'زَبِيلٍ', #2
u'زبيلا': u'زَبِيلًا', #2
u'زبينا': u'زَبِينًا', #1
u'زبينة': u'زَبِينَةَ', #1
u'زبينة': u'زَبِينة', #2
u'زبينة': u'زُبَيْنَةَ', #3
u'زتد': u'زتد', #1
u'زتن': u'زَتَنَ', #1
u'زتو': u'زتو', #2
u'زجم': u'زَجَمَ', #1
u'زجوم': u'زَجُومٌ', #1
u'زحك': u'زحك', #2
u'زحمويه': u'زحمويه', #1
u'زحمويه،': u'زَحْمَوَيهِ،', #1
u'زحمويه': u'زَحْمُوَيْهِ', #1
u'زحمويه': u'زَحْمَوَيْهِ', #5
u'زحمويه،': u'زَحْمَوَيْهِ،', #7
u'زحنة': u'زَحْنَةُ', #1
u'زخزبا': u'زُخْزُبًا', #1
u'زخزبا': u'زُخْزُبًّا', #2
u'زخفا': u'زَخْفًا', #1
u'زدتا': u'زِدْتَا', #1
u'زدنى': u'زِدْنِى', #5
u'زدودن': u'زدودن', #1
u'زديو': u'زديو', #1
u'زذه': u'زذه', #1
u'زرأ': u'زَرَّأَ', #1
u'زراء': u'زِرَاءِ', #1
u'زرابيب': u'زَرَابِيبَ', #1
u'زرابيب': u'زَرَابِيبُ', #1
u'زراح': u'زَرَاحٌ', #1
u'زراح': u'زراح', #2
u'زرارةفقال': u'زُرَارَةَفَقَالَ', #1
u'زراية': u'زِرَايَةً', #1
u'زربة،': u'زَرْبَةَ،', #1
u'زربة،': u'زُرْبَةَ،', #1
u'زربول': u'زُرْبُولٍ', #2
u'زربولا': u'زَرْبُولًا', #1
u'زربولا': u'زُرْبُولًا', #3
u'زربى': u'زَرْبِىٍّ', #2
u'زربيتى': u'زَرْبِيَّتِى', #1
u'زرجون': u'زرجون', #1
u'زرجون': u'زَرَجُونٍ', #1
u'زرجون': u'زَرْجُونٍ', #1
u'زرجونا': u'زَرْجُونًا', #1
u'زرخانها': u'زرخانها', #1
u'زردالو': u'زردالو', #1
u'زردة': u'زَرْدَةٍ', #1
u'زردج': u'زَرْدَجِ', #1
u'زردردمه': u'زردردمه', #1
u'زردوست': u'زردوست', #1
u'زرسرخ': u'زرسرخ', #1
u'زرعى': u'زَرْعِى', #1
u'زرقان،': u'زُرْقَانَ،', #1
u'زرقم': u'زُرْقُمٍ', #1
u'زرقون': u'زَرْقُون', #1
u'زرقون': u'زَرْقُونٍ', #189
u'زرقون': u'زَرْقُونَ', #6
u'زرقويه': u'زرقُوَيْهِ', #1
u'زرقويه': u'زَرْقُوَيْهِ', #1
u'زرقى': u'زُرَقِىٌّ', #2
u'زركه': u'زركه', #1
u'زركوبان': u'زركوبان', #1
u'زرم': u'زَرِمَ', #2
u'زرمانقة': u'زُرْمَانِقَةٌ', #2
u'زرموزة': u'زرموزة', #1
u'زرموزة': u'زُرْمُوزَةٍ', #1
u'زرنب': u'زَرْنَبٍ', #1
u'زرنج': u'زَرَنْج', #1
u'زرنج': u'زَرَنْجَ', #1
u'زرنج،': u'زَرَنْج،', #1
u'زرنر': u'زرنر', #1
u'زرنوق': u'زَرْنُوقٍ', #3
u'زرنوقان': u'زُرْنُوقَانِ', #1
u'زرهارا': u'زرهارا', #1
u'زروان،': u'زُرْوَانَ،', #1
u'زروان': u'زَرْوَانَ', #3
u'زرواند': u'زرواند', #1
u'زروق': u'زَرُّوقْ', #1
u'زروق': u'زَرُّوقٌ', #177
u'زروق': u'زَرُّوقٍ', #60
u'زروقا': u'زَرُّوقًا', #2
u'زريب': u'زُرَيْبٍ', #1
u'زريب': u'زُرَيْبَ', #1
u'زريب': u'زُرَيْبُ', #1
u'زريبا': u'زُرَيْبًا', #1
u'زطا': u'زُطًّا', #1
u'زطب': u'زطب', #2
u'زطط': u'زطط', #1
u'زطي': u'زطي', #1
u'زطي': u'زُطِّيُّ', #1
u'زطي': u'زُطِّيٌّ', #11
u'زطي': u'زُطِّيٍّ', #55
u'زطيا': u'زُطِّيًّا', #10
u'زطية': u'زَطِّيَةٌ', #1
u'زطية': u'زُطِّيَّةٌ', #1
u'زطية': u'زُطِّيَّةٍ', #1
u'زطيين': u'زُطِّيَّيْنِ', #1
u'زعابة': u'زُعَابَةُ', #1
u'زعب': u'زَعْبِ', #2
u'زعب': u'زِعْبِ', #2
u'زعبة': u'زَعْبَةً', #1
u'زعبل': u'زَعْبَلٍ', #2
u'زعكرة': u'زعكرة', #1
u'زعكرة': u'زَعْكَرَةَ', #1
u'زعمات': u'زَعَمَاتِ', #1
u'زعمان': u'زَعْمَانِ', #1
u'زعمتمو': u'زَعَمْتُمُو', #1
u'زعميهما': u'زَعْمَيْهِمَا', #1
u'زعنة': u'زَعْنَةَ', #9
u'زعورا': u'زعورا', #1
u'زعورا': u'زَعْوَرَا', #1
u'زعورا': u'زَعُورَا', #6
u'زعوراء': u'زَعُوراء', #1
u'زعوراء': u'زَعُورَاءُ', #1
u'زعوراء': u'زَعُورَاءِ', #1
u'زعوراء': u'زَعُورَاءَ', #13
u'زعوراء': u'زَعَوْرَاءَ', #2
u'زعوراء': u'زعوراء', #4
u'زعون': u'زَعْوَنِ', #1
u'زغابات': u'زَغَابَاتٍ', #1
u'زغابة': u'زَغَابَةُ', #1
u'زغابة': u'زُغَابَةَ', #1
u'زغابة': u'زَغَابَةَ', #8
u'زغار': u'زغار', #1
u'زغاريت': u'زَغَارِيتَ', #1
u'زغد': u'زَغَدَ', #1
u'زغر': u'زُغَر', #1
u'زغر': u'زُغَرٍ', #1
u'زغر': u'زُغْرِ', #1
u'زغر': u'زُغَرَ', #6
u'زغرتة': u'زَغْرَتَةٍ', #1
u'زغرثا،': u'زَغَرْثَا،', #1
u'زغرنا،': u'زِغْرَنَا،', #1
u'زغف': u'زَغْفٍ', #1
u'زغلة': u'زُغْلَةً', #2
u'زغوتا،': u'زَغُوتًا،', #1
u'زغيبات': u'زغيبات', #1
u'زفزة': u'زَفْزَةٌ', #1
u'زفنكم': u'زَفْنِكُمْ', #1
u'زفنوا': u'زَفَنُوا', #1
u'زقيقة': u'زَقِيقَةٌ', #1
u'زقيقة': u'زَقِيقَةٍ', #1
u'زقيقة': u'زُقَيْقَةٌ', #1
u'زقيقة': u'زُقَيْقَةٍ', #1
u'زكأت': u'زَكَأْتُ', #1
u'زكاتية': u'زَكَاتِيَّةٌ', #1
u'زكران': u'زِكْرَانَ', #1
u'زكري': u'زِكْرِي', #1
u'زكرى': u'زكرى', #1
u'زكري': u'زِكْرِيّ', #2
u'زكري': u'زِكْرِيٍّ', #8
u'زكرياوأبوبكر': u'زَكَرِيَّاوأَبُوبَكْرٍ', #1
u'زكمة': u'زُكْمَةً', #1
u'زكمة': u'زُكْمَةٌ', #2
u'زكيبة': u'زَكِيبَةً', #1
u'زكيبة': u'زَكِيبَةٍ', #3
u'زكيبتين': u'زَكِيبَتَيْنِ', #2
u'زكير': u'زِكِّيرٍ', #1
u'زكير،': u'زُكَيْرٍ،', #2
u'زكير': u'زُكَيْرٍ', #3
u'زلاء': u'زَلَّاءَ', #11
u'زلاء': u'زَلَّاءُ', #2
u'زلائل': u'زُلَائِلٌ', #1
u'زلةSحكم': u'زَلّةًSحُكْمُ', #1
u'زلطا': u'زَلَطًا', #2
u'زلطة': u'زَلَطَةً', #1
u'زلطة': u'زُلْطَةٌ', #1
u'زليخا': u'زُلَيْخَا', #11
u'زمانةوروي': u'زَمَانَةٌوَرُوِيَ', #1
u'زمتولئ': u'زمتولئ', #1
u'زمزام': u'زَمْزَامُ', #1
u'زمزومها': u'زُمْزُومَهَا', #1
u'زمستان': u'زَمَسْتَانَ', #1
u'زمعةو': u'زَمْعَةَوَ', #1
u'زمعةوعلي': u'زَمَعَةَوَعَلِيّ', #1
u'زمغ': u'زمغ', #1
u'زملونى': u'زَمِّلُونِى', #11
u'زمن': u'زَمَنً', #1
u'زمناء': u'زُمَنَاءَ', #3
u'زمنة': u'زَمِنَةً', #40
u'زمنة': u'زَمِنَةٍ', #7
u'زمنة': u'زَمِنَةٌ', #9
u'زمنى،': u'زَمْنَى،', #1
u'زمنى': u'زَمْنَى', #22
u'زميلى': u'زَمِيلَىْ', #1
u'زمين': u'زَمِينٍ', #2
u'زمين': u'زمين', #4
u'زمين': u'زُمَيْن', #5
u'زمينها': u'زمينها', #2
u'زمينها': u'زُمَيْنهَا', #3
u'زنأ': u'زَنَأَ', #11
u'زناب؟،': u'زُنَابُ؟،', #1
u'زناب': u'زَنَابُ', #3
u'زناب؟': u'زُنَابُ؟', #3
u'زناب': u'زُنَابُ', #5
u'زناباها': u'زُنَابَاهَا', #1
u'زنابكم': u'زُنَابَكُمْ', #1
u'زنأت': u'زَنَأْتِ', #1
u'زنأت': u'زَنَأْتَ', #12
u'زنأت': u'زَنَأْتُ', #3
u'زنأت': u'زَنَأْت', #53
u'زنأت': u'زَنَأَتْ', #6
u'زناق': u'زِنَاقٌ', #1
u'زناها': u'زِنَاهًا', #2
u'زنايا': u'زنايا', #1
u'زنباع': u'زِنْبَاعٌ', #1
u'زنباع': u'زِنْبَاعِ', #1
u'زنباع': u'زِنْبَاعٍ', #19
u'زنباع': u'زنباع', #2
u'زنباع،': u'زِنْبَاعٍ،', #5
u'زنباعا': u'زِنْبَاعًا', #5
u'زنبر': u'زَنَبْرٍ', #1
u'زنبر': u'زُنْبُر', #1
u'زنبر،': u'زُنْبُرٍ،', #1
u'زنبر': u'زَنْبَرٍ', #11
u'زنبر': u'زَنْبَر', #2
u'زنبر': u'زَنْبَرِ', #2
u'زنبر': u'زَنْبَرَ', #3
u'زنبرة': u'زَنْبَرَةَ', #1
u'زنبرة': u'زَنْبَرَةٌ', #2
u'زنجة': u'زَنْجَةَ', #1
u'زنجة،': u'زنجةَ،', #2
u'زنجة،': u'زِنْجَةَ،', #3
u'زنجة،': u'زَنْجَةَ،', #4
u'زنجرلي': u'زنجرلي', #1
u'زنجلة،': u'زنجلةَ،', #1
u'زنجلة': u'زَنْجَلَةَ', #2
u'زنجلة،': u'زَنْجَلَةَ،', #2
u'زنجويه،': u'زَنْجُويَهِ،', #1
u'زنجويه،': u'زَنْجُوَيْهِ،', #15
u'زنجويه': u'زَنْجَوَيْه', #2
u'زنجويه': u'زَنْجُوَيْهِ', #36
u'زنجويه': u'زَنْجُويَهْ', #4
u'زنجويه': u'زَنْجَوَيْهِ', #4
u'زنجويه،': u'زنجويه،', #5
u'زنجويه،': u'زَنْجَوَيْهِ،', #6
u'زنجى': u'زَنْجِىٍّ', #1
u'زنخة': u'زَنِخَةٍ', #1
u'زندبجيبيا': u'زندبجيبيا', #1
u'زندبيجا': u'زَنْدَبِيجًا', #1
u'زندبيجيا': u'زَنْدَبِيجِيًّا', #1
u'زندنة': u'زَنْدَنَةَ', #3
u'زندنيجي': u'زَنْدَنِيجِيٌّ', #1
u'زندويسي': u'زَنْدَوِيسِيِّ', #1
u'زندى': u'زَنْدَىَّ', #1
u'زندى': u'زَنْدَىْ', #1
u'زندىء': u'زندىء', #1
u'زنديقة': u'زِنْدِيقَةً', #2
u'زنكان': u'زنكان', #3
u'زنكلوني': u'زَنْكَلُونِيٌّ', #3
u'زنوة': u'زَنْوَةً', #2
u'زنود': u'زُنُودٌ', #2
u'زنئا': u'زَنْئًا', #9
u'زنئان': u'زِنَئَانِ', #1
u'زنيات': u'زَنَيَاتٍ', #1
u'زنيب،': u'زنيب،', #1
u'زنيب': u'زُنَيْبٍ', #2
u'زنية': u'زَنْيَةٌ', #1
u'زنية': u'زِنْيَةً', #1
u'زنية': u'زَنِيَّةٍ', #2
u'زنية،': u'زِنْيَةٍ،', #2
u'زنية': u'زَنْيَةً', #22
u'زنية': u'زِنْيَةٍ', #23
u'زنية': u'زَنْيَةٍ', #9
u'زنيج': u'زُنَيْجٍ', #1
u'زنيج،': u'زُنَيْجٍ،', #1
u'زنيج،': u'زُنَيْجُ،', #1
u'زنيج،': u'زُنَيْجٌ،', #181
u'زنيج': u'زُنَيْجٌ', #19
u'زنيج،': u'زُنَيْج،', #4
u'زنيرة': u'زِنّيرَةَ', #1
u'زنيرة': u'زِنّيرَةُ', #1
u'زنيكه': u'زنيكه', #1
u'زنيم': u'زُنيم', #1
u'زنيم': u'زُنَيْم', #1
u'زنيم': u'زُنَيْمٌ', #1
u'زنيم': u'زُنَيْمٍ', #13
u'زنيم': u'زَنِيمٍ', #16
u'زنيم،': u'زُنَيْمٍ،', #2
u'زنيم': u'زَنِيمٌ', #7
u'زنيين': u'زَنَيَيْنِ', #1
u'زهاب': u'زهاب', #1
u'زهاليل': u'زَهَالِيلُ', #3
u'زهاو': u'زَهَاوٌ', #1
u'زهاوة': u'زَهَاوَةٍ', #1
u'زهج': u'زَهَجُ', #1
u'زهدم': u'زَهْدَم', #1
u'زهدم': u'زَهْدَمِ', #1
u'زهدم،': u'زَهْدَمٌ،', #1
u'زهدم،': u'زهدم،', #4
u'زهدم': u'زَهْدَمٍ', #47
u'زهدم': u'زهدم', #5
u'زهدم': u'زَهْدَمَ', #5
u'زهدم': u'زَهْدَمُ', #5
u'زهدم': u'زَهْدَمٌ', #6
u'زهدم،': u'زَهْدَمٍ،', #6
u'زهلول': u'زُهْلُولٌ', #1
u'زهم': u'زَهْمٍ', #1
u'زهمتهم': u'زَهَمَتُهُمْ', #1
u'زهمهم': u'زُهْمهمْ', #1
u'زهمهم': u'زَهَمُهُمْ', #2
u'زهومة': u'زُهُومَةٍ', #1
u'زهومة': u'زُهُومَةَ', #1
u'زهومة': u'زُهُومَةٌ', #5
u'زهومة': u'زُهُومَةً', #9
u'زهومته': u'زُهُومَتِهِ', #1
u'زهومتها': u'زُهُومَتَهَا', #1
u'زهومتها': u'زُهُومَتِهَا', #1
u'زهيرا': u'زهيرا', #1
u'زهيرا': u'زُهَيْرًا', #10
u'زو': u'زُو', #2
u'زؤار': u'زُؤَارَ', #1
u'زوانة': u'زُوَانَةٌ', #1
u'زوانة': u'زُوَانَةُ', #1
u'زوانى': u'زَوَانِى', #1
u'زوتي': u'زوتي', #1
u'زوجتكه': u'زَوَّجْتُكَهُ', #2
u'زوجتكها،': u'زَوَّجْتُكَهَا،', #1
u'زوجتكها': u'زَوَّجْتُكَهَا', #73
u'زوجتكها': u'زَوَّجْتُكهَا', #95
u'زوجتكهما': u'زَوَّجْتُكَهُمَا', #2
u'زوجتكيه': u'زَوَّجْتُكِيهِ', #1
u'زوجتمانيها': u'زَوَّجْتُمَانِيهَا', #1
u'زوجتنى': u'زَوَّجْتَنِى', #1
u'زوجتنيها': u'زَوَّجَتْنِيهَا', #1
u'زوجتنيها': u'زَوَّجْتنِيهَا', #5
u'زوجتنيها': u'زَوَّجْتَنِيهَا', #5
u'زوجتى': u'زَوْجَتَىِ', #1
u'زوجتى': u'زَوْجَتِى', #2
u'زوجناكها': u'زَوّجْنَاكهَا', #1
u'زوجناكها': u'زَوّجْنَاكَهَا', #3
u'زوجناكها': u'زَوَّجْنَاكَهَا', #37
u'زوجناكها': u'زَوَّجْنَاكهَا', #5
u'زوجنى': u'زَوِّجْنِى', #4
u'زوجنى': u'زَوَّجَنِى', #6
u'زوجنيك': u'زَوَّجَنِيكَ', #1
u'زوجنيك': u'زَوَّجَنِيكِ', #1
u'زوجنيه': u'زَوِّجْنِيهِ', #2
u'زوجنيها،': u'زَوِّجْنِيهَا،', #1
u'زوجنيها': u'زوجنيها', #2
u'زوجنيها': u'زَوَّجَنِيهَا', #3
u'زوجنيها': u'زَوِّجْنِيهَا', #42
u'زوجونى': u'زَوِّجُونِى', #1
u'زوجى': u'زَوْجَىِ', #2
u'زوجى': u'زَوْجِى', #43
u'زودنى': u'زَوِّدْنِى', #1
u'زوراء': u'زَوْرَاءَ', #1
u'زوراء': u'زَوْرَاءُ', #2
u'زورات': u'زَوَّرَاتِ', #1
u'زورات': u'زَوْرَاتِ', #1
u'زورتين': u'زَوْرَتَيْنِ', #1
u'زوزان': u'زوزان', #1
u'زوزت': u'زَوَّزْتُ', #2
u'زوزتك': u'زَوَّزْتُك', #1
u'زوزتك': u'زَوَّزْتُكَ', #2
u'زوزتي': u'زَوْزَتِي', #1
u'زوزني': u'زَوِّزْنِي', #1
u'زولاق': u'زُولَاقٍ', #1
u'زويلة': u'زُوَيْلَةَ', #8
u'زى': u'زِىَّ', #2
u'زئبر': u'زِئْبِرِ', #1
u'زئبرية': u'زِئْبِرِيَّةً', #1
u'زيادا': u'زَيِادًا', #1
u'زيادا،': u'زيادًا،', #2
u'زيادا،': u'زِيَادًا،', #2
u'زيادا': u'زيادًا', #4
u'زيادا': u'زِيَادًا', #46
u'زيادت': u'زيادت', #2
u'زيادعن': u'زِيَادٍعَنْ', #1
u'زياده': u'زِيَاده', #1
u'زياده': u'زِيَادَهْ', #1
u'زياده': u'زِيَادُهُ', #1
u'زياده': u'زِيَادِهِ', #1
u'زياده': u'زياده', #3
u'زيازده': u'زيازده', #1
u'زياف': u'زِيَافٍ', #1
u'زيافة': u'زِيَافَةِ', #3
u'زيافته': u'زِيَافَتِهِ', #1
u'زيافته': u'زِيَافَتُهُ', #2
u'زياقيل': u'زياقيل', #1
u'زيالها': u'زِيَالُهَا', #2
u'زيام': u'زيام', #1
u'زيب': u'زيب', #1
u'زيبا': u'زَيْبَا', #1
u'زيبر': u'زِيبِرِ', #1
u'زيبق': u'زِيبَقِ', #1
u'زيدعن': u'زَيْدٍعَنِ', #1
u'زيدل': u'زَيْدَلٌ', #1
u'زيدل': u'زَيْدَلٍ', #1
u'زيدل': u'زَيْدَلَ', #1
u'زيدونى': u'زِيدُونِى', #1
u'زيراكد': u'زيراكد', #1
u'زيرع،': u'زَيْرَعٍ،', #1
u'زيع': u'زَيْعٍ', #1
u'زيغة': u'زَيْغَةَ', #3
u'زيقاتها': u'زِيقَاتِهَا', #1
u'زيقة': u'زِيَقَةٍ', #1
u'زيلع': u'زَيْلَعِ', #2
u'زيلعي': u'زَيْلَعِيُّ', #1
u'زيلعي': u'زَيْلَعِيٌّ', #787
u'زينو': u'زَيِّنُو', #1
u'زييد': u'زييد', #1
u'زييد': u'زُيَيْد', #1
u'زييد': u'زُيَيْدَ', #1
u'زييد': u'زُيَيْدٍ', #2
u'زييد': u'زُيَيْدِ', #4
u'سا': u'سًا', #1
u'ساءوا': u'سَاءُوا', #1
u'ساباط': u'سَابَاطُ', #1
u'ساباط': u'سَابَاطٌ', #13
u'ساباط': u'سَابَاطِ', #2
u'ساباط': u'سَابَاطٍ', #28
u'ساباطا': u'سَابَاطًا', #16
u'ساباطه': u'سَابَاطَهُ', #1
u'ساباطه': u'سَابَاطِهِ', #2
u'ساببت': u'سَابَبْت', #1
u'ساببت': u'سَابَبْتَ', #1
u'ساببت': u'سَابَبْتُ', #4
u'سابرزن': u'سابرزن', #1
u'سابرية': u'سَابِرِيَّةً', #2
u'سابط': u'سابط', #1
u'سابط': u'سَابِط', #1
u'سابط': u'سَابِطٌ', #1
u'سابط،': u'سَابِطٍ،', #15
u'سابط،': u'سابط،', #4
u'سابط': u'سَابِطٍ', #53
u'سابط،في': u'سَابِطٍ،فِي', #2
u'سابقنى': u'سَابَقَنِى', #1
u'سابقية': u'سَابِقِيَّةُ', #1
u'سابقية': u'سَابِقِيَّةَ', #11
u'سابقية': u'سَابِقِيَّةِ', #6
u'سابقينوروى': u'سَابِقِينَوَرُوِِىِ', #1
u'سابور،': u'سابور،', #2
u'سابور،': u'سَابُورٍ،', #2
u'سابور': u'سَابُورَ', #20
u'سابور': u'سَابُورُ', #32
u'سابور': u'سابور', #5
u'سابور،': u'سَابُورَ،', #5
u'سأتلوا': u'سَأَتْلُوا', #1
u'سأتني': u'سأتني', #1
u'ساجا': u'سَاجًا', #2
u'ساجة': u'سَاجَة', #1
u'ساجة': u'سَاجَةُ', #1
u'ساجة': u'سَاجَةِ', #2
u'ساجة': u'سَاجَةً', #28
u'ساجة': u'سَاجَةٍ', #7
u'ساجته': u'سَاجَتَهُ', #1
u'ساجر': u'سَاجِرُ', #2
u'ساحروا': u'سَاحِرُوا', #2
u'ساحقت': u'سَاحَقَتْ', #7
u'سادتى': u'سَادَتِى', #2
u'سادروان': u'سادروان', #1
u'سادع': u'سَادِعٍ', #1
u'ساذنج': u'ساذنج', #1
u'سآر': u'سَآَّرٌ', #1
u'سأر': u'سَأَرَ', #1
u'سارةالحديث': u'سَارَةُالْحَدِيثُ', #1
u'سارثلاثة': u'سَارَثَلَاثَةَ', #1
u'سارروه': u'سَارَرُوهُ', #1
u'سارعتني': u'سَارَعَتْنِي', #1
u'سارنى': u'سَارَّنِى', #5
u'ساروغ': u'ساروغ', #1
u'ساروغ': u'سَارُوغَ', #3
u'سازد': u'سازد', #2
u'ساسان': u'ساسان', #1
u'ساسان': u'سَاسَان', #1
u'ساسان': u'سَاسَانِ', #2
u'ساسان': u'سَاسَانَ', #26
u'ساسان': u'سَاسَانُ', #3
u'ساسان،': u'سَاسَانَ،', #4
u'ساسويه،': u'سَاسَوَيْهِ،', #1
u'ساسويه': u'سَاسَوَيْهِ', #3
u'ساسويه': u'سَاسُوَيْهِ', #4
u'ساعتى': u'سَاعَتِى', #5
u'سأعطيكها': u'سَأُعْطِيكَهَا', #3
u'سأعلمكها': u'سَأُعَلِّمُكَهَا', #1
u'ساغب': u'سَاغِبٍ', #1
u'ساغبا': u'سَاغِبًا', #6
u'ساغين': u'سَاغَيْنِ', #2
u'ساف': u'سَافَ', #3
u'ساف': u'سَافٍ', #5
u'سافرناه': u'سافرناه', #1
u'سافرناه': u'سَافَرْنَاهُ', #1
u'سافرناه،': u'سَافَرْنَاهُ،', #1
u'سافرناها': u'سَافَرْنَاهَا', #3
u'سافروها': u'سَافِرُوهَا', #1
u'سافروها': u'سَافَرُوهَا', #7
u'سافع': u'سَافِعٍ', #1
u'سافع': u'سَافِعِ', #3
u'ساقات': u'سَاقَاتٍ', #1
u'ساقب': u'سَاقِبٍ', #1
u'ساكنى': u'سَاكِنِى', #1
u'سالادية': u'سالادية', #1
u'سالار': u'سالار', #3
u'سألتكه': u'سَأَلْتُكَهُ', #5
u'سألتكوالوجه': u'سَأَلْتُكَوَالْوَجْهُ', #1
u'سألتمانى': u'سَأَلْتُمَانِى', #1
u'سألتمونى': u'سَأَلْتُمُونِى', #3
u'سألتمونيها': u'سَأَلْتُمُونِيهَا', #5
u'سألتنى': u'سَأَلْتَنِى', #16
u'سألتنى': u'سَأَلَتْنِى', #6
u'سألتنيه': u'سَأَلْتَنِيهِ', #1
u'سألتيني': u'سَأَلْتِينِي', #9
u'سالحون': u'سَالِحُونَ', #2
u'سالحين': u'سَالِحِين', #1
u'سالحين': u'سَالِحِينَ', #1
u'سالفتى': u'سَالِفَتِى', #1
u'سالمبما': u'سَالِمٌبِمَا', #1
u'سالميا': u'سَالِمِيًّا', #1
u'سألنى': u'سَأَلَنِى', #35
u'سألنيه': u'سَأَلَنِيهِ', #1
u'سألنيها': u'سَأَلَنِيهَا', #1
u'سالور': u'سالور', #1
u'سألونى': u'سَأَلُونِى', #1
u'سآم': u'سَآمٍ', #1
u'سآما': u'سَآمًا', #1
u'سامتت': u'سَامَتَتْ', #7
u'سامتتها': u'سَامَتَتْهَا', #1
u'سامجة': u'سَامِجَةً', #1
u'سامراء': u'سَامِرَّاءَ', #1
u'سأنبيك': u'سَأُنْبِيكَ', #2
u'سانم': u'سانم', #4
u'سانيد': u'سانيد', #1
u'سانيده': u'سانيده', #1
u'سآها': u'سَآهَا', #2
u'ساوة،': u'سَاوَةَ،', #1
u'ساوة': u'سَاوَةَ', #2
u'سأوفيكه': u'سَأُوَفِّيكَهُ', #1
u'ساوق': u'سَاوَقَ', #2
u'ساوقه': u'سَاوَقَهُ', #1
u'سآئبة': u'سَآئِبَةٍ', #1
u'سائحاني': u'سائحاني', #1
u'سائحاني': u'سَائِحَانِيٍّ', #1
u'سائحاني': u'سَائِحَانِيٌّ', #182
u'سائم': u'سَائِمٌ', #1
u'سائم': u'سَائِمِ', #1
u'سائم': u'سَائِمٍ', #5
u'سائما': u'سَائِمًا', #3
u'سائمات': u'سَائِمَاتٍ', #2
u'سائمه': u'سَائِمِهِ', #1
u'ساية': u'سَايَةَ', #4
u'ساية': u'سَايَةُ', #6
u'سايرون': u'سَايِرُونِ', #1
u'سبأ': u'سَبَأً', #8
u'سباء': u'سباء', #1
u'سباء': u'سَبَاءٍ', #1
u'سباء': u'سِبَاءً', #1
u'سباء': u'سِبَاءِ', #1
u'سباء': u'سِبَاءُ', #2
u'سباء': u'سِبَاءٍ', #3
u'سباء': u'سِبَاءٌ', #5
u'سباءها': u'سِبَاءَهَا', #1
u'سباءى': u'سَبَاءَى', #1
u'سباط': u'سَبَاطِ', #1
u'سباط': u'سِبَاطٍ', #1
u'سباط': u'سُبَاطَ', #2
u'سباطر': u'سَبَاطِرٌ', #1
u'سباكا': u'سَبَّاكًا', #1
u'سباليه': u'سِبَالَيْهِ', #8
u'سباؤك': u'سِبَاؤُك', #1
u'سباؤه': u'سِبَاؤُهُ', #25
u'سباؤها،': u'سِبَاؤُهَا،', #1
u'سبائب': u'سَبَائِبَ', #2
u'سبائبها': u'سَبَائِبُهَا', #3
u'سبائي': u'سَبَائِي', #2
u'سببى': u'سَبَبِى', #3
u'سبتة': u'سَبْتَةً', #1
u'سبتة': u'سَبْتَةَ', #8
u'سبتى': u'سِبْتَىَّ', #1
u'سبتيا': u'سِبْتِيًّا', #1
u'سبتية': u'سِبْتِيَّة', #1
u'سبتية': u'سَبْتِيَّةٌ', #2
u'سبتيتان،': u'سِبْتِيَّتَانِ،', #1
u'سبتيتك': u'سِبْتِيَّتَكَ', #2
u'سبتيتيك': u'سِبْتِيَّتَيْك', #2
u'سبتيتيك': u'سِبْتِيَّتَيْكَ', #5
u'سبجا': u'سَبَجًا', #1
u'سبحانا': u'سُبْحَانًا', #1
u'سبحتى': u'سُبْحَتِى', #1
u'سبحلا': u'سِبَحْلًا', #1
u'سبد': u'سَبْدُ', #1
u'سبد': u'سَبَدٌ', #5
u'سبد': u'سَبَدُ', #7
u'سبدا': u'سَبَدًا', #1
u'سبدا': u'سَبَدَا', #1
u'سبذان': u'سَبَذَان', #1
u'سبرة': u'سَبُرَةَ', #1
u'سبرة': u'سَبْرَةِ', #1
u'سبرة،': u'سَبُرَةَ،', #1
u'سبرة،': u'سُبْرَةَ،', #1
u'سبرة': u'سبرة', #10
u'سبرة،': u'سَبْرَة،', #2
u'سبرة،': u'سبرة،', #3
u'سبرة': u'سَبْرة', #3
u'سبرة': u'سَبْرَةَ', #350
u'سبرة': u'سَبْرَة', #4
u'سبرة،': u'سَبْرَةَ،', #51
u'سبرة': u'سَبْرَةُ', #9
u'سبردني': u'سبردني', #1
u'سبردنى': u'سبردنى', #1
u'سبزك': u'سبزك', #1
u'سبس': u'سبس', #1
u'سبست': u'سبست', #1
u'سبطاء': u'سَبْطَاءُ', #1
u'سبطة': u'سَبِطَةً', #1
u'سبطة': u'سَبِطَةَ', #1
u'سبطة': u'سَبْطَةٌ', #1
u'سبطة': u'سَبْطَةٍ', #1
u'سبطة': u'سَبْطَةُ', #1
u'سبطة': u'سَبْطَةَ', #2
u'سبطة': u'سَبْطَةً', #3
u'سبطر': u'سِبَطْرِ', #2
u'سبع': u'سَبُعً', #1
u'سبعاوالوجه': u'سَبْعًاوَالْوَجْهُ', #1
u'سبعتين': u'سَبْعَتَيْنِ', #1
u'سبغة': u'سَبْغَةٌ', #1
u'سبقتكمو': u'سَبَقْتُكُمُو', #2
u'سبقتنى': u'سَبَقْتَنِى', #2
u'سبقتيني': u'سَبَقْتِينِي', #2
u'سبقنى': u'سَبَقَنِى', #7
u'سبقيته': u'سَبْقِيَّتِهِ', #10
u'سبكتكين': u'سُبُكْتِكِينَ', #1
u'سبلاتكم': u'سَبَلَاتِكُمْ', #1
u'سبلانات': u'سَبَلَانَاتٍ', #1
u'سبند': u'سبند', #1
u'سبنى': u'سَبَّنِى', #4
u'سبنية': u'سَبَنِيّةَ', #1
u'سبنية': u'سَبَنِيَّةً', #2
u'سبهللا': u'سَبَهْلَلَا', #1
u'سبهللا': u'سَبَهْلَلًا', #5
u'سبواورد': u'سبواورد', #1
u'سبوح': u'سَبُوحٌ', #1
u'سبوح': u'سُبّوحٍ', #1
u'سبوح': u'سَبُوحٍ', #2
u'سبوح': u'سَبُوحِ', #2
u'سبوح': u'سُبُّوح', #2
u'سبوح': u'سَبُّوحٌ', #3
u'سبوح': u'سُبُّوحٌ', #43
u'سبوس': u'سبوس', #1
u'سبولا': u'سُبُولًا', #1
u'سبوي': u'سبوي', #1
u'سبوى': u'سبوى', #2
u'سبويه،': u'سَبُّوَيْهِ،', #1
u'سبويه،': u'سِبُّوَيْهِ،', #1
u'سبويى': u'سبويى', #1
u'سبئ': u'سُبِئَ', #1
u'سبيبة': u'سَبِيبَةٍ', #1
u'سبيبته': u'سَبِيبَتِهِ', #1
u'سبيبي': u'سبيبيّ', #1
u'سبيداج': u'سِبِيدَاجَ', #1
u'سبيدار': u'سبيدار', #1
u'سبيع،': u'سبيع،', #1
u'سبيع': u'سُبَيْعٍ', #16
u'سبيع': u'سبيع', #2
u'سبيع،': u'سُبَيْعٍ،', #2
u'سبيع': u'سُبَيْعِ', #20
u'سبيع': u'سُبَيْع', #3
u'سبيع': u'سُبَيْعُ', #8
u'سبيعة': u'سُبَيْعَةُ', #24
u'سبيعة': u'سبيعة', #3
u'سبيعة': u'سُبَيعة', #3
u'سبيعة': u'سُبَيْعَة', #3
u'سبيعة': u'سُبَيْعَةَ', #55
u'سبيعين': u'سبيعين', #1
u'سبيق': u'سَبِيقُ', #1
u'سبيلهاقوله': u'سَبِيلَهَاقَوْلُهُ', #1
u'سبيلهالوجه': u'سَبِيلَهُالْوَجْهُ', #1
u'سبيلى': u'سَبِيلِى', #4
u'سبينة': u'سُبَيْنَة', #1
u'سبينة': u'سُبَيْنَةَ', #1
u'سبينة': u'سُبَيْنَةُ', #1
u'ستأتى': u'سَتَأْتِى', #3
u'ستأتيان': u'سَتَأْتِيَانِ', #1
u'ستاد': u'ستاد', #1
u'ستاسرت': u'ستاسرت', #1
u'ستاند': u'ستاند', #1
u'ستجدنى': u'سَتَجِدُنِى', #3
u'ستخلجه': u'سَتَخْلِجُهُ', #1
u'ستدى': u'ستدى', #2
u'سترةأو': u'سُتْرَةٍأَوْ', #1
u'ستقرءون': u'سَتَقْرَءُونَ', #1
u'ستم': u'ستم', #2
u'ستمكاره': u'ستمكاره', #1
u'ستو': u'ستو', #1
u'ستورراه': u'ستورراه', #1
u'ستوق': u'سَتُّوق', #1
u'ستوق': u'سُتُّوقُ', #1
u'ستوق': u'سَتُّوقٌ', #3
u'ستوق': u'سَتُّوقٍ', #4
u'ستوقا': u'سُتُّوقًا', #36
u'ستوقة': u'سَتُّوقَةً', #116
u'ستوقة': u'سَتُّوقَةَ', #2
u'ستوقة': u'سَتُّوقَةٌ', #59
u'ستوقة': u'سَتُّوقَةٍ', #6
u'ستوقية': u'سَتُّوقِيَّةً', #1
u'ستونا': u'سِتُّونَا', #1
u'ستويه': u'ستويه', #1
u'ستويه،': u'سَتَّوَيْهِ،', #1
u'ستويه،': u'سَتُّوَيْهِ،', #1
u'ستئيم': u'سَتَئِيمُ', #2
u'ستيتة': u'سُتَيْتَة', #1
u'ستيتة': u'سُتَيْتَةُ', #2
u'ستيتة': u'سُتَيْتَةَ', #6
u'ستير': u'سَتِير', #1
u'ستير': u'سِتِّيرٌ', #11
u'ستيرا': u'سَتِيرًا', #2
u'ستيرا': u'سِتِّيرًا', #4
u'ستينا': u'سِتِّينَا', #3
u'سجاجا': u'سَجَاجًا', #1
u'سجاح': u'سَجَاحُ', #3
u'سجاسج': u'سَجَاسِجُ', #1
u'سجام': u'سَجّام', #1
u'سجام': u'سَجّامِ', #1
u'سجام': u'سِجَامٌ', #1
u'سجام': u'سِجَامُ', #1
u'سجام': u'سِجَامِ', #1
u'سجائب': u'سَجَائِبُ', #1
u'سجدتى': u'سَجْدَتَىْ', #2
u'سجدتى': u'سَجْدَتَىِ', #46
u'سجدتين': u'سَجْدَتَيْنًًًًِ', #1
u'سجدناها': u'سَجَدْنَاهَا', #1
u'سجدوها': u'سَجَدُوهَا', #12
u'سجدوهما': u'سَجَدُوهُمَا', #1
u'سجز': u'سَجَزٍ', #1
u'سجستان': u'سجستان', #1
u'سجستان،': u'سجِسْتان،', #1
u'سجستان': u'سَجِسْتان', #1
u'سجستان،': u'سَجَسْتَان،', #1
u'سجستان،': u'سِجِسْتَانَ،', #11
u'سجستان،': u'سجستان،', #2
u'سجستان': u'سِجِسْتَانَ', #21
u'سجسج': u'سَجْسَجُ', #1
u'سجسج،': u'سَجْسَجٌ،', #1
u'سجسج': u'سَجْسَجٌ', #3
u'سجسج': u'سَجْسَجَ', #3
u'سجسجا': u'سَجْسَجًا', #2
u'سجسح': u'سَجَسْحٌ', #1
u'سجلة': u'سَجْلَةُ', #1
u'سجلة': u'سَجْلَةَ', #3
u'سجلماسا': u'سِجِلْمَاسَا', #1
u'سجلماسة': u'سِجِلْمَاسَةَ', #2
u'سجمت': u'سَجَمَتْ', #2
u'سجوفه': u'سُجُوفَهُ', #1
u'سجوما': u'سُجُومًا', #1
u'سجيس': u'سَجِيسَ', #1
u'سحابات': u'سَحَابَاتٌ', #2
u'سحالته': u'سُحَالَتُهُ', #1
u'سحالتها': u'سِحَالَتُهَا', #1
u'سحام': u'سُحَامٌ', #1
u'سحام': u'سُحَامِ', #1
u'سحايب': u'سَحَايِبَ', #1
u'سحباة': u'سحباة', #1
u'سحبان': u'سَحْبَانُ', #13
u'سحبان': u'سَحْبَانَ', #6
u'سحبل': u'سَحْبَلُ', #2
u'سحتويه': u'سَحْتَوَيْهِ', #1
u'سحرتنى؟': u'سَحَرْتِنِى؟', #1
u'سحرى': u'سَحْرِى', #2
u'سحل': u'سَحَلَ', #2
u'سحل': u'سَحْلٍ', #2
u'سحل': u'سَحْلَ', #2
u'سحل': u'سَحْلُ', #2
u'سحل': u'سُحُلٍ', #3
u'سحلت': u'سَحَلَتْ', #2
u'سحلت': u'سَحَلْت', #2
u'سحله': u'سَحَلَهُ', #2
u'سحلها': u'سَحْلَهَا', #1
u'سحلها': u'سَحْلِهَا', #6
u'سحلية': u'سِحْلِيَّةً', #1
u'سحلية': u'سِحْلِيَّةٌ', #1
u'سحلية': u'سِحْلِيَّةٍ', #2
u'سحنون': u'سُحْنُونٌ', #1
u'سحنون': u'سَحْنُونَ', #1122
u'سحنون': u'سَحْنُونٍ', #1587
u'سحنون': u'سَحْنُونُ', #19
u'سحنون': u'سَحْنُون', #2
u'سحنون': u'سَحْنُونٌ', #2442
u'سحنون': u'سَحْنَونٌ', #25
u'سحنون': u'سَحْنَونَ', #4
u'سحنونا': u'سَحْنُونًا', #44
u'سحنونلأنه': u'سَحْنَونٌلِأَنَّهُ', #1
u'سحورين': u'سَحُورَيْنِ', #2
u'سحول': u'سَحُولَ', #1
u'سحول': u'سُحُول', #1
u'سحول': u'سُحُولَ', #1
u'سحول': u'سحول', #2
u'سحول': u'سَحُولٍ', #3
u'سحول': u'سُحُولٌ', #3
u'سحول': u'سُحُولٍ', #4
u'سحولا': u'سُحُولًا', #1
u'سحولة': u'سَحُولَةَ', #1
u'سحوليا': u'سُحُولِيًّا', #1
u'سحوليا،': u'سَحُولِيًا،', #1
u'سحولية': u'سَحُولِيَّة', #1
u'سحولية': u'سُحُولِيّةٍ', #1
u'سحولية،': u'سَحُولِيَّةٍ،', #1
u'سحولية': u'سَحُولِيَّةٌ', #2
u'سحولية': u'سُحُولِيَّةٍ', #25
u'سحولية': u'سَحُولِيَّةٍ', #28
u'سحولية': u'سُحُولِيَّة', #3
u'سحيم،': u'سحيم،', #1
u'سحيم،': u'سُحَيم،', #1
u'سحيم': u'سُحَيْمُ', #1
u'سحيم': u'سحيم', #2
u'سحيم': u'سُحَيْمِ', #2
u'سحيم،': u'سُحَيْمٍ،', #23
u'سحيم': u'سُحَيْم', #4
u'سحيم،': u'سُحَيْمٌ،', #4
u'سحيم': u'سُحَيْمٌ', #5
u'سحيم': u'سُحَيْمٍ', #66
u'سحيما': u'سحيمًا', #1
u'سحيما': u'سُحَيْمًا', #5
u'سحيمة': u'سُحَيْمَةُ', #2
u'سحيمي': u'سُحَيْمِيٌّ', #1
u'سخاب،': u'سَخَّابٍ،', #1
u'سخاب': u'سَخَّابٍ', #5
u'سخابا': u'سَخَّابًا', #3
u'سخابا': u'سِخَابًا', #5
u'سخابها': u'سِخَابَهَا', #2
u'سخاطته': u'سَخَاطَتُهُ', #1
u'سخال': u'سخال', #1
u'سخال': u'سِخَالِ', #1
u'سخال': u'سِخَالٌ', #4
u'سخال': u'سِخَالٍ', #5
u'سخالا': u'سِخَالًا', #5
u'سخالها': u'سِخَالَهَا', #1
u'سخالها': u'سِخَالِهَا', #10
u'سخائف': u'سخائف', #1
u'سخائف': u'سَخَائِفَ', #1
u'سخب': u'سَخَبٌ', #1
u'سخب': u'سَخَبَ', #1
u'سخب': u'سُخُبُ', #1
u'سخب': u'سُخُبٌ', #2
u'سخبرة،': u'سخبرة،', #2
u'سخبرة': u'سَخْبَرَةَ', #33
u'سخبرة': u'سخبرة', #4
u'سخبرة،': u'سَخْبَرَةَ،', #4
u'سختويه': u'سَخَتُوَيْهِ', #1
u'سختويه': u'سَخْتُوَيْهُ', #1
u'سختويه': u'سَخْتَوَيْهِ', #15
u'سختويه': u'سَختوَيْهِ', #2
u'سختويه': u'سَخْتُوَيْهِ', #66
u'سختيانية': u'سُخْتِيَانِيَّةً', #1
u'سخفاء': u'سُخَفَاءِ', #2
u'سخل': u'سَخْلٌ', #2
u'سخل': u'سَخْلٍ', #3
u'سخل': u'سَخْلَ', #4
u'سخلات': u'سَخْلَاتٍ', #2
u'سخلة،': u'سَخْلَةٍ،', #1
u'سخلة': u'سَخْلَة', #2
u'سخلة': u'سَخْلَةَ', #2
u'سخلة': u'سَخْلَةُ', #2
u'سخلة': u'سَخْلَةِ', #2
u'سخلة': u'سَخْلَةٍ', #28
u'سخلة': u'سَخْلَةٌ', #38
u'سخلة': u'سَخْلَةً', #50
u'سخلتاه': u'سَخْلَتَاهُ', #1
u'سخلته': u'سَخْلَتَهُ', #1
u'سخلتها': u'سَخْلَتَهَا', #1
u'سخلتها': u'سَخْلَتِهَا', #1
u'سخلتها': u'سَخْلَتُهَا', #2
u'سخلتين': u'سَخْلَتَيْنِ', #4
u'سخلها': u'سَخْلَهَا', #2
u'سخم': u'سَخِمَ', #1
u'سخم': u'سَخَّمَ', #4
u'سخنى': u'سخنى', #1
u'سخيل': u'سُخَيْلٌ', #1
u'سخيل': u'سُخَيْلَ', #3
u'سخيل': u'سُخَيْلُ', #5
u'سخيلة،': u'سُخَيْلَةَ،', #1
u'سخيلة': u'سُخَيْلَةَ', #2
u'سخيلة': u'سَخِيلَةُ', #3
u'سخيلة': u'سُخَيْلَةُ', #7
u'سخيمة': u'سَخِيمَة', #1
u'سخيمة': u'سَخِيمَةِ', #1
u'سخيمة': u'سَخِيمَةَ', #2
u'سخيمته': u'سَخِيمَتَهُ', #6
u'سداء': u'سُدَاءَ', #1
u'سداسا': u'سُدَاسًا', #1
u'سدام': u'سِدَامٌ', #2
u'سداؤها': u'سَدَاؤُهَا', #1
u'سدسة': u'سُدْسَةٍ', #1
u'سدف': u'سَدَفٍ', #1
u'سدف': u'سُدَفُ', #1
u'سدفة': u'سُدْفَةً', #1
u'سدفك': u'سُدْفِك', #1
u'سدكت': u'سَدِكَتْ', #1
u'سدوس': u'سَدُوس', #1
u'سدوس': u'سَدُوسٌ', #1
u'سدوس': u'سَدُوسَ', #1
u'سدوس': u'سَدُوسُ', #1
u'سدوس': u'سَدُوسٍ', #10
u'سدوس': u'سدوس', #2
u'سدوس': u'سُدُوسٍ', #2
u'سدوس،': u'سَدُوسٍ،', #2
u'سدوسي': u'سَدُوسِيّ', #1
u'سدوم': u'سدوم', #1
u'سدوم': u'سَدُومٌ', #1
u'سدوم': u'سَدُومٍ', #1
u'سدوم': u'سَدُومُ', #2
u'سدوم': u'سَدُومَ', #4
u'سديسة': u'سُدَيْسَةُ', #2
u'سرابات': u'سَرَابَاتٌ', #2
u'سراباتي': u'سَرَابَاتِيٍّ', #1
u'سرابادين': u'سَرَابَادِينَ', #1
u'سراتهمو': u'سُرَاتُهُمُو', #1
u'سراحة': u'سُرَاحَةَ', #1
u'سراحين': u'سَرَاحِينَ', #1
u'سراحين': u'سَرَاحِينُ', #3
u'سرأها': u'سُرُأَهَا', #1
u'سراوع': u'سُرَاوِعَ', #2
u'سراويلا': u'سَرَاوِيلًا', #1
u'سرائيل': u'ِسْرَائِيلُ', #1
u'سرايجه': u'سرايجه', #1
u'سرباري': u'سرباري', #1
u'سربالا': u'سِرْبَالاً', #1
u'سربالا': u'سِرْبالًا', #1
u'سربالا': u'سِرْبَالًا', #1
u'سرباوكان': u'سَرَبًاوَكَانَ', #1
u'سربلنيه': u'سَرْبَلَنِيه', #1
u'سربلنيه': u'سَرْبَلَنيِهُ', #1
u'سرتسر': u'سرتسر', #1
u'سرتو': u'سرتو', #1
u'سرجس،': u'سَرْجِسٍ،', #1
u'سرجس': u'سرجس', #2
u'سرجس': u'سَرْجِس', #3
u'سرجس': u'سَرْجِسُ', #3
u'سرجس،': u'سَرْجِسَ،', #4
u'سرجس': u'سَرْجِسَ', #68
u'سرجس': u'سَرْجِسٍ', #7
u'سرجون': u'سَرْجُونٌ', #1
u'سرجينا': u'سِرْجِينًا', #4
u'سرحات': u'سَرَحَاتٍ', #1
u'سرحات': u'سَرَحَاتِ', #1
u'سرخ': u'سرخ', #2
u'سرخكت': u'سُرْخَكَتَ', #1
u'سرخه': u'سرخه', #2
u'سرخويش': u'سرخويش', #1
u'سردابة': u'سِرْدَابَةَ', #2
u'سردانية،': u'سَرْدَانِيَةَ،', #1
u'سردانية،': u'سِرْدَانِيَّةَ،', #1
u'سردد': u'سُرْدَدٍ', #2
u'سردوسل،': u'سَرْدَوْسَلَ،', #1
u'سررتنى': u'سَرَرْتَنِى', #1
u'سرساما': u'سِرْسَامًا', #1
u'سرشيتن': u'سرشيتن', #1
u'سرطاقة': u'سِرْطَاقَةَ', #1
u'سرغ،': u'سرغ،', #1
u'سرغ،': u'سَرغ،', #1
u'سرغ': u'سَرَغَ', #1
u'سرغ': u'سَرْغٌ', #1
u'سرغ،': u'سَرْغ،', #1
u'سرغ': u'سَرْغَ', #14
u'سرغ': u'سرغ', #4
u'سرف': u'سَرَف', #1
u'سرف': u'سَرِفٌ', #1
u'سرف': u'سَرْفٍ', #1
u'سرف': u'سُرْفٌ', #1
u'سرف': u'ِسَرِف', #1
u'سرف،': u'سَرَفٌ،', #1
u'سرف،': u'سَرَفٍ،', #1
u'سرف؟': u'سَرَفٌ؟', #1
u'سرف': u'سَرَفٍ', #101
u'سرف': u'سَرِف', #2
u'سرف': u'سَرِفَ', #21
u'سرف': u'سَرَفَ', #26
u'سرف': u'سَرَفِ', #3
u'سرف': u'سَرِفُ', #3
u'سرف': u'سَرِفٍ', #6
u'سرف': u'سَرَفٌ', #69
u'سرفا،': u'سَرَفًا،', #1
u'سرفا': u'سَرِفًا', #2
u'سرفا': u'سَرَفًا', #67
u'سرفة': u'سُرْفَةِ', #2
u'سرقنة': u'سَرْقَنَةٍ', #1
u'سرقين': u'سِرْقِينَ', #1
u'سرقين': u'سِرْقِينٌ', #11
u'سرقين': u'سِرْقِينٍ', #2
u'سرقين': u'سِرْقِينِ', #5
u'سرقينا': u'سِرْقِينًا', #3
u'سرقينه': u'سِرْقِينُهُ', #1
u'سرقينه': u'سِرْقِينِهِ', #7
u'سرقينها؟': u'سِرْقِينَهَا؟', #1
u'سركارا': u'سركارا', #1
u'سركارهم': u'سركارهم', #1
u'سرماد': u'سرماد', #1
u'سرمدتها': u'سَرْمَدَتِهَا', #1
u'سرموجة': u'سُرْمُوجَةٍ', #3
u'سرموذة': u'سرموذة', #1
u'سرموزة': u'سرموزة', #1
u'سرموزة': u'سُرْمُوزَةً', #1
u'سرموزه': u'سَرْمُوزِه', #1
u'سرمين': u'سِرْمِينَ', #1
u'سرنديب': u'سَرَنْدِيبَ', #4
u'سرنماز': u'سرنماز', #1
u'سرنى': u'سَرَّنِى', #1
u'سرهرشش': u'سرهرشش', #1
u'سروالة': u'سِرْوَالَةٌ', #1
u'سروالة': u'سِرْوَالَةَ', #1
u'سروالة': u'سِرْوَالَةٍ', #2
u'سروان': u'سَرْوَانَ', #1
u'سروان،': u'سَرْوَانَ،', #1
u'سروعة': u'سًرْوَعَةَ', #1
u'سروعة': u'سَرْوَعَةَ', #1
u'سروعة': u'سِرْوَعَةَ', #8
u'سروق': u'سَرُوقُ', #1
u'سروى': u'سُرْوَى', #1
u'سرويل': u'سِرْوِيلٍ', #1
u'سريتى': u'سُرِّيَّتِى', #1
u'سريج': u'سُرَيجٌ', #1
u'سريج': u'سُرَيجٍ', #1
u'سريج': u'سُرَيجُ', #1
u'سريج': u'سُرَيْجَ', #1
u'سريج،': u'سريج،', #14
u'سريج': u'سُرَيْجٌ', #188
u'سريج': u'سُرَيْجُ', #260
u'سريج،': u'سُرَيْجٌ،', #27
u'سريج': u'سُرَيْجِ', #28
u'سريج': u'سُرَيْج', #3
u'سريج': u'سريج', #4
u'سريج،': u'سُرَيْجٍ،', #42
u'سريج': u'سُرَيْجٍ', #659
u'سريجة': u'سُرَيْجَةَ', #1
u'سريح': u'سَرِيحٍ', #1
u'سريح': u'سُرَيحُ', #1
u'سريح': u'سُرَيْحٍ', #1
u'سريحة': u'سريحة', #1
u'سريحة': u'سَرِيحَة', #1
u'سريحة،': u'سُرَيْحَةَ،', #1
u'سريحة،': u'سَرِيحَةَ،', #2
u'سريحة': u'سَرِيحَةَ', #22
u'سريرتى': u'سَرِيرَتِى', #1
u'سريس': u'سَرِيسٍ', #2
u'سريط': u'سُرّيْطٌ', #1
u'سريقا': u'سريقاً', #1
u'سزاوار': u'سزاوار', #1
u'سزاي': u'سزاي', #3
u'سطبر': u'سطبر', #1
u'سطيح،': u'سَطِيحٌ،', #1
u'سطيح': u'سُطَيْحٌ', #1
u'سطيح': u'سَطِيحٍ', #18
u'سطيح،': u'سَطِيحٍ،', #2
u'سطيح': u'سُطَيْحٍ', #2
u'سطيح': u'سَطِيحٌ', #26
u'سطيح': u'سَطِيحُ', #4
u'سطيحا': u'سَطِيحًا', #2
u'سعادا': u'سُعَادَا', #1
u'سعاده': u'سُعَاده', #1
u'سعاف': u'سَعَافٍ', #1
u'سعانين': u'سَعَانِينَ', #1
u'سعانينا': u'سَعَانِينًا', #1
u'سعايت': u'سعايت', #3
u'سعتربري': u'سَعْتَرْبِرِّي', #1
u'سعدانة': u'سَعْدَانَةَ', #1
u'سعدة': u'سعدة', #1
u'سعدة،': u'سَعْدَةَ،', #2
u'سعدة': u'سَعْدَةَ', #3
u'سعد،وأسامة': u'سَعْدٍ،وَأُسَامَةُ', #1
u'سعدويه': u'سَعْدَوَيْهِ', #2
u'سعدويه،': u'سَعْدَوَيْهِ،', #3
u'سعدويه': u'سَعْدُوَيْهِ', #8
u'سعط': u'سُعِطَ', #1
u'سعط': u'سَعَطَ', #2
u'سعفص': u'سعفص', #1
u'سعلاء': u'سِعْلَاءٍ', #1
u'سعلاة': u'سِعْلَاةٍ', #1
u'سعنة': u'سَعْنَةٌ', #1
u'سعنة،': u'سَعْنَة،', #1
u'سعنة،': u'سَعْنَةَ،', #1
u'سعنة': u'سُعْنَةُ', #2
u'سعنة': u'سُعُنَّةَ', #3
u'سعنة': u'سُعْنَةَ', #4
u'سعنة': u'سَعْنَةَ', #7
u'سعوة': u'سَعْوَةَ', #2
u'سعوط': u'سَعُوطِ', #1
u'سعوط': u'سَعُوطٍ', #11
u'سعوط': u'سَعُوطُ', #2
u'سعوطا': u'سَعُوطًا', #12
u'سعوطا': u'سُعُوطًا', #2
u'سعوطه': u'سُعُوطُهُ', #1
u'سعوطي': u'سَعُوطِي', #2
u'سعوم': u'سَعُومُ', #1
u'سعيدفي': u'سَعِيدٍفِي', #1
u'سعيدية': u'سَعِيدِيَّةٌ', #1
u'سعيى': u'سَعْيِى', #1
u'سغام': u'سَغَامِ', #1
u'سغيبا': u'سَغِيبَا', #1
u'سفاتج': u'سَفَاتِجَ', #2
u'سفاتج': u'سَفَاتِجُ', #2
u'سفاسفة': u'سَفَاسِفَةُ', #1
u'سفتة': u'سُفْتَةٌ', #1
u'سفتجة': u'سَفْتَجَةَ', #1
u'سفتجة': u'سَفْتَجَةٍ', #16
u'سفتجة': u'سَفْتَجَة', #2
u'سفتجة': u'سَفْتَجَةً', #26
u'سفرم': u'سفرم', #1
u'سفرى': u'سَفْرَى', #1
u'سفرى': u'سَفَرِى', #6
u'سفعاء': u'سَفْعَاءَ', #1
u'سفعاء': u'سَفْعَاء', #2
u'سفعاء': u'سَفْعَاءُ', #9
u'سفقة': u'سفقة', #1
u'سفقة': u'سَفْقَةٍ', #1
u'سفقة': u'سَفْقَةَ', #1
u'سفقتان': u'سفقتان', #1
u'سفقتان': u'سَفْقَتَانِ', #1
u'سفنة': u'سِفَنَّةٍ', #1
u'سفنة': u'سِفْنَةٍ', #1
u'سفواء': u'سَفْوَاءُ', #1
u'سفوان': u'سَفَوَانَ', #1
u'سفوان': u'سَفْوَانَ', #4
u'سفوان': u'سَفْوَانُ', #4
u'سفوف': u'سَفُوفٌ', #2
u'سفوف': u'سَفُوفٍ', #3
u'سفوفا': u'سَفُوفًا', #1
u'سفيانكان': u'سُفْيَانُكَانَ', #1
u'سفيانوإن': u'سُفْيَانُوَإِنْ', #1
u'سفيحة': u'سَفِيحَةٍ', #1
u'سفيده': u'سفيده', #1
u'سقاف': u'سِقَافَ', #1
u'سقاناه': u'سَقَانَاهُ', #1
u'سقانى': u'سَقَانِى', #1
u'سقاوية': u'سِقَاوِيَّةٍ', #1
u'سقائى': u'سِقَائِى', #1
u'سقب': u'سَقَبٌ', #1
u'سقب': u'سَقْبُ', #1
u'سقبت': u'سَقِبَتْ', #1
u'سقبه': u'سَقَبِهِ', #1
u'سقبه': u'سَقَبُهُ', #3
u'سقبها': u'سَقْبَهَا', #1
u'سقبها': u'سُقْبُهَا', #1
u'سقبها،': u'سَقَبَهَا،', #1
u'سقبها،': u'سُقْبَهَا،', #1
u'سقة': u'سِقَةً', #1
u'سقة': u'سِقَةٍ', #1
u'سقة': u'سِقَةَ', #1
u'سقة': u'سِقَةُ', #1
u'سقة،': u'سُقَةَ،', #1
u'سقتنى': u'سَقَتْنِى', #4
u'سقطانا': u'سُقْطَانًا', #1
u'سقع': u'سُقْعِ', #1
u'سقلاب،': u'سِقْلابٍ،', #5
u'سقلاب': u'سِقْلَابٍ', #6
u'سقم': u'سَقَمً', #1
u'سقماثاه': u'سقماثاه', #1
u'سقمونيا': u'سَقَمُونْيَا', #3
u'سقمى': u'سُقْمَى', #1
u'سقوب': u'سُقُوبَ', #3
u'سقوبا': u'سُقُوبًا', #1
u'سقيات': u'سَقِيَّات', #1
u'سقيات': u'سَقْيَاتٍ', #1
u'سقيات': u'سَقِيَّاتٍ', #2
u'سقيات': u'سَقَيَاتٍ', #6
u'سقية': u'سَقِيَّة', #1
u'سقية': u'سَقِيَّةِ', #1
u'سقية': u'سَقْيَةٌ', #1
u'سقية': u'سُقَيّةً', #1
u'سقية': u'سُقَيّةَ', #1
u'سقية': u'سُقَيّةُ', #1
u'سقية': u'سُقْيَةً', #1
u'سقية': u'سُقْيَةٍ', #1
u'سقية': u'سَقِيَّةٌ', #11
u'سقية': u'سَقْيَةٍ', #4
u'سقية': u'سَقِيَّةٍ', #7
u'سقية': u'سَقِيَّةً', #8
u'سقيتين': u'سَقِيَّتَيْنِ', #2
u'سقيتين': u'سَقْيَتَيْنِ', #7
u'سقير،': u'سُقَيْرٍ،', #2
u'سقير': u'سُقَيْرٍ', #6
u'سقيرا': u'سُقَيْرًا', #1
u'سكاء': u'سَكَّاءَ', #1
u'سكاجبة': u'سكاجبة', #1
u'سكباج': u'سِكْبَاجٍ', #3
u'سكباجا': u'سِكْبَاجًا', #1
u'سكباجة': u'سِكْبَاجَةٍ', #1
u'سكباجة': u'سِكْبَاجَةً', #2
u'سكتتى': u'سَكْتَتَىِ', #1
u'سكديكم': u'سكديكم', #1
u'سكرج': u'سَكْرَجَ', #1
u'سكرجة': u'سُكْرُجَةٍ', #1
u'سكرجة': u'سُكْرُجَةَ', #1
u'سكرجة': u'سُكُرُّجَةٍ', #5
u'سكنجبيل': u'سَكَنْجَبِيل', #1
u'سكنجبين': u'سَكَنْجَبِينٍ', #1
u'سكنجبين': u'سَكَنْجَبِينَ', #1
u'سكنجبين': u'سَكَنْجَبِينُ', #1
u'سكنجبينا': u'سَكَنْجَبِينًا', #2
u'سكنجيبا': u'سكنجيبا', #1
u'سكندري': u'سَكَنْدَرِيٌّ', #1
u'سكندرية': u'سَكَنْدَرِيَّةٍ', #1
u'سكندرية': u'سَكَنْدَرِيَّةٌ', #2
u'سكنى': u'سُكْنًى', #1
u'سكنين': u'سَكَنَيْنِ', #1
u'سكيتا': u'سُكَيْتًا', #1
u'سكيتها': u'سُكَيْتُهَا', #1
u'سلأ': u'سَلَأَ', #1
u'سلاءة': u'سُلَّاءَةً', #1
u'سلابة': u'سَلَّابَةٌ', #1
u'سلار': u'سَلَارٌ', #1
u'سلار': u'سلار', #2
u'سلار': u'سَلَارٍ', #2
u'سلار': u'سَلَّارَ', #2
u'سلار': u'سَلَّارٍ', #3
u'سلار': u'سَلَّارٌ', #8
u'سلاسلا': u'سَلَاسِلَا', #1
u'سلافة': u'سُلافَةُ', #1
u'سلافة': u'سُلَافَةِ', #1
u'سلافة': u'سُلَافَةَ', #11
u'سلافة': u'سُلَافَةُ', #5
u'سلاق': u'سَلّاقٌ', #2
u'سلالما': u'سَلَالِمًا', #1
u'سلاليم': u'سَلَالِيمَ', #1
u'سلائخ': u'سَلَائِخَ', #1
u'سلائخ': u'سَلَائِخُ', #1
u'سلبتنيه': u'سَلَبْتَنِيهِ', #1
u'سلبتهمو': u'سَلَبَتْهُمُو', #1
u'سلجج': u'سَلَجج', #1
u'سلجج': u'سَلْجَج', #1
u'سلجج': u'سَلْجَجْ', #3
u'سلجج': u'سَلْجَجِ', #4
u'سلجم': u'سَلْجَمٌ', #1
u'سلجم': u'سَلْجَمَ', #1
u'سلجم': u'سَلْجَمُ', #2
u'سلجم': u'سَلْجَمٍ', #3
u'سلجما': u'سَلْجَمًا', #1
u'سلجما': u'سَلْجَمَا', #1
u'سلجوق': u'سَلْجُوقٍ', #1
u'سلحتكها': u'سَلَّحْتُكَهَا', #1
u'سلحتكها؟': u'سَلَّحْتُكَهَا؟', #1
u'سلحفية': u'سُلَحْفِيَةٌ', #2
u'سلحون': u'سَلْحُونٌ', #1
u'سلطنى': u'سَلِّطْنِى', #1
u'سلعات': u'سَلَعَاتٍ', #2
u'سلله': u'سِلَلَهُ', #1
u'سلمات،': u'سَلِمَاتٍ،', #1
u'سلمةSوذكر': u'سلمةSوَذَكَرَ', #1
u'سلمةعن': u'سَلَمَةَعَنْ', #1
u'سلمنت': u'سَلْمُنْتُ', #1
u'سلمنى': u'سَلَّمَنِىَ', #1
u'سلمنيها': u'سَلَّمَنِيهَا', #1
u'سلمهماه': u'سَلَّمَهُمَاهُ', #1
u'سلمويه': u'سَلَمُوَيْهِ', #1
u'سلمويه': u'سَلْمُوَيْهِ', #1
u'سلنى': u'سَلْنِى', #1
u'سلهب': u'سَلْهَبِ', #1
u'سلهب': u'سَلْهَبٍ', #2
u'سلهبة': u'سَلْهَبَةٍ', #5
u'سلهبهSشعر': u'سَلْهَبَهْSشِعْرُ', #1
u'سلهبه': u'سَلْهَبَهْ', #1
u'سلوع': u'سُلُوعٌ', #1
u'سلوق': u'سَلُوقَ', #1
u'سلول،': u'سلول،', #1
u'سلول،': u'سَلُولَ،', #1
u'سلول،': u'سَلُولِ،', #1
u'سلول': u'سَلُولَ', #159
u'سلول': u'سَلُولٍ', #16
u'سلول': u'سَلُول', #2
u'سلول': u'سلول', #6
u'سلول': u'سَلُولُ', #6
u'سلول،': u'سَلُولٍ،', #9
u'سلولية': u'سَلُولِيَّةَ', #1
u'سلولية،': u'سَلُولِيَّةٍ،', #1
u'سلولية،': u'سَلُولِيَّةُ،', #1
u'سلولية': u'سَلُولِيّةٍ', #4
u'سلومات': u'سَلُومَاتِ', #1
u'سلومات': u'سُلُومَاتِ', #2
u'سلونى': u'سَلُونِى', #9
u'سلئه': u'سَلْئِهِ', #1
u'سليح': u'سَلِيحِ', #1
u'سليع': u'سُلَيْعٍ', #1
u'سليك': u'سُلَيْك', #1
u'سليك،': u'سُلَيْك،', #1
u'سليك': u'سليك', #2
u'سليك،': u'سُلَيْكٍ،', #2
u'سليك': u'سُلَيْكٍ', #20
u'سليك': u'سُلَيْكٌ', #31
u'سليك': u'سُلَيْكِ', #4
u'سليك': u'سُلَيْكُ', #8
u'سليكا': u'سُلَيْكًا', #19
u'سليمى': u'سُلَيْمَى', #8
u'سليمية': u'سُلَيْمِيَّةٍ', #1
u'سلينى': u'سَلِينِى', #2
u'سماحق': u'سَمَاحِقِ', #2
u'سماحيق': u'سَمَاحِيقَ', #1
u'سماحيق': u'سَمَاحِيقُ', #3
u'سماحيق': u'سَمَاحِيقِ', #3
u'سماخها': u'سِمَاخُهَا', #1
u'سمادير': u'سَمَادِيرَ', #2
u'سمارى': u'سَمَارَى', #1
u'سماطين': u'سماطين', #1
u'سماطين،': u'سِمَاطَيْنِ،', #1
u'سماطين': u'سِمَاطَيْنِ', #4
u'سمال': u'سَمّالِ', #3
u'سمامته': u'سَمَامَتُهُ', #1
u'سماوة': u'سَمَاوَةَ', #2
u'سمائين': u'سَمَائَيْنِ', #2
u'سمتنى': u'سَمَّتْنِى', #2
u'سمحاق': u'سِمْحَاقُ', #1
u'سمحاق': u'سِمْحَاقٌ', #2
u'سمحاق': u'سِمْحَاقٍ', #2
u'سمحاقا': u'سِمْحَاقًا', #9
u'سمرةأنه': u'سَمُرَةَأَنَّهُ', #1
u'سمسمة': u'سِمْسِمَةً', #18
u'سمسمة': u'سِمْسِمَةٍ', #25
u'سمسمتين': u'سِمْسِمَتَيْنِ', #3
u'سمعتسعيد': u'سَمِعْتُسَعِيدَ', #1
u'سمععروة،': u'سَمِعَعُرْوَةَ،', #1
u'سمعنى': u'سَمِعَنِى', #1
u'سمعون،': u'سَمْعُونٍ،', #1
u'سمعون': u'سَمْعُونٍ', #5
u'سمعى': u'سَمْعِى', #12
u'سمقاثا': u'سمقاثا', #1
u'سممتنى': u'سَمَمْتِنِى', #1
u'سمنود': u'سَمَنُّودَ', #3
u'سمنى': u'سمنى', #1
u'سمهر': u'سَمْهَرٍ', #1
u'سموءل': u'سَمَوْءلٍ', #1
u'سموال': u'سِمْوَالٍ', #1
u'سمى': u'سَمًى', #1
u'سميدع': u'سَمَيْدَع', #1
u'سميدع': u'سَمَيْدَعِ', #1
u'سميدع': u'سَمَيْدَعٍ', #2
u'سميذ': u'سَمِيذَ', #1
u'سميذا': u'سَمِيذًا', #1
u'سميفع': u'سَمَيْفَع', #1
u'سنات': u'سِنَاتٍ', #1
u'سناته': u'سِنَاتِهِ', #2
u'سنأتى': u'سَنَأْتِى', #1
u'سناجية': u'سَنَّاجِيَةَ', #1
u'سناط': u'سُنَاطَ', #1
u'سنامان': u'سَنَامَانِ', #13
u'سنامين': u'سِنَامَيْنِ', #2
u'سنامين': u'سَنَامَيْنِ', #26
u'سناوة': u'سِنَاوَةً', #1
u'سنباذ': u'سِنْبَاذَ', #1
u'سنبلاني،': u'سُنْبُلانيّ،', #1
u'سنبلانية': u'سُنْبُلَانِيّة', #1
u'سنبوسقا': u'سَنْبُوسَقًا', #1
u'سنبوسكة': u'سَنْبُوسَكَةٍ', #1
u'سنتى': u'سُنَّتِى', #6
u'سنجرة': u'سُنْجِرَةَ', #1
u'سندادS': u'سِنْدَادِS', #1
u'سندارا': u'سِنْدَارًا', #1
u'سندرا': u'سَنْدَرًا', #3
u'سندروس': u'سندروس', #2
u'سنكستان': u'سنكستان', #1
u'سنورة': u'سِنَّوْرَةٍ', #1
u'سنورة': u'سِنَّوْرَةٌ', #3
u'سنوطا': u'سَنُوطَا', #8
u'سنى': u'سنى', #1
u'سنى': u'سِنَى', #1
u'سنى': u'سَنَى', #2
u'سنى': u'سِنِى', #3
u'سنى': u'سِنِّى', #8
u'سنيد': u'سَنِيدٍ', #1
u'سنيد': u'سُنَيْدٍ', #1
u'سنيد': u'سُنَيْدِ', #1
u'سنيد': u'سَنِيدِ', #2
u'سنيد': u'سُنَيْدٌ', #2
u'سنيد،': u'سُنَيْدٌ،', #2
u'سنيد': u'سُنَيْدُ', #6
u'سنير': u'سَنِيرٍ', #1
u'سنينا': u'سَنِينًا', #2
u'سنينا': u'سُنَيْنًا', #4
u'سنينا': u'سِنِينًا', #8
u'سنينة': u'سُنَيْنَة', #1
u'سنينة': u'سُنَيْنَةَ', #9
u'سنينن': u'سنينن', #1
u'سنينه': u'سَنِينُهُ', #1
u'سهافي': u'سَهَافِي', #1
u'سهدلي': u'سِهْدِلِيّ', #1
u'سهرام': u'سِهْرَامُ', #1
u'سهك': u'سَهِكٌ', #1
u'سهكوه': u'سَهَكُوهُ', #1
u'سهماء': u'سَهْمَاءُ', #1
u'سهمانا': u'سُهْمَانًا', #6
u'سهماننا،': u'سُهْمَانُنَا،', #1
u'سهماننا': u'سُهْمَانُنَا', #15
u'سهمانه': u'سُهْمَانَهُ', #1
u'سهمانه': u'سُهْمَانُهُ', #1
u'سهمانه': u'سُهْمَانِهِ', #5
u'سهمانهم،': u'سَهْمَانِهِمْ،', #1
u'سهمانهم': u'سُهْمَانُهُمْ', #17
u'سهمانهم': u'سُهْمَانَهُمْ', #6
u'سهمانهم': u'سُهْمَانِهِمْ', #6
u'سهمانهم': u'سُهْمَانُهُمُ', #7
u'سهمى': u'سَهْمِىَ', #1
u'سهمى': u'سَهْمِى', #12
u'سهوكة': u'سَهُوكَةٍ', #1
u'سهوكة': u'سَهُوكَةِ', #1
u'سهوكة': u'سَهْوَكَةٍ', #2
u'سهوكته': u'سَهُوكَتَهُ', #1
u'سهيلة': u'سُهَيْلَةُ', #2
u'سهيمة': u'سُهَيْمَةُ', #3
u'سهيمة': u'سُهَيْمَةَ', #6
u'سهينمة': u'سُهَيْنَمَةَ', #1
u'سوء': u'سَوْءً', #2
u'سوء': u'سُوءً', #3
u'سوءالعذاب': u'سوءالعذاب', #1
u'سوءى': u'سُوءَى', #1
u'سوأ': u'سُوأً', #1
u'سواءة': u'سَوَاءَةَ', #1
u'سواءة': u'سُوَاءَةَ', #6
u'سوابغ': u'سَوَابِغ', #1
u'سوابغ': u'سَوَابِغَ', #4
u'سوابغ': u'سَوَابِغِ', #6
u'سوابغ': u'سَوَابِغُ', #8
u'سوابغا': u'سَوَابِغًا', #2
u'سوابغها': u'سَوَابِغُهَا', #1
u'سوابيط': u'سَوَابِيطَ', #1
u'سوابيط': u'سَوَابِيطُ', #1
u'سواة': u'سواة', #5
u'سؤآتهما': u'سَؤآتِهِمَا', #1
u'سواجم': u'سَوَاجِمُ', #1
u'سواحها': u'سَواحِهَا', #1
u'سوادان': u'سَوَادَانِ', #1
u'سوادة،': u'سَوَادة،', #1
u'سوادة': u'سِوَادَةٍ', #1
u'سوادة': u'سِوَادَةُ', #1
u'سوادة': u'سَوَادَةُ', #11
u'سوادة': u'سُوَادَةَ', #2
u'سوادة': u'سِوَادَةَ', #2
u'سوادة': u'سِوَادَةِ', #3
u'سوادة،': u'سَوَادَةَ،', #36
u'سوادة،': u'سوادة،', #5
u'سوادة': u'سوادة', #6
u'سوادة': u'سَوَادَةَ', #93
u'سوادى': u'سِوَادِى', #1
u'سوادى': u'سَوَادِى', #2
u'سواديا': u'سَوَادِيًّا', #1
u'سوادين': u'سَوَادَيْنِ', #11
u'سوادين': u'سِوَادَيْنِ', #2
u'سوارخ': u'سوارخ', #1
u'سوارى': u'سِوَارَىْ', #4
u'سوارى': u'سَوَارِى', #9
u'سواع': u'سُوَاعً', #1
u'سواعا': u'سُوَاعًا', #7
u'سوافيها': u'سَوَافِيهَا', #2
u'سوال': u'سُوَالٍ', #1
u'سوال': u'سُوَالُ', #1
u'سؤالة': u'سُؤَالَةَ', #1
u'سوآن': u'سَوَآنِ', #1
u'سوائما': u'سَوَائِمَا', #1
u'سوايب': u'سَوَايِبَ', #1
u'سوايه': u'سِوَايَهْ', #1
u'سوبان': u'سُوبَانَ', #2
u'سؤتنى': u'سُؤْتَنِى', #1
u'سوخت': u'سوخت', #2
u'سوخته': u'سوخته', #2
u'سودانا': u'سُودَانًا', #5
u'سوداوتان': u'سَوْدَاوَتَانِ', #1
u'سودة،': u'سَودة،', #1
u'سودة،': u'سَوْدة،', #1
u'سودة': u'سَوْدَةٌ', #1
u'سودة': u'سَوْدَةٍ', #1
u'سودة؟': u'سَوْدَةُ؟', #1
u'سودة': u'سَوْدَةُ', #161
u'سودة': u'سَوْدَة', #18
u'سودة': u'سَوْدَةَ', #189
u'سودة': u'سَوْدة', #3
u'سودة': u'سودة', #4
u'سودة،': u'سَوْدَةُ،', #5
u'سودة،': u'سَوْدَةَ،', #7
u'سودد': u'سُوْدُدِ', #1
u'سوددا': u'سُودَدًا', #1
u'سوددا': u'سُوْدُدًا', #1
u'سوددادن': u'سوددادن', #1
u'سودرين': u'سودرين', #2
u'سودزيانه': u'سودزيانه', #2
u'سوذان': u'سوذان', #1
u'سوذانقا': u'سَوْذَانِقًا', #1
u'سورتى': u'سورتى', #1
u'سورتى': u'سُورَتِى', #1
u'سورستان': u'سُورَسْتَانَ', #1
u'سوسات': u'سُوسَاتٍ', #1
u'سوطل': u'سَوْطَلٍ', #1
u'سوطى': u'سَوْطِى', #3
u'سوغكها': u'سَوّغَكَهَا', #1
u'سوغنيه': u'سَوَّغَنِيهِ', #8
u'سوفا': u'سُوَّفًا', #1
u'سوقاء': u'سَوْقَاءَ', #2
u'سوقة': u'سُوقَةٍ', #1
u'سوقة': u'سُوقَةِ', #1
u'سوقة': u'سَوْقَةً', #1
u'سوقة': u'سَوْقَةَ', #1
u'سوقة،': u'سُوقَةَ،', #14
u'سوقة': u'سُوقَةَ', #20
u'سوقة': u'سُوقَةً', #3
u'سوقة': u'سُوقَةٌ', #4
u'سوقى': u'سُوقَى', #1
u'سؤك': u'سُؤُكٌ', #2
u'سوكرة': u'سَوْكَرَةً', #2
u'سوكند': u'سوكند', #34
u'سوكندا': u'سوكندا', #1
u'سوكندخور': u'سوكندخور', #1
u'سوكندراست': u'سوكندراست', #1
u'سوكندمي': u'سُوكِنْدِمِي', #1
u'سوكندمي': u'سوكندمي', #2
u'سؤلتي': u'سُؤْلَتِي', #1
u'سومنات': u'سُومَنَاتٍ', #1
u'سونيفتي': u'سونيفتي', #1
u'سوهان': u'سوهان', #1
u'سويبط': u'سُوَيْبِطِ', #1
u'سويبط': u'سُوَيْبِطُ', #3
u'سويبط': u'سُوَيْبِطٌ', #5
u'سويبق': u'سُويْبِق', #1
u'سويبق': u'سُوَيْبِقُ', #1
u'سويدا': u'سُوَيْدًا', #15
u'سويداه': u'سُوَيْدَاهُ', #1
u'سويدة': u'سُوَيْدَةَ', #1
u'سويق،': u'سَوِيقٍ،', #1
u'سويق': u'سَوَيْقٍ', #1
u'سويق': u'سُوَيْقٍ', #1
u'سويق': u'سُوَيْقُ', #1
u'سويق': u'سَوِيقٌ', #15
u'سويق': u'سَوِيقٍ', #47
u'سويق': u'سَوِيقَ', #6
u'سويق': u'سَوِيقُ', #6
u'سويق': u'سَوِيقِ', #8
u'سويقا': u'سَوِيقًا', #149
u'سويقك': u'سَوِيقَك', #2
u'سويقه': u'سَوِيقُهُ', #3
u'سويقه': u'سَوِيقِهِ', #39
u'سويقه': u'سَوِيقَهُ', #7
u'سويقها': u'سَوِيقَهَا', #1
u'سويقها': u'سَوِيقِهَا', #11
u'سويقهما': u'سُوَيْقُهُمَا', #1
u'سويقهما': u'سَوِيقُهُمَا', #2
u'سويلم': u'سُوَيْلَمٍ', #1
u'سويلم': u'سُوَيْلِمٍ', #9
u'سئلعن': u'سُئِلَعَنْ', #1
u'سئول،': u'سَئُولٌ،', #1
u'سئول': u'سَئُولٍ', #4
u'سئولا': u'سَئُولًا', #2
u'سئوم': u'سَئُومٌ', #1
u'سئوم': u'سَئُومُ', #2
u'سيابان،': u'سَيَابَانَ،', #1
u'سيابة': u'سَيَّابَة', #1
u'سيابة': u'سِيَابَةٍ', #1
u'سيابة': u'سِيَابَةُ', #2
u'سيابة': u'سيابة', #3
u'سيابة': u'سِيَابَةَ', #3
u'سيآتهم': u'سَيَّآتِهِمْ', #1
u'سيأتى': u'سَيَأْتِى', #2
u'سياتي': u'سِيَاتِي', #7
u'سيأتيان': u'سَيَأْتِيَانِ', #7
u'سياس': u'سياس', #1
u'سيانا': u'سِيَّانًا', #1
u'سياها': u'سِيَاهًا', #1
u'سياهة': u'سياهة', #1
u'سياهه': u'سياهه', #2
u'سياهها': u'سِيَاهَهَا', #1
u'سيائد': u'سَيَائِدَ', #2
u'سيبا': u'سَيْبًا', #14
u'سية': u'سِيَةً', #1
u'سية': u'سِيَةَ', #1
u'سية': u'سِيَةُ', #1
u'سية': u'سِيَةِ', #2
u'سيتان': u'سيتان', #1
u'سيتها،': u'سِيَتُهَا،', #1
u'سيتها،': u'سِيَتِهَا،', #1
u'سيتها': u'سِيَتَهَا', #2
u'سيتها': u'سِيَتُهَا', #2
u'سيجىء': u'سَيَجِىءُ', #1
u'سيحدثنى': u'سَيُحَدِّثُنِى', #1
u'سيدى': u'سَيِّدِى', #8
u'سيدية': u'سَيِّدِيَّةٌ', #1
u'سيدية': u'سَيِّدِيَّةِ', #2
u'سيدية': u'سَيِّدِيَّةَ', #6
u'سيدية': u'سَيِّدِيَّةٌ', #8
u'سيراء': u'سِيَرَاءُ', #11
u'سيراء': u'سيراء', #2
u'سيراء،': u'سِيَرَاءُ،', #2
u'سيراء': u'سِيرَاءَ', #3
u'سيراء': u'سِيَرَاءَ', #36
u'سيراء': u'سِيَرَاء', #4
u'سيراء،': u'سِيَرَاءَ،', #6
u'سيرتنى': u'سَيَّرْتَنِى', #1
u'سيرينإذ': u'سِيرِينَإِذْ', #1
u'سيستقرضه': u'سَيَسْتَقْرِضُهُ', #1
u'سيستنجحها': u'سَيَسْتَنْجِحُهَا', #1
u'سيطبررا': u'سيطبررا', #1
u'سيطؤه': u'سَيَطَؤُهُ', #1
u'سيطؤها': u'سَيَطَؤُهَا', #1
u'سيفقدونى': u'سَيَفْقِدُونِى', #1
u'سيفى': u'سَيْفِى', #13
u'سيقتلوننى': u'سَيَقْتُلُونَنِى', #1
u'سيقه': u'سَيّقِهِ', #1
u'سيكرانا': u'سَيْكَرَانًا', #1
u'سيكي': u'سَيَكِي', #1
u'سيكي': u'سيكي', #2
u'سيكى': u'سيكى', #2
u'سيلة': u'سِيلَة', #1
u'سيلى': u'سَيَلِى', #1
u'سيما': u'سِيَمًا', #1
u'سيمى': u'سِيمَى', #1
u'سيمين': u'سِيمِينْ', #2
u'سيهوب': u'سَيْهُوبٍ', #2
u'سيو': u'سِيْوَ', #1
u'سيؤاخذ': u'سَيُؤَاخَذُ', #1
u'سيواس': u'سِيوَاسَ', #1
u'سيور': u'سَيُورٌ', #1
u'سيور': u'سُيُورَ', #1
u'سيور': u'سيور', #2
u'سيور': u'سُيُور', #6
u'سيور': u'سُيُورٌ', #6
u'سيور': u'سُيُورٍ', #8
u'سيور': u'سُيُورِ', #9
u'سيورا': u'سُيُورًا', #3
u'سيوم': u'سُيُومٌ', #5
u'سيويا': u'سِيوِيًّا', #1
u'سيىء': u'سَيِّىءَ', #1
u'سيىء': u'سَيِّىءُ', #1
u'سيئول': u'سَيَئُولُ', #2
u'شا': u'شَا', #10
u'شاء': u'شَاءً', #1
u'شاآ': u'شَاآ', #1
u'شاباش': u'شاباش', #1
u'شأبور': u'شَأبُورَ', #2
u'شابور،': u'شابور،', #2
u'شأبور،': u'شَأْبُورَ،', #3
u'شابور': u'شَابُورَ', #30
u'شأبور،': u'شَأبُورَ،', #5
u'شابور': u'شَابُورٍ', #5
u'شابور،': u'شَابُورٍ،', #5
u'شابور،': u'شَابُورَ،', #53
u'شاتون': u'شَاتُونَ', #3
u'شاتى': u'شَاتِى', #3
u'شاتى': u'شَاتَىْ', #8
u'شاث': u'شاث', #1
u'شاخاتها': u'شَاخَاتُهَا', #1
u'شادل': u'شَادِلٍ', #1
u'شادل': u'شْادِلِ', #1
u'شادل': u'شَادِلِ', #2
u'شادوران': u'شادوران', #1
u'شادى': u'شادى', #1
u'شاذروان': u'شاذروان', #1
u'شاذروان': u'شَاذَرْوَانَ', #10
u'شاذروان': u'شَاذَرْوَانُ', #18
u'شاذروان': u'شَاذَرْوَانِ', #4
u'شاذروانه': u'شَاذَرْوَانُهُ', #2
u'شاذروانه': u'شَاذَرْوَانِهِ', #6
u'شارفاى': u'شَارِفَاىَ', #2
u'شاركنى': u'شَارَكَنِى', #2
u'شازبة': u'شَازِبَةً', #1
u'شازية': u'شَازِيَةَ', #1
u'شأس': u'شَأْسٌ', #1
u'شأس': u'شَأْسٍ', #1
u'شاس': u'شَاسِ', #1
u'شأس': u'شَأْسُ', #2
u'شاس': u'شَاسُ', #2
u'شاس': u'شَاسٍ', #2553
u'شأس': u'شَأْسِ', #4
u'شاسويه': u'شَاسَوَيْهِ', #2
u'شاسويه': u'شَاسُوَيْهِ', #2
u'شأش': u'شَأْشٍ', #1
u'شاصر': u'شَاصِرٌ', #1
u'شاطيطوش': u'شاطيطوش', #1
u'شاعث': u'شَاعِثِ', #2
u'شاعي': u'شَاعِي', #2
u'شاغية': u'شَاغِيَةٍ', #3
u'شاغية': u'شَاغِيَةٌ', #6
u'شاغيه': u'شَاغِيَهْ', #1
u'شافتي': u'شَافَّتِي', #1
u'شاقلا': u'شَاقِلَا', #85
u'شاكرباه': u'شَاكِرْبَاهْ', #1
u'شاكريا': u'شَاكِرِيًّا', #1
u'شالح': u'شَالَحٍ', #1
u'شآم': u'شَآمٍ', #2
u'شآم': u'شَآمٌ', #3
u'شامحة': u'شامحة', #1
u'شاممتنا': u'شَامَمْتَنَا', #1
u'شامى': u'شَامِىٍّ', #1
u'شامى': u'شَامِىٌّ', #4
u'شانى': u'شَانِى', #1
u'شأنى': u'شَأْنِى', #11
u'شأنى؟': u'شَأْنِى؟', #3
u'شانيا': u'شَانِيًا', #1
u'شانيكا': u'شَانِيكَا', #1
u'شاه': u'شَاهً', #2
u'شاهان': u'شاهان', #1
u'شاهان': u'شَاهَانْ', #28
u'شاهبور': u'شَاهَبُورَ', #2
u'شاهبور': u'شَاهَبُورُ', #3
u'شاهبور': u'شاهَبُور', #5
u'شاهترج': u'شاهترج', #1
u'شاهداين': u'شاهداين', #1
u'شاهويه': u'شَاهْوَيْهِ', #1
u'شاؤا': u'شَاؤُا', #1
u'شاوخش': u'شاوخش', #3
u'شأوفعلوها؟': u'شأَوَفَعَلُوهَا؟', #1
u'شاؤه': u'شَاؤُهُ', #2
u'شاويا': u'شَاوِيًا', #1
u'شاويه': u'شَاوِيهِ', #5
u'شائه': u'شَائِهِ', #1
u'شائها': u'شَائِهَا', #1
u'شايد': u'شايد', #2
u'شبابة': u'شَبَابَة', #1
u'شبابة': u'شَبَابَةِ', #1
u'شبابة': u'شَبَّابَةً', #1
u'شبابة،': u'شَبَابَة،', #1
u'شبابة،': u'شَبَابَةَ،', #15
u'شبابة': u'شَبَّابَةٌ', #2
u'شبابة': u'شَبَّابَةِ', #2
u'شبابة': u'شَبَابَةُ', #252
u'شبابة،': u'شبابة،', #3
u'شبابة': u'شَبَّابَةُ', #3
u'شبابة': u'شَبَابَةَ', #37
u'شبابة': u'شبابة', #7
u'شبابة،': u'شَبَابَةُ،', #724
u'شبابة': u'شَبَّابَةَ', #8
u'شبابةح': u'شَبَابَةُح', #1
u'شبابى': u'شَبَابِى', #3
u'شباة': u'شَبَاةُ', #1
u'شبات': u'شبات', #1
u'شباث': u'شُبَاثٍ', #1
u'شبار': u'شِبَارٍ', #1
u'شبار،': u'شَبَارٌ،', #1
u'شبارقة': u'شُبَارِقَةٍ', #2
u'شباشا': u'شباشا', #1
u'شباشا': u'شَبَاشًا', #2
u'شباشا': u'شَبَاشَا', #3
u'شباشب': u'شَبَاشِبَ', #1
u'شبانة': u'شُبَانَةَ', #1
u'شبانروز': u'شبانروز', #2
u'شبانكاه': u'شبانكاه', #1
u'شببة': u'شَبَبَة', #1
u'شببة': u'شَبَبَةً', #1
u'شببة،': u'شَبَبَةٌ،', #1
u'شببة،': u'شَبَبَةُ،', #1
u'شببة': u'شَبَبَةٌ', #10
u'شبة': u'شَبَّة', #1
u'شبة': u'شَبّةَ', #2
u'شبة،': u'شبة،', #3
u'شبة': u'شَبَّةٍ', #3
u'شبة': u'شَبَّةَ', #39
u'شبة،': u'شَبَّةَ،', #66
u'شبته': u'شُبْتُهُ', #2
u'شبث': u'شَبَثٍ', #1
u'شبث': u'شِبْثَ', #1
u'شبث': u'شَبَثُ', #8
u'شبراملسي': u'شَبْرَامَلِّسِيٌّ', #1
u'شبرخيتي': u'شَبْرَخِيتِيٌّ', #13
u'شبرقة': u'شِبْرِقَةٌ', #1
u'شبرقة': u'شِبْرِقَةٍ', #1
u'شبرقة،': u'شِبْرَقَةٌ،', #1
u'شبرمة': u'شبرمة', #1
u'شبرمة،': u'شُبْرُمَةُ،', #1
u'شبرمة،': u'شُبْرُمَةَ،', #10
u'شبرمة': u'شُبْرُمَةُ', #13
u'شبرمة،': u'شبرمة،', #2
u'شبرمة؟': u'شُبْرُمَةُ؟', #2
u'شبرمة': u'شُبْرُمَةَ', #218
u'شبشيري': u'شَبْشِيرِيٌّ', #1
u'شبطون': u'شَبْطُونٍ', #1
u'شبطون': u'شَبْطُونَ', #1
u'شبطون': u'شَبْطُونُ', #1
u'شبعاء': u'شَبْعَاءَ', #1
u'شبعانا': u'شَبْعَانًا', #6
u'شبلون': u'شَبْلُونِ', #1
u'شبلون': u'شَبْلُونَ', #22
u'شبلون': u'شَبْلُونٍ', #61
u'شبناه': u'شِبْنَاهُ', #1
u'شبهنى': u'شَبِّهْنِى', #1
u'شبوبية': u'شُبُوبِيَّةٍ', #1
u'شبور': u'شَبُّور', #1
u'شبور': u'شَبُّورَ', #2
u'شبوه': u'شَبُّوهُ', #2
u'شبويه': u'شَبُّوَيْهِ', #10
u'شبويه': u'شَبَّوَيْهِ', #5
u'شبويه،': u'شَبُّوَيْهِ،', #6
u'شبيب': u'شَبِيب', #1
u'شبيب،': u'شَبِيبُ،', #1
u'شبيب': u'شُبَيْب', #1
u'شبيب': u'شُبَيْبٍ', #1
u'شبيب': u'شبيب', #17
u'شبيب': u'شَبِيبٍ', #251
u'شبيب': u'شُبَيْبِ', #3
u'شبيب': u'شَبِيبٌ', #41
u'شبيب': u'شَبِيبُ', #46
u'شبيب،': u'شبيب،', #5
u'شبيب': u'شَبِيبِ', #52
u'شبيب': u'شَبِيبَ', #6
u'شبيب،': u'شَبِيبٍ،', #71
u'شبيب،': u'شَبِيبٌ،', #8
u'شبيبا': u'شَبِيبًا', #10
u'شبيبها': u'شُبَيْبِهَا', #1
u'شبيت،': u'شَبِيتٍ،', #1
u'شبيل': u'شُبَيْلٌ', #1
u'شبيل': u'شُبَيْلٍ', #13
u'شبيل': u'شُبَيْلُ', #2
u'شبيل،': u'شُبَيْلٍ،', #5
u'شبيل': u'شُبَيْلِ', #6
u'شتر': u'شَتَرَ', #1
u'شتر': u'شَتَرُ', #1
u'شتر': u'شَتَرِ', #1
u'شترائه': u'شَتْرَائِهِ', #1
u'شتل': u'شَتْلَ', #1
u'شتل': u'شَتْلِ', #1
u'شتلا': u'شَتْلًا', #3
u'شتمة': u'شَتْمَةً', #1
u'شتمنى': u'شَتَمَنِى', #2
u'شتوة': u'شَتْوَةً', #1
u'شتوة': u'شِتْوَة', #1
u'شتوة،': u'شَتْوَةً،', #1
u'شتوة': u'شَتْوَةٍ', #5
u'شتوتين': u'شَتْوَتَيْنِ', #1
u'شتوتين،': u'شَتْوَتَيْنِ،', #2
u'شتى': u'شَتًّى', #1
u'شتير': u'شُتَيْر', #2
u'شتير': u'شُتَيْرٍ', #2
u'شتير': u'شُتَيْرِ', #29
u'شتير': u'شُتَيْرُ', #3
u'شتىوروي': u'شَتَّىوَرُوِيَ', #1
u'شث': u'شث', #1
u'شث': u'شَثٍّ', #1
u'شثن': u'شَثْنِ', #1
u'شثن': u'شَثْنَ', #18
u'شثن': u'شثن', #2
u'شثن': u'شَثْنُ', #9
u'شجاح': u'شَجَّاحٍ', #1
u'شجاع': u'شجاعً', #1
u'شججتك': u'شَجَجْتُك', #1
u'شججته': u'شَجَجْتَهُ', #3
u'شججته': u'شَجَجْته', #5
u'شجوجاة': u'شَجَوْجَاةٍ', #1
u'شحاث': u'شَحَّاثٌ', #1
u'شحاده': u'شحاده', #2
u'شحر': u'شَحْرٍ', #1
u'شحوبة': u'شَحَوبة', #1
u'شحيمة،': u'شَحِيمَةٌ،', #1
u'شحيمة': u'شُحَيْمَةُ', #1
u'شخام': u'شخام', #1
u'شختة': u'شختة', #1
u'شخصى': u'شخصى', #1
u'شخم': u'شَخِمَ', #1
u'شداخ': u'شدّاخ', #1
u'شدازين': u'شدازين', #1
u'شدخ': u'شَدْخٌ', #1
u'شدخ': u'شَدْخُ', #1
u'شدخ': u'شَدْخِ', #1
u'شدخ': u'شَدْخٍ', #2
u'شدخ': u'شُدِخَ', #2
u'شدخ': u'شَدَخٍ', #5
u'شدخ': u'شَدَخَ', #6
u'شدخا': u'شَدْخًا', #4
u'شدخت': u'شَدَخَتْ', #1
u'شدخت': u'شُدِخَتْ', #1
u'شدخته': u'شَدْخَتَهُ', #1
u'شدخه': u'شَدَخَهُ', #5
u'شدرنج': u'شِدْرَنْجَ', #1
u'شدف': u'شَدِفٌ', #1
u'شدف': u'شَدِفَ', #1
u'شدف': u'شُدْفٍ', #1
u'شدف': u'شُدُفٌ', #2
u'شدف': u'شُدُفٍ', #5
u'شدفا': u'شَدَفًا', #1
u'شدقيني': u'شِدْقِينِيِّ', #1
u'شدكه': u'شدكه', #1
u'شدكي': u'شدكي', #1
u'شدم': u'شدم', #6
u'شدمارا': u'شدمارا', #1
u'شدمى': u'شدمى', #1
u'شده،': u'شِدَّهً،', #1
u'شدوف': u'شَدُوفٌ', #3
u'شديدوأمر': u'شَدِيدٍوَأَمَرَ', #1
u'شديدوروي': u'شَدِيدٌوَرُوِيَ', #1
u'شديران': u'شديران', #1
u'شديم': u'شديم', #1
u'شديم': u'شُدِيمْ', #1
u'شذم': u'شذم', #1
u'شذى': u'شذى', #1
u'شرابة': u'شَرَابَةٌ', #1
u'شرابة': u'شَرَابَةٍ', #1
u'شرابة': u'شَرَابَةُ', #1
u'شرابة': u'شَرَابَةِ', #1
u'شرابة': u'شُرَابَةٌ', #1
u'شرابة': u'شُرَابَةُ', #1
u'شرابة': u'شِرَابَةً', #1
u'شرابة': u'شِرَابَةُ', #1
u'شرابة': u'شِرَابَةٌ', #2
u'شرابتها': u'شِرَابَتُهَا', #1
u'شرابتها': u'شرابتها', #2
u'شرابى': u'شْرَابِى', #1
u'شراج': u'شِرَاجِ', #15
u'شراج': u'شِرَاجٍ', #4
u'شراج': u'شِرَاج', #5
u'شراحبيل': u'شراحبيل', #1
u'شراحبيل': u'شُرَاحْبِيلَ', #1
u'شراحة': u'شَرَاحَةَ', #1
u'شراحة': u'شُرَاحَةَ', #14
u'شراحة': u'شُرَاحَةُ', #2
u'شراحيل،': u'شراحيل،', #1
u'شراحيل،': u'شَرَاحيل،', #1
u'شراحيل': u'شَرَاحيل', #2
u'شراحيل': u'شُرَاحِيلَ', #3
u'شراحيل': u'شَرَاحِيلَ', #48
u'شراحيل': u'شراحيل', #6
u'شراحيل': u'شَرَاحِيلُ', #6
u'شراحيل،': u'شَرَاحِيلَ،', #8
u'شراريبها': u'شَرَارِيبُهَا', #2
u'شراريبها': u'شَرَارِيبِهَا', #3
u'شرازة': u'شَرَازَة', #1
u'شراعة': u'شُرَاعَةَ', #1
u'شراعة،': u'شُرَاعَةَ،', #1
u'شراكت': u'شراكت', #1
u'شربواالوجه': u'شَرِبُواالْوَجْهُ', #1
u'شرة': u'شِرَّةٌ', #10
u'شرة': u'شِرَّةً', #12
u'شرة': u'شِرَّةٍ', #14
u'شرتي': u'شِرّتِي', #1
u'شرجاته': u'شَرَجَاتِهِ', #1
u'شرجبا': u'شَرْجَبًا', #1
u'شرجة': u'شرجة', #1
u'شرجة': u'شَرَجَةٍ', #1
u'شرجة': u'شَرْجَةٍ', #1
u'شرجة': u'شَرْجَةٌ', #2
u'شرجة': u'شَرْجَة', #4
u'شرحبيل': u'شُرحبيل', #1
u'شرحبيل،': u'شُرَحبيل،', #1
u'شرحبيل،': u'شرَحْبيل،', #1
u'شرحبيل': u'شُرَحْبيلُ', #1
u'شرحبيل،': u'شُرَحْبيل،', #1
u'شرحبيل': u'شَرَحْبِيلَ', #1
u'شرحبيل،': u'شَرَحْبِيلَ،', #1
u'شرحبيل؟': u'شُرَحْبِيلُ؟', #1
u'شرحبيل': u'شُرَحْبِيل', #10
u'شرحبيل': u'شُرَحْبِيلُ', #101
u'شرحبيل': u'شُرَحْبِيلٌ', #2
u'شرحبيل': u'شُرَحْبيِلُ', #2
u'شرحبيل': u'شرحبيل', #23
u'شرحبيل': u'شُرَحْبِيلٍ', #3
u'شرحبيل': u'شُرَحْبِيلِ', #3
u'شرحبيل': u'شُرَحْبِيلَ', #318
u'شرحبيل،': u'شُرَحْبِيلَ،', #44
u'شرحبيل،': u'شرحبيل،', #5
u'شرحبيل': u'شُرَحْبيل', #7
u'شرحبيل،': u'شُرَحْبِيلُ،', #7
u'شرحيل': u'شَرَحِيلَ', #1
u'شرشا': u'شَرْشًا', #1
u'شرشه': u'شَرَشَهُ', #1
u'شرط': u'شَرْطً', #2
u'شرطى': u'شَرْطِى', #1
u'شرعاب': u'شَرْعَابٌ', #1
u'شرعابة': u'شَرْعَابَةٌ', #1
u'شرعب': u'شَرْعَبَ', #1
u'شرعست': u'شرعست', #1
u'شرعواSشعر': u'شَرَعُواSشِعْرُ', #1
u'شرعى': u'شَرْعِىٍّ', #1
u'شرغ': u'شَرْغٍ', #1
u'شرغبه': u'شُرْغبِهِ', #1
u'شرقاء': u'شَرْقَاءَ', #19
u'شرقاء': u'شَرْقَاء', #2
u'شرقاء': u'شَرْقَاءُ', #2
u'شرقاوي': u'شَرْقَاوِيُّ', #1
u'شرقاوي': u'شَرْقَاوِيٌّ', #57
u'شرقة': u'شَرْقَة', #1
u'شرقة': u'شَرْقَةٌ', #1
u'شرقى': u'شَرْقِىَّ', #1
u'شركآؤكم': u'شُرَكَآؤُكُمُ', #1
u'شرككا': u'شِرْكَكَا', #1
u'شركنى': u'شَرِكَنِى', #3
u'شرمطته': u'شَرْمَطَتِهِ', #1
u'شرنبلالي': u'شُرُنْبُلَالِيّ', #11
u'شرنبلالي': u'شُرُنْبُلَالِيٌّ', #17
u'شرنبلالي': u'شرنبلالي', #2
u'شرنبلالية': u'شُرُنْبُلَالِيَّةً', #1
u'شرنبلالية': u'شُرُنْبُلَالِيَّةٍ', #1
u'شرنبلالية': u'شُرْنْبُلَالِيَّةٌ', #2
u'شرنبلالية': u'شُرُنْبُلَالِيَّةٌ', #236
u'شرنبلالية': u'شُرُنْبُلَالِيَّةُ', #4
u'شروان،': u'شروان،', #1
u'شروان': u'شِرْوَانَ', #1
u'شروان': u'شروان', #2
u'شروان': u'شُرْوَانَ', #2
u'شروحات': u'شُرُوحَاتِ', #2
u'شرورى': u'شَرَوْرَى', #1
u'شروس،': u'شروسٍ،', #1
u'شروس،': u'شَرُوسٍ،', #1
u'شروس': u'شَرُوسٍ', #2
u'شروغ،': u'شَرْوَغَ،', #1
u'شروفا': u'شُرُوفًا', #1
u'شريب': u'شُرَيْبٍ', #1
u'شريب': u'شِرِّيبٍ', #12
u'شريب': u'شِرِّيبٌ', #5
u'شريبا': u'شِرِّيبًا', #6
u'شريج': u'شُرَيْجُ', #1
u'شريج،': u'شُرَيْجٍ،', #1
u'شريجان': u'شَرِيجَانِ', #1
u'شريجة': u'شَرِيجَةَ', #1
u'شريجة': u'شَرِيجَةٍ', #3
u'شريجيا': u'شَرِيجِيًّا', #1
u'شريسها': u'شَرِيسُهَا', #3
u'شريعت': u'شريعت', #5
u'شريكى': u'شَرِيكِى', #3
u'شريكية': u'شَرِيكِيَّةٌ', #1
u'شزن': u'شَزَنْ', #2
u'شس': u'شس', #1
u'شستن': u'شستن', #1
u'شسع': u'شِسْع', #2
u'شسع': u'شِسْعَ', #2
u'شسع': u'شِسْعُ', #47
u'شسع': u'شِسْعِ', #7
u'شسعا': u'شِسْعًا', #2
u'شسعه،': u'شسعه،', #1
u'شسعه': u'شِسْعُهُ', #2
u'شسعه': u'شِسْعِهِ', #2
u'شسعه،': u'شِسْعَهُ،', #2
u'شسعه': u'شِسْعَهُ', #9
u'شسوع': u'شسوع', #1
u'شسوع': u'شُسُوعٌ', #1
u'شسيا': u'شسيا', #8
u'شسيا': u'شِسْيَا', #8
u'شش': u'شش', #4
u'ششرنك': u'ششرنك', #1
u'ششى': u'ششى', #1
u'شصاص': u'شِصَاصٍ', #2
u'شطأة': u'شَطْأَةٌ', #1
u'شطأة': u'شِطْأَةٌ', #1
u'شطأه': u'شَطْأَهُ', #8
u'شطح': u'شَطْحٍ', #1
u'شطح': u'شَطْحٌ', #2
u'شطح': u'شَطَحَ', #5
u'شطرالحسن': u'شَطْرَالْحُسْنِ', #1
u'شطرع': u'شطرع', #1
u'شطريته': u'شَطْرِيَّتِهِ', #1
u'شطوح': u'شُطُوحُ', #1
u'شطون': u'شَطُونٌ', #3
u'شطون': u'شَطُونٍ', #3
u'شطؤه': u'شَطْؤُهُ', #2
u'شطوي': u'شَطَوِيٍّ', #2
u'شطويا': u'شَطَوِيًّا', #1
u'شطويين': u'شَطَوِيَّيْنِ', #1
u'شطير': u'شُطَيْرُ', #1
u'شعارة': u'شَعَارَةٌ', #1
u'شعارة': u'شِعَارَةٌ', #2
u'شعآئر': u'شَعَآئِرِ', #1
u'شعايريا': u'شعايريا', #1
u'شعباذا': u'شِعْبَاذًا', #1
u'شعبةسمعت': u'شُعْبَةُسَمِعْتُ', #1
u'شعبتى': u'شُعْبَتَىِ', #1
u'شعبذ': u'شَعْبَذَ', #1
u'شعبذة': u'شَعْبَذَةً', #1
u'شعبى': u'شَعْبِىُّ', #2
u'شعثم': u'شَعْثَمُ', #2
u'شعوثة': u'شُعُوثَةُ', #1
u'شعوف': u'شُعُوفِ', #1
u'شعيبا': u'شُعَيْبَاً', #1
u'شعيبا،': u'شُعَيْبًا،', #3
u'شعيبا': u'شُعَيْبًا', #42
u'شعيبة': u'شُعَيْبَةُ', #1
u'شعيث': u'شُعَيْثِ', #2
u'شعيث': u'شُعَيْثٌ', #3
u'شعيث': u'شُعَيْثُ', #6
u'شغا،': u'شغا،', #1
u'شغا': u'شَغًا', #1
u'شغارة': u'شِغَارَةَ', #1
u'شغزبا': u'شُغْزُبًا', #1
u'شغزبا': u'شُغْزُبًّا', #3
u'شغزوبا': u'شُغْزُوبًّا', #1
u'شغفنى': u'شَغَفَنِى', #1
u'شغلتنى': u'شَغَلْتَنِى', #1
u'شغلتنى': u'شَغَلَتْنِى', #3
u'شغلنى': u'شَغَلَنِى', #3
u'شغواء': u'شَغْوَاءُ', #1
u'شغوبا': u'شَغُوبًا', #1
u'شغول': u'شُغُولٌ', #1
u'شغول': u'شُغُولُ', #1
u'شفاعت': u'شفاعت', #1
u'شفاعتى': u'شَفَاعَتِى', #6
u'شفاعنه': u'شفاعنَه', #1
u'شفاكا': u'شَفَاكَا', #1
u'شفاكا': u'شِفَاكَا', #1
u'شفانا': u'شَفّانًا', #1
u'شفانى': u'شَفَانِى', #3
u'شفانيا': u'شَفَانِيَا', #1
u'شفترنك': u'شفترنك', #1
u'شفتى': u'شَفَتَىِ', #1
u'شفعوي': u'شَفْعَوِيٍّ', #2
u'شفعوي': u'شَفْعَوِيِّ', #2
u'شفعوي': u'شَفْعَوِيٌّ', #4
u'شفعوي': u'شَفْعَوِيُّ', #4
u'شفعوي': u'شَفْعَوِيَّ', #6
u'شفعويا': u'شَفْعَوِيًّا', #2
u'شفقان': u'شَفَقَانِ', #1
u'شفهة': u'شَفَهَةٌ', #7
u'شفوة': u'شَفْوَةٌ', #3
u'شفوع': u'شَفُوعٌ', #1
u'شفيتنى': u'شَفَيْتَنِى', #2
u'شفيهة': u'شُفَيْهَةٌ', #2
u'شقاتهم': u'شُقَّاتُهُمْ', #1
u'شقحب': u'شقحب', #1
u'شقحة': u'شُقْحَةٌ', #1
u'شقحية': u'شَقْحِيّةٌ', #1
u'شقحية': u'شُقَحِيّةٌ', #1
u'شقدف': u'شُقْدُفٍ', #6
u'شقدفا': u'شُقْدُفًا', #1
u'شقران': u'شَقْرَانُ', #1
u'شقران': u'شُقْرَان', #2
u'شقران': u'شُقْرَانُ', #25
u'شقران': u'شقران', #3
u'شقران': u'شُقْرَانَ', #7
u'شقرى': u'شَقْرَى', #1
u'شقشاء': u'شِقٍّشَاءَ', #1
u'شقص': u'شِقْصٌ', #138
u'شقص': u'شِقْصٍ', #200
u'شقص': u'شِقْصَ', #25
u'شقص': u'شِقْصِ', #38
u'شقص': u'شِقْصُ', #9
u'شقصا': u'شِقْصًا', #620
u'شقصان': u'شِقْصَانِ', #2
u'شقصاه': u'شِقْصَاهُ', #1
u'شقصك': u'شِقْصَكَ', #1
u'شقصه': u'شِقْصَه', #1
u'شقصه': u'شِقْصَهُ', #40
u'شقصه': u'شِقْصِهِ', #49
u'شقصه': u'شِقْصُهُ', #8
u'شقصها': u'شِقْصِهَا', #1
u'شقصها': u'شِقْصُهَا', #8
u'شقصها': u'شِقْصَهَا', #9
u'شقصي': u'شِقْصِي', #2
u'شقصين': u'شِقْصَيْنِ', #14
u'شقفة': u'شَقَفَةٍ', #1
u'شقى': u'شَقِىٍّ', #1
u'شقى': u'شَقَّىْ', #1
u'شقى': u'شِقَّىَّ', #1
u'شقى': u'شِقِّى', #1
u'شقى': u'شَقِىَ', #2
u'شقى': u'شِقَّىْ', #2
u'شقى': u'شقى', #3
u'شقى': u'شَقِىٌّ', #3
u'شقير': u'شُقَيْر', #1
u'شقير': u'شُقَيْرِ', #1
u'شقيراء': u'شُقَيْرَاءُ', #1
u'شقيصا': u'شَقِيصًا', #21
u'شكارا': u'شَكَّارًا', #1
u'شكازا': u'شَكَّازًا', #1
u'شكاوقال': u'شَكًاوَقَالَ', #1
u'شكران': u'شُكْرَانِ', #1
u'شكرى': u'شُكْرِى', #1
u'شكريهما': u'شُكْرَيْهِمَا', #1
u'شكفت': u'شكفت', #1
u'شككتنى': u'شَكَّكْتَنِى', #2
u'شكمجة': u'شكمجة', #3
u'شكمجه': u'شكمجه', #4
u'شكوى': u'شَكْوًى', #6
u'شكى': u'شَكَى', #10
u'شكى': u'شُكِىَ', #4
u'شكير': u'شَكِيرٌ', #2
u'شكيس': u'شُكَيْس', #1
u'شكيس': u'شُكَيْسٍ', #1
u'شكيل': u'شُكَيْل', #10
u'شكيل': u'شُكَيْلٍ', #60
u'شكيلته': u'شَكِيلَتِهِ', #2
u'شكيمهن': u'شَكِيمَهُنّ', #1
u'شلبي': u'شَلَبَيّ', #1
u'شلبي': u'شَلَبِيٍّ', #1
u'شلبي': u'شَلَبِيّ', #13
u'شلبي': u'شَلَبِيٌّ', #8
u'شلقة': u'شَلْقَةٍ', #1
u'شلم': u'شَلّمَ', #1
u'شلنا': u'شِلِنًا', #1
u'شلير': u'شُلَيْرَ', #1
u'شليل': u'شُلَيْلٍ', #1
u'شليلا': u'شَلِيلًا', #2
u'شمارااز': u'شمارااز', #1
u'شماريخ': u'شَمَارِيخ', #1
u'شماريخ': u'شَمَارِيخُ', #1
u'شماريخ': u'شَمَارِيخَ', #6
u'شماسة': u'شماسة', #1
u'شماسة،': u'شماسة،', #1
u'شماسة': u'شِمَاسة', #1
u'شماسة،': u'شَمَاسَةَ،', #1
u'شماسة،': u'شُمَاسَةَ،', #17
u'شماسة': u'شَمَاسَةَ', #2
u'شماسة': u'شُمَاسَةَ', #22
u'شماسة،': u'شِمَاسَةَ،', #4
u'شماسة': u'شِمَاسَةَ', #40
u'شماسة،أنه': u'شِمَاسَةَ،أَنَّهُ', #1
u'شماشة': u'شِمَاشَةَ', #2
u'شماطيط': u'شَمَاطِيطُ', #4
u'شمأل': u'شَمْأَلٍ', #2
u'شمالى': u'شِمَالِى', #6
u'شمامة': u'شَمَامَةِ', #1
u'شمامر': u'شمامر', #1
u'شمامسة': u'شَمَامِسَةُ', #2
u'شمة': u'شَمَّةٌ', #1
u'شمة': u'شَمَّةً', #2
u'شمة': u'شِمَّةٌ', #2
u'شمختانية': u'شَمَخْتَانِيَّةٍ', #2
u'شمخشا': u'شمخشا', #1
u'شمذ': u'شُمّذٌ', #1
u'شمذات': u'شَمَذَاتِ', #1
u'شمردل': u'شَمَرْدَلُ', #1
u'شمردلات': u'شَمَرْدَلَات', #1
u'شمردلات': u'شَمَرْدَلَاتٍ', #1
u'شمركية': u'شَمْرَكِيَّةٍ', #1
u'شمروخ': u'شُمْرُوخٍ', #1
u'شمسبن': u'شَمْسِبْنِ', #1
u'شمط': u'شمطٌ', #1
u'شمط': u'شَمَطٌ', #1
u'شمط': u'شَمْطٌ', #1
u'شمط': u'شَمْطَ', #1
u'شمط': u'شَمِطَ', #11
u'شمط': u'شمط', #2
u'شمط': u'شُمْطٍ', #2
u'شمطا': u'شَمْطًا', #1
u'شمطا': u'شُمْطًا', #1
u'شمطات': u'شَمَطَاتٍ', #4
u'شمطاته': u'شَمَطَاتِهِ', #1
u'شمطاط': u'شِمْطَاطٌ', #1
u'شمطة': u'شَمْطَةَ', #1
u'شمعون،': u'شَمْعُونُ،', #1
u'شمعون': u'شَمْعُونَ', #14
u'شمعون': u'شمعون', #3
u'شمعون،': u'شَمْعُونَ،', #4
u'شمعون': u'شَمْعُونُ', #7
u'شملال': u'شِمْلَالِ', #1
u'شمليل': u'شِمْليل', #1
u'شمليل': u'شِمْلِيلُ', #3
u'شموصا': u'شَمُوصًا', #4
u'شموئيل': u'شَمَوْئِيلُ', #1
u'شمويل': u'شَمْوِيلٍ', #1
u'شمويل': u'شَمْوِيلَ', #1
u'شمى': u'شُمِّى', #1
u'شميخ': u'شُمَيْخٍ', #3
u'شمير': u'شِمِّيرُ', #1
u'شمير': u'شُمَيْرٍ', #8
u'شميس': u'شُمَيْسٍ', #2
u'شميسة': u'شُمَيْسَة', #1
u'شميسة': u'شُمَيْسَةَ', #14
u'شميسة': u'شُمَيْسَةُ', #4
u'شميط': u'شُمَيْطِ', #1
u'شميط': u'شُمَيْطٍ', #2
u'شميط،': u'شُمَيْطٍ،', #6
u'شميل': u'شُمَيْلٌ', #1
u'شميل': u'شُمَيْلِ', #1
u'شميل،': u'شميل،', #12
u'شميل': u'شُمَيْلٍ', #165
u'شميل': u'شميل', #8
u'شميل،': u'شُمَيْلٍ،', #95
u'شميله': u'شُمَيْلَهْ', #1
u'شناتر': u'شناتر', #1
u'شناتر': u'شَناتر', #1
u'شناتر': u'شَنَاتِرَ', #2
u'شناخيب': u'شَنَاخِيبَ', #1
u'شنار': u'شَنَار', #1
u'شنار': u'شَنَارُ', #1
u'شنار': u'شَنَارٌ', #3
u'شنارا': u'شَنَارًا', #1
u'شناس': u'شناس', #1
u'شنباء': u'شَنْبَاءُ', #2
u'شنبة': u'شَنَبَةَ', #2
u'شنبة': u'شَنْبَةَ', #2
u'شنبثا': u'شَنْبَثًا', #4
u'شنبر': u'شَنْبَرٌ', #1
u'شنبر': u'شَنْبَرٍ', #2
u'شنبر': u'شنبر', #4
u'شنبوذ': u'شَنَبُوذٍ', #1
u'شنبوذ': u'شَنَبُوذَ', #1
u'شنة': u'شنة', #1
u'شنة': u'شَنّةِ', #1
u'شنة': u'شَنَّةٌ', #1
u'شنة': u'شَنَّةُ', #1
u'شنة': u'شَنَّةٍ', #10
u'شنة': u'شَنَّة', #2
u'شنة': u'شَنَّةً', #2
u'شنترة': u'شَنْتَرَةٍ', #1
u'شند': u'شند', #1
u'شند': u'شَنَدٍ', #1
u'شنداخ': u'شِنْدَاخٌ', #1
u'شندحي': u'شِنْدِحِيٌّ', #1
u'شندخ': u'شُنْدُخٌ', #3
u'شندخي': u'شِنْدِخِيٌّ', #1
u'شندخية': u'شُنْدَخِيَّةٌ', #1
u'شندنه': u'شندنه', #1
u'شنشنة': u'شنشنة', #1
u'شنشنة': u'شِنْشِنَةٌ', #1
u'شنشنة': u'شَنْشَنَةٌ', #2
u'شنشنته': u'شِنْشِنَتُهُ', #1
u'شنشوري': u'شَنْشُورِيٌّ', #4
u'شنصدى': u'شنصدى', #1
u'شنظير': u'شِنْظِيرٍ', #14
u'شنظير': u'شِنْظِيرَ', #2
u'شنظير،': u'شِنْظِيرٍ،', #7
u'شنناها': u'شَنَنَّاهَا', #1
u'شنوأة': u'شَنُوأَةَ', #2
u'شنواني': u'شَنَوَانِيٌّ', #4
u'شنوة': u'شنوة', #1
u'شنوق': u'شَنُوقِ', #1
u'شنوكة': u'شَنُوكَةُ', #2
u'شنوكة': u'شَنُوكَةَ', #3
u'شنى': u'شَنَى', #1
u'شنيفا': u'شَنِيفًا', #1
u'شنينة': u'شُنَيْنَةَ', #1
u'شنينة': u'شُنَيْنَةُ', #1
u'شهابثم': u'شِهَابٍثُمَّ', #1
u'شهابولا': u'شِهَابٍوَلا', #1
u'شهادت': u'شَهَادَتِ', #1
u'شهادتة': u'شهادتة', #1
u'شهادتهاقوله': u'شَهَادَتَهَاقَوْلُهُ', #1
u'شهادتى': u'شَهَادَتِى', #3
u'شهبرة': u'شَهْبَرَةً', #1
u'شهبرة': u'شَهْبَرَةٌ', #1
u'شهبرة': u'شَهْبَرَةَ', #2
u'شهداءأحدللجرح': u'شُهَدَاءِأُحُدٍلِلْجُرْحِ', #1
u'شهررى': u'شهررى', #1
u'شهرستانية': u'شِهْرِسْتَانِيَّةٌ', #1
u'شهريار': u'شَهْرَيار', #1
u'شهريار': u'شَهْرَيَارَ', #10
u'شهريار': u'شَهْرَيَار', #2
u'شهريار': u'شَهْرَيَارُ', #2
u'شهريران،': u'شهريران،', #1
u'شهريران': u'شهريران', #4
u'شهودهالعقبة': u'شُهُودِهِالْعَقَبَةَ', #1
u'شهيب': u'شُهَيْبٍ', #1
u'شهيداSحول': u'شَهِيدًاSحَوْلَ', #1
u'شواب': u'شَوَابُّ', #1
u'شواب': u'شَوَابَّ', #6
u'شوابين': u'شَوَابِينَ', #1
u'شواريز': u'شَوَارِيزِ', #1
u'شوازب': u'شَوَازِبٌ', #3
u'شوازمن': u'شوازمن', #1
u'شواويل': u'شَوَاوِيلَ', #1
u'شوائل': u'شَوَائِلُ', #2
u'شوبرى': u'شوبرى', #1
u'شوبري': u'شَوْبَرِيٌّ', #409
u'شوبري': u'شَوْبَرِيٍّ', #5
u'شوبري': u'شَوْبَرِيُّ', #91
u'شوبوا': u'شَوِّبُوا', #1
u'شوحط': u'شَوْحَطٍ', #4
u'شوخة': u'شَوْخَةَ', #1
u'شوخة': u'شَوْخَةُ', #1
u'شودب،': u'شودب،', #1
u'شودواين': u'شودواين', #1
u'شودونه': u'شودونه', #1
u'شوديا': u'شوديا', #1
u'شوديانه': u'شوديانه', #1
u'شوديانى': u'شوديانى', #1
u'شودياني': u'شودياني', #2
u'شؤذب،': u'شُؤذَبٍ،', #1
u'شوذب': u'شوذب', #1
u'شوذب': u'شَوذَب', #1
u'شوذب،': u'شوذب،', #2
u'شوذب': u'شَوْذَب', #2
u'شوذب،': u'شَوْذَبٍ،', #28
u'شوذب': u'شَوْذَبَ', #3
u'شوذب': u'شَوْذَبٍ', #82
u'شورة': u'شَوْرَةَ', #1
u'شورة': u'شُورَةٍ', #2
u'شورة': u'شُورَةَ', #2
u'شورة': u'شَوْرَةٌ', #2
u'شورة': u'شَوْرَةِ', #2
u'شورة': u'شُورَةٌ', #3
u'شورة': u'شُورَةِ', #7
u'شورلي': u'شورلي', #3
u'شوكر،': u'شَوْكَرٍ،', #1
u'شوكر': u'شَوْكَرَ', #3
u'شوكر': u'شَوْكَرٍ', #4
u'شومان،': u'شُومَانَ،', #1
u'شومه': u'شُومَهُ', #1
u'شونيزا': u'شُونِيزًا', #1
u'شونيزية': u'شُونِيزِيَّةَ', #1
u'شوهران': u'شوهران', #1
u'شويخ': u'شُوَيْخٌ', #1
u'شويد': u'شويد', #2
u'شويس': u'شُوَيْسٍ', #1
u'شويس': u'شُوَيْسُ', #1
u'شويكات': u'شُوَيْكَاتٍ', #1
u'شويكة': u'شُوَيْكَةٌ', #2
u'شويم': u'شويم', #1
u'شويهة،': u'شُوَيْهة،', #1
u'شويهة': u'شُوَيْهَةُ', #1
u'شويهة': u'شُوَيْهَةٌ', #3
u'شويهة': u'شُوَيْهَةً', #5
u'شيء': u'شيءً', #1
u'شىء': u'شَىءٍ', #1
u'شىء؟': u'شَىْءٍ؟', #14
u'شىء': u'شَىْء', #2
u'شىء': u'شَىْءِ', #2
u'شىء؟': u'شَىْءٌ؟', #24
u'شيء': u'شَيْءً', #3
u'شىء': u'شَىْءَ', #51
u'شىء': u'شَىْءٌ', #723
u'شىء': u'شَىْءٍ', #757
u'شىء،': u'شىء،', #8
u'شئاها': u'شَئَاهَا', #2
u'شئتا': u'شِئْتَا', #1
u'شئته': u'شِئْتُهُ', #1
u'شئته': u'شِئْتِهِ', #2
u'شئته': u'شِئْته', #3
u'شئتها': u'شِئْتهَا', #1
u'شئتها': u'شِئْتِهَا', #1
u'شئتهما': u'شِئْتهمَا', #1
u'شئتي': u'شِئْتِي', #1
u'شيءعن': u'شَيْءٍعَنْ', #1
u'شيءقوله': u'شَيْءٍقَوْلُهُ', #1
u'شئوالوجه': u'شَئٌوَالْوَجْهُ', #1
u'شيابهم': u'شُيّابُهُمْ', #1
u'شياع': u'شِيَاعٍ', #3
u'شياعه': u'شِيَاعِهِ', #1
u'شيبع': u'شِيبَعَ', #1
u'شيث': u'شيثَ', #1
u'شيث،': u'شِيثَ،', #1
u'شيث': u'شِيثٌ', #10
u'شيث': u'شيث', #2
u'شيث': u'شِيثٍ', #35
u'شيث': u'شِيثَ', #4
u'شيث': u'شِيثِ', #4
u'شيث': u'شِيثُ', #8
u'شيثا': u'شِيثًا', #1
u'شيخو': u'شِيخُو', #1
u'شيخون': u'شَيْخُونٍ', #1
u'شيخى': u'شَيْخِى', #4
u'شيدابي': u'شيدابي', #1
u'شيراز،': u'شيراز،', #1
u'شيراز،': u'شِيراز،', #1
u'شيراز': u'شِيرَازُ', #1
u'شيراز': u'شِيرَازِ', #3
u'شيراز': u'شِيرَازَ', #5
u'شيرازا': u'شِيرَازًا', #16
u'شيرازي': u'شِيرَازِيٍّ', #1
u'شيرجة': u'شَيْرَجَةً', #1
u'شيرجة': u'شَيْرَجَةٍ', #1
u'شيرخشك': u'شيرخشك', #1
u'شيرز،': u'شَيْرَزَ،', #1
u'شيرم': u'شيرم', #1
u'شيره': u'شَيْرَهْ', #1
u'شيره': u'شيره', #2
u'شيرويه': u'شِيْرُوَيْهِ', #1
u'شيرويه': u'شِيرُوَيْهِ', #22
u'شيرويه،': u'شيرويه،', #3
u'شيرويه': u'شِيرَوَيْه', #3
u'شيرويه': u'شِيرَوَيْهِ', #4
u'شيرويه،': u'شِيرَوَيْهِ،', #8
u'شيرين': u'شِيرِينُ', #1
u'شيزر': u'شَيْزَرٍ', #1
u'شيزي': u'شِيزِي', #1
u'شيزى': u'شِيزَى', #2
u'شيشاء': u'شِيشَاءِ', #1
u'شيصا': u'شِيصًا', #9
u'شيطأنا': u'شَيْطَأنا', #2
u'شيطانة': u'شَيْطَانَةً', #17
u'شيطانة': u'شَيْطَانَةَ', #2
u'شيظمي': u'شَيْظميّ', #1
u'شيظمي': u'شَيْظَمِيّ', #3
u'شيكران': u'شَيْكَرَانُ', #1
u'شيماء': u'شَيْمَاءُ', #1
u'شيماء': u'شَيْمَاءَ', #2
u'شيمان': u'شَيْمان', #1
u'شينات': u'شِينَاتٍ', #29
u'شينة': u'شِينَةً', #1
u'شينة': u'شِينَةٍ', #1
u'شيوم': u'شُيُومٌ', #2
u'شيؤه': u'شَيْؤُهُ', #14
u'شيىء؟': u'شيىء؟', #1
u'شيىء': u'شيىء', #2
u'شيئ': u'شَيْئً', #2
u'شيئاSذكر': u'شَيْئًاSذِكْرُ', #1
u'شيئاء': u'شَيْئَاءُ', #3
u'شيئة': u'شِيئَةَ', #3
u'شيئته': u'شِيئَته', #1
u'شييخ': u'شُيَيْخٌ', #1
u'شييم': u'شَيَيْمَ', #1
u'شييم': u'شُيَيْمٌ', #1
u'شييم': u'شُيَيْمٍ', #1
u'شييم': u'شِيَيْمَ', #1
u'شييم': u'شُيَيْم', #2
u'شييم': u'شُيَيْمَ', #3
u'شييم': u'شِيَيْمِ', #5
u'شييم': u'شُيَيْمِ', #6
u'صا': u'صَا', #2
u'صابونين': u'صَابُونَيْنِ', #1
u'صاج': u'صَاجٌ', #1
u'صاحباى': u'صَاحِبَاىَ', #4
u'صاحبنى': u'صَاحَبَنِى', #1
u'صاحبى': u'صَاحِبَى', #1
u'صاحبى': u'صَاحِبَىِّ', #1
u'صاحبى': u'صَاحِبَىْ', #1
u'صاحبى': u'صَاحِبَىِ', #2
u'صاحبى': u'صَاحِبِى', #33
u'صاحبى': u'صَاحِبَىَّ', #7
u'صاحبيا،': u'صَاحِبِيًّا،', #1
u'صاحبيون': u'صَاحِبُيُّونَ', #1
u'صادفنى': u'صَادَفَنِى', #1
u'صادفيوم': u'صَادَفَيَوْمَ', #1
u'صادق؟،': u'صَادِقً؟،', #1
u'صادقى': u'صَادِقِى', #1
u'صادقية': u'صَادِقِيَّةُ', #1
u'صادقية': u'صَادِقِيَّةِ', #9
u'صادقيته': u'صَادِقِيَّتَهُ', #1
u'صادقيته': u'صَادِقِيَّتِهِ', #1
u'صادوق': u'صَادُوقٌ', #1
u'صاردا': u'صَارِدًا', #1
u'صارعظم': u'صَارَعُظْمَ', #1
u'صاروجه': u'صَارُوجِهِ', #1
u'صأصأ': u'صَأْصَأَ', #4
u'صاع': u'صَاعً', #2
u'صاعدية': u'صَاعِدِيّةٌ', #2
u'صاعى': u'صَاعَىْ', #4
u'صاغان': u'صَاغَانَ', #2
u'صافحنى': u'صَافَحَنِى', #3
u'صافر': u'صَافِرٍ', #1
u'صافعتم': u'صَافَعْتُمُ', #1
u'صافنة': u'صَافِنَةٌ', #1
u'صأكا': u'صَأَكًا', #1
u'صالح': u'صَالِحً', #1
u'صالحالوجه': u'صَالِحٌالْوَجْهُ', #1
u'صالحواالنبي': u'صَالَحُواالنَّبِيَّ', #1
u'صالحى': u'صَالِحِى', #2
u'صالحية': u'صَالِحِيَّةِ', #2
u'صالغ': u'صَالِغٌ', #2
u'صالوجا': u'صَالُوجَا', #1
u'صامتSفصل': u'صَامِتٍSفَصْلٌ', #1
u'صاوير': u'صَاوِيرَ', #1
u'صائفون': u'صَائِفُونَ', #1
u'صائم،': u'صَائِمً،', #1
u'صاير': u'صَايِرٌ', #1
u'صباب': u'صِبَابِ', #2
u'صبات': u'صَبَّاتٍ', #1
u'صباحاه': u'صَباحَاهُ', #1
u'صباحاه': u'صُبَاحَاه', #1
u'صباحاه': u'صَبَاحَاهُ', #14
u'صباحاه': u'صَبَاحَاهْ', #16
u'صباحاه،': u'صَبَاحَاهُ،', #6
u'صباوة': u'صَبَاوَةَ', #1
u'صباوته': u'صَبَاوَتِهِ', #1
u'صببته': u'صَبَبْتُهُ', #5
u'صببته': u'صَبَبْته', #8
u'صببناها': u'صَبَبْنَاهَا', #1
u'صبة': u'صَبَّةٌ', #1
u'صبة': u'صَبَّةً', #23
u'صبتتصف': u'صبتتصف', #1
u'صبراء': u'صُبَرَاءَ', #1
u'صبرى': u'صَبْرَى', #1
u'صبكارند': u'صبكارند', #1
u'صبوب': u'صَبُوبٍ', #1
u'صبوب': u'صَبُوبٌ', #2
u'صبي': u'صَبِيًّ', #1
u'صبى': u'صِبَى', #1
u'صبى': u'صَبِىٌّ', #13
u'صبى': u'صَبِىٍّ', #17
u'صبى': u'صِبًى', #2
u'صبيانى': u'صِبْيَانِى', #1
u'صبيحتئذ،': u'صَبِيحَتَئِذٍ،', #1
u'صبيرة': u'صُبَيْرَة', #1
u'صبيرة': u'صُبَيْرَةَ', #7
u'صجقا': u'صجقا', #1
u'صحاء': u'صَحَّاءَ', #1
u'صحابتهاقوله': u'صَحَابَتَهَاقَوْلُهُ', #1
u'صحابتى': u'صَحَابَتِى', #2
u'صحابى': u'صَحَابِىٌّ', #1
u'صحابى': u'صَحَابِىٍّ', #1
u'صحابى': u'صَحَابِىُّ', #1
u'صحابى': u'صحابى', #2
u'صحارية': u'صُحَارِيّةٍ', #1
u'صحاريين': u'صَحَارِيَّيْنِ', #1
u'صحاريين': u'صَحَارِيّيْنِ', #1
u'صحاريين،': u'صُحَارِيَّيْنِ،', #1
u'صحاريين': u'صُحَارِيّيْنِ', #2
u'صحاصح': u'صَحاصَح', #1
u'صحاصح': u'صَحَاصِحْ', #1
u'صحائح': u'صَحَائِحُ', #1
u'صحائح': u'صَحَائِحِ', #1
u'صحائح': u'صَحَائِحْ', #1
u'صحبتالنبي': u'صَحِبْتَالنَّبِيَّ', #1
u'صحراة': u'صَحْرَاةٌ', #1
u'صحراة': u'صَحْرَاةً', #2
u'صحل': u'صَحَلَ', #1
u'صحل': u'صَحِلٍ', #1
u'صحل،': u'صَحَلٌ،', #1
u'صحل': u'صَحِلَ', #4
u'صحلت': u'صَحِلَتْ', #1
u'صحما': u'صُحْما', #1
u'صحما': u'صُحْمًا', #1
u'صحمة': u'صَحْمَةُ', #1
u'صحمة': u'صُحْمَةُ', #2
u'صحورا': u'صَحُورَا', #1
u'صحيبة،': u'صُحَيْبَةَ،', #1
u'صحيح': u'صَحِيحً', #1
u'صحيحلأن': u'صَحِيحٌلِأَنَّ', #1
u'صحيحيا': u'صَحِيحِيًّا', #1
u'صحيحية': u'صَحِيحِيَّةٍ', #1
u'صحيفتى': u'صَحِيفَتِى', #3
u'صحيفه': u'صَحِيفَهْ', #1
u'صخير،': u'صُخَيْرٍ،', #2
u'صخير': u'صُخَيْرٍ', #5
u'صخيرات': u'صُخَيْرَاتُ', #3
u'صخيرات': u'صُخَيْرَاتِ', #7
u'صداء': u'صُدَاءً', #1
u'صداء،': u'صُدَاءٌ،', #1
u'صداء،': u'صُدَاءٍ،', #1
u'صداء؟': u'صُدَاءَ؟', #1
u'صداء': u'صُدَاءٍ', #6
u'صداء': u'صُدَاءَ', #9
u'صداغ': u'صِدَاغٌ', #1
u'صداقى': u'صَدَاقِى', #1
u'صدائق': u'صَدَائِقِ', #1
u'صددرهم': u'صددرهم', #2
u'صدرى': u'صَدْرِى', #47
u'صدعة': u'صَدْعَةً', #1
u'صدعة': u'صِدْعَةً', #1
u'صدعتين': u'صَدْعتَيْنِ', #1
u'صدعين': u'صِدْعَيْنِ', #1
u'صدعين': u'صَدْعَيْنِ', #2
u'صدقاتكمقوله': u'صَدَقَاتِكُمْقَوْلُهُ', #1
u'صدقةاااا': u'صَدَقَةٍاااا', #1
u'صدقةيييي': u'صَدَقَةٌيييي', #1
u'صدقتهقوله': u'صَدَقَتَهُقَوْلُهُ', #1
u'صدقتى': u'صَدَقَتِى', #1
u'صدقتيني': u'صَدّقْتِينِي', #2
u'صدقوروي': u'صِدْقٍوَرُوِيَ', #1
u'صدكو': u'صدكو', #1
u'صدوع': u'صَدُوعَ', #1
u'صدوع': u'صُدُوعٌ', #2
u'صديع': u'صَدِيعُ', #1
u'صديع': u'صَدِيعِ', #1
u'صديعا': u'صَدِيعًا', #3
u'صديعها': u'صَدِيعَهَا', #1
u'صديغ': u'صَدِيغٌ', #1
u'صديقيته': u'صِدِّيقِيَّتُهُ', #1
u'صذ': u'صذ', #1
u'صراششصدي': u'صراششصدي', #1
u'صراصر': u'صَرَاصِرَ', #1
u'صراصر': u'صَرَاصِرُ', #3
u'صراه': u'صَرَاهُ', #1
u'صراه': u'صَرَّاهُ', #1
u'صراها': u'صَرَّاهَا', #1
u'صراوام': u'صراوام', #1
u'صرائح': u'صَرَائِحٌ', #1
u'صرائح': u'صَرَائِحَ', #24
u'صرائح': u'صَرَائِحِ', #31
u'صرائح': u'صَرَائِحُ', #65
u'صرائحه': u'صَرَائِحِهِ', #10
u'صرائحه': u'صَرَائِحَهُ', #5
u'صرائحه': u'صَرَائِحُهُ', #7
u'صرائحها': u'صَرَائِحَهَا', #1
u'صرائحها': u'صَرَائِحُهَا', #4
u'صرائحها': u'صَرَائِحِهَا', #5
u'صرآيد': u'صرآيد', #1
u'صربت': u'صَرَبَتْ', #1
u'صرج': u'صَرَّجَ', #1
u'صرح': u'صَرْحً', #2
u'صرحة': u'صَرْحَة', #1
u'صرخد': u'صَرْخَدُ', #2
u'صردة': u'صِرْدَةٌ', #1
u'صردح': u'صَرْدَحٍ', #1
u'صرغتمش': u'صَرْغَتْمَشَ', #2
u'صرفانا': u'صَرَفَانًا', #3
u'صرماء': u'صَرْمَاءَ', #2
u'صرورة': u'صَرُورَةَ', #14
u'صرورة': u'صَرُورَةٍ', #22
u'صرورة': u'صَرُورَةٌ', #23
u'صرورة': u'صَرُورَةً', #73
u'صروها': u'صُرُّوهَا', #1
u'صرى': u'صَرًى', #1
u'صرى': u'صَرَى', #1
u'صرى': u'صِرَّى', #3
u'صرى': u'صَرَّى', #8
u'صريت': u'صَرَيْت', #1
u'صريت': u'صُرِّيَتْ', #1
u'صريته': u'صَرَيْته', #1
u'صريج': u'صريج', #1
u'صصة': u'صَصَّةَ', #1
u'صصة': u'صِصَّةُ', #1
u'صصرى': u'صَصْرَى', #4
u'صط': u'صط', #3
u'صطاخية': u'صطاخية', #1
u'صعاء': u'صِعَاءُ', #1
u'صعبر': u'صعبر', #2
u'صعدب': u'صعدب', #1
u'صعر': u'صعر', #1
u'صعر': u'صَعَّرَ', #1
u'صعر': u'صَعَرٍ', #2
u'صعر': u'صُعْرٌ', #2
u'صعر': u'صُعْرَ', #2
u'صعر': u'صُعْرُ', #3
u'صعصة': u'صعصة', #1
u'صعصعة،': u'صعصعة،', #1
u'صعصعة،': u'صَعصَعة،', #1
u'صعصعة': u'صَعصَعَة', #1
u'صعصعة': u'صَعْصَعَةُ', #17
u'صعصعة': u'صَعْصَعَة', #2
u'صعصعة،': u'صَعْصَعَةَ،', #24
u'صعصعة': u'صعصعة', #25
u'صعصعة': u'صَعْصَعَةَ', #251
u'صعلة،': u'صَعْلَةُ،', #1
u'صعنبها': u'صَعْنَبَهَا', #1
u'صعو': u'صَعْوٍ', #1
u'صعوبا': u'صعوبا', #1
u'صعوة': u'صَعْوَةً', #1
u'صعوة': u'صَعْوَةٌ', #4
u'صعيدات': u'صَعِيدَاتِ', #1
u'صعير': u'صُعَيْر', #1
u'صعير': u'صعير', #12
u'صعير': u'صُعَيْرٍ', #59
u'صعير،': u'صُعَيْرٍ،', #7
u'صغا': u'صَغًا', #1
u'صغاء': u'صُغَاءَ', #1
u'صغار': u'صِغَارً', #1
u'صغدي': u'صغدي', #1
u'صغدى': u'صُغْدِىُّ', #2
u'صغرى': u'صُغْرًى', #2
u'صغير': u'صَغِيرً', #1
u'صفاة،': u'صَفَاةٍ،', #1
u'صفاة': u'صَفَاةٌ', #2
u'صفاة': u'صَفَاةٍ', #9
u'صفاف': u'صِفَافِ', #1
u'صفاف': u'صِفَافُ', #9
u'صفافهم': u'صِفَافَهُمْ', #3
u'صفافهم': u'صِفَافُهُمْ', #4
u'صفاقص': u'صَفَاقُصَ', #2
u'صفةالنار': u'صِفَةِالنَّارِ', #1
u'صفر': u'صَفَرً', #1
u'صفصفا': u'صَفْصَفًا', #5
u'صفورة': u'صَفُورَةَ', #1
u'صفورية': u'صَفُورِيَّةً', #1
u'صفورية': u'صَفُورِيَّةٍ', #1
u'صفورية': u'صَفُّورِيَةَ', #1
u'صفورية': u'صَفّورِيَةَ', #2
u'صفوقا': u'صُفُوقًا', #2
u'صفونا': u'صُفُونًا', #2
u'صقالبة': u'صَقَالِبَةٌ', #2
u'صقب': u'صَقَبُ', #2
u'صقبت': u'صَقِبَتْ', #1
u'صقبه؟': u'صَقَبُهُ؟', #1
u'صقراطا': u'صُقْرَاطًا', #2
u'صقلاب': u'صِقْلَابُ', #1
u'صقلاب': u'صِقْلَابِ', #1
u'صقلبي': u'صَقْلَبِيٌّ', #2
u'صقلة': u'صَقْلَةٌ', #1
u'صقيبة': u'صُقَيْبةً', #1
u'صقيبة': u'صُقَيْبَةً', #1
u'صقير': u'صُقَيْرٍ', #1
u'صقير،': u'صُقَيْرٍ،', #2
u'صكاكا': u'صِكَاكاً', #1
u'صكاكا': u'صَكَّاكًا', #1
u'صكاكا': u'صِكَاكًا', #1
u'صكة': u'صَكّةً', #1
u'صكة': u'صَكَّةَ', #1
u'صكة': u'صَكَّةُ', #1
u'صكة،': u'صَكَّةً،', #2
u'صكة': u'صَكّةَ', #5
u'صكة': u'صَكَّةً', #8
u'صكو': u'صكو', #1
u'صلاء': u'صِلَاءِ', #1
u'صلاءة': u'صَلَاءَةُ', #2
u'صلاب': u'صِلَابُ', #1
u'صلاب': u'صِلَابِ', #1
u'صلابه': u'صِلَابه', #1
u'صلابه': u'صِلَابُهْ', #2
u'صلاةالجمعة': u'صَلَاةِالْجُمْعَةِ', #1
u'صلاةالعيد': u'صَلَاةِالْعِيدِ', #2
u'صلاةالكسوف': u'صَلَاةِالْكُسُوفِ', #1
u'صلاةالنافلة': u'صَلَاةُالنَّافِلَةِ', #1
u'صلاةصلاها': u'صَلَاةٍصَلَّاهَا', #1
u'صلاتة': u'صَلاَتِةِ', #1
u'صلاتهالسرقة': u'صَلَاتَهُالسَّرِقَةُ', #1
u'صلاتى': u'صَلاَتِىَ', #1
u'صلاتى': u'صَلاَتِىِ', #1
u'صلاتى': u'صَلاَتَىِ', #12
u'صلاتى؟': u'صَلاَتِى؟', #2
u'صلاتى': u'صَلاَتِى', #43
u'صلاتية': u'صَلَاتِيَّةٌ', #20
u'صلاتية': u'صَلَاتِيَّةً', #37
u'صلاتية': u'صَلَاتِيَّةٍ', #5
u'صلاصل': u'صَلاصِلَ', #1
u'صلاصل': u'صَلَاصِلَ', #1
u'صلاية': u'صَلَايَةً', #1
u'صلبى': u'صلبى', #1
u'صلبى': u'صُلْبِى', #1
u'صلبيون': u'صُلْبِيُّونَ', #2
u'صلتة': u'صَلْتَة', #1
u'صلتة': u'صَلْتَةً', #1
u'صلتة،': u'صَلْتَةً،', #2
u'صلخد': u'صَلْخَدُ', #1
u'صلدد': u'صَلْدَدَ', #1
u'صلدد': u'صَلْدَدُ', #2
u'صلصله': u'صَلْصَلُهُ', #1
u'صلغها': u'صُلُّغُهَا', #1
u'صلق': u'صَلَقَ', #1
u'صلق': u'صَلْقٌ', #1
u'صلق': u'صَلْقِ', #1
u'صلق': u'صَلْقُ', #2
u'صلق': u'صُلِقَ', #20
u'صلقا': u'صَلْقًا', #1
u'صلقه': u'صَلَقَهُ', #1
u'صلقه': u'صَلْقَهُ', #2
u'صلقه': u'صَلْقِهِ', #6
u'صللعقيلي': u'صللعقيلي', #1
u'صلو': u'صُلُوِّ', #1
u'صلوبا': u'صلوبا', #1
u'صلوبا': u'صَلُوبًا', #1
u'صلوبا': u'صَلُوبَا', #12
u'صلوبا': u'صَلُوبا', #4
u'صلوة': u'صِلْوَةً', #1
u'صلوتا': u'صلوتا', #1
u'صلوتا': u'صِلْوَتَا', #1
u'صلوحيا': u'صُلُوحِيًّا', #4
u'صلوى': u'صَلَوَى', #2
u'صلويه': u'صَلَوَيْهِ', #1
u'صلىالله': u'صَلَّىاللَّهُ', #3
u'صلىبمسافرين': u'صَلَّىبِمُسَافِرِينَ', #1
u'صليتن': u'صَلَّيْتُنَّ', #4
u'صليح': u'صُلَيح', #1
u'صليح،': u'صُلَيْحٍ،', #2
u'صليح': u'صُلَيْحٍ', #4
u'صليحة': u'صُلَيْحَةَ', #1
u'صلىرجل': u'صَلَّىرَجُلٌ', #1
u'صليع': u'صليع', #1
u'صليع': u'صُلَيْعٌ', #1
u'صليع': u'صَلِيعٍ', #2
u'صليع،': u'صُلَيْعٍ،', #2
u'صليع': u'صُلَيْعٍ', #8
u'صلىعبد': u'صَلَّىعَبْدُ', #1
u'صلىعلى': u'صَلَّىعَلَى', #1
u'صلىفي': u'صَلَّىفِي', #1
u'صماخاتهم': u'صماخاتهم', #1
u'صماخى': u'صِمَاخَىِ', #1
u'صماخى': u'صِمَاخَىْ', #1
u'صمانة': u'صِمَّانَةِ', #1
u'صمحت': u'صَمَحْت', #1
u'صمحمحة': u'صَمَحْمَحَةٍ', #2
u'صمديته': u'صَمَدِيَّتِهِ', #5
u'صمصامة': u'صَمْصَامَةٍ', #2
u'صمعاء': u'صَمْعَاءَ', #2
u'صمعاء': u'صَمْعَاءُ', #3
u'صمعان': u'صَمْعَانَ', #1
u'صمعة': u'صَمْعَةَ', #7
u'صمعج': u'صَمْعَجَ', #1
u'صمعج': u'صمعج', #5
u'صمنيها': u'صَمَّنِيهَا', #1
u'صموخا': u'صَمُوخًا', #1
u'صموما': u'صُمُومًا', #1
u'صمومى': u'صُمُومَى', #2
u'صميد': u'صُمَيْدٌ', #1
u'صنابها': u'صِنَابُهَا', #2
u'صنابي': u'صِنَابِيٌّ', #2
u'صناجة': u'صَنَّاجَةً', #1
u'صناجة': u'صَنَّاجَةٌ', #1
u'صنادد': u'صَنَادِدُ', #1
u'صناعان': u'صَنَاعَانِ', #1
u'صنائعا': u'صَنَائِعًا', #2
u'صنبلا': u'صِنْبِلَا', #1
u'صنجات': u'صَنَجَاتُ', #1
u'صنجات': u'صَنَجَاتِ', #1
u'صنجاته': u'صَنَجَاتِهِ', #1
u'صنجاتهم': u'صَنَجَاتِهِمْ', #1
u'صنجة': u'صَنْجَة', #1
u'صنجة': u'صَنْجَةٌ', #1
u'صنجة': u'صَنْجَةٍ', #22
u'صنجة': u'صَنْجَةُ', #3
u'صنجة': u'صَنْجَةً', #6
u'صنجة': u'صَنْجَةَ', #7
u'صنجة': u'صَنْجَةِ', #9
u'صنجتان': u'صَنْجَتَانِ', #2
u'صندد': u'صَنْدَدَ', #2
u'صنصنرافر': u'صنصنرافر', #1
u'صنع': u'صُنْعً', #1
u'صنعتى': u'صَنْعَتِى', #1
u'صنفة': u'صَنِفَةُ', #1
u'صنفة': u'صَنِفَةِ', #1
u'صنفحيهلا': u'صنفحيهلا', #1
u'صنهاجة': u'صِنْهَاجَةَ', #1
u'صنوصاروراء': u'صنوصاروراء', #1
u'صنوى': u'صِنْوَى', #1
u'صهاب،': u'صُهاب،', #1
u'صهارا': u'صِهَارًا', #1
u'صهرة': u'صِهْرَةٌ', #2
u'صهرتي': u'صِهْرَتِي', #6
u'صهيبا': u'صهيبا', #1
u'صهيبا،': u'صُهَيْبًا،', #2
u'صهيبا': u'صُهَيْبًا', #30
u'صهيبة': u'صُهَيْبَةَ', #1
u'صهيرة': u'صُهَيْرَةَ', #3
u'صهيلة': u'صُهَيْلَةُ', #2
u'صؤاب،': u'صُؤَابٌ،', #1
u'صؤاب': u'صُؤَابٌ', #2
u'صؤاب': u'صُؤَابِ', #2
u'صؤاب': u'صُؤَابٍ', #4
u'صواحبات': u'صَوَاحِبَاتٍ', #1
u'صواحبات': u'صَوَاحِبَات', #2
u'صواحبات': u'صَوَاحِبَاتٌ', #2
u'صواحبات': u'صَوَاحِبَاتُ', #8
u'صواحباتها': u'صَوَاحِبَاتُهَا', #1
u'صواحباتها': u'صَوَاحِبَاتِهَا', #14
u'صواحباتي': u'صَوَاحِبَاتِي', #2
u'صواحبتها': u'صَوَاحِبَتِهَا', #1
u'صواحبى': u'صَوَاحِبِى', #5
u'صوارا': u'صُوَارًا', #2
u'صوارف': u'صَوَارِفَ', #1
u'صوارف': u'صَوَارِفِ', #1
u'صوارف': u'صَوَارِفُ', #2
u'صوارفها': u'صَوَارِفَهَا', #1
u'صواع': u'صُوَاعٌ', #1
u'صواع': u'صُوَاعَ', #9
u'صواعك': u'صُوَاعَكَ', #1
u'صواعي': u'صُوَاعِي', #2
u'صوافن': u'صَوَافِنُ', #1
u'صوافن': u'صَوَافِنْ', #2
u'صوافن': u'صَوَافِنَ', #4
u'صوافى': u'صَوَافِى', #1
u'صوالجة': u'صَوَالِجَةَ', #1
u'صوامة': u'صَوَّامَةً', #1
u'صوامة،': u'صَوَّامَةً،', #1
u'صوامة،': u'صَوَّامَةٌ،', #1
u'صوامة': u'صَوَّامَةٌ', #16
u'صوائج': u'صوائج', #1
u'صوتى': u'صَوْتِى', #15
u'صودة': u'صُودَةٍ', #1
u'صورتى': u'صُورَتِى', #1
u'صومى': u'صُوْمِى', #1
u'صومى': u'صَوْمِى', #2
u'صومى': u'صُومِى', #3
u'صومين': u'صَوِّمِينِ', #1
u'صومين': u'صَوْمَيْنِ', #18
u'صويحبات': u'صُوَيْحِبَاتُ', #1
u'صويحباتها': u'صُوَيْحِبَاتِهَا', #2
u'صويحباتي': u'صُوَيْحِبَاتِي', #2
u'صويراء': u'صُوَيْرَاءَ', #2
u'صئبان': u'صِئْبَانُ', #2
u'صئبانا': u'صِئْبَانًا', #1
u'صئبانه': u'صِئْبَانهِ', #1
u'صئبانه': u'صِئْبَانُهُ', #1
u'صئر': u'صِئْر', #1
u'صئر': u'صِئْرِ', #1
u'صئك': u'صَئِكَ', #1
u'صئولا': u'صَئُولًا', #1
u'صئيا': u'صَئِيّا', #1
u'صياب': u'صِيَابِ', #3
u'صيال': u'صِيَالٍ', #23
u'صيال': u'صِيَالٌ', #7
u'صيالا': u'صِيَالًا', #2
u'صيالته': u'صِيَالَتِهِ', #2
u'صياله': u'صِيَالُهُ', #1
u'صياله': u'صِيَالَهُ', #2
u'صياله': u'صِيَالِهِ', #26
u'صيالها': u'صِيَالُهَا', #1
u'صيالها': u'صِيَالِهَا', #2
u'صيان': u'صَيّانٍ', #1
u'صيان': u'صِيَانٌ', #3
u'صيائب': u'صَيَائِبُ', #2
u'صيحانيا': u'صِيحَانِيًّا', #1
u'صيحانيا': u'صَيْحَانِيًّا', #13
u'صيدين': u'صَيْدَيْنِ', #2
u'صيرة': u'صِيرَةٍ', #1
u'صيرة': u'صَيْرَةٍ', #1
u'صيصيته': u'صِيصِيَتَهُ', #2
u'صيفون': u'صَيْفُونٍ', #1
u'صيفى': u'صَيْفَى', #1
u'صيفى': u'صَيْفِىٌّ', #1
u'صيفى': u'صَيْفِىَّ', #1
u'صيفى': u'صَيْفِىِّ', #1
u'صيفى': u'صَيْفِىٍّ', #20
u'صيفيون': u'صَيْفِيّونْ', #1
u'صيقل': u'صَيْقَلٍ', #2
u'صيقلا': u'صَيْقَلًا', #1
u'صيقلي': u'صَيْقَلِي', #1
u'صيقلي': u'صَيْقَلِيٍّ', #1
u'صيلم': u'صَيْلَمٌ', #1
u'صيلما': u'صَيْلَمًا', #2
u'صيمر': u'صَيْمَرَ', #2
u'صيمرة': u'صَيْمَرَةَ', #1
u'صيود': u'صَيُودُ', #1
u'صيود': u'صُيُودِ', #1
u'صيود': u'صَيُودٍ', #12
u'صيود': u'صَيُودِ', #2
u'صيود': u'صَيُودٌ', #3
u'صيود': u'صُيُودٍ', #5
u'صيود': u'صُيُودٌ', #9
u'صيودا': u'صَيُودًا', #15
u'صيودا': u'صُيُودًا', #9
u'صيوده': u'صَيُودَهُ', #1
u'صيوده': u'صَيُودِهِ', #1
u'صيوده': u'صُيُودُهُ', #1
u'صيوده': u'صُيُودِهِ', #4
u'ضابط': u'ضَابِطً', #1
u'ضابئ': u'ضَابِئٍ', #2
u'ضابئ': u'ضَابِئُ', #2
u'ضاحت': u'ضَاحَتْ', #1
u'ضاربية': u'ضَارِبِيَّةُ', #1
u'ضارى': u'ضَارِى', #3
u'ضأس': u'ضَأْسٌ', #1
u'ضاطر': u'ضَاطِرَ', #1
u'ضاطر': u'ضَاطِرِ', #1
u'ضاطرة': u'ضَاطِرَةَ', #1
u'ضاقتك': u'ضَاقَتْك', #1
u'ضالتى': u'ضَالَّتِى', #1
u'ضاليين،': u'ضاليين،', #1
u'ضانا': u'ضَانًّا', #1
u'ضأنتين': u'ضَأْنَتَيْنِ', #1
u'ضائر': u'ضَائِرٌ', #1
u'ضائر': u'ضَائِرٍ', #21
u'ضائرا': u'ضَائِرًا', #1
u'ضائرة': u'ضَائِرَةٌ', #1
u'ضائرة': u'ضَائِرَةً', #4
u'ضائرة': u'ضَائِرَةٍ', #4
u'ضبأ': u'ضَبَأَ', #3
u'ضبابة': u'ضَبَابَة', #1
u'ضبابة': u'ضَبَابَةٍ', #1
u'ضبابة،': u'ضَبَابَةَ،', #1
u'ضبابة': u'ضُبَابَةَ', #2
u'ضبابة': u'ضَبَابَةٌ', #4
u'ضبابة': u'ضَبَابَةَ', #5
u'ضبات': u'ضَبَّاتٌ', #5
u'ضبارات': u'ضِبَارَاتٍ', #2
u'ضباعة': u'ضُباعة', #1
u'ضباعة': u'ضِبَاعَةَ', #1
u'ضباعة': u'ضُبَاعَةُ', #18
u'ضباعة': u'ضباعة', #3
u'ضباعة': u'ضُبَاعَة', #3
u'ضباعة': u'ضُبَاعَةَ', #96
u'ضباعين': u'ضُبَاعِينَ', #1
u'ضباعين': u'ضَبَاعِينَ', #2
u'ضباعين': u'ضَبَاعِينُ', #2
u'ضببوا': u'ضَبَّبُوا', #1
u'ضبث': u'ضَبَثَ', #6
u'ضبثت': u'ضَبَثَتْ', #1
u'ضبحة': u'ضَبْحَةً', #1
u'ضبطاء': u'ضَبْطَاءَ', #1
u'ضبطاء': u'ضَبْطَاءُ', #2
u'ضبعانات': u'ضُبْعَانَاتٍ', #1
u'ضبعانات': u'ضُبْعَانَاتٌ', #2
u'ضبعانان': u'ضَبُعَانَانِ', #1
u'ضبعانة': u'ضَبْعَانَةٌ', #1
u'ضبعت': u'ضَبَعَتْ', #1
u'ضبوب': u'ضَبُوبٌ', #2
u'ضبيب': u'ضُبَيْبٍ', #1
u'ضبيح': u'ضُبَيْحٍ', #1
u'ضبيرة': u'ضَبِيرَةُ', #1
u'ضبيرة': u'ضُبَيْرَة', #2
u'ضبيرة': u'ضُبَيْرَةَ', #22
u'ضبيس': u'ضُبيس', #1
u'ضبيس': u'ضُبَيْسٍ', #1
u'ضبيس': u'ضُبَيْسِ', #1
u'ضبيع': u'ضُبَيْعٍ', #1
u'ضبيعا': u'ضُبَيْعًا', #4
u'ضبيعة،': u'ضُبيعة،', #1
u'ضبيعة': u'ضبيعة', #2
u'ضبيعة': u'ضُبَيْعَة', #2
u'ضبيعة': u'ضُبَيْعَةُ', #3
u'ضبيعة،': u'ضُبَيْعَةَ،', #6
u'ضبيعة': u'ضُبَيْعَةَ', #62
u'ضبيغ': u'ضَبِيغِ', #1
u'ضبينه': u'ضَبِينِهِ', #1
u'ضجنان': u'ضَجْنان', #1
u'ضجنان': u'ضَجَنَانِ', #1
u'ضجنان': u'ضَجْنَانُ', #1
u'ضجنان': u'ضُجْنَانَ', #1
u'ضجنان': u'ضَجَنَانَ', #2
u'ضجنان': u'ضَجَنَانُ', #2
u'ضجنان': u'ضَجْنَانَ', #7
u'ضجيع': u'ضَجِيعٍ', #1
u'ضجيع': u'ضَجِيعُ', #1
u'ضجيعتي': u'ضَجِيعَتِي', #1
u'ضجيعك': u'ضَجِيعَك', #1
u'ضجيعك': u'ضَجِيعك', #2
u'ضجيعه': u'ضَجِيعُهُ', #1
u'ضجيعي': u'ضَجِيعَيْ', #1
u'ضجيعي': u'ضَجِيعِي', #1
u'ضجيعين': u'ضَجِيعَيْنِ', #1
u'ضحا': u'ضُحًا', #1
u'ضحر': u'ضَحْرٍ', #1
u'ضحضاح': u'ضحضاح', #1
u'ضحضاح': u'ضَحْضَاحِ', #1
u'ضحضاح': u'ضَحْضَاحٍ', #26
u'ضحضاح': u'ضَحْضَاحَ', #3
u'ضحكى': u'ضَحِكِى', #1
u'ضحلة': u'ضَحْلَةٍ', #1
u'ضرابون': u'ضَرّابُونَ', #3
u'ضرات': u'ضِرَّاتٌ', #1
u'ضرات': u'ضَرَّاتٍ', #3
u'ضرارافضاروا': u'ضِرَارًافَضَارُوا', #1
u'ضرارة': u'ضَرَارَةِ', #1
u'ضرارة': u'ضَرَارَةٍ', #2
u'ضرارته': u'ضَرَارَتَهُ', #7
u'ضراسها': u'ضِرَاسِهَا', #1
u'ضربتنى': u'ضَرَبَتْنِى', #1
u'ضربتيني': u'ضَرَبْتِينِي', #1
u'ضربنى': u'ضَرَبَنِى', #9
u'ضربى': u'ضَرْبِى', #1
u'ضرر': u'ضَرَرً', #1
u'ضرزما': u'ضِرْزِمَا', #1
u'ضرغامة': u'ضِرْغَامَةَ', #6
u'ضرغامين': u'ضِرْغَامَيْنِ', #2
u'ضرغد': u'ضَرْغَدِ', #1
u'ضرغم': u'ضَرْغَمٌ', #1
u'ضرغمين': u'ضَرْغَمَيْنِ', #1
u'ضروة': u'ضِرْوَةٍ', #1
u'ضروة': u'ضِرْوَةَ', #1
u'ضرور': u'ضَرُورُ', #2
u'ضريط': u'ضُرّيْطٌ', #1
u'ضط': u'ضط', #1
u'ضعا': u'ضَعًّا', #1
u'ضعائف': u'ضَعَائِفَ', #1
u'ضعفى': u'ضِعْفَىْ', #1
u'ضعفى': u'ضَعْفَى', #2
u'ضعفينقوله': u'ضِعْفَيْنِقَوْلُهُ', #2
u'ضعى': u'ضَعِى', #1
u'ضغاطر': u'ضغاطر', #1
u'ضغبوس': u'ضُغْبُوسٌ', #2
u'ضغيف': u'ضغيف', #1
u'ضفارة': u'ضَفَارَةَ', #2
u'ضفرة': u'ضفرة', #1
u'ضفرة': u'ضَفَرَةٌ', #1
u'ضفرتين': u'ضَفْرَتَيْنِ', #1
u'ضك': u'ضك', #1
u'ضلالا': u'ضَلًالًا', #3
u'ضلالقوله': u'ضَلالٍقَوْلُهُ', #1
u'ضلول': u'ضَلُولْ', #1
u'ضمارتها': u'ضِمَارَتَهَا', #1
u'ضمامة': u'ضِمَامَةٌ', #3
u'ضمضما': u'ضَمْضَمًا', #3
u'ضمعج': u'ضَمْعَجَ', #1
u'ضمعج،': u'ضَمْعَج،', #1
u'ضمعج': u'ضَمْعَجٍ', #17
u'ضمعج،': u'ضَمْعَجٍ،', #4
u'ضمعج،أنه': u'ضَمْعَجٍ،أَنَّهُ', #1
u'ضمى': u'ضُمِّى', #2
u'ضميرة': u'ضَمِيرَةُ', #1
u'ضميرة،': u'ضُمَيْرَةَ،', #1
u'ضميرة': u'ضُمَيْرَةَ', #26
u'ضميرة': u'ضُمَيْرةَ', #3
u'ضميرة': u'ضُمَيْرَةُ', #6
u'ضنء': u'ضِنْءُ', #1
u'ضنء': u'ضَنْءِ', #2
u'ضنء': u'ضِنْءِ', #2
u'ضنة': u'ضِنَةً', #2
u'ضنوب،': u'ضَنُوبٌ،', #2
u'ضه': u'ضَهْ', #1
u'ضهده': u'ضَهَدَهُ', #1
u'ضوارى': u'ضَوَارِىَ', #2
u'ضوج': u'ضَوْجُ', #1
u'ضوج': u'ضَوْجٍ', #2
u'ضوجي': u'ضَوْجَيْ', #3
u'ضوضوا': u'ضَوْضَوْا', #3
u'ضوطري': u'ضَوْطَرَي', #1
u'ضويدة': u'ضُوَيْدَةُ', #1
u'ضى': u'َضَى', #1
u'ضى': u'َضِىَ', #2
u'ضئت': u'ضئت', #1
u'ضئضيء': u'ضِئْضِيء', #1
u'ضئضئ': u'ضَئْضَئِ', #1
u'ضئضئ': u'ضِئْضِئُ', #1
u'ضئضئ': u'ضِئْضِئِ', #17
u'ضئضئ': u'ضِئْضِئ', #2
u'ضئضئا': u'ضِئْضِئًا', #1
u'ضئضئه': u'ضِئْضِئِهِ', #2
u'ضئضئي': u'ضِئْضِئِي', #1
u'ضئين': u'ضَئِينٍ', #1
u'ضئين': u'ضَئِينٌ', #2
u'ضياءنور': u'ضِيَاءَنُورٍ', #1
u'ضياح': u'ضياح', #1
u'ضياح': u'ضَيَاحَ', #1
u'ضياح': u'ضَيّاحٍ', #2
u'ضياح': u'ضَيّاحِ', #5
u'ضيار': u'ضِيَارٍ', #1
u'ضيح': u'ضَيْحَ', #1
u'ضيح': u'ضَيْحُ', #1
u'ضيح': u'ضِيَحِ', #1
u'ضيح': u'ضَيْح', #119
u'ضيح': u'ضَيْحٍ', #4
u'ضيزن': u'ضَيْزَنٍ', #1
u'ضيزى': u'ضِيزَى', #4
u'ضيفانا': u'ضِيفَانًا', #1
u'ضيق': u'ضَيِّقً', #1
u'ضيمران': u'ضَيْمَرَانٌ', #1
u'طء': u'طْءُ', #2
u'طا': u'طا', #2
u'طا': u'طَا', #3
u'طاالأرض': u'طاالأرض', #1
u'طابة،': u'طَابَةٌ،', #1
u'طابة،': u'طَابَةَ،', #1
u'طابة،': u'طَابَةُ،', #1
u'طابة': u'طَابَةُ', #11
u'طابة': u'طَابَةَ', #15
u'طابة': u'طَابَةٌ', #2
u'طابقات': u'طَابِقَاتُ', #1
u'طابو': u'طابو', #2
u'طابو': u'طَابُو', #22
u'طاحية،': u'طَاحِيَةَ،', #1
u'طاحية': u'طَاحِيَةَ', #2
u'طاخ': u'طَاخٌ', #1
u'طاخية': u'طَاخِيَةٌ', #1
u'طارقت': u'طَارَقَتْ', #1
u'طارقت': u'طَارَقْت', #1
u'طارقت': u'طَارَقْتُ', #1
u'طارمة': u'طَارِمَةٍ', #1
u'طافاه': u'طَافَاهُ', #1
u'طافئة': u'طَافِئَةٌ', #2
u'طاقاتالوجه': u'طَاقَاتٌالْوَجْهُ', #1
u'طالبأن': u'طَالِبٍأَنَّ', #1
u'طالببعث': u'طَالِبٍبَعَثَ', #1
u'طالق': u'طَالِقً', #1
u'طالقات': u'طَالِقَاتٌ', #1
u'طالوت،': u'طالوت،', #1
u'طالوت،': u'طَالُوتُ،', #1
u'طالوت،': u'طَالُوتَ،', #14
u'طالوت': u'طَالُوتَ', #18
u'طالوت': u'طَالُوتُ', #18
u'طالوت': u'طالوت', #4
u'طاليس': u'طَالِيسُ', #1
u'طاليس': u'طَالِيسَ', #5
u'طانجة': u'طانجة', #3
u'طاهرية': u'طَاهِرِيَّةَ', #1
u'طاهريته': u'طَاهِرِيَّتَهُ', #1
u'طاهريته': u'طَاهِرِيَّتِهِ', #1
u'طاوس': u'طَاوُسُ', #1
u'طاوس،': u'طَاوُس،', #1
u'طاوس،': u'طَاوُسَ،', #1
u'طاوس،': u'طَاوُسُ،', #1
u'طاوس': u'طَاوُسٌ', #128
u'طاوس': u'طَاوُس', #2
u'طاوس،': u'طَاوُسٍ،', #214
u'طاوس': u'طاوس', #3
u'طاوس': u'طَاوُسَ', #3
u'طاوس': u'طَاوُسِ', #8
u'طاوس،': u'طَاوُسٌ،', #8
u'طاوس': u'طَاوُسٍ', #880
u'طاوسا،': u'طَاوُسًا،', #6
u'طاوسا': u'طَاوُسًا', #97
u'طاوسأن': u'طَاوُسٍأَنَّ', #1
u'طاوس،أن': u'طَاوُسٍ،أَنَّ', #1
u'طاوسي': u'طَاوُسِيٌّ', #1
u'طآئفة': u'طَآئِفَةً', #1
u'طآئفة': u'طَآئِفَةٌ', #3
u'طآئفة': u'طَّآئِفَةٌ', #3
u'طآئفتان': u'طَّآئِفَتَانِ', #1
u'طباراء': u'طَبَارَاءَ', #1
u'طباطبا': u'طَبَاطَبَا', #2
u'طباقاء': u'طَبَاقَاءُ', #2
u'طباهجة': u'طُبَاهَجَةً', #1
u'طباهجة': u'طُبَاهَجَةَ', #1
u'طبة': u'طَبّةٍ', #1
u'طبخاتون': u'طَبْخَاتُونُ', #1
u'طبخة': u'طَبْخَةً', #8
u'طبخة': u'طَبْخَةٍ', #85
u'طبر': u'طَبَرٌ', #1
u'طبراني': u'طَبَرَانِيّ', #1
u'طبراني': u'طَبَرَانِيٌّ', #10
u'طبرزد': u'طَبَرْزَد', #1
u'طبرزد': u'طَبَرْزَدَ', #4
u'طبرزين': u'طَبَرْزِينَ', #1
u'طبرزين': u'طَبَرْزِينُ', #2
u'طبرستان': u'طبرستان', #1
u'طبرستان،': u'طبرستان،', #1
u'طبرستان،': u'طَبَرِسْتان،', #1
u'طبرستان': u'طَبَرَسْتَانَ', #1
u'طبرستان،': u'طَبَرِسْتَانَ،', #1
u'طبرستان': u'طَبَرِسْتَانَ', #24
u'طبرستان': u'طَبَرِسْتَانُ', #3
u'طبري': u'طَبَرِيّ', #1
u'طبري': u'طَبَرِيٌّ', #1
u'طبري': u'طَبَرِيُّ', #1
u'طبريا': u'طبريا', #1
u'طبرية': u'طبرية', #1
u'طبرية': u'طَبَرِيَّة', #1
u'طبرية': u'طَبَرِيَّةُ', #1
u'طبرية،': u'طَبَرِيَّةَ،', #1
u'طبرية': u'طَبَرِيَّةَ', #16
u'طبرية': u'طَبَرِيّةَ', #3
u'طبرية': u'طَبَرِيَّةِ', #3
u'طبرية': u'طَبَرِيَّةً', #4
u'طبرية': u'طَبَرِيَّةٍ', #4
u'طبرية': u'طَبَرِيَّةٌ', #6
u'طبفت،': u'طَبَّفْتُ،', #1
u'طبلاوي': u'طَبَلَاوِيٌّ', #20
u'طبنة': u'طُبْنَةَ', #3
u'طبوع': u'طَبُوعٌ', #1
u'طبوع': u'طَبُوعٍ', #2
u'طبوع': u'طُبُوعٌ', #2
u'طبوع': u'طُبُوعٍ', #5
u'طبولات': u'طُبُولَاتٍ', #1
u'طبى': u'طُبْىُ', #1
u'طبيعا': u'طَبِيعًا', #1
u'طبيق': u'طُبَيْقٌ', #1
u'طت': u'طت', #1
u'طحا': u'طَحَا', #1
u'طحاها': u'طَحَاهَا', #5
u'طحاوي': u'طَحَاوِيّ', #1
u'طحاوي': u'طَحَاوِيٍّ', #1
u'طحاوي': u'طَحَاوِيٌّ', #10
u'طحطاوي': u'طَحْطَاوِيّ', #1
u'طحطاوي': u'طَحْطَاوِيٌّ', #30
u'طحفة': u'طِحْفَةَ', #2
u'طحنة': u'طَحْنَةٍ', #1
u'طحياء': u'طَحْيَاءَ', #1
u'طحيل': u'طُحَيْلِ', #1
u'طحينة': u'طَحِينَةً', #1
u'طحينة': u'طَحِينَةٌ', #1
u'طحينته': u'طَحِينَتُهُ', #1
u'طخ': u'طخ', #8
u'طخاء': u'طَخَاءٌ', #1
u'طخاء': u'طَخَاءً', #3
u'طخارستان،': u'طَخَارِستان،', #1
u'طخفة': u'طِخْفَةَ', #17
u'طخفة': u'طخفة', #2
u'طخفة': u'طَخْفَةُ', #4
u'طخفة،': u'طِخْفَةَ،', #5
u'طخمة': u'طَخْمَةَ', #1
u'طخياء': u'طَخْيَاءَ', #2
u'طخية': u'طُخْيَةٌ', #2
u'طخية': u'طُخْيَةِ', #3
u'طخيخي': u'طَخِّيخِيٌّ', #1
u'طخيم': u'طُخَيْمٌ', #1
u'طرءان': u'طَرَءَانِ', #4
u'طرابا': u'طِرَابًا', #1
u'طراحة': u'طَرَّاحَةٌ', #1
u'طراحة': u'طَرَّاحَةً', #3
u'طراحة': u'طَرَّاحَةٍ', #3
u'طراحته': u'طَرَّاحَتِهِ', #2
u'طراخم': u'طَرَاخِمٌ', #1
u'طرار': u'طِرَارِ', #1
u'طرار': u'طَرَّارٌ', #2
u'طرار': u'طَرَّارٍ', #3
u'طرار': u'طَرَارٍ', #4
u'طرارا': u'طَرَّارًا', #1
u'طرآن': u'طَرَآنُ', #1
u'طرآن': u'طَرَآنِ', #2
u'طرايا': u'طَرَايَا', #1
u'طربة': u'طَرْبَةِ', #1
u'طربة': u'طَرِبَةٌ', #2
u'طربة': u'طَرْبَةٍ', #3
u'طربة': u'طَرِبَةٍ', #4
u'طربزوني': u'طربزوني', #2
u'طرثوث': u'طُرْثُوثٌ', #1
u'طرخال': u'طَرْخَالَ', #2
u'طرخان،': u'طَرْخَانَ،', #3
u'طرخان': u'طَرْخَانَ', #4
u'طرخون': u'طَرَخُونُ', #1
u'طرخون': u'طَرَخُونَ', #2
u'طرخي': u'طَرْخِيّ', #1
u'طرسوس،': u'طَرَسُوسٍ،', #1
u'طرسوس،': u'طَرَسُوسَ،', #2
u'طرسوس': u'طَرَسُوسَ', #5
u'طرسوسي': u'طَرْسُوسِيٌّ', #5
u'طرطوس': u'طَرَطُوسَ', #2
u'طرطوشة': u'طَرْطُوشَةُ', #1
u'طرطوشة': u'طُرْطُوشَةَ', #1
u'طرطوشة': u'طَرْطُوشَةَ', #6
u'طرطوشي': u'طُرْطُوشِيٌّ', #1
u'طرطيرا': u'طِرْطِيرًا', #1
u'طرفى': u'طَرَفَىِ', #10
u'طرفى': u'طَرَفَىْ', #2
u'طرقنى': u'طَرَقَنِى', #1
u'طرم': u'طَرْمٌ', #1
u'طرمساء': u'طِرْمِسَاءِ', #2
u'طروا': u'طُرُوًّا', #5
u'طروقة': u'طَرُوقَة', #2
u'طروقة': u'طَرُوقَةَ', #2
u'طروقة': u'طَرُوقَةُ', #29
u'طروقة': u'طَرُوقَةِ', #4
u'طروقتا': u'طَرُوقَتَا', #17
u'طروقتها': u'طَرُوقَتِهَا', #2
u'طرى': u'طَرَّى', #1
u'طريانا': u'طَرَيَانًا', #1
u'طريانه': u'طَرَيَانُه', #1
u'طريانه': u'طَرَيَانُهُ', #7
u'طريانه': u'طَرَيَانِهِ', #7
u'طريانها': u'طَرَيَانُهَا', #3
u'طريانها': u'طَرَيَانِهَا', #3
u'طريانهما': u'طَرَيَانِهِمَا', #1
u'طريخم': u'طُرَيْخِمٌ', #1
u'طزه': u'طزه', #3
u'طساس': u'طساس', #1
u'طساس': u'طِسَاسُ', #1
u'طساس': u'طِسَاسٌ', #4
u'طساسيج': u'طَسَاسِيجَ', #1
u'طسم': u'طسم', #16
u'طسم': u'طَسْمٌ', #2
u'طسم': u'طَسْمٍ', #5
u'طسما': u'طَسْمًا', #1
u'طسوج': u'طُسُوجٌ', #1
u'طسوج': u'طُسُوجٍ', #1
u'طسوجا': u'طَسُوجًا', #1
u'طسوجا': u'طَسُّوجًا', #2
u'طسوجات': u'طَسُّوجَاتٍ', #2
u'طسوس': u'طُسُوسٍ', #1
u'طسيسة': u'طُسَيْسَةُ', #1
u'طشتا': u'طَشْتًا', #11
u'طص': u'طص', #3
u'طصس': u'طصس', #1
u'طط': u'طط', #22
u'ططر': u'ططر', #1
u'ططص': u'ططص', #4
u'ططك': u'ططك', #1
u'ططن': u'طَطَنٍ', #1
u'طعامى': u'طَعَامِى', #3
u'طعرة': u'طَعْرَةَ', #1
u'طعنتنى': u'طَعَنْتَنِى', #1
u'طعها': u'َطَعَهَا', #1
u'طعيم': u'طُعَيِّمٌ', #1
u'طعيما،': u'طُعَيْمًا،', #1
u'طعيمة': u'طُعَيْمَةَ', #11
u'طعيمة': u'طُعَيْمَة', #2
u'طعيمة': u'طُعَيْمَةُ', #9
u'طعين': u'طَعِينٌ', #1
u'طعين،': u'طَعِينٌ،', #1
u'طعينا': u'طَعِينًا', #1
u'طغام': u'طَغَامٌ', #1
u'طغام': u'طَغَامَ', #1
u'طغامة': u'طَغَامَةٍ', #1
u'طغامه': u'طُغَامِهِ', #1
u'طغتكين': u'طغتكين', #1
u'طغتكين': u'طُغْتِكِينَ', #1
u'طغفة': u'طِغْفَةَ', #4
u'طغياناوروي': u'طُغْيَانًاوَرُوِيَ', #1
u'طفافا': u'طِفَافًا', #1
u'طففا': u'طَفَفًا', #1
u'طفى': u'طُفًى', #2
u'طفى': u'طُفَى', #3
u'طفى': u'طفى', #416
u'طفية': u'طُفْيَة', #1
u'طفية': u'طُفْيَةٌ', #1
u'طفية': u'طُفْيَةٍ', #2
u'طفيتين': u'طُفْيَتَيْنِ', #4
u'طفيل': u'طَفِيلٌ', #1
u'طفيل': u'طَفِيلٍ', #1
u'طفيل': u'طَفِيلِ', #1
u'طفيل': u'طُفَيْلُ', #13
u'طفيل': u'طُفَيْلٍ', #16
u'طفيل': u'طُفَيْلِ', #6
u'طفيل': u'طُفَيْلٌ', #8
u'طفيلا': u'طُفَيْلا', #1
u'طفيلا': u'طُفَيْلًا', #2
u'طقز': u'طقز', #1
u'طقز': u'طَقَزَ', #2
u'طقفة': u'طِقْفَةَ', #1
u'طك': u'طك', #12
u'طكط': u'طكط', #5
u'طلاءة': u'طِلَاءَةٌ', #1
u'طلاطلة': u'طُلَاطِلَةٌ', #1
u'طلاغ': u'طَلَاغ', #1
u'طلاغ': u'طَلَاغٍ', #2
u'طلاقم': u'طلاقم', #1
u'طلاقى': u'طَلاَقِى', #6
u'طلائح': u'طَلَائِحُ', #2
u'طلبو': u'طَلَبُو', #1
u'طلحون': u'طَلَحُونَ', #3
u'طلختها': u'طَلَخْتُهَا', #2
u'طلخها': u'طَلَخَهَا', #2
u'طلقتكها': u'طَلَّقْتُكَهَا', #1
u'طلقنى': u'طَلِّقْنِى', #1
u'طلقنى': u'طَلَّقَنِى', #14
u'طلوعالشمس': u'طُلُوعِالشَّمْسِ', #1
u'طليب': u'طليب', #1
u'طليب': u'طُلَيْبٌ', #2
u'طليب': u'طُلَيْبِ', #3
u'طليب': u'طُلَيْبُ', #8
u'طليبا': u'طَلِيبًا', #1
u'طليبا': u'طُلَيْبًا', #1
u'طليبة': u'طَلِيبَةً', #1
u'طليح': u'طَلِيحٌ', #1
u'طليحا': u'طَلِيحًا', #1
u'طليع': u'طليع', #1
u'طمرات': u'طِمِرّاتِ', #2
u'طمرة': u'طِمِرّةٌ', #1
u'طمرة': u'طِمِرّةِ', #1
u'طمرة': u'طِمِرَّةٌ', #1
u'طمرة': u'طِمِرَّةٍ', #1
u'طمرة': u'طِمرّة', #2
u'طمرة': u'طِمِرّةً', #2
u'طمرة': u'طِمِرّةٍ', #6
u'طمطم': u'طَمْطَمُ', #1
u'طمطماني': u'طُمْطُمَانِيّ', #1
u'طمغا': u'طمغا', #1
u'طمغاج': u'طمغاج', #1
u'طمغاج،': u'طَمْغَاجَ،', #1
u'طمغاجي': u'طمغاجي', #2
u'طمغاجية': u'طمغاجية', #2
u'طمل': u'طِمْلٍ', #3
u'طنابيب': u'طَنَابِيبَ', #1
u'طنبار': u'طَنْبَارٌ', #1
u'طنبار': u'طِنْبَارٌ', #1
u'طنبار': u'طِنْبَارٍ', #1
u'طنبى': u'طُنُبَىِ', #2
u'طنة': u'طُنَّةٌ', #1
u'طندتا': u'طَنْدَتَا', #1
u'طندتائي': u'طَنْدَتَائِيٌّ', #2
u'طنوب': u'طَنُوبٌ', #1
u'طهارى': u'طَهَارَى', #1
u'طهرنى': u'طَهِّرْنِى', #24
u'طهرين': u'طُهْرَيْنِ', #25
u'طهفة': u'طِهْفَةَ', #5
u'طهمان': u'طهمان', #1
u'طهمان': u'طُهْمَانَ', #1
u'طهمان،': u'طَهْمَانٍ،', #1
u'طهمان': u'طَهْمَانَ', #222
u'طهمان،': u'طهمان،', #3
u'طهمان': u'طَهْمَانُ', #4
u'طهمان،': u'طَهْمَانَ،', #92
u'طهمورث': u'طهمورث', #1
u'طهوريتين': u'طَهُورِيَّتَيْنِ', #1
u'طواء': u'طُوَاءٍ', #1
u'طواء': u'طِوَاءٍ', #1
u'طواءهما': u'طَوَاءَهُمَا', #1
u'طوابيق': u'طَوَابِيقِ', #1
u'طوابيقها': u'طَوَابِيقُهَا', #1
u'طواشي': u'طَوَاشِي', #1
u'طواشيا': u'طَوَاشِيًا', #1
u'طواف': u'طَوَافً', #1
u'طواقي': u'طَوَّاقِيٌّ', #1
u'طوالات': u'طُوَالَاتُ', #1
u'طوالات': u'طُوَالَاتِ', #1
u'طوالة': u'طوالة', #1
u'طوالة': u'طَوَالَةَ', #1
u'طوالة': u'طُوَالَة', #1
u'طوالة': u'طُوَالَةً', #2
u'طوالة': u'طُوَالَةَ', #23
u'طوالة،': u'طُوَالَةَ،', #8
u'طوانا': u'طَوَّانًا', #1
u'طوانة': u'طَوَّانَةَ', #1
u'طوائر': u'طَوَائِرُ', #1
u'طوائر': u'طَوَائِرَ', #2
u'طوبس': u'طُوبَسَ', #1
u'طوخي': u'طُوخِيٍّ', #1
u'طوخي': u'طُوخِيٌّ', #9
u'طوطي': u'طُوطِيٍّ', #1
u'طوطيا': u'طوطيا', #1
u'طوعاالوجه': u'طَوْعًاالْوَجْهُ', #2
u'طوعاوالوجه': u'طَوْعًاوَالْوَجْهُ', #1
u'طوفات': u'طَوْفَاتٍ', #1
u'طوفانة': u'طُوفَانَةٌ', #1
u'طوفة': u'طَوْفَةً', #3
u'طوفة': u'طَوْفَةٍ', #39
u'طوفة': u'طَوْفَةٌ', #5
u'طوفى': u'طُوفِى', #5
u'طوقانشاه،': u'طوقانشاه،', #1
u'طوقتيه': u'طُوِّقْتِيهِ', #1
u'طوكر': u'طوكر', #1
u'طولالمكث': u'طُولِالْمُكْثِ', #1
u'طولون': u'طُولُونَ', #7
u'طومارا': u'طُومَارًا', #1
u'طومان': u'طُومَانَ', #4
u'طونس': u'طَوْنَسُ', #3
u'طونسا': u'طَوَنْسًا', #1
u'طويرة': u'طُوَيْرَةٌ', #1
u'طويس': u'طُوَيْسٍ', #1
u'طويس،': u'طُوَيْسٍ،', #1
u'طويس': u'طُوَيْسٌ', #3
u'طويط': u'طُوَيْطٍ', #1
u'طويلالصرف': u'طَوِيلٍالصَّرْفُ', #1
u'طيء': u'طيء', #1
u'طيء': u'طيّء', #1
u'طيء': u'طَيِّءٌ', #1
u'طيء': u'طَيْءٍ', #1
u'طيء،': u'طَيِّء،', #1
u'طيء،': u'طَيْءٍ،', #1
u'طيء،': u'طيّء،', #2
u'طيء': u'طَيِّءٍ', #3
u'طيء': u'طَيّءٍ', #4
u'طئها': u'طِئَهَا', #1
u'طئوا': u'طَئُوا', #2
u'طئوه': u'طَئُوهُ', #1
u'طياب': u'طِيَابِ', #1
u'طيالة': u'طيالة', #1
u'طيالسية': u'طَيَالِسِيَّةٌ', #1
u'طيبتنى': u'طَيَّبَتْنِى', #2
u'طيسلة،': u'طَيْسَلَةَ،', #1
u'طيسلة': u'طَيْسَلَةُ', #2
u'طيسلة': u'طَيْسَلَةَ', #8
u'طيشة': u'طَيْشَةٌ', #1
u'طيفور،': u'طيفور،', #1
u'طيفور': u'طَيْفُورُ', #2
u'طيفور': u'طَيْفُورٍ', #3
u'طيلس': u'طَيْلَسَ', #1
u'طيلسة': u'طَيْلَسَةَ', #1
u'طيلها': u'طِيلهَا', #1
u'طيلها': u'طِيلَهَا', #1
u'طيلها': u'طِيلِهَا', #2
u'طيلها': u'طِيَلَهَا', #4
u'طيلها': u'طِيَلِهَا', #4
u'طيما': u'طيما', #1
u'طينوروي': u'طِينٌوَرُوِيَ', #1
u'طينوروي': u'طِينٍوَرُوِيَ', #1
u'طيوب': u'طُيُوبٌ', #1
u'طيوليات': u'طُيُولِيَّاتِ', #1
u'طيولية': u'طُيُولِيَةٌ', #2
u'طيولية': u'طُيُولِيَّةٌ', #2
u'طيئ،': u'طيئ،', #1
u'طيئ': u'طَيّئَ', #1
u'طيئ': u'طَيِّئ', #1
u'طيئ': u'طَيْئٍ', #1
u'طيئ،': u'طَيِّئٍ،', #1
u'طيئ': u'طَيّئُ', #2
u'طيئ': u'طَيِّئٌ', #2
u'طيئ': u'طَيّئٍ', #36
u'طيئ': u'طَيّئ', #4
u'طيئ': u'طَيِّئٍ', #52
u'طيئ': u'طيئ', #6
u'طيئا': u'طَيّئًا', #4
u'طيئا': u'طَيِّئًا', #4
u'ظالمى': u'ظَالِمِى', #3
u'ظاهر': u'ظَاهِرً', #1
u'ظاهراوروي': u'ظَاهِرًاوَرُوِيَ', #1
u'ظباتها': u'ظُبَاتُهَا', #1
u'ظباتهن': u'ظُبَاتِهِنّ', #2
u'ظبة': u'ظُبَةٍ', #1
u'ظبة': u'ظُبَةَ', #3
u'ظبته': u'ظُبَتِهِ', #2
u'ظبى': u'ظَبْىٌ', #5
u'ظبين': u'ظُبِينَ', #2
u'ظت': u'ظت', #2
u'ظخز': u'ظخز', #1
u'ظربة': u'ظِرْبَةٍ', #1
u'ظررة': u'ظُرَرَةً', #1
u'ظرفيته': u'ظَرْفِيَّتُهُ', #1
u'ظرفيته': u'ظَرْفِيَّتَهُ', #2
u'ظرفيته': u'ظَرْفِيَّتِهِ', #4
u'ظرفيتها': u'ظَرْفِيَّتِهَا', #2
u'ظريب': u'ظُرَيْبٍ', #1
u'ظعانه': u'ظِعَانِهِ', #1
u'ظعائنا': u'ظَعَائِنًا', #1
u'ظعائنا': u'ظَعَائِنَا', #2
u'ظعاينه': u'ظَعَايِنَهُ', #1
u'ظفيرة': u'ظفيرة', #1
u'ظفيرتان': u'ظفيرتان', #1
u'ظفيرتان': u'ظَفِيرَتَانِ', #1
u'ظلمانية': u'ظُلْمَانِيَّةً', #1
u'ظلمنى': u'ظَلَمَنِى', #3
u'ظلى': u'ظِلِّى', #5
u'ظمآنا': u'ظَمْآنًا', #4
u'ظمعن': u'ظَمَعْنُ', #1
u'ظميا': u'ظُمْيًا', #1
u'ظميئا': u'ظَمِيئَا', #1
u'ظنا': u'ظَنًّاً', #1
u'ظنهوالوجه': u'ظَنِّهِوَالْوَجْهُ', #1
u'ظنى': u'ظَنِّى', #12
u'ظنياته': u'ظَنِّيَّاتِهِ', #1
u'ظنيته': u'ظَنِّيَّتَهُ', #1
u'ظنيته': u'ظَنِّيَّتِهِ', #2
u'ظنيته': u'ظَنِّيَّتُهُ', #4
u'ظنيتها': u'ظَنِّيَّتَهَا', #1
u'ظنيتهما': u'ظَنِّيَّتِهِمَا', #1
u'ظهاران': u'ظِهَارَانِ', #2
u'ظهارين': u'ظِهَارَيْنِ', #38
u'ظهاريه': u'ظِهَارَيْهِ', #2
u'ظهراء': u'ظُهَرَاءُ', #2
u'ظهرانى': u'ظَهْرَانِىْ', #1
u'ظهرانى': u'ظَهْرَانَىْ', #4
u'ظهرانى': u'ظَهْرَانَىِ', #9
u'ظهرانيا': u'ظَهْرَانِيًّا', #1
u'ظهرانيكم': u'ظَهْرَانَيْكُمُ', #1
u'ظهرانيكم': u'ظَهْرَانَيْكُمْ', #1
u'ظهرانيكم': u'ظَهْرَانِيكُمْ', #3
u'ظهرانينا،': u'ظَهْرَانَيْنَا،', #1
u'ظهرانينا': u'ظَهْرَانِينَا', #2
u'ظهرانينا': u'ظَهْرَانَيْنَا', #3
u'ظهرانيه': u'ظَهْرَانَيْهِ', #3
u'ظهرانيهم،': u'ظَهْرَانِيهِمْ،', #1
u'ظهرانيهم': u'ظَهْرَانِيهِمْ', #12
u'ظهرانيهم': u'ظَهْرَانَيْهِمْ', #16
u'ظوأما': u'ظوَأَمّا', #1
u'ظئر': u'ظِئْرَ', #1
u'ظئر': u'ظئر', #2
u'ظئر': u'ظِئْرٍ', #30
u'ظئر': u'ظِئْرٌ', #5
u'ظئر': u'ظِئْرُ', #5
u'ظئر': u'ظِئْرِ', #9
u'ظئرا': u'ظئرًا', #1
u'ظئرا': u'ظِئْرًا', #81
u'ظئران': u'ظِئْرَانِ', #3
u'ظئرك': u'ظِئْرَكَ', #1
u'ظئره،': u'ظِئْرَهُ،', #1
u'ظئره': u'ظِئْرَهُ', #3
u'ظئره': u'ظِئْرُهُ', #4
u'ظئره': u'ظِئْرِهِ', #7
u'ظئرها': u'ظِئْرَهَا', #1
u'ظئري': u'ظِئْرَيْ', #1
u'ظئري': u'ظِئْرِي', #1
u'ظئرى': u'ظِئْرَى', #1
u'ظئرين': u'ظِئْرَيْنِ', #10
u'ظئورة': u'ظُئُورَةُ', #1
u'عأ': u'عَأْ', #4
u'عا': u'عَا', #7
u'عابرى': u'عَابِرِى', #4
u'عاتقى': u'عَاتِقَىْ', #1
u'عاتقى؟': u'عَاتِقِى؟', #1
u'عاتكة': u'عاتِكَة', #1
u'عاتكة': u'عَاتِكَةٌ', #1
u'عاتكة': u'عَاتِكَةِ', #1
u'عاتكة،': u'عَاتِكَةُ،', #1
u'عاتكة': u'عَاتِكَة', #2
u'عاتكة': u'عاتكة', #3
u'عاتكة،': u'عَاتِكَةَ،', #3
u'عاتكة': u'عَاتِكَةَ', #45
u'عاتكة': u'عَاتِكَةُ', #60
u'عاثورا': u'عَاثُورًا', #6
u'عاثوراء': u'عَاثُورَاءَ', #2
u'عاجة': u'عَاجَةٌ', #1
u'عاجة': u'عَاجَّةٌ', #1
u'عاجر': u'عَاجِرٌ', #1
u'عادانيها': u'عَادَانِيهَا', #4
u'عادنى': u'عَادَنِى', #8
u'عاديتكها': u'عَادَيْتُكَهَا', #1
u'عاذلSوفيها': u'عَاذِلِSوَفِيهَا', #1
u'عاربت': u'عاربت', #1
u'عارضيا': u'عَارِضِيًّا', #12
u'عارضية': u'عَارِضِيَّةً', #1
u'عارضية': u'عَارِضِيَّةٌ', #1
u'عارضية': u'عَارِضِيَّةٍ', #1
u'عارضية': u'عَارِضِيَّةِ', #1
u'عاروة': u'عَارِوَةٌ', #2
u'عارووة': u'عَارُووَةٌ', #2
u'عاريت': u'عَارَيْت', #6
u'عازبأن': u'عَازِبٍأَنَّ', #1
u'عازك': u'عَازَك', #1
u'عازك': u'عَازّك', #1
u'عازهم': u'عَازَّهُمْ', #1
u'عازوا': u'عَازُوا', #2
u'عاشه': u'عَاشَهُ', #2
u'عاشها': u'عَاشَهَا', #2
u'عاصشم': u'عَاصِشمٌ', #1
u'عاصم': u'عَاصِمً', #2
u'عاطب': u'عَاطِبٍ', #2
u'عاطشة': u'عَاطِشَةٌ', #1
u'عاطنا،': u'عَاطِنَا،', #1
u'عأعأ': u'عَأْعَأْ', #1
u'عاعا': u'عاعا', #1
u'عافانى': u'عَافَانِى', #1
u'عافصه': u'عَافَصَهُ', #1
u'عافنى': u'عَافِنِى', #1
u'عافيةالوجه': u'عَافِيَةًالْوَجْهُ', #1
u'عافيتنى': u'عَافَيْتَنِى', #1
u'عاقدى': u'عَاقِدِى', #2
u'عالمقوله': u'عالمقوله', #1
u'عام': u'عَامً', #1
u'عامد': u'عَامِدً', #1
u'عاملتنى': u'عَامَلْتَنِى', #1
u'عاملى': u'عَامِلِى', #3
u'عامود': u'عَامُودٍ', #1
u'عامى': u'عَامِى', #5
u'عامئذ': u'عامئذٍ', #1
u'عامئذ': u'عَامَئِذٍ', #8
u'عانتى': u'عَانَتِى', #2
u'عاندSحكمة': u'عَانِدُSحِكْمَةُ', #1
u'عاننت': u'عَانَنْتُ', #1
u'عاهان': u'عَاهَانَ', #1
u'عاهان،': u'عَاهَانَ،', #1
u'عاودنى': u'عَاوَدَنِى', #1
u'عاى': u'عاى', #1
u'عائذابالله': u'عَائِذًابِاللَّهِ', #1
u'عائر': u'عائِرٌ', #1
u'عائر،': u'عَائِرٌ،', #1
u'عائر': u'عَائِرٌ', #10
u'عائر': u'عَائِرٍ', #3
u'عائر': u'عَائِرُ', #3
u'عائرا': u'عَائِرًا', #1
u'عائشةأن': u'عَائِشَةُأَنْ', #1
u'عائشةأنها': u'عَائِشَةَأَنَّهَا', #1
u'عائشةعن': u'عَائِشَةَعَنِ', #1
u'عائط': u'عَائِط', #1
u'عائط': u'عَائِطٌ', #1
u'عائف': u'عَائِفٌ', #2
u'عائفا،': u'عَائِفًا،', #1
u'عائفا': u'عَائِفًا', #5
u'عائن': u'عَائِنٌ', #2
u'عائن': u'عَائِنٍ', #5
u'عائنا': u'عَائِنًا', #1
u'عايا': u'عَايَا', #1
u'عاياه': u'عَايَاهُ', #1
u'عبادان': u'عَبّادَانَ', #1
u'عبادان': u'عَبَّادَانُ', #1
u'عبادان': u'عَبَّادَانَ', #29
u'عبادان': u'عَبَّادَانِ', #6
u'عبادتهوالوجه': u'عِبَادَتَهُوَالْوَجْهُ', #1
u'عبادكا17673id': u'عبادكا17673id', #1
u'عبادكا': u'عِبَادُكَا', #1
u'عبادكا': u'عِبَادِكَا', #2
u'عبادكا': u'عُبّادِكَا', #4
u'عبادل': u'عَبَادِلَ', #1
u'عبادل،': u'عَبَادِلَ،', #1
u'عبادى؟': u'عِبَادِىَ؟', #1
u'عبادى': u'عِبَادِىَ', #3
u'عبادى': u'عِبَادِى', #35
u'عباديد': u'عَبَادِيدَ', #1
u'عباديد': u'عَبَادِيدُ', #1
u'عباس': u'عَبَّاسً', #1
u'عباسابتلاه': u'عَبَّاسٍابْتَلاهُ', #1
u'عباسأخبر': u'عَبَّاسٍأَخْبَرَ', #1
u'عباسالأعمال': u'عَبَّاسٍالأَعْمَالُ', #1
u'عباسالحمد': u'عَبَّاسٍالْحَمْدُ', #3
u'عباسالفواحش،': u'عَبَّاسٍالْفَوَاحِشَ،', #1
u'عباسالكتاب': u'عَبَّاسٍالْكِتَابُ', #1
u'عباسإن': u'عَبَّاسٍإِنْ', #1
u'عباسأن': u'عَبَّاسٍأَنَّ', #16
u'عباسإن': u'عَبَّاسٍإِنَّ', #3
u'عباسأنه': u'عَبَّاسٍأَنَّهُ', #2
u'عباسأوفوا': u'عَبَّاسٍأَوْفُوا', #1
u'عباسأول': u'عَبَّاسٍأَوَّلُ', #1
u'عباسترك': u'عَبَّاسٍتَرَكَ', #1
u'عباسخلق': u'عَبَّاسٍخَلَقَ', #1
u'عباسرضى': u'عَبَّاسٍرَضِىَ', #1
u'عباسعن': u'عَبَّاسٍعَنِ', #4
u'عباسفأرسل': u'عَبَّاسٍفَأَرْسَلَ', #1
u'عباسفألقى': u'عَبَّاسٍفَأَلْقَى', #1
u'عباسفأمره': u'عَبَّاسٍفَأَمَرَهُ', #1
u'عباسفأنزل': u'عَبَّاسٍفَأَنْزَلَ', #3
u'عباسفبينما': u'عَبَّاسٍفَبَيْنَمَا', #1
u'عباسفلما': u'عَبَّاسٍفَلَمَّا', #5
u'عباسفلو': u'عَبَّاسٍفَلَوِ', #1
u'عباسقال': u'عَبَّاسٍقَالَ', #2
u'عباسقالوا': u'عَبَّاسٍقالوا', #1
u'عباسقرأ': u'عَبَّاسٍقَرَأَ', #1
u'عباسكان': u'عَبَّاسٍكَانَ', #3
u'عباسلما': u'عَبَّاسٍلَمَّا', #1
u'عباسليست': u'عَبَّاسٍلَيْسَتِ', #1
u'عباسما': u'عَبَّاسٍمَا', #2
u'عباسنسخت': u'عَبَّاسٍنَسَخَتْ', #1
u'عباسنعبد': u'عَبَّاسٍنَعْبُدُ', #1
u'عباسنفقة': u'عَبَّاسٍنَفَقَةُ', #1
u'عباسوأعلم': u'عَبَّاسٍوَأَعْلَمَ', #1
u'عباسوإنما': u'عَبَّاسٍوَإِنَّمَا', #1
u'عباسوشاورهم': u'عَبَّاسٍوَشَاوِرْهُمْ', #1
u'عباسوغير': u'عَبَّاسٍوَغَيْرِ', #1
u'عباسوقست': u'عَبَّاسٍوَقَسَتْ', #1
u'عباسيسأله': u'عَبَّاسٍيَسْأَلُهُ', #1
u'عباسيستحب': u'عَبَّاسٍيَسْتَحِبُّ', #1
u'عباسيقول': u'عَبَّاسٍيَقُولُ', #3
u'عبالة': u'عَبَالَةَ', #2
u'عبالة': u'عَبَالَةٍ', #4
u'عبالة': u'عَبَالَةِ', #4
u'عبالته': u'عَبَالَتِهِ', #1
u'عبالته': u'عَبَالَتَهُ', #5
u'عبالته': u'عَبَالَتُهُ', #7
u'عبة': u'ُعْبَةُ', #1
u'عبثر': u'عبثر', #1
u'عبثر،': u'عبثر،', #1
u'عبثر': u'عَبْثَرَ', #1
u'عبثر،': u'عَبْثَرٍ،', #1
u'عبثر،': u'عَبْثَرٌ،', #16
u'عبثر': u'عَبْثَرُ', #18
u'عبثر': u'عَبْثَرٍ', #2
u'عبثر': u'عَبْثَرِ', #2
u'عبثر،': u'عَبْثَرُ،', #2
u'عبثر': u'عَبْثَرٌ', #24
u'عبدالجبار': u'عَبْدِالْجَبَّارِ', #4
u'عبدالحكم': u'عَبْدِالْحَكَمِ', #1
u'عبدالحميد': u'عَبْدِالْحَمِيدِ', #1
u'عبدالرحمن،': u'عبدالرحمن،', #1
u'عبدالرحمن': u'عَبْدِالرَّحْمَنِ', #2
u'عبدالسلام': u'عَبْدِالسَّلاَمِ', #1
u'عبدالعزيز': u'عَبْدِالْعَزِيزِ', #1
u'عبدالله،': u'عَبْدَاللَّهِ،', #1
u'عبدالله': u'عَبْدِاللَّهِ', #12
u'عبدالله': u'عَبْدُاللَّهِ', #2
u'عبدالله': u'عبدالله', #5
u'عبدالوهاب': u'عبدالوهاب', #1
u'عبدالوهاب': u'عَبْدُالْوَهَّابِ', #1
u'عبدالوهاب': u'عَبْدِالْوَهَّابِ', #1
u'عبداؤك': u'عِبِدّاؤُكَ', #1
u'عبداؤنا': u'عِبْدَاؤُنَا', #1
u'عبدرية': u'عَبْدَرِيَّةً', #1
u'عبدسى': u'عَبْدَسِىٍّ', #1
u'عبدل': u'عَبْدَلٌ', #1
u'عبدل': u'عَبْدَلٍ', #2
u'عبدلي': u'عَبْدَلِيٌّ', #1
u'عبدم': u'عَبْدَمِ', #1
u'عبدود': u'عَبْدُودِ', #1
u'عبدود': u'عَبْدُودٍ', #2
u'عبدوس': u'عبدوس', #1
u'عبدوس': u'عَبْدُوسٌ', #1
u'عبدوس': u'عَبْدَوْسُ', #1
u'عبدوس': u'عَبْدُوسُ', #10
u'عبدوس': u'عُبْدُوسٍ', #132
u'عبدوس': u'عَبْدُوسِ', #16
u'عبدوس': u'عُبْدُوسُ', #16
u'عبدوس': u'عَبْدُوسٍ', #1679
u'عبدوس': u'عَبْدُوسَ', #2
u'عبدوس': u'عُبْدُوسَ', #2
u'عبدوس': u'عَبْدَوْسَ', #2
u'عبدوس،': u'عُبْدُوسٍ،', #3
u'عبدوس': u'عُبْدُوسِ', #4
u'عبدوس،': u'عَبْدُوسٍ،', #6
u'عبدون': u'عَبْدُونَ', #3
u'عبدويه،': u'عَبْدَوَيْهِ،', #1
u'عبدويه،': u'عَبْدُوَيْهِ،', #1
u'عبدويه': u'عَبْدَوَيْهِ', #2
u'عبدويه': u'عَبْدُوَيْهِ', #2
u'عبدى': u'عَبْدِى', #86
u'عبديته': u'عَبْدِيَّتَهُ', #1
u'عبديته': u'عَبْدِيَّتُهُ', #1
u'عبديته': u'عَبْدِيَّتِهِ', #1
u'عبذان': u'عَبْذَانُ', #1
u'عبرةقوله': u'عِبْرَةًقَوْلُهُ', #1
u'عبسين': u'عَبْسِينَ', #11
u'عبعب': u'عَبْعَبٌ', #1
u'عبقرى': u'عَبْقَرِىٌّ', #1
u'عبقرى': u'عَبْقَرِىٍّ', #1
u'عبل': u'عَبْلُ', #2
u'عبل': u'عَبْلَ', #6
u'عبلا': u'عَبْلًا', #1
u'عبلات': u'عَبَلَاتٌ', #1
u'عبلات': u'عَبَلَاتٍ', #1
u'عبلة': u'عَبْلَةً', #10
u'عبهلة،': u'عَبْهَلَةُ،', #1
u'عبهلة': u'عَبْهَلَةَ', #2
u'عبود': u'عُبُودٌ', #1
u'عبود': u'عَبُّودٍ', #2
u'عبوق': u'عُبُوقِ', #1
u'عبوق': u'عُبُوقُ', #2
u'عبيدالله': u'عُبَيْدُاللَّهِ', #1
u'عبيدالله': u'عُبَيْدِاللَّهِ', #1
u'عبيدان،': u'عبيدانَ،', #1
u'عبيدان': u'عُبَيْدَانِ', #24
u'عبيدان': u'عُبَيْدَانَ', #625
u'عبيدعن': u'عُبَيْدٍعَنْ', #1
u'عبيدكمو': u'عبيدكمو', #1
u'عبيس': u'عبيس', #1
u'عبيس،': u'عُبَيْسٍ،', #2
u'عبيس': u'عُبَيْسٌ', #3
u'عبيس': u'عُبَيْسُ', #3
u'عبيس': u'عُبَيْسٍ', #4
u'عبيسا': u'عُبَيْسًا', #1
u'عبيل': u'عِبِيلٍ', #1
u'عبيل': u'عِبِيلِ', #1
u'عبيلة': u'عُبَيْلَةَ', #1
u'عت': u'عَتٍّ', #1
u'عت': u'عت', #5
u'عتابة': u'عَتَّابَةَ', #1
u'عتاث': u'عِتَاثٍ', #1
u'عتائر': u'عَتَائِرُ', #2
u'عتائق': u'عَتَائِقُ', #2
u'عتبى': u'عُتْبَى', #1
u'عتة': u'عِتَّةَ', #1
u'عتر': u'عِتَرٍ', #1
u'عتر': u'عِتَرِ', #1
u'عتر': u'عَتَرَ', #10
u'عتر': u'عِتْرِ', #3
u'عتر،': u'عِتْرٍ،', #5
u'عتر': u'عِتْرٍ', #6
u'عترا': u'عَتْرًا', #1
u'عترت': u'عَتَرْتُ', #1
u'عتريس': u'عِتْرِيسُ', #1
u'عتريس': u'عِتْرِيسٌ', #2
u'عتريس': u'عِتْرِيسِ', #5
u'عتق': u'عَتْقً', #1
u'عتقاء': u'عُتَقَاءَ', #18
u'عتقاء': u'عُتَقَاءِ', #21
u'عتقاء': u'عُتَقَاء', #4
u'عتقاء': u'عُتَقَاءُ', #60
u'عتقاءه': u'عُتَقَاءَهُ', #2
u'عتقاؤه': u'عُتَقَاؤُهُ', #2
u'عتقاؤها': u'عُتَقَاؤُهَا', #1
u'عتقاؤهم': u'عُتَقَاؤُهُمْ', #1
u'عتقاي،': u'عُتَقَاي،', #1
u'عتقائه': u'عُتَقَائِهِ', #18
u'عتقائها': u'عُتَقَائِهَا', #1
u'عتقائهم': u'عُتَقَائِهِمْ', #2
u'عتقائي': u'عُتَقَائِي', #10
u'عتقى': u'عَتْقَى', #1
u'عتقين': u'عِتْقَيْنِ', #3
u'عتكت': u'عَتَكَتْ', #1
u'عتوارة': u'عُتْوَارَةَ', #1
u'عتوة': u'عُتُوَّةً', #1
u'عتود،': u'عَتُودٌ،', #1
u'عتود': u'عِتْوَدُ', #1
u'عتود': u'عَتُودٌ', #12
u'عتود': u'عَتُود', #2
u'عتودا': u'عَتُودًا', #8
u'عتودة': u'عَتُودَةٌ', #1
u'عتودة': u'عَتْوَدَةَ', #1
u'عتودة': u'عَتْوَدة', #2
u'عتودة': u'عَتَوْدَة', #2
u'عتودة': u'عَتْوَدَةُ', #2
u'عتور': u'عِتْوَرٌ', #1
u'عتويرة': u'عتويرة', #1
u'عتويس': u'عَتْوِيسَ', #1
u'عتى': u'عُتَىٌّ', #1
u'عتى': u'عُتَىِّ', #1
u'عتى': u'عَتَى', #2
u'عتى': u'عُتَىٍّ', #3
u'عتيب': u'عُتَيْبُ', #4
u'عتية': u'عُتَيّة', #1
u'عتيرة': u'عَتِيرَةٍ', #1
u'عتيرة،': u'عَتِيرَةَ،', #1
u'عتيرة': u'عَتِيرَةً', #12
u'عتيرة': u'عَتِيرَةٌ', #2
u'عتيرة': u'عَتِيرَةَ', #35
u'عتيرة': u'عَتِيرَة', #4
u'عثاكلها': u'عَثَاكِلُهَا', #1
u'عثام': u'عَثَّامِ', #1
u'عثام': u'عَثَّامُ', #12
u'عثام': u'عَثَّامٌ', #3
u'عثام،': u'عَثَّامٌ،', #3
u'عثام': u'عَثَّامٍ', #6
u'عثامة': u'عُثَامَةَ', #1
u'عثامنة': u'عَثَامِنَةٌ', #1
u'عثامنة': u'عَثَامِنَةً', #2
u'عثامنة': u'عَثَامِنَةَ', #2
u'عثامنة': u'عَثَامِنَةٍ', #5
u'عثان': u'عُثَانٌ', #2
u'عثانينكم': u'عَثَانِينَكُمْ', #2
u'عثانينهم': u'عَثَانِينَهُمْ', #2
u'عثة': u'عُثَّةٍ', #4
u'عثعث': u'عَثْعَثٍ', #1
u'عثعث': u'عَثْعَثٌ', #3
u'عثعثا': u'عَثْعَثًا', #1
u'عثكال': u'عَثْكَالٍ', #1
u'عثكال': u'عِثْكَالٍ', #1
u'عثكالا': u'عِثْكَالا', #1
u'عثكالا': u'عِثْكَالاً', #1
u'عثكالا': u'عِثْكَالًا', #2
u'عثكالا': u'عُثْكَالًا', #6
u'عثل': u'عَثَلٍ', #2
u'عثل': u'عَثِلٌ', #2
u'عثل': u'عَثْلٌ', #2
u'عثل': u'عَثْلٍ', #24
u'عثل': u'عَثَلٌ', #5
u'عثلة': u'عُثْلَةُ', #2
u'عثم': u'عَثَمٍ', #1
u'عثم': u'عَثْمٌ', #2
u'عثم': u'عَثْمٍ', #8
u'عثما': u'عَثْمًا', #1
u'عثما': u'عُثِمَا', #1
u'عثمانلو': u'عُثْمَانُلَوْ', #1
u'عثمانوروي': u'عُثْمَانُوَرُوِيَ', #1
u'عثمانين': u'عُثْمَانَيْنِ', #1
u'عثمة،': u'عثمة،', #1
u'عثمة،': u'عَثْمَةُ،', #1
u'عثمة،': u'عَثْمَةَ،', #12
u'عثمة': u'عَثْمَةَ', #13
u'عثمثم': u'عَثَمْثَمُ', #1
u'عثنون': u'عُثْنُونٍ', #1
u'عثنونه': u'عُثْنُونُه', #1
u'عثنونه': u'عُثْنُونَهُ', #5
u'عثنونها': u'عُثْنُونُهَا', #1
u'عثوثل': u'عَثَوْثَلٍ', #2
u'عثيم': u'عثيم', #1
u'عثيم،': u'عُثَيْمٍ،', #1
u'عثيم': u'عُثَيْمٌ', #2
u'عثيم': u'عُثَيْمُ', #2
u'عثيم': u'عُثَيْمٍ', #5
u'عثيم': u'عُثَيْمِ', #7
u'عثيمة': u'عُثَيْمَةَ', #2
u'عجاجيل': u'عَجَاجِيلٌ', #1
u'عجاجيل': u'عَجَاجِيلٍ', #2
u'عجاجيل': u'عَجَاجِيلُ', #3
u'عجاجيل': u'عَجَاجِيلَ', #6
u'عجاجيلها': u'عجاجيلها', #1
u'عجافSعن': u'عِجَافِSعَنْ', #1
u'عجرة': u'عجرة', #2
u'عجرة': u'عُجْرة', #2
u'عجرة،': u'عُجْرة،', #2
u'عجرة': u'عَجْرَةَ', #2
u'عجرة': u'عُجْرَة', #2
u'عجرة،': u'عُجْرَةَ،', #29
u'عجرة': u'عُجْرَةَ', #303
u'عجرة،أن': u'عُجْرَةَ،أَنّ', #1
u'عجرة،أنه': u'عُجْرَةَ،أَنَّهُ', #1
u'عجرد': u'عَجْرَدُ', #1
u'عجرد،': u'عَجْرَدٍ،', #1
u'عجرد': u'عَجْرَدٍ', #6
u'عجزاء': u'عَجْزَاءُ', #3
u'عجلنى': u'عَجَّلَنِى', #2
u'عجمى': u'عَجَمِىٍّ', #1
u'عجوبا': u'عُجُوبًا', #1
u'عجورا': u'عَجُّورًا', #1
u'عجورة': u'عَجُّورَةً', #1
u'عجوم': u'عَجُومٍ', #1
u'عجوم': u'عُجُومٍ', #1
u'عجونة': u'عُجُونَةٌ', #1
u'عجير': u'عُجَيْرٌ', #1
u'عجير،': u'عُجَيْرٍ،', #1
u'عجير': u'عُجَيْرٍ', #10
u'عجير': u'عُجَيْرِ', #5
u'عجيف': u'عُجَيْفٍ', #1
u'عجيف': u'عَجِيفٌ', #2
u'عجيف': u'عَجِيفٍ', #2
u'عجيل': u'عُجَيْل', #1
u'عجيل': u'عُجَيْلُ', #1
u'عجيل': u'عُجَيْلٍ', #126
u'عجيل': u'عُجَيْلٌ', #4
u'عجيم': u'عُجَيْمٌ', #1
u'عجيما': u'عجيماً', #1
u'عدات': u'عِدَاتٌ', #1
u'عدات': u'عِدَاتٍ', #1
u'عداس،': u'عَدَّاسٌ،', #1
u'عداس': u'عَدّاسٌ', #19
u'عداس': u'عَدَّاسٍ', #2
u'عداس': u'عَدَّاسُ', #2
u'عداس': u'عَدَّاسٌ', #3
u'عداس': u'عَدّاسٍ', #5
u'عداس': u'عَدّاسُ', #7
u'عداسا،': u'عَدَّاسًا،', #1
u'عداسا': u'عَدّاسًا', #2
u'عداوه': u'عَدَاوَهْ', #1
u'عدتى': u'عِدَّتِى', #6
u'عدثان': u'عُدْثان', #1
u'عدثان': u'عُدْثَانُ', #1
u'عدثان': u'عُدْثَانَ', #4
u'عدر': u'عُدَرُ', #1
u'عدرا': u'عَدْرَا', #1
u'عدلتان': u'عِدْلَتَانِ', #2
u'عدلتان': u'عَدْلَتَانِ', #7
u'عدلتين': u'عِدْلَتَيْنِ', #1
u'عدلتين': u'عَدْلَتَيْنِ', #18
u'عدم': u'عَدَمً', #1
u'عدملي': u'عدملي', #1
u'عدملي': u'عُدْمِلِيّ', #2
u'عدمين': u'عَدْمَيْنِ', #1
u'عدناء': u'عَدْنَاءَ', #1
u'عدوات': u'عَدُوَّاتِ', #4
u'عدوم': u'عَدُومٍ', #1
u'عدوهمو': u'عَدُوَّهُمُو', #1
u'عدوى': u'عَدْوًى', #1
u'عدىحدثنا': u'عَدِىٍّحَدَّثَنَا', #1
u'عديس،': u'عُدَيْسٍ،', #1
u'عديس': u'عُدَيْسٍ', #2
u'عديس': u'عديس', #3
u'عديس': u'عُدَيْس', #3
u'عديسة': u'عُدَيْسَةَ', #2
u'عذابى': u'عَذَابِى', #3
u'عذارة': u'عَذَارَةُ', #1
u'عذارتها': u'عَذَارَتُهَا', #1
u'عذافر': u'عُذَافِرٍ', #1
u'عذافرة': u'عُذَافِرَةٌ', #3
u'عذاقا': u'عِذَاقًا', #3
u'عذاقها': u'عِذَاقَهَا', #1
u'عذاقها،': u'عِذَاقَهَا،', #1
u'عذرى': u'عُذْرِى', #1
u'عذما': u'عَذْمًا', #1
u'عذمها': u'عَذَمَهَا', #1
u'عذو': u'عَذْوٍ', #1
u'عذوب': u'عُذُوبٌ', #1
u'عذوبا': u'عُذُوبًا', #1
u'عذوط': u'عَذْوَطَ', #2
u'عذي': u'عِذْيُ', #1
u'عذيب': u'عذيب', #1
u'عذيب': u'عَذِيبِ', #1
u'عذيب': u'عُذَيْب', #1
u'عذيب': u'عُذَيْبِ', #1
u'عذيب': u'عُذَيْبٍ', #2
u'عذيبها': u'عُذَيْبِهَا', #2
u'عذير': u'عَذِيرٌ', #2
u'عذير': u'عَذِيرَ', #3
u'عذيرا': u'عَذِيرًا', #1
u'عذيرة': u'عَذِيرَة', #1
u'عذيرة': u'عَذِيرَةً', #1
u'عذيرة': u'عَذِيرَةٌ', #1
u'عذيرك': u'عَذِيرَك', #1
u'عذيرك': u'عَذِيرَكَ', #1
u'عذيرك': u'عَذِيرُك', #2
u'عذيره': u'عَذِيرَهُ', #1
u'عذيري': u'عَذِيرِي', #3
u'عذيط': u'عَذْيَطَ', #2
u'عذيوط': u'عِذْيَوْطٌ', #2
u'عذيوطا': u'عِذْيَوْطًا', #2
u'عذيوطة': u'عِذْيَوْطَةً', #1
u'عذيوطة': u'عِذْيَوْطَةٌ', #3
u'عرادة': u'عَرَّادَةً', #1
u'عرادة،': u'عَرَادَةَ،', #1
u'عرادة': u'عَرَادَةَ', #3
u'عراصة': u'عَرّاصَةً', #1
u'عراهية': u'عَرَاهِيَةً', #1
u'عراو': u'عَرَاوٌّ', #1
u'عرائسا': u'عَرَائِسَا', #1
u'عرباض': u'عِرْبَاضُ', #1
u'عرباض': u'عِرْبَاضِ', #12
u'عرباض': u'عِرْبَاضٌ', #4
u'عرباض،وهو': u'عِرْبَاضُ،وَهُوَ', #1
u'عربى': u'عَرَبِىٍّ', #18
u'عربى': u'عَرَبِىٌّ', #5
u'عربيل': u'عَرْبِيلَ', #1
u'عرتة': u'عرتة', #2
u'عرد': u'عَرَدَ', #1
u'عرد': u'عَرَّد', #1
u'عرد': u'عَرَّدَ', #3
u'عرد': u'عَرّدَ', #6
u'عردت': u'عَرَّدَتُ', #1
u'عردت': u'عَرّدَتْ', #3
u'عرزب': u'عرزب', #1
u'عرزب،': u'عرزب،', #1
u'عرزب': u'عَرْزَب', #2
u'عرزب': u'عَرْزَبٍ', #2
u'عرزة': u'عَرَزَةَ', #1
u'عرزة،': u'عَرَزَةَ،', #1
u'عرسة': u'عِرْسَةٌ', #1
u'عرسى': u'عُرُسِى', #2
u'عرسى': u'عُرْسِى', #3
u'عرص': u'عَرِصُ', #1
u'عرص': u'عَرْصُ', #2
u'عرصا': u'عَرِصًا', #1
u'عرصه': u'عرصه', #2
u'عرضنى': u'عَرَضَنِى', #7
u'عرضي': u'عَرَضِيًّ', #1
u'عرضى': u'عِرْضِى', #1
u'عرطابة': u'عَرْطَابَةٍ', #3
u'عرطبة': u'عَرْطَبَةٍ', #1
u'عرطليل': u'عَرْطَلِيلٍ', #1
u'عرعا': u'عرعا', #1
u'عرعرة': u'عرعرة', #1
u'عرعرة': u'عَرْعَرَةُ', #2
u'عرعرة،': u'عرعرة،', #3
u'عرعرة،': u'عَرْعَرَةَ،', #30
u'عرعرة': u'عَرْعَرَةَ', #41
u'عرعور': u'عُرْعُورٌ', #1
u'عرفابخنهء': u'عرفابخنهء', #1
u'عرفاتا': u'عَرَفَاتًا', #1
u'عرفةاااا': u'عَرَفَةَاااا', #1
u'عرفج': u'عَرْفَجٌ', #1
u'عرفج': u'عَرْفَجٍ', #2
u'عرفجة،': u'عَرْفَجَةُ،', #1
u'عرفجة؟': u'عَرْفَجَةَ؟', #1
u'عرفجة': u'عَرْفَجَةَ', #107
u'عرفجة': u'عَرْفَجَةُ', #11
u'عرفجة': u'عرفجة', #3
u'عرفجة،': u'عَرْفَجَةَ،', #8
u'عرفطة،': u'عرفطة،', #1
u'عرفطة': u'عُرْفُطة', #1
u'عرفطة': u'عْرفَطَة', #1
u'عرفطة': u'عَرْفَطَة', #1
u'عرفطة': u'عُرْفُطَة', #1
u'عرفطة': u'عرفطة', #2
u'عرفطة،': u'عَرْفَطَةَ،', #3
u'عرفطة': u'عُرْفُطَةَ', #68
u'عرفطة': u'عَرْفَطَةَ', #7
u'عرفطة،': u'عُرْفُطَةَ،', #7
u'عرفنى': u'عَرَفَنِى', #3
u'عرقبة': u'عَرْقَبَةً', #1
u'عرقبة': u'عَرْقَبَةُ', #1
u'عرقبة': u'عَرْقَبَةِ', #1
u'عرقبت': u'عُرْقِبَتْ', #2
u'عرقبته': u'عَرْقَبَتَهُ', #2
u'عرقبته': u'عَرْقَبَتِهِ', #4
u'عرقبها': u'عَرْقَبَهَا', #1
u'عرقوبة': u'عرقُوبة', #1
u'عرقوص': u'عُرْقُوصٍ', #1
u'عركتين': u'عَرْكَتَيْنِ', #1
u'عرمس': u'عِرْمِسٌ', #1
u'عرمس': u'عِرْمِسُ', #3
u'عرنات': u'عُرَنَاتٍ', #1
u'عرنة،': u'عُرَنَةَ،', #1
u'عرنة': u'عُرَنَةُ', #15
u'عرنة': u'عُرَنَةَ', #159
u'عرندس': u'عَرَنْدَسُ', #2
u'عرندسة': u'عَرَنْدَسَةً', #2
u'عرنيته': u'عُرَنِيّتُهُ', #1
u'عروةعن': u'عُرْوَةَعَنْ', #1
u'عروف': u'عَرُوفٍ', #2
u'عروى': u'عَرْوَى', #4
u'عريب': u'عَرِيب', #1
u'عريب': u'عَرِيبُ', #1
u'عريب': u'عَرِيبٍ', #10
u'عريب': u'عَرِيبِ', #14
u'عريب': u'عَرِيبَ', #2
u'عريب،': u'عَرِيبٍ،', #2
u'عريب': u'عُرَيْبٌ', #3
u'عريب': u'عريب', #4
u'عريب': u'عُرَيْبٍ', #4
u'عريبا': u'عَرِيبَا', #1
u'عريبا': u'عَرِيبًا', #3
u'عريباء': u'عَرِيبَاءَ', #1
u'عريط': u'عُرَيْطَ', #1
u'عريفى': u'عَرِيفِى', #4
u'عريوة': u'عَرَيْوَةٌ', #1
u'عريوة': u'عَرْيِوَةٌ', #1
u'عزاة': u'عَزَاةٍ', #1
u'عزازير': u'عَزَازِيرَ', #1
u'عزازيل': u'عَزَازِيلَ', #1
u'عزازيل': u'عَزَازِيلُ', #1
u'عزازيل،': u'عَزَازِيلُ،', #2
u'عزالى': u'عَزَالِى', #1
u'عزاليها': u'عَزَالِيهَا', #1
u'عزاليها،': u'عَزَالِيهَا،', #1
u'عزاليها': u'عَزَالَيْهَا', #1
u'عزاليها': u'عَزَالِيَهَا', #2
u'عزائز': u'عَزَائِزَ', #1
u'عزائكا': u'عَزَائِكَا', #4
u'عزرة': u'عزرة', #1
u'عزرة،': u'عزرة،', #1
u'عزرة': u'عُزْرَةُ', #1
u'عزرة': u'عُزْرَةَ', #13
u'عزرة،': u'عَزْرَةَ،', #25
u'عزرة،': u'عَزْرَةُ،', #3
u'عزرة': u'عَزْرَةُ', #36
u'عزرة': u'عَزْرَةَ', #47
u'عزرى': u'عزْرَى', #1
u'عزرى': u'عِزْرَى', #1
u'عزريا،': u'عُزَرْيَا،', #1
u'عزمات': u'عَزَمَاتِ', #14
u'عزمات': u'عَزَمَات', #2
u'عزماته': u'عَزَمَاتِهِ', #1
u'عزهل': u'عِزْهِلِ', #2
u'عزوان،': u'عزوان،', #1
u'عزوان،': u'عَزْوَانَ،', #2
u'عزوة': u'عَزْوَةِ', #1
u'عزوة': u'عزوة', #2
u'عزوجل': u'عزوجل', #1
u'عزور': u'عَزُورٌ', #1
u'عزور': u'عَزْوَرَ', #1
u'عزوز': u'عَزُوزٌ', #1
u'عزوزا': u'عَزُوزًا', #1
u'عزوى': u'عُزْوَى', #6
u'عزير': u'عزير', #1
u'عزير': u'عَزِيرٌ', #1
u'عزير': u'عُزَيرٌ', #1
u'عزير': u'عُزَيْرُ', #11
u'عزير': u'عُزَيْرٍ', #15
u'عزير،': u'عُزَيْرٌ،', #2
u'عزير،': u'عُزَيْرٍ،', #2
u'عزير،': u'عُزَيْرُ،', #2
u'عزير': u'عُزَيْرَ', #5
u'عزير': u'عُزَيْرٌ', #57
u'عزيرا': u'عُزَيْرًا', #32
u'عزيلة': u'عُزَيْلَة', #1
u'عساور': u'عَسَاوِرَ', #1
u'عسب': u'عَسَبَ', #2
u'عسب': u'عَسْبٌ', #2
u'عسب': u'عَسْبٍ', #2
u'عسب': u'عَسَبِ', #3
u'عسب': u'عَسْب', #3
u'عسب': u'عَسْبُ', #7
u'عسب': u'عَسْبِ', #71
u'عسب': u'عَسْبَ', #8
u'عسبا': u'عَسْبًا', #1
u'عسبه': u'عَسْبِهِ', #1
u'عسبه': u'عَسْبُهُ', #2
u'عسبه': u'عَسْبه', #4
u'عسجر': u'عَسْجَرٌ', #1
u'عسجر': u'عَسْجَرٍ', #4
u'عسرقة': u'عَسْرَقَةَ', #1
u'عسريتهما': u'عُسْرِيَّتِهِمَا', #1
u'عسق': u'عسق', #3
u'عسقلون': u'عَسْقَلُونَ', #1
u'عسلهون': u'عسلهون', #1
u'عسوف': u'عَسُوفٌ', #1
u'عسوفا': u'عَسُوفًا', #3
u'عسيب': u'عسيب', #1
u'عسيب': u'عُسَيْبٍ', #1
u'عسيب': u'عَسِيبٍ', #18
u'عسيب،': u'عسيب،', #2
u'عسيب': u'عَسِيبُ', #2
u'عسيب': u'عَسِيبِ', #21
u'عسيب': u'عَسِيبٌ', #7
u'عسيبا': u'عسيبا', #1
u'عسيبا': u'عَسِيبًا', #1
u'عسيبه': u'عَسِيبِهِ', #1
u'عسيبه': u'عَسِيبَهُ', #2
u'عسيبه': u'عَسِيبُهُ', #2
u'عسيبها': u'عَسِيبِهَا', #1
u'عسيفاSمن': u'عَسِيفًاSمِنْ', #1
u'عسيفا': u'عَسِيفًا', #51
u'عسيلة': u'عسيلة', #1
u'عسيلة': u'عُسَيْلةَ', #1
u'عسيلة': u'عُسَيْلَة', #1
u'عسيلة': u'عُسَيْلَةٌ', #1
u'عسيلة،': u'عُسَيْلَةَ،', #1
u'عسيلة': u'عُسَيْلَةَ', #20
u'عسيلة': u'عُسَيْلَةٍ', #3
u'عسيلتك،': u'عُسَيْلَتَك،', #1
u'عسيلتك،': u'عُسَيْلَتَكِ،', #1
u'عسيلتك': u'عُسَيْلَتَك', #17
u'عسيلتك': u'عُسَيْلَتك', #2
u'عسيلتك': u'عُسَيْلَتِك', #3
u'عسيلتك': u'عُسَيْلَتِكِ', #3
u'عسيلتك': u'عُسَيْلَتَكِ', #39
u'عسيلته': u'عُسَيْلَتِهِ', #12
u'عسيلته': u'عُسَيْلَته', #3
u'عسيلته،': u'عُسَيْلَتَهُ،', #4
u'عسيلته': u'عُسَيْلَتَهُ', #71
u'عسيلتها': u'عُسَيْلَتَهَاِِِِ', #1
u'عسيلتها': u'عُسَيْلَتَهَا', #11
u'عسيلتها': u'عُسَيْلَتِهَا', #7
u'عسيم': u'عَسِيمٍ', #2
u'عشانة': u'عُشَانة', #1
u'عشانة،': u'عُشَانَةَ،', #1
u'عشانة،': u'عُشَّانَةَ،', #10
u'عشانة': u'عُشَّانَةَ', #28
u'عشانة': u'عُشَانَةَ', #3
u'عشبة': u'عُشْبَةً', #1
u'عشبة': u'عُشْبَةٌ', #1
u'عشذر': u'عَشذرَ', #1
u'عشر': u'عَشَرً', #5
u'عشراوان': u'عُشَرَاوَانِ', #3
u'عشراوين': u'عَشْرَاوَيْنِ', #3
u'عشرةحتى': u'عَشْرَةًحَتَّى', #1
u'عشرقة': u'عشرقة', #1
u'عشرقة': u'عِشْرِقَةَ', #2
u'عشرينه': u'عِشْرِينَهُ', #1
u'عشرينه': u'عِشْرِينِهِ', #1
u'عشرينها': u'عِشْرِينِهَا', #4
u'عشعش': u'عَشْعَشَ', #1
u'عشماوي': u'عَشْمَاوِيٌّ', #16
u'عشنق': u'عَشَنَّقٌ', #2
u'عشوان': u'عَشَوَانٍ', #1
u'عشورات': u'عُشُورَاتِ', #1
u'عشياء': u'عَشْيَاءَ', #1
u'عشيتئذ': u'عَشِيَّتَئِذٍ', #2
u'عشيراء': u'عُشَيْرَاءُ', #1
u'عشيرتى': u'عَشِيرَتِى', #2
u'عشيشية': u'عُشَيْشِيةً', #1
u'عشيشية': u'عُشَيْشِيَةً', #1
u'عشيشية': u'عُشَيْشِيَةٌ', #1
u'عشيشية': u'عُشَيْشِيّةً', #1
u'عصاء': u'عَصَاءٌ', #1
u'عصارو': u'عَصَّارُو', #1
u'عصافقال': u'عَصًافَقَالَ', #1
u'عصافه': u'عِصَافُهُ', #1
u'عصال': u'عِصَالٍ', #1
u'عصانى': u'عَصَانِى', #8
u'عصاوين': u'عَصَاوَيْنِ', #2
u'عصبى': u'عَصَبِى', #1
u'عصرتيها': u'عَصَرْتِيهَا', #1
u'عصرون': u'عَصْرُونَ', #10
u'عصرون': u'عَصْرُونٍ', #178
u'عصفة': u'عَصْفَةٌ', #2
u'عصفر': u'عُصْفُرٍ', #37
u'عصفرا': u'عُصْفُرًا', #23
u'عصفرة': u'عُصْفُرَةٍ', #1
u'عصفره': u'عُصْفُرَهُ', #3
u'عصفره': u'عُصْفُرِهِ', #4
u'عصمنى': u'عَصَمَنِى', #1
u'عصوبة': u'عُصُوبَةٍ', #17
u'عصوبة': u'عُصُوبَةَ', #30
u'عصوبة': u'عُصُوبَةِ', #30
u'عصوبة': u'عُصُوبَةٌ', #31
u'عصوبة': u'عُصُوبَةً', #42
u'عصوبة': u'عُصُوبَةُ', #9
u'عصوبته': u'عُصُوبَتَهُ', #4
u'عصوبته': u'عُصُوبَتِهِ', #5
u'عصوبته': u'عُصُوبَتُهُ', #7
u'عصوبتها': u'عُصُوبَتُهَا', #1
u'عصوبتها': u'عُصُوبَتِهَا', #1
u'عصوبتها': u'عُصُوبَتَهَا', #2
u'عصوبتهم': u'عُصُوبَتُهُمْ', #1
u'عصوبتهم': u'عُصُوبَتِهِمْ', #3
u'عصوبتهما': u'عُصُوبَتِهِمَا', #1
u'عصوبتهن': u'عُصُوبَتُهُنَّ', #1
u'عصوبتين': u'عُصُوبَتَيْنِ', #1
u'عصى': u'عَصًى', #7
u'عصيتته': u'عصيتته', #1
u'عصيتن': u'عَصَيْتُنَّ', #2
u'عصيتنى': u'عَصَيْتَنِى', #1
u'عصيراهما': u'عَصِيرَاهُمَا', #3
u'عصيروالوجه': u'عَصِيرٍوَالْوَجْهُ', #1
u'عصيفتها17421id': u'عصيفتها17421id', #1
u'عصيفير': u'عُصَيْفِيرٌ', #1
u'عصيفير': u'عُصَيْفِيرَ', #1
u'عصيفير': u'عُصَيْفِيرٍ', #4
u'عصيفيرا': u'عصيفيرا', #1
u'عصيفيرا': u'عُصَيْفِيرًا', #2
u'عصيم': u'عُصَيْمٍ', #2
u'عصينة': u'عُصَيْنَةَ', #1
u'عضاء': u'عِضَاءُ', #1
u'عضادتى': u'عِضَادَتَىِ', #2
u'عضالة': u'عَضَالَةً', #1
u'عضاهة': u'عِضَاهَةٍ', #1
u'عضاهه': u'عِضَاهَهُ', #1
u'عضاهه': u'عِضَاهُهُ', #1
u'عضاهه': u'عِضَاهِهِ', #1
u'عضاهها': u'عِضَاهَهَا', #1
u'عضاهها،': u'عِضَاهُهَا،', #1
u'عضاهها': u'عِضَاهُهَا', #19
u'عضائد': u'عَضَائِدُ', #1
u'عضائد': u'عَضَائِدَ', #2
u'عضب': u'عَضَبٌ', #1
u'عضب': u'عَضَبُ', #1
u'عضب': u'عَضْبَ', #1
u'عضب': u'عَضْبِ', #1
u'عضب': u'عُضِبْ', #1
u'عضب': u'عَضَبٍ', #2
u'عضب': u'عَضَبِ', #2
u'عضب': u'عَضْبٍ', #21
u'عضب': u'عَضَبَ', #35
u'عضب': u'عَضْبُ', #4
u'عضب': u'عَضْبٌ', #7
u'عضب': u'عُضِبَ', #9
u'عضبا': u'عَضَبًا', #1
u'عضبا': u'عَضْبًا', #6
u'عضباء؟': u'عَضْبَاءَ؟', #1
u'عضباء': u'عَضْبَاءُ', #12
u'عضباء': u'عَضْبَاء', #2
u'عضباء': u'عَضْبَاءَ', #2
u'عضباء': u'عَضْبَاءِ', #3
u'عضبت': u'عَضَبْت', #1
u'عضبت': u'عَضَبْتِ', #1
u'عضبت': u'عَضِبَتْ', #3
u'عضبت': u'عُضِبَتْ', #5
u'عضبت': u'عَضَبَتْ', #6
u'عضبه': u'عَضْبِهِ', #17
u'عضدى': u'عَضُدَىَّ', #1
u'عضدى': u'عَضُدِى', #1
u'عضضتنيها': u'عَضَضْتَنِيهَا', #4
u'عضها': u'عَضْهًا', #1
u'عضهة': u'عِضَهَةٍ', #1
u'عضهت': u'عَضَهْت', #1
u'عضهه': u'عَضَهَهُ', #1
u'عضهوا': u'عضهوا', #1
u'عضواوالوجه': u'عُضْوًاوَالْوَجْهُ', #1
u'عضول': u'عُضُولٍ', #1
u'عضيت': u'عَضَيْتُ', #1
u'عضيت': u'عَضّيْت', #1
u'عضيض': u'عَضِيضَ', #3
u'عضين': u'عِضِينَ', #8
u'عطاءالبدن': u'عطاءالبدن', #1
u'عطاءالواسطي،': u'عَطَاءٍالْوَاسِطِيِّ،', #1
u'عطاءفي': u'عَطَاءٍفِي', #1
u'عطاءوأما': u'عَطَاءٍوَأَمَّا', #1
u'عطائى': u'عَطَائِى', #6
u'عطبة': u'عَطْبَةٌ', #1
u'عطربعثيا': u'عِطْرَبَعْثِيًّا', #1
u'عطرى': u'عطرى', #3
u'عطشانا': u'عَطْشَانًا', #8
u'عطفى': u'عِطْفَىَّ', #1
u'عطنا': u'عَطِنًا', #1
u'عطنا': u'عَطَنًا', #16
u'عطنت': u'عَطَنَتْ', #1
u'عطنوا': u'عَطَنُوا', #1
u'عطوة': u'عَطْوَةَ', #2
u'عطونا': u'عُطُونًا', #1
u'عطيات': u'عَطِيَّاتٍ', #1
u'عطيات': u'عَطِيَّاتٌ', #4
u'عطياتهم': u'عَطِيَّاتِهِمْ', #6
u'عطيان': u'عَطَيَانُ', #1
u'عطيف': u'عَطِيف', #1
u'عطيف': u'عُطَيْفٍ', #2
u'عطيفتين': u'عُطَيْفَتَيْنِ', #1
u'عطيل': u'عُطَيْلٍ', #1
u'عظاميا': u'عِظَامِيًّا', #1
u'عفار': u'عَفَارٍ', #1
u'عفار': u'عِفَارِ', #1
u'عفار': u'عَفَارِ', #3
u'عفارة': u'عِفَارَة', #1
u'عفازة': u'عَفَازَةَ', #1
u'عفاص': u'عِفَاصٍ', #1
u'عفاص': u'عِفَاصُ', #1
u'عفاص': u'عِفَاصِ', #1
u'عفاص': u'عِفَاصَ', #4
u'عفاصا': u'عِفَاصًا', #3
u'عفاصه': u'عِفَاصَهُ', #1
u'عفاصها،': u'عفاصها،', #1
u'عفاصها': u'عِفَاصهَا', #1
u'عفاصها': u'عِفَاصُهَا', #1
u'عفاصها؟': u'عِفَاصَهَا؟', #1
u'عفاصها': u'عِفَاصِهَا', #4
u'عفاصها،': u'عِفَاصَهَا،', #6
u'عفاصها': u'عِفَاصَهَا', #84
u'عفال': u'عُفَالٌ', #1
u'عفج': u'عَفَجَ', #4
u'عفرتى': u'عُفْرَتَىْ', #2
u'عفرس': u'عفرس', #1
u'عفرس': u'عِفْرِسِ', #3
u'عفز': u'عَفَزَ', #1
u'عفزا': u'عَفْزًا', #5
u'عفزا': u'عفزا', #8
u'عفش': u'عَفَشٌ', #1
u'عفص': u'عَفْصٌ', #2
u'عفص': u'عَفْصٍ', #2
u'عفصا': u'عَفْصًا', #1
u'عفل': u'عَفَلٌ', #1
u'عفل': u'عَفْلٌ', #1
u'عفل': u'عَفَلَ', #2
u'عفل': u'عَفَلٍ', #4
u'عفلاء': u'عَفْلَاءُ', #3
u'عفلاء': u'عَفْلَاءَ', #7
u'عفلة': u'عَفْلَةَ', #1
u'عفوصة': u'عُفُوصَةً', #2
u'عفوصته': u'عُفُوصَتُهُ', #2
u'عفيرأن': u'عُفَيْرٍأَنّ', #1
u'عفينا': u'عَفِينًا', #1
u'عقاص': u'عَقَاصِ', #1
u'عقاص': u'عِقَاصِ', #9
u'عقاصا': u'عِقَاصًا', #1
u'عقاصه': u'عِقَاصِهِ', #1
u'عقاصها': u'عِقَاصُهَا', #1
u'عقاصها،': u'عِقَاصِهَا،', #1
u'عقاصها': u'عِقَاصِهَا', #17
u'عقاصها': u'عِقَاصَهَا', #2
u'عقالاته': u'عِقَالَاتُهُ', #1
u'عقامة': u'عَقَامَةَ', #1
u'عقامة': u'عُقَامَةَ', #2
u'عقباوية': u'عَقْبَاوِيَّةٌ', #3
u'عقبش': u'عقبش', #1
u'عقدات': u'عَقَدَاتِ', #1
u'عقدى': u'عِقْدِى', #4
u'عقرتنى': u'عَقَرْتَنِى', #1
u'عقرس': u'عِقْرِسِ', #1
u'عقصاء': u'عَقْصَاءُ', #12
u'عقصاء': u'عَقْصَاء', #2
u'عقصاء،': u'عَقْصَاءُ،', #2
u'عقصة': u'عقصة', #1
u'عقله': u'عُقُلِهًًًًِ', #1
u'عقوبةS': u'عُقُوبَةًS', #1
u'عقى': u'عُقِّى', #1
u'عقى': u'عَقَى', #2
u'عقيبة': u'عَقِيبَةَ', #1
u'عقيصة': u'عقيصة', #1
u'عقيصة': u'عَقِيصَةٍ', #2
u'عقيصة': u'عَقِيصَةٌ', #3
u'عقيصتان،': u'عقيصتان،', #1
u'عقيصتان': u'عَقِيصَتَانِ', #3
u'عقيصته': u'عَقِيصَتُهُ', #1
u'عقيصتي': u'عقيصتي', #1
u'عقيصتى': u'عَقِيصَتَىْ', #1
u'عقيصتي': u'عَقِيصَتَيْ', #2
u'عقيفا': u'عَقِيفًا', #1
u'عقيلا': u'عَقِيلاً', #1
u'عقيلا': u'عَقيلًا', #1
u'عقيلا،': u'عَقِيلًا،', #1
u'عقيلا': u'عُقَيْلًا', #1
u'عقيلا': u'عَقِيلًا', #23
u'عقيه': u'عِقْيُهُ', #1
u'عكاء': u'عَكَّاءَ', #3
u'عكاب': u'عُكَابِ', #1
u'عكابة': u'عكابة', #1
u'عكابة': u'عُكَابَةَ', #16
u'عكارين': u'عَكَّارِينَ', #1
u'عكامس': u'عُكَامِسَ', #1
u'عكامس': u'عُكَامِسٍ', #2
u'عكانة': u'عكانة', #1
u'عكبرا': u'عُكْبَرا', #1
u'عكبرا': u'عُكْبَرَا', #1
u'عكبرا،': u'عُكْبُرَا،', #1
u'عكبرة': u'عُكْبُرَةُ', #1
u'عكبرة': u'عكبرة', #3
u'عكة': u'عَكَّة', #1
u'عكة': u'عَكَّةَ', #1
u'عكة،': u'عَكَّةٍ،', #1
u'عكة': u'عَكَّةُ', #2
u'عكة': u'عُكَّةَ', #3
u'عكة': u'عُكَّةِ', #3
u'عكة': u'عُكَّةٌ', #4
u'عكة': u'عُكَّةٍ', #6
u'عكة': u'عُكَّةً', #8
u'عكتها': u'عُكَّتِهَا', #1
u'عكراش': u'عِكْرَاشٌ', #1
u'عكراش': u'عِكْرَاشَ', #1
u'عكراش': u'عِكْرَاشُ', #19
u'عكراش': u'عِكْرَاشِ', #6
u'عكراش': u'عِكْرَاشٍ', #7
u'عكراشا': u'عِكْرَاشًا', #3
u'عكرشة': u'عَكْرِشَةٌ', #1
u'عكرشة': u'عِكْرِشَةٌ', #1
u'عكرم،': u'عِكْرِمٍ،', #1
u'عكرم': u'عِكْرِمَ', #2
u'عكرمةأنه': u'عِكْرِمَةَأَنَّهُ', #1
u'عكرمةإني': u'عِكْرِمَةُإِنِّي', #1
u'عكرمةقول': u'عِكْرِمَةَقَوْلُ', #1
u'عكرمه،': u'عكرمه،', #1
u'عكرمه': u'عِكْرَمَهْ', #1
u'عكرمه': u'عِكْرِمَهْ', #4
u'عكظ': u'عَكَظَ', #1
u'عكلية': u'عُكْلِيّةٌ', #1
u'عكم': u'عِكم', #1
u'عكم': u'عِكْمٌ', #1
u'عكم': u'عِكْمٍ', #1
u'عكم': u'عَكَمَ', #7
u'عكما': u'عِكْمًا', #1
u'عكمت': u'عَكَمْتُ', #1
u'عكنة': u'عُكْنَة', #1
u'عكنة': u'عُكْنَةً', #1
u'عكنة': u'عُكْنَةٌ', #1
u'عكنة': u'عُكْنَةٍ', #7
u'عكوس': u'عُكُوسِ', #1
u'عكوسها': u'عُكُوسِهَا', #1
u'عكومها': u'عُكُومُهَا', #1
u'عكير': u'عُكْيَرٍ', #1
u'عكيم،': u'عكيم،', #1
u'عكيم': u'عُكَيْمٌ', #1
u'عكيم': u'عُكَيْمِ', #2
u'عكيم': u'عكيم', #3
u'عكيم': u'عُكَيْمٍ', #77
u'عكيم،': u'عُكَيْمٍ،', #9
u'علاثة': u'عُلاثة', #1
u'علاثة': u'عِلَاثَةَ', #1
u'علاثة': u'عُلاَثَةَ', #28
u'علاثة': u'عُلَاثَةَ', #33
u'علاثة': u'عُلاثَةَ', #4
u'علاثة،': u'عُلاثَةَ،', #4
u'علاثة': u'عُلَاثَة', #5
u'علاط': u'عِلاط', #2
u'علاط': u'عِلاطٍ', #3
u'علاط': u'عِلَاطٍ', #36
u'علاط': u'عِلاَطٍ', #4
u'علاق': u'عَلَاقِ', #1
u'علاق': u'عَلَّاق', #1
u'علاق': u'عَلاَّقٍ', #1
u'علاق': u'عِلَاقٍ', #11
u'علاق': u'عَلَّاقٍ', #4
u'علاق': u'عَلَاقٍ', #45
u'علاكا': u'عَلاكَا', #1
u'علال': u'عَلاَلٍ', #1
u'علال': u'عِلَالٍ', #1
u'علال': u'عَلَّالٍ', #3
u'علالات': u'عُلَالَاتٌ', #1
u'علالة': u'عُلَالَةً', #1
u'علالة': u'عُلَالَةٍ', #1
u'علالة': u'عُلَالَةُ', #2
u'علالة': u'عُلَالَةَ', #5
u'علاليم': u'عَلَالِيمُ', #1
u'علانة': u'علانة', #1
u'علانة': u'عَلَانَةٍ', #1
u'علاوات': u'عِلَاوَاتٌ', #1
u'علاوين': u'عَلَاوِينُ', #1
u'علائف': u'عَلَائِفُ', #5
u'علبون': u'عَلْبُونٍ', #1
u'علثت': u'عَلَثْت', #1
u'علجة': u'عِلْجَةٌ', #1
u'علجة': u'عِلْجَةً', #2
u'علس': u'عَلْس', #1
u'علس': u'عَلْسٍ', #1
u'علس': u'عَلَسُ', #2
u'علس': u'عَلَسٍ', #6
u'علفة': u'عِلْفَةٌ', #1
u'علقام': u'عَلْقَامَ', #2
u'علقمة،': u'علقْمة،', #1
u'علقمة،': u'عَلْقَمة،', #1
u'علقمة': u'عَلَقْمَةَ', #1
u'علقمة': u'عِلْقَمَةَ', #1
u'علقمة،': u'عَلْقَمَة،', #1
u'علقمة،': u'عَلْقَمَةٌ،', #1
u'علقمة': u'عَلْقَمَة', #10
u'علقمة': u'عَلْقَمَةَ', #1284
u'علقمة،': u'عَلْقَمَةَ،', #185
u'علقمة': u'عَلْقَمَةُ', #193
u'علقمة،': u'علْقمة،', #2
u'علقمة': u'عَلْقَمة', #2
u'علقمة': u'علْقمة', #3
u'علقمة': u'علقمة', #51
u'علقمة،': u'علقمة،', #58
u'علقمة،': u'عَلْقَمَةُ،', #9
u'علقمة،أنه': u'عَلْقَمَةَ،أَنَّهُ', #1
u'علقمةفإن': u'عَلْقَمَةَفَإِنْ', #1
u'علقمة،في': u'عَلْقَمَةَ،فِي', #2
u'علقمة،قوله': u'عَلْقَمَةَ،قَوْلُهُ', #1
u'علكد': u'عَلْكَدّ', #1
u'علكوم': u'عُلْكومٌ', #1
u'علكوم': u'عُلْكُومٌ', #2
u'علمتأنه': u'علمتأنه', #1
u'علمتكموه': u'عَلَّمْتُكُمُوهُ', #1
u'علمتمونه،': u'علمتمونه،', #1
u'علمتنى': u'عَلَّمَتْنِى', #1
u'علمتنى': u'عَلَّمْتَنِى', #1
u'علمكه': u'عَلَّمَكَهُ', #4
u'علمنى': u'عَلَّمَنِى', #14
u'علمنى': u'عَلِّمْنِى', #14
u'علمى': u'عِلْمِى', #11
u'علنداة': u'عَلَنْدَاةٌ', #2
u'علوة': u'عُلْوَةٌ', #1
u'علوة': u'عُلْوَةٍ', #2
u'علوتا': u'عَلَوَتَا', #2
u'علوسا': u'عَلُوسَا', #3
u'علوشا': u'عَلُوشَا', #3
u'علوص': u'عِلَّوْصٌ', #1
u'علوفة': u'عَلُوفَةٌ', #1
u'علوفة': u'عَلُوفَةِ', #1
u'علوفة': u'عُلُوفَةِ', #1
u'علوفة': u'عُلُوفَةً', #2
u'علوفة': u'عَلُوفَةً', #51
u'علوفتها': u'عُلُوفَتِهَا', #3
u'علي؟': u'عليًّ؟', #1
u'علي': u'عَلِيًّ', #1
u'عليابة': u'عَلْيَابَة', #1
u'علياعن': u'عَلِيًّاعَنْ', #1
u'علىالأوراك': u'عَلَىالْأَوْرَاكِ', #1
u'علىالميت': u'عَلَىالْمَيِّتِ', #1
u'علىالنبي': u'عَلَىالنَّبِيِّ', #2
u'عليإنما': u'عَلِيّإِنَّمَا', #1
u'عليأنه': u'عليأنه', #1
u'عليبة': u'عُلَيْبَةَ', #9
u'علىرسول': u'عَلَىرَسُولِ', #1
u'عليش': u'عُلَيْش', #1
u'عليش': u'عُلَيْشٌ', #1
u'عليش': u'عُلَيْشٍ', #2
u'علىعمر': u'عَلَىعُمَرَ', #1
u'عليفة': u'عَلِيفَةُ', #1
u'عليفة': u'عُلَيْفَةُ', #2
u'عليكثم': u'عَلَيْكَثُمَّ', #1
u'علىمالك': u'عَلَىمَالِكٍ', #1
u'عليناSمصالحة': u'عَلَيْنَاSمُصَالَحَةُ', #1
u'عليهSحول': u'عَلَيْهِSحَوْلَ', #1
u'عليهاالوجه': u'عَلَيْهَاالْوَجْهُ', #1
u'عليهدلائل': u'عَلَيْهِدَلَائِلُ', #1
u'عليهقوله': u'عَلَيْهِقَوْلُهُ', #1
u'عليهماقوله': u'عَلَيْهِمَاقَولُهُ', #1
u'عليهمقوله': u'عَلَيْهِمْقَولُهُ', #2
u'عليهمن': u'عَلَيْهِمِنْ', #2
u'عليهمو': u'عَلَيْهِمُو', #1
u'عليهموالوجه': u'عَلَيْهِمْوَالْوَجْهُ', #2
u'عليهنقوله': u'عَلَيْهِنَّقَوْلُهُ', #1
u'عليولا': u'عَلَيَّوَلا', #1
u'عليوي': u'عُلَيْوِيٌّ', #1
u'علييات': u'عَلِييَّاتٍ', #1
u'علييييي': u'عَلَيَّيييي', #1
u'عمار': u'عمارً', #1
u'عمارت': u'عمارت', #1
u'عماس': u'عَمَاسَ', #1
u'عماس': u'عَمَاسٍ', #2
u'عماس': u'عِمَاسٍ', #2
u'عماص': u'عُمَاصُ', #1
u'عمالتى': u'عُمَالَتِى', #1
u'عمالق': u'عَمَالِقٌ', #1
u'عمالى': u'عُمَّالِى', #3
u'عماى': u'عَمَّاىَ', #1
u'عمتى': u'عَمَّتِىَ', #1
u'عمتى': u'عَمَّتِى', #15
u'عمد': u'عَمْدً', #1
u'عمديته': u'عَمْدِيَّتَهُ', #2
u'عمرأبي': u'عُمَرُأُبَيُّ', #1
u'عمراللهم': u'عُمَرُاللَّهُمَّ', #1
u'عمرأن': u'عُمَرَأَنَّ', #1
u'عمرأن': u'عُمَرَأَنْ', #1
u'عمرانة': u'عِمْرَانَةَ', #3
u'عمرأنه': u'عمرأنه', #1
u'عمرأنه': u'عُمَرَأَنَّهُ', #1
u'عمرأنهى': u'عُمَرَأَنْهَى', #1
u'عمراوي': u'عَمْرَاوِيٍّ', #1
u'عمربن': u'عُمَرُبْنُ', #1
u'عمرتى': u'عمرتى', #1
u'عمرتى؟': u'عُمْرَتِى؟', #1
u'عمرتى': u'عُمْرَتِى', #12
u'عمرد': u'عَمَرَّدُ', #1
u'عمررضى': u'عُمَرَرَضِىَ', #1
u'عمرعن': u'عُمَرَعَنْ', #1
u'عمرقد': u'عُمَرُقَدْ', #1
u'عمرلم': u'عُمَرَلَمْ', #1
u'عمرلما': u'عُمَرَلَمَّا', #1
u'عمرنهى': u'عُمَرَنَهَى', #1
u'عمرهذا': u'عُمَرُهَذَا', #1
u'عمروSحديث': u'عَمْرٌوSحَدِيثُ', #1
u'عمروا،': u'عَمْروًا،', #1
u'عمروا': u'عَمْرَوًا', #1
u'عمروبن': u'عمروبن', #1
u'عمروبن': u'عَمْرُوَبْنُ', #3
u'عمروزنيج،': u'عَمْرٍوزُنَيْج،', #1
u'عمروس': u'عَمْرُوسٍ', #3
u'عمرون': u'عَمْرُون', #1
u'عمرون': u'عَمْرُونُ', #1
u'عمرون': u'عَمْرُونٍ', #5
u'عمرويه': u'عَمْرَوِيْهِ', #1
u'عمرويه،': u'عَمْرَوَيْهِ،', #1
u'عمرويه': u'عَمْرَوَيْهِ', #6
u'عمرويه': u'عَمْرُوَيْهِ', #7
u'عمرى': u'عُمُرِى', #1
u'عمرى،': u'عُمْرَى،', #1
u'عمرى': u'عُمْرَى', #193
u'عمرى': u'عُمْرِى', #3
u'عمست': u'عمست', #1
u'عمصهم': u'عَمْصُهُمْ', #1
u'عمقانا': u'عُمْقَانًا', #1
u'عملتوروي': u'عَمِلَتْوَرُوِيَ', #1
u'عملى': u'عَمَلِى', #8
u'عمليق': u'عِمْليق', #1
u'عمليق': u'عِمْلِيقَ', #1
u'عمليق': u'عِمْلِيقُ', #2
u'عممنى': u'عَمَّمَنِى', #1
u'عمهة': u'عَمِهَةٌ', #2
u'عمهون': u'عَمِهُونَ', #2
u'عمواس': u'عَمَواس', #1
u'عمواس': u'عَمَوَاس', #1
u'عمواس': u'عَمَوَاسٌ', #1
u'عمواس': u'عَمَوَاسُ', #1
u'عمواس': u'عَمْوَاسٌ', #1
u'عمواس': u'عَمْوَاسَ', #1
u'عمواس': u'عمواس', #10
u'عمواس،': u'عمواس،', #2
u'عمواس': u'عَمَوَاسَ', #22
u'عمواس': u'عَمْوَاسٍ', #5
u'عمودى': u'عَمُودَىْ', #4
u'عمورية': u'عَمُورية', #1
u'عمورية': u'عَمُّورِية', #1
u'عمورية،': u'عَمُّورِيَّةَ،', #1
u'عمورية': u'عَمُورِيّةَ', #2
u'عمورية': u'عَمّورِيَةَ', #2
u'عمورية': u'عَمُّورِيَّةُ', #2
u'عمورية': u'عَمُورِيَّةَ', #3
u'عمورية': u'عَمُّورِيَّةَ', #5
u'عموقها': u'عُمُوقِهَا', #1
u'عمومتى': u'عُمُومَتِى', #8
u'عمومى': u'عُمُومَى', #2
u'عمون': u'عَمُونٍ', #1
u'عمون': u'عَمُونَ', #4
u'عميانا': u'عُمْيَانًا', #22
u'عميانس': u'عُمْيَانِسُ', #4
u'عميانس': u'عُمْيَانِسَ', #8
u'عميرأنه': u'عُمَيْرٍأَنَّهُ', #1
u'عميرما': u'عُمَيْرٍمَا', #1
u'عميريصوم': u'عُمَيْرٍيَصُومُ', #1
u'عميس': u'عُمَيْسٌ', #1
u'عميس،': u'عُمَيْس،', #2
u'عميس': u'عُمَيْسٍ', #212
u'عميس،': u'عُمَيْسٍ،', #23
u'عميس': u'عُمَيْس', #4
u'عميس،': u'عميس،', #5
u'عميس': u'عُمَيْسِ', #6
u'عميس': u'عميس', #7
u'عنNعليه': u'عنNعليه', #9
u'عنابل': u'عُنَابِلُ', #3
u'عنابن': u'عَنابْنِ', #1
u'عنابن': u'عَنْابْنِ', #3
u'عنابن': u'عَنِابْنِ', #4
u'عنأبي': u'عَنْأَبِي', #2
u'عناة': u'عُنَاةً', #1
u'عناجج': u'عَنَاجِجَ', #1
u'عناجيج': u'عَناجيجَ', #1
u'عنأشهب': u'عَنْأَشْهَبَ', #1
u'عناقة': u'عِنَاقَة', #2
u'عنالاشتغال': u'عَنْالِاشْتِغَالِ', #1
u'عنالأعمال': u'عَنْالْأَعْمَالِ', #1
u'عنالتسع،': u'عَنِالتِّسْعِ،', #1
u'عنالجريري،': u'عَنِالْجُرَيْرِيِّ،', #1
u'عنالزهري': u'عَنِالزُّهْرِيِّ', #1
u'عنالسفاح': u'عَنِالسِّفَاحِ', #1
u'عنالوالدان': u'عَنْالوالدان', #1
u'عنان': u'عِنَانً', #2
u'عنانة': u'عَنَانَةٌ', #1
u'عنانى': u'عَنَانِى', #1
u'عنبس': u'عَنْبس', #1
u'عنبس': u'عَنْبَس', #1
u'عنبس': u'عَنْبَسُ', #1
u'عنبس': u'عَنْبَسٍ', #14
u'عنبس،': u'عَنْبَسِ،', #2
u'عنبس': u'عَنْبَسٌ', #3
u'عنبسة،': u'عَنْبَسَةُ،', #2
u'عنبسة،': u'عَنْبَسَةَ،', #23
u'عنبسة؟': u'عَنْبَسَةُ؟', #3
u'عنبسة،': u'عنبسة،', #4
u'عنبسة': u'عَنْبَسَةُ', #56
u'عنبسة': u'عنبسة', #7
u'عنبسة': u'عَنْبَسَةَ', #90
u'عنبوانة': u'عُنْبُوَانَةَ', #1
u'عنة': u'عُنَّةِ', #1
u'عنة': u'عُنَّةً', #14
u'عنة': u'عُنَّةٌ', #17
u'عنة': u'عُنَّةُ', #3
u'عنة': u'عُنَّةٍ', #45
u'عنة': u'عُنَّةَ', #7
u'عنتزويج': u'عَنْتَزْوِيجِ', #1
u'عنثو': u'عُنْثُوَ', #1
u'عنج': u'عَنَج', #1
u'عنج': u'عَنَجٍ', #2
u'عنج،': u'عَنْجٍ،', #2
u'عنجد': u'عَنْجَدٌ', #1
u'عنجدة': u'عَنْجَدَةَ', #1
u'عنجدة': u'عَنْجَدَةُ', #1
u'عنجدة': u'عُنْجُدَةَ', #3
u'عند': u'عِنْدً', #4
u'عندكمالوجه': u'عِنْدَكُمْالْوَجْهُ', #1
u'عندكمقوله': u'عِنْدَكُمْقَوْلُهُ', #1
u'عندمالك': u'عِنْدَمَالِكٍ', #1
u'عندنده': u'عندنده', #1
u'عندهوالوجه': u'عِنْدَهُوَالْوَجْهُ', #1
u'عندى': u'عِنْدِىَ', #1
u'عندى': u'عِنْدِى', #270
u'عنديات': u'عِنْدِيَّاتِ', #1
u'عندياته': u'عِنْدِيَاتِهِ', #1
u'عندياته': u'عِنْدِيَّاتِهِ', #6
u'عندية': u'عِنْدِيَّةٌ', #1
u'عندية': u'عِنْدِيَّةَ', #1
u'عندية': u'عِنْدِيَّةُ', #6
u'عنديه': u'عِنْدَيَهْ', #1
u'عنزيد': u'عَنْزَيْدِ', #1
u'عنشعبة،': u'عَنْشُعْبَةَ،', #1
u'عنصالح': u'عَنْصَالِحِ', #1
u'عنصلي': u'عنصلي', #1
u'عنطنطة': u'عَنَطْنَطَةٌ', #1
u'عنظوانة': u'عُنْظَوَانَةَ', #1
u'عنظوانة': u'عُنْظُوَانَةُ', #1
u'عنظوانة': u'عُنْظُوَانَةَ', #2
u'عنعائشة': u'عَنْعَائِشَةَ', #1
u'عنعبد': u'عَنْعَبْدِ', #2
u'عنعمر': u'عَنْعُمَرَ', #1
u'عنعمومه': u'عَنْعُمُومِهِ', #1
u'عنعنه': u'عنعنه', #1
u'عنعنه': u'عَنْعَنَهُ', #20
u'عنعنوه': u'عَنْعَنُوهُ', #1
u'عنفوة': u'عُنْفُوَةَ', #3
u'عنقة': u'عُنُقَةُ', #1
u'عنقتادة،': u'عَنْقَتَادَةَ،', #1
u'عنقفير': u'عَنْقَفِيرُ', #2
u'عنقول': u'عَنْقَوْلِ', #3
u'عنقوله': u'عنقوله', #1
u'عنقوله': u'عَنْقَوْلِهِ', #11
u'عنقى': u'عُنُقِى', #9
u'عنكا': u'عَنْكَا', #1
u'عنكثة': u'عَنْكَثَةَ', #3
u'عنكفنزلت': u'عَنْكَفَنَزَلَتْ', #1
u'عنمالك': u'عَنْمَالِكٍ', #3
u'عنمة': u'عنمة', #1
u'عنمة': u'عَنَمَةُ', #1
u'عنمة،': u'عَنَمَةَ،', #1
u'عنمة': u'عَنَمَةَ', #8
u'عنمسعر': u'عَنْمِسْعَرٍ', #1
u'عنمعقل،': u'عَنْمَعْقِلٍ،', #1
u'عنمه': u'عَنَمِهِ', #1
u'عنمي': u'عَنْمِيٌّ', #1
u'عننافع،': u'عَنِنَافِعٍ،', #1
u'عنهSحول': u'عَنْهُSحَوْلَ', #1
u'عنهاا': u'عَنْهُاا', #1
u'عنهأرضعتهما': u'عَنْهُأَرْضَعَتْهُمَا', #1
u'عنهأشهب': u'عَنْهُأَشْهَبُ', #1
u'عنهالجماعة': u'عَنْهُالْجَمَاعَةُ', #1
u'عنهألحقت': u'عَنْهُأَلْحَقْتُ', #1
u'عنهالمال': u'عَنْهُالْمَالُ', #1
u'عنهإما': u'عَنْهُإمَّا', #1
u'عنهامع': u'عَنْهَامَعَ', #1
u'عنهأن': u'عَنْهُأَنَّ', #1
u'عنهإن': u'عَنْهُإِنَّ', #2
u'عنهانظر': u'عَنْهُاُنْظُرْ', #1
u'عنهأنه': u'عَنْهُأَنَّهُ', #1
u'عنهأي': u'عَنْهُأَيُّ', #1
u'عنهباليمين': u'عَنْهُبِالْيَمِينِ', #2
u'عنهخذ': u'عَنْهُخُذْ', #1
u'عنهرضا': u'عَنْهُرِضَا', #1
u'عنهرواه': u'عَنْهُرَوَاهُ', #1
u'عنهعلى': u'عَنْهُعَلَى', #1
u'عنهعن': u'عَنْهُعَنْ', #2
u'عنهفذلك': u'عَنْهُفَذَلِكَ', #1
u'عنهفهم': u'عَنْهُفَهِمَ', #1
u'عنهفي': u'عَنْهُفِي', #1
u'عنهقال': u'عَنْهُقَالَ', #1
u'عنهقوله': u'عَنْهُقَوْلُهُ', #1
u'عنهكان': u'عَنْهُكَانَ', #1
u'عنهلا': u'عَنْهُلَا', #5
u'عنهلأزواج': u'عَنْهُلِأَزْوَاجِ', #1
u'عنهللجارية': u'عَنْهُلِلْجَارِيَةِ', #1
u'عنهلما': u'عَنْهُلَمَّا', #1
u'عنهلو': u'عَنْهُلَوْ', #1
u'عنهمقوله': u'عَنْهُمْقَوْلُهُ', #1
u'عنهمن': u'عَنْهُمِنْ', #1
u'عنهوأذكر': u'عَنْهُوَأَذْكُرُ', #1
u'عنهوالتسعير': u'عَنْهُوَالتَّسْعِيرُ', #1
u'عنهوالذي': u'عَنْهُوَاَلَّذِي', #5
u'عنهوالوجه': u'عَنْهُوَالْوَجْهُ', #1
u'عنهوالوجهان': u'عَنْهُوَالْوَجْهَانِ', #1
u'عنهوإنما': u'عَنْهُوَإِنَّمَا', #1
u'عنهوجه': u'عَنْهُوَجْهُ', #1
u'عنهوذلك': u'عَنْهُوَذَلِكَ', #2
u'عنهوعندي': u'عَنْهُوَعِنْدِي', #4
u'عنهوقال': u'عَنْهُوَقَالَ', #2
u'عنهوقد': u'عَنْهُوَقَدْ', #1
u'عنهوكان': u'عَنْهُوَكَانَ', #1
u'عنهولا': u'عَنْهُوَلَا', #2
u'عنهوما': u'عَنْهُوَمَا', #1
u'عنهومعنى': u'عَنْهُوَمَعْنَى', #4
u'عنهوهذا': u'عَنْهُوَهَذَا', #2
u'عنهوهم': u'عَنْهُوَهُمْ', #1
u'عنهووجه': u'عَنْهُوَوَجْهُ', #2
u'عنهويجوز': u'عَنْهُوَيَجُوزُ', #1
u'عنهويحتمل': u'عَنْهُوَيَحْتَمِلُ', #2
u'عنهويصح': u'عَنْهُوَيَصِحُّ', #1
u'عنوانات': u'عُنْوَانَاتِ', #1
u'عنويا': u'عَنَوِيًّا', #4
u'عنوية': u'عَنْوَيَّةٍ', #1
u'عنوية': u'عَنْوِيَّةٌ', #3
u'عنوية': u'عَنْوِيَّةً', #5
u'عنويين': u'عَنَوِيِّينَ', #1
u'عنيSأجود': u'عَنّيSأَجْوَدُ', #1
u'عنيب': u'عُنَيْبٍ', #3
u'عنيزة': u'عُنَيْزَةُ', #1
u'عنينا،': u'عَنِينًا،', #1
u'عنينا': u'عِنِّينًا', #179
u'عنينة': u'عِنِّينَةٌ', #4
u'عهد': u'عَهْدً', #1
u'عهداوروي': u'عَهْدًاوَرُوِيَ', #1
u'عهدرسول': u'عَهْدِرَسُولِ', #1
u'عهدى': u'عَهْدِى', #5
u'عهديته': u'عَهْدِيَّتِهِ', #1
u'عوابسا': u'عَوَابِسَا', #1
u'عواتك': u'عَوَاتِكُ', #1
u'عواتك': u'عَوَاتِكَ', #2
u'عواثن': u'عَوَاثِنُ', #1
u'عوارضا': u'عَوَارِضًا', #1
u'عواره': u'عَوَارَهُ', #1
u'عواره': u'عَوَارُهُ', #1
u'عواره': u'عَوَارِهِ', #1
u'عوارى': u'عَوَارِىٌّ', #1
u'عوارى': u'عَوَارِىِّ', #1
u'عوافى': u'عَوَافِىَ', #1
u'عواقبهوالوجه': u'عَوَاقِبُهُوَالْوَجْهُ', #1
u'عوالى': u'عَوَالِى', #1
u'عواميده': u'عَوَامِيدِهِ', #1
u'عوانة،': u'عُوانة،', #1
u'عوانة': u'عَوَانة', #1
u'عوانة،': u'عَوَانة،', #1
u'عوانة': u'عَوَانَةٌ', #1
u'عوانة': u'عُوَانَةُ', #1
u'عوانة': u'عَوَانَةُ', #10
u'عوانة': u'عَوَانَةَ', #1210
u'عوانة': u'عوانة', #16
u'عوانة': u'عُوانة', #2
u'عوانة،': u'عَوَانَةَ،', #363
u'عوانة،': u'عوانة،', #41
u'عوانة': u'عَوَانَة', #6
u'عوائر': u'عَوَائِرِ', #1
u'عوائرا': u'عَوَائِرًا', #2
u'عوبد': u'عَوْبَدُ', #1
u'عوجر': u'عَوْجَرٍ', #1
u'عود': u'عُودً', #1
u'عودى': u'عُودى', #1
u'عودى': u'عُودِى', #2
u'عودى': u'عُودِىَ', #3
u'عوزم': u'عَوْزَمٍ', #1
u'عوشجة،': u'عَوْشَجَةَ،', #1
u'عوض': u'عِوَضً', #1
u'عولات': u'عَوْلَاتٍ', #14
u'عولة': u'عَوْلَةٌ', #3
u'عولة': u'عَوْلَةً', #8
u'عوليا': u'عَوْلِيًّا', #2
u'عولية': u'عَوْلِيَّةٌ', #2
u'عولية': u'عَوْلِيَّةً', #7
u'عومره': u'عَوْمَرَهْ', #1
u'عونة': u'عَوْنَةً', #1
u'عونة': u'عَوْنَةٌ', #1
u'عونة': u'عِوْنَةٌ', #2
u'عويج': u'عَوِيجِ', #1
u'عويج': u'عُوَيْجٍ', #1
u'عويج': u'عُوَيْجِ', #17
u'عويج': u'عويج', #2
u'عويدا': u'عُوَيْدًا', #1
u'عويف': u'عُوَيْفِ', #1
u'عويف': u'عُوَيْفٍ', #11
u'عويف': u'عُوَيْفَ', #2
u'عويلم': u'عُوَيْلِمٌ', #2
u'عويم': u'عُوَيْم', #1
u'عويم،': u'عُوَيْمٍ،', #1
u'عويم،': u'عُوَيْمُ،', #1
u'عويم': u'عُوَيْمِ', #14
u'عويم': u'عُوَيْمُ', #20
u'عويم': u'عويم', #5
u'عويم': u'عُوَيْمٌ', #6
u'عويم': u'عُوَيْمٍ', #6
u'عويم': u'عُوَيْمَ', #6
u'عويما': u'عُوَيْمًا', #1
u'عويمرا': u'عُوَيْمِرا', #1
u'عويمرا،': u'عُوَيْمِرًا،', #1
u'عويمرا': u'عُوَيْمِرًا', #42
u'عويمرإن': u'عُوَيْمِرٍإِنْ', #1
u'عويمل': u'عُوَيْمِلٌ', #1
u'عوينا': u'عَوِينًا', #1
u'عى': u'عَىَّ', #2
u'عياب': u'عِيَابُ', #1
u'عياب،': u'عَيَّابٍ،', #1
u'عياب': u'عَيَّابٍ', #3
u'عيابهم': u'عِيَابُهُمْ', #1
u'عيابين': u'عَيَّابِينَ', #1
u'عياد': u'عيَادِ', #1
u'عياد': u'عَيّادٍ', #1
u'عياد': u'عَيَّادُ', #3
u'عيادا': u'عِيَادًا', #1
u'عيارة': u'عِيَارَةً', #1
u'عيارة': u'عِيَارَةٌ', #1
u'عيارة': u'عِيَارَةٍ', #2
u'عياش': u'عَيّاش', #1
u'عياش': u'عِيَاشٌ', #1
u'عياش': u'عِيَاشٍ', #1
u'عياش': u'عِيَاشِ', #1
u'عياش': u'عَيَّاشٍ', #1006
u'عياش': u'عَيَّاشِ', #106
u'عياش': u'عَيَّاشٌ', #16
u'عياش': u'عَيَّاش', #19
u'عياش': u'عيّاش', #2
u'عياش،': u'عَيَّاشٌ،', #2
u'عياش': u'عَيَّاشَ', #29
u'عياش،': u'عيّاش،', #3
u'عياش': u'عَيّاشٍ', #31
u'عياش،': u'عَيَّاشٍ،', #330
u'عياش': u'عَيّاشُ', #4
u'عياش،': u'عياش،', #45
u'عياش': u'عياش', #52
u'عياش': u'عَيّاشِ', #7
u'عياش': u'عَيَّاشُ', #76
u'عياشا،': u'عَيَّاشًا،', #1
u'عياشا': u'عَيَّاشًا', #2
u'عياض': u'عِياضُ', #1
u'عياض،': u'عِيَاض،', #1
u'عياض،': u'ْعِيَاضٍ،', #1
u'عياض،': u'عياض،', #12
u'عياض،': u'عِيَاضٍ،', #120
u'عياض': u'عِيَاض', #123
u'عياض': u'عِيَاضِ', #164
u'عياض': u'عِيَاضٌ', #1954
u'عياض': u'عياض', #25
u'عياض': u'عِيَاضَ', #27
u'عياض،': u'عِيَاضٌ،', #3
u'عياض': u'عِياض', #4
u'عياض': u'عِيَاضٍ', #837
u'عياض': u'عِيَاضُ', #85
u'عياضا': u'عياضا', #1
u'عياضا،': u'عِيَاضًا،', #1
u'عياضا': u'عِيَاضًا', #34
u'عياضفي': u'عِيَاضٍفِي', #1
u'عيافة': u'عِيَافَةٍ', #1
u'عيافة': u'عِيَافَةُ', #1
u'عيافة': u'عِيَافَةِ', #1
u'عيافة': u'عِيَافَةً', #3
u'عيالات': u'عِيَالَاتٍ', #1
u'عيالاتهم': u'عِيَالَاتِهِمْ', #1
u'عيالاتهم': u'عَيَّالَاتُهُمْ', #2
u'عيالة': u'عِيَالَةٍ', #1
u'عيالكا': u'عِيَالِكَا', #1
u'عيالم': u'عَيَالِمِ', #2
u'عيالى': u'عِيَالِى', #4
u'عياياء': u'عَيَايَاءُ', #2
u'عيبة': u'عَيْبَة', #1
u'عيبة،': u'عَيْبَةَ،', #1
u'عيبة': u'عيبة', #2
u'عيبة': u'عَيْبَةٌ', #3
u'عيبة': u'عَيْبَةٍ', #4
u'عيبة': u'عَيْبَةُ', #4
u'عيبة': u'عَيْبَةَ', #8
u'عيبة': u'عَيْبَةً', #9
u'عيبتي': u'عيبتي', #1
u'عيبتي،': u'عِيبَتِي،', #1
u'عيبتي،': u'عَيْبَتِي،', #1
u'عيبتى': u'عيبتى', #1
u'عيبتى': u'عَيْبَتِى', #1
u'عيبتي': u'عَيْبَتِي', #13
u'عيبر': u'عَيْبَر', #2
u'عيبر': u'عَيْبَرَ', #5
u'عيجلون': u'عَيْجَلُونَ', #1
u'عيجلون': u'عَيْجَلُونُ', #2
u'عيدانة': u'عَيْدَانَة', #4
u'عيذاب': u'عَيْذَابُ', #1
u'عيذاب': u'عَيْذَابَ', #3
u'عيذاب': u'عَيْذَابٍ', #8
u'عيرانة': u'عَيْرَانَةٌ', #6
u'عيرة': u'عَيْرَةً', #1
u'عيرة': u'عَيْرَةٌ', #1
u'عيرتمونى': u'عَيَّرْتُمُونِى', #1
u'عيزار': u'عِيزَارٌ', #1
u'عيس': u'عيس', #1
u'عيس': u'عِيس', #1
u'عيس': u'عَيْسٍ', #1
u'عيس،': u'عَيْسٍ،', #1
u'عيس': u'عِيسٌ', #2
u'عيسا': u'عِيسًا', #1
u'عيساء': u'عَيْسَاءَ', #1
u'عيست': u'عيست', #1
u'عيسنت': u'عيسنت', #1
u'عيسوي': u'عِيسَوِيٌّ', #1
u'عيسوي': u'عِيسَوِيٍّ', #3
u'عيسويا': u'عِيسَوِيًّا', #10
u'عيسي': u'عيسي', #2
u'عيسي': u'عِيسَي', #2
u'عيشون': u'عَيْشُونَ', #1
u'عيشون،': u'عَيْشُونَ،', #1
u'عيشون': u'عَيْشُونٍ', #7
u'عيشونة': u'عَيْشُونَةَ', #1
u'عيشى': u'عيشى', #1
u'عيشى': u'عَيْشِى', #1
u'عيصا،': u'عيصا،', #1
u'عيصا': u'عِيصَا', #1
u'عيصا،': u'عِيصَا،', #1
u'عيصا،': u'عَيْصَا،', #2
u'عيصو': u'عِيصَو', #1
u'عيصو': u'عِيصُوِ', #1
u'عيصو': u'عيصو', #2
u'عيصو': u'عِيصُو', #5
u'عيطاء': u'عَيْطَاءَ', #1
u'عيطاء،': u'عَيْطَاءُ،', #2
u'عيطاء': u'عَيْطَاءُ', #7
u'عيطل': u'عَيْطَلٍ', #6
u'عيلانا': u'عَيْلَانًا', #1
u'عيلم': u'عَيْلَمٍ', #1
u'عيلولة': u'عَيْلُولَةٌ', #1
u'عيناء': u'عَيْنَاء', #1
u'عيناء': u'عَيْنَاءَ', #1
u'عيناء،': u'عَيْنَاءُ،', #1
u'عيناء': u'عَيْنَاءُ', #2
u'عيناى': u'عَيْنَاىَ', #16
u'عينون،': u'عَيْنُون،', #1
u'عينى': u'عَيْنِىَ', #1
u'عينى': u'عَيْنَىَّ', #14
u'عينى': u'عَيْنِى', #14
u'عينى': u'عَيْنَىِ', #2
u'عينيوالوجه': u'عَيْنِيوَالْوَجْهُ', #1
u'عيهامة': u'عيهامة', #1
u'عيهامة': u'عَيْهَامَةَ', #1
u'عيهامة': u'عَيْهَامَةُ', #3
u'عيهب': u'عَيْهَب', #1
u'عيهب': u'عَيْهَبُ', #1
u'عيهب': u'عَيْهَبِ', #1
u'عيهلة': u'عَيْهَلَةَ', #1
u'عيوفا': u'عَيُوفًا', #1
u'عيوق': u'عَيُّوقَ', #1
u'عيى': u'عيى', #1
u'عيى': u'عَيِىَ', #2
u'عييس5436id': u'عييس5436id', #1
u'عييس': u'عُيَيْس', #1
u'عييس': u'عُيَيْسٍ', #1
u'عييش': u'عُيَيْشٍ', #1
u'عييشا': u'عُيَيْشًا', #1
u'عييم': u'عُيَيْمِ', #1
u'عيينة،': u'عُيينة،', #1
u'عيينة': u'عُييْنَةَ', #1
u'عيينة': u'عُيَيَنْةَ', #1
u'عيينة': u'عُيَيْنَةٌ', #1
u'عيينة،': u'عُيَيْنة،', #2
u'عيينة': u'عُيَيْنَة', #20
u'عيينة': u'عُيَيْنَةُ', #219
u'عيينة': u'عُيَيْنة', #23
u'عيينة،': u'عيينة،', #25
u'عيينة': u'عُيَيْنَةَ', #2643
u'عيينة،': u'عُيَيْنَة،', #4
u'عيينة،': u'عُيَيْنَةُ،', #4
u'عيينة': u'عيينة', #7
u'عيينة،': u'عُيَيْنَةَ،', #713
u'عيينةأنه': u'عُيَيْنَةَأَنَّهُ', #1
u'عيينةعلى': u'عُيَيْنَةَعَلَى', #1
u'عيينة،قوله': u'عُيَيْنَةَ،قَوْلُهُ', #2
u'غابطا': u'غَابِطًا', #1
u'غابن': u'غَابِنِ', #1
u'غابنا': u'غَابِنًا', #1
u'غازى': u'غَازِى', #3
u'غاضر': u'غاضرُ', #1
u'غاضرة': u'غَاضِرَةُ', #3
u'غاضرة': u'غَاضِرَةَ', #4
u'غاطية': u'غَاطِيَةٌ', #1
u'غافصت': u'غَافَصْت', #1
u'غافصه': u'غَافَصَهُ', #3
u'غالطا': u'غَالِطًا', #60
u'غالطة': u'غَالِطَةً', #1
u'غالطون': u'غَالِطُونَ', #1
u'غالطين': u'غَالِطِينَ', #9
u'غامد': u'غامد', #1
u'غامد': u'غَامِدٌ', #2
u'غامد': u'غَامِدٍ', #24
u'غامد،': u'غَامِدٍ،', #3
u'غاور': u'غَاوَرَ', #2
u'غبذلك': u'غبِذَلِكَ', #1
u'غبرت': u'غَبَرْت', #1
u'غبرت،': u'غَبَرْتُ،', #1
u'غبرت': u'غَبَرْتُ', #4
u'غبروا': u'غُبِّرُوا', #1
u'غبس': u'غُبْسٌ', #1
u'غبط': u'غَبَطَ', #1
u'غبط': u'غَبِطَ', #1
u'غبط': u'غُبُطٌ', #3
u'غبطا': u'غَبْطًا', #1
u'غبطت': u'غَبَطْت', #1
u'غبطت': u'غَبَطْتُ', #3
u'غبطناهم': u'غَبَطْنَاهُمْ', #1
u'غبطه': u'غَبَطَهُ', #4
u'غبطوا': u'غُبِطُوا', #2
u'غبغب': u'غَبْغَبِ', #2
u'غبقته': u'غَبَقَتْهُ', #2
u'غبنت': u'غُبِنَتْ', #1
u'غبنت': u'غُبِنْتَ', #1
u'غبنت': u'غُبِنْتُ', #1
u'غبنت': u'غُبِنْت', #13
u'غبنت': u'غَبَنْت', #2
u'غبنتني': u'غَبَنْتنِي', #1
u'غبنتني': u'غَبَنْتَنِي', #2
u'غبنته': u'غَبَنْتُهُ', #1
u'غبنوا': u'غَبَنُوا', #2
u'غبنوا': u'غُبِنُوا', #5
u'غبوق': u'غَبُوقِ', #1
u'غبوق': u'غَبُوقٌ', #2
u'غبوقا': u'غَبُوقًا', #2
u'غبوقهما': u'غَبُوقَهُمَا', #4
u'غبونها': u'غُبُونِهَا', #1
u'غبي': u'غَبِيًّ', #1
u'غبى': u'غبى', #1
u'غبى': u'غَبِىَ', #1
u'غبى': u'غُبِىَ', #1
u'غبيراء': u'غُبَيْرَاءَ', #1
u'غبيراء': u'غُبَيْرَاءِ', #1
u'غبيط': u'غَبِيطُ', #1
u'غت': u'غَتُّ', #1
u'غتمي': u'غُتْمِيٌّ', #1
u'غثاة': u'غثاة', #1
u'غثاة': u'غُثَاةً', #1
u'غثور': u'غُثُورِ', #1
u'غثيم': u'غثيم', #1
u'غداالغادي': u'غَدَاالْغَادِي', #1
u'غداتئذ': u'غَدَاتَئِذٍ', #7
u'غداف': u'غُدَافٍ', #2
u'غدانة': u'غُدَانَةَ', #4
u'غداوما': u'غَدًاوَمَا', #1
u'غدائتذ': u'غَدَائتِذٍ', #1
u'غدرات': u'غَدَرَاتٍ', #1
u'غدراتك': u'غَدَرَاتُكَ', #1
u'غدراته': u'غَدَرَاتُهُ', #2
u'غدراته': u'غَدَرَاتِهِ', #2
u'غدفان': u'غِدْفَانٌ', #2
u'غدفان': u'غِدْفَانُ', #2
u'غدور': u'غَدُورٍ', #1
u'غديقة': u'غُدَيْقَة', #1
u'غديقة': u'غُدَيْقَةَ', #1
u'غديقة': u'غديقة', #3
u'غديقة': u'غُدَيْقَةٌ', #7
u'غذاءالوجه': u'غِذَاءًالْوَجْهُ', #1
u'غذاءقوله': u'غِذَاءًقَوْلُهُ', #1
u'غذرة': u'غُذْرَةَ', #1
u'غذوة': u'غُذْوَةً', #1
u'غرابر': u'غَرَابِرَ', #1
u'غرازة': u'غِرَازَةٍ', #1
u'غرائزا': u'غَرَائِزَا', #1
u'غرثان': u'غَرْثَانِ', #2
u'غرثت،': u'غَرِثْتَ،', #1
u'غرثهم': u'غَرَثُهُمْ', #1
u'غرثى': u'غَرْثَى', #16
u'غرزين': u'غَرْزَيْنِ', #1
u'غرشا': u'غرشا', #4
u'غرضوف': u'غُرْضُوفٌ', #1
u'غرقد': u'غَرْقَدٍ', #1
u'غرقدة،': u'غرقدة،', #1
u'غرقدة،': u'غَرْقَدَةَ،', #4
u'غرقدة': u'غَرْقَدَةَ', #40
u'غرل': u'غُرْلٌ', #3
u'غرلا': u'غرلا', #1
u'غرلا،': u'غُرْلا،', #1
u'غرلا': u'غرلاً', #2
u'غرلا،': u'غُرْلًا،', #2
u'غرلا': u'غُرْلًا', #30
u'غرلا': u'غُرْلاً', #5
u'غرلا': u'غُرْلا', #7
u'غرلة': u'غُرْلَةُ', #1
u'غرلة': u'غُرْلَةٌ', #2
u'غرلته': u'غُرْلَتِهِ', #1
u'غرلته': u'غُرْلَتَهُ', #3
u'غرماء': u'غُرَمَاءً', #1
u'غرمة': u'غَرْمَةً', #1
u'غرمول': u'غُرْمُولُ', #1
u'غرمولا': u'غُرْمُولًا', #1
u'غرموله': u'غُرْمُولَهُ', #1
u'غرنق': u'غُرْنَقٍ', #2
u'غرهءماه': u'غرهءماه', #1
u'غروة': u'غَرْوَةِ', #1
u'غروش': u'غروش', #1
u'غريث': u'غِرّيث', #1
u'غريف': u'غَرِيفٍ', #4
u'غزاء': u'غَزَّاءً', #1
u'غزاء،': u'غَزَّاءً،', #1
u'غزات': u'غَزَّاتِ', #1
u'غزات': u'غَزّاتٍ', #2
u'غزات': u'غَزَّاتُ', #2
u'غزات': u'غَزّاتِ', #4
u'غزاتى': u'غَزَاتِى', #1
u'غزاون،': u'غزاون،', #8
u'غزنة': u'غَزْنَةَ', #5
u'غزنوية': u'غَزْنَوِيَّةٌ', #1
u'غزولهم': u'غُزُولِهِمْ', #1
u'غزى': u'غُزًّى', #6
u'غزيا': u'غَزْيًا', #1
u'غزية': u'غَزِّيَّةَ', #1
u'غزية': u'غُزَيَّة', #1
u'غزية': u'غُزَيَّةُ', #1
u'غزية': u'غَزِيَّةَ', #104
u'غزية': u'غُزَيّةُ', #2
u'غزية': u'غَزِيّةُ', #3
u'غزية': u'غَزِيّةَ', #34
u'غزية': u'غَزِيّة', #4
u'غزية،': u'غَزِيَّةَ،', #41
u'غزية': u'غَزِيَّةُ', #5
u'غزية': u'غُزَيّةَ', #5
u'غزية': u'غزية', #8
u'غزيلة': u'غُزَيْلَةُ', #1
u'غس': u'غُسّ', #1
u'غس': u'غِسْ', #1
u'غشمشم': u'غَشَمْشَمٌ', #1
u'غشوش': u'غُشُوشُ', #1
u'غشوش': u'غُشُوشِ', #9
u'غشوشه': u'غُشُوشِهِ', #1
u'غشوشهم': u'غُشُوشِهِمْ', #3
u'غشينى': u'غَشِيَنِى', #2
u'غصبانى': u'غَصَبَانِى', #1
u'غصبتكه': u'غَصَبْتُكَهُ', #3
u'غصبتكها': u'غَصَبْتُكَهَا', #1
u'غصبتنيه': u'غَصَبَتْنِيهِ', #1
u'غصبتنيه': u'غَصَبْتَنِيهِ', #2
u'غصبتنيه': u'غَصَبْتنِيهِ', #5
u'غصبتنيها': u'غَصَبْتنِيهَا', #4
u'غصبتنيها': u'غَصَبْتَنِيهَا', #5
u'غصبكها': u'غَصَبَكهَا', #3
u'غصبنيه': u'غَصَبَنِيهِ', #4
u'غصبنيها': u'غَصَبَنِيهَا', #9
u'غصوب': u'غَصُوبٌ', #1
u'غصوب': u'غُصُوبٌ', #12
u'غصوب': u'غُصُوبٍ', #4
u'غصوبا': u'غُصُوبًا', #1
u'غصينة': u'غُصَيْنَةُ', #2
u'غصينة': u'غُصَيْنَةَ', #9
u'غضبانا': u'غَضْبَانًا', #9
u'غضبهوالوجه': u'غَضَبُهُوَالْوَجْهُ', #1
u'غضة': u'غَضَّةً', #4
u'غضفا': u'غُضْفَا', #2
u'غضوض': u'غُضُوضُ', #1
u'غضونات': u'غُضُونَاتِ', #1
u'غضيف': u'غُضَيْف', #1
u'غضيف': u'غُضَيْفٍِ', #1
u'غضيف،': u'غُضَيْفٌ،', #1
u'غضيف': u'غُضَيْفِ', #20
u'غضيف': u'غضيف', #3
u'غضيف': u'غُضَيْفٌ', #3
u'غضيف،': u'غُضَيْفٍ،', #3
u'غضيف': u'غُضَيْفٍ', #4
u'غضيف': u'غُضَيْفَ', #4
u'غضيف': u'غُضَيْفُ', #5
u'غطارفة': u'غَطَارِفَةً', #1
u'غطريفيا': u'غِطْرِيفِيًّا', #1
u'غطريفية': u'غِطْرِيفِيِّةٌ', #1
u'غطريفية': u'غِطْرِيفِيَّةٍ', #4
u'غطريفية': u'غِطْرِيفِيَّةً', #6
u'غطفاني': u'غَطَفَانِيّ', #1
u'غطفانية': u'غَطَفَانِيّةٍ', #1
u'غطونى': u'غطونى', #2
u'غطيان': u'غَطَيَانُ', #1
u'غطيف': u'غُطَيْفُ', #1
u'غطيف،': u'غُطَيْفٍ،', #1
u'غطيف': u'غطيف', #2
u'غطيف': u'غُطَيْفِ', #2
u'غطيف': u'غُطَيْفٍ', #25
u'غطيف': u'غَطِيف', #9
u'غفرSذكر': u'غَفَرَSذَكَرَ', #1
u'غفرةعن': u'غُفْرَةَعَنِ', #1
u'غفرةقلت': u'غُفْرَةَقُلْتُ', #1
u'غلاصم': u'غَلَاصِمُ', #3
u'غلافته': u'غَلَّافَتِهِ', #1
u'غلاق،': u'غِلاقٍ،', #1
u'غلاق': u'غَلَّاقٌ', #1
u'غلاق': u'غَلَّاقٍ', #2
u'غلاق': u'غِلاَقٍ', #2
u'غلاقتها': u'غَلَاقَتِهَا', #1
u'غلاقه': u'غِلَاقُهُ', #1
u'غلامى': u'غُلاَمِى', #8
u'غلبتنى': u'غَلَبَتْنِى', #2
u'غلبنى': u'غَلَبَنِى', #14
u'غلبون': u'غَلْبُونٍ', #4
u'غلث': u'غَلَثٌ', #1
u'غلث': u'غَلِثٌ', #1
u'غلث': u'غَلْثَ', #1
u'غلث': u'غَلْثِ', #1
u'غلث': u'غَلَثٍ', #2
u'غلث': u'غَلَثِ', #2
u'غلث': u'غَلِثٍ', #6
u'غلثا': u'غَلَثًا', #3
u'غلثا': u'غَلِثًا', #4
u'غلثا': u'غَلْثًا', #5
u'غلثت': u'غَلَثْت', #1
u'غلثه': u'غَلِثُهُ', #1
u'غلثه': u'غَلْثُهُ', #6
u'غلثه': u'غَلَثُهُ', #8
u'غلثها': u'غَلْثُهَا', #1
u'غلطى': u'غَلْطَى', #1
u'غلفى': u'غُلْفَى', #1
u'غلكثيره': u'غلِكَثِيرِهِ', #1
u'غلهاى': u'غلهاى', #2
u'غلوبا': u'غَلُوبًا', #1
u'غلوة': u'غَلْوَةً', #11
u'غلوة': u'غَلْوَةٌ', #2
u'غلوة': u'غَلْوَةٍ', #35
u'غلوة': u'غَلْوَةُ', #5
u'غلوة': u'غَلْوَةِ', #5
u'غلوطة': u'غَلُوطَةٌ', #1
u'غلوفا': u'غُلُوفًا', #1
u'غلوفى': u'غُلُوفَى', #2
u'غلوقا': u'غُلُوقًا', #1
u'غليب': u'غُلَيْبٍ', #18
u'غليب': u'غُلَيْبِ', #3
u'غليب،': u'غُلَيْبٍ،', #3
u'غليسية': u'غليسية', #1
u'غليط': u'غُلَيْطٍ', #1
u'غليم': u'غُلَيِّمٌ', #1
u'غليم': u'غُلَيِّمُ', #1
u'غليم،': u'غُلَيْمٌ،', #1
u'غليم': u'غُلَيْمٌ', #3
u'غماس': u'غِمَاسٍ', #1
u'غمامSحول': u'غَمّامِSحَوْلَ', #1
u'غمدت': u'غَمَدْتُ', #1
u'غمدوا': u'غَمَدُوا', #1
u'غمراء': u'غَمْرَاءُ', #2
u'غمرى': u'غُمَرِى', #1
u'غمزان': u'غَمْزَانَ', #1
u'غمزنى': u'غَمَزَنِى', #7
u'غمسات': u'غَمَسَاتٍ', #3
u'غمسة': u'غَمْسَة', #1
u'غمسة': u'غَمْسَةٍ', #3
u'غمسة': u'غَمْسَةً', #5
u'غمصاء': u'غَمْصَاءَ', #1
u'غمغمه': u'غَمْغَمَهْ', #3
u'غموس': u'غَمُوسَ', #1
u'غموس': u'غُمُوسٌ', #1
u'غموس': u'غَمُوسٍ', #21
u'غموس': u'غَمُوسٌ', #64
u'غموسا': u'غَمُوسًا', #89
u'غمى': u'غَمًى', #1
u'غمى': u'غَمَى', #1
u'غمى': u'غُمِّىَ', #2
u'غمى': u'غَمَّى', #4
u'غميت': u'غَمَّيْت', #1
u'غميس': u'غَمِيسُ', #1
u'غميس': u'غَمِيسِ', #3
u'غميض': u'غَمِيضٌ', #1
u'غنثر': u'غُنْثَرُ', #9
u'غنجار،': u'غُنْجَارٍ،', #1
u'غنجار،': u'غُنْجَارُ،', #1
u'غنمة،': u'غنمة،', #1
u'غنمة': u'غُنْمَةٍ', #1
u'غنمة،': u'غَنَمَةَ،', #1
u'غنمة': u'غَنَمَةَ', #13
u'غنمة': u'غنمة', #2
u'غنمة': u'غَنَمَة', #2
u'غنمة': u'غَنْمَةَ', #2
u'غنمنيها': u'غَنَّمَنِيهَا', #3
u'غنمى': u'غَنَمِى', #2
u'غنيم': u'غُنَيْم', #1
u'غنيم': u'غُنَيْمٌ', #1
u'غنيم': u'غنيم', #2
u'غنيم': u'غُنَيْمٍ', #3
u'غنيم': u'غُنَيْمَ', #4
u'غنيم': u'غُنَيْمُ', #6
u'غنيم': u'غُنَيْمِ', #9
u'غنيما': u'غُنَيْمًا', #2
u'غنيمات،': u'غُنَيْمَاتٍ،', #1
u'غنيمات': u'غُنَيْمَاتٍ', #5
u'غنيمي': u'غُنَيْمِيٌّ', #2
u'غواث': u'غُوَاثٌ', #2
u'غوار': u'غُوّارِ', #1
u'غوتركوك': u'غوَتَرَكُوكَ', #1
u'غوثاه،': u'غَوْثَاهْ،', #1
u'غوثاه': u'غَوْثَاهُ', #4
u'غوج': u'غَوْجٌ', #1
u'غوجي': u'غوجي', #1
u'غوراء': u'غَوْرَاءُ', #5
u'غوراء': u'غَوْرَاءَ', #63
u'غوراج': u'غَوْرَاجٌ', #1
u'غورث': u'غَوْرَثَ', #2
u'غورث': u'غُوْرَثُ', #2
u'غورث': u'غَوْرَثُ', #7
u'غورى': u'غَوْرَى', #2
u'غوزك': u'غَوْزَكُ', #1
u'غوزك،': u'غَوْزَكَ،', #1
u'غوش': u'غوش', #3
u'غوصة': u'غَوْصَة', #1
u'غوصة': u'غَوْصَةَ', #1
u'غوصة': u'غَوْصَةً', #8
u'غوطة': u'غُوطَةِ', #1
u'غوطة': u'غُوطَةُ', #3
u'غوغا': u'غَوْغًا', #1
u'غوغا': u'غوغا', #2
u'غوفص': u'غُوفِصَ', #1
u'غولتهم': u'غَوْلَتُهُمْ', #1
u'غويص': u'غَوِيصٌ', #1
u'غويص': u'غَوِيصِ', #1
u'غويم': u'غُوَيْمِ', #1
u'غيابت': u'غَيَابَتِ', #5
u'غياطل': u'غَيَاطِلَ', #3
u'غيال': u'غِيَالِ', #1
u'غياه': u'غَيَّاهُ', #7
u'غياهما': u'غَيَّاهُمَا', #1
u'غياياء': u'غَيَايَاءُ', #1
u'غياية': u'غياية', #1
u'غياية': u'غَيَايَة', #2
u'غياية': u'غَيَايَةٌ', #2
u'غيايتان': u'غَيَايَتَانِ', #10
u'غيبوبيته': u'غَيْبُوبِيَّتِهِ', #1
u'غية': u'غَيَّةٍ', #1
u'غيداء': u'غَيْدَاءُ', #2
u'غيداق': u'غَيْدَاقٍ', #2
u'غيدق': u'غَيْدَقَ', #1
u'غيدن': u'غَيْدَنُ', #1
u'غير': u'ًًًًغَيْرَ', #1
u'غير': u'غَيْرً', #2
u'غيرالقبلة': u'غَيْرِالْقِبْلَةِ', #1
u'غيرأنه': u'غَيْرَأَنَّهُ', #4
u'غيرتلك': u'غَيْرَتِلْكَ', #1
u'غيرجوار': u'غَيْرِجِوَارِ', #1
u'غيرسترة': u'غَيْرِسُتْرَةٍ', #1
u'غيرطهارة': u'غَيْرِطَهَارَةٍ', #1
u'غيرهاإرادة': u'غَيْرَهَاإِرَادَةَ', #1
u'غيرهاوالوجه': u'غَيْرُهَاوَالْوَجْهُ', #1
u'غيرهماكالتسبيح': u'غَيْرِهِمَاكَالتَّسْبِيحِ', #1
u'غيشان': u'غَيْشَانَ', #1
u'غيضوضتها': u'غَيْضُوضَتُهَا', #1
u'غيطانها': u'غِيطَانِهَا', #2
u'غيطانهم': u'غِيطَانِهِمْ', #2
u'غيظة': u'غَيْظَةٍ', #2
u'غيغ': u'غَيْغ', #1
u'غيغ': u'غَيْغِ', #2
u'غيقة': u'غَيْقَةَ', #5
u'غيلا': u'غَيْلًا', #3
u'غيله': u'غِيلَهُ', #2
u'غيلولة': u'غَيْلُولَةٌ', #1
u'غيوط': u'غُيُوطٌ', #1
u'فاءوا': u'فَاءُوا', #78
u'فإبارتهم': u'فَإِبَارَتُهُمْ', #1
u'فإباره': u'فَإِبَارُهُ', #4
u'فإباق': u'فَإِبَاقٌ', #1
u'فإباقه': u'فَإِبَاقُهُ', #3
u'فإباية': u'فَإِبَايَةُ', #1
u'فابت': u'فابت', #1
u'فابتاعنى': u'فَابْتَاعَنِى', #1
u'فابتدءوا': u'فَابْتَدَءُوا', #1
u'فابتداهم': u'فَابْتَدَاهُمْ', #1
u'فابتدر': u'فابتدر', #1
u'فابتدر': u'فَابْتَدَرَ', #14
u'فابتدراه': u'فَابْتَدَرَاهُ', #12
u'فابتدرت': u'فَابْتُدِرَتْ', #2
u'فابتدرت': u'فَابْتَدَرْتُ', #3
u'فابتدرت': u'فَابْتَدَرَتْ', #8
u'فابتدرتنى': u'فَابْتَدَرَتْنِى', #1
u'فابتدرته': u'فَابْتَدَرَتْهُ', #1
u'فابتدرناه': u'فَابْتَدَرْنَاهُ', #12
u'فابتدرناها': u'فابتدرناها', #1
u'فابتدرناها': u'فَابْتَدَرْنَاهَا', #9
u'فابتدره': u'فَابْتَدَرُه', #1
u'فابتدره': u'فَابْتَدَرَهُ', #17
u'فابتدرها': u'فَابْتَدَرَهَا', #2
u'فابتدروا': u'فَابْتَدَرُوا', #4
u'فابتدروها': u'فَابْتَدِرُوهَا', #1
u'فابتدي': u'فَابْتَدِي', #1
u'فابتدى': u'فَابْتَدَى', #1
u'فابدءوا': u'فَابْدَءُوا', #72
u'فابدءوه': u'فَابْدَءُوهُ', #2
u'فابدؤا': u'فَابْدَؤُا', #2
u'فابدئى': u'فَابْدَئِى', #2
u'فابذرى': u'فَابْذُرِى', #1
u'فابرءوا': u'فَابْرَءُوا', #2
u'فأبرءوه': u'فَأَبْرَءُوهُ', #1
u'فأبردوا': u'فَأَبْرِدُوا', #69
u'فأبردوها': u'فَأَبْرِدُوهَا', #23
u'فأبرؤه': u'فَأَبْرَؤُهُ', #1
u'فابرؤه': u'فَابْرُؤْهُ', #1
u'فإبريسم': u'فَإِبْرِيسَمٌ', #1
u'فإبريسم': u'فَإِبْرَيْسَمٌ', #2
u'فإبضاع': u'فَإِبْضَاعٌ', #8
u'فأبضعاه': u'فَأَبْضَعَاهُ', #2
u'فابعد': u'فَابْعُدْ', #1
u'فابعدي': u'فَابْعُدِي', #1
u'فأبقنى': u'فَأَبْقِنِى', #1
u'فأبلس': u'فَأَبْلَسَ', #1
u'فأبنوهم': u'فَأَبَنُوهُمْ', #1
u'فأبهش': u'فَأَبْهَشَ', #1
u'فأبواالوجه': u'فَأَبَوْاالْوَجْهُ', #1
u'فأبيعكه': u'فَأَبِيعُكَهُ', #1
u'فأبيعكها': u'فَأَبِيعُكهَا', #1
u'فأبيعكها': u'فَأَبِيعُكَهَا', #1
u'فأبىفنزلت': u'فَأَبَىفَنَزَلَتْ', #1
u'فاتأب': u'فَاتَّأَبَ', #1
u'فأتألفهم': u'فَأَتَأَلَّفُهُمْ', #2
u'فأتانى': u'فَأَتَانِى', #16
u'فاتبعنى': u'فَاتَّبَعَنِى', #1
u'فاتبعنى': u'فَاتَّبِعْنِى', #2
u'فاتبعونى': u'فَاتَّبَعُونِى', #1
u'فاتتنى': u'فَاتَتْنِى', #1
u'فأتتنى': u'فَأَتَتْنِى', #8
u'فاتخذى': u'فَاتَّخِذِى', #1
u'فاتذأ': u'فاتَّذَأ', #1
u'فاتركى': u'فَاتْرُكِى', #4
u'فاتزرى': u'فَاتَّزِرِى', #1
u'فاتضعت': u'فَاتُّضِعْتُ', #1
u'فاتعدا': u'فَاتّعَدَا', #1
u'فاتعدت': u'فَاتّعَدْت', #1
u'فاتعدت': u'فَاتَّعَدْتُ', #1
u'فاتعدوا': u'فَاتّعَدُوا', #3
u'فأتعرقه': u'فَأَتَعَرَّقُهُ', #2
u'فأتفكت': u'فَأْتَفَكَتْ', #1
u'فاتقانى': u'فَاتَّقَانِى', #1
u'فاتقنا': u'فَاتَّقِنًا', #1
u'فأتقنح': u'فَأَتَقَنَّحُ', #1
u'فاتقول': u'فاتقول', #1
u'فاتلا': u'فاتلا', #1
u'فاتلا': u'فَاتِلًا', #1
u'فأتنف': u'فَأْتَنِفْ', #1
u'فاتنى': u'فَاتَنِى', #6
u'فأتنى': u'فَأْتِنِى', #8
u'فاتهب': u'فَاتّهِبْ', #1
u'فاتهبه': u'فَاتَّهَبَهُ', #1
u'فأتواالنبي': u'فَأَتَوُاالنَّبِيَّ', #2
u'فأتوجز': u'فَأَتَوَجَّزُ', #1
u'فأتونى': u'فَأْتَوْنِى', #1
u'فأتونى': u'فَأْتُونِى', #5
u'فاتى': u'فاتى', #1
u'فاتئد': u'فَاتَّئِدْ', #3
u'فأتيانى': u'فَأْتِيَانِى', #1
u'فاثرت': u'فَاثَّرَتْ', #1
u'فاثور': u'فاثور', #1
u'فاثور': u'فَاثُورٍ', #1
u'فاثور': u'فَاثُورِ', #1
u'فاثور': u'فَاثُورَ', #3
u'فأجاءها': u'فَأَجَاءَهَا', #18
u'فأجأبوه،': u'فَأَجَأَبُوهُ،', #1
u'فأجأتها': u'فَأَجَأْتهَا', #1
u'فأجأزت': u'فأجأزت', #1
u'فأجازنى': u'فَأَجَازَنِى', #8
u'فأجافوا': u'فَأَجَافُوا', #5
u'فأجأناكم': u'فَأَجَأْنَاكُمْ', #2
u'فاجتال': u'فَاجْتَالَ', #1
u'فاجتالتهم': u'فَاجْتَالَتْهُمْ', #2
u'فاجتبذ': u'فَاجْتَبَذَ', #3
u'فاجتبذه': u'فَاجْتَبَذَهُ', #2
u'فاجتبذهما': u'فَاجْتَبَذَهُمَا', #1
u'فاجتزأ': u'فَاجْتَزَأَ', #2
u'فاجتزأت': u'فَاجْتَزَأْت', #1
u'فاجتزأت': u'فَاجْتَزَأْتَ', #1
u'فاجتزرتها': u'فَاجْتَزَرْتُهَا', #3
u'فاجتزرناها': u'فَاجْتَزَرْنَاهَا', #1
u'فاجتزئ': u'فَاجْتَزِئْ', #11
u'فاجتس': u'فَاجْتَسَّ', #1
u'فاجتلد': u'فَاجْتَلَدَ', #1
u'فاجتلدت': u'فَاجْتَلَدَتْ', #1
u'فأجتمعوا': u'فَأَجْتَمَعُوا', #1
u'فاجتنبنى': u'فَاجْتَنِبْنِى', #1
u'فاجتنبوهSوذكر': u'فَاجْتَنِبُوهُSوَذَكَرَ', #1
u'فاجتووا': u'فاجْتَوَوا', #1
u'فاجتووا،': u'فَاجْتَوَوْا،', #1
u'فاجتووا': u'فَاجْتَوَوُا', #11
u'فاجتووا': u'فَاجْتَوَوْا', #21
u'فاجتووها': u'فَاجْتَوَوْهَا', #15
u'فاجتووها،': u'فَاجْتَوَوْهَا،', #3
u'فاجتويتها': u'فَاجْتَوَيْتُهَا', #1
u'فاجتوينا': u'فَاجْتَوَيْنَا', #1
u'فاجتويناها': u'فَاجْتَوَيْنَاهَا', #2
u'فاجث': u'فَاجْثُ', #1
u'فأجحفها': u'فَأَجْحَفَهَا', #1
u'فأجحفهم': u'فَأَجْحَفَهُمْ', #1
u'فاجدح': u'فَاجْدَحْ', #17
u'فأجدنى': u'فَأَجِدُنِى', #3
u'فأجرنى': u'فَأْجُرْنِى', #1
u'فأجزأت': u'فَأَجْزَأَتْ', #13
u'فأجزأته': u'فَأَجْزَأَتْهُ', #7
u'فأجزأتهم': u'فَأَجْزَأَتْهُمْ', #1
u'فاجعلنى': u'فَاجْعَلْنِى', #2
u'فاجعلى': u'فَاجْعَلِى', #1
u'فأجفت': u'فَأَجَفْت', #1
u'فأجلسنى': u'فَأَجْلَسَنِى', #3
u'فأجلسونى': u'فَأَجْلَسُونِى', #1
u'فأجمرت': u'فَأَجْمَرَتْ', #1
u'فأجمروا': u'فَأَجْمِرُوا', #1
u'فأجمروه': u'فَأَجْمِرُوهُ', #3
u'فاجمعى': u'فَاجْمَعِى', #1
u'فاجهضوهم': u'فَاجْهَضُوهُمْ', #1
u'فأجىء': u'فَأَجِىءُ', #2
u'فاجئة': u'فَاجِئَةُ', #5
u'فأجيحت': u'فَأُجِيحَتْ', #19
u'فأجيئك': u'فَأَجِيئُكَ', #1
u'فأجيئهما': u'فَأَجِيئُهُمَا', #1
u'فأحاطوابه': u'فَأَحَاطُوابِهِ', #1
u'فاحتاجها': u'فَاحْتَاجَهَا', #1
u'فاحتجبى': u'فَاحْتَجِبِى', #1
u'فاحتجر': u'فَاحْتَجَرَ', #2
u'فاحتجرت': u'فاحتجرت', #1
u'فاحتجم': u'فَاحْتَجِمْ', #1
u'فاحتجم': u'فَاحْتَجَمَ', #5
u'فاحتجموا،': u'فَاحْتَجَمُوا،', #1
u'فاحتجموا': u'فَاحْتَجَمُوا', #3
u'فاحترزتها': u'فَاحْتَرَزْتُهَا', #1
u'فاحتز': u'فَاحْتَزْ', #1
u'فاحتز': u'فَاحْتَزّ', #2
u'فاحتز': u'فَاحْتَزَّ', #4
u'فاحتززت': u'فَاحْتَزَزْتُ', #5
u'فاحتززنا': u'فَاحْتَزَزْنَا', #1
u'فاحتزم': u'فَاحْتَزَمَ', #1
u'فاحتسباوصبرا': u'فَاحْتَسَبَاوَصَبَرَا', #1
u'فاحتش': u'فَاحْتَشَّ', #1
u'فاحتطبى': u'فَاحْتَطِبِى', #1
u'فاحتفر': u'فَاحْتَفَرَ', #1
u'فاحتفر': u'فَاحْتُفِرَ', #1
u'فاحتفرت': u'فَاحْتَفَرْتُ', #1
u'فاحتفره': u'فَاحْتَفَرَهُ', #1
u'فاحتفرها': u'فَاحْتَفَرَهَا', #1
u'فاحتفروا': u'فَاحْتَفَرُوا', #1
u'فاحتفروا': u'فَاحْتَفِرُوا', #1
u'فاحتفز': u'فَاحْتَفَزَ', #2
u'فاحتفزت': u'فَاحْتَفَزْتُ', #3
u'فاحتيطا': u'فَاحْتِيطَا', #1
u'فأحجرناهم': u'فَأَحْجَرْنَاهُمُ', #2
u'فأحجروهم': u'فَأَحْجَرُوهُمْ', #1
u'فأحجنى': u'فَأَحِجَّنِى', #1
u'فأحجوا': u'فَأَحَجُّوا', #10
u'فاحداها': u'فاحداها', #1
u'فأحذاه': u'فَأَحْذَاهُ', #1
u'فإحذروا': u'فَإحْذَرُوا', #1
u'فاحذم': u'فَاحْذِمْ', #4
u'فأحراد': u'فَأَحْرَادٌ', #1
u'فأحرقونى': u'فَأَحْرِقُونِى', #2
u'فأحرمى': u'فَأَحْرِمِى', #1
u'فأحسبني': u'فَأَحْسَبُنِي', #1
u'فاحسنوا': u'فاحسنوا', #1
u'فأحسنى': u'فَأَحْسِنِى', #2
u'فاحشتني': u'فَاحَشْتَنِي', #1
u'فأحشفت': u'فَأَحْشَفَتْ', #2
u'فأحصرتم،': u'فَأُحْصِرْتُمْ،', #1
u'فاحفظكان': u'فَاحْفَظْكَانَ', #1
u'فأحقلت': u'فَأَحْقَلَتْ', #1
u'فأحلكها': u'فَأَحْلَكُهَا', #1
u'فاحمار': u'فَاحْمَارَّ', #3
u'فاحملنى': u'فَاحْمِلْنِى', #2
u'فاحملونى': u'فَاحْمِلُونِى', #1
u'فأحنثته': u'فَأَحْنَثَتْهُ', #3
u'فأحيى': u'فأحيى', #1
u'فأحيى': u'فَأَحْيَى', #1
u'فأخبأنا': u'فَأَخْبَأْنَا', #1
u'فأخبرتنى': u'فَأَخْبَرَتْنِى', #8
u'فأخبرنى': u'فَأَخْبِرْنِى', #27
u'فأخبرنى': u'فَأَخْبَرَنِى', #54
u'فأخبرنيمحمد': u'فَأَخْبَرَنِيمُحَمَّدُ', #1
u'فأخبرنيه': u'فَأَخْبَرَنِيهِ', #1
u'فأخبرنيه،': u'فَأَخْبَرَنِيهِ،', #1
u'فأخبرونى': u'فَأَخْبَرُونِى', #11
u'فأخبرونى': u'فَأَخْبِرُونِى', #2
u'فأخبرينى': u'فَأَخْبِرِينِى', #1
u'فأخبزت': u'فَأَخْبَزَتْ', #1
u'فأخبئني': u'فَأَخْبِئْنِي', #1
u'فاختبط': u'فَاخْتَبَطَ', #1
u'فاختة': u'فَاخْتَةَ', #1
u'فاختة': u'فاختة', #3
u'فاختة،': u'فاختة،', #3
u'فاختة': u'فَاخِتَةً', #3
u'فاختة': u'فَاخِتَةَ', #34
u'فاختة،': u'فَاخِتَةَ،', #6
u'فاختة': u'فَاخِتَةُ', #8
u'فاختدمه': u'فَاخْتَدَمَهُ', #1
u'فاخترج': u'فَاخْتَرَجَ', #3
u'فاخترط': u'فَاخْتَرَطَ', #6
u'فاخترطت': u'فَاخْتَرَطْتُ', #4
u'فاخترطه،': u'فَاخْتَرَطَهُ،', #1
u'فاخترطه': u'فَاخْتَرَطَهُ', #5
u'فاخترم': u'فَاخْتَرَمَ', #1
u'فاخترمته': u'فَاخْتَرَمَتْهُ', #3
u'فاختضعت': u'فَاخْتَضَعْت', #1
u'فاختضعت': u'فَاخْتَضَعْتُ', #1
u'فاختطب،': u'فَاخْتَطَبَ،', #1
u'فاختطب': u'فَاخْتَطَبَ', #6
u'فاختلع': u'فَاخْتَلَعَ', #4
u'فاختلعت': u'فَاخْتَلَعْتُ', #1
u'فاختلعت': u'فَاخْتُلِعَتْ', #2
u'فاختلعت': u'فَاخْتَلَعَتْ', #26
u'فاختلعها': u'فَاخْتَلَعَهَا', #5
u'فاختنثه': u'فَاخْتَنَثَهُ', #1
u'فاختنثها': u'فَاخْتَنَثَهَا', #1
u'فاختنست': u'فاختنست', #1
u'فاخذت': u'فَاخَذْتُ', #4
u'فاخذت': u'فَاخَذْتَ', #7
u'فأخذتنى': u'فَأَخَذَتْنِى', #2
u'فأخذنى': u'فَأَخَذَنِى', #13
u'فأخذونى': u'فَأَخَذُونِى', #2
u'فأخربت': u'فَأَخْرَبَتْ', #1
u'فأخربوها،': u'فأخربوها،', #1
u'فأخرجانى': u'فَأَخْرَجَانِى', #1
u'فاخرجى': u'فَاخْرُجِى', #4
u'فأخرقت': u'فَأَخْرَقَتْ', #1
u'فأخرقوا': u'فَأَخْرَقُوا', #1
u'فأخرنى': u'فَأَخَّرَنِى', #2
u'فأخرواالصلاة': u'فَأَخِّرُواالصَّلاَةَ', #1
u'فاخشون،': u'فَاخْشَوْنِ،', #1
u'فأخصرتهم': u'فَأَخْصَرَتْهُمْ', #1
u'فأخصية': u'فَأَخَصِّيَّةُ', #1
u'فأخلفنى': u'فَأَخْلَفَنِى', #1
u'فإخمال': u'فَإِخْمَالُ', #2
u'فأخمصت': u'فَأُخْمِصَتْ', #1
u'فاخورة': u'فَاخُورَةٍ', #1
u'فأدارنى': u'فَأَدَارَنِى', #5
u'فادان': u'فَادَّانَ', #12
u'فأدخلتنى': u'فَأَدْخَلَتْنِى', #3
u'فأدخلنى': u'فَأَدْخَلَنِى', #2
u'فأدخلونى': u'فَأَدْخِلُونِى', #1
u'فادرءوا': u'فَادْرَءُوا', #12
u'فادرءوه': u'فَادْرَءُوهُ', #1
u'فأدربنا': u'فَأَدْرَبْنَا', #3
u'فأدركنى': u'فَأَدْرَكَنِى', #2
u'فادركوا': u'فَادْرَكُوا', #1
u'فأدركونى': u'فَأَدْرَكُونِى', #1
u'فادعونى': u'فَادْعُونِى', #2
u'فادفعى': u'فَادْفَعِى', #1
u'فأدمانة': u'فأُدْمانَةٍ', #1
u'فأدمانة': u'فَأُدْمَانَةٍ', #1
u'فادنى': u'فَادِنِى', #1
u'فأدونية': u'فَأَدْوَنِيَّةُ', #1
u'فاذ': u'فَاذٍّ', #1
u'فاذا': u'فاذا', #1
u'فإذارسول': u'فَإِذَارَسُولُ', #1
u'فإذاعملها': u'فَإِذَاعَمِلَهَا', #1
u'فأذراه': u'فَأَذْرَاهُ', #3
u'فأذرت': u'فَأَذْرَتْ', #1
u'فأذروني': u'فَأَذْرُونِي', #2
u'فاذشاه': u'فَاذشاه', #1
u'فاذشاه': u'فَاذشَاهَ', #1
u'فاذشاه': u'فَاذِشَاهَ', #1
u'فأذكرني': u'فَأَذْكَرَنِي', #1
u'فأذكرنيه': u'فَأَذْكَرَنِيهِ', #1
u'فاذكرونهن': u'فَاذْكُرُونَهُنَّ', #1
u'فاذكرى': u'فَاذْكُرِى', #1
u'فآذننى': u'فَآذِنَّنِى', #7
u'فآذنونى': u'فَآذِنُونِى', #2
u'فآذنى': u'فَآذِنِّى', #4
u'فآذنينى': u'فَآذِنِينِى', #8
u'فاذهبى': u'فَاذْهَبِى', #9
u'فأذيود': u'فأذيود', #1
u'فاراب': u'فَارَابَ', #2
u'فاراد': u'فَارَادَ', #1
u'فاراد': u'فَارَاد', #3
u'فأرانى': u'فَأَرَانِى', #2
u'فأرانيه': u'فَأَرَانِيهِ', #2
u'فأربحني': u'فَأَرْبَحَنِي', #1
u'فارتتق': u'فَارْتَتَقَ', #1
u'فارتث': u'فَارتُثَّ', #1
u'فارتث': u'فَارْتَثَّ', #1
u'فارتث': u'فَارْتُثَّ', #1
u'فارتث': u'فَارْتُثّ', #5
u'فأرتجز،': u'فَأَرْتَجِزُ،', #1
u'فأرتجز': u'فَأَرْتَجِزُ', #2
u'فارتجز': u'فَارْتَجَزَ', #3
u'فارتجع': u'فَارْتَجَعَ', #4
u'فارتجعت': u'فَارْتَجَعْتُ', #1
u'فارتجعت': u'فَارْتُجِعَتْ', #1
u'فارتجعتها': u'فَارْتَجَعْتهَا', #1
u'فارتجعه': u'فَارْتَجِعْهُ', #5
u'فارتجعها،': u'فَارْتَجِعْهَا،', #1
u'فارتجعها': u'فَارْتَجِعْهَا', #2
u'فارتجعها': u'فَارْتَجَعَهَا', #5
u'فارتجعهما': u'فَارْتَجِعْهُمَا', #4
u'فارتضع': u'فَارْتَضَعَ', #13
u'فارتضعت': u'فَارْتَضَعَتْ', #19
u'فارتضعته': u'فَارْتَضَعَتْهُ', #1
u'فارتضعتها': u'فَارْتَضَعَتْهَا', #5
u'فارتعج': u'فَارْتَعَجَ', #3
u'فارتعجت': u'فَارْتَعَجَتْ', #2
u'فارتغم': u'فَارْتَغَمَ', #1
u'فارتفض': u'فَارْتُفِضَ', #1
u'فارتفض': u'فَارْتَفَضَ', #2
u'فارتفق': u'فَارْتَفَقَ', #1
u'فارتهنه': u'فَارْتَهَنَهُ', #3
u'فارجعى': u'فَارْجِعِى', #6
u'فارحضوها': u'فَارْحَضُوهَا', #7
u'فإردب': u'فَإِرْدَبٌّ', #1
u'فاردتكم': u'فَارِدَتُكُمْ', #3
u'فأردفنى': u'فَأَرْدَفَنِى', #7
u'فأرزقوهم': u'فَأرْزُقُوهُمْ', #1
u'فأرساله': u'فَأَرْسَاله', #1
u'فارسكور': u'فَارَسْكُورَ', #3
u'فأرسلنى': u'فَأَرْسَلَنِى', #13
u'فأرسلون': u'فَأَرْسِلُونِ', #4
u'فارسى': u'فَارِسِىٍّ', #1
u'فارسى': u'فَارِسِىُّ', #6
u'فأرشان': u'فَأَرَشَانِ', #1
u'فأرضنى': u'فَأَرْضِنِى', #1
u'فارفدوهمSحديث': u'فَارْفِدُوهُمْSحَدِيثُ', #1
u'فارفضضت': u'فَارْفَضَضْتُ', #1
u'فإرقاقهم': u'فَإِرْقَاقُهُمْ', #1
u'فارقدوه،': u'فَارْقُدُوهُ،', #1
u'فارقنى': u'فَارِقْنِى', #1
u'فارقون': u'فَارِقُونَ', #2
u'فاركعها': u'فَارْكَعْهَا', #1
u'فاركعهما': u'فَارْكَعْهُمَا', #6
u'فأرملوا': u'فَأَرْمَلُوا', #2
u'فأرناه': u'فَأَرِنَاهُ', #2
u'فأرنت': u'فَأَرْنَتْ', #2
u'فارهبون': u'فَارْهَبُونَ', #1
u'فارهبون': u'فَارْهَبُونِ', #9
u'فأرونيه،': u'فَأَرْوَنِيهِ،', #1
u'فازإن': u'فَازَإِنْ', #1
u'فازدلف': u'فَازْدَلِفْ', #2
u'فازدلف': u'فَازْدَلَفَ', #8
u'فأزوجت': u'فَأَزْوَجَتْ', #1
u'فأزيب': u'فَأَزْيَبُ', #1
u'فأزيدكموه': u'فَأَزِيدَكُمُوهُ', #2
u'فأزيدكموه؟': u'فَأَزِيدُكُمُوهُ؟', #2
u'فاسا': u'فَاسًا', #2
u'فأسألوه': u'فَأَسْأَلُوهُ', #2
u'فأسألوهن': u'فَأَسْأَلُوهُنَّ', #1
u'فاستأجل': u'فَاسْتَأْجَلَ', #1
u'فاستأجله': u'فَاسْتَأْجَلَهُ', #1
u'فاستأخرى': u'فَاسْتَأْخِرِى', #3
u'فاستأدت': u'فَاسْتَأْدَتْ', #1
u'فاستاس': u'فَاسْتَاسَ', #1
u'فاستأسر': u'فَاسْتَأْسَرَ', #3
u'فاستأسرته': u'فَاسْتَأْسَرَتْهُ', #1
u'فاستأسروا': u'فَاسْتَأْسَرُوا', #2
u'فاستاق': u'فَاسْتَاقَ', #6
u'فاستاقه': u'فَاسْتَاقَهُ', #5
u'فاستاقها،': u'فَاسْتَاقَهَا،', #1
u'فاستاقها': u'فَاسْتَاقَهَا', #4
u'فاستاقوا': u'فَاسْتَاقُوا', #5
u'فاستاقوه،': u'فَاسْتَاقُوهُ،', #1
u'فاستاقوها': u'فَاسْتَاقُوهَا', #1
u'فاستاقوهم': u'فَاسْتَاقُوهُمْ', #1
u'فاستاقوهن،': u'فاستاقوهنّ،', #1
u'فاستاقوهن': u'فَاسْتَاقُوهُنّ', #1
u'فاستاك': u'فَاسْتَاك', #1
u'فاستاك': u'فَاسْتَاكَ', #10
u'فاستاكوا': u'فَاسْتَاكُوا', #18
u'فاستام': u'فَاسْتَامَ', #1
u'فأستأمن': u'فَأَسْتَأْمِنُ', #1
u'فاستأمن،': u'فَاسْتَأْمَنَ،', #1
u'فاستأمن': u'فَاسْتَأْمَنَ', #9
u'فاستأمنت': u'فَاسْتَأْمَنَتْ', #5
u'فأستأمنه': u'فَأَسْتَأْمِنَهُ', #1
u'فاستأمنه': u'فَاسْتَأْمَنَهُ', #1
u'فاستأمنه': u'فَاسْتَأْمِنْهُ', #3
u'فاستأمنوا': u'فَاسْتَأْمَنُوا', #1
u'فاستأمنوه': u'فَاسْتَأْمَنُوهُ', #1
u'فاستأمنوهم': u'فَاسْتَأْمَنُوهُمْ', #1
u'فاستامها': u'فَاسْتَامَهَا', #2
u'فاستب': u'فَاسْتَبَّ', #5
u'فاستبا': u'فَاسْتَبّا', #1
u'فاستبا': u'فَاسْتَبَّا', #2
u'فاستبا،': u'فَاسْتَبَّا،', #2
u'فاستباع': u'فَاسْتَبَاعَ', #3
u'فاستباعت': u'فَاسْتَبَاعَتْ', #1
u'فاستبذلوا': u'فَاسْتَبْذَلُوا', #1
u'فاستبرءه،': u'فَاسْتَبْرَءَهُ،', #1
u'فاستبراها': u'فَاسْتَبْرَاهَا', #1
u'فاستبضعي': u'فَاسْتَبْضِعِي', #3
u'فاستبكيت': u'فَاسْتَبْكَيْت', #1
u'فاستبكيت': u'فَاسْتَبْكَيْتُ', #1
u'فاستتابها': u'فَاسْتَتَابَهَا', #2
u'فاستتابهم': u'فَاسْتَتَابَهُمْ', #7
u'فاستتبته': u'فَاسْتَتَبْتَهُ', #1
u'فاستتبعنى': u'فَاسْتَتْبَعَنِى', #1
u'فاستتبه': u'فَاسْتَتِبْهُ', #3
u'فاستتبها': u'فَاسْتَتِبْهَا', #1
u'فاستتم': u'فَاسْتَتَمّ', #2
u'فاستتم': u'فَاسْتَتَمَّ', #4
u'فاستتموا': u'فَاسْتَتِمُّوا', #1
u'فاستتيب': u'فَاسْتُتِيبَ', #1
u'فاستثبت': u'فَاسْتَثْبَتَ', #2
u'فاستثبت': u'فَاسْتَثْبَتُّ', #3
u'فاستثبته': u'فَاسْتَثْبَتُّهُ', #1
u'فاستثفرت': u'فَاسْتَثْفَرْتُ', #1
u'فاستجاز': u'فَاسْتَجَازَ', #1
u'فاستجازت': u'فَاسْتَجَازَتْ', #1
u'فاستجازه': u'فَاسْتَجَازَهُ', #2
u'فاستجال': u'فَاسْتَجَالَ', #4
u'فاستجسد': u'فَاسْتَجْسَدَ', #2
u'فاستجعل': u'فَاسْتَجْعَلَ', #1
u'فاستجمد': u'فَاسْتَجْمَدَ', #1
u'فاستجمر': u'فَاسْتَجْمَرَ', #1
u'فاستجمرت': u'فَاسْتَجْمَرَتْ', #2
u'فاستجهله': u'فَاسْتَجْهَلَهُ', #1
u'فأستجهله': u'فَأَسْتَجْهِلُهُ', #2
u'فأستجيد': u'فَأَسْتَجِيدُ', #1
u'فأستجيدها': u'فَأَسْتَجِيدُهَا', #3
u'فاستح': u'فَاسْتَحِ', #1
u'فاستحاضة': u'فَاسْتِحَاضَةٌ', #14
u'فاستحر': u'فَاسْتَحَرَّ', #1
u'فاستحشف': u'فَاسْتَحْشَفَ', #1
u'فاستحشف': u'فَاسْتُحْشِفَ', #1
u'فاستحشفت': u'فَاسْتَحْشَفَتْ', #2
u'فاستحصنت': u'فَاسْتَحْصَنَتْ', #1
u'فاستحقاقة': u'فَاسْتِحْقَاقَةُ', #1
u'فاستحلفنى': u'فَاسْتَحْلَفَنِى', #2
u'فاستحمقه': u'فَاسْتَحْمَقَهُ', #1
u'فاستحى،': u'فَاسْتَحَى،', #1
u'فاستحى': u'فَاسْتَحَى', #7
u'فاستحيت': u'فاستحيت', #1
u'فاستحيت': u'فَاسْتَحَيْتُ', #3
u'فاستحيت': u'فَاسْتَحْيَتْ', #7
u'فاستحيتهSكيسة': u'فَاسْتَحْيَتْهُSكَيّسَةُ', #1
u'فاستحيته': u'فَاسْتَحْيَتْهُ', #1
u'فاستحيضت': u'فَاسْتُحِيضَتْ', #7
u'فاستحيى': u'فَاسْتَحْيَى', #5
u'فاستخار': u'فَاسْتَخَارَ', #3
u'فاستخبأت': u'فَاسْتَخْبَأْتُ', #1
u'فاستخباث': u'فَاسْتِخْبَاثُ', #1
u'فاستخر': u'فَاسْتَخِرْ', #5
u'فاستخرت': u'فَاسْتَخَرْت', #10
u'فاستخرت': u'فَاسْتَخَرْتُ', #4
u'فاستخشف': u'فَاسْتَخْشَفَ', #1
u'فاستخلاه': u'فَاسْتَخْلاَهُ', #1
u'فاستد': u'فَاسْتَدَّ', #1
u'فاستدارني': u'فَاسْتَدَارَنِي', #1
u'فاستدخلت': u'فَاسْتَدْخَلَتْ', #1
u'فاستدخلته': u'فَاسْتَدْخَلَتْهُ', #18
u'فاستدخلتها': u'فَاسْتَدْخَلَتْهَا', #1
u'فاستدوا': u'فاستدوا', #1
u'فاستراب': u'فَاسْتَرَابَ', #2
u'فاستربت': u'فَاسْتَرَبْت', #1
u'فاستربت': u'فَاسْتَرَبْتُ', #1
u'فاسترقفته': u'فَاسْتَرْقَفْتُهُ', #1
u'فاسترم': u'فَاسْتَرَمَّ', #1
u'فاستسعاه': u'فَاسْتَسْعَاهُ', #5
u'فاستسعاها': u'فَاسْتَسْعَاهَا', #1
u'فاستسعت': u'فَاسْتَسْعَتْ', #1
u'فاستسعى': u'فَاسْتَسْعَى', #12
u'فاستسلف': u'فَاسْتَسْلَفَ', #3
u'فاستسلفنا': u'فَاسْتَسْلَفْنَا', #2
u'فاستسلفه': u'فَاسْتَسْلَفَهُ', #3
u'فاستشربه': u'فَاسْتَشْرَبَهُ', #4
u'فاستشريته': u'فَاسْتَشْرَيْتُهُ', #1
u'فاستشكله': u'فَاسْتَشْكَلَهُ', #8
u'فاستشم': u'فَاسْتَشَمَّ', #1
u'فاستشمه': u'فَاسْتَشَمَّهُ', #5
u'فاستصبحوا': u'فَاسْتَصْبِحُوا', #7
u'فاستصغرنى': u'فَاسْتَصْغَرَنِى', #7
u'فاستصفاها': u'فَاسْتَصْفَاهَا', #1
u'فاستصناع': u'فَاسْتِصْنَاعٌ', #1
u'فاستضحك': u'فَاسْتَضْحَكَ', #3
u'فاستضحكوا': u'فَاسْتَضْحَكُوا', #1
u'فاستطعمونى': u'فَاسْتَطْعِمُونِى', #2
u'فاستعاننى': u'فَاسْتَعَانَنِى', #1
u'فاستعبر': u'فَاسْتَعْبَرَ', #2
u'فاستعبرت': u'فَاسْتَعْبَرَتْ', #1
u'فاستعبرت': u'فَاسْتَعْبَرْت', #1
u'فاستعبرت': u'فَاسْتَعْبَرْتُ', #1
u'فاستعبرته': u'فَاسْتَعْبَرْته', #1
u'فاستعبرها': u'فَاسْتَعْبَرَهَا', #1
u'فاستعذر': u'فَاسْتَعْذَرَ', #10
u'فاستعز': u'فَاسْتُعِزَّ', #1
u'فاستعطشت': u'فَاسْتَعْطَشَتْ', #1
u'فاستعفى': u'فَاسْتَعْفَى', #1
u'فاستعقب': u'فَاسْتَعْقَبَ', #2
u'فاستعقبت': u'فَاسْتَعْقَبَتْ', #1
u'فاستعينوابى': u'فَاسْتَعِينُوابِى', #1
u'فاستغار': u'فَاسْتَغَارَ', #1
u'فاستغدرت': u'فَاسْتَغْدَرَتْ', #2
u'فاستغضب': u'فَاسْتُغْضِبَ', #7
u'فاستغفرالله': u'فَاسْتَغْفِرِاللَّهَ', #1
u'فاستغفرونى': u'فَاسْتَغْفِرُونِى', #2
u'فاستغفرى': u'فَاسْتَغْفِرِى', #6
u'فاستغنه': u'فَاسْتَغْنِهْ', #1
u'فاستغواهم': u'فَاسْتَغْوَاهُمْ', #2
u'فاستفاءه': u'فَاسْتَفَاءَهُ', #1
u'فاستفاده': u'فَاسْتَفَادَهُ', #2
u'فاستفادها': u'فَاسْتَفَادَهَا', #4
u'فاستفده': u'فَاسْتَفِدْهُ', #10
u'فاستفدها': u'فَاسْتَفِدْهَا', #4
u'فاستفزعني': u'فَاسْتَفْزَعَنِي', #1
u'فاستفضل': u'فَاسْتَفْضَلَ', #1
u'فأستفضل': u'فَأَسْتَفْضِلُ', #3
u'فاستفعل': u'فَاسْتَفْعَلَ', #1
u'فاستقاءتا': u'فَاسْتِقَاءَتَا', #1
u'فاستقاد': u'فَاسْتَقَادَ', #2
u'فاستقادا': u'فَاسْتَقَادَا', #1
u'فاستقبلنى': u'فَاسْتَقْبَلَنِى', #4
u'فاستقد': u'فَاسْتَقِدْ', #4
u'فاستقرض': u'فَاسْتَقَرَضَ', #1
u'فاستقرض': u'فَاسْتُقْرِضَ', #1
u'فأستقرض': u'فَأَسْتَقْرِضُ', #2
u'فاستقرض': u'فَاسْتَقْرِضْ', #2
u'فاستقرض': u'فَاسْتَقْرَضَ', #31
u'فاستقرضا': u'فَاسْتَقْرَضَا', #3
u'فاستقرضت': u'فاستقرضت', #1
u'فاستقرضت': u'فَاسْتَقْرَضَتْ', #2
u'فاستقرضه': u'فَاسْتَقْرَضَهُ', #1
u'فاستقرضها': u'فَاسْتَقْرَضَهَا', #2
u'فاستقضاه': u'فَاسْتَقْضَاهُ', #1
u'فاستقضوه': u'فَاسْتَقْضَوْهُ', #1
u'فاستقضى': u'فَاسْتَقْضَى', #2
u'فاستقضيت': u'فَاسْتَقْضَيْتُ', #1
u'فاستقفاه': u'فَاسْتَقْفَاهُ', #1
u'فاستكتا': u'فَاسْتَكَّتَا', #1
u'فاستكتبتنى': u'فَاسْتَكْتَبَتْنِى', #1
u'فاستكتمه': u'فاستكتمه', #1
u'فاستكرى': u'فَاسْتَكْرَى', #2
u'فاستكسونى': u'فَاسْتَكْسُونِى', #2
u'فاستكف': u'فاستكفّ', #1
u'فاستلاط': u'فَاسْتَلَاطَ', #1
u'فاستلأم': u'فَاسْتَلْأَمَ', #1
u'فاستلحق': u'فَاسْتَلْحَقَ', #6
u'فاستلحقت': u'فَاسْتَلْحَقَتْ', #1
u'فاستلحقته،': u'فَاسْتَلْحَقْتُهُ،', #1
u'فاستلحقته': u'فَاسْتَلْحَقْتُهُ', #5
u'فاستلحقه،': u'فاستلحقه،', #1
u'فاستلحقه': u'فَاسْتَلْحَقَهُ', #26
u'فاستلحقها': u'فَاسْتَلْحَقَهَا', #7
u'فاستمثل': u'فَاسْتَمْثَلَ', #1
u'فاستمديت': u'فَاسْتَمْدَيْتُ', #1
u'فاستمكن': u'فَاسْتَمْكَنَ', #1
u'فاستن،': u'فَاسْتَنَّ،', #1
u'فاستن': u'فَاسْتَنَّ', #10
u'فاستن': u'فَاسْتُنَّ', #13
u'فاستن': u'فَاسْتَنّ', #2
u'فاستناب': u'فَاسْتَنَابَ', #12
u'فاستنابه': u'فَاسْتَنَابَهُ', #2
u'فاستناخت،': u'فَاسْتَنَاخَتْ،', #1
u'فاستنان': u'فَاسْتِنَانٌ', #1
u'فاستنبه': u'فَاسْتَنْبَهَ', #4
u'فاستنت': u'فَاسْتَنَّتْ', #14
u'فاستنتر': u'فَاسْتَنْتِرْ', #1
u'فاستنثر': u'فَاسْتَنْثِرْ', #1
u'فاستنثر،': u'فَاسْتَنْثِرْ،', #1
u'فاستنثرها': u'فَاسْتَنْثَرَهَا', #1
u'فاستنجز': u'فَاسْتَنْجَزَ', #1
u'فاستنزهوا': u'فَاسْتَنْزِهُوا', #2
u'فاستنصتني': u'فَاسْتَنْصَتَنِي', #4
u'فاستنظره': u'فَاسْتَنْظَرَهُ', #2
u'فاستنفجنا': u'فَاسْتَنْفَجْنَا', #1
u'فاستنفع': u'فَاسْتَنْفِعْ', #1
u'فاستنفعها': u'فَاسْتَنْفِعْهَا', #1
u'فاستنفق': u'فَاسْتَنْفِقْ', #2
u'فاستنفقها،': u'فَاسْتَنْفِقْهَا،', #1
u'فاستنفقها': u'فَاسْتَنْفِقْهَا', #25
u'فاستنقص': u'فَاسْتَنْقَصَ', #1
u'فاستنقع': u'فَاسْتُنْقِعَ', #1
u'فاستنكه': u'فَاسْتَنْكَهَ', #1
u'فاستنكهه،': u'فَاسْتَنْكَهَهُ،', #1
u'فاستنكهه': u'فَاسْتَنْكَهَهُ', #12
u'فاستنوا': u'فاستنوا', #1
u'فاستنوا': u'فَاسْتَنُّوا', #4
u'فاستهدونى': u'فَاسْتَهْدُونِى', #1
u'فاستهما': u'فَاسْتَهَمَا', #1
u'فاستهما': u'فَاسْتَهِمَا', #1
u'فاستهموا': u'فَاسْتَهَمُوا', #3
u'فاستوبأوا': u'فَاسْتَوْبَأُوا', #1
u'فاستوبئوا': u'فَاسْتَوْبَئُوا', #2
u'فاستوجه': u'فَاسْتَوْجَهَ', #1
u'فاستوجهه': u'فَاسْتَوْجَهَهُ', #1
u'فاستوخمنا': u'فَاسْتَوْخَمْنَا', #2
u'فاستوخموا': u'فَاسْتَوْخَمُوا', #12
u'فاستوخموها': u'فَاسْتَوْخَمُوهَا', #2
u'فاستودى': u'فَاسْتَوْدَى', #1
u'فاستوعى': u'فَاسْتَوْعَى', #1
u'فاستوفزت': u'فَاسْتَوْفَزَتْ', #1
u'فأستوفق': u'فَأَسْتَوْفِقُ', #1
u'فاستوكف': u'فَاسْتَوْكَفَ', #4
u'فاستؤمن': u'فَاسْتُؤْمِنَ', #3
u'فاستوهبت': u'فَاسْتَوْهَبْتُ', #1
u'فأستوهبه': u'فَأَسْتَوْهِبَهُ', #1
u'فاستوهبه،': u'فَاسْتَوْهَبَهُ،', #1
u'فاستوهبه': u'فَاسْتَوْهَبَهُ', #7
u'فاستوهبها': u'فَاسْتَوْهَبَهَا', #2
u'فاستويتا': u'فَاسْتَوَيَتَا', #1
u'فاستيجاهه': u'فَاسْتِيجَاهُهُ', #2
u'فأسجح،': u'فَأَسْجِحْ،', #2
u'فاسجح': u'فَاسْجَحْ', #2
u'فأسجح': u'فَأَسْجِحْ', #6
u'فاسجحوا،': u'فَاسْجِحُوا،', #1
u'فإسحاقي': u'فَإِسْحَاقِيٌّ', #1
u'فإسرارها': u'فَإِسْرَارُهَا', #2
u'فإسرارهما': u'فَإِسْرَارُهُمَا', #1
u'فأسعطيه': u'فَأَسْعِطِيهِ', #1
u'فأسغسغه': u'فَأُسَغْسِغُهُ', #1
u'فأسقنى': u'فَأَسْقِنِى', #1
u'فاسقنى': u'فَاسْقِنِى', #3
u'فاسقنيها': u'فَاسْقِنِيهَا', #1
u'فأسقيناكموه': u'فَأَسْقَيْنَاكُمُوهُ', #2
u'فأسلفكماه': u'فَأُسَلِّفَكُمَاهُ', #1
u'فأسلفكماه': u'فَأُسَلِّفُكُمَاهُ', #1
u'فأسلفكماه': u'فَأُسْلِفُكُمَاهُ', #2
u'فأسلفيناه': u'فَأَسْلِفِينَاهُ', #1
u'فأسلفينى': u'فَأَسْلِفِينِى', #1
u'فأسلمتنى': u'فَأَسْلَمَتْنِى', #3
u'فأسلمننى': u'فَأَسْلَمْنَنِى', #5
u'فإسماعيلي': u'فَإِسْمَاعِيلِيٌّ', #1
u'فأسمعتنى': u'فَأَسْمَعَتْنِى', #2
u'فاسمعدت': u'فَاسْمَعَدّتْ', #1
u'فأسمعنى': u'فَأَسْمَعْنِى', #1
u'فاسمعون': u'فَاسْمَعُونِ', #1
u'فاسهكوني': u'فَاسْهَكُونِي', #2
u'فأشابها': u'فَأَشَابَهَا', #1
u'فأشارإليه': u'فَأَشَارَإِلَيْهِ', #1
u'فأشالها،': u'فَأَشَالَّهَا،', #1
u'فأشالها': u'فَأَشَالَهَا', #2
u'فأشبة': u'فَأَشْبَة', #2
u'فأشبعنى': u'فَأَشْبِعْنِى', #1
u'فاشتار': u'فَاشْتَارَ', #1
u'فاشتجر': u'فَاشْتَجَرَ', #2
u'فاشتجروا': u'فَاشْتَجَرُوا', #2
u'فاشترا': u'فَاشْتَرَا', #1
u'فاشترانى': u'فَاشْتَرَانِى', #1
u'فأشتراه': u'فَأَشْتَرَاهُ', #1
u'فاشترطى': u'فَاشْتَرِطِى', #1
u'فاشتطت': u'فَاشْتَطَّتْ', #1
u'فاشتكاه': u'فَاشْتَكَاهُ', #1
u'فاشتكاه،': u'فَاشْتَكَاهُ،', #1
u'فاشتواه': u'فَاشْتَوَاهُ', #1
u'فاشتووها': u'فَاشْتَوَوْهَا', #1
u'فأشخصت': u'فَأُشْخِصْتُ', #1
u'فأشخصوا': u'فَأَشْخَصُوا', #1
u'فأشرجت': u'فأُشْرِجَتْ', #1
u'فأشكيته': u'فَأَشْكَيْتُهُ', #3
u'فأشلى': u'فَأَشْلَى', #3
u'فأشليت': u'فَأَشْلَيْتُ', #1
u'فاشمعلت': u'فَاشْمَعَلّتِ', #2
u'فأشمليته': u'فَأَشْمَلِيَّتُهُ', #1
u'فأشمى': u'فَأَشِمِّى', #1
u'فاشهدى': u'فَاشْهَدِى', #3
u'فأشواه،': u'فَأَشْوَاهُ،', #1
u'فأشواه': u'فَأَشْوَاهُ', #3
u'فأصأب': u'فَأَصْأَبَ', #1
u'فأصابتنى': u'فَأَصَابَتْنِى', #5
u'فأصابنى': u'فَأَصَابَنِى', #4
u'فأصبحينا': u'فَأَصْبِحِينَا', #1
u'فاصحبنى': u'فَاصْحَبْنِى', #1
u'فإصرافة': u'فَإِصْرَافَةُ', #1
u'فأصرخه': u'فَأَصْرَخَهُ', #1
u'فأصرفاه': u'فَأَصْرَفَاهُ', #1
u'فاصطبح': u'فَاصْطَبَحَ', #1
u'فاصطرفا': u'فَاصْطُرِفَا', #1
u'فاصطرفا': u'فَاصْطَرَفَا', #2
u'فاصطرفها': u'فَاصْطَرَفَهَا', #2
u'فأصطكه': u'فَأَصْطَكُّهُ', #1
u'فاصطكه': u'فَاصْطَكَّهُ', #1
u'فاصطلم': u'فَاصْطَلَمَ', #2
u'فاصطلمت': u'فَاصْطَلَمَتْ', #1
u'فاصطلمته': u'فَاصْطَلَمَتْهُ', #1
u'فاصطلمه': u'فَاصْطَلَمَهُ', #1
u'فأصلحى': u'فَأَصْلِحِى', #1
u'فأصمى': u'فَأُصْمِى', #2
u'فاصنعى': u'فَاصْنَعِى', #1
u'فأضبوا': u'فَأَضَبُّوا', #1
u'فاضحى': u'فَاضِحِى', #1
u'فاضخا': u'فَاضِخًا', #1
u'فاضربى': u'فَاضْرِبِى', #1
u'فأضرت': u'فَأَضَرَّتْ', #5
u'فأضروا': u'فَأَضَرُّوا', #2
u'فاضطبع': u'فَاضْطَبَعَ', #6
u'فاضطبعوا': u'فَاضْطَبَعُوا', #4
u'فإضم': u'فَإِضَمٍ', #1
u'فأط': u'فَأُطَّ', #1
u'فاطبخناه': u'فَاطّبَخْنَاهُ', #2
u'فاطبخناها': u'فَاطَّبَخْنَاهَا', #1
u'فأطحنت': u'فَأَطْحَنَتْ', #1
u'فاطراح': u'فَاطِّرَاحُ', #1
u'فإطراحه': u'فَإِطْرَاحُهُ', #1
u'فاطراحه': u'فَاطِّرَاحُهُ', #1
u'فاطرحى': u'فَاطْرَحِى', #1
u'فأطعمنى': u'فَأَطْعَمَنِى', #1
u'فأطعمنى': u'فَأَطْعِمْنِى', #3
u'فأطعموناه': u'فَأَطْعِمُونَاهُ', #1
u'فأطعموناه': u'فَأَطْعَمُونَاهُ', #2
u'فأطعمى': u'فَأَطْعِمِى', #3
u'فأطفئى': u'فَأَطْفِئِى', #1
u'فاطلى': u'فَاطَّلَى', #3
u'فأطؤها': u'فَأَطَؤُهَا', #5
u'فأطيبيته': u'فَأَطْيَبِيَّتُهُ', #1
u'فأطيعونى': u'فَأَطِيعُونِى', #1
u'فاظ،': u'فاظ،', #1
u'فاظ': u'فَاظَ', #3
u'فاظت': u'فَاظَتْ', #2
u'فأظعنوا': u'فَأَظْعِنُوا', #2
u'فاعبدون': u'فاعبدون', #1
u'فاعبدون': u'فَاعَبُدُونِ', #1
u'فاعبدون': u'فَاعْبُدُونِ', #9
u'فاعتاص': u'فَاعْتَاصَ', #1
u'فاعتاقه': u'فَاعْتَاقَهُ', #2
u'فاعتجر': u'فَاعْتَجَرَ', #1
u'فاعتجرت': u'فَاعْتَجَرَتْ', #1
u'فأعتدت': u'فَأَعْتَدَتْ', #1
u'فأعترق': u'فَأَعْتَرِق', #1
u'فأعترق': u'فَأَعْتَرِقُ', #1
u'فاعتضد': u'فَاعْتَضَدَ', #3
u'فاعتضدت': u'فَاعْتَضَدَتْ', #2
u'فاعتقبوها': u'فَاعْتَقَبُوهَا', #1
u'فاعتقت': u'فاعتقت', #2
u'فأعتقتنى': u'فَأَعْتَقَتْنِى', #2
u'فأعتقنى': u'فَأَعْتَقَنِى', #2
u'فأعتقونى': u'فَأَعْتَقُونِى', #1
u'فأعتقى': u'فَأَعْتِقِى', #2
u'فأعتقينى': u'فَأَعْتِقِينِى', #2
u'فاعتكفه': u'فَاعْتَكَفَهُ', #1
u'فاعتكفه': u'فَاعْتَكِفْهُ', #1
u'فاعتلفه': u'فَاعْتَلَفَهُ', #1
u'فاعتمرى': u'فَاعْتَمِرِى', #4
u'فأعتملها': u'فَأَعْتَمِلُهَا', #1
u'فاعتور': u'فَاعْتَوَرَ', #1
u'فاعتوره': u'فَاعْتَوَرَهُ', #1
u'فأعجبتنى': u'فَأَعْجَبَتْنِى', #1
u'فأعجبننى': u'فَأَعْجَبْنَنِى', #1
u'فأعجبنى': u'فَأَعْجَبَنِى', #9
u'فأعجزنى': u'فَأَعْجَزَنِى', #1
u'فاعداني': u'فَاعَدَانِي', #1
u'فأعرست': u'فَأَعْرَسْتَ', #3
u'فأعرست': u'فَأَعْرَسْت', #5
u'فأعضوه': u'فَأَعْضُوهُ', #1
u'فأعضوه': u'فَأَعِضُّوهُ', #13
u'فأعطاناها': u'فَأَعْطَانَاهَا', #1
u'فأعطانى': u'فأعطانى', #1
u'فأعطانى': u'فَأَعْطَانِى', #29
u'فأعطانيه،': u'فَأَعْطَانِيهِ،', #2
u'فأعطانيه': u'فَأَعْطَانِيهِ', #20
u'فأعطانيها': u'فأعطانيها', #1
u'فأعطانيها': u'فَأَعْطَانِيهَا', #40
u'فأعطانيها،': u'فَأَعْطَانِيهَا،', #6
u'فأعطانيهم': u'فَأَعْطَانِيهِمْ', #2
u'فأعطانيهن،': u'فَأَعْطَانِيهُنَّ،', #1
u'فأعطانيهن،': u'فَأَعْطَانِيهِنَّ،', #1
u'فأعطانيهن': u'فَأَعْطَانِيهِنَّ', #2
u'فأعطتنى': u'فَأَعْطَتْنِى', #1
u'فأعطتنيه': u'فَأَعْطَتْنِيهِ', #1
u'فأعطناها': u'فَأَعْطِنَاهَا', #2
u'فأعطنى': u'فَأَعْطِنِى', #2
u'فأعطنيه': u'فَأُعْطِنِيهِ', #1
u'فأعطنيه': u'فَأَعْطِنِيهِ', #7
u'فأعطنيها،': u'فَأَعْطِنِيهَا،', #1
u'فأعطنيها': u'فَأَعْطِنِيهَا', #2
u'فأعطونى': u'فَأَعْطُونِى', #1
u'فأعطيتكها': u'فَأَعْطَيْتُكَهَا', #1
u'فأعطيتنيه': u'فَأَعْطَيْتنِيهِ', #1
u'فأعطيتنيه': u'فَأَعْطَيْتِنِيهِ', #1
u'فأعطيتهموها': u'فأعْطَيْتُهُمُوها', #1
u'فأعطيتهموها': u'فَأعْطَيْتُهُموهَا', #1
u'فأعطيتهموها': u'فَأَعْطَيْتُهُمُوهَا', #1
u'فأعطيكها': u'فَأُعْطِيكَهَا', #1
u'فأعطينيه': u'فَأَعْطِينِيهِ', #1
u'فأعفانى': u'فَأَعْفَانِى', #1
u'فأعفنى': u'فَأَعْفِنِى', #2
u'فأعقبنى': u'فَأَعْقَبَنِى', #3
u'فاعلاء': u'فَاعِلَاءَ', #1
u'فاعلت': u'فَاعَلْت', #1
u'فاعلتم': u'فَاعَلْتُمْ', #1
u'فأعلمننى': u'فَأَعْلِمْنَنِى', #1
u'فاعلمو': u'فَاعْلَمُو', #1
u'فاعليا': u'فَاعِلِيًّا', #5
u'فأعمرنى': u'فَأَعْمَرَنِى', #2
u'فاعول': u'فَاعُولٍ', #3
u'فاعول': u'فَاعُولٌ', #5
u'فاعولا': u'فَاعُولًا', #1
u'فاعولاء': u'فَاعُولَاءُ', #1
u'فاعولاء': u'فَاعُولَاءِ', #1
u'فاعولة': u'فَاعُولَةٍ', #1
u'فاعولة': u'فَاعُولَةٌ', #3
u'فأعولت': u'فأعولت', #1
u'فأعولت': u'فَأَعْوَلَتْ', #2
u'فأعولته': u'فَأَعْوَلْتُهُ', #2
u'فأعى': u'فَأَعِى', #2
u'فأعيانى': u'فَأَعْيَانِى', #1
u'فاعيل': u'فَاعِيلٍ', #1
u'فاعيل': u'فَاعِيلَ', #2
u'فأعينينى': u'فَأَعِيْنِينِى', #2
u'فأعينينى': u'فَأَعِينِينِى', #4
u'فاغتدت': u'فَاغْتَدَتْ', #1
u'فاغتدوا': u'فَاغْتَدَوْا', #1
u'فاغترق': u'فَاغْتَرَقَ', #2
u'فاغترقه': u'فَاغْتَرَقَهُ', #1
u'فاغتسلى': u'فَاغْتَسِلِى', #23
u'فاغتمضي': u'فَاغْتَمِضِي', #7
u'فأغذوا': u'فَأَغَذّوا', #1
u'فأغذوا': u'فَأَغَذّوْا', #1
u'فإغريض': u'فَإِغْرِيضٌ', #3
u'فأغزوا': u'فَأَغِزُّوا', #1
u'فاغسلنى': u'فَاغْسِلْنِى', #1
u'فاغسلى': u'فَاغْسِلِى', #15
u'فاغسلينى': u'فَاغْسِلِينِى', #2
u'فأغضبنى': u'فَأَغْضَبَنِى', #2
u'فاغضضه': u'فَاغْضُضْهُ', #2
u'فأغمى': u'فَأُغْمِىَ', #10
u'فإغياؤه': u'فَإِغْيَاؤُهُ', #1
u'فاغية': u'فَاغِيَةٍ', #3
u'فاغيته': u'فَاغِيَتُهُ', #1
u'فأفاء': u'فَأْفَاءً', #2
u'فأفأة': u'فَأْفَأَةً', #1
u'فأفأة': u'فَأْفَأَةٍ', #2
u'فأفأة': u'فَأْفَأَةٌ', #4
u'فأفاته': u'فَأَفَاتَهُ', #3
u'فأفاتها': u'فَأَفَاتَهَا', #3
u'فافاه': u'فَافَاهُ', #2
u'فأفتانى': u'فَأَفْتَانِى', #2
u'فافتتلنا': u'فافتتلنا', #1
u'فافتض': u'فَافْتَضَّ', #2
u'فافتضضتها': u'فَافْتَضَضْتُهَا', #1
u'فافتضني': u'فَافْتَضَّنِي', #1
u'فافتضها': u'فَافْتَضَّهَا', #22
u'فافتككتها': u'فَافْتَكَكْتُهَا', #1
u'فأفتنى': u'فَأَفْتِنِى', #2
u'فأفرغى': u'فَأَفْرِغِى', #1
u'فأفرقتا': u'فَأَفْرَقَتَا', #1
u'فأفزعنى': u'فَأَفْزَعَنِى', #2
u'فأفطرى': u'فَأَفْطِرِى', #2
u'فافعلى': u'فَافْعَلِى', #4
u'فأفلجنى': u'فَأَفْلَجَنِى', #1
u'فافلعوه': u'فَافْلَعُوهُ', #1
u'فأفنوا': u'فَأَفْنَوْا', #1
u'فأفنوهم': u'فَأَفَنُوهُمْ', #1
u'فأفني': u'فَأُفْنِيَ', #1
u'فأفنيت،': u'فَأَفْنَيْتَ،', #1
u'فأفنيت': u'فَأَفْنَيْتَ', #14
u'فأفنيت': u'فَأَفْنَيْت', #3
u'فأقادنا': u'فَأَقَادَنَا', #1
u'فأقاده': u'فَأَقَادَهُ', #10
u'فأقادهم': u'فَأَقَادَهُمْ', #1
u'فأقامنى': u'فَأَقَامَنِى', #10
u'فإقباض': u'فَإِقْبَاضُ', #4
u'فإقباضه': u'فَإِقْبَاضُهُ', #2
u'فأقبضتها': u'فَأَقْبَضَتْهَا', #1
u'فاقترأ': u'فاقترأ', #1
u'فاقترأ': u'فَاقْتَرَأَ', #15
u'فاقترأهن': u'فَاقْتَرَأَهُنَّ', #1
u'فاقتمروا': u'فَاقْتَمَرُوا', #1
u'فاقتويته،': u'فَاقْتَوَيْتُهُ،', #1
u'فاقتويناه': u'فَاقْتَوَيْنَاهُ', #1
u'فأقدروا': u'فَأَقْدِرُوا', #3
u'فأقدني': u'فَأَقِدْنِي', #2
u'فأقرءوا': u'فَأَقْرِءُوا', #1
u'فاقرءوا': u'فَاقْرَءُوا', #143
u'فاقرءوا': u'فاقرءوا', #2
u'فاقرءوه': u'فَاقْرَءُوهُ', #3
u'فأقرأنى': u'فَأَقْرَأَنِى', #1
u'فأقرأنيها،': u'فَأَقْرَأَنِيهَا،', #1
u'فاقرأوا': u'فَاقْرَأُوا', #1
u'فاقرأوه،': u'فَاقْرَأُوهُ،', #1
u'فأقراؤها': u'فَأَقْرَاؤُهَا', #2
u'فأقصعته،': u'فَأَقْصَعَتْهُ،', #1
u'فاقضنى': u'فَاقْضِنِى', #2
u'فاقضى': u'فَاقْضِى', #4
u'فأقعدنى': u'فَأَقْعَدَنِى', #2
u'فأقعصته،': u'فَأَقْعَصَتْهُ،', #1
u'فأقعصته': u'فَأَقْعَصَتْهُ', #9
u'فأقعصه،': u'فأقْعَصَه،', #1
u'فأقعصه': u'فَأَقْعَصهُ', #1
u'فأقلوا': u'فَأَقِلُّوا', #14
u'فاقهم': u'فَاقَهُمْ', #1
u'فاقئ': u'فَاقِئِ', #1
u'فأقيدوا': u'فَأَقِيدُوا', #1
u'فاكتبى': u'فَاكْتُبِى', #2
u'فأكترت': u'فَأَكْتَرَتْ', #2
u'فاكتسرها': u'فَاكْتَسَرَهَا', #1
u'فاكتسرها،': u'فَاكْتَسَرَهَا،', #1
u'فاكتسعت': u'فَاكْتَسَعَتِ', #1
u'فاكتسعت': u'فَاكْتَسَعَتْ', #4
u'فاكتنعا': u'فَاكْتَنَعَا', #1
u'فاكتني': u'فَاكْتَنِي', #5
u'فأكحلته': u'فَأَكْحَلَتْهُ', #1
u'فأكسابه': u'فَأَكْسَابُهُ', #4
u'فأكشفت': u'فَأُكْشِفَتْ', #1
u'فاكفنى': u'فَاكْفنِىِ', #1
u'فاكفنى': u'فَاكْفِنِى', #4
u'فاكفئوها': u'فَاكْفِئُوهَا', #2
u'فالإباق': u'فَالْإِبَاقُ', #5
u'فالإبراد': u'فَالْإِبْرَادُ', #2
u'فالإبريسم': u'فَالْإِبْرَيْسَمُ', #1
u'فالإبضاع': u'فَالْإِبْضَاعُ', #2
u'فالآبق': u'فَالْآبِقُ', #3
u'فالأبقع': u'فَالْأَبْقَعُ', #5
u'فالاتي': u'فَالَّاتِي', #1
u'فالأثبت': u'فَالْأَثْبَتُ', #3
u'فالأثم': u'فَالْأَثِمُ', #2
u'فالاثنا': u'فَالِاثْنَا', #3
u'فالإجاز': u'فَالْإِجَازُ', #1
u'فالاجتزاء': u'فَالِاجْتِزَاءُ', #1
u'فالاحتواش': u'فَالِاحْتِوَاشُ', #1
u'فالإحداد': u'فَالْإِحْدَادُ', #1
u'فالأحسنية': u'فَالْأَحْسَنِيَّةُ', #1
u'فالإحصار': u'فَالْإِحْصَارُ', #2
u'فالأحظ': u'فَالْأَحَظُّ', #5
u'فالأحوط': u'فَالْأَحْوَط', #2
u'فالأحوط': u'فَالْأَحْوَطِ', #2
u'فالأحوط': u'فَالْأَحْوَطُ', #64
u'فالإخارة': u'فَالْإِخَارَةُ', #1
u'فالأخس': u'فَالْأَخَسَّ', #1
u'فالأخس': u'فَالْأَخَسُّ', #1
u'فالأخس': u'فَالْأَخَسِّ', #4
u'فالأخصر': u'فَالْأَخْصَرُ', #3
u'فالإخفار': u'فَالْإِخْفَارُ', #1
u'فالأخلص': u'فَالْأَخْلَصُ', #1
u'فالإدلال': u'فَالْإِدْلَالُ', #1
u'فالآدم': u'فَالْآدَمُ', #1
u'فالادهان': u'فَالِادِّهَانُ', #1
u'فالأدين': u'فَالْأَدْيَنُ', #2
u'فالأذرعي': u'فَالْأَذْرَعِيُّ', #4
u'فالارتثاث': u'فَالِارْتِثَاثُ', #2
u'فالارتفاق': u'فَالِارْتِفَاقُ', #2
u'فالإردب': u'فَالْإِرْدَبُ', #1
u'فالإردب': u'فَالْإِرْدَبُّ', #1
u'فالأرش': u'فَالْأَرْش', #1
u'فالأرش': u'فَالْأَرْشُ', #87
u'فالأرشدية': u'فَالْأَرْشَدِيَّةُ', #1
u'فالأرفق': u'فَالْأَرْفَقِ', #1
u'فالأزد': u'فَالْأَزْدُ', #3
u'فالأسارى': u'فَالْأَسَارَى', #1
u'فالأسارى': u'فَالْأُسَارَى', #2
u'فالأسبك': u'فَالْأَسْبَكُ', #1
u'فالأسبلة': u'فَالْأَسْبِلَةُ', #1
u'فالاست': u'فَالِاسْتُ', #2
u'فالاستحاضة': u'فَالِاسْتِحَاضَةُ', #1
u'فالاسترقاق': u'فَالِاسْتِرْقَاقُ', #1
u'فالاستصناع': u'فَالِاسْتِصْنَاعُ', #1
u'فالاستعراق': u'فَالِاسْتِعْرَاقُ', #1
u'فالاستفراش': u'فَالِاسْتِفْرَاشُ', #1
u'فالاستقاءة': u'فَالِاسْتِقَاءَةُ', #1
u'فالاستنجاء': u'فَالِاسْتِنْجَاءُ', #6
u'فالاستيام': u'فَالِاسْتِيَامُ', #1
u'فالاستيجاه': u'فَالِاسْتِيجَاهُ', #1
u'فالاستيمار': u'فَالِاسْتِيمَارُ', #1
u'فالأسراء': u'فَالْأُسَرَاءُ', #1
u'فالإسرار': u'فَالْإِسْرَارُ', #13
u'فالإسنوي': u'فَالْإِسْنَوِيُّ', #2
u'فالأشفق': u'فَالْأَشْفَقِ', #1
u'فالأشقاص': u'فَالْأَشْقَاصُ', #2
u'فالأشنان': u'فَالْأُشْنَانُ', #3
u'فالأصطبة': u'فَالْأُصْطُبَّةُ', #1
u'فالإصماء': u'فَالْإِصْمَاءُ', #1
u'فالإضاقة': u'فَالْإِضَاقَةُ', #1
u'فالأضر': u'فَالْأَضَرُّ', #2
u'فالاضطباع': u'فَالِاضْطِبَاعُ', #1
u'فالأضعف': u'فَالْأَضْعَفَ', #1
u'فالأضعف': u'فَالْأَضْعَفُ', #7
u'فالاطعام': u'فَالِاطِّعَامُ', #1
u'فالأعدام': u'فَالْأَعْدَامُ', #1
u'فالأعلي': u'فَالْأَعْلَيْ', #1
u'فالأغبط': u'فَالْأَغْبَطُ', #6
u'فالإفاتة': u'فَالْإِفَاتَةُ', #1
u'فالافتيات': u'فَالِافْتِيَاتُ', #1
u'فالأفقر': u'فَالْأَفْقَرُ', #1
u'فالأفقر': u'فَالْأَفْقَرِ', #4
u'فالأفقه': u'فَالْأَفْقَهُ', #5
u'فالاقتراني': u'فَالِاقْتِرَانِيُّ', #1
u'فالأقراء': u'فَالْأَقْرَاءُ', #8
u'فالأقربية': u'فَالْأَقْرَبِيَّةُ', #1
u'فالأقيس': u'فَالْأَقْيَسُ', #7
u'فالإكاف': u'فَالْإِكَافُ', #4
u'فالأكة': u'فَالْأَكّةُ', #1
u'فالآكد': u'فَالْآكِدَ', #1
u'فالآكد': u'فَالْآكَدُ', #15
u'فالآكد': u'فَالْآكَدَ', #3
u'فالأكساب': u'فَالْأَكْسَابُ', #4
u'فالإل': u'فَالْإِلّ', #1
u'فالأليس': u'فَالْأَلْيَسُ', #1
u'فالآمدي': u'فَالْآمِدِيُّ', #1
u'فالأنزل': u'فَالْأَنْزَلِ', #1
u'فالإواية': u'فَالْإِوَايَةُ', #1
u'فالأورع': u'فَالْأَوْرَعُ', #10
u'فالأوزاعي': u'فَالْأَوْزَاعِيّ', #1
u'فالأوزاعي': u'فَالْأَوْزَاعِيُّ', #1
u'فالأوسق': u'فَالْأَوْسُقُ', #1
u'فالأوقاص': u'فَالأَوْقَاصُ', #1
u'فالأوقاص': u'فَالْأَوْقَاصُ', #1
u'فالأوكد': u'فَالْأَوْكَدُ', #1
u'فالأوكد': u'فَالْأَوْكَدِ', #1
u'فالأولتان': u'فَالْأُولَتَانِ', #1
u'فالإيجارة': u'فَالْإِيجَارَةُ', #1
u'فالآيس': u'فَالْآيِسُ', #21
u'فالآيسة': u'فَالْآيِسَةُ', #1
u'فالآيسون': u'فَالْآيِسُونَ', #2
u'فالإيصا': u'فَالْإِيصَا', #1
u'فالآيل': u'فَالْآيِلُ', #1
u'فالباذق': u'فَالْبَاذِقُ', #1
u'فألبتة': u'فَأَلْبَتَّةَ', #3
u'فالبخع': u'فَالْبَخْعُ', #1
u'فالبخية': u'فَالْبَخِيَّةُ', #1
u'فالبدار': u'فَالْبِدَارَ', #1
u'فالبراذعي': u'فَالْبَرَاذِعِيُّ', #1
u'فالبز': u'فَالْبَزُّ', #3
u'فالبسائط': u'فَالْبَسَائِطُ', #1
u'فألبسنى': u'فَأَلْبَسَنِى', #2
u'فألبسنيها': u'فَأَلْبَسَنِيهَا', #2
u'فالبشم': u'فَالْبَشَمُ', #1
u'فالبصريون': u'فَالْبَصْرِيُّونَ', #5
u'فالبغوي': u'فَالْبَغَوِيُّ', #1
u'فالبقار': u'فَالْبَقَّارُ', #2
u'فالبلخي': u'فَالْبَلْخِيُّ', #2
u'فالبلغم': u'فَالْبَلْغَمُ', #1
u'فالبلقيني': u'فَالْبُلْقِينِيُّ', #3
u'فالبيتوتة': u'فَالْبَيْتُوتَةُ', #1
u'فالتأدي': u'فَالتَّأَدِّي', #1
u'فالتاط': u'فَالْتَاطَ', #1
u'فالتاطته،': u'فَالْتَاطَتْهُ،', #1
u'فالتاطه': u'فَالْتَاطَهُ', #1
u'فالتالف': u'فَالتَّالِفُ', #16
u'فالتبدئة': u'فَالتَّبْدِئَةُ', #2
u'فالتبطوا': u'فَالْتَبَطُوا', #3
u'فالتبوأ': u'فَالتَّبَوُّأُ', #1
u'فالتجا': u'فَالْتَجَا', #1
u'فالتختم': u'فَالتَّخَتُّمُ', #3
u'فالترخص': u'فَالتَّرَخُّصُ', #3
u'فالترقيح': u'فَالتَّرْقِيحُ', #2
u'فالتزمنى': u'فَالْتَزَمَنِى', #1
u'فالتزيد': u'فَالتَّزَيُّدُ', #1
u'فالتسحب': u'فَالتَّسَحُّبُ', #1
u'فالتسري': u'فَالتَّسَرِّي', #1
u'فالتسليمة': u'فَالتَّسْلِيمَةُ', #1
u'فالتصرية': u'فَالتَّصْرِيَةُ', #2
u'فالتطليقة': u'فَالتَّطْلِيقَةُ', #3
u'فالتعيب': u'فَالتَّعَيُّبُ', #3
u'فالتفتأبو': u'فَالْتَفَتَأَبُو', #1
u'فالتفث': u'فَالتَّفَثُ', #1
u'فألتفع': u'فَأَلْتَفِعُ', #1
u'فالتقاص': u'فَالتَّقَاصُّ', #7
u'فالتقري': u'فَالتَّقَرِّي', #1
u'فالتلبيبة': u'فَالتَّلْبِيبَةُ', #1
u'فالتلتلة': u'فَالتَّلْتَلَةُ', #1
u'فالتمانع': u'فَالتَّمَانُعُ', #1
u'فالتمحض': u'فَالتَّمَحُّضُ', #1
u'فالتمع': u'فَالْتَمَعْ', #1
u'فالتهامة': u'فَالتِّهَامَةُ', #1
u'فالتهايؤ': u'فَالتَّهَايُؤُ', #4
u'فالتى': u'فَالَّتِى', #8
u'فالثان': u'فَالثَّانِ', #1
u'فالثجير': u'فَالثَّجِيرُ', #2
u'فالثخانة': u'فَالثَّخَانَةُ', #1
u'فالثلثمائة': u'فَالثَّلَثُمِائَةِ', #1
u'فالثنيا': u'فَالثُّنْيَا', #1
u'فالثيوبة': u'فَالثُّيُوبَةُ', #1
u'فالجامكية': u'فَالْجَامِكِيَّةُ', #1
u'فالجأها': u'فَالْجَأْهَا', #1
u'فالجبران': u'فَالْجُبْرَانُ', #1
u'فالجذعة': u'فَالْجَذَعَةُ', #1
u'فالجروب': u'فَالْجُرُوبُ', #1
u'فالجريب': u'فَالْجَرِيبُ', #6
u'فالجريث': u'فَالْجِرِّيثُ', #1
u'فالجعالة': u'فَالْجِعَالَةُ', #3
u'فالجعالة': u'فَالْجَعَالَةُ', #6
u'فالجعائل': u'فَالْجَعَائِلُ', #1
u'فالجعرانة': u'فَالْجِعْرَانَةُ', #1
u'فالجليب': u'فَالْجَلِيبُ', #1
u'فالجميعية': u'فَالْجَمِيعِيَّةُ', #2
u'فالجوزقة': u'فالجوزقة', #1
u'فالجوزقة': u'فَالْجَوْزَقَةُ', #1
u'فألجؤهم': u'فَأَلْجَؤُهُمْ', #2
u'فالجئوهم': u'فَالْجِئُوهُمْ', #1
u'فالحارصة': u'فَالْحَارِصَةُ', #2
u'فالحسنيون': u'فَالْحَسَنِيُّونَ', #1
u'فالحشوش': u'فَالْحُشُوشُ', #1
u'فالحطيم': u'فَالْحَطِيمُ', #3
u'فألحقنى': u'فَأَلْحَقَنِى', #2
u'فالحيضان': u'فَالْحِيضَان', #1
u'فإلخ': u'فَإِلَخْ', #1
u'فالخارص': u'فَالْخَارِصُ', #1
u'فالخارصة': u'فَالْخَارِصَةُ', #1
u'فالخبتين': u'فَالْخَبَّتَيْنِ', #1
u'فالخدب': u'فَالْخَدَبُ', #1
u'فالخرء': u'فَالْخَرْءُ', #1
u'فالخضخاض': u'فَالْخِضْخَاضُ', #1
u'فالخلا': u'فَالْخَلَا', #1
u'فالخلى': u'فَالْخَلَى', #2
u'فالخيروالوجه': u'فَالْخَيرُوَالْوَجْهُ', #1
u'فالدانق': u'فَالدَّانَقُ', #1
u'فالدانق': u'فَالدَّانِقُ', #4
u'فالذروع': u'فَالذَّرُوعُ', #1
u'فالذى': u'فَالَّذِى', #23
u'فالراتج': u'فَالرَّاتِجُ', #1
u'فالرأى': u'فَالرَّأْىُ', #1
u'فالرحا': u'فَالرَّحَا', #2
u'فالرحمن': u'فَالرَّحْمَنُ', #7
u'فالركاز': u'فَالرِّكَازُ', #3
u'فالروشن': u'فَالرَّوْشَنُ', #2
u'فالروياني': u'فَالرُّويَانِيُّ', #5
u'فالريالات': u'فَالرِّيَالَاتُ', #1
u'فالزلطة': u'فَالزُّلْطَةُ', #1
u'فالزيلعي': u'فَالزَّيْلَعِيُّ', #1
u'فالسباهي': u'فَالسَّبَاهِيُّ', #1
u'فالستوق': u'فَالسَّتُّوقُ', #1
u'فالسرف': u'فَالسَّرَفُ', #2
u'فالسرقين': u'فَالسِّرْقِينُ', #1
u'فالسريانيون': u'فَالسُّرْيَانِيُّونَ', #1
u'فالسقية': u'فَالسَّقِيَّةُ', #1
u'فالسلجم': u'فَالسَّلْجَمِ', #1
u'فالسمحاق': u'فَالسِّمْحَاقُ', #1
u'فالسويق': u'فَالسَّوِيقُ', #4
u'فالشاف': u'فَالشَّافُّ', #1
u'فالشالوسي': u'فَالشَّالُوسِيُّ', #1
u'فالشرائحي': u'فَالشَّرَائِحِيُّ', #1
u'فالشرقاء': u'فَالشَّرْقَاءُ', #2
u'فالشظاة': u'فَالشَّظَاة', #1
u'فالشقص': u'فَالشِّقْصُ', #11
u'فالشواب': u'فَالشَّوَابُّ', #1
u'فالصالقة': u'فَالصَّالِقَةُ', #3
u'فالصبى': u'فَالصِّبَى', #1
u'فالصداء': u'فَالصِّدَاءُ', #2
u'فالصرورة': u'فَالصَّرُورَةُ', #3
u'فالصفاتي': u'فَالصِّفَاتِيُّ', #1
u'فالصلاتية': u'فَالصَّلَاتِيَّةُ', #1
u'فالطحاوي': u'فَالطَّحَاوِيُّ', #2
u'فالطعاما': u'فَالطَّعَامَا', #2
u'فالطلا': u'فَالطَّلَا', #1
u'فالطهران': u'فَالطُّهْرَانِ', #1
u'فالظلمانية': u'فالظلمانية', #1
u'فالظئر': u'فَالظِّئْرُ', #1
u'فالع': u'فَالِعٌ', #1
u'فالع': u'فَالَع', #2
u'فالعبادلة': u'فَالْعَبَادِلَةُ', #1
u'فالعتيرة؟': u'فَالْعَتِيرَةُ؟', #1
u'فالعتيرة': u'فَالْعَتِيرَةُ', #2
u'فالعرفا': u'فَالْعُرْفَا', #2
u'فالعسب': u'فَالْعَسْبُ', #1
u'فالعضب': u'فَالْعَضْبُ', #1
u'فالعفاص': u'فَالْعِفَاصُ', #2
u'فالعقنقل': u'فَالْعَقَنْقَلِ', #1
u'فالعلس': u'فَالْعَلَسُ', #1
u'فالعمرى': u'فَالْعُمْرَى', #4
u'فالعندية': u'فَالْعِنْدِيَّةُ', #1
u'فالعنوي': u'فَالْعَنَوِيُّ', #1
u'فالعنين': u'فَالْعِنِّينُ', #1
u'فالعيلم': u'فَالْعَيْلَمُ', #1
u'فالغبيراء': u'فَالْغُبَيْرَاءُ', #1
u'فالغموس': u'فَالْغَمُوسُ', #6
u'فالغوراء': u'فَالْغَوْرَاءُ', #1
u'فالفتيا': u'فَالْفُتْيَا', #2
u'فالفسكل': u'فَالْفِسْكِلُ', #1
u'فالفسوخ': u'فَالْفُسُوخُ', #1
u'فالفسيخ': u'فَالْفَسِيخُ', #1
u'فالفعول': u'فَالْفَعُولُ', #1
u'فالفلاتج': u'فَالْفَلَاتِجُ', #3
u'فالفلو': u'فَالْفِلْوُ', #3
u'فالفوائت': u'فَالْفَوَائِتُ', #5
u'فالفىء': u'فَالْفَىْءُ', #1
u'فالقابسي': u'فَالْقَابِسِيُّ', #1
u'فالقاحة': u'فَالْقَاحَّةُ', #1
u'فالقاضيا': u'فَالْقَاضِيَا', #3
u'فالقافة': u'فَالْقَافَّةُ', #1
u'فالقافة': u'فَالْقَافَةُ', #21
u'فالقائف': u'فَالْقَائِفُ', #8
u'فالقحطاني': u'فَالْقَحْطَانِيُّ', #1
u'فالقرافي': u'فَالْقَرَافِيُّ', #1
u'فالقرظ': u'فَالْقَرَظُ', #1
u'فالقفيز': u'فَالْقَفِيزُ', #2
u'فالقليب': u'فَالْقَلِيبُ', #1
u'فالقمسة': u'فَالْقَمَسَةُ', #1
u'فألقونى': u'فَأَلْقُونِى', #1
u'فالكاملا': u'فَالْكَامِلَا', #1
u'فالكباسة': u'فَالْكِبَاسَةُ', #1
u'فالكديد': u'فَالْكَدِيدُ', #1
u'فالكرا': u'فَالْكِرَا', #3
u'فالكرخي': u'فَالْكَرْخِيُّ', #4
u'فالكلامان': u'فَالْكَلَامَانِ', #3
u'فالكمل': u'فَالْكُمَّلُ', #1
u'فالكيول': u'فَالْكَيّولُ', #1
u'فاللا': u'فَاللَّا', #1
u'فاللاء': u'فَاللّاءُ', #1
u'فاللتوقف': u'فَالِلتَّوَقُّفِ', #1
u'فاللخمي': u'فَاللَّخْمِيُّ', #8
u'فاللدم': u'فَاللّدَمُ', #1
u'فاللعباء': u'فَاللَّعْبَاءَ', #1
u'فإلم': u'فَإِلَّمْ', #1
u'فالمأتي': u'فَالْمَأْتِيُّ', #1
u'فالمازري': u'فَالْمَازِرِيُّ', #2
u'فالماش': u'فَالْمَاشُ', #1
u'فالماش': u'فَالْمَاشُّ', #2
u'فالماشى': u'فَالْمَاشِى', #1
u'فالماصدق': u'فَالْمَاصَدَقَ', #1
u'فالمبادله': u'فَالْمُبَادَلَهْ', #1
u'فالمبارأة': u'فَالْمُبَارَأَةُ', #2
u'فالمباضعة': u'فَالْمُبَاضَعَةُ', #1
u'فالمباعلة': u'فَالْمُبَاعَلَةُ', #1
u'فالمبان': u'فَالْمُبَانُ', #3
u'فالمباينة': u'فَالْمُبَايَنَةُ', #1
u'فالمبتنى': u'فَالْمُبْتَنَى', #1
u'فالمبتوتة': u'فَالْمَبْتُوتَةُ', #1
u'فالمبعض': u'فَالْمُبَعَّضُ', #1
u'فالمبعضة': u'فَالْمُبَعَّضَةُ', #1
u'فالمتجوز': u'فَالْمُتَجَوِّزُ', #1
u'فالمتخفف': u'فَالْمُتَخَفِّفُ', #4
u'فالمتعيب': u'فَالْمُتَعَيِّبُ', #1
u'فالمتكاري': u'فَالْمُتَكَارِي', #2
u'فالمتكاريان': u'فَالْمُتَكَارَيَانِ', #1
u'فالمتمحضة': u'فَالْمُتَمَحِّضَةُ', #1
u'فالمجاح': u'فَالْمُجَاحُ', #2
u'فالمجبوب': u'فَالْمَجْبُوبُ', #5
u'فالمحاصة': u'فَالْمُحَاصَّةُ', #2
u'فالمحاقلة': u'فَالْمُحَاقَلَةُ', #2
u'فالمحصر': u'فَالْمُحْصَرُ', #4
u'فالمحصوب': u'فَالْمَحْصُوبُ', #1
u'فالمحمودية': u'فَالْمَحْمُودِيَّةُ', #1
u'فالمخارجة': u'فَالْمُخَارَجَةُ', #1
u'فالمختال': u'فَالْمُخْتَالُ', #1
u'فالمخذل': u'فَالْمُخَذِّلُ', #1
u'فالمخضوب': u'فَالْمَخْضُوبُ', #1
u'فالمراطلة': u'فَالْمُرَاطَلَةُ', #2
u'فالمراعى': u'فَالْمُرَاعَى', #6
u'فالمرتث': u'فَالْمُرْتَثُّ', #2
u'فالمرتجز': u'فَالْمُرْتَجِزُ', #1
u'فالمرتضع': u'فَالْمُرْتَضَعُ', #2
u'فالمرتضع': u'فَالْمُرْتَضِعُ', #3
u'فالمرتضعة': u'فَالْمُرْتَضِعَةُ', #12
u'فالمزابنة': u'فَالْمُزَابَنَةُ', #4
u'فالمسامتة': u'فَالْمُسَامَتَةُ', #1
u'فالمستام': u'فَالْمُسْتَامُ', #1
u'فالمستبحر': u'فَالْمُسْتَبْحَرُ', #1
u'فالمستحاضة': u'فَالْمُسْتَحَاضَةُ', #1
u'فالمستحفظ': u'فَالْمُسْتَحْفَظُ', #1
u'فالمستحفظ': u'فَالْمُسْتَحْفِظُ', #1
u'فالمستسعى': u'فَالْمُسْتَسْعَى', #4
u'فالمستصنع': u'فَالْمُسْتَصْنَعُ', #1
u'فالمستقرض': u'فَالْمُسْتَقْرِضُ', #2
u'فالمستكري': u'فَالْمُسْتَكْرِي', #1
u'فالمستوفى': u'فَالْمُسْتَوْفَى', #8
u'فالمسناة': u'فَالْمُسَنَّاةُ', #6
u'فالمشاححة': u'فَالْمُشَاحَحَةُ', #1
u'فالمشاوذ': u'فَالْمَشَاوِذُ', #1
u'فالمشتراة': u'فَالْمُشْتَرَاةُ', #1
u'فالمشترى': u'فَالْمُشْتَرَى', #45
u'فالمشوذ': u'فَالْمِشْوَذُ', #1
u'فالمصافع': u'فَالْمُصَافِعُ', #1
u'فالمطاليا': u'فَالْمَطَالِيَا', #1
u'فالمعتر': u'فَالْمُعْتَرُّ', #1
u'فالمعجوز': u'فَالْمَعْجُوزُ', #1
u'فالمعدى': u'فَالْمُعَدَّى', #1
u'فالمعراض': u'فَالْمِعْرَاضُ', #1
u'فالمعيز': u'فَالْمَعِيزُ', #1
u'فالمغارسة': u'فَالْمُغَارَسَةُ', #1
u'فالمغالية': u'فَالْمُغَالِيَةُ', #1
u'فالمغروم': u'فَالْمَغْرُومُ', #4
u'فالمغلصمة': u'فَالْمُغَلْصِمَةُ', #1
u'فالمغيا': u'فَالْمُغَيَّا', #1
u'فالمفاتي': u'فَالْمَفَاتِي', #1
u'فالمفاعلة': u'فَالْمُفَاعَلَةُ', #16
u'فالمفقوءة': u'فَالْمَفْقُوءَةُ', #2
u'فالمقاثي': u'فَالْمَقَاثِي', #1
u'فالمقارض': u'فَالْمُقَارِضُ', #1
u'فالمقاعدة': u'فَالْمُقَاعَدَةُ', #1
u'فالمقيس': u'فَالْمَقِيسُ', #8
u'فالمكارى': u'فَالْمُكَارَى', #1
u'فالمكتراة': u'فَالْمُكْتَرَاةُ', #1
u'فالمكترى': u'فَالْمُكْتَرَى', #1
u'فالمكرى': u'فَالْمُكْرَى', #1
u'فالمكيون': u'فَالْمَكِّيُّونَ', #1
u'فالملازق': u'فَالْمُلَازِقُ', #2
u'فالملاقيح': u'فَالْمَلَاقِيحُ', #2
u'فالملحقه': u'فَالْمُلْحَقَهْ', #1
u'فالملزوم': u'فَالْمَلْزُومُ', #30
u'فالمناخل': u'فَالْمَنَاخِلُ', #1
u'فالمناكرة': u'فَالْمُنَاكَرَةُ', #1
u'فالمنخسف': u'فَالْمُنْخَسِفُ', #1
u'فالمندى': u'فَالْمُنَدَّى', #1
u'فالمنقود': u'فَالْمَنْقُودُ', #2
u'فالمنكسود': u'فَالْمَنْكسُودِ', #1
u'فالمهايأة': u'فَالْمُهَايَأَةُ', #17
u'فالمهايئات': u'فَالْمُهَايَئَاتُ', #1
u'فالمواجل': u'فَالْمَوَاجِلُ', #1
u'فالمؤبر': u'فَالْمُؤَبَّرُ', #5
u'فالمؤتم': u'فَالْمُؤْتَمُّ', #1
u'فالموريات': u'فَالْمُورِيَاتِ', #1
u'فالموطوءة': u'فَالْمَوْطُوءَةُ', #1
u'فالموقوذة': u'فَالْمَوْقُوذَةُ', #1
u'فالمؤنة': u'فَالْمُؤْنَةُ', #32
u'فالموهب': u'فَالْمُوهِبُ', #1
u'فالمئونة': u'فَالْمَئُونَةُ', #2
u'فالناصور': u'فَالنَّاصُورُ', #2
u'فالنامصة': u'فَالنَّامِصَةُ', #1
u'فالنبهرجة': u'فَالنَّبَهْرَجَةُ', #1
u'فالنبى': u'فَالنَّبِىُّ', #3
u'فالنجام': u'فَالنّجَامِ', #1
u'فالنجح': u'فَالنُّجْحُ', #2
u'فالنفسا': u'فَالنُّفَسَا', #1
u'فالهملاج': u'فَالْهِمْلَاجُ', #1
u'فالهملجة': u'فَالْهَمْلَجَةُ', #2
u'فالوالدية': u'فَالْوَالِدِيَّةُ', #1
u'فالوجادة': u'فَالْوِجَادَةُ', #2
u'فالوضو': u'فَالْوُضُو', #1
u'فالوقص': u'فَالْوَقَصُ', #10
u'فالوقص': u'فَالْوَقْصُ', #5
u'فالوقية': u'فَالْوَقِيَّةُ', #1
u'فالويبة': u'فَالْوَيْبَةُ', #1
u'فاليز': u'فَالِيزِ', #1
u'فاليز': u'فاليز', #3
u'فاليزا': u'فاليزا', #1
u'فاليزه': u'فاليزه', #1
u'فاليزيا': u'فاليزيا', #1
u'فاليزيا': u'فَالِيزِيًّا', #1
u'فاما': u'فامّا', #1
u'فأماالإمام': u'فَأَمَّاالْإِمَامُ', #1
u'فامتحشت': u'فَامْتَحَشَتْ', #1
u'فامتسح': u'فَامْتَسَحَ', #1
u'فامتسحت': u'فَامْتَسَحَتْ', #1
u'فأمذى': u'فَأَمْذَى', #19
u'فامر': u'فامر', #1
u'فأمرأته': u'فَأَمْرَأَتْهُ', #2
u'فأمرالنبي': u'فَأَمَرَالنَّبِيُّ', #1
u'فأمرأني': u'فَأَمْرَأَنِي', #1
u'فأمرتنى': u'فَأَمَرْتَنِى', #1
u'فأمرتنى': u'فَأَمَرَتْنِى', #5
u'فامرثه': u'فَامْرُثْهُ', #1
u'فأمرنى': u'فَأَمَرَنِى', #48
u'فامره': u'فامره', #2
u'فأمرونى': u'فَأَمَرُونِى', #2
u'فأمسكى': u'فَأَمْسِكِى', #2
u'فأمشير': u'فَأَمْشِيرْ', #1
u'فأمشير': u'فَأَمْشِيرُ', #2
u'فامكثى': u'فَامْكُثِى', #1
u'فأمكننى': u'فَأَمْكَنَنِى', #1
u'فأملصت': u'فَأَمْلَصَتْ', #1
u'فامي': u'فامي', #1
u'فامي': u'فَامِيٌّ', #2
u'فامي': u'فَامِيٍّ', #4
u'فأميتموهما': u'فَأَمِيتُمُوهُمَا', #1
u'فإناغتسل': u'فَإِنْاغْتَسَلَ', #1
u'فأنبأنى': u'فَأَنْبَأَنِى', #2
u'فأنبتتت': u'فأنبتتت', #1
u'فانبخس': u'فَانْبَخَسَ', #1
u'فأنبعت': u'فَأَنْبَعَتْ', #1
u'فانبغى': u'فَانْبَغَى', #2
u'فانبهمت': u'فَانْبَهَمَتْ', #2
u'فأنبهني،': u'فَأَنْبَهَنِي،', #2
u'فانتتف': u'فَانْتُتِفَ', #1
u'فانتثر': u'فَانْتَثَرَ', #7
u'فانتثر': u'فَانْتَثِرْ', #7
u'فانتثرت': u'فَانْتَثَرَتْ', #2
u'فانتسبني': u'فَانْتَسَبَنِي', #1
u'فانتشد': u'فَانْتَشَدَ', #7
u'فانتشطا': u'فَانْتَشَطَا', #1
u'فانتشطت': u'فَانْتَشَطَتْ', #1
u'فانتشطه': u'فَانْتَشَطَهُ', #1
u'فانتشطها': u'فَانْتَشَطَهَا', #1
u'فأنتشينا': u'فأْنتَشَيْنَا', #1
u'فانتضخ': u'فَانْتَضَخَ', #1
u'فانتضى': u'فَانْتَضَى', #3
u'فانتفحت': u'فَانْتَفَحَتْ', #1
u'فانتفعتموه،': u'فَانْتَفَعْتُمُوهُ،', #1
u'فانتفق': u'فَانْتَفَقَ', #1
u'فانتقعت': u'فَانْتَقَعَتْ', #1
u'فانتقلته،': u'فَانْتَقَلْتُهُ،', #1
u'فانتقله': u'فَانْتَقَلَهُ', #3
u'فانتقلها': u'فَانْتَقَلَهَا', #2
u'فانتقلى': u'فَانْتَقِلِى', #4
u'فانتقمه': u'فَانْتَقَمَهُ', #2
u'فانتلف': u'فَانْتَلَفَ', #1
u'فأنتمو': u'فَأَنْتُمُو', #1
u'فانتهرنى': u'فَانْتَهَرَنِى', #5
u'فانتهش': u'فَانْتَهَشَ', #3
u'فانتوى': u'فَانْتَوَى', #2
u'فانثعب': u'فَانْثَعَبَ', #1
u'فانثلج': u'فَانْثَلَجَ', #1
u'فانجحروا': u'فَانْجَحَرُوا', #1
u'فانجرح': u'فَانْجَرَحَ', #1
u'فانجرحت': u'فَانْجَرَحَتْ', #2
u'فانجعف': u'فَانْجَعَفَ', #2
u'فانجمد': u'فانجمد', #2
u'فانجمد': u'فَانْجَمَدَ', #2
u'فانحاش': u'فَانْحَاشَ', #1
u'فانحتم': u'فَانْحَتَمَ', #2
u'فانحرق': u'فانحرق', #1
u'فانحزم': u'فَانْحَزَمَ', #2
u'فانحسفت': u'فَانْحَسَفَتْ', #1
u'فانحكن': u'فَانْحَكَنْ', #1
u'فانحكوهن،': u'فَانْحِكُوهُنَّ،', #1
u'فانحلق': u'فَانْحَلَقَ', #1
u'فانحنث': u'فَانْحَنَثَ', #1
u'فانخزل': u'فَانْخَزَلَ', #2
u'فانخنس': u'فَانْخَنَسَ', #1
u'فانخنست': u'فَانْخَنَسْتُ', #1
u'فاندرأ': u'فَانْدَرَأَ', #1
u'فاندغمت': u'فَانْدَغَمَتْ', #2
u'فانذلق': u'فَانْذَلَقَ', #2
u'فانزلS': u'فَانْزِلْS', #1
u'فأنزلتنى': u'فَأَنْزَلَتْنِى', #1
u'فأنزى': u'فَأَنْزَى', #3
u'فأنسأتها': u'فَأَنْسَأْتَهَا', #1
u'فانساحت': u'فَانْسَاحَتْ', #2
u'فانساخ': u'فَانْسَاخَ', #1
u'فانساخت': u'فَانْسَاخَتْ', #1
u'فانسقطت': u'فَانْسَقَطَتْ', #1
u'فانشرخ': u'فَانْشَرَخَ', #1
u'فانشلى': u'فَانْشَلَى', #2
u'فانصاغ': u'فَانْصَاغَ', #1
u'فانصبغ': u'فَانْصَبَغَ', #17
u'فانصدغت،': u'فَانْصَدَغَتْ،', #1
u'فانصدمت': u'فَانْصَدَمَتْ', #1
u'فأنطاه': u'فَأَنْطَاهُ', #1
u'فانطلقى': u'فَانْطَلِقِى', #3
u'فانظرى': u'فَانْظُرِى', #8
u'فأنظور': u'فَأَنْظُورُ', #1
u'فانعثر': u'فَانْعَثَرَ', #2
u'فانعجف': u'فَانْعَجَفَ', #1
u'فانعقرت': u'فَانْعَقَرَتْ', #1
u'فانعلق': u'فَانْعَلَقَ', #1
u'فأنفجنا': u'فَأَنْفَجْنَا', #2
u'فانفرش': u'فَانْفَرَشَ', #3
u'فانفرى': u'فَانْفِرِى', #3
u'فأنفقى': u'فَأَنْفِقِى', #1
u'فأنفلكه': u'فَأُنَفِّلَكَهُ', #1
u'فانقضه': u'فَانْقُضْهُ', #8
u'فانقمع': u'فَانْقَمَعَ', #3
u'فانقمعتا': u'فَانْقَمَعْتَا', #1
u'فإنكان': u'فَإِنْكَانَ', #1
u'فانكتفت': u'فَانْكَتَفَتْ', #1
u'فأنكحنى': u'فَأَنْكِحْنِى', #1
u'فأنكحنى': u'فَأَنْكَحَنِى', #7
u'فأنكرالنبي': u'فَأَنْكَرَالنَّبِيُّ', #1
u'فانكسعت': u'فَانْكَسَعَتْ', #1
u'فانما': u'فانما', #3
u'فانماز': u'فَانْمَازَ', #2
u'فإنمامقامه': u'فَإِنَّمَامُقَامُهُ', #1
u'فانمسحت': u'فَانْمَسَحَتْ', #2
u'فانملس': u'فانْمَلَسَ', #1
u'فانملس': u'فَانْمَلَسَ', #1
u'فإننزل': u'فَإِنْنَزَلَ', #1
u'فانها': u'فَانّهَا', #1
u'فانهدرت': u'فَانْهَدَرَتْ', #1
u'فانهرق': u'فَانْهَرَقَ', #1
u'فإنههن': u'فَإِنَّههُنَّ', #1
u'فإنى': u'فَإِنّى', #1
u'فإنى': u'فَإِنَى', #16
u'فإنى': u'فَإِنِّى', #393
u'فإنى': u'فَإِنَّى', #9
u'فانيد': u'فَانِيدٌ', #1
u'فانيد': u'فَانِيدٍ', #1
u'فانيد': u'فَانِيدُ', #1
u'فانيذ': u'فَانِيذٍ', #2
u'فانيذا': u'فَانِيذًا', #1
u'فآها': u'فَآهًا', #1
u'فأهالوا': u'فَأَهَالُوا', #1
u'فأهالوه': u'فَأَهَالُوهُ', #1
u'فاهتجرا': u'فَاهْتَجَرَا', #1
u'فاهتضموا': u'فَاهْتُضِمُوا', #2
u'فأهدا': u'فأهدا', #1
u'فأهراق': u'فَأُهْرَاقَ', #2
u'فأهراق': u'فَأَهْرَاقَ', #5
u'فأهراقه': u'فَأَهْرَاقَهُ', #10
u'فأهراقوا': u'فَأَهَرَاقُوا', #1
u'فأهريق': u'فَأُهَرِيقَ', #2
u'فأهريق': u'فَأُهْرِيقَ', #27
u'فأهريقت': u'فَأُهْرِيقَتِ', #1
u'فأهريقت،': u'فَأُهْرِيقَتْ،', #1
u'فأهريقت': u'فَأُهَرِيقَتْ', #2
u'فأهريقت': u'فَأُهْرِيقَتْ', #9
u'فأهريقوا': u'فَأَهْرِيقُوا', #33
u'فأهريقوه': u'فَأَهْرِيقُوهُ', #3
u'فأهريقي': u'فَأَهْرِيقِي', #1
u'فأهلى': u'فَأَهِلِّى', #4
u'فأهمنى': u'فَأَهَمَّنِى', #1
u'فأهنيه': u'فَأُهَنِّيهِ', #1
u'فأهنيه': u'فَأُهَنِّيَهُ', #1
u'فأهنيها': u'فَأُهَنِّيهَا', #2
u'فاوت': u'فَاوَتَ', #17
u'فأوترى': u'فَأَوْتِرِى', #1
u'فأوجعنى': u'فَأَوْجَعَنِى', #1
u'فأوجئوا': u'فأوجئوا', #1
u'فأودعنيها': u'فَأَوْدَعَنِيهَا', #1
u'فأوطاس': u'فَأَوْطَاسٌ', #2
u'فأوطت': u'فَأَوْطَتْ', #1
u'فاوع': u'فَاوْعِ', #1
u'فأوقصته': u'فَأَوْقَصَتْهُ', #4
u'فأوقصه،': u'فَأَوْقَصَهُ،', #1
u'فأوقفتنى': u'فَأَوْقَفَتْنِى', #3
u'فأوكأت': u'فَأَوْكَأَتْ', #3
u'فأوكت': u'فَأَوْكَتْ', #3
u'فأوكرت': u'فَأَوْكَرَتْ', #3
u'فأوكئه': u'فَأُوكِئُهُ', #1
u'فأوكيه': u'فأوكيه', #1
u'فاؤلف': u'فاؤلف', #1
u'فأوم': u'فَأُومِ', #2
u'فأوم': u'فَأَوْمِ', #9
u'فأوما': u'فَأَوْمَا', #1
u'فأومأإلى': u'فَأَوَمَأَإِلَى', #1
u'فأومأوا': u'فأومأوا', #1
u'فأومت': u'فَأَوْمَتْ', #5
u'فأومى': u'فَأَوْمَى', #10
u'فآؤوا': u'فَآؤُوا', #1
u'فائتدموا': u'فَائْتَدِمُوا', #1
u'فائتفكت': u'فائتفكت', #1
u'فائتموا': u'فَائْتَمُّوا', #7
u'فائتنف': u'فَائْتَنِفْ', #1
u'فائتنى': u'فَائْتِنِى', #3
u'فائتونى': u'فَائْتُونِى', #1
u'فائتى': u'فَائْتِى', #1
u'فائد': u'فَائدٍ', #1
u'فائد،': u'فائد،', #2
u'فائد': u'فَائِدَ', #2
u'فائد': u'فَائِدُ', #2
u'فائد': u'فَائِدٍ', #33
u'فائد': u'فَائِد', #5
u'فائد،': u'فَائِدٍ،', #6
u'فائد': u'فَائِدِ', #7
u'فائد': u'فَائِدٌ', #8
u'فائدا': u'فَائِدًا', #1
u'فائده': u'فَائِده', #1
u'فائده': u'فَائِدَهْ', #3
u'فائذنى': u'فَائْذَنِى', #1
u'فائش': u'فَائِشِ', #2
u'فائع': u'فَائِعٌ', #1
u'فائلا': u'فَائِلًا', #1
u'فإياى': u'فَإِيَّاىَ', #1
u'فآيسه': u'فَآيِسْهُ', #1
u'فأيش': u'فَأَيْش', #1
u'فأيش': u'فَأَيْشٍ', #1
u'فأيش': u'فَأَيْشْ', #1
u'فأيقظينى': u'فَأَيْقِظِينِى', #1
u'فإيلآن': u'فَإِيلَآنٌ', #1
u'فايم': u'فَايْمُ', #4
u'فبا': u'فَبَا', #1
u'فباءوا': u'فَبَاءُوا', #13
u'فبابة': u'فَبَابَةُ', #1
u'فبأبى': u'فَبِأَبِى', #5
u'فبارزنى': u'فَبَارَزَنِى', #1
u'فباسترقاق': u'فَبِاسْتِرْقَاقِ', #1
u'فباعنى': u'فَبَاعَنِى', #1
u'فباعنيه': u'فَبَاعَنِيهِ', #1
u'فبالأحظ': u'فَبِالْأَحَظِّ', #1
u'فبالأدا': u'فَبِالْأَدَا', #3
u'فبالأغبط': u'فَبِالْأَغْبَطِ', #1
u'فبالإياس': u'فَبِالْإِيَاسِ', #1
u'فبالتطليقة': u'فَبِالتَّطْلِيقَةِ', #1
u'فبالحرى': u'فَبِالْحَرِىِّ', #1
u'فبالذى': u'فَبِالَّذِى', #9
u'فبالشقص': u'فَبِالشِّقْصِ', #1
u'فبالضيمران': u'فَبِالضَّيْمَرَانِ', #2
u'فبالغموس': u'فَبِالْغَمُوسِ', #1
u'فبالفسوخ': u'فَبِالْفُسُوخِ', #1
u'فبالما': u'فَبِالْمَا', #1
u'فبالمجامعه': u'فَبِالْمُجَامَعَهْ', #1
u'فبالمهايأة': u'فَبِالْمُهَايَأَةِ', #2
u'فبآؤوا': u'فَبَآؤُواْ', #1
u'فبأى': u'فَبِأَىِّ', #3
u'فبائتون': u'فبائتون', #1
u'فبايعنى': u'فَبَايَعَنِى', #2
u'فبايعونى': u'فَبَايَعُونِى', #1
u'فبتسليمتين': u'فَبِتَسْلِيمَتَيْنِ', #1
u'فبتما': u'فَبِتُّمَا', #2
u'فبثخانة': u'فَبِثَخَانَةٍ', #2
u'فبثخانة': u'فَبِثَخَانَةِ', #2
u'فبثلاثتين': u'فَبِثَلَاثَتَيْنِ', #1
u'فبحبح': u'فَبَحْبَحَ', #1
u'فبخارى': u'فَبُخَارَى', #2
u'فبدءوا': u'فَبَدَءُوا', #5
u'فبدانق': u'فَبِدَانَقٍ', #2
u'فبدأنى': u'فَبَدَأَنِى', #1
u'فبدرتنى': u'فَبَدَرَتْنِى', #2
u'فبدى': u'فَبَدَّى', #1
u'فبرءوس': u'فَبِرُءُوسِ', #1
u'فبرمهات': u'فَبَرَمْهَاتْ', #1
u'فبرمهات': u'فَبَرَمْهَاتُ', #2
u'فبرمودة': u'فَبَرْمُودَةُ', #2
u'فبرموده': u'فَبَرْمُودَهْ', #1
u'فبرىء': u'فبرىء', #1
u'فبشرنى': u'فَبَشَّرَنِى', #3
u'فبشنس': u'فَبَشَنْسُ', #2
u'فبعثنى': u'فَبَعَثَنِى', #8
u'فبعثونى': u'فَبَعَثُونِى', #2
u'فبعصا': u'فَبِعَصًا', #1
u'فبقرأين': u'فَبِقُرْأَيْنِ', #1
u'فبقرمود': u'فَبِقُرْمُودٍ', #1
u'فبكتوه': u'فَبَكَّتُوهُ', #3
u'فبكثوا': u'فَبَكَثُوا', #1
u'فبكعه': u'فَبَكَعَهُ', #4
u'فبلأي': u'فَبِلأْيٍ', #1
u'فبلأي': u'فَبِلَأْيٍ', #1
u'فبلغتنى': u'فَبَلَغَتْنِى', #1
u'فبلغناكموه': u'فَبَلَّغْنَاكُمُوهُ', #1
u'فبلغنى': u'فَبَلَغَنِى', #6
u'فبلى': u'فَبَلَى', #7
u'فبهرام': u'فَبَهْرَامُ', #1
u'فبهشوا': u'فَبَهَشُوا', #1
u'فبولى': u'فَبُولِى', #3
u'فبؤنة': u'فبؤنة', #1
u'فبؤنة': u'فَبُؤْنَةُ', #1
u'فبئونه': u'فَبَئُونَهْ', #1
u'فبينون': u'فَبَيْنُونُ', #1
u'فبينى': u'فَبَيْنِى', #1
u'فتأبيت': u'فَتَأَبَّيْت', #1
u'فتأتنف': u'فَتَأْتَنِفُ', #8
u'فتاتى': u'فَتَاتِى', #2
u'فتأثلت': u'فَتَأَثّلْت', #1
u'فتأدى': u'فَتَأَدَّى', #6
u'فتاركني': u'فَتَارِكْنِي', #1
u'فتأكلهSحديث': u'فَتَأْكُلُهُSحَدِيثُ', #1
u'فتالهم': u'فتالهم', #1
u'فتاوى': u'فَتَاوًى', #1
u'فتأويان': u'فَتَأْوِيَانِ', #1
u'فتاى': u'فَتَاىَ', #3
u'فتأيمت': u'فتأيمت', #1
u'فتأيمت': u'فَتَأَيَّمَتْ', #7
u'فتبادرناها': u'فَتَبَادَرْنَاهَا', #2
u'فتبجست': u'فَتَبَجّسَتْ', #1
u'فتبذلت': u'فَتَبَذَّلَتْ', #2
u'فتبرءوا': u'فَتَبَرَّءُوا', #1
u'فتبعض': u'فَتَبَعَّضَ', #1
u'فتبعض': u'فَتُبَعَّضُ', #2
u'فتبوآن': u'فَتُبَوَّآنِ', #1
u'فتبورت': u'فَتَبَوَّرَتْ', #1
u'فتبيعنيه،': u'فَتَبِيعَنِيهِ،', #1
u'فتبينى': u'فَتَبِينِى', #1
u'فتتأدى': u'فَتَتَأَدَّى', #11
u'فتتأديان': u'فَتَتَأَدَّيَانِ', #1
u'فتتأذى': u'فَتَتَأَذَّى', #3
u'فتتاركا': u'فَتَتَارَكَا', #3
u'فتتام': u'فَتَتَامُ', #1
u'فتتام': u'فَتَتَامَّ', #1
u'فتتامت': u'فَتَتَامَّتْ', #4
u'فتتحاصص': u'فَتَتَحَاصَصُ', #1
u'فتتخدر': u'فَتَتَخَدَّرَ', #1
u'فتتخدر': u'فَتَتَخَدَّرُ', #2
u'فتترس': u'فَتَتَرَّسَ', #1
u'فتترسوا': u'فَتَتَرَّسُوا', #5
u'فتتساويان': u'فَتَتَسَاوَيَانِ', #1
u'فتتشرق': u'فَتَتَشَرّقُ', #2
u'فتتعمر': u'فَتَتَعَمَّرُ', #2
u'فتتغلظ': u'فَتَتَغَلَّظُ', #1
u'فتتقايأه': u'فَتَتَقَايَأَهُ', #1
u'فتتلجم': u'فَتَتَلَجَّمُ', #1
u'فتتمانع': u'فَتَتَمَانَعُ', #1
u'فتتمحض': u'فَتَتَمَحَّضُ', #3
u'فتتوحه': u'فَتَتَوَحَّهُ', #1
u'فتتوضئين': u'فَتَتَوَضَّئِينَ', #1
u'فتثاور': u'فَتَثَاوَرَ', #2
u'فتجاحدا': u'فَتَجَاحَدَا', #1
u'فتجاحدهما': u'فَتَجَاحُدُهُمَا', #1
u'فتجاولا': u'فَتَجَاوَلَا', #1
u'فتجتزئ': u'فَتَجْتَزِئُ', #4
u'فتجشيت': u'فَتَجَشَّيْت', #1
u'فتجلبت': u'فَتَجَلَّبَتْ', #1
u'فتجهمنى': u'فَتَجَهَّمَنِى', #1
u'فتجوزتها': u'فَتَجَوَّزْتهَا', #1
u'فتجوير': u'فَتَجْوِيرُ', #1
u'فتجىء': u'فَتَجِىءُ', #2
u'فتجيزى': u'فَتُجِيزِى', #1
u'فتجيئه': u'فَتَجِيئُهُ', #1
u'فتحاجزوا': u'فَتَحَاجَزُوا', #3
u'فتحارسنا': u'فَتَحَارَسْنَا', #1
u'فتحاص': u'فَتَحَاصّ', #1
u'فتحاص': u'فَتَحَاصَّ', #1
u'فتحاص': u'فَتُحَاصُّ', #1
u'فتحاصا': u'فَتَحَاصًّا', #1
u'فتحاصا': u'فَتَحَاصَّا', #2
u'فتحاصت': u'فَتَحَاصَّتْ', #1
u'فتحاصص': u'فَتُحَاصَصُ', #1
u'فتحاصص': u'فَتُحَاصِصَ', #1
u'فتحاصص': u'فَتُحَاصِصْ', #2
u'فتحاصص': u'فَتُحَاصِصُ', #6
u'فتحتفز': u'فَتَحْتَفِزُ', #1
u'فتحرفت': u'فتحرفت', #1
u'فتحرفت': u'فَتَحَرَّفْتَ', #1
u'فتحنطت': u'فتحنطت', #1
u'فتحولنى': u'فَتُحَوِّلُنِى', #1
u'فتحيضى': u'فَتَحَيَّضِى', #1
u'فتخاء': u'فَتَخَاءُ', #1
u'فتخة': u'فَتَخَةٍ', #1
u'فتخة': u'فَتْخَة', #1
u'فتخة': u'فَتْخَةٍ', #1
u'فتخة': u'فَتْخَةِ', #1
u'فتختلع': u'فَتَخْتَلِعُ', #2
u'فتختمت': u'فَتَخَتَّمَتْ', #1
u'فتدملت': u'فَتَدَمَّلَتْ', #2
u'فتدهدهت': u'فَتَدَهْدَهَتْ', #1
u'فتدهدى': u'فَتَدَهْدَى', #1
u'فتذامروا': u'فَتَذَامَرُوا', #2
u'فتراكه': u'فَتَرَاكَهُ', #2
u'فترانى': u'فَتَرَانِى', #2
u'فتراوضنا': u'فَتَرَاوَضْنَا', #4
u'فترتضع': u'فَتَرْتَضِعَ', #1
u'فترتفض': u'فترتفض', #1
u'فترتفض': u'فَتَرْتَفِضُ', #3
u'فترتفض': u'فَتُرْتَفَضُ', #3
u'فتركنى': u'فَتَرَكَنِى', #1
u'فتزلعت': u'فَتَزَلَّعَتْ', #1
u'فتزوجى': u'فَتَزَوَّجِى', #1
u'فتساورت': u'فَتَسَاوَرْتُ', #1
u'فتساوقا': u'فَتَسَاوَقَا', #5
u'فتستتاب': u'فَتُسْتَتَابُ', #1
u'فتستثنيان': u'فَتُسْتَثْنَيَانِ', #1
u'فتستدخله': u'فَتَسْتَدْخِلَهُ', #1
u'فتستدخله': u'فَتَسْتَدْخِلُهُ', #1
u'فتستن': u'فَتَسْتَنُّ', #2
u'فتستوهب': u'فَتَسْتَوْهِبُ', #1
u'فتستويان': u'فَتَسْتَوِيَانِ', #2
u'فتسجيت': u'فَتَسَجَّيْتُ', #2
u'فتسخطت': u'فَتَسَخَّطَتْ', #1
u'فتسخطته،': u'فَتَسَخَّطَتْهُ،', #1
u'فتسليمتين': u'فَتَسْلِيمَتَيْنِ', #1
u'فتسمنت': u'فتسمنت', #1
u'فتشامت': u'فَتَشَامَّتِ', #1
u'فتشدخ': u'فَتَشْدَخُ', #1
u'فتشربت': u'فَتَشَرَّبَتْ', #1
u'فتشربته': u'فَتَشَرَّبَتْهُ', #1
u'فتشزن': u'فَتَشَزَّنَ', #1
u'فتشطرت': u'فَتَشَطَّرَتْ', #1
u'فتشقيان،': u'فتشقيان،', #1
u'فتشقيان': u'فَتَشْقَيَانِ', #1
u'فتصحفت': u'فَتَصَحَّفَتْ', #1
u'فتصدانى': u'فَتَصَدَّانِى', #2
u'فتصرب': u'فَتُصْرَبُ', #1
u'فتصلقه': u'فَتَصْلُقُهُ', #1
u'فتصورف': u'فَتُصُورِفَ', #1
u'فتصيبنى': u'فَتُصِيبُنِى', #2
u'فتضرونى': u'فَتَضُرُّونِى', #1
u'فتضعفت': u'فَتَضَعَّفْتُ', #3
u'فتضيفت': u'فَتَضَيَّفْتُ', #1
u'فتطليقة': u'فَتَطْلِيقَةٌ', #4
u'فتطليقتان': u'فَتَطْلِيقَتَانِ', #1
u'فتطهرى': u'فَتَطْهُرِى', #1
u'فتطهرى': u'فَتَطَهَّرِى', #2
u'فتطوقت': u'فَتَطَوَّقَتْ', #1
u'فتطؤه': u'فَتَطَؤُهُ', #8
u'فتعات': u'فَتَعَاتّ', #1
u'فتعاررت': u'فَتَعَارَرْتُ', #1
u'فتعسلت': u'فَتَعَسَّلَتْ', #1
u'فتعصفر': u'فَتَعَصْفَرَ', #1
u'فتعطيان': u'فَتُعْطَيَانِ', #1
u'فتعطينيه': u'فَتُعْطِينِيهِ', #1
u'فتعقى': u'فَتُعْقَى', #1
u'فتعيبت': u'فَتَعَيَّبَتْ', #8
u'فتغلبونى': u'فَتَغْلِبُونِى', #1
u'فتغلظت': u'فَتَغَلَّظَتْ', #3
u'فتفاج': u'فَتَفَاجَّ', #3
u'فتفاجت': u'فَتَفاجَّتْ', #1
u'فتفاجت': u'فَتَفَاجّتْ', #1
u'فتفاجت': u'فَتَفَاجَّتْ', #1
u'فتفتض': u'فَتَفْتَضّ', #1
u'فتفتض': u'فَتَفْتَضُّ', #10
u'فتفرخت': u'فَتَفَرَّخَتْ', #4
u'فتفوح': u'فَتَفُوحُ', #1
u'فتقادع': u'فَتَقَادَعُ', #1
u'فتقايأها': u'فَتَقَايَأَهَا', #1
u'فتقتلنى': u'فَتَقْتُلَنِى', #1
u'فتقيأه': u'فَتَقَيَّأَهُ', #1
u'فتكاب': u'فَتَكَابَّ', #1
u'فتكاته': u'فَتَكَاتِهِ', #1
u'فتكارت': u'فَتَكَارَتْ', #2
u'فتكاريتها': u'فَتَكَارِيَتُهَا', #1
u'فتكشطت': u'فَتَكَشَّطَتْ', #3
u'فتكلمى': u'فَتَكَلَّمِى', #1
u'فتكوعت': u'فَتَكَوَّعَتْ', #1
u'فتلاء': u'فَتْلَاءِ', #2
u'فتلتمع': u'فَتَلْتَمِعَ', #1
u'فتلفعت': u'فَتَلَفَّعَتْ', #1
u'فتلقانى': u'فَتَلَقَّانِى', #2
u'فتلكت': u'فَتَلَكَّتِ', #1
u'فتلمحت': u'فَتَلَمَّحْتُ', #1
u'فتلمظ،': u'فتلمظ،', #1
u'فتلمظ': u'فَتَلَمَّظَ', #3
u'فتلومنى': u'فَتَلُومُنِى', #1
u'فتمتحق': u'فَتَمْتَحِقُ', #1
u'فتمتلىء': u'فتمتلىء', #1
u'فتمجس': u'فَتَمَجَّسَ', #6
u'فتمجسا': u'فَتَمَجَّسَا', #4
u'فتمجست': u'فَتَمَجَّسَتْ', #5
u'فتمحضت': u'فَتَمَحَّضَتْ', #9
u'فتمحيض': u'فَتَمْحِيضُ', #1
u'فتمحيضه': u'فَتَمْحِيضُهُ', #1
u'فتمخى': u'فَتَمَخَّى', #1
u'فتمرضنى': u'فَتُمْرِضُنِى', #1
u'فتمرط': u'فَتَمَرَّطَ', #3
u'فتمزع': u'فَتَمَزَّعَ', #2
u'فتمطأت': u'فَتَمَطَّأْتُ', #1
u'فتمعر': u'فَتَمَعَّرَ', #9
u'فتمعط': u'فَتَمَعَّطَ', #5
u'فتمعطت': u'فَتَمَعَّطَتْ', #1
u'فتمعكت': u'فَتَمَعَّكْتُ', #16
u'فتمعكت': u'فَتَمَعَّكْت', #7
u'فتموتت': u'فَتُمُوِّتَتْ', #1
u'فتناخرت': u'فَتَنَاخَرَتْ', #5
u'فتنافستموها': u'فَتَنَافَسْتُمُوهَا', #1
u'فتناولنى': u'فَتَنَاوَلَنِى', #2
u'فتنجير': u'فَتَنْجِيرٌ', #1
u'فتندرئ': u'فَتَنْدَرِئُ', #2
u'فتنسئها': u'فَتُنْسِئُهَا', #2
u'فتنشيء': u'فَتُنْشِيءُ', #1
u'فتنفسد': u'فَتَنْفَسِدُ', #1
u'فتنفعونى': u'فَتَنْفَعُونِى', #1
u'فتنقمع': u'فَتَنْقَمِعُ', #1
u'فتنهزل': u'فَتَنْهَزِلُ', #1
u'فتهابنا': u'فَتَهَابُنَا', #1
u'فتهارج': u'فَتَهَارَجَ', #1
u'فتهامة': u'فَتِهَامَةُ', #4
u'فتهايآ': u'فَتَهَايَآ', #10
u'فتهايأ': u'فَتَهَايَأَ', #2
u'فتهايؤا': u'فَتَهَايُؤَا', #1
u'فتهايئا': u'فَتَهَايَئَا', #3
u'فتهراق': u'فَتُهْرَاقُ', #2
u'فتهرى': u'فَتَهَرَّى', #1
u'فتهيأوا': u'فَتَهَيَّأُوا', #1
u'فتؤاجر': u'فَتُؤَاجِرُ', #1
u'فتؤاجر': u'فَتُؤَاجَرُ', #3
u'فتؤاخذ': u'فَتُؤَاخَذ', #1
u'فتؤاخذ': u'فَتُؤَاخِذُ', #1
u'فتؤاخذ': u'فَتُؤَاخَذُ', #8
u'فتؤاخذه': u'فَتُؤَاخِذُهُ', #1
u'فتواضعناها': u'فَتَوَاضَعْنَاهَا', #1
u'فتواطئت': u'فَتَوَاطَئْتُ', #1
u'فتوامرنا،': u'فَتَوَامَرْنَا،', #1
u'فتؤديان': u'فَتُؤَدِّيَانِ', #2
u'فتوضئى': u'فَتَوَضَّئِى', #3
u'فتوقتتا': u'فَتَوَقَّتَتَا', #1
u'فتوهقه': u'فَتُوهِقُهُ', #1
u'فتئول': u'فَتَئُولُ', #2
u'فتيأبا': u'فَتَيْأَبَا', #4
u'فتياممت': u'فَتَيَامَمْتُ', #1
u'فتيانى': u'فِتْيَانِى', #5
u'فتيتى': u'فِتْيَتِى', #1
u'فثع': u'فَثَعَّ', #2
u'فثعب': u'فَثَعَبَ', #2
u'فثلاثه': u'فَثَلَاثُهُ', #1
u'فثلثمائة': u'فَثُلْثُمِائَةِ', #1
u'فثلثمائة': u'فَثَلَثُمِائَةٍ', #2
u'فثلثمائة': u'فَثَلَثُمِائَةِ', #3
u'فثلطت': u'فَثَلَطَتْ', #10
u'فجء': u'فَجْءٍ', #1
u'فجء': u'فَجْءِ', #1
u'فجاءتنى': u'فَجَاءَتْنِى', #1
u'فجاءنى': u'فَجَاءَنِى', #19
u'فجاءوا': u'فجاءوا', #1
u'فجاءوا': u'فَجَاءُوا', #164
u'فجاءوا،': u'فَجَاءُوا،', #9
u'فجاءوني': u'فَجَاءُونِي', #1
u'فجاءوه': u'فجاءوه', #1
u'فجاءوه،': u'فَجَاءُوهُ،', #2
u'فجاءوه': u'فَجَاءُوهُ', #9
u'فجاءوهم': u'فَجَاءُوهُمْ', #3
u'فجارSحول': u'فَجَارِSحَوْلَ', #1
u'فجاض': u'فَجَاضَ', #4
u'فجاؤا': u'فَجَاؤا', #1
u'فجاؤه': u'فَجَاؤُهُ', #1
u'فجبذنى': u'فَجَبَذَنِى', #1
u'فجبرائيل': u'فَجَبْرَائِيلُ', #1
u'فجثى': u'فَجَثَى', #2
u'فجحدنى': u'فَجَحَدَنِى', #1
u'فجحشت': u'فَجَحَشَتْ', #1
u'فجحشت': u'فَجُحِشَتْ', #1
u'فجحظت': u'فجحظت', #1
u'فجحف': u'فَجَحَفَ', #3
u'فجدح': u'فَجَدَحَ', #5
u'فجدودة': u'فَجُدُودَةٍ', #1
u'فجدى': u'فَجُدِّى', #2
u'فجذبنى': u'فَجَذَبَنِى', #4
u'فجذعة': u'فَجَذَعَةَ', #2
u'فجذعة': u'فَجَذَعَةُ', #2
u'فجذعة': u'فَجَذَعَةٌ', #3
u'فجرات': u'فَجَرَاتٍ', #1
u'فجرات': u'فَجَرَّاتُ', #1
u'فجرات': u'فَجَرَاتُ', #2
u'فجرهمي': u'فَجُرْهُمِيٌّ', #2
u'فجريب': u'فَجَرِيبٌ', #1
u'فجريب': u'فَجَرِيبُ', #4
u'فجزء': u'فَجُزْءً', #1
u'فجزءوها': u'فَجَزّءُوهَا', #1
u'فجزآؤه': u'فَجَزَآؤُهُ', #1
u'فجعالة': u'فَجِعَالَةٌ', #4
u'فجعالة': u'فَجَعَالَةٌ', #5
u'فجعفتها': u'فَجَعَفَتْهَا', #2
u'فجعلنى': u'فَجَعَلَنِى', #15
u'فجعلونى': u'فَجَعَلُونِى', #1
u'فجلسنى': u'فَجَلَّسَنِى', #1
u'فجلسها': u'فَجَلَسَهَا', #2
u'فجلعت': u'فَجَلَعْتُ', #1
u'فجلعها': u'فَجَلَعَهَا', #1
u'فجلعوا': u'فَجَلَعُوا', #2
u'فجنأ': u'فَجَنَأَ', #2
u'فجهجأه': u'فَجَهْجَأَهُ', #1
u'فجىء': u'فَجِىءَ', #31
u'فجئتمانى': u'فَجِئْتُمَانِى', #1
u'فجئتنى': u'فَجِئْتَنِى', #1
u'فجئثت': u'فَجُئِثْتُ', #7
u'فجيىء': u'فَجِيىءَ', #2
u'فجيئى': u'فَجِيئِى', #1
u'فحاسوا': u'فَحَاسُوا', #8
u'فحاصت': u'فَحَاصَّتْ', #1
u'فحاصت': u'فَحَاصَتْ', #3
u'فحاصص': u'فَحَاصَصَ', #2
u'فحاصصها': u'فَحَاصِصْهَا', #1
u'فحاصوا': u'فَحَاصُوا', #1
u'فحاصوا': u'فَحَاصُّوا', #1
u'فحبسنى': u'فَحَبَسَنِى', #1
u'فحترت': u'فَحُتِرَتْ', #1
u'فحتيتها': u'فَحَتَّيْتُهَا', #1
u'فحثحثها': u'فَحَثْحَثَهَا', #1
u'فحثى': u'فَحُثِىَ', #1
u'فحثى': u'فَحَثَى', #13
u'فحجى': u'فَحُجِّى', #5
u'فحدثتنى': u'فَحَدَّثَتْنِى', #6
u'فحدثنى': u'فَحَدِّثْنِى', #2
u'فحدثنى': u'فَحَدَّثَنِى', #83
u'فحدثنيعمرو': u'فَحَدَّثَنِيعَمْرُو', #1
u'فحدثنيه،': u'فَحَدَّثَنِيهِ،', #1
u'فحدثنيه': u'فَحَدَّثَنِيهِ', #11
u'فحدثنيها': u'فَحَدَّثَنِيهَا', #1
u'فحدثونى': u'فَحَدَّثُونِى', #1
u'فحدثونى': u'فَحَدِّثُونِى', #1
u'فحدقنى': u'فَحَدَقَنِى', #2
u'فحصبنى': u'فَحَصَبَنِى', #2
u'فحطأنى': u'فَحَطَأَنِى', #1
u'فحفظنيها': u'فَحَفَّظَنِيهَا', #1
u'فحلأتهم،': u'فَحَلأْتُهُمْ،', #1
u'فحملنى': u'فَحَمَلَنِى', #2
u'فحنذ': u'فَحُنِذَ', #1
u'فحولنى': u'فَحَوَّلَنِى', #2
u'فحومل': u'فَحَوْمَلِ', #7
u'فحى': u'فَحَىَّ', #1
u'فحيهلا': u'فَحَيَّهَلاَ', #1
u'فحيهلا': u'فَحَيْهلًا', #1
u'فحيهلا': u'فَحَيَّهَلَا', #1
u'فخاس': u'فَخَاسَ', #2
u'فخاسق': u'فَخَاسِقٌ', #3
u'فخاصمنى': u'فَخَاصَمَنِى', #1
u'فخاصمونى': u'فَخَاصَمُونِى', #1
u'فخالفتنى': u'فَخَالَفَتْنِى', #1
u'فخالفتيني': u'فَخَالَفْتِينِي', #4
u'فخالفنى': u'فَخَالَفَنِى', #1
u'فخذة': u'فَخْذَةِ', #2
u'فخذف،': u'فَخَذَفَ،', #1
u'فخذف': u'فَخُذِفَ', #2
u'فخذف': u'فَخَذَفَ', #5
u'فخذفت': u'فَخُذِفَتْ', #2
u'فخذفت': u'فَخَذَفَتْ', #3
u'فخذفته': u'فَخَذَفْته', #1
u'فخذفته': u'فَخَذَفْتَهُ', #2
u'فخذى': u'فَخَذِى', #1
u'فخذى': u'فَخُذِى', #2
u'فخذى': u'فَخِذِى', #29
u'فخذى': u'فَخِذَىَّ', #3
u'فخذيت': u'فَخَذِيتُ', #2
u'فخرء': u'فَخُرْءُ', #1
u'فخرجو': u'فخرجو', #1
u'فخرؤها': u'فَخَرْؤُهَا', #1
u'فخرؤهما': u'فَخُرْؤُهُمَا', #1
u'فخرى': u'فَخْرَى', #1
u'فخزم': u'فَخُزِمَ', #1
u'فخزم': u'فَخَزَمَ', #3
u'فخزيمة': u'فَخُزَيْمَةُ', #3
u'فخسق': u'فَخَسَقَ', #2
u'فخضخضته': u'فَخَضْخَضَتْهُ', #1
u'فخطبنى': u'فَخَطَبَنِى', #3
u'فخلفتنى': u'فَخَلَّفَتْنِى', #1
u'فخلفونى': u'فَخَلَّفُونِى', #1
u'فخلقونى': u'فَخَلَّقُونِى', #1
u'فخيرونى': u'فَخَيَّرُونِى', #1
u'فدا': u'فِداً', #2
u'فدا': u'فِدًا', #5
u'فدادا': u'فِدَادًا', #1
u'فدافد': u'فَدَافِدَ', #1
u'فدانق': u'فَدَانَقُ', #3
u'فدانق': u'فَدَانِقُ', #3
u'فداى': u'فداى', #1
u'فدثرونى': u'فَدَثَّرُونِى', #2
u'فدعانى': u'فَدَعَانِى', #20
u'فدعتنى': u'فَدعَتْنِى', #1
u'فدعتنى': u'فَدَعَتْنِى', #1
u'فدعنى': u'فَدَعْنِى', #2
u'فدعونى': u'فَدَعَوْنِى', #1
u'فدعى': u'فَدَعِى', #11
u'فدعى': u'فَدُعِىَ', #14
u'فدعى': u'فَدَعَى', #7
u'فدعياني': u'فدعياني', #1
u'فدفد': u'فَدْفَدٌ', #1
u'فدفد': u'فَدْفَدٍ', #11
u'فدفدا': u'فَدْفَدًا', #3
u'فدقر': u'فَدَقَر', #1
u'فدلنى': u'فَدُلَّنِى', #2
u'فدلونى': u'فَدُلُّونِى', #1
u'فدمعى': u'فَدَمْعَى', #1
u'فدهدهوا': u'فَدُهْدِهُوا', #1
u'فدهدهوه': u'فَدَهْدِهُوهُ', #1
u'فدونكها': u'فَدُونَكَهَا', #3
u'فديدا': u'فَدِيدًا', #1
u'فذارها': u'فَذَارَّهَا', #1
u'فذرنى': u'فَذَرْنِى', #1
u'فذعتني': u'فَذَعَتَنِي', #1
u'فذعته': u'فَذَعْتهُ', #1
u'فذعته': u'فَذَعَتُّهُ', #4
u'فذكرقارون': u'فَذَكَرَقَارُونَ', #1
u'فذكرنى': u'فَذَكَّرَنِى', #1
u'فذكرنيه': u'فَذَكَّرَنِيهِ', #1
u'فذكرنيها': u'فَذَكَّرَنِيهَا', #2
u'فذكرونى': u'فَذَكِّرُونِى', #3
u'فذلكقوله': u'فَذَلِكَقَوْلُهُ', #1
u'فذميل': u'فَذَمِيلُ', #1
u'فذهبتبه': u'فَذَهَبَتْبِهِ', #1
u'فذهبمالك': u'فَذَهَبَمَالِكٌ', #1
u'فذوذيته': u'فُذُوذِيَّتُهُ', #1
u'فذئر': u'فَذَئِرَ', #1
u'فذيرة': u'فُذَيْرَةُ', #1
u'فرءاه': u'فَرَءَاهُ', #1
u'فرءوس': u'فَرُءُوسُ', #1
u'فرأتنى': u'فَرَأَتْنِى', #2
u'فراشهيييي': u'فِرَاشِهِيييي', #1
u'فراعنى': u'فَرَاعَنِى', #1
u'فراعونى': u'فَرَاعُونِى', #1
u'فراغى': u'فَرَاغِى', #2
u'فرافصة': u'فُرَافِصَةٌ', #1
u'فرافصة،': u'فُرَافِصَةَ،', #1
u'فرافصة': u'فَرَافِصَةَ', #3
u'فرافصة': u'فُرَافِصَةَ', #9
u'فرامرز': u'فَرَامُرْزِ', #1
u'فراموش': u'فراموش', #1
u'فرآنى': u'فَرَآنِى', #8
u'فرآهاقال': u'فَرَآهَاقَالَ', #1
u'فراهيته': u'فَرَاهِيَتِهِ', #1
u'فراهيج': u'فَرَاهِيجَ', #12
u'فراهيجتين': u'فَرَاهِيجَتَيْنِ', #1
u'فراهيجيك': u'فَرَاهِيجَيْكَ', #1
u'فراوة': u'فَرَاوَةَ', #2
u'فراودنى': u'فَرَاوَدَنِى', #1
u'فراوى': u'فَرَاوِى', #1
u'فرايت': u'فرايت', #1
u'فرأيتمانى': u'فَرَأَيْتُمَانِى', #2
u'فرباش': u'فرباش', #1
u'فربر': u'فِرَبْرَ', #1
u'فربر': u'فِرْبَرُ', #1
u'فربطونى': u'فَرَبَطُونِى', #1
u'فرتنى': u'فَرْتَنَى', #3
u'فرثيث': u'فَرَثِيثُ', #1
u'فرخنده': u'فرخنده', #1
u'فردء': u'فَرَدْءُ', #1
u'فردء': u'فَرِدْءُ', #1
u'فردء': u'فَرِدْءٌ', #2
u'فردابتو': u'فردابتو', #1
u'فردابتوتسليم': u'فردابتوتسليم', #1
u'فردابيايم': u'فردابيايم', #1
u'فردأتهم': u'فَرَدَأْتُهُمْ', #1
u'فرداسا': u'فرداساً', #1
u'فردايتو': u'فردايتو', #1
u'فرداين': u'فرداين', #1
u'فرددنى': u'فَرَدَّدَنِى', #1
u'فردموده': u'فردموده', #1
u'فردنى': u'فَرَدَّنِى', #3
u'فردونى': u'فَرُدُّونِى', #1
u'فردونى': u'فَرَدُّونِى', #2
u'فرزندا': u'فرزندا', #1
u'فرزندان': u'فرزندان', #4
u'فرستاد': u'فرستاد', #2
u'فرستادتا': u'فرستادتا', #1
u'فرشتة': u'فَرْشَتَةَ', #6
u'فرشهنه': u'فَرْشِهِنَّهْ', #3
u'فرضاخية': u'فِرْضَاخِيَّةٌ', #2
u'فرضتى': u'فُرْضَتَىِ', #1
u'فرضعتان': u'فَرَضْعَتَانِ', #5
u'فرضمناها': u'فَرَضَمْنَاهَا', #2
u'فرطات': u'فَرَطَاتٍ', #1
u'فرطات': u'فَرَطَاتِ', #2
u'فرطاتك': u'فَرَطَاتِك', #1
u'فرطاته': u'فَرَطَاتُهُ', #1
u'فرطاته': u'فَرَطَاتِهِ', #1
u'فرطاته': u'فُرُطَاتِهِ', #3
u'فرع': u'فَرْعً', #1
u'فرعل': u'فُرْعُلِ', #3
u'فرغار': u'فرغار', #3
u'فرغانة': u'فَرْغَانَةَ', #12
u'فرغانة،': u'فَرْغَانَةَ،', #3
u'فرفصته': u'فَرَفَصَتْهُ', #1
u'فرفصه': u'فَرَفَصَهُ', #1
u'فرفعنى': u'فَرَفَعَنِى', #1
u'فرق': u'فِرَقً', #1
u'فرق': u'فَرْقً', #2
u'فرقأ': u'فَرَقَأَ', #3
u'فرقبى': u'فَرُقْبَى', #3
u'فركاز': u'فَرِكَازٌ', #14
u'فركسني': u'فَرَكَسَنِي', #1
u'فركضتنى': u'فَرَكَضَتْنِى', #3
u'فرمانى': u'فَرَمَانِى', #6
u'فرمايدبكنم': u'فرمايدبكنم', #1
u'فرمايم': u'فرمايم', #1
u'فرمصت': u'فَرَمَصَتْ', #1
u'فرمصت': u'فَرَمِصَتْ', #2
u'فرمضته': u'فَرَمَضْتُهُ', #1
u'فرمود': u'فرمود', #3
u'فرموداين': u'فرموداين', #1
u'فرناص': u'فِرْنَاصَ', #1
u'فرنساوي': u'فَرَنْسَاوِيٍّ', #2
u'فرنساوي': u'فَرَنْسَاوِيٌّ', #3
u'فرنساوية': u'فَرَنْسَاوِيَّةً', #1
u'فرنساوية': u'فَرَنْسَاوِيَّةٍ', #2
u'فرنسة': u'فَرْنَسَةً', #1
u'فرهد،': u'فَرْهَدٍ،', #1
u'فرهدة،': u'فَرْهَدَةَ،', #1
u'فروأ': u'فَرَوَّأَ', #1
u'فروأت': u'فَرَوَّأْتُ', #1
u'فروجة': u'فَرَوْجَةً', #1
u'فروجة': u'فَرُّوجَةً', #6
u'فروحب': u'فروحب', #1
u'فروخت': u'فروخت', #2
u'فروختم': u'فروختم', #21
u'فروختني': u'فروختني', #1
u'فروخته': u'فروخته', #4
u'فروختي': u'فروختي', #4
u'فرورود': u'فرورود', #1
u'فروعات': u'فُرُوعَاتِ', #1
u'فروعات': u'فَرَوْعَاتِ', #1
u'فروفتم': u'فروفتم', #3
u'فروماند': u'فروماند', #1
u'فرومينكر': u'فرومينكر', #1
u'فرونكذارم': u'فرونكذارم', #1
u'فرئى': u'فَرُئِىَ', #1
u'فرئيتهما': u'فَرُئِيتُهُمَا', #1
u'فرياب،': u'فِرْيَابَ،', #1
u'فريضتى': u'فَرِيضَتِى', #1
u'فريعات': u'فُرَيْعَاتٌ', #1
u'فريعة': u'فريعة', #1
u'فريعة': u'فَرِيعَةُ', #1
u'فريعة': u'فُرَيْعَةُ', #20
u'فريعة': u'فُرَيْعَةَ', #34
u'فزاءين': u'فَزَاءَيْنِ', #1
u'فزادنى': u'فَزَادَنِى', #4
u'فزارة': u'فَزارة', #1
u'فزارة': u'فِزارة', #1
u'فزارة،': u'فِزارة،', #1
u'فزارة': u'فَزَارة', #1
u'فزارة': u'فَزَارَةِ', #1
u'فزارة،': u'فِزَارَةَ،', #1
u'فزارة': u'فَزَارَةُ', #11
u'فزارة،': u'فَزَارَةَ،', #13
u'فزارة': u'فَزَارَةَ', #134
u'فزارة': u'فَزَارَة', #2
u'فزارة': u'فزارة', #4
u'فزارة،': u'فزارة،', #4
u'فزاري': u'فَزَارِيّ', #1
u'فزاريا': u'فَزَارِيّا', #1
u'فزاريا': u'فَزَارِيًّا', #1
u'فزغله': u'فَزُغْلَهْ', #2
u'فزملونى': u'فَزَمَّلُونِى', #2
u'فزنبرة': u'فَزَنْبَرَةُ', #1
u'فزوجنى': u'فَزَوَّجَنِى', #1
u'فزوجنيه': u'فَزَوِّجْنِيهِ', #4
u'فزوجنيها': u'فَزَوِّجْنِيهَا', #4
u'فزوجنيها': u'فَزَوَّجَنِيهَا', #7
u'فزودنى': u'فَزَوِّدْنِى', #1
u'فساءة': u'فَسَاءَةَ', #3
u'فساءنى': u'فَسَاءَنِى', #2
u'فساحقت': u'فَسَاحَقَتْ', #10
u'فسارنى': u'فَسَارَّنِى', #1
u'فسألتمانيها،': u'فَسَأَلْتُمَانِيهَا،', #1
u'فسألتنى': u'فَسَأَلَتْنِى', #2
u'فسألتيه': u'فَسَأَلْتِيهِ', #1
u'فسألنى': u'فَسَأَلَنِى', #17
u'فسألنيه': u'فَسَأَلَنِيهِ', #1
u'فسألنيها': u'فَسَأَلَنِيهَا', #1
u'فسألونى': u'فَسَأَلُونِى', #4
u'فساومنى': u'فَسَاوَمَنِى', #1
u'فسبتنى': u'فَسَبَتْنِى', #1
u'فسبحبه': u'فَسَبَحَبِهِ', #1
u'فسبقنى': u'فَسَبَقَنِى', #3
u'فسبنى': u'فَسَبَّنِى', #2
u'فسبونى': u'فَسَبَوْنِى', #1
u'فستأتيان': u'فَسَتَأْتِيَانِ', #2
u'فسجدوها': u'فَسَجَدُوهَا', #1
u'فسحات': u'فُسُحَاتِ', #1
u'فسحبان': u'فَسَحْبَانُ', #3
u'فسحلت': u'فَسَحَلَتْ', #2
u'فسحلها،': u'فسحلها،', #1
u'فسحلها': u'فَسَحَلَهَا', #1
u'فسحنون': u'فَسَحْنُونٌ', #1
u'فسرف': u'فَسَرَفٌ', #1
u'فسرفتهم': u'فَسَرِفْتهمْ', #1
u'فسرقينها': u'فَسِرْقِينُهَا', #1
u'فسريط': u'فَسُرّيْطٌ', #1
u'فسطاطا': u'فُسْطًاطًا', #1
u'فسقارا': u'فِسْقَارًا', #2
u'فسقانى': u'فَسَقَانِى', #1
u'فسقطفقد': u'فَسَقَطَفَقَدْ', #1
u'فسقونى': u'فَسَّقُونِى', #1
u'فسكل': u'فِسْكِلٌ', #3
u'فسكل': u'فُسْكُلٌ', #4
u'فسكيت': u'فَسُكَيْتٌ', #3
u'فسلاء': u'فُسَلَاءُ', #1
u'فسلافة': u'فَسُلَافَةُ', #1
u'فسلبنيه': u'فَسَلَبْنِيهِ', #1
u'فسلجج': u'فَسَلْجَجُ', #1
u'فسلعن': u'فَسَلَعْنَ', #1
u'فسلنى': u'فَسَلْنِى', #1
u'فسمحاق': u'فَسِمْحَاقٌ', #1
u'فسمعنى': u'فَسَمِعَنِى', #2
u'فسنكفيكموه': u'فَسَنَكْفِيكُمُوهُ', #1
u'فسنؤتيكها': u'فَسَنُؤْتِيكهَا', #2
u'فسهمانها': u'فَسُهْمَانُهَا', #1
u'فسودة': u'فَسَوْدَةُ', #2
u'فسويق': u'فَسَوِيقُ', #1
u'فسويقهما': u'فَسَوِيقُهُمَا', #2
u'فسيأتيان': u'فَسَيَأْتِيَانِ', #6
u'فسيأنى': u'فَسَيَأْنَى', #1
u'فسيتابعنى': u'فَسَيُتَابِعُنِى', #1
u'فسيرانى': u'فَسَيَرَانِى', #1
u'فسيعطه': u'فَسَيُعْطِهِ', #1
u'فسيكفيكهم': u'فَسَيَكْفِيكَهُمْ', #4
u'فسيكفيكهم': u'فَسَيَكْفِيكَهُمُ', #6
u'فشاتيل': u'فَشَاتِيلَ', #1
u'فشادنى': u'فَشَادَّنِى', #1
u'فشاورنى': u'فَشَاوِرْنِى', #1
u'فشاول': u'فَشَاوِلْ', #1
u'فشخانة': u'فَشَخَانَةٍ', #1
u'فشدخ': u'فَشَدْخُ', #1
u'فشدخت': u'فَشُدِخَتْ', #1
u'فشدخت': u'فَشَدَخَتْ', #3
u'فشدخته': u'فَشَدَخَتْه', #1
u'فشدخته': u'فَشَدَخَتْهُ', #4
u'فشدختها': u'فَشَدَخَتْهَا', #1
u'فشدخه': u'فَشَدَخَهُ', #2
u'فشراج': u'فَشِرَاجُ', #1
u'فشرفنى': u'فَشَرَّفَنِى', #1
u'فشطح': u'فَشَطَحَ', #1
u'فشغلنى': u'فَشَغَلَنِى', #2
u'فشغلونى': u'فَشَغَلُونِى', #4
u'فشقص': u'فَشِقْصٌ', #5
u'فشقصا': u'فَشِقْصًا', #3
u'فشقى': u'فَشَقِىَ', #1
u'فشكانى': u'فَشَكَانِى', #5
u'فشكى': u'فَشَكى', #1
u'فشكى': u'فَشُكِىَ', #3
u'فشكى': u'فَشَكَى', #5
u'فشنوها': u'فَشُنُّوهَا', #2
u'فشهادتى': u'فَشَهَادَتِى', #2
u'فشهدنى': u'فَشَهِدَنِى', #1
u'فشوبوا': u'فَشُوبُوا', #1
u'فشوبوه': u'فَشُوبُوهُ', #17
u'فشوبوها': u'فَشُوبُوهَا', #2
u'فشى': u'فَشَى', #1
u'فشىء': u'فَشَىْءٌ', #3
u'فشيث': u'فَشِيثُ', #1
u'فصاة': u'فَصَاةٍ', #1
u'فصببته': u'فَصَبَبْتُهُ', #1
u'فصببته': u'فَصَبَبْته', #2
u'فصببتها': u'فَصَبَبْتُهَا', #2
u'فصدقنى': u'فَصَدِّقْنِى', #1
u'فصدقنى': u'فَصَدَقَنِى', #4
u'فصرخد': u'فَصَرْخَدَ', #1
u'فصرخدا': u'فَصَرْخَدَا', #3
u'فصط': u'فَصَطْ', #2
u'فصل': u'فَصْلً', #1
u'فصلاتية': u'فَصَلَاتِيَّةٌ', #1
u'فصلق': u'فَصَلَقَ', #1
u'فصلقه': u'فَصَلْقُهُ', #1
u'فصلىبهم': u'فَصَلَّىبِهِمْ', #1
u'فصمى': u'فَصَمَى', #1
u'فصواحباتك': u'فَصَوَاحِبَاتُك', #1
u'فصواحباتها': u'فَصَوَاحِبَاتُهَا', #10
u'فصواحبتها': u'فَصَوَاحِبَتُهَا', #1
u'فصولين': u'فَصُولَيْنِ', #18
u'فصولين': u'فُصُولَيْنِ', #38
u'فصومى': u'فَصُومِى', #5
u'فضافض': u'فَضَافِضَ', #2
u'فضتان': u'فِضَّتَانِ', #1
u'فضتين': u'فِضَّتَيْنِ', #3
u'فضحتيه': u'فَضَحْتِيهِ', #1
u'فضربنى': u'فَضَرَبَنِى', #7
u'فضعونى': u'فَضَعُونِى', #1
u'فضلنى': u'فَضَّلَنِى', #1
u'فضلويه': u'فَضْلُوَيْهِ', #1
u'فضليته': u'فَضْلِيَّتَهُ', #1
u'فضمخونى': u'فَضَمَّخُونِى', #1
u'فضمننيه': u'فَضَمَّنَنِيهِ', #1
u'فضوح': u'فَضُوحُ', #1
u'فضيح': u'فَضِيحٌ', #1
u'فضيخ،': u'فَضِيخٍ،', #1
u'فضيخ': u'فَضِيخ', #2
u'فضيخ': u'فَضِيخَ', #3
u'فضيخ': u'فَضِيخُ', #3
u'فضيخ': u'فَضِيخِ', #4
u'فضيخ': u'فَضِيخٍ', #9
u'فضيخا': u'فَضِيخًا', #3
u'فضيخكم': u'فَضِيخُكُمْ', #1
u'فضيخكم': u'فَضِيخِكُمْ', #3
u'فضيلةإلا': u'فَضِيلَةٌإِلَّا', #1
u'فط': u'فط', #1
u'فطرتى': u'فِطْرَتِى', #1
u'فطريانه': u'فَطَرَيَانُهُ', #2
u'فطلقتكها': u'فَطَلَقْتُكهَا', #1
u'فطلقتكيها': u'فَطَلَّقْتُكِيهَا', #1
u'فطلقنى': u'فَطَلِّقْنِى', #1
u'فطلقنى': u'فَطَلَّقَنِى', #6
u'فطمهورث': u'فطمهورث', #1
u'فطهرنى': u'فَطَهِّرْنِى', #1
u'فظاظ': u'فِظَاظٍ', #1
u'فظلمنى': u'فَظَلَّمَنِى', #1
u'فظنتأنه': u'فَظَنَّتْأَنَّهِ', #1
u'فعاء': u'فُعَاءَ', #1
u'فعاتبنى': u'فَعَاتَبَنِى', #3
u'فعادنى': u'فَعَادَنِى', #2
u'فعة': u'فِعَة', #1
u'فعت': u'فَعَتَّ', #1
u'فعجيما،': u'فعجيماً،', #1
u'فعذرنى': u'فَعَذَرَنِى', #1
u'فعذمني': u'فَعَذَمَنِي', #1
u'فعرضتهاعليه': u'فَعَرَضْتُهَاعَلَيْهِ', #1
u'فعرفنى': u'فَعَرَفَنِى', #1
u'فعرقب': u'فعَرْقَب', #1
u'فعرقب': u'فَعَرْقَبَ', #7
u'فعرقبه': u'فَعَرْقَبَهُ', #1
u'فعرقبها': u'فَعَرْقَبَهَا', #3
u'فعصيتنى': u'فَعَصَيْتَنِى', #2
u'فعضب': u'فعضب', #1
u'فعضبا': u'فَعُضِبَا', #1
u'فعلال': u'فَعِلَالٌ', #1
u'فعلال': u'فَعْلَالٌ', #1
u'فعلالا': u'فِعْلَالًا', #1
u'فعلانة': u'فَعْلَانَةُ', #1
u'فعلانة': u'فَعْلَانَةً', #2
u'فعلانة': u'فَعْلَانَةَ', #3
u'فعلس': u'فَعَلْسٌ', #1
u'فعلعلة': u'فَعَلْعَلَةٌ', #1
u'فعللة': u'فَعْلَلَةٌ', #1
u'فعللة': u'فُعْلَلَةٌ', #1
u'فعللة': u'فُعْلُلَةٌ', #1
u'فعلمنى': u'فَعَلِّمْنِى', #10
u'فعلمنى': u'فَعَلَّمَنِى', #2
u'فعلمهموه': u'فَعَلَّمَهُمُوهُ', #1
u'فعلمونى': u'فَعَلَّمُونِى', #1
u'فعلهاإلا': u'فِعْلِهَاإِلَّا', #1
u'فعلهة': u'فَعْلَهَةٌ', #1
u'فعلوة': u'فَعْلُوةٌ', #1
u'فعلوة': u'فَعُلْوَةٌ', #1
u'فعلوة': u'فَعْلُوَةٍ', #2
u'فعلوة': u'فَعْلُوَةٌ', #3
u'فعلول': u'فَعَلُولٌ', #1
u'فعليكموه': u'فَعَلَيْكُمُوهُ', #7
u'فعماة،': u'فَعُمَاةُ،', #1
u'فعملنى': u'فَعَمَّلَنِى', #3
u'فعنم': u'فَعَنَمٌ', #1
u'فعوعل': u'فَعَوْعَلٌ', #1
u'فعوعلة': u'فَعَوْعَلَةٌ', #1
u'فعولة': u'فَعُولَةً', #1
u'فعولة': u'فَعُولَة', #2
u'فعولة': u'فُعُولَةٌ', #3
u'فعولة': u'فَعُولَةٌ', #8
u'فعولل': u'فَعَوْلَلْ', #3
u'فعولية': u'فَعَوْلِيَّةٌ', #2
u'فعيلام': u'فَعَيْلَام', #1
u'فعيول': u'فِعْيُولٌ', #2
u'فعيى': u'فَعَيِىَ', #1
u'فعيينة': u'فَعُيَيْنَةُ', #1
u'فغاضبنى': u'فَغَاضَبَنِى', #2
u'فغبرت': u'فَغَبَرْتُ', #1
u'فغبروا': u'فَغَبَرُوا', #1
u'فغبطنا': u'فَغَبَطْنَا', #1
u'فغبطه': u'فَغَبَطَهُ', #1
u'فغتني': u'فَغَتَّنِي', #3
u'فغتني': u'فَغَتّنِي', #6
u'فغشوشه': u'فَغُشُوشُهُ', #1
u'فغصبتنيها': u'فَغَصَبْتَنِيهَا', #1
u'فغطنى': u'فَغَطَّنِى', #6
u'فغلبنى': u'فَغَلَبَنِى', #1
u'فغمزنى': u'فَغَمَزَنِى', #4
u'فغموس': u'فَغَمُوسٌ', #7
u'فغواء': u'فغواء', #1
u'فغواء': u'فَغْوَاءَ', #1
u'ففارقتنى': u'فَفَارَقَتْنِى', #1
u'ففجعات': u'فَفَجَعَاتٌ', #1
u'ففجئني': u'فَفَجِئَنِي', #1
u'ففحج': u'فَفَحَّجَ', #1
u'ففسكل': u'فَفُسْكُلٌ', #3
u'ففشج': u'فَفَشَجَ', #1
u'ففعلواSأصحاب': u'فَفَعَلُواSأَصْحَابُ', #1
u'ففعيل': u'فَفَعِيلٌ', #9
u'ففعيلة': u'فَفَعِيلَةٌ', #2
u'ففقء': u'فَفَقْءِ', #2
u'ففنى': u'فَفَنَى', #1
u'ففنى': u'فَفِنَى', #1
u'ففنى': u'فَفَنِىَ', #3
u'ففهق': u'فَفَهِقَ', #1
u'ففى': u'فَفِىَّ', #3
u'ففى': u'فَفِى', #98
u'ففيؤه': u'فَفَيْؤُهُ', #37
u'فقء': u'فَقْءٌ', #1
u'فقء': u'فَقْءُ', #15
u'فقء': u'فَقْءَ', #17
u'فقء': u'فَقْءٍ', #2
u'فقء': u'فَقْء', #3
u'فقء': u'فَقْءِ', #73
u'فقاتلنى': u'فَقَاتَلَنِى', #2
u'فقاحية،': u'فقاحية،', #1
u'فقاحية': u'فَقّاحِيّةٌ', #2
u'فقاحية': u'فُقّاحِيّةٌ', #4
u'فقاقع': u'فَقَاقِعَ', #1
u'فقالاسم': u'فَقَالَاسْمٌ', #1
u'فقالأعوذ': u'فَقَالَأَعُوذُ', #1
u'فقالألا': u'فقالألا', #1
u'فقالالرحيموروي': u'فَقَالَالرَّحِيمُوَرُوِيَ', #1
u'فقالإن': u'فقالإِنَّ', #1
u'فقالإن': u'فَقَالَإِنَّ', #2
u'فقالإنه': u'فَقَالَإِنَّهُ', #1
u'فقالإني': u'فَقَالَإِنِّي', #1
u'فقالتعلمون': u'فَقَالَتَعْلَمُونَ', #1
u'فقالثمنها': u'فَقَالَثَمَنُهَا', #1
u'فقالحل': u'فَقَالَحَلَّ', #1
u'فقالرسول': u'فَقَالَرَسُولُ', #2
u'فقالصدق،': u'فَقَالَصَدَقَ،', #1
u'فقالكانت': u'فَقَالَكَانَتْ', #1
u'فقاللقد': u'فَقَالَلَقَدْ', #1
u'فقاللئن': u'فَقَالَلَئِنْ', #1
u'فقالليس': u'فَقَالَلَيْسَ', #1
u'فقالما': u'فَقَالَمَا', #1
u'فقالمالك': u'فَقَالَمَالِكٌ', #1
u'فقالوابلى': u'فَقَالُوابَلَى', #1
u'فقالوالو': u'فَقَالُوالَوْ', #1
u'فقالومن': u'فَقَالَوَمَنْ', #1
u'فقاليجعلون': u'فَقَالَيُجْعَلُونَ', #1
u'فقاليقول': u'فَقَالَيَقُولُ', #1
u'فقأوا': u'فَقَأُوا', #1
u'فقائف': u'فَقَائِفٌ', #2
u'فقائف': u'فَقَائِفٍ', #2
u'فقايلهما': u'فَقَايَلَهُمَا', #1
u'فقبصت،': u'فقبصت،', #1
u'فقبلنى': u'فَقَبِلَنِى', #1
u'فقبلى': u'فَقَبِّلِى', #1
u'فقة': u'فِقَةٌ', #1
u'فقة': u'فِقَةٍ', #1
u'فقتلاهSأبو': u'فَقَتَلَاهُSأَبُو', #1
u'فقدعني': u'فَقَدَعَنِي', #1
u'فقدعنى': u'فَقَدَعَنِى', #1
u'فقدفت': u'فَقَدَفَتْ', #1
u'فقدمنى': u'فَقَدَّمَنِى', #2
u'فقدمونى': u'فَقَدَّمُونِى', #3
u'فقرءان': u'فَقَرْءَانِ', #1
u'فقرءان': u'فَقُرْءَانِ', #1
u'فقرءوا،': u'فَقَرَءُوا،', #1
u'فقرءوا': u'فَقَرَءُوا', #5
u'فقرءوها': u'فَقَرَءُوهَا', #1
u'فقرأا': u'فَقَرَأَا', #1
u'فقراقر': u'فَقَرَاقِرُ', #1
u'فقربنى': u'فَقَرَّبَنِى', #1
u'فقرم': u'فَقَرَمَ', #1
u'فقرم': u'فَقَرِمَ', #2
u'فقرمود': u'فَقَرْمُودٌ', #2
u'فقريوش': u'فَقِرْيُوشٌ', #1
u'فقضانى': u'فَقَضَانِى', #3
u'فقعة': u'فِقَعة', #1
u'فقفير': u'فَقَفِيرُ', #1
u'فقفيز': u'فَقَفِيزِ', #1
u'فقفيز': u'فَقَفِيزٌ', #2
u'فقلبى': u'فَقَلْبِى', #1
u'فقلتمو': u'فَقُلْتُمُو', #1
u'فقميه': u'فقميه', #1
u'فقميه': u'فُقْمَيْهِ', #1
u'فقميه': u'فَقْمَيْهِ', #3
u'فقهين': u'فِقْهَيْنِ', #1
u'فقولى': u'فَقُولِى', #11
u'فكاتبتنى': u'فَكَاتَبَتْنِى', #1
u'فكاتبونى': u'فَكَاتَبُونِى', #1
u'فكاختلاعه': u'فَكَاخْتِلَاعِهِ', #1
u'فكاختلاعها': u'فَكَاخْتِلَاعِهَا', #2
u'فكالإباق': u'فَكَالْإِبَاقِ', #1
u'فكالاستحاضة': u'فَكَالِاسْتِحَاضَةِ', #5
u'فكالتالف': u'فَكَالتَّالِفِ', #11
u'فكالجبيرة': u'فَكَالْجَبِيرَةِ', #1
u'فكالجرموقين': u'فَكالْجُرْمُوقَيْن', #3
u'فكالجماء': u'فَكَالْجَمَّاءِ', #1
u'فكالعائن': u'فَكَالْعَائِنِ', #1
u'فكالعنوي': u'فَكَالْعَنْوِيِّ', #1
u'فكالمثغورة': u'فَكَالْمَثْغُورَةِ', #2
u'فكالمزحوم': u'فَكَالْمَزْحُومِ', #1
u'فكالمستحاضة': u'فَكَالْمُسْتَحَاضَةِ', #1
u'فكالمعضوب': u'فَكَالْمَعْضُوبِ', #2
u'فكأنى': u'فَكَأَنِّى', #17
u'فكأنى': u'فَكَأَنَّى', #2
u'فكآيسة': u'فَكَآيِسَةٍ', #2
u'فكتمجسها': u'فَكَتَمَجُّسِهَا', #1
u'فكذبنى': u'فَكَذِّبْنِى', #1
u'فكرتقاء': u'فَكَرَتْقَاءَ', #2
u'فكردن': u'فكردن', #1
u'فكرسوع': u'فَكُرْسُوعٌ', #1
u'فكزنا': u'فَكَزِنًا', #4
u'فكسانى': u'فَكَسَانِى', #1
u'فكسع': u'فَكَسَعَ', #8
u'فكسونى': u'فَكَسَوْنِى', #1
u'فكعموه': u'فَكَعَمُوهُ', #1
u'فكفاناه': u'فَكَفَانَاهُ', #1
u'فكفتنى': u'فَكَفَتْنِى', #1
u'فكفيتكهم': u'فَكَفَيْتُكَهُمْ', #1
u'فكقبلت': u'فَكَقَبِلْتُ', #1
u'فكلمانى': u'فَكَلَّمَانِى', #1
u'فكلمنى': u'فَكَلِّمْنِى', #1
u'فكلمنى': u'فَكَلَّمَنِى', #4
u'فكمتى': u'فَكَمَتَى', #1
u'فكمخرف': u'فَكَمُخَرِّفٍ', #1
u'فكمزحوم': u'فَكَمَزْحُومٍ', #2
u'فكمعراض': u'فَكَمِعْرَاضٍ', #4
u'فكمعضوب': u'فَكَمَعْضُوبٍ', #2
u'فكندند': u'فكندند', #1
u'فكهميان': u'فَكَهِمْيَانٍ', #1
u'فكيدون': u'فَكِيدُونِ', #2
u'فكيدوني': u'فَكِيدُونِي', #8
u'فكيهة': u'فُكَيْهَةُ', #12
u'فكيهة': u'فَكِيهَةَ', #2
u'فكيهة': u'فُكَيْهَةَ', #4
u'فكيهك': u'فَكِيَهْكُ', #1
u'فكيهك': u'فَكِيهَكُ', #2
u'فلاتج': u'فَلَاتِجَ', #1
u'فلاسه': u'فَلَاسُهُ', #1
u'فلإعافة': u'فَلِإِعَافَةِ', #1
u'فلاعترافة': u'فَلِاعْتِرَافَةِ', #1
u'فلاعتضاد': u'فَلِاعْتِضَادِ', #1
u'فلاعي': u'فَلَاعِي', #1
u'فلال': u'فِلالُ', #1
u'فلالا': u'فَلَالَا', #1
u'فلالا': u'فُلّالَا', #2
u'فلامتنى': u'فَلاَمَتْنِى', #1
u'فلامنى': u'فَلاَمَنِى', #1
u'فلان': u'فُلَانً', #1
u'فلانتسألنى': u'فُلاَنٍتَسْأَلُنِى', #1
u'فلانرا': u'فلانرا', #2
u'فلانراكه': u'فلانراكه', #1
u'فلانست': u'فلانست', #1
u'فلانوروي': u'فُلانٌوَرُوِيَ', #1
u'فلإهلك': u'فَلإِهْلِك', #1
u'فلأى': u'فَلأَىِّ', #1
u'فلائس': u'فَلَائِسُ', #1
u'فلبسنى': u'فَلَبَسَنِى', #1
u'فلتبايعنى': u'فَلْتُبَايِعْنِى', #2
u'فلتبعض': u'فَلِتَبَعُّضِ', #1
u'فلتحاصص': u'فَلْتُحَاصَصْ', #1
u'فلتحتش': u'فَلْتَحْتَشِ', #1
u'فلتحتفز': u'فَلْتَحْتَفِزْ', #1
u'فلتستوفز': u'فَلْتَسْتَوْفِزْ', #1
u'فلتهكن': u'فَلَتَهُكّنّ', #1
u'فلججوا': u'فَلَجَّجُوا', #3
u'فلحقنى': u'فَلَحِقَنِى', #6
u'فلسحنون': u'فَلِسَحْنُونٍ', #2
u'فلسطين،أنهبلغه': u'فِلَسْطِينَ،أَنَّهُبَلَغَهُ', #1
u'فلطمنى': u'فَلَطَمَنِى', #1
u'فلطيم': u'فَلَطِيمٌ', #3
u'فلعضبه': u'فَلِعَضْبِهِ', #1
u'فلعمرى': u'فَلَعَمْرِى', #5
u'فلعية': u'فَلْعِيَّةٌ', #1
u'فلقننى': u'فَلَقَّنَنِى', #2
u'فلقينى': u'فَلَقِيَنِى', #11
u'فلكأنى': u'فَلَكَأَنِّى', #3
u'فلكزنى': u'فَلَكَزَنِى', #1
u'فللاثنين': u'فَلِلِاثْنَيْنِ', #1
u'فللأذرعي': u'فَلِلْأَذْرَعِيِّ', #1
u'فللأقفهسي': u'فَلِلْأَقْفَهْسِيِّ', #2
u'فللبسوطة': u'فَلِلْبُسُوطَةِ', #1
u'فللتيماري': u'فَلِلتَّيْمَارِيِّ', #2
u'فللثنتين': u'فَلِلثِّنْتَيْنِ', #1
u'فللجزيري': u'فَلِلْجَزِيرِيِّ', #1
u'فللسباهي': u'فَلِلسَّبَاهِيِّ', #1
u'فللظئر': u'فَلِلظِّئْرِ', #1
u'فللعنوي': u'فَلِلْعَنَوِيِّ', #1
u'فللقضا': u'فَلِلْقَضَا', #2
u'فللكوسج': u'فَلِلْكَوْسَجِ', #2
u'فللمبعضة': u'فَلِلْمُبَعَّضَةِ', #1
u'فللمتيطي': u'فَلِلْمُتَيْطِيِّ', #1
u'فللمذفف': u'فَلِلْمُذَفِّفِ', #1
u'فللمساقى': u'فَلَلْمُسَاقَى', #1
u'فللمساقى': u'فَلِلْمُسَاقَى', #1
u'فللمستصنع': u'فَلِلْمُسْتَصْنِعِ', #3
u'فللمستقرض': u'فَلِلْمُسْتَقْرِضِ', #3
u'فللمستكري': u'فَلِلْمُسْتَكْرِي', #1
u'فللمسعي': u'فَلِلْمَسْعِيِّ', #3
u'فللمشترى': u'فَلِلْمُشْتَرَى', #1
u'فللمقتص': u'فَلِلْمُقْتَصِّ', #2
u'فللمقضى': u'فَلِلْمُقْضَى', #1
u'فللمكرى': u'فَلِلْمُكْرَى', #1
u'فللمنحول': u'فَلِلْمَنْحُولِ', #1
u'فللمؤاجر': u'فَلِلْمُؤَاجِرِ', #2
u'فللموطوءة': u'فَلِلْمَوْطُوءَةِ', #5
u'فلميتقدم': u'فَلَمْيَتَقَدَّمْ', #1
u'فلنضوضه': u'فَلِنُضُوضِهِ', #3
u'فلنضوضه': u'فَلِنَضُوضِهِ', #5
u'فلهدنى': u'فَلَهَدَنِى', #1
u'فلهيننى': u'فَلَهَّيْنَنِى', #1
u'فلوا': u'فُلُوًّا', #1
u'فلوا': u'فِلْوًا', #1
u'فلوا': u'فَلُوًّا', #2
u'فلوة': u'فَلُوَّةٌ', #1
u'فلولاأنه': u'فَلَوْلاأَنَّهُ', #1
u'فليأتنف': u'فَلْيَأْتَنِفْ', #3
u'فليأتنى': u'فَلْيَأْتِنِى', #3
u'فليبايعنى': u'فَلْيُبَايِعْنِى', #2
u'فليبتدر': u'فَلْيَبْتَدِرْ', #1
u'فليبدءوا': u'فَلْيُبْدَءُوا', #1
u'فليبدإ': u'فَلْيَبْدَإِ', #1
u'فليبدأبه': u'فَلْيَبْدَأْبِهِ', #1
u'فليبركه': u'فَلْيُبَرِّكْهُ', #1
u'فليبعنيها': u'فَلْيَبِعْنِيهَا', #1
u'فليتحاذر': u'فَلْيَتَحَاذَرْ', #1
u'فليتحاص': u'فَلْيَتَحَاصَّ', #1
u'فليتحيل': u'فَلْيَتَحَيَّلْ', #2
u'فليتراد': u'فَلْيَتَرَادَّ', #1
u'فليترادا': u'فَلْيَتَرَادَّا', #1
u'فليتسحر': u'فَلْيَتَسَحَّرْ', #3
u'فليتشطر': u'فَلْيَتَشَطَّرْ', #1
u'فليتعز': u'فَلْيَتَعَزَّ', #3
u'فليتعزر': u'فَلَيَتَعَزَّرْ', #1
u'فليتلمح': u'فَلْيَتَلَمَّحْ', #1
u'فليتمخر': u'فَلْيَتَمَخَّر', #1
u'فليتنخع': u'فَلِيَتَنَخَّعْ', #1
u'فليتنخع': u'فَلْيَتَنَخَّعْ', #8
u'فليتنخم': u'فَلْيَتَنَخَّمْ', #1
u'فليتنى': u'فَلَيْتَنِى', #1
u'فليتئد،': u'فَلْيَتَّئِدْ،', #2
u'فليتئد': u'فَلْيَتَّئِدْ', #9
u'فليجتزئ': u'فَلْيَجْتَزِئْ', #1
u'فليحا': u'فُلَيْحًا', #3
u'فليحالل': u'فَلْيُحَالِلْ', #1
u'فليحنأ': u'فَلْيَحْنَأْ', #1
u'فليحى': u'فَلْيُحْىِ', #1
u'فليرتجعها': u'فَلْيَرْتَجِعْهَا', #1
u'فليزوغ': u'فَلْيُزَوِّغْ', #1
u'فليسألنى': u'فَلْيَسْأَلْنِى', #1
u'فليستاك': u'فَلْيَسْتَاكَ', #1
u'فليستجمر': u'فَلْيَسْتَجْمِرْ', #16
u'فليستحلب': u'فَلْيَسْتَحْلِبْ', #2
u'فليستسن': u'فَلْيَسْتَسِنَّ', #2
u'فليستقد': u'فَلْيَسْتَقِدْ', #2
u'فليستقئ': u'فَلْيَسْتَقِئْ', #8
u'فليستك': u'فَلْيَسْتَكْ', #1
u'فليستنب': u'فَلْيَسْتَنِبْ', #1
u'فليستنثر': u'فَلْيَسْتَنْثِرْ', #16
u'فليستنثر،': u'فَلْيَسْتَنْثِرْ،', #4
u'فليستنقع': u'فَلْيَسْتَنْقِعْ', #1
u'فليستهما': u'فَلْيَسْتَهِمَا', #5
u'فليسجده': u'فَلْيَسْجُدْهُ', #1
u'فليسجدها': u'فَلْيَسْجُدْهَا', #2
u'فليسجدهما': u'فَلْيَسْجُدْهُمَا', #3
u'فليشقص': u'فَلْيُشَقِّصِ', #1
u'فليشقص': u'فَلْيُشَقِّصْ', #3
u'فليصها': u'فليصها', #1
u'فليعرقبوا': u'فَلْيُعَرْقِبُوا', #1
u'فليعطنى': u'فَلْيُعْطِنِى', #1
u'فليقرءوا': u'فَلْيَقْرَءُوا', #2
u'فليقرأوا': u'فَلْيَقْرَأُوا', #1
u'فليلقنى': u'فَلْيَلْقَنِى', #1
u'فليمتضغ': u'فَلْيَمْتَضِغْ', #1
u'فليهريق': u'فَلْيُهْرِيقَ', #1
u'فليهنيكم': u'فَلْيَهْنِيكُمْ', #1
u'فليؤاجر': u'فَلْيُؤَاجِرْ', #1
u'فليؤاخذه': u'فَلْيُؤَاخِذْهُ', #1
u'فليؤتنف': u'فَلْيُؤْتَنَفْ', #2
u'فليولم': u'فَلْيُولِمْ', #1
u'فمااجتمع': u'فَمَااِجْتَمَعَ', #1
u'فمأبون': u'فَمَأْبُونٌ', #1
u'فماجئتم': u'فَمَاجِئْتُمْ', #1
u'فمازلنا': u'فَمَازِلْنَا', #1
u'فمازها': u'فَمَازَهَا', #1
u'فماصدق': u'فَمَاصَدَقَ', #1
u'فماصدق': u'فَمَاصَدَقُ', #1
u'فمانعية': u'فَمَانِعِيَّةٌ', #1
u'فمانوس': u'فَمَانُوسٌ', #1
u'فمأيوس': u'فَمَأْيُوسٌ', #1
u'فمباين': u'فَمُبَايِنٌ', #2
u'فمبقاة': u'فَمُبْقَاةٌ', #1
u'فمتاركة': u'فَمُتَارَكَةٌ', #1
u'فمتاركة': u'فَمُتَارَكَةُ', #1
u'فمتالع': u'فَمُتَالِعُ', #4
u'فمثلة': u'فَمُثْلَةٌ', #3
u'فمثناتين': u'فَمُثَنَّاتَيْنِ', #1
u'فمجادلSوقوله': u'فَمَجَادِلِSوَقَوْلُهُ', #1
u'فمجاسرة': u'فَمُجَاسَرَةُ', #1
u'فمجبوب': u'فَمَجْبُوبٌ', #10
u'فمحجوج': u'فَمَحْجُوجٌ', #1
u'فمحسر': u'فَمُحَسِّرٌ', #1
u'فمحصر': u'فَمُحْصَرٌ', #4
u'فمحوج': u'فَمُحْوِجٌ', #1
u'فمخدوش': u'فَمَخْدُوشٌ', #2
u'فمداوله': u'فَمُدَاوِلُهُ', #1
u'فمدرت': u'فَمَدَرْتُ', #1
u'فمذارعة': u'فَمُذَارَعَةٌ', #1
u'فمذحج': u'فَمَذْحِجٌ', #1
u'فمذحج': u'فَمَذْحِجُ', #1
u'فمذى': u'فَمَذَى', #3
u'فمرأة': u'فَمَرْأَةٌ', #2
u'فمراطلة': u'فَمُرَاطَلَةُ', #1
u'فمرامر': u'فَمُرَامِرُ', #1
u'فمرتضع': u'فَمُرْتَضِعٌ', #1
u'فمرطوا،': u'فمرطوا،', #1
u'فمرنى': u'فَمُرْنِى', #4
u'فمستبضع': u'فَمُسْتَبْضِعٌ', #1
u'فمستحاضة': u'فَمُسْتَحَاضَةٌ', #4
u'فمستقرض': u'فَمُسْتَقْرِضٌ', #1
u'فمستنكح': u'فَمُسْتَنْكِحٌ', #1
u'فمسجديتهما': u'فمسجديتهما', #1
u'فمسرى': u'فَمِسْرَى', #3
u'فمسناة': u'فَمُسْنَاةٌ', #1
u'فمشروطية': u'فمشروطية', #1
u'فمشرى': u'فَمُشْرَى', #1
u'فمشريه': u'فَمُشْرِيهِ', #2
u'فمشطتنى': u'فَمَشَطَتْنِى', #1
u'فمشية': u'فَمِشْيَةٌ', #1
u'فمصعته': u'فَمَصَعَتْهُ', #3
u'فمصلق': u'فَمَصْلَقُ', #1
u'فمضارر': u'فَمُضَارِرٌ', #1
u'فمعثتهم': u'فَمَعَثَتْهُمُ', #1
u'فمعلومية': u'فَمَعْلُومِيَّةُ', #1
u'فمفيت': u'فَمُفِيتٌ', #4
u'فمقيس': u'فَمَقِيسٌ', #2
u'فمكحول': u'فَمَكْحُولٌ', #1
u'فمكدوش': u'فَمَكْدُوشٌ', #1
u'فملأوا': u'فَمَلَأُوا', #1
u'فملأوها': u'فَمَلأُوهَا', #1
u'فملتذ': u'فَمُلْتَذُّ', #1
u'فملخ': u'فَمَلَخَ', #1
u'فملزومه': u'فَمَلْزُومُهُ', #2
u'فملزومهما': u'فَمَلْزُومُهُمَا', #1
u'فممطول': u'فَمَمْطُولُ', #1
u'فمنتنفل': u'فَمَنْتَنَفَّلَ', #1
u'فمنتهبون': u'فَمُنْتَهَبُونَ', #1
u'فمنتهبون': u'فَمُنْتَهِبُونَ', #3
u'فمنجوفة': u'فَمَنْجُوفَةٌ', #1
u'فمنعتمو': u'فَمَنَعْتُمُو', #1
u'فمنعتنى': u'فَمَنَعْتَنِى', #1
u'فمنعنيه': u'فَمَنَعْنِيهِ', #2
u'فمنعنيها': u'فَمَنَعَنِيهَا', #13
u'فمنفحته': u'فَمِنْفَحَتُهُ', #1
u'فمنهيون': u'فَمَنْهِيُّونَ', #1
u'فمواضعة': u'فَمُوَاضَعَةُ', #1
u'فمؤبر': u'فَمُؤَبَّرٌ', #1
u'فموطوءة': u'فَمَوْطُوءَةُ', #1
u'فمؤل': u'فَمُؤْلٍ', #2
u'فمومئا': u'فَمُومِئًا', #1
u'فموميا': u'فَمُومِيًا', #1
u'فمؤنة': u'فَمُؤْنَةٌ', #1
u'فمؤنة': u'فَمُؤْنَةُ', #69
u'فمؤنته': u'فَمَؤُنَتُهُ', #1
u'فمؤنته': u'فَمُؤْنَتُهُ', #24
u'فمؤنتها': u'فَمُؤْنَتُهَا', #9
u'فمؤنتهما': u'فَمُؤْنَتُهُمَا', #1
u'فمى': u'فَمِى', #1
u'فمئونة': u'فَمَئُونَةُ', #7
u'فميرات': u'فَمِيرَاتٌ', #1
u'فنأتى': u'فَنَأْتِى', #1
u'فنأتى': u'فَنَأْتِىَ', #5
u'فناخرت': u'فَنَاخَرَتْ', #1
u'فنادا': u'فَنَادَا', #1
u'فنادانى': u'فَنَادَانِى', #5
u'فنادتنى': u'فَنَادَتْنِى', #1
u'فنارة': u'فَنَارَةً', #1
u'فنارياق': u'فنارياق', #1
u'فناطه': u'فَنَاطَهُ', #1
u'فناولنى': u'فَنَاوَلَنِى', #3
u'فناولنيه': u'فَنَاوِلْنِيهِ', #1
u'فناولنيها': u'فَنَاوَلَنِيهَا', #1
u'فنباكيه': u'فَنُبَاكِيهِ', #1
u'فنبتدر': u'فَنَبْتَدِرُ', #1
u'فنبطس': u'فَنَبْطَسُ', #2
u'فنتسارعه': u'فَنَتَسَارَعَهُ', #1
u'فنجانة': u'فنجانة', #1
u'فنجانة': u'فِنْجَانَةً', #2
u'فنجنجه': u'فَنَجْنَجَهُ', #1
u'فنجهتنى': u'فَنَجَهْتَنِى', #1
u'فنجهنى': u'فَنَجَهَنِى', #1
u'فنحاص': u'فَنُحَاصُ', #1
u'فنحاص': u'فَنْحَاصَ', #1
u'فنحاص،': u'فَنْحَاصُ،', #2
u'فنحاص': u'فِنْحَاصُ', #20
u'فنحاص': u'فَنْحَاصُ', #5
u'فنحاص': u'فِنْحَاصَ', #6
u'فنحتفرها': u'فَنَحْتَفِرُهَا', #1
u'فندقليا': u'فُنْدُقْلِيًا', #1
u'فندمني،': u'فَنَدَّمَنِي،', #1
u'فنزلنى': u'فَنَزَّلَنِى', #2
u'فنزى': u'فَنَزَى', #1
u'فنزى': u'فَنَزَّى', #1
u'فنزى': u'فَنُزِىَ', #3
u'فنسبنى': u'فَنَسَبَنِى', #2
u'فنستخير': u'فَنَسْتَخِيرُ', #1
u'فنستريحا': u'فَنَسْتَرِيحَا', #1
u'فنستسعيه': u'فَنَسْتَسْعِيهِ', #1
u'فنستمطرها': u'فَنَسْتَمْطِرُهَا', #2
u'فنعطيكهم،': u'فنعطيكهُم،', #1
u'فنعطيكهم': u'فَنُعْطِيكَهُمْ', #1
u'فنعطيكهم': u'فَنُعْطِيَكَهُمْ', #1
u'فنعفوا': u'فَنَعْفُوا', #1
u'فنفرموسى': u'فَنَفَرَمُوسَى', #1
u'فنفلنى': u'فَنَفَّلَنِى', #5
u'فنفلنيه': u'فَنَفَّلَنِيهِ', #3
u'فنفلنيها': u'فَنَفّلَنِيهَا', #1
u'فنفلنيها': u'فَنَفَّلَنِيهَا', #1
u'فنفلنيها،': u'فَنَفَلَنِيهَا،', #1
u'فنفيع': u'فَنُفَيْعٌ', #1
u'فنقدنى': u'فَنَقَدَنِى', #2
u'فنكفيكموه': u'فَنَكْفِيكُمُوهُ', #2
u'فنكفيكه': u'فَنَكْفِيكَهُ', #2
u'فنليات': u'فنليات', #2
u'فنمتار': u'فَنَمْتَارُ', #1
u'فنملؤه': u'فَنَمْلَؤُهُ', #2
u'فنهانى': u'فَنَهَانِى', #14
u'فنؤاجره': u'فَنُؤَاجِرُهُ', #1
u'فنواقض': u'فَنَوَاقِضُ', #1
u'فنى': u'فنى', #1
u'فنى': u'فَنَى', #11
u'فنى': u'فَنِىَ', #4
u'فنيخت': u'فَنِيخَتْ', #1
u'فنيزا': u'فنيزا', #1
u'فنيفرهم': u'فنيفرهم', #1
u'فنيق': u'فَنِيقٍ', #1
u'فنيق': u'فَنِيقُ', #1
u'فهاتا': u'فَهَاتَا', #1
u'فهاتها': u'فَهَاتِهَا', #2
u'فهاتور': u'فَهَاتُورْ', #1
u'فهاتور': u'فَهَاتُورُ', #2
u'فهاكها': u'فَهَاكَهَا', #3
u'فهاكهم': u'فَهَاكُهُمْ', #1
u'فهأنذا،': u'فهأنذا،', #1
u'فهأنذا': u'فَهَأَنَذَا', #1
u'فهاهة': u'فَهَاهَةً', #1
u'فهبتوه': u'فَهَبّتُوهُ', #1
u'فهة': u'فَهّةِ', #1
u'فهة': u'فَهَّةً', #1
u'فهراق': u'فَهَرَاقَ', #2
u'فهريق': u'فَهُرِيقَ', #1
u'فهريقت': u'فَهُرِيقَتْ', #2
u'فهزءوا': u'فَهَزَءُوا', #1
u'فهق': u'فَهِقَ', #1
u'فهقا': u'فَهَقًا', #1
u'فهقا': u'فَهْقًا', #1
u'فهلبتها': u'فَهَلَبْتُهَا', #1
u'فهلما': u'فَهَلُمَّا', #1
u'فهلموا': u'فَهَلُمُّوا', #3
u'فهلمى': u'فَهَلُمِّى', #1
u'فهلميها': u'فهلميها', #1
u'فهلوية': u'فَهْلَوِيَّةٌ', #1
u'فهمنى': u'فَهَمَّنِى', #1
u'فهمنيها': u'فَهِّمْنِيهَا', #1
u'فهمنيها،': u'فَهِّمْنِيهَا،', #1
u'فهمنيها': u'فَهّمْنِيهَا', #2
u'فهندرة': u'فَهَنْدَرَةٍ', #2
u'فهنيته': u'فَهَنَّيْتُهُ', #1
u'فهوذة': u'فَهَوْذَةُ', #1
u'فهى': u'فَهْىَ', #11
u'فهى': u'فَهِىَ', #217
u'فهيرةSخبر': u'فُهَيْرَةَSخَبَرُ', #1
u'فهيرة،': u'فُهَيْرة،', #1
u'فهيرة': u'فُهَيْرَة', #1
u'فهيرة': u'فُهَيْرَةُ', #1
u'فهيرة': u'فهيرة', #2
u'فهيرة': u'فَهَيْرَةَ', #4
u'فهيرة،': u'فُهَيْرَةَ،', #7
u'فهيرة': u'فُهَيْرَةَ', #71
u'فهينم': u'فَهَيْنِمْ', #1
u'فواءل': u'فَوَاءَلَ', #2
u'فواحربا': u'فَوَاحَرْبًا', #1
u'فواخت': u'فَوَاخِتُ', #1
u'فواخت': u'فَوَاخِتَ', #3
u'فواخيناهم': u'فَوَاخَيْنَاهُمْ', #1
u'فؤادكا': u'فُؤَادِكَا', #5
u'فوارسننا': u'فَوَارِسُنَنا', #1
u'فوارغة': u'فَوَارِغَةٍ', #1
u'فواضعوا': u'فَوَاضَعُوا', #1
u'فواعجبا': u'فَوَاعَجَبَا', #1
u'فواعيل': u'فَوَاعِيلُ', #1
u'فواكبدي': u'فَوَاكَبِدِي', #1
u'فوالحالة': u'فَوَالْحَالَةِ', #1
u'فوالحالة': u'فَوَالْحَالَةُ', #5
u'فوالحرمة': u'فَوَالْحُرْمَةِ', #1
u'فوالذى': u'فَوَالَّذِى', #41
u'فواللاتي': u'فَوَاَللّاتِي', #1
u'فوأنت': u'فَوَأَنْتَ', #2
u'فوائت': u'فَوَائِتُ', #40
u'فوائت': u'فَوَائِتَ', #50
u'فوائت': u'فَوَائِتِ', #9
u'فوائته': u'فَوَائِتَهُ', #2
u'فوائته': u'فَوَائِتِهِ', #5
u'فوائتهم': u'فَوَائِتِهِمْ', #1
u'فوثئت': u'فوثِئَتْ', #1
u'فوثئت': u'فَوَثِئَتْ', #1
u'فوثئت': u'فَوُثِئَتْ', #2
u'فوجأ': u'فَوَجَأَ', #11
u'فوجأت': u'فَوَجَأْت', #2
u'فوجأت': u'فَوَجَأْتُ', #5
u'فوجأته': u'فَوَجَأْته', #1
u'فوجأتها': u'فَوَجَأْتُهَا', #1
u'فوجأه': u'فَوَجْأَهُ', #1
u'فوجأه': u'فَوَجَأَهُ', #5
u'فوجدنى': u'فَوَجَدَنِى', #3
u'فورتى': u'فَوْرَتِى', #1
u'فوري': u'فَوْرِيًّ', #1
u'فوضعنى': u'فَوَضَعَنِى', #1
u'فوطاف': u'فَوَطَافَ', #1
u'فوطىء': u'فَوَطِىءَ', #1
u'فوطيت': u'فَوَطِيتُ', #1
u'فوعة': u'فَوْعَةُ', #1
u'فوعزتي': u'فَوَعِزَّتِي', #4
u'فوقذه': u'فَوَقَذَهُ', #15
u'فوقذها': u'فَوَقَذَهَا', #2
u'فوقص': u'فَوُقِصَ', #15
u'فوقصت': u'فَوُقِصَتْ', #2
u'فوقصت': u'فَوَقَصَتْ', #4
u'فوقصته': u'فَوَقِصَّتِهِ', #1
u'فوقصته،': u'فَوَقَصَتْهُ،', #1
u'فوقصته': u'فَوَقَصَتْهُ', #13
u'فوقصتها': u'فَوَقَصَتْهَا', #2
u'فوقصه': u'فَوَقَصَهُ', #3
u'فولانيه': u'فَوَلَّانِيهِ', #1
u'فولانيه': u'فَوَلاَّنِيهِ', #1
u'فولائيته': u'فَوَلَائِيَّتُهُ', #1
u'فوليتكماها': u'فَوَلَّيْتُكُمَاهَا', #1
u'فوليس': u'فَوَلِيسِ', #1
u'فوه': u'فُوَّهً', #2
u'فوهاء': u'فَوْهَاءَ', #2
u'فوهاء': u'فَوْهَاءُ', #2
u'فويسق': u'فُوَيْسِقٌ', #15
u'فويسقا': u'فُوَيْسِقًا', #12
u'فويسقة': u'فُوَيْسِقَةٍ', #1
u'فويسقة': u'فُوَيْسِقَةً', #7
u'فويق': u'فُوَيْقُ', #1
u'فويق': u'فُوَيْقَ', #4
u'فويقه': u'فُوَيْقَهُ', #1
u'فويهة': u'فُوَيْهَةِ', #1
u'فى': u'َفى', #1
u'فى': u'َفِى', #1
u'فى': u'فى', #314
u'فى': u'فِى', #31877
u'فى': u'فِىَّ', #54
u'فىء': u'فَىْءٍ', #3
u'فىء': u'فَىْءُ', #3
u'فىء': u'فَىْءِ', #3
u'فىء': u'فَىْءٌ', #4
u'فىء': u'فَىْءَ', #5
u'فئام': u'فِئَام', #1
u'فئام': u'فِئَامٍ', #1
u'فئام': u'فِئَامِ', #1
u'فئام': u'فِئَامٌ', #18
u'فئاما': u'فِئَامًا', #2
u'فئقوله': u'فَئٌقَوْلُهُ', #1
u'فئون': u'فُئُونٌ', #1
u'فيأبق': u'فَيَأْبِقُ', #1
u'فيأبق': u'فَيَأْبَقُ', #10
u'فيأتدم': u'فَيَأْتَدِمُ', #1
u'فيأتمون': u'فَيَأْتَمُّونَ', #3
u'فيأتونى': u'فَيَأْتُونِى', #1
u'فيأتونى': u'فَيَأْتُونِّى', #1
u'فيأتى': u'فَيَأْتِى', #25
u'فيأتى': u'فَيَأْتِىَ', #3
u'فيأتينى': u'فَيَأْتِينِى', #4
u'فياح': u'فِيَاحٌ', #1
u'فيأذنه': u'فَيَأْذَنُهُ', #2
u'فياعل': u'فَيَاعِلَ', #1
u'فيأكلفي': u'فَيَأْكُلُفِي', #1
u'فيالأيام': u'فِيالْأَيَّامِ', #1
u'فيالترتيل': u'فِيالتَّرْتِيلِ', #1
u'فيالجامع': u'فِيالْجَامِعِ', #1
u'فيالركعة': u'فِيالرَّكْعَةِ', #1
u'فيالصف': u'فِيالصَّفِّ', #1
u'فيالصلاة': u'فِيالصَّلَاةِ', #2
u'فيالعتبية': u'فِيالْعُتْبِيَّةِ', #1
u'فيالقصي': u'فَيَالَقُصِيّ', #1
u'فيالقصى': u'فَيَالَقُصَىّ', #1
u'فيالله': u'فَيَالَلَّهِ', #1
u'فيالمبسوط': u'فِيالْمَبْسُوطِ', #2
u'فيالمجموعة': u'فِيالْمَجْمُوعَةِ', #2
u'فيالمشي': u'فِيالْمَشْيِ', #1
u'فياليت': u'فَيَالَيْتَ', #2
u'فيأمرنى': u'فَيَأْمُرُنِى', #1
u'فيبادرنى': u'فَيُبَادِرُنِى', #2
u'فيباغين': u'فَيُبَاغِينَ', #1
u'فيباين': u'فَيُبَايِنُ', #2
u'فيباينان': u'فَيُبَايِنَانِ', #1
u'فيبتدآن': u'فَيُبْتَدَآنِ', #1
u'فيبتدرون': u'فَيَبْتَدِرُونَ', #2
u'فيبتدي': u'فَيَبْتَدِي', #1
u'فيبخلوني': u'فَيُبْخِلُونِي', #1
u'فيبدءون': u'فَيَبْدَءُونَ', #2
u'فيبدآن': u'فَيَبْدَآنِ', #1
u'فيبرءون': u'فَيَبْرَءُونَ', #5
u'فيبرءونهم': u'فَيُبْرِءُونَهُمْ', #1
u'فيبرآن': u'فَيُبَرَّآنِ', #1
u'فيبرآن': u'فَيَبْرَآنِ', #7
u'فيبسون': u'فَيَبُسُّونَ', #2
u'فيبقله': u'فَيُبْقِلُهُ', #1
u'فيبقيان': u'فَيَبْقَيَانِ', #6
u'فيبنيان': u'فَيَبْنِيَانِ', #1
u'فيبنيان': u'فَيُبْنَيَانِ', #3
u'فية': u'فية', #2
u'فيتأبى': u'فَيَتَأَبَّى', #4
u'فيتأدى': u'فَيَتَأَدَّى', #21
u'فيتأذون': u'فَيَتَأَذَّوْنَ', #4
u'فيتأذى': u'فَيَتَأَذَّى', #32
u'فيتأقت': u'فَيَتَأَقَّتُ', #1
u'فيتألفهم': u'فَيَتَأَلَّفُهُمْ', #1
u'فيتبايعانه': u'فَيَتَبَايَعَانِهِ', #1
u'فيتبعد': u'فَيَتَبَعَّدَ', #1
u'فيتبعونى': u'فَيَتَّبِعُونِى', #4
u'فيتحاص': u'فَيَتَحَاصُّ', #3
u'فيتحاص': u'فَيَتَحَاصَّ', #4
u'فيتحاصان': u'فَيَتَحَاصَّانِ', #35
u'فيتحاصص': u'فَيَتَحَاصَصُ', #2
u'فيتحاصصون': u'فَيَتَحَاصَصُونَ', #4
u'فيتحاصصونه': u'فَيَتَحَاصَصُونَهُ', #1
u'فيتحاصون': u'فَيَتَحَاصّونَ', #1
u'فيتحاصون': u'فَيَتَحَاصُّونَ', #16
u'فيتحتم': u'فَيَتَحَتَّمَ', #1
u'فيتحتم': u'فَيَتَحَتَّمُ', #16
u'فيتحذر': u'فيتحذر', #1
u'فيتحرم': u'فَيُتَحَرَّمُ', #1
u'فيتحيل': u'فَيُتَحَيَّلَ', #1
u'فيتحيل': u'فَيَتَحَيَّلُ', #3
u'فيتحيلون': u'فَيَتَحَيَّلُونَ', #2
u'فيتخدمونه': u'فَيَتَخَدَّمُونَهُ', #1
u'فيتدهده': u'فَيَتَدَهْدَهُ', #3
u'فيتدهدى': u'فَيَتَدَهْدَى', #1
u'فيترادان': u'فَيُتَرَادَّانِ', #1
u'فيترادون': u'فَيَتَرَادُّونَ', #2
u'فيترادونها': u'فَيَتَرَادُّونَهَا', #1
u'فيترخص': u'فَيَتَرَخَّص', #1
u'فيترخص': u'فَيَتَرَخَّصَ', #1
u'فيترخص': u'فَيُتَرَخَّصُ', #2
u'فيترخص': u'فَيَتَرَخَّصُ', #20
u'فيتسالب': u'فَيَتَسَالَبُ', #1
u'فيتساويان': u'فَيَتَسَاوَيَانِ', #25
u'فيتسحر،': u'فيتسحر،', #1
u'فيتسحر': u'فَيَتَسَحَّر', #1
u'فيتسحر': u'فَيَتَسَحَّرَ', #1
u'فيتسحروا،': u'فيتسحروا،', #1
u'فيتسخطها': u'فَيَتَسَخَّطَهَا', #2
u'فيتسخطها': u'فَيَتَسَخَّطُهَا', #2
u'فيتسرر': u'فَيَتَسَرَّرُ', #1
u'فيتسوك': u'فَيَتَسَوَّكَ', #1
u'فيتسوك': u'فَيَتَسَوَّكُ', #8
u'فيتشاجوا': u'فَيَتَشَاجُّوا', #1
u'فيتشاركونه': u'فَيَتَشَارَكُونَهُ', #1
u'فيتشرب': u'فَيَتَشَرَّبَ', #1
u'فيتشرب': u'فَيَتَشَرَّبُ', #1
u'فيتشطر': u'فَيَتَشَطَّرَ', #1
u'فيتشطر': u'فَيَتَشَطَّرُ', #10
u'فيتشقص': u'فَيَتَشَقَّصُ', #4
u'فيتصرفه': u'فَيَتَصَرَّفُهُ', #1
u'فيتعار': u'فَيَتَعَارُّ', #1
u'فيتعار': u'فَيَتَعَارَّ', #3
u'فيتعاطسون': u'فَيَتَعَاطَسُونَ', #1
u'فيتعاقبوه': u'فَيَتَعَاقَبُوهُ', #1
u'فيتعاوضان': u'فَيَتَعَاوَضَانِ', #1
u'فيتعيب': u'فَيَتَعَيَّبُ', #1
u'فيتعير': u'فَيَتَعَيَّرُ', #1
u'فيتغسل': u'فَيَتَغَسَّلُ', #1
u'فيتغلظ': u'فَيَتَغَلَّظُ', #6
u'فيتغمض': u'فَيَتَغَمَّضُ', #1
u'فيتغول': u'فَيَتَغَوَّلُ', #1
u'فيتقابضا': u'فَيَتَقَابَضَا', #1
u'فيتقابضان': u'فَيَتَقَابَضَانِ', #2
u'فيتقاص': u'فَيُتَقَاصَّ', #1
u'فيتقاص': u'فَيُتَقَاصُّ', #1
u'فيتقاصا': u'فَيَتَقَاصَّا', #1
u'فيتقاصان': u'فَيَتَقَاصَّانِ', #37
u'فيتقاضان': u'فَيَتَقَاضَانِ', #1
u'فيتقاولونها': u'فَيَتَقَاوَلُونَهَا', #1
u'فيتقسط': u'فَيَتَقَسَّطُ', #1
u'فيتقصان': u'فَيَتَقَصَّانِ', #1
u'فيتقيأها': u'فَيَتَقَيَّأُهَا', #1
u'فيتكارى': u'فَيَتَكَارَى', #1
u'فيتكافآن': u'فَيَتَكَافَآنِ', #2
u'فيتلاقيان': u'فَيَتَلَاقَيَانِ', #1
u'فيتمحض': u'فَيَتَمَحَّضُ', #9
u'فيتمحل': u'فَيَتَمَحَّلَ', #2
u'فيتمرق': u'فَيَتَمَرَّقُ', #1
u'فيتناصفاه': u'فَيَتَنَاصَفَاهُ', #1
u'فيتنافيان': u'فَيَتَنَافَيَانِ', #8
u'فيتنخع': u'فَيَتَنَخَّعَ', #1
u'فيتنخع': u'فَيُتَنَخَّعَ', #5
u'فيتنخع': u'فَيَتَنَخَّعُ', #6
u'فيتنخل': u'فَيُتَنَخَّلُ', #1
u'فيتنخم': u'فَيَتَنَخَّمُ', #1
u'فيتنخم': u'فَيُتَنَخَّمَ', #1
u'فيتهرى': u'فَيَتَهَرَّى', #1
u'فيتهول': u'فَيَتَهَوَّلُ', #1
u'فيتهيئوا': u'فَيَتَهَيَّئُوا', #1
u'فيتواضعانها': u'فَيَتَوَاضَعَانِهَا', #2
u'فيتواطآن': u'فَيَتَوَاطَآنِ', #1
u'فيتوضآن': u'فَيَتَوَضَّآنِ', #1
u'فيتوضئون': u'فَيَتَوَضَّئُونَ', #3
u'فيتوقت': u'فَيُتَوَقَّتُ', #1
u'فيتوقت': u'فَيَتَوَقَّتُ', #9
u'فيتوليان': u'فَيَتَوَلَّيَانِ', #1
u'فيتوي': u'فَيَتْوِي', #1
u'فيثاغورث': u'فِيثَاغُورثَ', #1
u'فيثاغورس': u'فِيثَاغُورْسَ', #2
u'فيثلطون': u'فَيَثْلِطُونَ', #1
u'فيثلغ': u'فَيَثْلَغُ', #2
u'فيج': u'فَيْجٍ', #1
u'فيجا': u'فَيْجًا', #4
u'فيجتزئ': u'فَيَجْتَزِئُ', #3
u'فيجتعل': u'فَيَجْتَعِلَ', #3
u'فيجثو': u'فَيَجْثُو', #1
u'فيجريان': u'فَيَجْرِيَانِ', #8
u'فيجزءون': u'فَيُجَزَّءُونَ', #1
u'فيجزئان': u'فَيُجْزِئَانِ', #2
u'فيجزيان': u'فَيَجْزِيَانِ', #1
u'فيجلعه': u'فَيَجْلَعُهُ', #1
u'فيجىء': u'فَيَجِىءُ', #14
u'فيجىء': u'فَيَجِىءَ', #2
u'فيجيبنى': u'فَيُجِيبُنِى', #1
u'فيجيفه': u'فَيُجِيفُهُ', #1
u'فيجيئه': u'فَيَجِيئُهُ', #1
u'فيحاص': u'فَيُحَاصَّ', #1
u'فيحاص': u'فَيُحَاصُّ', #2
u'فيحاصص': u'فَيُحَاصِصْ', #1
u'فيحاصص': u'فَيُحَاصَصُ', #2
u'فيحاصص': u'فَيُحَاصِصُ', #7
u'فيحاصصن': u'فَيُحَاصِصْنَ', #1
u'فيحاصصه': u'فَيُحَاصِصُهُ', #1
u'فيحاصصهم': u'فَيُحَاصِصُهُمْ', #1
u'فيحاصهم': u'فَيُحَاصُّهُمْ', #1
u'فيحاصوا': u'فَيُحَاصُّوا', #1
u'فيحاصون': u'فَيُحَاصُّونَ', #1
u'فيحاصوهم': u'فَيُحَاصُّوهُمْ', #1
u'فيحامل': u'فَيُحَامِلُ', #1
u'فيحتاز': u'فَيَحْتَازُ', #2
u'فيحتثي': u'فَيَحْتَثِي', #1
u'فيحتفرون': u'فَيَحْتَفِرُونَ', #1
u'فيحثي': u'فَيَحْثِي', #2
u'فيحدثنى': u'فَيُحَدِّثُنِى', #1
u'فيحذفنى': u'فَيَحْذِفُنِى', #1
u'فيحيف': u'فَيَحِيفُ', #1
u'فيحيف': u'فَيَحِيفَ', #2
u'فيحيى': u'فَيَحْيَى', #5
u'فيحييان،': u'فَيَحْيَيَانِ،', #1
u'فيختدم': u'فَيُخْتَدَمَ', #1
u'فيختدمه': u'فَيَخْتَدِمُهُ', #3
u'فيختدمهم': u'فَيَخْتَدِمُهُمْ', #1
u'فيختلع': u'فَيَخْتَلِعُ', #5
u'فيخضخضه': u'فَيُخَضْخِضُهُ', #3
u'فيخطبته': u'فِيخُطْبَتِهِ', #1
u'فيخطرف': u'فَيُخَطْرِفُ', #1
u'فيخطئان': u'فَيُخْطِئَانِ', #1
u'فيدركنى': u'فَيُدْرِكَنِى', #1
u'فيدعثره': u'فَيُدَعْثِرُهُ', #6
u'فيدعنى': u'فَيَدَعُنِى', #2
u'فيدعيان': u'فَيَدَّعِيَانِ', #5
u'فيذئرهم': u'فَيُذْئِرَهُمْ', #2
u'فيذيدها': u'فَيُذِيدُهَا', #1
u'فيراجيه': u'فَيُرَاجِيهِ', #1
u'فيراطلهم': u'فَيُرَاطِلُهُمْ', #1
u'فيرانى': u'فَيَرَانِى', #2
u'فيراوضه': u'فَيُرَاوِضَهُ', #1
u'فيرتاض': u'فَيَرْتَاضُ', #2
u'فيرتجع': u'فَيَرْتَجِعُ', #2
u'فيرتدف': u'فَيَرْتَدِفُ', #1
u'فيرتفض': u'فَيُرْتَفَضُ', #4
u'فيرتفض': u'فَيَرْتَفِضُ', #5
u'فيرتفضان': u'فَيُرْتَفَضَانِ', #1
u'فيرتفضان': u'فَيَرْتَفِضَانِ', #2
u'فيرتفق': u'فَيَرْتَفِقُ', #1
u'فيرتفقون': u'فَيَرْتَفِقُونَ', #1
u'فيرتفقون': u'فَيُرْتَفَقُونَ', #1
u'فيرتهنه': u'فَيَرْتَهِنَهُ', #1
u'فيرتهنه': u'فَيَرْتَهِنُهُ', #1
u'فيرضيان': u'فَيَرْضَيَانِ', #4
u'فيرفؤه': u'فَيَرْفَؤُهُ', #1
u'فيرمضهم': u'فَيُرْمِضُهُمْ', #1
u'فيرميان': u'فَيَرْمِيَانِ', #2
u'فيروزج': u'فَيْرُوزَجِ', #1
u'فيروزج': u'فَيْرُوزَجُ', #5
u'فيروزج': u'فَيْرُوزَجَ', #7
u'فيروزجا': u'فَيْرُوزَجَا', #1
u'فيريان': u'فَيَرَيَانِ', #4
u'فيزدرعوا': u'فَيَزْدَرِعُوا', #1
u'فيزكيان': u'فَيُزَكِّيَانِ', #2
u'فيزكيان': u'فَيُزَكَّيَانِ', #5
u'فيزيدنى': u'فَيَزِيدُنِى', #1
u'فيسألنى': u'فَيَسْأَلَنِى', #1
u'فيسألنى': u'فَيَسْأَلُنِى', #1
u'فيسامتها': u'فَيُسَامِتُهَا', #6
u'فيستاك': u'فَيَسْتَاكَ', #1
u'فيستاك': u'فَيُسْتَاكُ', #1
u'فيستاك': u'فَيَسْتَاكُ', #8
u'فيستأمنهم': u'فَيَسْتَأْمِنُهُمْ', #1
u'فيستأمنوا': u'فَيَسْتَأْمِنُوا', #2
u'فيستأمنوه،': u'فَيَسْتَأْمِنُوهُ،', #1
u'فيستأمنوه': u'فَيَسْتَأْمِنُوهُ', #6
u'فيستأني': u'فَيَسْتَأْنِي', #1
u'فيستأنى': u'فَيُسْتَأْنَى', #2
u'فيستتاب': u'فَيُسْتَتَابَ', #2
u'فيستتاب': u'فَيُسْتَتَابُ', #38
u'فيستتابون': u'فَيُسْتَتَابُونَ', #1
u'فيستتيبهم': u'فَيَسْتَتِيبُهُمْ', #1
u'فيستثنيان': u'فَيُسْتَثْنَيَانِ', #4
u'فيستجمر': u'فَيَسْتَجْمِرُ', #1
u'فيستحيى': u'فَيَسْتَحْيِى', #4
u'فيستخلي': u'فَيَسْتَخْلِي', #1
u'فيستد': u'فَيَسْتَدُّ', #1
u'فيستريب': u'فَيَسْتَرِيبُ', #1
u'فيستسعط': u'فَيُسْتَسْعَطُ', #1
u'فيستسعون': u'فَيَسْتَسْعَوْنَ', #1
u'فيستسعونه': u'فَيَسْتَسْعَوْنَهُ', #1
u'فيستسعوه': u'فَيَسْتَسْعُوهُ', #1
u'فيستسعي': u'فَيَسْتَسْعِي', #2
u'فيستسعى': u'فَيُسْتَسْعَى', #8
u'فيستسعيه': u'فَيَسْتَسْعِيه', #2
u'فيستسعيه': u'فَيَسْتَسْعِيهِ', #21
u'فيستسعيه': u'فَيَسْتَسْعِيَهُ', #4
u'فيستسلفها': u'فَيَسْتَسْلِفُهَا', #1
u'فيستسلفون': u'فَيَسْتَسْلِفُونَ', #1
u'فيستسميها': u'فَيَسْتَسْمِيهَا', #1
u'فيستصبح': u'فَيُسْتَصْبَحُ', #1
u'فيستعضل': u'فَيَسْتَعْضِلُ', #1
u'فيستعقب': u'فَيَسْتَعْقِبُ', #4
u'فيستعقبها': u'فَيَسْتَعْقِبُهَا', #1
u'فيستعقبهما': u'فَيَسْتَعْقِبُهُمَا', #1
u'فيستفتينى': u'فَيَسْتَفْتِينِى', #1
u'فيستفحلونها': u'فَيَسْتَفْحِلُونَهَا', #1
u'فيستفرش': u'فَيَسْتَفْرِشُ', #1
u'فيستفيده': u'فَيَسْتَفِيدُهُ', #1
u'فيستفيدها': u'فَيَسْتَفِيدُهَا', #1
u'فيستقتل': u'فَيَسْتَقْتِلُ', #1
u'فيستقرض': u'فَيَسْتَقْرِضُ', #3
u'فيستقرضهم': u'فَيَسْتَقْرِضُهُمْ', #1
u'فيستقضي': u'فَيَسْتَقْضِي', #2
u'فيستكدوا': u'فَيَسْتَكِدُّوا', #1
u'فيستكسبه': u'فَيَسْتَكْسِبُهُ', #1
u'فيستلحق': u'فَيَسْتَلْحِقُ', #1
u'فيستلحقون': u'فيستلحقون', #1
u'فيستن': u'فَيَسْتَنُّ', #1
u'فيستناب': u'فَيُسْتَنَابُ', #4
u'فيستنثر': u'فَيَسْتَنْثِرُ', #3
u'فيستنقع': u'فَيَسْتَنْقِعُ', #3
u'فيستنكه': u'فَيَسْتَنْكِهَ', #1
u'فيستنكه': u'فَيُسْتَنْكَهُ', #2
u'فيستنكهه': u'فَيَسْتَنْكِهُهُ', #2
u'فيستنى': u'فَيُسْتَنَى', #1
u'فيستنيب': u'فَيَسْتَنِيبُ', #9
u'فيستهما': u'فَيَسْتَهِمَا', #1
u'فيستوفيان': u'فَيَسْتَوْفِيَانِ', #6
u'فيستوهب': u'فَيُسْتَوْهَبُ', #1
u'فيستويان': u'فَيَسْتَوِيَانِ', #108
u'فيسجده': u'فَيَسْجُدُهُ', #6
u'فيسجدها': u'فَيَسْجُدْهَا', #1
u'فيسجدها': u'فَيَسْجُدُهَا', #10
u'فيسجدهما': u'فَيَسْجُدُهُمَا', #1
u'فيسجدونها': u'فَيَسْجُدُونَهَا', #1
u'فيسرنى': u'فَيَسَّرَنِى', #1
u'فيسعيان': u'فَيَسْعَيَانِ', #5
u'فيسفي': u'فَيُسْفِي', #1
u'فيسقيناه': u'فَيَسْقِينَاهُ', #2
u'فيسميان': u'فَيُسَمَّيَانِ', #2
u'فيسئلهم': u'فيسئلهم', #1
u'فيشتريان': u'فَيَشْتَرِيَانِ', #5
u'فيشتفي': u'فَيَشْتَفِي', #1
u'فيشتملها': u'فَيَشْتَمِلُهَا', #1
u'فيشدخ': u'فَيَشْدَخُ', #1
u'فيشدخون': u'فَيَشْدَخُونَ', #1
u'فيشلى': u'فَيُشْلَى', #1
u'فيشوبه': u'فَيَشُوبُهُ', #1
u'فيص': u'فِيِّص', #1
u'فيصطلمون': u'فَيَصْطَلِمُونَ', #1
u'فيصلاة': u'فِيصَلَاةِ', #1
u'فيصلاة': u'فِيصَلَاةٍ', #2
u'فيضات': u'فَيْضَاتٍ', #2
u'فيضأل': u'فَيَضْأَلُ', #1
u'فيطرحونى': u'فَيَطْرَحُونِى', #2
u'فيطعمنى': u'فَيُطْعِمُنِى', #1
u'فيطفيه،': u'فَيُطْفِيهِ،', #1
u'فيطؤها': u'فَيَطَؤُهَا', #49
u'فيطؤهما': u'فَيَطَؤُهُمَا', #1
u'فيطئون': u'فَيَطَئُونَ', #1
u'فيطئونها': u'فَيَطَئُونَهَا', #3
u'فيظطلم': u'فَيُظْطَلَمُ', #1
u'فيعالة': u'فَيْعَالَةً', #1
u'فيعالة': u'فَيْعَالَةٌ', #1
u'فيعايا': u'فَيُعَايَا', #22
u'فيعايى': u'فَيُعَايَى', #210
u'فيعايي': u'فَيُعَايِي', #5
u'فيعتضد': u'فَيُعْتَضَدُ', #1
u'فيعتضده': u'فَيَعْتَضِدُهْ', #2
u'فيعتلجان': u'فَيَعْتَلِجَانِ', #6
u'فيعجبنى': u'فَيُعْجِبُنِى', #1
u'فيعطيان': u'فَيُعْطِيَانِ', #1
u'فيعطيان': u'فَيُعْطَيَانِ', #4
u'فيعطيكها': u'فَيُعْطِيكَها', #1
u'فيعطينى': u'فَيُعْطِينِى', #1
u'فيعطينيها': u'فَيُعْطِينِيهَا', #2
u'فيعلة': u'فَيْعِلَةٌ', #1
u'فيعلة': u'فَيْعَلَةٌ', #4
u'فيعلمنى': u'فَيُعَلِّمُنِى', #2
u'فيعلمنيها': u'فَيُعَلِّمُنِيهَا', #1
u'فيعولا': u'فَيْعُولًا', #2
u'فيغافله': u'فَيُغَافِلُهُ', #1
u'فيغترق': u'فَيَغْتَرِقُ', #1
u'فيغتفلها': u'فَيَغْتَفِلُهَا', #1
u'فيغطئل': u'فَيَغْطَئِلُ', #3
u'فيغليان': u'فَيَغْلِيَانِ', #2
u'فيغمى': u'فَيُغْمَى', #4
u'فيفاة': u'فَيْفَاةٌ', #1
u'فيفتات': u'فَيَفْتَاتَ', #1
u'فيفتاتون': u'فَيَفْتَاتُونَ', #1
u'فيفتض': u'فَيُفْتَضَّ', #1
u'فيفتضها': u'فَيَفْتَضَّهَا', #1
u'فيفتضها': u'فَيَفْتَضُّهَا', #2
u'فيفديان': u'فَيَفْدِيَانِ', #1
u'فيفسدهالأن': u'فَيُفْسِدُهَالِأَنَّ', #1
u'فيفقؤها': u'فَيَفْقَؤُهَا', #1
u'فيفنيه': u'فَيُفْنِيه', #1
u'فيفنيه': u'فَيُفْنِيهِ', #2
u'فيفوح': u'فَيَفُوحُ', #1
u'فيفىء': u'فَيَفِىءُ', #3
u'فيفيت': u'فَيُفِيتُ', #2
u'فيفيتها': u'فَيُفِيتُهَا', #2
u'فيفيتهما': u'فَيُفِيتُهُمَا', #1
u'فيفيدناه': u'فَيُفِيدَنَاهُ', #1
u'فيقاليطأطئون': u'فَيُقَالُيُطَأْطِئُونَ', #1
u'فيقتصده': u'فَيَقْتَصِدُهْ', #2
u'فيقتضيان': u'فَيَقْتَضِيَانِ', #2
u'فيقتفر': u'فَيَقْتَفِرُ', #1
u'فيقتلنى': u'فَيَقْتُلُنِى', #2
u'فيقتلونى': u'فَيَقْتُلُونِى', #1
u'فيقرءون': u'فَيَقْرَءُونَ', #14
u'فيقرؤه': u'فَيَقْرَؤُهُ', #1
u'فيقرؤها': u'فيقرؤها', #1
u'فيقرؤها': u'فَيَقْرَؤُهَا', #15
u'فيقرؤهما': u'فَيَقْرَؤُهُمَا', #1
u'فيقضيناه': u'فَيَقْضِينَاهُ', #1
u'فيقلة': u'فيقلة', #1
u'فيقوللا': u'فَيَقُولُلا', #1
u'فيكا': u'فِيكَا', #6
u'فيكافئان': u'فَيُكَافِئَانِ', #1
u'فيكريان': u'فَيُكْرِيَانِ', #1
u'فيكريون': u'فَيَكْرِيُونَ', #1
u'فيكلمنى': u'فَيُكَلِّمُنِى', #1
u'فيكوسار': u'فِيكَوسَارَ', #1
u'فيكيدوا': u'فَيَكِيدواْ', #1
u'فيكيدوا': u'فَيَكِيدُوا', #5
u'فيلانشاه،': u'فيلانشاه،', #1
u'فيلبش': u'فيلبش', #1
u'فيلبيان': u'فَيُلَبِّيَانِ', #1
u'فيلتقيان': u'فَيَلْتَقِيَانِ', #34
u'فيلزمناأن': u'فَيَلْزَمُنَاأَنْ', #1
u'فيلس': u'فيلس', #1
u'فيلغيان': u'فَيُلْغِيَانِ', #1
u'فيلمانيا': u'فَيْلَمَانِيًّا', #1
u'فيلولة': u'فَيْلُولَةٌ', #1
u'فيلى': u'فَيَلِى', #2
u'فيليق': u'فَيَلِيقُ', #30
u'فيماأرى': u'فِيمَاأَرَى', #1
u'فيمتارون': u'فَيَمْتَارُونَ', #1
u'فيمتليء': u'فيمتليء', #1
u'فيمحمله': u'فِيمَحْمِلِهِ', #1
u'فيمدر': u'فَيَمْدُرَ', #1
u'فيمدر': u'فَيَمْدُرُ', #1
u'فيمذي': u'فَيُمْذِي', #3
u'فيمسجدهم': u'فِيمَسْجِدِهِمْ', #1
u'فيمضيان': u'فَيَمْضِيَانِ', #1
u'فيمعرض': u'فِيمَعْرِضِ', #1
u'فيمقابر': u'فِيمَقَابِرِ', #1
u'فيملؤه': u'فَيَمْلَؤُهُ', #1
u'فيملؤها': u'فيملؤها', #1
u'فيملؤها': u'فَيَمْلَؤُهَا', #3
u'فيملئون': u'فَيَمْلَئُونَ', #1
u'فيمنأتى': u'فِيمَنْأَتَى', #1
u'فيمنزله': u'فِيمَنْزِلِهِ', #1
u'فيميون': u'فَيْمِيون', #20
u'فيميون': u'فَيْمِيُون', #20
u'فيناكر': u'فَيُنَاكِرُ', #1
u'فيناكرها': u'فَيُنَاكِرُهَا', #1
u'فينانة': u'فَيْنَانَةٍ', #1
u'فينبغى': u'فَيَنْبَغِى', #1
u'فينتثر': u'فَيَنْتَثِرُ', #4
u'فينتثل': u'فَيَنْتَثِلَ', #1
u'فينتثل': u'فَيُنْتَثَلَ', #13
u'فينتصرونه': u'فَيَنْتَصِرُونَهُ', #1
u'فينتفيان': u'فَيَنْتَفِيَانِ', #2
u'فينتقمه': u'فَيَنْتَقِمَهُ', #2
u'فينجرح': u'فَيَنْجَرِحُ', #1
u'فينحجر': u'فَيَنْحَجِرُ', #2
u'فيندرئ': u'فَيَنْدَرِئُ', #24
u'فينشآن': u'فَيَنْشَآنِ', #1
u'فينشلي': u'فَيَنْشَلِي', #1
u'فينظهر': u'فَيَنْظَهِرُ', #1
u'فينقدح': u'فَيَنْقَدِحُ', #9
u'فينقضيان': u'فَيَنْقَضِيَانِ', #1
u'فينقمع': u'فَيَنْقَمِعُ', #1
u'فينماع': u'فَيَنْمَاعُ', #3
u'فينويان': u'فَيَنْوِيَانِ', #1
u'فيهاالصلاة': u'فِيهَاالصَّلَاةُ', #1
u'فيهاثم': u'فِيهَاثُمَّ', #1
u'فيهافإنه': u'فِيهَافَإِنَّهُ', #1
u'فيهاقوله': u'فِيهَاقَوْلُهُ', #2
u'فيهأن': u'فِيهِأَنْ', #1
u'فيهريق': u'فَيُهَرِيقُ', #2
u'فيهريق': u'فَيُهْرِيقُ', #2
u'فيهعلى': u'فِيهِعَلَى', #1
u'فيهقوله': u'فِيهِقَولُهُ', #1
u'فيهلأن': u'فِيهِلِأَنَّ', #1
u'فيهلغ': u'فَيَهْلَغُ', #1
u'فيهمو': u'فِيهِمُو', #2
u'فيهنيه': u'فَيُهَنِّيهِ', #1
u'فيهوالوجه': u'فِيهِوَالْوَجْهُ', #1
u'فيهوروي': u'فِيهِوَرُوِيَ', #3
u'فيهوكلمة': u'فِيهِوَكَلِمَةُ', #1
u'فيؤاجر': u'فَيُؤَاجَرَ', #1
u'فيؤاجر': u'فَيُؤَاجِرَ', #3
u'فيؤاجر': u'فَيُؤَاجَرُ', #4
u'فيؤاجر': u'فَيُؤَاجِرُ', #7
u'فيؤاجراه': u'فَيُؤَاجِرَاهُ', #1
u'فيؤاجره': u'فَيُؤَاجِرَهُ', #1
u'فيؤاجره': u'فَيُؤَاجِرُهُ', #4
u'فيؤاجرها': u'فَيُؤَاجِرُهَا', #1
u'فيؤاجرها': u'فَيُؤَاجِرَهَا', #3
u'فيؤاجروه': u'فَيُؤَاجِرُوهُ', #2
u'فيؤاخذ': u'فَيُؤَاخَذُ', #153
u'فيؤاخذ': u'فَيُؤَاخَذ', #2
u'فيؤاخذ': u'فَيُؤَاخَذَ', #2
u'فيؤاخذ': u'فَيُؤَاخِذُ', #7
u'فيؤاخذان': u'فَيُؤَاخَذَانِ', #6
u'فيؤاخذن': u'فَيُؤَاخَذُنَّ', #1
u'فيؤاخذه': u'فَيُؤَاخِذُهُ', #2
u'فيواضع': u'فَيُوَاضِعُ', #1
u'فيؤاكلهم': u'فَيُؤَاكِلُهُمْ', #1
u'فيوائل': u'فَيُوَائِلُ', #3
u'فيؤبد': u'فَيُؤَبَّدُ', #1
u'فيؤبد': u'فَيُؤَبِّدَ', #1
u'فيؤبد': u'فَيُؤَبِّدُ', #1
u'فيؤتنف': u'فَيُؤْتَنَفُ', #1
u'فيؤديان': u'فَيُؤَدَّيَانِ', #1
u'فيؤديان': u'فَيُؤَدِّيَانِ', #1
u'فيؤذينى': u'فَيُؤْذِينِى', #1
u'فيؤقت': u'فَيُؤَقَّتُ', #2
u'فيوكأ': u'فَيُوكَأُ', #1
u'فيوكي': u'فَيُوكِي', #1
u'فيوكي': u'فَيُوكِيَ', #1
u'فيوكى': u'فَيُوكَى', #3
u'فيؤه': u'فَيْؤُهُ', #47
u'فيؤها': u'فَيْؤُهَا', #2
u'فيؤهم': u'فَيْؤُهُمْ', #1
u'فيئوب': u'فَيَئُوبُ', #1
u'فيئوس': u'فَيَئُوسٌ', #3
u'فيئول': u'فَيَئُولَ', #5
u'فيئول': u'فَيَئُولُ', #57
u'فييوم': u'فِييَوْمِ', #1
u'قا': u'قا', #1
u'قا': u'قَا', #1
u'قابل': u'قَابِلً', #2
u'قابيل': u'قَابِيلِ', #1
u'قابيل': u'قَابِيلُ', #10
u'قابيل': u'قَابِيلَ', #18
u'قابيل': u'قَابِيل', #2
u'قاتلتنى': u'قَاتَلَتْنِى', #1
u'قاتلنى': u'قَاتَلَنِى', #1
u'قاتلنى؟': u'قَاتَلَنِى؟', #2
u'قاتلى': u'قَاتِلِى', #1
u'قاحز': u'قَاحِزٍ', #1
u'قادس': u'قَادِسٌ', #1
u'قادس': u'قَادِسَ', #1
u'قادس': u'قَادِسٍ', #2
u'قارءا': u'قَارِءًا', #1
u'قارظ': u'قَارِظٌ', #1
u'قارظ،': u'قَارِظٍ،', #11
u'قارظ': u'قارظ', #2
u'قارظ،': u'قارظ،', #2
u'قارظ': u'قَارِظِ', #4
u'قارظ': u'قَارِظٍ', #51
u'قازح': u'قَازَحَ', #1
u'قازح': u'قَازِحٌ', #1
u'قازح': u'قَازِحٍ', #2
u'قاسارية': u'قَاسَارِيَّةٌ', #1
u'قاسانية': u'قَاسَانِيَّةٍ', #1
u'قاسطية': u'قَاسِطِيَّةٌ', #1
u'قاسيون': u'قَاسِيُونَ', #7
u'قاش': u'قَاشٍ', #1
u'قاشان': u'قَاشَانَ', #1
u'قاشاني': u'قَاشَانِيٍّ', #1
u'قاشانيا': u'قَاشَانِيًّا', #1
u'قاشه': u'قاشه', #1
u'قاصح': u'قَاصِحٌ', #1
u'قاصرية': u'قَاصِرِيَّةٌ', #2
u'قاصصوه': u'قَاصَصُوهُ', #1
u'قاضيا': u'قَاضِيًاًًًً', #1
u'قاضيخان': u'قَاضِيخَانْ', #103
u'قاطع': u'قَاطِعً', #1
u'قاطم': u'قَاطِمٌ', #1
u'قاطمة': u'قَاطِمَة', #1
u'قاطورا': u'قَاطُورَا', #1
u'قاعدت': u'قَاعَدْتُ', #6
u'قاعدناك': u'قَاعَدْنَاكَ', #1
u'قافة': u'قَافَةُ', #1
u'قافة': u'قَافَةٍ', #15
u'قافة': u'قَافَةَ', #19
u'قافة': u'قَافَّةٌ', #3
u'قافة،': u'قَافَةً،', #4
u'قافة': u'قَافَةٌ', #44
u'قافة': u'قَافَةً', #7
u'قأقبل': u'قَأَقْبَلَ', #1
u'قالابن': u'قَالابْنُ', #1
u'قالابن': u'قَالَابْنُ', #4
u'قالأبو': u'قَالَأَبُو', #1
u'قالاحدثناأبو': u'قَالاَحَدَّثَنَاأَبُو', #1
u'قالأصحاب': u'قَالَأَصْحَابُ', #1
u'قالاغتصبتموها': u'قَالَاغْتَصَبْتُمُوهَا', #1
u'قالالأشهاد': u'قَالَالأَشْهَادُ', #1
u'قالالإمام': u'قَالَالْإِمَامُ', #1
u'قالالشافعي': u'قَالالشَّافِعِيُّ', #1
u'قالالشافعي': u'قَالَالشَّافِعِيُّ', #2
u'قالالظهري': u'قَالَالظِّهْرِيُّ', #1
u'قالالقاضي': u'قَالَالْقَاضِي', #2
u'قالالمحرم': u'قَالَالْمُحَرَّمُ', #1
u'قالإلى': u'قَالَإِلَى', #1
u'قالإني': u'قَالَإِنِّي', #1
u'قالبزا': u'قالبزا', #1
u'قالة': u'قَالَةُ', #1
u'قالة': u'قَالَة', #2
u'قالة': u'قَالَةٌ', #2
u'قالة': u'قَالَةً', #3
u'قالة': u'قَالَةِ', #3
u'قالرصوا': u'قَالَرُصُّوا', #1
u'قالسمعتأن': u'قَالَسَمِعْتُأَنَّ', #1
u'قالضحى': u'قَالَضحى', #1
u'قالضرب': u'قَالَضَرَبَ', #1
u'قالعثمان': u'قَالَعُثْمَانُ', #1
u'قالعذابه': u'قَالَعَذَابُهُ', #1
u'قالفي': u'قَالَفي', #1
u'قالق': u'قَالِقٌ', #1
u'قاللما': u'قَالَلَمَّا', #1
u'قالليلني': u'قَالَلِيَلِنِي', #1
u'قالمالك': u'قَالَمَالِكٌ', #2
u'قالمعمر': u'قَالَمَعْمَرٌ', #1
u'قالمن': u'قَالَمِنْ', #1
u'قالنزلت': u'قَالَنَزَلَتْ', #1
u'قالهابن': u'قَالَهُابْنُ', #2
u'قالهديناهم': u'قَالَهَدَيْنَاهُمْ', #1
u'قالهذا': u'قَالَهَذَا', #1
u'قالهو': u'قَالَهُوَ', #1
u'قالواآمنا': u'قَالُواآمَنَّا', #1
u'قالواإنا': u'قَالُواإِنَّا', #1
u'قالواإنما': u'قَالُواإِنَّمَا', #1
u'قالواأنؤمن': u'قَالُواأَنُؤْمِنُ', #2
u'قالوجه': u'قَالَوَجْهُ', #1
u'قاليجلد': u'قَالَيجلد', #1
u'قانف': u'قانف', #1
u'قانف،': u'قَانِفٍ،', #1
u'قانف': u'قَانِفٍ', #8
u'قاه': u'قاه', #1
u'قاه': u'قَاهُ', #1
u'قاهث': u'قَاهِث', #1
u'قاهث': u'قَاهِثِ', #1
u'قاواه': u'قَاوَاهُ', #2
u'قاوند': u'قَاوَنْدَ', #2
u'قاووس': u'قاووس', #5
u'قائش': u'قَائِشِ', #2
u'قائف': u'قَائِفِ', #1
u'قائف،': u'قَائِفٌ،', #1
u'قائف': u'قَائِف', #2
u'قائف': u'قَائِفٍ', #39
u'قائف': u'قَائِفَ', #5
u'قائف': u'قَائِفٌ', #76
u'قائفا،': u'قائفا،', #1
u'قائفا': u'قائفًا', #1
u'قائفا': u'قَائِفًا', #27
u'قائفان': u'قَائِفَانِ', #16
u'قائفين': u'قَائِفِينَ', #1
u'قائفين': u'قَائِفَيْنِ', #7
u'قآئما': u'قَآئِمًا', #1
u'قآئما': u'قَآئِمَاً', #2
u'قآئمة': u'قَآئِمَةٌ', #1
u'قائمتى': u'قَائِمَتَىِ', #1
u'قائن': u'قَائِنٍ', #3
u'قايتباي': u'قَايِتْبَايَ', #1
u'قايتباي': u'قَايِتْبَاي', #2
u'قايتباي': u'قَايِتْبَايْ', #6
u'قايد،': u'قَايدٍ،', #1
u'قايل': u'قَايَلَ', #4
u'قايله': u'قَايَلَهُ', #1
u'قايلهم': u'قَايَلَهُمْ', #1
u'قايماز': u'قَايْمَازُ', #1
u'قايماز': u'قَايْماز', #2
u'قايماز': u'قَايْمَازِ', #2
u'قاين': u'قَايَنَ', #1
u'قاين': u'قاين', #3
u'قبابين': u'قَبَابِينَ', #1
u'قبات': u'قبات', #1
u'قباث': u'قَبَاثٌ', #1
u'قباث': u'قُبَاثَ', #1
u'قباث': u'قُبَاثِ', #1
u'قباث': u'قِبَاثَ', #1
u'قباث،': u'قَبَاثٍ،', #1
u'قباث،': u'قُبَاثٍ،', #1
u'قباث،': u'قُبَاثُ،', #1
u'قباث': u'قباث', #2
u'قباث': u'قُبَاثٍ', #2
u'قباث': u'قُبَاثُ', #2
u'قباث': u'قَبَاثُ', #4
u'قباث': u'قَبَاثِ', #4
u'قباذ': u'قَبَاذٍ', #1
u'قباذ': u'قَبَاذِ', #1
u'قباذ': u'قباذ', #2
u'قباذ': u'قُبَاذٍ', #2
u'قباص': u'قَبَّاصُ', #1
u'قباطاق': u'قَبَاطَاقَ', #1
u'قباطي،': u'قَبَاطيّ،', #1
u'قباكه': u'قباكه', #1
u'قبالان': u'قِبَالانِ', #1
u'قبالان،': u'قِبَالَانِ،', #1
u'قبالان': u'قِبَالَانِ', #16
u'قبالين': u'قِبَالَيْنِ', #2
u'قبجة': u'قَبْجَةٌ', #1
u'قبرس': u'قُبْرس', #1
u'قبرس': u'قُبْرُسَ', #18
u'قبرس،': u'قبرس،', #2
u'قبرو': u'قبرو', #1
u'قبرى': u'قَبْرِى', #11
u'قبصا': u'قَبْصًا', #1
u'قبصات': u'قَبَصَاتٌ', #1
u'قبصة': u'قَبْصَةٌ', #1
u'قبصة': u'قَبْصَةٍ', #1
u'قبصة': u'قَبْصَةً', #2
u'قبصت': u'قَبَصَتْ', #1
u'قبضين': u'قَبْضَيْنِ', #3
u'قبطى': u'قِبْطِىٌّ', #3
u'قبل': u'قَبْلً', #4
u'قبلالفريضة': u'قَبْلَالْفَرِيضَةِ', #1
u'قبلتهبين': u'قِبْلَتُهُبَيْنَ', #1
u'قبلتى': u'قِبْلَتِى', #1
u'قبلنى': u'قَبَّلَنِى', #1
u'قبلهكل': u'قَبْلَهُكُلُّ', #1
u'قبلهماوالوجه': u'قِبَلَهُمَاوَالْوَجْهُ', #1
u'قبلى': u'قِبَلِى', #4
u'قبلى': u'قَبْلِى', #47
u'قبلينى': u'قَبِّلِينِى', #1
u'قبيبة': u'قُبَيْبَةَ', #1
u'قبيس،': u'قبيس،', #1
u'قبيس': u'قَبِيسٍ', #1
u'قبيس': u'قُبَيْس', #1
u'قبيس': u'قُبَيْسِ', #1
u'قبيس': u'قُبَيْسٍ', #160
u'قبيس': u'قبيس', #2
u'قبيس،': u'قُبَيْسٍ،', #5
u'قبيسا': u'قُبَيْسًا', #1
u'قبيصة': u'قَبِيصة', #1
u'قبيصة': u'قَبِيصَةٌ', #1
u'قبيصة': u'قُبَيْصة', #1
u'قبيصة؟': u'قَبِيصَةُ؟', #1
u'قبيصة': u'قُبَيْصَةُ', #1
u'قبيصة،': u'قُبَيْصَةَ،', #1
u'قبيصة،': u'قَبِيصَةُ،', #119
u'قبيصة،': u'قبيصة،', #15
u'قبيصة': u'قبيصة', #19
u'قبيصة،': u'قَبِيصَةَ،', #19
u'قبيصة': u'قَبِيصَةُ', #263
u'قبيصة': u'قَبِيصَةَ', #278
u'قبيصة': u'قُبَيْصَةَ', #4
u'قبيصة': u'قَبِيصَة', #6
u'قبيصة،': u'قُبَيْصَةُ،', #6
u'قبيطة': u'قَبِيطَةُ', #1
u'قبيطة،': u'قُبَيْطَةَ،', #1
u'قبيل': u'قُبَيْلً', #1
u'قبيلان': u'قَبِيلَانَ', #1
u'قبيلان': u'قَبِيلَانِ', #1
u'قبيلين': u'قَبِيلَيْنِ', #1
u'قتاة': u'قَتَاةٍ', #1
u'قتادةالبور': u'قَتَادَةَالْبُورُ', #1
u'قتادةالحواري': u'قَتَادَةُالْحَوَارِيُّ', #1
u'قتادةأن': u'قَتَادَةَأَنَّ', #6
u'قتادةأنه': u'قَتَادَةَأَنَّهُ', #2
u'قتادةإنهم': u'قَتَادَةُإِنَّهُمْ', #1
u'قتادةتبين': u'قَتَادَةَتَبَيَّنَ', #1
u'قتادةثم': u'قَتَادَةَثُمَّ', #1
u'قتادةح': u'قَتَادَةَح', #1
u'قتادةحتى': u'قَتَادَةَحَتَّى', #1
u'قتادةصم': u'قَتَادَةَصُمٌّ', #2
u'قتادةعن': u'قَتَادَةَعَنْ', #1
u'قتادةفظلت': u'قَتَادَةَفَظَلَّتْ', #1
u'قتادةفما': u'قَتَادَةُفَمَا', #1
u'قتادةفي': u'قَتَادَةَفِي', #1
u'قتادةقال': u'قَتَادَةَقَالَ', #1
u'قتادةكان': u'قَتَادَةَكَانَ', #1
u'قتادةكان': u'قَتَادَةُكَانَ', #1
u'قتادةوشرابه': u'قَتَادَةَوَشَرَابُهُ', #1
u'قتالة': u'قَتَّالَةٌ', #6
u'قتب': u'قتب', #1
u'قتب': u'قَتَبَ', #1
u'قتب': u'قَتَبِ', #1
u'قتب': u'قَتَب', #2
u'قتب': u'قَتَبٌ', #2
u'قتب': u'قَتْبٍ', #2
u'قتب': u'قِتْبٌ', #2
u'قتب': u'قَتَبٍ', #37
u'قتبك': u'قَتَبِك', #1
u'قتبه': u'قَتَبِهِ', #1
u'قتبه': u'قَتَبَهُ', #3
u'قتبية': u'قُتَبْيَةَ', #1
u'قتبية': u'قُتَبْيَةُ', #1
u'قتده': u'قَتَدَهْ', #1
u'قتلات': u'قَتْلَاتٍ', #1
u'قتلات': u'قَتْلَاتٌ', #2
u'قتلات': u'قِتْلَاتٌ', #6
u'قتلاتك': u'قَتَلَاتِكَ', #1
u'قتلتنى': u'قَتَلْتَنِى', #2
u'قتلكSمن': u'قَتَلَكSمِنْ', #1
u'قتلنى': u'قَتَلَنِى', #10
u'قتلنى؟': u'قَتَلَنِى؟', #2
u'قتلونى': u'قَتَلُونِى', #1
u'قتودي': u'قُتُودِي', #2
u'قتير': u'قُتَير', #1
u'قتيرة،': u'قُتَيْرَة،', #1
u'قتيرها': u'قَتِيرُهَا', #1
u'قتيرها': u'قَتِيرَهَا', #4
u'قتيريها': u'قَتِيرَيْهَا', #2
u'قتيلى': u'قَتِيلِى', #1
u'قثاما': u'قُثَامًا', #1
u'قثائكم': u'قِثَّائِكُمْ', #1
u'قثم؟': u'قُثْمُ؟', #1
u'قثم': u'قُثَمُ', #12
u'قثم': u'قُثَمَ', #16
u'قثم': u'قُثَمِ', #2
u'قثم،': u'قُثَمَ،', #2
u'قثم': u'قُثَم', #3
u'قثم': u'قُثَمٍ', #4
u'قثم': u'قُثَمْ', #4
u'قثم': u'قثم', #9
u'قثما': u'قَثْمًا', #1
u'قثما': u'قُثَمًا', #3
u'قثنازهير': u'قثنازُهَيْرُ', #1
u'قجه': u'قجه', #1
u'قحافةأن': u'قُحَافَةَأَنْ', #1
u'قحدم': u'قَحْدَمٍ', #2
u'قحذم': u'قحذم', #1
u'قحذم': u'قَحْذَمٍ', #1
u'قحذم،': u'قَحْذَمٍ،', #1
u'قحز': u'قَحَزَ', #1
u'قحزانا': u'قَحَزَانًا', #1
u'قحزم': u'قَحْزَمٍ', #2
u'قحطبة': u'قُحْطَبَةَ', #1
u'قحطبة،': u'قُحْطَبَةَ،', #1
u'قحطبة،': u'قُحْطُبَةَ،', #1
u'قحطبة،': u'قحطبة،', #2
u'قحطبة،': u'قَحْطَبَةَ،', #26
u'قحطبة': u'قَحْطَبَةَ', #6
u'قحطم': u'قَحْطَمٍ', #1
u'قحمة': u'قُحْمَةٌ', #1
u'قحمة': u'قُحْمَةٍ', #1
u'قحوط': u'قُحُوطَ', #4
u'قحيف': u'قحيف', #1
u'قدحة': u'قَدْحَةٍ', #1
u'قدخرج': u'قَدْخَرَجَ', #1
u'قدرعفو': u'قدرعفو', #1
u'قدع': u'قدع', #1
u'قدع': u'قَدَعَ', #1
u'قدعا': u'قَدَعَا', #1
u'قدعا': u'قَدَعًا', #2
u'قدغ': u'قَدغ', #1
u'قدف': u'قَدَفَ', #1
u'قدف': u'قَدْفٍ', #1
u'قدف': u'قَدْفَ', #1
u'قدف': u'قُدِفَ', #1
u'قدفا': u'قَدَفَا', #1
u'قدفه': u'قَدْفِهِ', #1
u'قدفوا': u'قَدَفُوا', #1
u'قدلعن': u'قَدْلَعَنْ', #1
u'قدماى': u'قَدَمَاىَ', #2
u'قدمنى': u'قَدِّمْنِى', #3
u'قدمونى': u'قَدِّمُونِى', #4
u'قدميته': u'قِدَمِيَّتُهُ', #1
u'قدميهوالوجه': u'قَدَمَيْهِوَالْوَجْهُ', #1
u'قدنفعني': u'قَدْنَفَعَنِي', #1
u'قدوطئت': u'قَدْوَطِئْتُ', #1
u'قديدة': u'قَدِيدَةً', #1
u'قديديمة': u'قُدَيْدِيمَةُ', #1
u'قذاء': u'قَذَاءً', #1
u'قذرنى': u'قَذَرَنِى', #1
u'قذرنى': u'قَذِرَنِى', #2
u'قذفان': u'قَذْفَانِ', #9
u'قذفنى': u'قَذَفَنِى', #1
u'قذفين': u'قَذْفَيْنِ', #2
u'قذقت': u'قذقت', #1
u'قرء': u'قُرْءً', #4
u'قرءاته': u'قرءاته', #1
u'قرءان': u'قَرْءَانِ', #1
u'قرءان': u'قُرْءَانٍ', #1
u'قرءان': u'قُرْءَانَ', #2
u'قرءان': u'قُرْءَانِ', #37
u'قرءانا': u'قُرْءَانًا', #4
u'قرءانه': u'قُرْءَانَهُ', #1
u'قرءوا': u'قَرَءُوا', #51
u'قرءوه': u'قَرَءُوهُ', #6
u'قرءوها': u'قَرَءُوهَا', #5
u'قراءةالقرآن': u'قِرَاءَةَالْقُرْآنِ', #1
u'قراءةالقرآن': u'قِرَاءَةُالْقُرْآنِ', #1
u'قراءتى': u'قِرَاءَتِى', #1
u'قرابتى': u'قَرَابَتِى', #5
u'قرابغا': u'قَرَابَغَا', #1
u'قرأبه': u'قَرَأَبِهِ', #1
u'قرأتيه': u'قَرَأْتِيهِ', #4
u'قراثيم': u'قَرَاثِيمَ', #1
u'قراحصاري': u'قراحصاري', #1
u'قراخاني': u'قَرَاخَانِيٍّ', #2
u'قراد،': u'قُرَادً،', #1
u'قراريب': u'قَرَارِيبُ', #1
u'قراسنقر': u'قَرَاسُنْقُر', #3
u'قراسنقر': u'قَرَاسُنْقُرَ', #4
u'قراسيات': u'قراسيات', #2
u'قراطين': u'قِرَاطَيْنِ', #1
u'قراف': u'قِرَافٍ', #2
u'قرافا': u'قِرَافًا', #1
u'قرافة': u'قَرَافَةِ', #3
u'قرافة': u'قَرَافَةُ', #4
u'قراقر': u'قَرَاقِرَ', #1
u'قراقري': u'قَرَاقِرِي', #1
u'قرال': u'قرال', #1
u'قرام': u'قِرَامَ', #1
u'قرام': u'قِرَامٌ', #19
u'قرام': u'قِرَامِ', #2
u'قرام': u'قِرَامُ', #3
u'قراما': u'قِرَامًا', #9
u'قرامك،': u'قِرَامَكِ،', #1
u'قرامك': u'قِرَامَكِ', #3
u'قران': u'قِرَانً', #1
u'قرأوا': u'قرأوا', #2
u'قرأوا': u'قَرَأُوا', #2
u'قرأوه': u'قَرَأُوهُ', #1
u'قرائته': u'قرائته', #1
u'قرأين': u'قُرْأَيْنِ', #53
u'قربائه': u'قُرَبَائِهِ', #1
u'قربزان،': u'قُرْبَزانُ،', #1
u'قربزان': u'قُرْبُزَانَ', #1
u'قربزان،': u'قُرْبَزَانَ،', #1
u'قربزان،': u'قربزان،', #2
u'قربزان': u'قُرْبُزَانُ', #2
u'قربزان،': u'قُرْبَزَانُ،', #3
u'قربزان،': u'قُرْبُزَانَ،', #4
u'قربزان،': u'قُرْبُزَانُ،', #8
u'قربوس': u'قَرْبُوسٌ', #1
u'قربوس': u'قَرْبُوسَ', #1
u'قربوس': u'قَرْبُوسِ', #3
u'قربوسة': u'قَرَبُوسَةٍ', #1
u'قربوسه': u'قَرَبُوسَهُ', #1
u'قربوسه': u'قَرَبُوسِهِ', #2
u'قربوسها': u'قربوسها', #1
u'قرثع': u'قرثع', #1
u'قرثع،': u'قرثع،', #1
u'قرثع': u'قَرْثَعٍ', #5
u'قرثع،': u'قَرْثَعٍ،', #5
u'قردد': u'قَرْدَدٍ', #1
u'قردد': u'قَرْدَدٌ', #2
u'قردد': u'قَرْدَدِ', #3
u'قردم': u'قَرْدَمُ', #2
u'قرزل': u'قُرْزَلٍ', #1
u'قرزل': u'قُرْزُلٌ', #2
u'قرزل': u'قُرْزل', #3
u'قرزل': u'قُرْزُلٍ', #3
u'قرشى': u'قُرَشِىٍّ', #1
u'قرشى': u'قُرَشِىٌّ', #2
u'قرصات': u'قُرُصَاتٍ', #1
u'قرصافة': u'قِرْصافة', #2
u'قرصافة': u'قرصافة', #8
u'قرصافة': u'قِرْصَافَةَ', #9
u'قرطاجنة،': u'قُرْطاجَنة،', #1
u'قرطاجنة،': u'قُرْطَاجَنَّةَ،', #1
u'قرطاجنة': u'قَرْطَاجَنّةَ', #2
u'قرطاجنة': u'قَرْطَاجَنَّةُ', #3
u'قرطاجنة': u'قَرْطَاجَنَّة', #4
u'قرطال': u'قِرْطَالٌ', #1
u'قرطالا': u'قُرْطَالًا', #1
u'قرطالة': u'قِرْطَالَةٍ', #1
u'قرطبان': u'قَرْطَبَانَ', #1
u'قرطبان': u'قَرْطِبَانِ', #1
u'قرطبان': u'قْرْطُبَانُ', #1
u'قرطبان': u'قَرْطَبَانُ', #16
u'قرطبان': u'قَرْطَبَانٌ', #2
u'قرطبان': u'قَرْطَبَانِ', #8
u'قرطة': u'قرطة', #1
u'قرطة': u'قِرَطَةٌ', #1
u'قرطة': u'قُرَطَةُ', #2
u'قرطعب': u'قرطعب', #1
u'قرطعب': u'قِرْطَعْبٍ', #2
u'قرطق': u'قُرْطَقٌ', #1
u'قرطم': u'قُرْطُمٍ', #2
u'قرطما': u'قُرْطُمًا', #1
u'قرظا': u'قَرَظًا', #4
u'قرظة': u'قَرَظَة', #1
u'قرظة': u'قُرَظَةُ', #1
u'قرظة': u'قَرَظَةَ', #33
u'قرظة': u'قَرَظَةُ', #8
u'قرظة،': u'قَرَظَةَ،', #8
u'قرغتم': u'قَرّغْتُمْ', #1
u'قرقبي': u'قُرْقُبِيٍّ', #1
u'قرقفا': u'قَرْقَفَا', #1
u'قرقل': u'قَرْقَلٍ', #1
u'قرقوب،': u'قُرْقُوبٍ،', #1
u'قرقوب': u'قَرْقُوبَ', #2
u'قرقوب': u'قُرْقُوبَ', #2
u'قرقوب': u'قُرْقُوبٍ', #9
u'قرقور': u'قُرْقُورٍ', #5
u'قرقورا': u'قُرْقُورًا', #2
u'قرقول': u'قُرْقُول', #1
u'قرقول': u'قُرْقُولٍ', #7
u'قرقيسا': u'قِرْقِيسًا', #1
u'قرقيسيا': u'قَرْقِيسَيَا', #1
u'قرقيسياء،': u'قَرْقِيسْياء،', #1
u'قرقيسياء': u'قَرْقِيسْيَاءَ', #1
u'قرقيسياء': u'قَرْقِيسِيَاءَ', #2
u'قرقيسياء،': u'قَرْقِيسِيَاءَ،', #2
u'قرم،': u'قرم،', #1
u'قرم': u'قَرَمٌ', #1
u'قرم': u'قَرِمٌ', #1
u'قرم': u'قُرْمٌ', #1
u'قرم': u'قُرْمٍ', #1
u'قرم': u'قِرْمُ', #1
u'قرم،': u'قَرْم،', #1
u'قرم،': u'قُرْمٍ،', #1
u'قرم،': u'قِرْمٍ،', #1
u'قرم': u'قرم', #2
u'قرم': u'قَرْمٍ', #21
u'قرم': u'قَرَمَ', #3
u'قرم': u'قَرِمَ', #3
u'قرم،': u'قَرْمٍ،', #8
u'قرم': u'قَرْمٌ', #9
u'قرما': u'قَرْمًا', #2
u'قرمان': u'قَرْمَانُ', #3
u'قرمت': u'قَرِمْت', #1
u'قرمنا': u'قَرِمنا', #1
u'قرمنا': u'قَرَمْنَا', #1
u'قرمنا': u'قَرِمْنَا', #1
u'قرمهم': u'قَرَمِهِمْ', #1
u'قرمهم': u'قُرُمِهِمْ', #1
u'قرمود': u'قَرْمُودٌ', #2
u'قرمود': u'قُرْمُودٍ', #2
u'قرمود': u'قَرْمُودٍ', #5
u'قرنفول': u'قرنفول', #1
u'قرنفول': u'قُرُنْفُولٌ', #1
u'قرنقة': u'قَرْنَقَةَ', #1
u'قرنى': u'قَرْنِى', #10
u'قرنى': u'قَرْنَىْ', #14
u'قرنى': u'قَرْنَىِ', #3
u'قرؤا': u'قَرَؤُا', #1
u'قرواش': u'قِرْوَاشٍ', #1
u'قرواش': u'قِرْوَاشُ', #1
u'قروحات': u'قُرُوحَاتٍ', #1
u'قروم': u'قُرُومٍ', #1
u'قريافإذا': u'قَرَيَافَإِذَا', #1
u'قريتى': u'قَرْيَتِى', #1
u'قريرة': u'قَرِيرَةً', #1
u'قريرة': u'قَرِيرَةٌ', #1
u'قريرة': u'قَرِيرَةَ', #1
u'قريرة': u'قَرِيرَةُ', #1
u'قريش': u'قُرَيْشً', #1
u'قريشة': u'قَرِيشَةً', #2
u'قريشي،': u'قُرَيِشيٌّ،', #1
u'قريشي': u'قُرَيْشِيٌّ', #4
u'قريشيا': u'قُرَيْشِيًّا', #3
u'قريشية': u'قُرَيْشِيَّةٍ', #1
u'قريضة': u'قُرَيْضَةُ', #1
u'قريط': u'قريط', #1
u'قريط': u'قُرَيْطِ', #1
u'قريط': u'قُرَيْطٍ', #3
u'قريظ': u'قُرَيْظٍ', #1
u'قريظة،': u'قريظة،', #1
u'قريظة،': u'قُريظة،', #1
u'قريظة': u'قَرَيْظَةَ', #1
u'قريظة': u'قُرَيْظَةِ', #1
u'قريظة،': u'قَرَيْظَةَ،', #1
u'قريظة؟': u'قُرَيْظَةَ؟', #1
u'قريظة،': u'قُرَيْظة،', #10
u'قريظة': u'قُرَيْظَة', #15
u'قريظة،': u'قُرَيْظَةَ،', #28
u'قريظة': u'قُريظة', #3
u'قريظة': u'قُرَيظة', #3
u'قريظة': u'قريظة', #4
u'قريظة': u'قُرَيْظَةُ', #43
u'قريظة': u'قُرَيْظَةَ', #680
u'قريظة': u'قُرَيْظة', #8
u'قريع': u'قَرِيعُ', #1
u'قريع': u'قُرَيْعٍ', #2
u'قريعكم': u'قَرِيعَكُمْ', #1
u'قريوس': u'قُرْيُوسُ', #1
u'قريوس': u'قِرْيُوسُ', #1
u'قريوس': u'قِرْيُوسٌ', #2
u'قريوش': u'قُرْيُوشٍ', #1
u'قريوش': u'قُرْيُوشِ', #1
u'قريوش': u'قِرْيُوشِ', #1
u'قريوش': u'قُرْيُوش', #2
u'قريوش': u'قِرْيُوشٍ', #2
u'قزاز': u'قَزَازُ', #1
u'قزاز': u'قَزَّازٌ', #1
u'قزاز': u'قَزَّازٍ', #2
u'قزبر': u'قزبر', #1
u'قزبيا': u'قزبيا', #1
u'قزدير': u'قَزْدِيرٍ', #1
u'قزع': u'قَزَع', #1
u'قزع': u'قَزَعٌ', #1
u'قزع': u'قَزْعِ', #1
u'قزع': u'قَزَعِ', #2
u'قزعة،': u'قزعة،', #1
u'قزعة': u'قَزَعَةَ', #100
u'قزعة': u'قَزْعَةَ', #11
u'قزعة': u'قَزْعَةً', #2
u'قزعة،': u'قَزَعَةً،', #2
u'قزعة،': u'قَزَعَةٌ،', #2
u'قزعة،': u'قَزْعَةَ،', #2
u'قزعة': u'قَزَعَةُ', #20
u'قزعة،': u'قَزَعَةَ،', #25
u'قزعة': u'قَزَعَةٍ', #3
u'قزعة،': u'قَزَعَةُ،', #3
u'قزعة': u'قَزَعَة', #4
u'قزعة': u'قَزَعَةٌ', #4
u'قزعة': u'قَزْعَةُ', #4
u'قزعة': u'قَزَعَةً', #9
u'قزعه': u'قَزَعَهْ', #4
u'قزلباش': u'قزلباش', #1
u'قزلباش': u'قَزِلْبَاشَ', #1
u'قزيح': u'قَزِيحٌ', #1
u'قزيمي': u'قزيمي', #1
u'قساس': u'قُسَاس', #3
u'قساقس': u'قَسَاقِسِ', #1
u'قسامان': u'قَسَّامَانِ', #1
u'قسبا': u'قَسْبًا', #4
u'قسرين': u'قَسْرِينَ', #1
u'قسطلاني': u'قَسْطَلَّانِيٌّ', #12
u'قسطنطين': u'قُسْطَنْطِينُ', #1
u'قسطنطين،': u'قُسْطَنْطِينَ،', #1
u'قسطنطين': u'قُسْطَنْطِينَ', #3
u'قسطنطينة': u'قُسْطَنْطِينَةُ', #1
u'قسقاسته': u'قَسْقَاسَتَهُ', #1
u'قسقاسته': u'قِسْقَاسَتَهُ', #1
u'قسمى': u'قَسْمِى', #2
u'قسميل': u'قَسْمِيلَ', #1
u'قسميل': u'قَسْمِيلِ', #1
u'قسميل': u'قِسْمِيلِ', #3
u'قسور': u'قَسْوَرٍ', #1
u'قسيط': u'قُسَيْطٍ', #142
u'قسيط': u'قسيط', #2
u'قسيط،': u'قسيط،', #2
u'قسيط،': u'قُسَيْطٍ،', #33
u'قشاش': u'قُشَاشٌ', #1
u'قشاشاريين': u'قَشَاشَارِيَيْنِ', #1
u'قشام': u'قُشَامٌ', #1
u'قشام،': u'قُشَامٌ،', #1
u'قشبنى': u'قشبنى', #1
u'قشبنى': u'قَشَبَنِى', #2
u'قشطة': u'قِشْطَةَ', #2
u'قشعر': u'قشعر', #1
u'قشعر': u'قَشْعَرَ', #1
u'قشعم': u'قَشْعَمٍ', #1
u'قشعم': u'قَشْعَمِ', #2
u'قشغر': u'قَشْغَرَ', #1
u'قشفتان': u'قَشْفَتَانِ', #1
u'قشمرد': u'قَشْمَرْدُ', #1
u'قشمش': u'قشمش', #1
u'قشير': u'قُشَيْر', #1
u'قشير': u'قُشَيْرٌ', #1
u'قشير،': u'قُشُيْرٍ،', #1
u'قشير': u'قُشَيْرِ', #10
u'قشير': u'قشير', #4
u'قشير،': u'قُشَيْرٍ،', #5
u'قشير': u'قُشَيْرٍ', #61
u'قشيف': u'قَشِيفُ', #1
u'قشيل': u'قُشيل', #1
u'قصاران': u'قَصَّارَانِ', #6
u'قصارت': u'قصارت', #1
u'قصارون': u'قَصَّارُونَ', #2
u'قصارين': u'قَصَّارِينَ', #6
u'قصارين': u'قَصَّارَيْنِ', #7
u'قصباء': u'قَصْبَاءُ', #1
u'قصدإلى': u'قَصَدَإِلَى', #1
u'قصدكمو': u'قَصْدَكُمُو', #1
u'قصديته': u'قَصْدِيَّتُهُ', #2
u'قصدين': u'قَصْدَيْنِ', #1
u'قصراتها': u'قَصِرَاتُهَا', #1
u'قصراتها': u'قَصِرَاتِهَا', #1
u'قصراتها': u'قَصَرَاتُهَا', #2
u'قصرتبه': u'قَصَرْتَبِهِ', #1
u'قصطب': u'قصطب', #1
u'قصواء': u'قَصْوَاء', #1
u'قصواء': u'قَصْوَاءَ', #2
u'قصود': u'قُصُودٍ', #1
u'قصودها': u'قُصُودُهَا', #1
u'قصى': u'قُصَىٌّ', #1
u'قصى': u'قُصَىِّ', #2
u'قصى': u'قُصَىٍّ', #5
u'قصيط': u'قُصَيْطٍ', #1
u'قضاب': u'قَضَّابِ', #1
u'قضاب': u'قَضّابِ', #4
u'قضاعى': u'قُضَاعِىٌّ', #1
u'قضاكها': u'قَضَاكَهَا', #1
u'قضانى': u'قَضَانِى', #1
u'قضاي': u'قَضَايٌ', #3
u'قضاي': u'قَضَايَ', #6
u'قضائى': u'قَضَائِىَ', #1
u'قضائى': u'قَضَائِى', #3
u'قضبة': u'قَضْبَةٍ', #2
u'قضف': u'قَضَفُ', #2
u'قضقاض': u'قَضْقَاضٌ', #1
u'قضوية': u'قَضَوِيَّةً', #1
u'قضوية': u'قَضَوِيَّةٌ', #1
u'قضيء': u'قَضِيءُ', #1
u'قضئ': u'قَضِئ', #1
u'قضىء': u'قَضِىءَ', #2
u'قضيء': u'قَضِيءَ', #4
u'قضيتكه': u'قَضَيْتُكَهُ', #4
u'قضيتكها': u'قَضَيْتُكَهَا', #13
u'قضيتنيه': u'قَضَيْتَنِيهِ', #2
u'قضيفا': u'قَضِيفًا', #1
u'قضيم': u'قَضِيمٍ', #1
u'قضيئة': u'قَضِيئَةٌ', #1
u'قطارميز': u'قطارميز', #1
u'قطام': u'قَطَام', #1
u'قطام': u'قَطَامٍ', #2
u'قطام': u'قَطَامِ', #4
u'قطربل': u'قُطْرَبُّلَ', #1
u'قطرى': u'قَطَرِىٍّ', #4
u'قطريل': u'قِطْرِيلٍ', #1
u'قطز': u'قُطُزَ', #1
u'قطز': u'قُطُزُ', #2
u'قطش': u'قطش', #4
u'قطع': u'قَطْعً', #1
u'قطعات': u'قِطْعَاتٍ', #2
u'قطعنى': u'قَطَعَنِى', #1
u'قطفيير': u'قطفيير', #2
u'قطقطا': u'قَطْقَطًا', #1
u'قطلب': u'قُطْلُبٍ', #1
u'قطلوبغا': u'قُطْلُوبُغَا', #11
u'قطلوبغا': u'قطلوبغا', #4
u'قطلوبغا': u'قُطُلُوبُغَا', #5
u'قطمر': u'قِطَمْرٍ', #1
u'قطمور': u'قطمور', #2
u'قطميرات': u'قِطْمِيرَاتٍ', #1
u'قطنط': u'قطنط', #1
u'قطوانيتان': u'قَطَوَانِيَّتَانِ', #1
u'قطوراء': u'قَطُوَرَاءُ', #1
u'قطوراء': u'قَطُورَاءُ', #2
u'قطوراء': u'قَطُورَاءَ', #4
u'قطوروي': u'قَطُّوَرُوِيَ', #1
u'قطوطاة': u'قَطَوْطَاةٍ', #1
u'قطوناء': u'قَطُونَاءَ', #1
u'قطيب،': u'قُطَيْبٍ،', #1
u'قطيب': u'قُطَيْبٍ', #3
u'قطير': u'قُطَيْرٍ', #1
u'قطيعتى': u'قَطِيعَتِى', #1
u'قطيم': u'قَطِيمُ', #1
u'قعاص': u'قُعَاصِ', #1
u'قعب': u'قَعْبٌ', #1
u'قعب،': u'قَعْبٍ،', #1
u'قعب': u'قَعْبٍ', #3
u'قعبا': u'قَعْبًا', #4
u'قعبان': u'قُعْبَانِ', #1
u'قعبان': u'قَعْبَانِ', #2
u'قعبة': u'قَعْبَةٍ', #1
u'قعبة': u'قُعْبَةٌ', #1
u'قعبة': u'قَعْبَةٌ', #2
u'قعبري': u'قَعْبَرِيٍّ', #1
u'قعدد': u'قُعْدُدٍ', #1
u'قعدد': u'قُعْدُدَ', #1
u'قعدد': u'قعدد', #3
u'قعدد': u'قُعْدُدِ', #4
u'قعددا': u'قُعْدُدَا', #1
u'قعددهن': u'قعددهن', #1
u'قعرة': u'قُعْرَةِ', #1
u'قعساء': u'قَعْسَاءُ', #1
u'قعص': u'قَعْصٌ', #1
u'قعص': u'قُعْصٌ', #1
u'قعص': u'قَعْصَ', #2
u'قعصا': u'قَعْصًا', #6
u'قعضبيا': u'قَعْضَبِيّا', #2
u'قعط': u'قَعَطَ', #2
u'قعطها': u'قَعَطَهَا', #1
u'قعقران': u'قَعْقَرَانَ', #2
u'قعم': u'قعم', #1
u'قعنب': u'قَعْنَبَ', #1
u'قعنب': u'قُعْنُبٍ', #1
u'قعنب،': u'قَعْنَبٌ،', #1
u'قعنب': u'قَعْنَبٍ', #100
u'قعنب،': u'قَعْنَبٍ،', #13
u'قعنب': u'قعنب', #2
u'قعنب': u'قَعْنَبٌ', #3
u'قعنب': u'قَعْنَبُ', #3
u'قعودى': u'قُعُودِى', #1
u'قعور': u'قُعُورٍ', #1
u'قعور': u'قُعُورِ', #1
u'قعورها': u'قُعُورُهَا', #2
u'قعيبة': u'قُعَيْبَةٍ', #1
u'قعيس،': u'قُعَيْسٍ،', #1
u'قعيس': u'قُعَيْسٍ', #16
u'قعيقعان': u'قُعَيْقَعَانَ', #1
u'قعيقعان،': u'قُعَيْقِعَانَ،', #1
u'قعيقعان': u'قُعَيْقِعَان', #2
u'قعيقعان': u'قُعَيْقِعَانَ', #29
u'قعيقعان': u'قُعَيْقِعَانُ', #6
u'قعيل': u'قَعِيلَ', #1
u'قعين': u'قُعَيْنٌ', #1
u'قفا': u'قَفًا', #9
u'قفاء': u'قَفَاءِ', #1
u'قفاعا': u'قُفَّاعًا', #1
u'قفاف': u'قُفَافِ', #1
u'قفاف': u'قَفَّافٌ', #2
u'قفافهم': u'قُفَافِهِمْ', #1
u'قفافهم': u'قِفَافِهِمْ', #1
u'قفاى': u'قَفَاىَ', #1
u'قفد': u'قفد', #1
u'قفدة': u'قَفْدَةً', #1
u'قفدنى': u'قَفَدَنِى', #1
u'قفزان': u'قُفْزَانُ', #1
u'قفزان': u'قُفْزَانَ', #3
u'قفزان': u'قُفْزَانٍ', #4
u'قفزان': u'قُفْزَانِ', #4
u'قفزان': u'قُفْزَانٌ', #7
u'قفزانا': u'قُفْزَانًا', #21
u'قفزانها': u'قُفْزَانِهَا', #22
u'قفزانها': u'قُفْزَانُهَا', #4
u'قفزانها': u'قُفْزَانَهَا', #7
u'قفصة': u'قَفِصَة', #1
u'قفصة': u'قَفِصَةً', #1
u'قفعة': u'قَفْعَةٌ', #1
u'قفعة': u'قَفْعَةً', #4
u'قفعتين': u'قَفْعَتَيْنِ', #1
u'قفير': u'قَفِيرِ', #1
u'قفير': u'قَفِيرٍ', #2
u'قفيرا': u'قَفِيرًا', #2
u'قفيز': u'قُفَيْزٌ', #1
u'قفيز': u'قَفِيزَ', #106
u'قفيز': u'قَفِيزِ', #170
u'قفيز': u'قَفِيزُ', #32
u'قفيز': u'قَفِيزٍ', #403
u'قفيز': u'قَفِيزٌ', #77
u'قفيزا': u'قَفِيزَا', #1
u'قفيزا': u'قَفِيزًا', #360
u'قفيزان': u'قَفِيزَانِ', #6
u'قفيزه': u'قَفِيزَهُ', #1
u'قفيزه': u'قَفِيزِهِ', #4
u'قفيزها': u'قَفِيزُهَا', #2
u'قفيزها': u'قَفِيزَهَا', #4
u'قفيزي': u'قَفِيزَيْ', #11
u'قفيزين': u'قَفِيزَيْنِ', #33
u'قك': u'قك', #1
u'قك': u'قَك', #2
u'قلابة،': u'قِلابةَ،', #1
u'قلابة': u'قِلابَةُ', #1
u'قلابة،': u'قَلابَةَ،', #1
u'قلابة': u'قِلَابَةِ', #1
u'قلابة؟': u'قِلاَبَةَ؟', #1
u'قلابة': u'قِلابَةَ', #111
u'قلابة': u'قلابة', #13
u'قلابة': u'قِلابة', #2
u'قلابة؟': u'قِلابَةَ؟', #2
u'قلابة': u'قَلَابَةَ', #2
u'قلابة،': u'قلابة،', #31
u'قلابة': u'قِلاَبَةَ', #404
u'قلابة،': u'قِلابَةَ،', #435
u'قلابة': u'قِلَابَةَ', #441
u'قلابة': u'قِلَابَةُ', #5
u'قلابة،': u'قِلَابَةَ،', #7
u'قلابة،في': u'قِلابَةَ،فِي', #2
u'قلاس': u'قَلَاسٍ', #1
u'قلاص': u'قِلاَصِ', #1
u'قلاص': u'قِلَاصِ', #3
u'قلاقة': u'قَلَاقَةً', #2
u'قلاقة': u'قَلَاقَةٍ', #4
u'قلاقة': u'قَلَاقَةَ', #5
u'قلاقة': u'قَلَاقَةٌ', #50
u'قلاقته': u'قَلَاقَتُهُ', #1
u'قلامسة': u'قَلَامِسَةٌ', #1
u'قلانص': u'قَلَانِصَ', #1
u'قلاوون': u'قَلَاوُونَ', #7
u'قلائص': u'قَلائِصَ', #1
u'قلائص': u'قَلائِصُ', #1
u'قلائص': u'قَلائِصِ', #1
u'قلائص': u'قَلَائِص', #1
u'قلائص': u'قَلَائِصُ', #1
u'قلائص': u'قَلاَئِصُ', #1
u'قلائص': u'قَلَائِصَ', #15
u'قلائص،': u'قَلَائِصَ،', #2
u'قلائص': u'قَلَائِصِ', #5
u'قلائصك': u'قَلَائِصَك', #1
u'قلائصك': u'قَلَائِصِك', #1
u'قلائصك': u'قَلائِصَكَ', #2
u'قلائصك': u'قَلاَئِصَكَ', #2
u'قلائصنا': u'قَلَائِصَنَا', #2
u'قلائمكم': u'قَلَائِمَكُمْ', #1
u'قلائين': u'قَلَّائِينَ', #3
u'قلاية': u'قَلاَّيَةً', #1
u'قلاية': u'قَلَّايَةً', #1
u'قلاية': u'قِلَّايَةً', #4
u'قلبى': u'قَلْبِىَ', #1
u'قلبى': u'قَلْبِى', #46
u'قلتبان': u'قَلْتَبَانٍ', #1
u'قلتبان': u'قَلْتَبَانُ', #1
u'قلتبان': u'قلتبان', #2
u'قلتبان': u'قَلْتَبَانَ', #2
u'قلتة': u'قَلْتُةُ', #1
u'قلتمو': u'قُلْتُمُو', #1
u'قلح': u'قَلَحٍ', #1
u'قلح': u'قُلْحٍ', #1
u'قلح': u'قُلْحِ', #1
u'قلح': u'قَلَحِ', #2
u'قلحا؟': u'قُلْحًا؟', #1
u'قلحا': u'قُلْحًا', #9
u'قلدتكه': u'قَلَّدْتُكَهُ', #1
u'قلدنيه': u'قَلَّدَنِيهِ', #3
u'قلشاني': u'قَلْشَانِيٌّ', #1
u'قلفطة': u'قَلْفَطَةٍ', #1
u'قلفطته': u'قَلْفَطَتِهِ', #2
u'قلقط،': u'قَلْقَطٌّ،', #1
u'قلنباة': u'قَلَنْبَاةٌ', #1
u'قلنساة': u'قَلَنْسَاةٌ', #1
u'قلنسية': u'قَلَنْسِيَةٍ', #1
u'قلنسية': u'قُلْنُسِيَةٌ', #1
u'قلنسية': u'قُلَنْسِيَةٍ', #2
u'قلنيات': u'قلنيات', #1
u'قلهي': u'قَلَهّي', #1
u'قلهى': u'قَلَهَى', #1
u'قليب': u'قَلِيبٌ', #1
u'قليب': u'قَلِيبَ', #1
u'قليب': u'قَلِيب', #2
u'قليب': u'قَلِيبُ', #3
u'قليب': u'قَلِيبِ', #32
u'قليب': u'قَلِيبٍ', #34
u'قليب،': u'قَلِيبٍ،', #4
u'قليد': u'قُلَيْدٍ', #2
u'قليس': u'قَلِيس', #2
u'قليس': u'قَلِيسٍ', #2
u'قليسة': u'قُلَّيْسَة', #1
u'قليقوس': u'قليقوس', #1
u'قليلون': u'قَلِيلُونَ', #14
u'قليما': u'قُلَيْمَا', #1
u'قليوب': u'قَلْيُوبَ', #2
u'قليوبي': u'قليوبي', #1
u'قليوبي': u'قَلْيُوبِيٌّ', #88
u'قما': u'قما', #1
u'قما': u'قَمًّا', #2
u'قماحد': u'قَمَاحِدُ', #1
u'قمادين': u'قَمَادِينَ', #1
u'قمادين': u'قَمّادِينَ', #2
u'قمال': u'قَمَالٌ', #1
u'قمدا': u'قَمْدًا', #1
u'قمطة': u'قَمّطَةَ', #1
u'قمطة،': u'قَمَطَةَ،', #1
u'قمقامة': u'قُمْقَامَةٌ', #1
u'قموح': u'قُمُوحَ', #1
u'قموع': u'قُمُوعِ', #1
u'قمولي': u'قَمُولِيٍّ', #1
u'قمئة': u'قَمِئة', #1
u'قمئة،': u'قَمِئَةَ،', #1
u'قمئة': u'قَمِئَةَ', #19
u'قميته': u'قَمَيْته', #1
u'قميته': u'قَمَيْتَهُ', #1
u'قمير،': u'قَمِيرُ،', #1
u'قمير': u'قُمَيْرِ', #1
u'قمير': u'قُمَيْرٌ', #2
u'قمير': u'قُمَيْرٍ', #2
u'قمير': u'قُمَيْرُ', #3
u'قمير': u'قَمِيرَ', #9
u'قميرا': u'قُمَيْرًا', #1
u'قميشع': u'قَمَيْشَعِ', #1
u'قنأ': u'قَنَأَ', #2
u'قناء': u'قناء', #1
u'قنابلا': u'قَنَابِلًا', #2
u'قناع': u'قِنَاعً', #1
u'قنافة': u'قُنَافَةَ', #1
u'قنالي': u'قَنَالِي', #4
u'قنايات': u'قَنَايَاتُ', #1
u'قنبر': u'قَنْبر', #1
u'قنبر': u'قَنْبَرِ', #1
u'قنبر،': u'قَنْبَرُ،', #1
u'قنبر': u'قَنْبَرٍ', #14
u'قنبر': u'قَنْبَرُ', #3
u'قنبر': u'قَنْبَرٌ', #6
u'قنبرا': u'قُنْبُرَا', #1
u'قنبرا': u'قَنْبَرًا', #8
u'قنبعة': u'قُنْبُعَةٌ', #1
u'قنج': u'قنج', #1
u'قند': u'قَنْدَ', #1
u'قندابل': u'قَنْدَابِلَ', #1
u'قندابيل،': u'قَنْدابيل،', #1
u'قندابيل،': u'قِنْدَابِيلَ،', #1
u'قنداقا': u'قُنْدَاقًا', #1
u'قندز': u'قندز', #2
u'قندها': u'قَنْدِهَا', #1
u'قنزبور،': u'قَنَّزْبُورَ،', #1
u'قنسرين': u'قِنَّسْرِين', #1
u'قنسرين،': u'قِنَّسْرِينَ،', #1
u'قنسرين': u'قِنَّسْرِينَ', #4
u'قنصة': u'قَنْصَةَ', #1
u'قنطورا': u'قَنْطُورَا', #1
u'قنطوراء': u'قَنْطُورَاءَ', #3
u'قنفد': u'قُنْفُدٍ', #1
u'قنفد': u'قُنْفُدِ', #2
u'قنلي': u'قُنْلِي', #4
u'قنلي': u'قنلي', #9
u'قنوء': u'قُنُوءٌ', #1
u'قنوءا': u'قُنُوءًا', #1
u'قنواء': u'قَنْوَاءُ', #5
u'قنواتيا': u'قَنَوَاتِيًّا', #1
u'قنيع': u'قُنَيْع', #1
u'قنيع': u'قُنَيْعٍ', #2
u'قنيع': u'قُنَيْعِ', #2
u'قهارمته': u'قَهَارِمَتِهِ', #1
u'قهد': u'قَهْدٌ', #1
u'قهد': u'قَهْدٍ', #19
u'قهد،': u'قهد،', #2
u'قهد': u'قَهْد', #2
u'قهد،': u'قَهْدٍ،', #2
u'قهد': u'قهد', #3
u'قهران': u'قَهْرَانِ', #1
u'قهرمان': u'قَهْرَمَانٍ', #1
u'قهرمان': u'قَهْرَمَانٌ', #2
u'قهرمان': u'قَهْرَمَانَ', #2
u'قهرمان': u'قَهْرَمَانُ', #2
u'قهرمانا': u'قَهْرَمَانًا', #2
u'قهرمانه': u'قَهْرمَانَهُ', #1
u'قهريته': u'قَهْرِيَّتِهِ', #1
u'قهزاذ': u'قُهْزَاذَ', #18
u'قهستان': u'قُهِسْتَانَ', #1
u'قهستاني': u'قُهُسْتَانِيٍّ', #1
u'قهستاني': u'قُهُسْتَانِيِّ', #1
u'قهستاني': u'قُهُسْتَانِيٌّ', #464
u'قهستاني': u'قُهُسْتَانِيُّ', #47
u'قهستاني': u'قُهُسْتَانِيٌ', #51
u'قهطم': u'قهطم', #1
u'قهطم': u'قِهْطِمُ', #2
u'قهقرى': u'قهقرى', #1
u'قهقرى': u'قَهْقَرَى', #8
u'قهقريا': u'قَهْقَرِيًّا', #2
u'قهيد': u'قهيد', #1
u'قهيد': u'قُهَيْدِ', #4
u'قهيد': u'قُهَيْدٍ', #5
u'قواحذ': u'قَوَاحِذِ', #2
u'قواحز': u'قَوَاحِزِ', #1
u'قواحزه': u'قَواحِزُهُ', #1
u'قواحزه': u'قَوَاحِزُهُ', #2
u'قوادح': u'قَوَادِحِ', #10
u'قوادحها': u'قَوَادِحِهَا', #1
u'قوادحهما': u'قَوَادِحِهِمَا', #1
u'قوادس': u'قَوَادِسَ', #1
u'قوارة': u'قُوَارَةُ', #1
u'قوارة': u'قُوَارَةٍ', #2
u'قواريرا': u'قَوَارِيرًا', #1
u'قواقلا': u'قَوَاقِلًا', #1
u'قواميته': u'قِوَامِيَّتُهُ', #1
u'قواميته': u'قِوَامِيَّتِهِ', #2
u'قوانس': u'قَوَانِسَ', #1
u'قوانس': u'قَوَانِسُ', #2
u'قوانسها': u'قَوَانِسُهَا', #2
u'قوب': u'قُوبٍ', #1
u'قوبا': u'قُوبًا', #1
u'قوبها،': u'قوبها،', #1
u'قوتة': u'قوتة', #1
u'قوتى': u'قُوتِى', #1
u'قوداء': u'قَوْداءُ', #1
u'قوداء': u'قَوْدَاءُ', #3
u'قوذ': u'قُوذٍ', #1
u'قوذر،': u'قَوْذَرٍ،', #1
u'قوذر،': u'قُوذَرَ،', #2
u'قوراء': u'قَوْرَاءَ', #1
u'قوز': u'قَوْزُ', #1
u'قوز': u'قَوْزٌ', #3
u'قوز': u'قَوْزِ', #3
u'قوسرة': u'قَوْسَرَةٍ', #2
u'قوسى؟': u'قَوْسِى؟', #1
u'قوسى': u'قَوْسِى', #2
u'قوش': u'قَوشَ', #1
u'قوصرة،': u'قَوْصرة،', #1
u'قوصرة': u'قَوْصَرَةَ', #1
u'قوصرة': u'قَوْصَرَّةٌ', #1
u'قوصرة': u'قَوْصَرَّةَ', #2
u'قوصرة': u'قَوْصَرَّةُ', #2
u'قوصرة': u'قَوْصَرَّةً', #3
u'قوصرة': u'قَوْصَرَّةٍ', #48
u'قوصرة': u'قَوْصَرَةٍ', #7
u'قوصرته': u'قَوْصَرَتِهِ', #1
u'قوصرته': u'قَوْصَرَّتِهِ', #3
u'قوصرتين': u'قَوْصَرَّتَيْنِ', #2
u'قوصره': u'قَوْصَرَّهْ', #5
u'قوصي': u'قُوصِيٌّ', #1
u'قوطة': u'قُوطَةَ', #1
u'قوطة': u'قَوْطَةٍ', #1
u'قوقعت': u'قوقعت', #1
u'قوقل': u'قَوْقَلٌ', #1
u'قوقل': u'قَوْقَلَ', #1
u'قوقل': u'قَوْقَلُ', #1
u'قوقل': u'قَوْقَلٍ', #19
u'قوقل': u'قوقل', #2
u'قوقل': u'قَوْقَلِ', #2
u'قوقل،': u'قَوْقَلٍ،', #2
u'قوقل': u'قَوْقِلْ', #4
u'قوقلا': u'قَوْقَلًا', #2
u'قولا': u'قَوْلاًًًًًًًًًٌ', #1
u'قولابن': u'قَوْلِابْنِ', #2
u'قولاق': u'قولاق', #1
u'قولنج': u'قُولُنْجُ', #1
u'قولنج': u'قُولَنْجُ', #7
u'قولنجا': u'قُولِنْجَا', #1
u'قولهفذلك': u'قَوْلِهِفَذَلِكَ', #1
u'قولهمما': u'قَوْلُهُمِمَّا', #1
u'قولهوهذا': u'قولهوَهَذَا', #1
u'قولى': u'قَوْلِى', #10
u'قولى': u'قُولِى', #17
u'قولى': u'قَوْلَىِ', #2
u'قومتى': u'قَوْمَتِى', #2
u'قومس': u'قُومِس', #1
u'قومس،': u'قُومِس،', #1
u'قومهموالوجه': u'قَوْمِهِمْوَالْوَجْهُ', #1
u'قومي11942id': u'قومي11942id', #1
u'قوميبني': u'قَوْمِيبَنِي', #1
u'قوندز': u'قوندز', #1
u'قونس': u'قَوْنَسٍ', #1
u'قوهستان': u'قُوهِسْتَانَ', #3
u'قوهي': u'قُوهِيٌّ', #3
u'قوهي': u'قُوهِيٍّ', #6
u'قوهيا': u'قُوهِيًّا', #3
u'قوهيار': u'قُوهْيَارَ', #5
u'قوهيار': u'قُوهِيَارَ', #9
u'قوهية': u'قُوهِيَّةٌ', #2
u'قويد': u'قُوَيْدٍ', #1
u'قويدر': u'قُوَيْدِرٌ', #1
u'قويرب': u'قُوَيْرِبٍ', #1
u'قويرب': u'قُوَيْرِبِ', #1
u'قويسني': u'قُوَيْسَنِيٍّ', #1
u'قويسني': u'قُوَيْسَنِيٌّ', #26
u'قويسني': u'قُوَيْسَنِيٌ', #4
u'قويلة': u'قُوَيْلَةٍ', #3
u'قويلة': u'قُوَيْلَةٌ', #5
u'قى': u'قَى', #1
u'قى': u'قِىٍّ', #3
u'قىء': u'قَىْءٌ', #1
u'قياريط': u'قَيَارِيط', #1
u'قياسات': u'قِيَاسَاتٍ', #2
u'قياساته': u'قِيَاسَاتُهُ', #1
u'قياساته': u'قِيَاسَاتِهِ', #1
u'قياساتها': u'قِيَاسَاتِهَا', #1
u'قياساتها': u'قِيَاسَاتُهَا', #3
u'قياطين': u'قَيَاطِينِ', #1
u'قيامت': u'قيامت', #5
u'قيامهإلى': u'قِيَامِهِإِلَى', #1
u'قيآن': u'قَيْآنِ', #2
u'قيانوس': u'قِيَانُوسٌ', #1
u'قيبلة': u'قَيْبَلَةَ', #1
u'قيتة': u'قِيتَةِ', #1
u'قيتة': u'قِيتَةً', #2
u'قيدر': u'قيدر', #1
u'قيدى': u'قَيِّدِى', #1
u'قيذار': u'قِيذَارَ', #1
u'قيذر': u'قَيْذَرَ', #6
u'قيذما': u'قَيْذُما', #1
u'قيسري': u'قَيْسَرِيٌّ', #1
u'قيسعرضت': u'قَيْسٍعَرَضْتُ', #1
u'قيسيين': u'قَيْسِيَّيْنِ', #1
u'قيطونا': u'قَيْطُونًا', #1
u'قيظى': u'قَيْظِىٍّ', #2
u'قيعة': u'قِيعَةٌ', #1
u'قيقب': u'قَيْقَبٍ', #1
u'قيقة': u'قِيقَةٍ', #1
u'قيقعان': u'قَيْقَعَانُ', #1
u'قيلة': u'قيلة', #1
u'قيلة': u'قِيلة', #1
u'قيلة': u'قِيلَةً', #1
u'قيلة': u'قِيلَةَ', #1
u'قيلة': u'قِيلَةُ', #1
u'قيلة،': u'قِيَلَةَ،', #1
u'قيلة': u'قَيْلَةُ', #10
u'قيلة': u'قَيْلَة', #2
u'قيلة': u'قَيْلَةَ', #27
u'قيلقوس': u'قيلقوس', #1
u'قيماء': u'قُيَمَاءِ', #1
u'قيماز': u'قيماز', #1
u'قيمانا': u'قِيمَانًا', #1
u'قيمؤن': u'قيمؤن', #1
u'قينقاع،': u'قَيْنُقَاعٍ،', #1
u'قينقاع،': u'قَيْنُقَاعَ،', #10
u'قينقاع': u'قَيْنُقَاعِ', #20
u'قينقاع': u'قَيْنُقَاعُ', #5
u'قينقاع': u'قَيْنُقَاع', #9
u'قينقاع': u'قَيْنُقَاعٍ', #9
u'قينقاع': u'قَيْنُقَاعَ', #90
u'قيوداته': u'قُيُودَاتِهِ', #1
u'قيول': u'قُيُولٍ', #1
u'قيول،': u'قُيُولٍ،', #1
u'قيون': u'قُيُونُ', #4
u'قيؤه': u'قَيْؤُهُ', #2
u'كا': u'كَا', #10
u'كآ': u'كَآ', #2
u'كا': u'كا', #53
u'كابا': u'كَابًّا', #1
u'كإبار': u'كَإِبَارِ', #1
u'كإبار': u'كَإِبَارٍ', #7
u'كإباق': u'كَإِبَاقٍ', #10
u'كإباق': u'كَإِبَاقِ', #17
u'كإباقه': u'كَإِبَاقِهِ', #2
u'كأبانين': u'كَأَبَانَيْنِ', #1
u'كإبايتهم': u'كَإِبَايَتِهِمْ', #1
u'كابتدعه': u'كَابْتَدَعَهُ', #1
u'كأبتدئ': u'كَأَبْتَدِئُ', #3
u'كابتع': u'كَابْتَعْ', #1
u'كابتعت': u'كَابْتَعْتُ', #1
u'كابتنى': u'كَابْتَنَى', #1
u'كأبحتك': u'كَأَبَحْتُك', #1
u'كأبدا': u'كَأَبَدًا', #1
u'كأبداه': u'كَأَبْدَاهُ', #1
u'كأبرأت': u'كَأَبْرَأْت', #1
u'كأبرأت': u'كَأَبْرَأْتُ', #2
u'كأبرأتك': u'كَأَبْرَأْتُكِ', #1
u'كأبرأتك': u'كَأَبْرَأْتُك', #3
u'كأبرأتك': u'كَأَبْرَأْتُكَ', #8
u'كأبرأتني': u'كَأَبْرَأْتَنِي', #2
u'كأبرأته': u'كَأَبْرَأْتُهُ', #4
u'كإبراد': u'كَإِبْرَادٍ', #3
u'كأبرأني': u'كَأَبْرَأَنِي', #2
u'كإبراهيمي': u'كَإِبْرَاهِيمِيٍّ', #2
u'كأبرائه': u'كَأَبْرَائِهِ', #1
u'كأبريت': u'كَأَبْرَيْتُ', #1
u'كإبريسم': u'كَإِبْرَيْسَم', #1
u'كإبريسم': u'كَإِبْرَيْسَمٍ', #7
u'كأبطلت': u'كَأَبْطَلْت', #1
u'كأبطلت': u'كَأَبْطَلْتُ', #2
u'كأبطلته': u'كَأَبْطَلْته', #1
u'كأبطلته': u'كَأَبْطَلْتُهُ', #4
u'كأبطلتها': u'كَأَبْطَلْتهَا', #1
u'كأبطلتها': u'كَأَبْطَلْتُهَا', #9
u'كابعث': u'كَابْعَثْ', #2
u'كآبق': u'كَآبِقٍ', #72
u'كأبقيت': u'كَأَبْقَيْتُ', #1
u'كأبنتك': u'كَأَبَنْتُكِ', #1
u'كأبى': u'كَأَبِى', #2
u'كأبيع': u'كَأَبِيعُ', #1
u'كأبيعك': u'كَأَبِيعُك', #1
u'كأبيعك': u'كَأَبِيعُكَ', #13
u'كأتبعتك': u'كَأَتْبَعْتُكَ', #2
u'كاتبنى': u'كَاتَبَنِى', #1
u'كاتبونى': u'كَاتَبُونِى', #3
u'كاتبى': u'كَاتِبِى', #1
u'كاتجر': u'كَاتَّجِرْ', #1
u'كأتحصن': u'كَأَتَحَصَّنُ', #2
u'كاتدع': u'كَاتَّدَعَ', #1
u'كاترك': u'كَاتْرُكْ', #1
u'كاتزن': u'كَاتَّزِنْ', #1
u'كأتزوجك': u'كَأَتَزَوَّجُكِ', #2
u'كأتزوجك': u'كَأَتَزَوَّجُك', #4
u'كاتضاعي': u'كَاتِّضَاعِي', #1
u'كأتلف': u'كَأَتْلِفْ', #1
u'كأتلف': u'كَأَتْلَفَ', #2
u'كأتموا': u'كَأَتِمُّوا', #1
u'كاتهاب': u'كَاتِّهَابِ', #1
u'كاتهاب': u'كَاتِّهَابٍ', #2
u'كاتهابه': u'كَاتِّهَابِهِ', #1
u'كإتهامه': u'كَإِتْهَامِهِ', #1
u'كاتهبت': u'كَاتَّهَبْتُ', #1
u'كآتوا': u'كَآتُوا', #1
u'كأثبتت': u'كَأَثْبَتْتُ', #1
u'كأثرده': u'كَأَثْرَدَهُ', #1
u'كأثم': u'كَأَثِمَ', #2
u'كإثمد': u'كَإِثْمِدٍ', #3
u'كاثنتين': u'كَاثْنَتَيْنِ', #14
u'كاثني': u'كَاثْنَيْ', #15
u'كاثنين': u'كَاثْنَيْنِ', #68
u'كأثياب': u'كَأَثْيَابٍ', #1
u'كأجاز': u'كَأَجَازَ', #1
u'كأجازه': u'كَأَجَازَهُ', #1
u'كأجاعلك': u'كَأُجَاعِلُك', #1
u'كإجافة': u'كَإِجَافَةٍ', #1
u'كإجافتين': u'كَإِجَافَتَيْنِ', #1
u'كأجبتك': u'كَأَجَبْتُكَ', #2
u'كأجبره': u'كَأُجْبِرُهُ', #1
u'كأجبرها': u'كَأَجْبِرْهَا', #1
u'كاجتزه': u'كَاجْتَزَّهُ', #1
u'كاجتمع': u'كَاجْتَمَعَ', #1
u'كاجتهد': u'كَاجْتَهَدَ', #1
u'كاجحده': u'كَاجْحَدْهُ', #1
u'كآجرت': u'كَآجَرْتُ', #1
u'كآجرتكها': u'كَآجَرْتُكَهَا', #17
u'كأجرتكها': u'كَأَجَرْتُكَهَا', #2
u'كأجرتكها': u'كَأَجَّرْتُكَهَا', #3
u'كآجرني': u'كَآجَرَنِي', #1
u'كآجرني': u'كَآجِرْنِي', #1
u'كأجرني': u'كَأَجِّرْنِي', #1
u'كأجزت': u'كَأَجَزْتُ', #8
u'كأجزتها': u'كَأَجَزْتُهَا', #1
u'كاجلس': u'كَاجْلِسْ', #2
u'كأجمعين': u'كَأَجْمَعِينَ', #1
u'كأجهر': u'كَأَجْهَرَ', #1
u'كأحببت': u'كَأَحْبَبْتَ', #2
u'كأحبسه': u'كَأَحْبَسَهُ', #1
u'كاحتشاش': u'كَاحْتِشَاشٍ', #2
u'كاحتشاشه': u'كَاحْتِشَاشِهِ', #2
u'كاحتشائها': u'كَاحْتِشَائِهَا', #3
u'كاحتضنه': u'كَاحْتَضَنَهُ', #4
u'كاحتياز': u'كَاحْتِيَازِ', #2
u'كأحث': u'كَأَحَثّ', #3
u'كإحجاج': u'كَإِحْجَاجِ', #2
u'كأحجوا': u'كَأَحِجُّوا', #2
u'كإحداد': u'كَإِحْدَادِ', #1
u'كأحذاه': u'كَأَحْذَاهُ', #1
u'كأحرمت': u'كَأَحْرَمْت', #1
u'كأحرمت': u'كَأَحْرَمْتُ', #2
u'كإحشافها': u'كَإِحْشَافِهَا', #1
u'كاحصد': u'كَاحْصُدْ', #6
u'كاحصده': u'كَاحْصُدْهُ', #1
u'كاحصدوا': u'كَاحْصُدُوا', #1
u'كأحفل': u'كَأَحْفَلِ', #1
u'كأحفى': u'كَأَحْفَى', #2
u'كاحكم': u'كَاحْكُمْ', #4
u'كأحل': u'كَأَحَلَّ', #1
u'كأحلتك': u'كَأَحَلْتُكِ', #1
u'كأحلتك': u'كَأَحَلْتُك', #3
u'كأحلتك': u'كَأَحَلْتُكَ', #6
u'كأحلف': u'كَأَحْلِفُ', #2
u'كأحللتك': u'كَأَحْلَلْتُكَ', #7
u'كأحمل': u'كَأَحْمِلُ', #2
u'كآخ': u'كَآخٍ', #1
u'كأخباز': u'كَأَخْبَازِ', #1
u'كأخبرنا': u'كَأَخْبَرَنَا', #1
u'كاختار': u'كَاخْتَارَ', #1
u'كأختار': u'كَأَخْتَارُ', #2
u'كاختاره': u'كَاخْتَارَهُ', #1
u'كاختاري': u'كَاخْتَارِي', #9
u'كاختدعه': u'كَاخْتَدَعَهُ', #1
u'كاخترت': u'كَاخْتَرْتُ', #13
u'كاخترت': u'كَاخْتَرْت', #2
u'كاخترتك': u'كَاخْتَرْتُك', #1
u'كاخترتك': u'كَاخْتَرْتُكِ', #2
u'كاختلاع': u'كَاخْتِلَاعِ', #7
u'كاختلاعه': u'كَاخْتِلَاعِهِ', #2
u'كاختلاعها': u'كَاخْتِلَاعِهَا', #8
u'كاختلسه': u'كَاخْتَلَسَهُ', #2
u'كاختلعت': u'كَاخْتَلَعَتْ', #1
u'كاختلعت': u'كَاخْتَلَعْت', #1
u'كاختلعتها': u'كَاخْتَلَعْتُهَا', #1
u'كإخدامه': u'كَإِخْدَامِهِ', #2
u'كإخدامها': u'كَإِخْدَامِهَا', #2
u'كأخذت': u'كَأَخَذْتُ', #1
u'كأخذت': u'كَأَخَذْت', #2
u'كأخرجه': u'كَأَخْرَجَهُ', #1
u'كاخرجي': u'كَاخْرُجِي', #4
u'كأخرني': u'كَأَخِّرْنِي', #5
u'كاخشوشن': u'كَاخْشَوْشِنْ', #1
u'كاخلعها': u'كَاخْلَعْهَا', #1
u'كأخين': u'كَأَخَّيْنِ', #1
u'كأد': u'كَأَدِّ', #2
u'كأدجى': u'كَأَدْجَى', #1
u'كأدخلته': u'كَأَدْخَلْته', #1
u'كادخلوا': u'كَادْخُلُوا', #3
u'كادخلوها': u'كَادْخُلُوهَا', #1
u'كادخلي': u'كَادْخُلِي', #2
u'كأدراع': u'كَأَدْرَاعٍ', #1
u'كادع': u'كَادْعُ', #3
u'كادفع': u'كَادْفَعْ', #3
u'كأدقع': u'كَأَدْقَعَ', #1
u'كإذ': u'كَإِذْ', #4
u'كإذا': u'كَإِذَا', #87
u'كاذابا': u'كاذاباً', #1
u'كاذب': u'كَاذِبً', #1
u'كإذخر': u'كَإِذْخِرٍ', #1
u'كأذرعات': u'كَأَذْرُعَاتٍ', #1
u'كأذنت': u'كَأَذِنْتُ', #3
u'كأذنتك': u'كَأَذَنْتُكَ', #1
u'كاذهب': u'كَاذْهَبْ', #7
u'كاذهبي': u'كَاذْهَبِي', #4
u'كاذي': u'كَاذِي', #1
u'كاذي': u'كَاذِيٍّ', #1
u'كاذيا': u'كَاذِيًا', #2
u'كآذيت': u'كَآذَيْتَ', #1
u'كاراست': u'كاراست', #1
u'كارآموزد': u'كارآموزد', #1
u'كارآموزداين': u'كارآموزداين', #1
u'كاربر': u'كاربر', #1
u'كاربسربرد': u'كاربسربرد', #1
u'كأربعين': u'كَأَرْبَعِينَ', #51
u'كاربكني': u'كاربكني', #1
u'كأرت': u'كَأَرَتَّ', #6
u'كارتتاق': u'كَارْتِتَاقِ', #2
u'كارتجعت': u'كَارْتَجَعْتُ', #4
u'كارتجعتها': u'كَارْتَجَعْتُهَا', #1
u'كارتددتها': u'كَارْتَدَدْتهَا', #1
u'كارتغب': u'كَارْتَغَبَ', #1
u'كارتفاق': u'كَارْتِفَاقِ', #2
u'كارتهنته': u'كَارْتَهَنْتُهُ', #1
u'كارتياض': u'كَارْتِيَاضِ', #1
u'كارث': u'كَارِثِ', #2
u'كأرحبية': u'كَأَرْحَبِيَّةِ', #1
u'كأرحبية': u'كَأَرْحَبِيَّةٍ', #2
u'كارحم': u'كَارْحَمْ', #2
u'كارخود': u'كارخود', #1
u'كارد': u'كارد', #2
u'كإردب': u'كَإِرْدَبِّ', #14
u'كإردب': u'كَإِرْدَبٍّ', #7
u'كإردبي': u'كَإِرْدَبَّيْ', #1
u'كإردبين': u'كَإِرْدَبَّيْنِ', #1
u'كاردة': u'كَارِدَة', #1
u'كأردت': u'كَأَرَدْت', #1
u'كأردت': u'كَأَرَدْتُ', #4
u'كارديا': u'كارديا', #1
u'كإرزام': u'كَإِرْزَامِ', #3
u'كارزقني': u'كَارْزُقْنِي', #2
u'كأرش': u'كَأَرْشٍ', #14
u'كأرش': u'كَأَرْشِ', #85
u'كأرضعته': u'كَأَرْضَعْتُهُ', #1
u'كأرطاة': u'كَأَرْطَاةَ', #8
u'كأرطاة': u'كَأَرْطَاةٍ', #9
u'كارع': u'كَارِعٌ', #1
u'كارعا': u'كَارِعًا', #4
u'كإرقاق': u'كَإِرْقَاقِ', #1
u'كارقني': u'كَارْقِنِي', #1
u'كاركند': u'كاركند', #3
u'كاركندا': u'كاركندا', #1
u'كاركنم': u'كاركنم', #4
u'كاركني': u'كاركني', #1
u'كاركه': u'كاركه', #1
u'كارميكتم': u'كارميكتم', #1
u'كارند': u'كارند', #1
u'كارنده': u'كارنده', #1
u'كارندو': u'كارندو', #1
u'كارنكرده': u'كارنكرده', #1
u'كارنكند': u'كارنكند', #1
u'كارنكنم': u'كارنكنم', #6
u'كارنمانده': u'كارنمانده', #1
u'كارهالوجه': u'كَارِهٌالْوَجْهُ', #1
u'كارهست': u'كارهست', #1
u'كأروش': u'كَأُرُوشِ', #4
u'كأريد': u'كَأُرِيدُ', #9
u'كاريز': u'كاريز', #2
u'كاريست': u'كاريست', #2
u'كاز': u'كَازٍ', #2
u'كازر': u'كازر', #1
u'كازرع': u'كَازْرَعْ', #6
u'كازروني': u'كَازَرُونِيٌّ', #8
u'كأزرى': u'كَأَزْرَى', #1
u'كازري': u'كازري', #3
u'كأزلت': u'كَأَزَلْتُ', #1
u'كأزلت': u'كَأَزَلْت', #3
u'كازم': u'كازم', #2
u'كازه': u'كَازَّهُ', #1
u'كأزوجتك': u'كَأَزْوَجْتُكَ', #1
u'كأزوجك': u'كَأُزَوِّجُكِ', #1
u'كأساراهم': u'كَأُسَارَاهُمْ', #2
u'كاسأل': u'كَاسْأَلْ', #1
u'كأسألك': u'كَأَسْأَلُك', #1
u'كأسألك': u'كَأَسْأَلُكَ', #3
u'كأسامة': u'كَأُسَامَةَ', #5
u'كإسامة': u'كَإِسَامَةِ', #5
u'كاستأجرت': u'كَاسْتَأْجَرُت', #1
u'كاستأجرت': u'كَاسْتَأْجَرْتُ', #1
u'كاستأجرت': u'كَاسْتَأْجَرْت', #2
u'كاستأجرتك': u'كاستأجرتك', #1
u'كاستأجرتك': u'كَاسْتَأْجَرْتُك', #11
u'كاستأجرتك': u'كَاسْتَأْجَرْتُكَ', #17
u'كأستأجرك': u'كَأَسْتَأْجِرُكَ', #3
u'كاستأجرناك': u'كَاسْتَأْجَرْنَاكَ', #3
u'كأستأجرها': u'كَأَسْتَأْجِرُهَا', #1
u'كاستأمنتك': u'كَاسْتَأْمَنْتُكَ', #1
u'كاستباه': u'كَاسْتَبَاهُ', #1
u'كاستبدلت': u'كَاسْتَبْدَلْتُ', #1
u'كاستبدلته': u'كَاسْتَبْدَلْتُهُ', #1
u'كاستبرئي': u'كَاسْتَبْرِئِي', #1
u'كاستتابة': u'كَاسْتِتَابَةِ', #2
u'كاستتري': u'كَاسْتَتِرِي', #1
u'كأستثني': u'كَأَسْتَثْنِي', #2
u'كاستجاب': u'كَاسْتَجَابَ', #1
u'كاستجمار': u'كَاسْتِجْمَارٍ', #1
u'كاستحاضة': u'كَاسْتِحَاضَةٍ', #2
u'كاستحجر': u'كَاسْتَحْجَرَ', #2
u'كاستحداد': u'كَاسْتِحْدَادٍ', #2
u'كاستحفظتك': u'كَاسْتَحْفَظْتُكَ', #1
u'كأستحق': u'كَأَسْتَحِقُّ', #1
u'كاستحمق': u'كَاسْتَحْمَقَ', #1
u'كاستخر': u'كَاسْتَخَرَ', #2
u'كاستدخال': u'كَاسْتِدْخَالِ', #8
u'كأستر': u'كَأَسْتَرَ', #1
u'كأستر': u'كَأَسْتَرِ', #5
u'كاسترح': u'كَاسْتَرِحْ', #2
u'كاسترشد': u'كَاسْتَرْشَدَ', #1
u'كاسترقاق': u'كَاسْتِرْقَاقِ', #1
u'كاستسخر': u'كَاسْتَسْخَرَ', #1
u'كاستسعاء': u'كَاسْتِسْعَاءِ', #8
u'كاستصناع': u'كَاسْتِصْنَاعِ', #9
u'كاستعبد': u'كَاسْتَعْبَدَ', #1
u'كاستعنت': u'كَاسْتَعَنْتُ', #1
u'كاستعوضت': u'كَاسْتَعْوَضْتُ', #1
u'كاستعينوا': u'كَاسْتَعِينُوا', #1
u'كاستغفر': u'كَاسْتَغْفِرْ', #1
u'كاستقراب': u'كَاسْتِقْرَابِ', #1
u'كاستكراء': u'كَاسْتِكْرَاءِ', #1
u'كاستمر': u'كَاسْتَمَرَّ', #1
u'كاستنان': u'كَاسْتِنَانِ', #1
u'كاستنبتك': u'كَاسْتَنَبْتُك', #1
u'كاستنبتك': u'كَاسْتَنَبْتُكَ', #1
u'كاستنت': u'كَاسْتَنَّتِ', #1
u'كاستنثاره': u'كَاسْتِنْثَارِهِ', #1
u'كاستنجاء': u'كَاسْتِنْجَاءٍ', #4
u'كاستودعتك': u'كَاسْتَوْدَعْتُك', #3
u'كاستودعتك': u'كَاسْتَوْدَعْتُكَ', #3
u'كاستياك': u'كَاسْتِيَاكٍ', #1
u'كاستياكه': u'كَاسْتِيَاكِهِ', #1
u'كإسرار': u'كَإِسْرَارِ', #2
u'كإسرافيل': u'كَإِسْرَافِيلَ', #2
u'كاسرحي': u'كَاِسْرَحِي', #1
u'كإسفيذاج': u'كَإِسْفِيذَاجٍ', #1
u'كاسفيذاج': u'كَاسْفِيذَاجٍ', #2
u'كإسفيذاج': u'كَإِسْفِيذَاجَ', #3
u'كاسقني': u'كاسقني', #1
u'كاسقني': u'كَاسْقِنِي', #14
u'كاسقيني': u'كَاسْقِينِي', #4
u'كإسكتيها': u'كإسكتيها', #1
u'كإسكتيها': u'كَإِسْكَتَيْهَا', #1
u'كأسكنتك': u'كَأَسْكَنْتُكَ', #3
u'كأسلفتك': u'كَأَسْلَفْتُكَ', #1
u'كأسلمت': u'كَأَسْلَمْتُ', #11
u'كأسلمت': u'كَأَسْلَمْت', #4
u'كأسم': u'كَأَسَمِّ', #1
u'كإسماحه': u'كَإِسْمَاحِهِ', #3
u'كأسمجه': u'كَأَسْمَجَهُ', #1
u'كأسمجه': u'كَأَسْمَجِهِ', #4
u'كأسمح': u'كَأَسْمَحَ', #1
u'كاسناه': u'كاسناه', #1
u'كأسيد': u'كَأُسَيْدٍ', #1
u'كأشاب': u'كَأَشَابَ', #1
u'كأشاح': u'كَأَشَاحَ', #1
u'كإشاح': u'كَإِشَاحٍ', #1
u'كأشأم': u'كَأَشْأَمَ', #1
u'كاشان': u'كَاشَانَ', #2
u'كاشانة': u'كَاشَانَةً', #1
u'كاشأنه': u'كاشأنه', #1
u'كأشب': u'كَأَشَبِّ', #1
u'كاشتر': u'كَاشْتَرِ', #16
u'كاشتركنا': u'كَاشْتَرَكْنَا', #5
u'كاشترها': u'كَاشْتَرِهَا', #1
u'كاشتروا': u'كَاشْتَرُوا', #2
u'كأشتري': u'كَأَشْتَرِي', #17
u'كاشتريت': u'كَاشْتَرَيْتُ', #18
u'كاشتريت': u'كَاشْتَرَيْت', #4
u'كاشتريته': u'كَاشْتَرَيْتُهُ', #8
u'كاشتريتها': u'كَاشْتَرَيْتُهَا', #2
u'كاشترينا': u'كَاشْتَرَيْنَا', #1
u'كأشتى': u'كَأَشْتَى', #2
u'كأشحذها': u'كَأَشْحَذَهَا', #1
u'كإشخاص': u'كَإِشْخَاصِ', #1
u'كأشداف': u'كَأَشْدَافِ', #1
u'كأشركتك': u'كَأَشْرَكْتُك', #2
u'كأشركتك': u'كَأَشْرَكْتُكَ', #2
u'كأشطان': u'كَأَشْطَانِ', #2
u'كاشغر': u'كَاشْغَرُ', #1
u'كاشغر': u'كَاشْغَرَ', #3
u'كأشكاه': u'كَأَشْكَاهُ', #5
u'كأشكله': u'كَأَشْكَلَهُ', #1
u'كاشكى': u'كاشكى', #1
u'كأشكى': u'كَأَشْكَى', #3
u'كأشنان': u'كَأُشْنَانٍ', #30
u'كأشهد': u'كَأَشْهَدْ', #1
u'كأشهد': u'كَأَشْهَدُ', #11
u'كاشهد': u'كَاشْهَدْ', #13
u'كاشهدوا': u'كَاشْهَدُوا', #3
u'كأصدقة': u'كَأَصْدِقَةِ', #2
u'كأصدقتك': u'كَأَصْدَقْتُك', #2
u'كأصدقتك': u'كَأَصْدَقْتُكِ', #2
u'كاصطباره': u'كَاصْطِبَارِهِ', #1
u'كاصنع': u'كَاصْنَعْ', #1
u'كأصنعة': u'كأصنعة', #1
u'كأصنف': u'كَأُصَنِّفُ', #1
u'كأصوم': u'كَأَصُومُ', #2
u'كإضاء': u'كَإِضَاءِ', #1
u'كاضرب': u'كَاضْرِبْ', #3
u'كاضطهده': u'كَاضْطَهَدَهُ', #1
u'كأضمن': u'كَأَضْمَنُ', #2
u'كأضوأ': u'كَأَضْوَأِ', #1
u'كأضوإ': u'كَأَضْوَإِ', #3
u'كأطاب': u'كَأَطَابَ', #3
u'كأطاعه': u'كَأَطَاعَهُ', #1
u'كأطاق': u'كَأَطَاقَ', #1
u'كأطب': u'كَأَطَبِّ', #1
u'كاطعام': u'كَاطِّعَامِ', #1
u'كأطعم': u'كَأَطْعِمْ', #1
u'كأطعميني': u'كَأَطْعِمِينِي', #2
u'كاطلب': u'كَاطْلُبْ', #1
u'كأطلع': u'كَأَطْلَعَ', #2
u'كأطيعوا': u'كَأَطِيعُوا', #2
u'كأظن': u'كَأَظُنُّ', #8
u'كأعاذ': u'كَأَعَاذَ', #2
u'كأعبد': u'كَأَعْبُدِ', #3
u'كاعة': u'كَاعَّةً', #1
u'كاعة': u'كَاعَّةٌ', #1
u'كاعتد': u'كَاعْتَدَّ', #1
u'كاعتد': u'كَاعْتَدِّ', #2
u'كاعتدي': u'كَاعْتَدِّي', #20
u'كاعتصرت': u'كَاعْتَصَرْتُ', #1
u'كأعتق': u'كَأَعْتَقَ', #1
u'كاعتق': u'كَاِعْتِقْ', #1
u'كأعتق': u'كَأَعْتِقْ', #29
u'كأعتقت': u'كَأَعْتَقْت', #1
u'كأعتقت': u'كَأَعْتَقْتُ', #2
u'كأعتقتك': u'كَأَعْتَقْتُكِ', #1
u'كأعتقتك': u'كَأَعْتَقْتُك', #4
u'كأعتقتك': u'كَأَعْتَقْتُكَ', #7
u'كأعتقتكم': u'كَأَعْتَقْتُكُمْ', #6
u'كأعتقته': u'كَأَعْتَقْتُه', #1
u'كأعتقك': u'كَأَعْتَقَكِ', #1
u'كأعتقك': u'كَأُعْتِقُكَ', #1
u'كأعتقني': u'كَأَعْتَقَنِي', #1
u'كأعتقه': u'كَأَعْتَقَهُ', #1
u'كأعتقوا': u'كأعتقوا', #1
u'كأعتقوا': u'كَأَعْتِقُوا', #18
u'كاعتلاف': u'كَاعْتِلَافٍ', #1
u'كاعتمدت': u'كَاعْتَمَدْت', #1
u'كاعتمدت': u'كَاعْتَمَدْتُ', #1
u'كأعجبني': u'كَأَعْجَبَنِي', #2
u'كأعجل': u'كَأَعْجَلَ', #1
u'كأعجل': u'كَأَعْجَلِ', #1
u'كأعجمت': u'كَأَعْجَمْتُ', #1
u'كأعدت': u'كَأَعَدْت', #2
u'كأعدت': u'كَأَعَدْتُ', #6
u'كأعدتها': u'كَأَعَدْتُهَا', #1
u'كأعرتك': u'كَأَعَرْتُكَ', #12
u'كأعرتك': u'كَأَعَرْتُك', #7
u'كأعرني': u'كَأَعِرْنِي', #3
u'كأعريتك': u'كَأَعْرَيْتُك', #1
u'كأعريتك': u'كَأَعْرَيْتُكَ', #1
u'كأعط': u'كَأَعْطِ', #1
u'كأعطني': u'كَأَعْطِنِي', #3
u'كأعطه': u'كَأَعْطِهِ', #1
u'كأعطوا': u'كَأعْطُوا', #1
u'كأعطوا': u'كَأَعْطَوْا', #1
u'كأعطوا': u'كَأَعْطُوا', #6
u'كأعطوه': u'كَأَعْطُوهُ', #4
u'كأعطى': u'كَأَعْطَى', #3
u'كأعطيت': u'كَأَعْطَيْتُ', #2
u'كأعطيه': u'كَأُعْطِيهِ', #1
u'كأعمر': u'كَأَعْمَرِ', #2
u'كأعمرتك': u'كَأَعْمَرْتُك', #8
u'كأعمرتك': u'كَأَعْمَرْتُكَ', #9
u'كاعمل': u'كَاعْمَلْ', #7
u'كأعني': u'كَأَعِنِّي', #1
u'كأعني': u'كَأَعْنِي', #1
u'كأعوذ': u'كَأَعُوذُ', #2
u'كأعونة': u'كَأَعْوِنَةِ', #1
u'كآغارة': u'كَآغَارَةٍ', #1
u'كاغتابه': u'كَاغْتَابَهُ', #1
u'كأغد': u'كَأَغَدّ', #1
u'كاغدة': u'كَاغِدَةٍ', #4
u'كاغدة': u'كَاغِدَةً', #6
u'كأغذ': u'كَأَغَذِّ', #6
u'كأغز': u'كَأَغَزِّ', #2
u'كإغسال': u'كَإِغْسَالِ', #1
u'كاغسل': u'كَاغْسِلْ', #2
u'كاغفر': u'كَاغْفِرْ', #7
u'كأفاعل': u'كَأَفَاعِلَ', #2
u'كآفة': u'كَآفَّةً', #1
u'كأفتح': u'كَأَفْتَحَ', #1
u'كأفتح': u'كَأَفْتَحُ', #1
u'كافتعله': u'كَافْتَعَلَهُ', #1
u'كافتيات': u'كَافْتِيَاتٍ', #2
u'كافرا': u'كَافرًاً', #1
u'كأفراس': u'كَأَفْرَاسٍ', #1
u'كأفرج': u'كَأَفْرَج', #1
u'كافرشوند': u'كافرشوند', #1
u'كافرقوله': u'كَافِرٍقَوْلُهُ', #1
u'كافرى': u'كافرى', #3
u'كافريا': u'كَافِرِيًّا', #1
u'كأفطر': u'كَأَفْطَرَ', #1
u'كأفعل': u'كَأَفْعَلَ', #1
u'كأفعل': u'كَأَفْعَلُ', #2
u'كافعل': u'كَافْعَلْ', #2
u'كأفلس': u'كَأَفْلُسَ', #1
u'كأفلس': u'كَأَفْلُسٍ', #2
u'كافى': u'كَافِىَ', #1
u'كافى': u'كَافِى', #2
u'كافيني': u'كَافِينِي', #1
u'كأقارير': u'كَأَقَارِيرِ', #1
u'كأقالك': u'كَأَقَالَك', #1
u'كأقالك': u'كَأَقَالَكَ', #3
u'كأقأم': u'كأقأم', #1
u'كإقباض': u'كَإِقْبَاضِ', #2
u'كاقبض': u'كَاقْبِضْ', #3
u'كاقترض': u'كَاقْتَرَضَ', #1
u'كاقترض': u'كَاقْتَرِضْ', #3
u'كاقتعاط': u'كَاقْتِعَاطَ', #1
u'كاقتعاط': u'كَاقْتِعَاطِ', #1
u'كاقتل': u'كَاقْتُلْ', #6
u'كاقتلوا': u'كَاقْتُلُوا', #4
u'كأقراء': u'كَأَقْرَاءِ', #1
u'كأقراب': u'كَأَقْرَابِ', #1
u'كأقربية': u'كَأَقْرَبِيَّةِ', #1
u'كأقرت': u'كَأَقَرَّتْ', #1
u'كأقرحة': u'كَأَقْرِحَةٍ', #1
u'كأقررتكم': u'كَأَقْرَرْتُكُمْ', #4
u'كأقرضتك': u'كَأَقْرَضْتكَ', #2
u'كأقرضتك': u'كَأَقْرَضْتُك', #2
u'كأقرضتك': u'كَأَقْرَضْتُكَ', #8
u'كأقرضني': u'كَأَقْرَضَنِي', #2
u'كأقرضني': u'كَأَقْرِضْنِي', #5
u'كأقرضه': u'كَأَقْرِضْهُ', #2
u'كأقركم': u'كَأُقِرُّكُمْ', #2
u'كأقسم': u'كَأُقْسِمُ', #7
u'كأقسمت': u'كَأَقْسَمْت', #1
u'كأقسمت': u'كَأَقْسَمْتُ', #4
u'كأقط': u'كَأَقِطٍ', #4
u'كاقطع': u'كَاقْطَعْ', #4
u'كاقطعها': u'كَاقْطَعْهَا', #2
u'كأقلت': u'كَأَقَلْتُ', #1
u'كأقلف': u'كَأَقْلَفَ', #1
u'كأقلني': u'كَأَقِلْنِي', #3
u'كأقمت': u'كَأَقَمْت', #1
u'كأقمتك': u'كَأَقَمْتُكَ', #8
u'كأقمعه': u'كَأَقْمَعَهُ', #1
u'كأقنى': u'كَأَقْنَى', #1
u'كأقيموا': u'كَأَقِيمُوا', #5
u'كإكاف': u'كَإِكَافٍ', #2
u'كأكالب': u'كَأَكَالِبَ', #1
u'كأكبه': u'كَأَكَبَّهُ', #1
u'كأكتري': u'كَأَكْتَرِي', #3
u'كاكتريتك': u'كَاكْتَرَيْتُكَ', #3
u'كاكتريته': u'كَاكْتَرَيْتُهُ', #1
u'كأكتع': u'كَأَكْتَعَ', #1
u'كاكتفى': u'كَاكْتَفَى', #3
u'كأكرمت': u'كأكرمت', #1
u'كأكريتك': u'كَأَكْرَيْتُكَ', #1
u'كأكساب': u'كَأَكْسَابِ', #1
u'كأكسابه': u'كَأَكْسَابِهِ', #1
u'كأكعب': u'كَأَكْعُبِ', #1
u'كأكلت': u'كَأَكَلْت', #1
u'كأكلت': u'كَأَكَلْتُ', #1
u'كاكي': u'كَاكِيٌّ', #681
u'كأل': u'كَأَلْ', #5
u'كألا': u'كَأَلَّا', #2
u'كإلا': u'كَإِلَّا', #29
u'كالإباق': u'كَالْإِبَاقِ', #37
u'كالإباية': u'كَالْإِبَايَةِ', #2
u'كالإبراد': u'كَالْإِبْرَادِ', #4
u'كالإبريسم': u'كَالْإِبْرَيْسِمِ', #1
u'كالإبريسم': u'كَالْإِبْرَيْسَمِ', #2
u'كالأبشار': u'كَالْأَبْشَارِ', #1
u'كالأبعدينا': u'كَالْأَبْعَدِينَا', #2
u'كالآبق': u'كَالْآبِقِ', #46
u'كالأبقع': u'كَالْأَبْقَعِ', #2
u'كالأبنوس': u'كَالْأَبَنُوسِ', #1
u'كالأتقاني': u'كَالْأَتْقَانِيِّ', #2
u'كالاتهاب': u'كَالِاتِّهَابِ', #5
u'كالآتوني': u'كَالْآتُونِيِّ', #1
u'كالأثانين': u'كَالْأَثَانِينَ', #1
u'كالأثرم': u'كَالْأَثْرَمِ', #2
u'كالإثمد': u'كَالْإِثْمِدِ', #9
u'كالاثني': u'كَالِاثْنَيْ', #4
u'كالاثنين': u'كَالِاثْنَيْنِ', #49
u'كالإجانات': u'كَالْإِجَّانَاتِ', #2
u'كالأجب': u'كَالْأَجَبْ', #2
u'كالأجزية': u'كَالْأَجْزِيَةِ', #1
u'كالأجهوري': u'كَالْأُجْهُورِيِّ', #2
u'كالاحتباك': u'كَالِاحْتِبَاكِ', #1
u'كالاحتجام': u'كَالِاحْتِجَامِ', #1
u'كالاحتزام': u'كَالِاحْتِزَامِ', #1
u'كالاحتشاش': u'كَالِاحْتِشَاشِ', #9
u'كالإحداد': u'كَالْإِحْدَادِ', #1
u'كالإحدى': u'كَالْإِحْدَى', #1
u'كالأحرمة': u'كَالْأَحْرَمَةِ', #1
u'كالأحسنية': u'كَالْأَحْسَنِيَّةِ', #1
u'كالإحصار': u'كَالْإِحْصَارِ', #1
u'كالأحكار': u'كَالْأَحْكَارِ', #2
u'كالأحوط': u'كَالْأَحْوَطِ', #1
u'كالأخباز': u'كَالْأَخْبَازِ', #2
u'كالاختيارة': u'كَالِاخْتِيَارَةِ', #4
u'كالإخدار': u'كَالْإِخْدَارِ', #1
u'كالأخصية': u'كَالْأَخَصِّيَّةِ', #1
u'كالأخلية': u'كَالْأَخْلِيَةِ', #2
u'كالآدر': u'كَالْآدُرِ', #1
u'كالأدرة': u'كَالْأُدْرَةِ', #4
u'كالإدهان': u'كَالْإِدْهَانِ', #1
u'كالادهان': u'كَالِادِّهَانِ', #1
u'كالإذخر': u'كَالْإِذْخِرِ', #10
u'كالأذرعي': u'كَالْأَذْرَعِيِّ', #111
u'كالأرايح': u'كَالْأَرَايِحِ', #1
u'كالأربعين': u'كَالْأَرْبَعِينَ', #20
u'كالأرت': u'كَالْأَرَتِّ', #3
u'كالارتضاع': u'كَالِارْتِضَاعِ', #1
u'كالارتفاق': u'كَالِارْتِفَاقِ', #1
u'كالأرحبية': u'كَالْأَرْحَبِيَّةِ', #1
u'كالأردبيلي': u'كالأردبيلي', #1
u'كالإرزبة': u'كَالْإِرْزَبّةِ', #1
u'كالأرش': u'كَالْأَرْشِ', #46
u'كالأرشدية': u'كَالْأَرْشَدِيَّةِ', #3
u'كالأرماك': u'كَالْأَرْمَاكِ', #1
u'كالإرمني': u'كَالْإِرْمِنِيِّ', #1
u'كالأزج': u'كَالْأَزَجِّ', #2
u'كالأزج': u'كَالْأَزَجِ', #4
u'كالأسارى': u'كَالْأَسَارَى', #1
u'كالأسارى': u'كَالْأُسَارَى', #2
u'كالإسبيجابي': u'كالإسبيجابي', #1
u'كالاستبار': u'كَالِاسْتِبَارِ', #1
u'كالاستبضاع': u'كَالِاسْتِبْضَاعِ', #2
u'كالاستجمار': u'كَالِاسْتِجْمَارِ', #6
u'كالاستجهاض': u'كَالِاسْتِجْهَاضِ', #1
u'كالاستحاضة': u'كَالِاسْتِحَاضَةِ', #8
u'كالاستحداد': u'كَالِاسْتِحْدَادِ', #5
u'كالاستدخال': u'كَالِاسْتِدْخَالِ', #1
u'كالاسترقاق': u'كَالِاسْتِرْقَاقِ', #4
u'كالاستشفار': u'كَالِاسْتِشْفَارِ', #1
u'كالاستصناع': u'كَالِاسْتِصْنَاعِ', #11
u'كالاستطراق': u'كَالِاسْتِطْرَاقِ', #1
u'كالاستفراش': u'كَالِاسْتِفْرَاشِ', #2
u'كالاستفهاميتي': u'كَالِاسْتِفْهَامِيَّتَيْ', #1
u'كالاستقاءة': u'كَالِاسْتِقَاءَةِ', #9
u'كالاستنجاء': u'كَالِاسْتِنْجَاءِ', #18
u'كالاستياك': u'كَالِاسْتِيَاكِ', #8
u'كالاستيام': u'كَالِاسْتِيَامِ', #7
u'كالاستيناء': u'كَالِاسْتِينَاءِ', #1
u'كالاستيهاب': u'كَالِاسْتِيهَابِ', #1
u'كالإسطرلاب': u'كَالْإِسْطِرْلَابِ', #1
u'كالإسفيداج': u'كَالْإِسْفِيدَاجِ', #1
u'كالإسنوي': u'كَالْإِسْنَوِيِّ', #42
u'كالأسنى': u'كَالْأَسْنَى', #2
u'كالأسودان': u'كَالْأَسْوَدَانِ', #1
u'كالإشاح': u'كَالْإِشَاحِ', #1
u'كالأشائم': u'كَالْأَشَائِمِ', #1
u'كالأشرفي': u'كَالْأَشْرَفِيِّ', #2
u'كالأشرفية': u'كَالْأَشْرَفِيَّةِ', #1
u'كالأشنان': u'كَالْأَشْنَانِ', #1
u'كالأشنان': u'كَالْأُشْنَانِ', #17
u'كالأصاريف': u'كَالْأَصَارِيفِ', #4
u'كالأصبحي': u'كَالْأَصْبَحِيِّ', #1
u'كالاصطرلاب': u'كَالِاصْطَرْلَابِ', #1
u'كالأصفوني': u'كَالْأُصْفُونِيِّ', #5
u'كالأصمعي': u'كَالْأَصْمَعِيِّ', #3
u'كالأصيد': u'كَالْأَصِيدِ', #1
u'كالاضطباع': u'كَالِاضْطِبَاعِ', #1
u'كالأعدام': u'كَالْأَعْدَامِ', #1
u'كالأغبط': u'كَالْأَغْبَطِ', #2
u'كالاغتصاص': u'كَالِاغْتِصَاصِ', #1
u'كالاغتلال': u'كَالِاغْتِلَالِ', #2
u'كالإغرار': u'كَالْإِغْرَارِ', #1
u'كالأغماء': u'كَالْأَغْمَاءِ', #1
u'كالافتيات': u'كَالِافْتِيَاتِ', #4
u'كالأفريت': u'كَالْأَفْرِيتِ', #1
u'كالأفقه': u'كَالْأَفْقَهِ', #8
u'كالإفناد': u'كَالْإِفْنَادِ', #2
u'كالأفهار': u'كَالْأَفْهَارِ', #2
u'كالأقارير': u'كالأقارير', #1
u'كالأقارير': u'كَالْأَقَارِيرِ', #6
u'كالإقاله': u'كَالْإِقَالَهْ', #1
u'كالإقباض': u'كَالْإِقْبَاضِ', #2
u'كالاقتداد': u'كَالِاقْتِدَادِ', #1
u'كالأقراء': u'كَالْأَقْرَاءِ', #12
u'كالأقرئية': u'كَالْأَقْرَئِيَّةِ', #1
u'كالأقرئية': u'كاَلْأَقَرَئِيَّةِ', #1
u'كالأقسمة': u'كَالْأَقْسِمَةِ', #1
u'كالأقط': u'كَالْأَقِطِ', #11
u'كالأقفهسي': u'كَالْأَقْفَهْسِيِّ', #2
u'كالأقلف': u'كَالْأَقْلَفِ', #1
u'كالإكاف': u'كَالْإِكَافِ', #10
u'كالأكدرية': u'كَالْأَكْدَرِيَّةِ', #1
u'كالأكرية': u'كَالْأَكْرِيَةِ', #1
u'كالأكساب': u'كَالْأَكْسَابِ', #3
u'كالإما': u'كَالْإِمَا', #1
u'كالأمات': u'كَالْأُمَّاتِ', #1
u'كالأمثله': u'كَالْأَمْثِلَهْ', #1
u'كالآمدي': u'كَالْآمِدِي', #1
u'كالآمدي': u'كَالْآمِدِيِّ', #29
u'كالإمناء': u'كَالْإِمْنَاءِ', #1
u'كالأمه': u'كَالْأَمَهْ', #1
u'كالأنافح': u'كَالْأَنَافِحْ', #2
u'كالإنفحة': u'كَالْإِنْفَحَةِ', #9
u'كالأنقص': u'كَالْأَنْقَصِ', #2
u'كالآنك': u'كَالْآنُكِ', #1
u'كالأنكحة': u'كَالْأَنْكِحَةِ', #5
u'كالأنوك': u'كَالْأَنْوَكِ', #1
u'كالإهليلج': u'كَالْإِهْلِيلِجِ', #1
u'كالإهليلج': u'كَالْإِهْلِيلَجِ', #2
u'كالأهوان': u'كَالْأَهْوَانِ', #1
u'كالإهوان': u'كَالْإِهْوَانِ', #4
u'كالأوزاعي': u'كَالْأَوْزَاعِيِّ', #5
u'كالأوصية': u'كَالْأَوْصِيَةِ', #1
u'كالأوقاص': u'كَالْأَوْقَاصِ', #1
u'كالأولتين': u'كَالْأُولَتَيْنِ', #1
u'كالائتدام': u'كَالِائْتِدَامِ', #1
u'كالأيا': u'كَالْأَيَا', #1
u'كالإيجارة': u'كَالْإِيجَارَةِ', #3
u'كالآيس': u'كَالْآيِسِ', #1
u'كالآيسة': u'كَالْآيِسَةِ', #8
u'كالبابورج': u'كَالْبَابُورْجِ', #1
u'كالبارزي': u'كَالْبَارِزِيِّ', #6
u'كالبازري': u'كَالْبَازِرِيِّ', #2
u'كالباشاوات': u'كَالْبَاشَاوَاتِ', #1
u'كالباغ': u'كَالْبَاغِ', #1
u'كالباقلا': u'كَالْبَاقِلَّا', #1
u'كالباقلاني': u'كالباقلاني', #1
u'كالباقلاني': u'كَالبَاقِلَّانِيِّ', #2
u'كالبامية': u'كَالْبَامِيَةِ', #3
u'كالبثرات': u'كَالْبَثَرَاتِ', #13
u'كالبثرة': u'كَالْبَثْرَةِ', #1
u'كالبجد': u'كَالْبُجُدِ', #1
u'كالبخاتى': u'كَالْبَخَاتَى', #1
u'كالبخاتي': u'كَالْبَخَاتِيِّ', #4
u'كالبدار': u'كَالْبِدَارِ', #1
u'كالبربط': u'كَالْبَرْبَطِ', #3
u'كالبرزلي': u'كَالْبُرْزُلِيِّ', #1
u'كالبرسام': u'كَالْبَرْسَامِ', #1
u'كالبرسام': u'كَالْبُرْسَامِ', #1
u'كالبرسام': u'كَالْبِرْسَامِ', #4
u'كالبرماوي': u'كَالْبِرْمَاوِيِّ', #2
u'كالبرهمتوشي': u'كالبرهمتوشي', #1
u'كالبز': u'كَالْبَزِّ', #9
u'كالبزاغ': u'كَالْبَزَّاغِ', #2
u'كالبس': u'كَالْبَسِ', #1
u'كالبسيلة': u'كَالْبَسِيلَةِ', #1
u'كالبشت': u'كَالْبِشْتِ', #1
u'كالبشخانات': u'كَالْبُشْخَاناتِ', #1
u'كالبشخانات': u'كَالْبُشْخَانَاتِ', #1
u'كالبشخانة': u'كَالْبَشَخَانَةِ', #1
u'كالبغاث': u'كَالْبُغَاثِ', #1
u'كالبغوي': u'كَالْبَغَوِيِّ', #39
u'كالبقار': u'كَالْبَقَّارِ', #1
u'كالبقلة': u'كَالْبَقْلَةِ', #3
u'كالبكا': u'كَالْبُكَا', #2
u'كالبكارج': u'كَالْبَكَارِجِ', #1
u'كالبكنى': u'كالبكنى', #1
u'كالبلانة': u'كَالْبَلَّانَةِ', #1
u'كالبلصة': u'كَالْبَلَصَةِ', #1
u'كالبلغم': u'كَالْبَلْغَمِ', #7
u'كالبلغمي': u'كَالْبَلْغَمِيِّ', #1
u'كالبلقيني': u'كَالْبُلْقِينِيِّ', #41
u'كالبليلة': u'كَالْبَلِيلَةِ', #4
u'كالبندنيجي': u'كَالْبَنْدَنِيجِيِّ', #2
u'كالبنين': u'كَالْبَنِينَ', #16
u'كالبهايم،': u'كَالْبَهَايِمِ،', #1
u'كالبوص': u'كَالْبُوصِ', #2
u'كالبوظة': u'كَالْبُوظَةِ', #5
u'كالبويطي': u'كَالْبُوَيْطِيِّ', #1
u'كالبيتوتة': u'كَالْبَيْتُوتَةِ', #7
u'كالبيهقي': u'كَالْبَيْهَقِيِّ', #3
u'كالبيوعات': u'كَالْبُيُوعَاتِ', #3
u'كالتاتورة': u'كَالتَّاتُورَةِ', #1
u'كالتأذي': u'كَالتَّأَذِّي', #1
u'كالتاسومة': u'كَالتَّاسُومَةِ', #4
u'كالتالف': u'كَالتَّالِفِ', #128
u'كالتالفة': u'كَالتَّالِفَةِ', #10
u'كالتأوي': u'كَالتَّأَوِّي', #1
u'كالتتارخانية': u'كالتتارخانية', #2
u'كالتتارخانية': u'كَالتَّتَارْخَانِيَّةِ', #3
u'كالتتائي': u'كَالتَّتَائِيِّ', #1
u'كالتترس': u'كَالتَّتَرُّسِ', #1
u'كالتتريب': u'كَالتَّتْرِيبِ', #3
u'كالتحدير': u'كَالتّحْدِيرِ', #1
u'كالتحرم': u'كَالتَّحَرُّمِ', #6
u'كالتحنك': u'كَالتَّحَنُّكِ', #2
u'كالتختم': u'كَالتَّخَتُّمِ', #1
u'كالترخص': u'كَالتَّرَخُّصِ', #3
u'كالتزعفر': u'كَالتَّزَعْفُرِ', #1
u'كالتسخن': u'كَالتَّسَخُّنِ', #1
u'كالتسري': u'كَالتَّسَرِّي', #4
u'كالتسليمة': u'كَالتَّسْلِيمَةِ', #3
u'كالتسمح': u'كَالتَّسَمُّحِ', #1
u'كالتصرية': u'كَالتَّصْرِيَةِ', #10
u'كالتصيرة': u'كَالتَّصْيِرَةِ', #1
u'كالتضبيب': u'كَالتَّضْبِيبِ', #6
u'كالتطليقة': u'كَالتَّطْلِيقَةِ', #1
u'كالتعازير': u'كَالتَّعَازِيرِ', #6
u'كالتعزوة': u'كَالتَّعْزُوَةِ', #1
u'كالتعيب': u'كَالتَّعَيُّبِ', #9
u'كالتفتازاني': u'كَالتَّفْتازانِيِّ', #1
u'كالتفتازاني': u'كالتَّفْتَازانِيِّ', #1
u'كالتقا': u'كَالتُّقَا', #1
u'كالتكاميش': u'كالتكاميش', #1
u'كالتكدي': u'كَالتَّكَدِّي', #1
u'كالتلعاب': u'كَالتَّلْعَابِ', #1
u'كالتنضيض': u'كَالتَّنْضِيضِ', #1
u'كالتنوخي': u'كَالتَّنُوخِيِّ', #1
u'كالتهايؤ': u'كَالتَّهَايُؤِ', #1
u'كالتوتيا': u'كَالتُّوتِيَا', #2
u'كالتوتيا': u'كَالتُّوتْيَا', #8
u'كالتور': u'كَالتَّوْرِ', #1
u'كالتوضي': u'كَالتَّوَضِّي', #1
u'كالثاوي': u'كَالثَّاوِي', #1
u'كالثخانة': u'كَالثَّخَانَةِ', #1
u'كالثرب': u'كَالثَّرَبِ', #1
u'كالثرب': u'كَالثَّرْبِ', #5
u'كالثغامة': u'كَالثُّغَامَةِ', #1
u'كالثغامة،': u'كَالثَّغَامَةِ،', #1
u'كالثغامة': u'كَالثَّغَامَةِ', #12
u'كالثلاثين': u'كَالثَّلَاثِينَ', #12
u'كالثمان': u'كَالثَّمَانِ', #1
u'كالثمانين': u'كَالثَّمَانِينَ', #2
u'كالثنتين': u'كَالثِّنْتَيْنِ', #3
u'كالثنوى': u'كَالثُّنْوَى', #1
u'كالثنيان': u'كَالثُّنْيَانِ', #1
u'كالثيابة': u'كَالثِّيَابَةِ', #1
u'كالثيابي': u'كَالثِّيَابِيِّ', #1
u'كالثيوبة': u'كَالثُّيُوبَةِ', #6
u'كالجامكية': u'كَالْجَامِكِيَّةِ', #1
u'كالجامكية': u'كَالْجَامِكِيِّةِ', #1
u'كالجاويش': u'كَالْجَاوِيشِ', #1
u'كالجبران': u'كَالْجُبْرَانِ', #1
u'كالجبيرة': u'كَالْجَبِيرَةِ', #39
u'كالجحفة': u'كَالْجَحْفَةِ', #1
u'كالجحفة': u'كَالْجُحْفَةِ', #14
u'كالجدودة': u'كَالْجُدُودَةِ', #1
u'كالجذعة': u'كَالْجَذَعَةِ', #3
u'كالجرائح': u'كَالْجَرَائِحِ', #1
u'كالجرائحي': u'كَالْجَرَائِحِيِّ', #1
u'كالجرموق': u'كَالْجُرْمُوقِ', #7
u'كالجرموقين': u'كَالْجُرْمُوقَيْنِ', #6
u'كالجرن': u'كَالْجُرْنِ', #1
u'كالجريث': u'كَالْجِرِّيثِ', #1
u'كالجرين': u'كَالْجَرِينِ', #3
u'كالجزولي': u'كَالْجَزُولِيِّ', #1
u'كالجعالة': u'كَالْجَعَالَةِ', #46
u'كالجعالة': u'كَالْجِعَالَةِ', #9
u'كالجعرانة': u'كَالْجِعْرَانَةِ', #5
u'كالجلجل': u'كَالْجُلْجُلِ', #1
u'كالجلدات': u'كَالْجَلَدَاتِ', #4
u'كالجلمين': u'كَالْجَلَمَيْنِ', #1
u'كالجماء': u'كَالْجَمَّاءِ', #2
u'كالجملون': u'كَالْجَمَلُونِ', #10
u'كالجموس': u'كَالْجُمُوسِ', #1
u'كالجنك': u'كَالْجِنْكِ', #1
u'كالجنه': u'كَالْجَنَّهْ', #1
u'كالجنيب': u'كَالْجَنِيبِ', #1
u'كالجنيبة': u'كَالْجَنِيبَةِ', #5
u'كالجنيد': u'كَالْجُنَيْدِ', #3
u'كالجهنية': u'كَالْجُهَنِيَّةِ', #1
u'كالجوبة': u'كَالْجَوْبَةِ', #1
u'كالجوجري': u'كَالْجَوْجَرِيِّ', #2
u'كالجوشن': u'كَالْجَوْشَنِ', #1
u'كالجويني': u'كَالْجُوَيْنِيِّ', #2
u'كالجيحون': u'كَالْجَيْحُونِ', #2
u'كالحثمة': u'كَالْحَثْمَةِ', #1
u'كالحثي': u'كَالْحَثْيِ', #1
u'كالحجفة': u'كَالْحَجَفَةِ', #1
u'كالحرقوص': u'كَالْحُرْقُوصِ', #1
u'كالحره': u'كَالْحُرَّهْ', #1
u'كالحزامة': u'كَالْحَزَامَةِ', #2
u'كالحزة': u'كَالْحُزَّةِ', #1
u'كالحساني': u'كَالْحَسَّانِيِّ', #3
u'كالحسبلة': u'كَالْحَسْبَلَةِ', #1
u'كالحسبه': u'كَالْحِسْبَهْ', #1
u'كالحشراتي': u'كَالْحَشَرَاتِيِّ', #1
u'كالحشوش': u'كَالْحُشُوشِ', #1
u'كالحطيم': u'كَالْحَطِيمِ', #1
u'كالحكورة': u'كالحكورة', #1
u'كالحكورة': u'كَالْحَكُّورَةِ', #2
u'كالحلوا': u'كَالْحَلْوَا', #1
u'كالحماليج': u'كَالْحَمَالِيجِ', #1
u'كالحمراني': u'كَالْحُمْرَانِيِّ', #1
u'كالحملاء': u'كَالْحُمَلَاءِ', #7
u'كالحولقة': u'كَالْحَوْلَقَةِ', #1
u'كالحويل': u'كَالْحَوِيلِ', #1
u'كالحيشان': u'كَالْحَيْشَانِ', #1
u'كالحيضفلا': u'كَالْحَيْضِفَلَا', #1
u'كالخبت': u'كَالْخَبْتِ', #1
u'كالخبزة': u'كَالْخُبْزَةِ', #1
u'كالخداج': u'كَالْخِدَاجِ', #1
u'كالخدشة': u'كَالْخَدْشَةِ', #1
u'كالخراءة': u'كَالْخِرَاءَةِ', #1
u'كالخزفة': u'كَالْخَزَفَةِ', #3
u'كالخشراني': u'كَالْخُشْرَانِيِّ', #1
u'كالخشرماني': u'كالخشرماني', #3
u'كالخشكنان': u'كَالْخُشْكَنَانِ', #4
u'كالخشمراني': u'كالخشمراني', #6
u'كالخصا': u'كَالْخِصَا', #1
u'كالخلول': u'كَالْخُلُولِ', #1
u'كالخليطين': u'كَالْخَلِيطَيْنِ', #3
u'كالخندمة': u'كَالْخَنْدَمَةِ', #1
u'كالخنفقيق': u'كَالْخِنْفِقِيقِ', #2
u'كالخوانك': u'كَالْخَوَانِكِ', #1
u'كالخيعل': u'كَالْخَيْعَلِ', #1
u'كالداتورة': u'كَالدَّاتُورَةِ', #2
u'كالدارصيني': u'كَالدَّارَصِينِيِّ', #1
u'كالدارقطني': u'كالدارقطني', #2
u'كالدانق': u'كَالدَّانِقِ', #2
u'كالدانق': u'كَالدَّانَقِ', #3
u'كالدانقين': u'كَالدَّانِقَيْنِ', #1
u'كالدباء': u'كَالدُّبَّاءِ', #3
u'كالدبلة': u'كَالدُّبْلَةِ', #1
u'كالدبيقي': u'كَالدَّبِيقِيِّ', #1
u'كالدجلة': u'كَالدِّجْلَةِ', #2
u'كالدخريص': u'كَالدِّخْرِيصِ', #1
u'كالدد': u'كَالدَّدِ', #1
u'كالدراري': u'كَالدَّرَارِي', #1
u'كالدسترة': u'كَالدُّسْتُرَةِ', #1
u'كالدسومات': u'كَالدُّسُومَاتِ', #1
u'كالدسومة': u'كَالدُّسُومَةِ', #1
u'كالدشت': u'كَالدَّشْتِ', #1
u'كالدعج': u'كَالدَّعَجِ', #4
u'كالدميري': u'كَالدَّمِيرِيِّ', #9
u'كالدويدار': u'كَالدُّوَيْدَارِ', #1
u'كالدويرة': u'كَالدُّوَيْرَةِ', #1
u'كالدياس': u'كَالدِّيَاسِ', #1
u'كالدياسة': u'كَالدِّيَاسَةِ', #1
u'كالذى': u'كَالَّذِى', #28
u'كالرءوس': u'كَالرُّءُوسِ', #7
u'كالرازي': u'كَالرَّازِيِّ', #3
u'كالراعى': u'كَالرَّاعِى', #2
u'كالرانج': u'كَالرَّانِجِ', #3
u'كالرايطة': u'كَالرَّايِطَةِ', #2
u'كالرتقاء': u'كَالرَّتْقَاءِ', #14
u'كالرحمن': u'كَالرَّحْمَنُ', #1
u'كالرحمن': u'كَالرَّحْمَنِ', #33
u'كالرحموت': u'كَالرَّحَمُوتِ', #1
u'كالردء': u'كَالرِّدْءِ', #4
u'كالرستاق': u'كَالرُّسْتَاقِ', #2
u'كالرضوانية': u'كالرَّضْوانِيَّةِ', #1
u'كالرعا': u'كَالرُّعَا', #1
u'كالرقبى': u'كَالرُّقْبَى', #2
u'كالرقمة': u'كالرقمة', #1
u'كالرقمة': u'كَالرَّقْمَةِ', #3
u'كالركاز': u'كَالرِّكَازُ', #1
u'كالركاز': u'كَالرِّكَازِ', #39
u'كالرماص': u'كَالرِّمَاصِ', #1
u'كالرمص': u'كَالرَّمَصِ', #2
u'كالرميا': u'كَالرِّمِّيَّا', #1
u'كالرميا': u'كَالرَّمْيَا', #2
u'كالرهمن': u'كَالرَّهْمَنِ', #1
u'كالرهوان': u'كالرهوان', #1
u'كالرهوان': u'كَالرَّهَوَانِ', #1
u'كالرهيص': u'كَالرَّهِيصِ', #1
u'كالروثة': u'كَالرَّوْثَةِ', #1
u'كالروشن': u'كَالرَّوْشَنِ', #1
u'كالروياني': u'كَالرُّويَانِيِّ', #7
u'كالريباس': u'كَالرِّيبَاسِ', #1
u'كالريطة': u'كَالرَّيْطَةِ', #2
u'كالزاهدي': u'كَالزَّاهِدِيِّ', #2
u'كالزبرة': u'كَالزُّبْرَةِ', #1
u'كالزربول': u'كَالزُّرْبُولِ', #5
u'كالزرنب': u'كَالزَّرْنَبِ', #3
u'كالزعفر': u'كَالزَّعْفَرِ', #1
u'كالزكمة': u'كَالزُّكْمَةِ', #1
u'كالزكمة،': u'كَالزَّكْمَةِ،', #1
u'كالزكمة': u'كَالزَّكْمَةِ', #2
u'كالزكوة': u'كَالزِّكْوَةِ', #1
u'كالزلاطة': u'كَالزَّلَاطَةِ', #1
u'كالزماورد': u'كالزماورد', #1
u'كألزمت': u'كَأَلْزَمْتُ', #5
u'كألزمت': u'كَأَلْزَمْت', #7
u'كألزمتك': u'كَأَلْزَمْتُكَ', #3
u'كالزمخشري': u'كَالزَّمَخْشَرِيِ', #1
u'كالزمخشري': u'كَالزَّمَخْشَرِيِّ', #2
u'كالزمنة': u'كَالزَّمِنَةِ', #3
u'كالزمنى': u'كَالزَّمْنَى', #1
u'كالزنية': u'كَالزَّنْيَةِ', #2
u'كالزيافة': u'كَالزِّيَافَةِ', #4
u'كالزيدين': u'كَالزَّيْدَيْنِ', #1
u'كالزيدين': u'كَالزّيْدَيْنِ', #1
u'كالزيدين': u'كَالزَّيْدِينَ', #3
u'كالزيلعي': u'كَالزَّيْلَعِيِّ', #18
u'كالساباط': u'كَالسَّابَاطِ', #2
u'كالساج': u'كَالسَّاجِ', #3
u'كالساجة': u'كَالسَّاجَةِ', #1
u'كالسبتة': u'كَالسَّبْتَةِ', #1
u'كالسبج': u'كَالسَّبَجِ', #1
u'كالستوق': u'كَالسَّتُّوقِ', #1
u'كالستوقة': u'كَالسَّتُّوقَةِ', #6
u'كالستين': u'كَالسِّتِّينَ', #10
u'كالسخال': u'كَالسِّخَالِ', #9
u'كالسخلة': u'كَالسَّخْلَةِ', #3
u'كالسدفة': u'كَالسُّدْفَةِ', #1
u'كالسرائل': u'كَالسَّرَائِلِ', #1
u'كالسرحان': u'كَالسّرْحَانِ', #1
u'كالسرقين': u'كَالسِّرْقِينِ', #5
u'كالسرموزة': u'كَالسُّرْمُوزَةِ', #1
u'كالسعانين': u'كَالسَّعَانِينَ', #1
u'كالسعانين': u'كَالسَّعَانِينِ', #1
u'كالسعلاطوي': u'كالسَّعْلاطَوِيِّ', #1
u'كالسعوط': u'كَالسَّعُوطِ', #2
u'كالسفاتج': u'كَالسَّفَاتِجِ', #2
u'كالسفنج': u'كَالسَّفِنْجِ', #2
u'كالسفيانين': u'كَالسُّفْيَانَيْنَ', #1
u'كالسقمونيا': u'كَالسَّقَمُونْيَا', #10
u'كالسقنقور': u'كَالسَّقَنْقُورِ', #4
u'كالسكاكي': u'كَالسَّكَّاكِيِّ', #4
u'كالسكباج': u'كَالسِّكْبَاجِ', #1
u'كالسكنجبين': u'كالسكنجبين', #1
u'كالسكنجبين': u'كَالسَّكَنْجَبِينَ', #1
u'كالسكنجبين': u'كَالسَّكَنْجَبِينِ', #2
u'كالسلجم': u'كَالسَّلْجَمِ', #3
u'كالسليمي': u'كَالسُّلَيْمِيِّ', #1
u'كالسما': u'كَالسَّمَا', #1
u'كالسمحاق': u'كَالسِّمْحَاقِ', #4
u'كالسمسمة': u'كَالسِّمْسِمَةِ', #2
u'كالسمندل': u'كَالسَّمَنْدَلِ', #1
u'كالسميذ': u'كَالسَّمِيذِ', #2
u'كالسنا': u'كَالسَّنَا', #1
u'كالسوادين': u'كَالسَّوَادَيْنِ', #1
u'كالسوقة': u'كَالسُّوقَةِ', #1
u'كالسويق': u'كَالسَّوِيقِ', #17
u'كالسيكران': u'كَالسَّيْكُرَانِ', #3
u'كالسيميا': u'كالسيميا', #1
u'كالسيور': u'كَالسُّيُورِ', #4
u'كالشاختين': u'كَالشَّاخَتَيْنِ', #1
u'كالشاذروان': u'كَالشَّاذَرْوَانِ', #1
u'كالشبابة': u'كَالشَّبَّابَةِ', #4
u'كالشبرملسي': u'كالشبرملسي', #1
u'كالشتل': u'كَالشَّتْلِ', #6
u'كالشث': u'كَالشَّثِّ', #1
u'كالشربيني': u'كَالشِّرْبِينِيِّ', #1
u'كالشرنبلالي': u'كالشرنبلالي', #2
u'كالشرواني': u'كَالشَّرْوَانِيِّ', #1
u'كالشريجة': u'كَالشَّرِيجَةِ', #1
u'كالشسع': u'كَالشِّسْعِ', #1
u'كالشعبذة': u'كَالشَّعْبَذَةِ', #1
u'كالشقدف': u'كَالشُّقْدُفِ', #2
u'كالشقص': u'كَالشِّقْصِ', #2
u'كالشماريخ': u'كَالشَّمَارِيخِ', #1
u'كالشمني': u'كَالشُّمُنِّيِّ', #3
u'كالشهاده': u'كَالشَّهَادَهْ', #1
u'كالشيخونية': u'كالشيخونية', #1
u'كالشيخونية': u'كَالشَّيْخُونِيَّة', #3
u'كالصافنات': u'كَالصَّافِنَاتِ', #1
u'كالصبى': u'كَالصِّبَى', #1
u'كالصداء': u'كَالصِّدَاءِ', #1
u'كالصدقه': u'كَالصَّدَقَهْ', #1
u'كالصراة': u'كَالصَّرَاةِ', #2
u'كالصعائدة': u'كَالصَّعَائِدَةِ', #1
u'كالصعل': u'كَالصَّعْلِ', #1
u'كالصعوة': u'كَالصَّعْوَةِ', #1
u'كالصفاف': u'كَالصِّفَافِ', #1
u'كالصقالبة': u'كَالصَّقَالِبَةِ', #1
u'كالصقلبي': u'كَالصَّقْلَبِيِّ', #1
u'كالصلاتية': u'كَالصَّلَاتِيَّةِ', #1
u'كالصناعين': u'كَالصَّنَّاعِينَ', #1
u'كالصنجة': u'كَالصَّنْجَةِ', #4
u'كالصهرة': u'كَالصِّهْرَةِ', #1
u'كالصومين': u'كَالصَّوْمَيْنِ', #5
u'كالصيال': u'كَالصِّيَالِ', #4
u'كالصيحاني': u'كَالصَّيْحَانِيِّ', #1
u'كالصيود': u'كَالصُّيُودِ', #1
u'كالصيود': u'كَالصَّيُودِ', #4
u'كالضرات': u'كَالضَّرَّاتِ', #1
u'كالطالبيين': u'كَالطَّالِبِيِّينَ', #1
u'كالطاوس': u'كَالطَّاوُسِ', #3
u'كالطبري': u'كَالطَّبَرِيِّ', #1
u'كالطبلاوي': u'كَالطَّبَلَاوِيِّ', #2
u'كالطبيعات': u'كَالطَّبِيعَاتِ', #1
u'كالطحاوي': u'كَالطَّحَاوِيِّ', #15
u'كالطراريح': u'كَالطَّرَارِيحِ', #1
u'كالطرفا': u'كَالطَّرْفَا', #1
u'كالطشت': u'كَالطَّشْتِ', #5
u'كالطنجهارة': u'كَالطِّنْجَهَارَةِ', #2
u'كالطواقي': u'كَالطَّوَاقِيِ', #1
u'كالطوطي': u'كَالطُّوطِيِّ', #1
u'كالطيرزد': u'كالطيرزد', #1
u'كالظبا': u'كَالظِّبَا', #2
u'كالظهران': u'كَالظُّهْرَانِ', #1
u'كالظئر': u'كَالظِّئْرِ', #10
u'كالعاطب': u'كَالْعَاطِبِ', #1
u'كالعالمون': u'كَالْعَالَمُونَ', #7
u'كالعبدلي': u'كَالْعَبْدَلِيِّ', #1
u'كالعبلاء': u'كَالْعَبْلَاءِ', #1
u'كالعبيدية': u'كَالْعُبَيْدِيَّةِ', #1
u'كالعتقاء': u'كَالْعُتَقَاءِ', #1
u'كالعتيرة': u'كَالْعَتِيرَةِ', #8
u'كالعثاكلSشرح': u'كَالْعَثَاكِلِSشَرْحُ', #1
u'كالعثاكل': u'كَالْعَثَاكِلِ', #1
u'كالعجرة': u'كَالْعُجْرَةِ', #1
u'كالعده': u'كَالْعِدَّهْ', #1
u'كالعذيطة': u'كَالْعَذْيَطَةِ', #1
u'كالعذيوط': u'كَالْعِذْيَوْطِ', #3
u'كالعسيلة': u'كَالْعُسَيْلَةِ', #1
u'كالعصفر': u'كَالْعُصْفُرِ', #7
u'كالعصوبة': u'كَالْعُصُوبَةِ', #1
u'كالعضب': u'كَالْعَضْبِ', #2
u'كالعطارين': u'كَالْعَطَّارِينَ', #4
u'كالعطن': u'كَالْعَطَنِ', #2
u'كالعظموت': u'كَالْعَظَمُوتِ', #1
u'كالعفا': u'كَالْعَفَا', #1
u'كالعفص': u'كَالْعَفْصِ', #6
u'كالعفلة': u'كَالْعَفَلَةِ', #2
u'كالعقادين': u'كَالْعَقَّادِينَ', #1
u'كالعقوص': u'كَالْعُقُوصِ', #1
u'كالعكام': u'كَالْعِكَامِ', #1
u'كالعلوفة': u'كَالْعَلُوفَةِ', #1
u'كالعمرى': u'كَالْعُمْرَى', #20
u'كالعميان': u'كَالْعُمْيَانِ', #3
u'كالعنة': u'كَالْعُنَّةِ', #9
u'كالعنجد،': u'كالعنجد،', #1
u'كالعنجد': u'كالعَنْجَدِ', #2
u'كالعنجد': u'كَالْعَنْجَدِ', #2
u'كالعنوي': u'كَالْعَنْوِيِّ', #2
u'كالعنين': u'كَالْعِنِّينِ', #35
u'كالعويجة': u'كَالْعَوِيجَةِ', #1
u'كالعيس': u'كَالْعِيسِ', #1
u'كالعيسوية': u'كَالْعِيسَوِيَّةِ', #5
u'كالعينان': u'كَالْعَيْنَان', #1
u'كالغاروقة': u'كَالْغَارُوقَةِ', #1
u'كالغازى': u'كَالْغَازِى', #1
u'كالغالط': u'كَالْغَالِطِ', #14
u'كالغالطة': u'كَالْغَالِطَةِ', #3
u'كالغامدية': u'كَالْغَامِدِيَّةِ', #1
u'كالغبريني': u'كَالْغُبْرِينِيِّ', #2
u'كالغبط': u'كَالْغُبُطِ', #1
u'كالغداف': u'كَالْغِدَافِ', #1
u'كالغرما': u'كَالْغُرَمَا', #3
u'كالغزي': u'كَالْغَزِّيِّ', #4
u'كالغصوب': u'كَالْغُصُوبِ', #11
u'كالغضنفر': u'كَالْغَضَنْفَرِ', #1
u'كالغطارف': u'كَالْغَطَارِفِ', #1
u'كالغلث': u'كَالْغَلَثِ', #1
u'كالغموس': u'كَالْغَمُوسِ', #1
u'كالغوراء': u'كَالْغَوْرَاءِ', #4
u'كالفاخت': u'كَالْفَاخِتِ', #1
u'كالفاختة': u'كَالْفَاخِتَةِ', #1
u'كالفارقي': u'كَالْفَارِقِيِّ', #2
u'كالفاغية': u'كَالْفَاغِيَةِ', #1
u'كالفانيد': u'كَالْفَانِيدِ', #1
u'كالفتيا': u'كَالْفُتْيَا', #1
u'كالفحج': u'كَالْفُحْجِ', #1
u'كالفسوخ': u'كَالْفُسُوخِ', #4
u'كالفسيخ': u'كَالْفَسِيخِ', #2
u'كالفسيل': u'كَالْفَسِيلِ', #3
u'كالفعلان': u'كَالْفَعَلَانِ', #1
u'كالفقاعين': u'كَالْفَقَّاعِينَ', #2
u'كالفواخت': u'كَالْفَوَاخِتِ', #5
u'كالفوائت': u'كَالْفَوَائِتِ', #3
u'كالفولة': u'كَالْفُولَةِ', #2
u'كالفيروزج': u'كَالْفَيْرُوزَجِ', #1
u'كالفيفاة': u'كَالْفَيْفَاةِ', #1
u'كالقابسي': u'كَالْقَابِسِيِّ', #1
u'كالقافة': u'كَالْقَافَةِ', #1
u'كالقاهرينا': u'كَالْقَاهِرِينَا', #2
u'كالقائف': u'كَالْقَائِفِ', #8
u'كالقدوري': u'كَالْقُدُورِيِّ', #15
u'كالقرافة': u'كَالْقَرَافَةِ', #2
u'كالقرافي': u'كَالْقَرَافِيِّ', #10
u'كالقرامل': u'كَالْقَرَامِلِ', #1
u'كالقرأين': u'كَالْقُرْأَيْنِ', #3
u'كالقرطالة': u'كَالْقِرْطَالَةِ', #1
u'كالقرطم': u'كَالْقُرْطُمِ', #1
u'كالقرطم': u'كَالْقِرْطِمِ', #1
u'كالقرظ': u'كَالْقَرَظِ', #13
u'كالقرظ': u'كَالْقَرْظِ', #3
u'كالقرقوش': u'كَالْقَرْقُوشِ', #2
u'كالقرقوشة': u'كَالْقَرْقُوشَةِ', #1
u'كالقرقوشة': u'كَالْقُرْقُوشَةِ', #1
u'كالقرمز': u'كَالْقِرْمِزِ', #1
u'كالقرمل': u'كَالْقَرْمَلِ', #1
u'كالقرندلية': u'كالقرندلية', #1
u'كالقزع': u'كَالْقَزَعِ', #1
u'كالقشيري': u'كَالْقُشَيْرِيِّ', #1
u'كالقصارين': u'كَالْقَصَّارِينَ', #2
u'كالقصارين': u'كَالْقَصَّارَيْنِ', #2
u'كالقفزان': u'كَالْقُفْزَانِ', #1
u'كالقفيز': u'كَالْقَفِيزِ', #4
u'كالقفيزين': u'كَالْقَفِيزَيْنِ', #2
u'كالقلزم': u'كَالْقِلْزِمِ', #1
u'كالقلفطة': u'كَالْقُلْفُطَةِ', #3
u'كالقلندري': u'كَالْقَلَنْدَرِيَّ', #2
u'كالقلندرية': u'كالقَلَنْدَرِيَّةِ', #1
u'كالقليوبي': u'كَالْقَلْيُوبِيِّ', #1
u'كالقمولي': u'كَالْقَمُولِيِّ', #13
u'كالقنواتي': u'كَالْقَنَوَاتِيِّ', #3
u'كالقهاوي': u'كَالْقَهَاوِي', #2
u'كالقهستاني': u'كالقهستاني', #4
u'كالقوصرة': u'كَالْقَوْصَرَّةِ', #1
u'كالقولنج': u'كَالْقُولَنْجِ', #2
u'كالقونوي': u'كَالْقُونَوِيِّ', #3
u'كالقياصير': u'كَالْقَيَاصِيرِ', #1
u'كالقيجر': u'كَالْقَيْجَرِ', #1
u'كالقير': u'كَالْقِيرِ', #6
u'كالقيسوني': u'كَالْقَيْسُونِيِّ', #1
u'كالقيسي': u'كَالْقَيْسِيِّ', #1
u'كالقيقب': u'كَالْقَيْقَبِ', #2
u'كالكاذي': u'كَالْكَاذِي', #3
u'كالكافرون': u'كَالْكَافِرُونَ', #2
u'كالكالئ': u'كَالْكَالِئِ', #2
u'كالكحال': u'كَالْكَحَّالِ', #1
u'كالكذان': u'كَالْكَذَّانِ', #5
u'كالكراش': u'كَالْكِرَاشِ', #1
u'كالكرباس': u'كَالْكِرْبَاسِ', #12
u'كالكرخي': u'كَالْكَرْخِيِّ', #16
u'كالكردار': u'كَالْكِرْدَارِ', #1
u'كالكرين': u'كَالْكُرَّيْنِ', #1
u'كالكسبرة': u'كَالْكُسْبَرَةِ', #2
u'كالكستيج': u'كَالْكَسْتِيجِ', #1
u'كالكستيج': u'كَالْكُسْتِيجُ', #1
u'كالكسفرة': u'كَالْكُسْفُرَةِ', #2
u'كالكفره': u'كَالْكَفَرَهْ', #2
u'كالكلامين': u'كَالْكَلَامَيْنِ', #5
u'كالكلنة': u'كالكلنة', #1
u'كالكلوتة': u'كَالْكَلْوَتَةِ', #2
u'كالكنفة': u'كَالْكَنَفَةِ', #1
u'كالكوبة': u'كَالْكُوبَةِ', #5
u'كالكيزان': u'كَالْكِيزَانِ', #6
u'كالكيسانيات': u'كالكيسانيات', #3
u'كالكيمان': u'كَالْكِيمَانِ', #1
u'كاللا': u'كَالَّلَا', #1
u'كاللادن': u'كاللادن', #1
u'كاللاذن': u'كَاللَّاذَنِ', #3
u'كاللامعدوم': u'كَالَّلَامَعْدُومِ', #1
u'كاللبأ': u'كَاللِّبَأِ', #1
u'كاللبإ': u'كَاللِّبَإِ', #2
u'كاللخمي': u'كَاللَّخْمِيِّ', #14
u'كاللغوى': u'كَاللَّغْوَى', #1
u'كاللقلق': u'كَاللَّقْلَقِ', #1
u'كاللكام': u'كَاللِّكَامِ', #4
u'كاللواز': u'كَاللِّوَازِ', #1
u'كاللوب': u'كَاللَّوْبِ', #1
u'كاللوب': u'كَاللّوبِ', #3
u'كاللؤلؤة': u'كَاللُّؤْلُؤَةِ', #1
u'كالليطة': u'كَاللِّيطَةِ', #2
u'كالمأتي': u'كَالْمَأْتِيِّ', #2
u'كالماذيانات': u'كَالْمَاذِيَانَاتِ', #1
u'كالمازري': u'كَالْمَازِرِيِّ', #5
u'كالمازني': u'كَالْمَازِنِيِّ', #1
u'كالماش': u'كَالْمَاشِّ', #1
u'كالماغوصة': u'كالماغوصةَ', #1
u'كالمأمومية': u'كالمأمومية', #1
u'كالماوردي': u'كَالْمَاوَرْدِيِّ', #32
u'كالمأيوس': u'كَالْمَأْيُوسِ', #3
u'كالمبارأة': u'كَالْمُبَارَأَةِ', #3
u'كالمبان': u'كَالْمُبَانِ', #4
u'كالمبانة': u'كَالْمُبَانَةِ', #1
u'كالمباهلة': u'كَالْمُبَاهَلَةِ', #2
u'كالمباينة': u'كَالْمُبَايَنَةِ', #2
u'كالمبتنى': u'كَالْمُبْتَنَى', #1
u'كالمبتوتة': u'كَالْمَبْتُوتَةِ', #4
u'كالمبرإ': u'كَالْمُبْرَإِ', #1
u'كالمبرسم': u'كالمبرسم', #1
u'كالمبعض': u'كَالْمُبَعَّضِ', #6
u'كالمبعضة': u'كَالْمُبَعَّضَةِ', #1
u'كالمبقاة': u'كَالْمُبْقَاةِ', #1
u'كالمبقى': u'كَالْمُبْقَى', #1
u'كالمتأدى': u'كَالْمُتَأَدَّى', #2
u'كالمتبايعان': u'كالمتبايعان', #1
u'كالمتبري': u'كَالْمُتَبَرِّي', #1
u'كالمتحثي': u'كَالْمُتَحَثِّي', #1
u'كالمتحرف': u'كَالْمُتَحَرِّفِ', #1
u'كالمتحركية': u'كالمُتَحَرِّكِيةِ', #1
u'كالمتحزن': u'كَالْمُتَحَزِّنِ', #7
u'كالمتخرق': u'كَالْمُتَخَرَّقِ', #1
u'كالمتخرق': u'كَالْمُتَخَرِّقِ', #2
u'كالمتخم': u'كَالْمُتْخِمِ', #1
u'كالمتداعى': u'كَالْمُتَدَاعَى', #1
u'كالمتراد': u'كَالْمُتَرَادِّ', #1
u'كالمتزبب': u'كَالْمُتَزَبِّبِ', #1
u'كالمتسخط': u'كَالْمُتَسَخِّطِ', #2
u'كالمتسلم': u'كَالْمُتَسَلِّمِ', #6
u'كالمتسور': u'كَالْمُتَسَوِّرِ', #1
u'كالمتشحط': u'كَالْمَتَشَحِّطِ', #1
u'كالمتشحط': u'كَالْمُتَشَحِّطِ', #8
u'كالمتضايفين': u'كَالْمُتَضَايِفَيْنِ', #1
u'كالمتقاطر': u'كَالْمُتَقَاطَرِ', #1
u'كالمتقاطر': u'كَالْمُتَقَاطِرِ', #4
u'كالمتقذر': u'كَالْمُتَقَذِّرِ', #1
u'كالمتكاري': u'كَالْمُتَكَارِي', #2
u'كالمتلقات': u'كالمتلقات', #1
u'كالمتمحض': u'كَالْمُتَمَحِّضِ', #1
u'كالمتمحضة': u'كَالْمُتَمَحِّضَةِ', #6
u'كالمتهب': u'كَالْمُتَّهِبِ', #1
u'كالمتهب': u'كَالْمُتَّهَبِ', #4
u'كالمتيطي': u'كَالْمُتَيْطِيِّ', #1
u'كالمثلة': u'كَالْمُثْلَةِ', #4
u'كالمجاديل': u'كَالْمَجَادِيلِ', #1
u'كالمجارير': u'كَالْمَجَارِيرِ', #2
u'كالمجاعل': u'كَالْمُجَاعِلِ', #2
u'كالمجاعلة': u'كَالْمُجَاعَلَةِ', #3
u'كالمجبوب': u'كَالْمَجْبُوبِ', #31
u'كالمجحود': u'كَالْمَجْحُودِ', #2
u'كالمجدودة': u'كَالْمَجْدُودَةِ', #2
u'كالمجراة': u'كَالْمُجْرَاةِ', #2
u'كالمجور': u'كَالْمَجُورِ', #1
u'كالمحابيب': u'كَالْمَحَابِيبِ', #1
u'كالمحاصة': u'كَالْمُحَاصَّةِ', #1
u'كالمحاقلة': u'كَالْمُحَاقَلَةِ', #1
u'كالمحاللة': u'كَالمُحَالَلَةِ', #1
u'كالمحاملي': u'كَالْمَحَامِلِيِّ', #1
u'كالمحبوبي': u'كَالْمَحْبُوبِيِّ', #1
u'كالمحة': u'كَالْمُحَّةِ', #1
u'كالمحتجم': u'كَالْمُحْتَجِمِ', #3
u'كالمحتفر': u'كَالْمُحْتَفَرِ', #2
u'كالمحجن': u'كَالْمِحْجَنِ', #3
u'كالمحدة': u'كَالْمُحِدَّةِ', #3
u'كالمحرس': u'كَالْمُحْرَسِ', #1
u'كالمحصر': u'كَالْمَحْصِرِ', #1
u'كالمحصر': u'كَالْمُحَصَّرِ', #1
u'كالمحصر': u'كَالْمَحْصَرِ', #3
u'كالمحصر': u'كَالْمُحْصِرِ', #3
u'كالمحصر': u'كَالْمُحْصَرِ', #73
u'كالمحصرة': u'كَالْمُحْصَرَةِ', #5
u'كالمحصرين': u'كَالْمُحْصَرِينَ', #1
u'كالمحمودية': u'كَالْمَحْمُودِيَّةِ', #2
u'كالمخارجة': u'كَالْمُخَارَجَةِ', #2
u'كالمختبل': u'كَالْمُخْتَبَلِ', #1
u'كالمختتن': u'كَالْمُخْتَتَنِ', #2
u'كالمختضر': u'كَالْمُخْتَضَرِ', #1
u'كالمختلعة': u'كَالْمُخْتَلِعَةِ', #16
u'كالمختلفي': u'كَالْمُخْتَلِفَيْ', #1
u'كالمختلى': u'كَالْمُخْتَلَى', #3
u'كالمخذل': u'كَالْمُخَذِّلِ', #1
u'كالمخروزة': u'كَالْمَخْرُوزَةِ', #2
u'كالمخفوض': u'كَالْمَخْفُوضِ', #1
u'كالمخمصة': u'كَالْمَخْمَصَةِ', #6
u'كالمداعيين': u'كَالْمُدَاعِيَيْنِ', #1
u'كالمدواة': u'كَالْمُدَوَاةِ', #1
u'كالمذارعة': u'كَالْمُذَارَعَةِ', #1
u'كالمذروع': u'كَالْمَذْرُوعِ', #9
u'كالمذروعات': u'كَالْمَذْرُوعَاتِ', #1
u'كالمذففة': u'كَالْمُذَفِّفَةِ', #1
u'كالمذكاة': u'كَالْمُذَكَّاةِ', #2
u'كالمذكوران': u'كَالْمَذْكُورَانِ', #1
u'كالمذي': u'كَالْمَذْيِ', #13
u'كالمراطلة': u'كَالْمُرَاطَلَةِ', #2
u'كالمراغمين': u'كَالْمُرَاغِمِينَ', #1
u'كالمراكبية': u'كَالْمَرَاكِبِيَّةِ', #3
u'كالمراوزة': u'كَالْمَرَاوِزَةِ', #2
u'كالمربات': u'كَالْمَرَبَّاتِ', #1
u'كالمرتك': u'كَالْمُرْتِكِ', #1
u'كالمرجيحة': u'كَالْمُرْجِيحَةِ', #1
u'كالمرقوق': u'كَالْمَرْقُوقِ', #4
u'كالمزحوم': u'كَالْمَزْحُومِ', #7
u'كالمزراق': u'كَالْمِزْرَاقِ', #2
u'كالمزعفر': u'كَالْمُزَعْفَرِ', #4
u'كالمزفوفة': u'كَالْمَزْفُوفَةِ', #1
u'كالمزهق': u'كَالْمُزْهِقِ', #4
u'كالمسبل': u'كَالْمُسَبَّلِ', #1
u'كالمستام': u'كَالْمُسْتَامِ', #38
u'كالمستامة': u'كَالْمُسْتَامَةِ', #1
u'كالمستأمر': u'كَالْمُسْتَأْمِرِ', #1
u'كالمستبحر': u'كَالْمُسْتَبْحَرِ', #1
u'كالمستبحر': u'كَالْمُسْتَبْحِرِ', #1
u'كالمستبرأة': u'كَالْمُسْتَبْرَأَةِ', #2
u'كالمستبضع': u'كَالْمُسْتَبْضَعِ', #1
u'كالمستبضع': u'كَالْمُسْتَبْضِعِ', #3
u'كالمستجمر': u'كَالْمُسْتَجْمِرِ', #1
u'كالمستحاضة': u'كَالْمُسْتَحَاضَةِ', #45
u'كالمستحال': u'كَالْمُسْتَحَالِ', #2
u'كالمستخفى': u'كَالْمُسْتَخْفِى', #1
u'كالمستسعى': u'كَالْمُسْتَسْعَى', #2
u'كالمستسقى': u'كَالْمُسْتَسْقَى', #2
u'كالمستسلف': u'كَالْمُسْتَسْلَفِ', #1
u'كالمستسلف': u'كَالْمُسْتَسْلِفِ', #2
u'كالمستصوب': u'كَالْمُسْتَصْوِبِ', #1
u'كالمستقذر': u'كَالْمُسْتَقْذَرِ', #1
u'كالمستقرض': u'كَالْمُسْتَقْرَضِ', #2
u'كالمستقرض': u'كَالْمُسْتَقْرِضِ', #9
u'كالمستلحقة': u'كَالْمُسْتَلْحَقَةِ', #2
u'كالمستنكح': u'كَالْمُسْتَنْكِحِ', #1
u'كالمستوفاة': u'كَالْمُسْتَوْفَاةِ', #3
u'كالمستوفر': u'كَالْمُسْتَوْفِرِ', #1
u'كالمستوفى': u'كَالْمُسْتَوْفَى', #14
u'كالمسدمة': u'كَالْمُسَدّمَةِ', #1
u'كالمسدمة': u'كَالْمُسْدَمَةِ', #1
u'كالمسقاوي': u'كَالْمِسْقَاوِيِّ', #3
u'كالمسقف': u'كَالْمُسَقَّفِ', #1
u'كالمسلماني': u'كالمسلماني', #2
u'كالمسناة': u'كَالْمُسَنَّاةِ', #3
u'كالمشتراة': u'كَالْمُشْتَرَاةِ', #9
u'كالمشترى': u'كَالْمُشْتَرَى', #15
u'كالمشد': u'كَالْمُشَدِّ', #1
u'كالمشيء': u'كَالْمُشِيءِ', #1
u'كالمشيم': u'كَالْمَشِيمِ', #2
u'كالمصراة': u'كَالْمُصْرَاةِ', #2
u'كالمصراة': u'كَالْمُصَرَّاةِ', #8
u'كالمصفود': u'كَالْمَصْفُودِ', #1
u'كالمضطجعووجه': u'كَالْمُضْطَجِعِوَوَجْهٌ', #1
u'كالمضمخ': u'كَالْمُضَمَّخِ', #1
u'كالمطيطا': u'كَالْمُطَيْطَا', #1
u'كالمعاطاة': u'كَالْمُعَاطَاةِ', #20
u'كالمعاوض': u'كَالْمُعَاوِضِ', #1
u'كالمعتمل': u'كَالْمُعْتَمِلِ', #2
u'كالمعتملين': u'كَالْمُعْتَمِلِينَ', #1
u'كالمعتوق': u'كَالْمَعْتُوقِ', #2
u'كالمعتوقة': u'كَالْمَعْتُوقَةِ', #1
u'كالمعجوز': u'كَالْمَعْجُوزِ', #2
u'كالمعراض': u'كَالْمِعْرَاضِ', #7
u'كالمعصفر': u'كَالْمُعَصْفَرِ', #2
u'كالمعضوب': u'كَالْمَعْضُوبِ', #9
u'كالمعلومية': u'كَالْمَعْلُومِيَّةِ', #1
u'كالمغافر': u'كَالْمَغَافِرِ', #1
u'كالمغرة': u'كَالْمَغْرَةِ', #3
u'كالمغروم': u'كَالْمَغْرُومِ', #3
u'كالمغفر': u'كَالْمِغْفَرِ', #3
u'كالمغيا': u'كَالْمُغَيَّا', #6
u'كالمفاخذة': u'كَالْمُفَاخَذَةِ', #6
u'كالمفاعلة': u'كَالْمُفَاعَلَةِ', #1
u'كالمفتات': u'كَالْمُفْتَاتِ', #4
u'كالمفرده': u'كَالْمُفْرَدَهْ', #1
u'كالمقاثي': u'كَالْمَقَاثِيِّ', #2
u'كالمقاثئ': u'كَالْمَقَاثِئِ', #14
u'كالمقاثئ': u'كالمقاثئ', #4
u'كالمقارض': u'كَالْمُقَارِضِ', #2
u'كالمقاصيص': u'كَالْمَقَاصِيصِ', #1
u'كالمقتنى': u'كَالْمُقْتَنَى', #2
u'كالمقثأة': u'كَالْمَقْثَأَةِ', #3
u'كالمقداد': u'كَالْمِقْدَادِ', #1
u'كالمقلش': u'كَالْمُقْلِشِ', #1
u'كالمقلوة': u'كَالْمَقْلُوَّةِ', #1
u'كالمقيس': u'كَالْمَقِيسِ', #5
u'كالمكاس': u'كَالْمَكَّاسِ', #1
u'كالمكاس': u'كَالْمِكَاسِ', #1
u'كالمكاسين': u'كَالْمَكَّاسِينَ', #3
u'كالمكتراة': u'كَالْمُكْتَرَاةِ', #2
u'كالمكدن': u'كَالْمِكْدَنِ', #1
u'كالممازج': u'كَالْمُمَازِجِ', #2
u'كالممذي': u'كَالْمُمْذِي', #2
u'كالممروق': u'كَالْمَمْرُوقِ', #2
u'كالممشاة': u'كَالْمَمْشَاةِ', #2
u'كالممني': u'كَالْمُمْنِي', #1
u'كالممهورة': u'كَالْمَمْهُورَةِ', #1
u'كالمناخل': u'كَالْمَنَاخِلِ', #1
u'كالمناكح': u'كَالْمَنَاكِحِ', #1
u'كالمناكح': u'كَالْمُنَاكِحِ', #1
u'كالمنخل': u'كَالْمُنْخُلِ', #2
u'كالمنفل': u'كَالْمُنَفَّلِ', #1
u'كالمنوب': u'كَالْمَنُوبِ', #5
u'كالمهازيل': u'كَالْمَهَازِيلِ', #1
u'كالمهايأة': u'كَالْمُهَايَأَةِ', #8
u'كالمهلب': u'كَالْمُهَلَّبِ', #1
u'كالموانيذ': u'كَالْمَوَانِيذِ', #1
u'كالمؤبر': u'كَالْمُؤَبَّرِ', #6
u'كالمؤبرة': u'كَالْمُؤَبَّرَةِ', #3
u'كالموتر': u'كَالْمُوتِرِ', #1
u'كالمؤتم': u'كَالْمُؤْتَمِّ', #3
u'كالمؤتمه': u'كَالْمُؤْتَمِهْ', #1
u'كالموتمه': u'كَالْمُوتَمَهْ', #2
u'كالموتمه': u'كَالْمُوتِمَهْ', #3
u'كالمورود': u'كَالْمَوْرُودِ', #2
u'كالموطوءة': u'كَالْمَوْطُوءَةِ', #34
u'كالموقوذة': u'كَالْمَوْقُوذَةِ', #4
u'كالمومي': u'كَالْمُومِي', #4
u'كالمومئ': u'كَالْمُومِئِ', #2
u'كالمؤنة': u'كَالْمُؤْنَةِ', #7
u'كالمئونة': u'كَالْمَئُونَةِ', #1
u'كالميلق': u'كَالْمَيْلَقِ', #1
u'كالميئوس': u'كَالْمَيْئُوسِ', #1
u'كالناجش': u'كَالنَّاجِشِ', #1
u'كالناد': u'كَالنَّادِّ', #3
u'كالناطقية': u'كَالنَّاطِقِيَّةِ', #1
u'كالنجاشة': u'كَالنِّجَاشَةِ', #1
u'كالنجش': u'كَالنَّجْشِ', #7
u'كالنحوسة': u'كَالنُّحُوسَةِ', #1
u'كالندا': u'كَالنَّدَا', #1
u'كالنرجندي': u'كالنرجندي', #1
u'كالنردشير': u'كَالنَّرْدَشِيرِ', #2
u'كالنسطورية': u'كالنسطورية', #1
u'كالنشان': u'كَالنَّشَانِ', #1
u'كالنشانج': u'كَالنَّشَّانَجِ', #1
u'كالنشائي': u'كَالنَّشَائِيِّ', #2
u'كالنصافي': u'كَالنَّصَّافِيِّ', #1
u'كالنصيرية': u'كَالنُّصَيْرِيَّةِ', #1
u'كالنط': u'كَالنَّطِّ', #1
u'كالنطالة': u'كَالنِّطَالَةِ', #1
u'كالنطرون': u'كَالنَّطْرُونَ', #1
u'كالنقاية': u'كَالنُّقَايَةِ', #2
u'كالنقشواني': u'كالنقشواني', #1
u'كالنه': u'كَالنّهْ', #1
u'كالنهاس': u'كَالنَّهَّاسِ', #1
u'كالنهالي': u'كَالنَّهَالِيِّ', #2
u'كالنورة': u'كَالنَّوْرَةِ', #2
u'كالنورة': u'كَالنُّورَةِ', #6
u'كالنياحة': u'كَالنِّيَاحَةِ', #5
u'كالنيرجيات': u'كالنِّيرَجِيَّاتِ', #1
u'كالنيك': u'كَالنَّيْكِ', #5
u'كالنيلة': u'كَالنِّيلَةِ', #2
u'كالهبه': u'كَالْهِبَهْ', #1
u'كالهدمى': u'كَالْهَدْمَى', #3
u'كالهرائس': u'كَالْهَرَائِسِ', #2
u'كالهسنجاني': u'كالهسنجاني', #1
u'كالهسنجاني': u'كَالَهِسِنْجانِيِّ', #1
u'كالهليلج': u'كَالْهَلِيلِجِ', #1
u'كالهليلج': u'كَالْهِلِيلَجِ', #1
u'كالهملجة': u'كَالْهَمْلَجَةِ', #1
u'كالهميان': u'كَالْهِمْيَانِ', #1
u'كالهوا': u'كَالْهَوَا', #1
u'كالواخذ': u'كالواخذ', #1
u'كالوأرة': u'كَالْوَأْرَةِ', #1
u'كالواقدي': u'كَالْوَاقِدِيّ', #1
u'كالوامصة': u'كَالْوَامِصَةِ', #1
u'كالوترة': u'كَالْوَتَرَةِ', #1
u'كالوجائب': u'كالوجائب', #1
u'كالودادة': u'كَالْوِدَادَةِ', #1
u'كالودة': u'كَالْوِدَّةِ', #1
u'كالوذاري': u'كَالْوَذَارِيِّ', #1
u'كالوذيل': u'كَالْوَذِيلِ', #3
u'كالوضر': u'كَالْوَضَرِ', #2
u'كالوضو': u'كَالْوُضُو', #1
u'كالوقرة': u'كَالْوَقْرَةِ', #3
u'كالوقص': u'كَالْوَقَصِ', #1
u'كالوكلين': u'كَالْوَكِلَيْنِ', #1
u'كالولاد': u'كَالْوِلَادِ', #8
u'كالولوالجية': u'كالولوالجية', #1
u'كإلى': u'كَإِلَى', #38
u'كالئ': u'كَالِئُ', #1
u'كالئ': u'كَالِئٍ', #15
u'كالئ': u'كَالِئٌ', #21
u'كالئ': u'كَالِئَ', #3
u'كالئ': u'كَالِئِ', #3
u'كالئا': u'كَالِئًا', #7
u'كالئة': u'كَالِئَةً', #1
u'كالئة': u'كَالِئَةٌ', #1
u'كالئها': u'كَالِئُهَا', #1
u'كالئها': u'كَالِئَهَا', #3
u'كالئها': u'كَالِئِهَا', #4
u'كاليزيد': u'كَالْيَزِيدِ', #1
u'كالينطل': u'كَاليَّنْطَلِ', #1
u'كاليواقيت': u'كَالْيَوَاقِيتِ', #3
u'كأما': u'كَأَمَّا', #2
u'كأمامة': u'كَأُمَامَةَ', #3
u'كامتصصته': u'كَامْتَصَصْتهُ', #1
u'كامتصصته': u'كَامْتَصَصْتُهُ', #1
u'كأمرتك': u'كَأَمَرْتُكَ', #1
u'كامرئ': u'كَامْرِئٍ', #1
u'كأمسكت': u'كَأَمْسَكْتُ', #1
u'كأمضيته': u'كَأَمْضَيْتُهُ', #4
u'كأمضيتها': u'كَأَمْضَيْتُهَا', #2
u'كأمضيناه': u'كَأَمْضَيْنَاهُ', #1
u'كامع': u'كَامَعَ', #3
u'كامعه': u'كَامَعَهُ', #1
u'كاملأ': u'كَامْلَأْ', #1
u'كأملكه': u'كَأَمْلِكُهُ', #4
u'كأمنت': u'كَأَمَّنْتُ', #1
u'كآمنت': u'كَآمَنْتُ', #2
u'كامه': u'كَامِه', #1
u'كامئ': u'كَامِئٍ', #1
u'كأميا': u'كَأُمِّيَا', #1
u'كانSإسلام': u'كَانَSإسْلَامُ', #1
u'كأنا': u'كَأنَا', #1
u'كإنا': u'كَإِنَّا', #2
u'كأنا': u'كَأَنَّا', #23
u'كأنا': u'كَأَنَا', #38
u'كأنا': u'كَأَنّا', #6
u'كأناب': u'كَأَنَابَ', #1
u'كأنأحتك': u'كَأَنْأَحْتُكَ', #1
u'كانإذا': u'كَانَإِذَا', #2
u'كانأراد': u'كَانَأَرَادَ', #1
u'كأنبت': u'كَأَنْبَتَ', #3
u'كأنت': u'كَأَنْتِ', #370
u'كأنت': u'كَأَنْتَ', #63
u'كانتثار': u'كَانْتِثَارِ', #1
u'كانتثاره': u'كَانْتِثَارِهِ', #4
u'كأنتقلن': u'كَأَنْتَقِلَنَّ', #5
u'كأنتم،': u'كأنتم،', #2
u'كأنتم': u'كَأَنْتُمْ', #5
u'كأنتما': u'كَأَنْتُمَا', #3
u'كأنتن': u'كَأَنْتَنِ', #1
u'كأنتن': u'كَأَنْتُنَّ', #1
u'كإنزاء': u'كَإِنْزَاءِ', #1
u'كأنشأك': u'كَأَنْشَأَك', #1
u'كانظر': u'كَانْظُرْ', #4
u'كانع': u'كَانِعُ', #2
u'كإنعاظ': u'كَإِنْعَاظٍ', #7
u'كأنعمت': u'كَأَنْعَمْتَ', #2
u'كأنعمت': u'كَأَنْعَمْتُ', #2
u'كأنعمت': u'كَأَنْعَمْت', #3
u'كانعمر': u'كَانَعُمَرُ', #1
u'كانفتال': u'كَانْفِتَالِ', #1
u'كأنفق': u'كَأَنْفِقْ', #2
u'كانقوله': u'كَانَقَولُهُ', #1
u'كإنك': u'كَإِنَّك', #1
u'كانكح': u'كَانْكِحْ', #1
u'كأنكحا': u'كَأَنْكَحَا', #1
u'كأنكحة': u'كَأَنْكِحَةِ', #4
u'كأنكحت': u'كَأَنْكَحْتُ', #5
u'كأنكحتك': u'كَأَنْكَحْتُكَ', #2
u'كأنكحتنا': u'كَأَنْكِحَتِنَا', #2
u'كأنكحتهم': u'كَأَنْكِحَتِهِمْ', #1
u'كأنكحك': u'كَأُنْكِحُكَ', #1
u'كإنكم': u'كَإِنَّكُمْ', #1
u'كانلابن': u'كَانَلِابْنِ', #1
u'كانللإمام': u'كَانَلِلْإِمَامِ', #1
u'كإنما': u'كَإِنَّمَا', #4
u'كأنمل': u'كَأُنْمُلِ', #1
u'كأنهمو': u'كَأَنَّهُمُو', #1
u'كانهو': u'كَانَهُوَ', #1
u'كانو': u'كَانُو', #2
u'كانواكما': u'كَانُواكَمَا', #1
u'كانوايعلمون': u'كَانُوايَعْلَمُونَ', #1
u'كانوة': u'كَانُوَةٌ', #1
u'كأنى': u'كَأَنَّى', #1
u'كانى': u'كانى', #2
u'كأنى': u'كَأَنِّى', #70
u'كانيء': u'كانيء', #1
u'كانية': u'كَانِيَةٌ', #1
u'كاه': u'كاه', #1
u'كاه': u'كَاهَ', #4
u'كأو': u'كَأَوْ', #1
u'كاؤ': u'كَاؤ', #2
u'كأوادم': u'كَأَوَادِمَ', #2
u'كأوحشه': u'كَأَوْحَشَهُ', #1
u'كأوحشه': u'كَأَوْحَشِهِ', #1
u'كأودعتك': u'كَأَوْدَعْتُكَ', #5
u'كأودعنيه': u'كَأَوْدَعَنِيهِ', #1
u'كاور': u'كاور', #4
u'كأوزة': u'كَأُوَزَّةٍ', #1
u'كأوصل': u'كَأَوْصِلْ', #2
u'كأوصيت': u'كَأَوْصَيْت', #4
u'كأوصيت': u'كَأَوْصَيْتُ', #61
u'كأوطاس': u'كَأَوْطَاسٍ', #2
u'كأوع': u'كَأَوَعَ', #1
u'كأوقعت': u'كَأَوْقَعْتُ', #2
u'كأوقفه': u'كَأَوْقَفَهُ', #1
u'كأوقفوا': u'كَأَوْقِفُوا', #1
u'كأولتي': u'كَأُولَتَيْ', #4
u'كأولجت': u'كَأَوْلَجْت', #1
u'كأولجت': u'كَأَوْلَجْتُ', #1
u'كأولجت': u'كَأَوْلَجْتَ', #4
u'كأؤلف': u'كَأُؤَلِّفُ', #1
u'كاؤميش': u'كاؤميش', #1
u'كاونيم': u'كاونيم', #1
u'كاوى': u'كاوى', #1
u'كائع،': u'كَائِعٍ،', #1
u'كإياسه': u'كَإِيَاسِهِ', #1
u'كإياك': u'كَإِيَّاكَ', #6
u'كإياه': u'كَإِيَّاهُ', #2
u'كإيجارة': u'كَإِيجَارَةٍ', #1
u'كآيسة': u'كَآيِسَةٍ', #14
u'كأيلة': u'كأَيْلَةَ', #1
u'كايمن': u'كَايْمُنٍ', #1
u'كأينع': u'كَأَيْنَعِ', #1
u'كأيوس': u'كَأَيُوسٍ', #1
u'كبإذنه': u'كَبِإِذْنِهِ', #3
u'كباسة': u'كِبَاسَةٍ', #4
u'كباسة': u'كِبَاسَةِ', #5
u'كباسة': u'كِبَاسَةَ', #7
u'كباعدت': u'كَبَاعَدْت', #1
u'كباعني': u'كَبَاعَنِي', #3
u'كباقلا': u'كَبَاقِلَّا', #2
u'كباكب': u'كَبَاكِبَ', #3
u'كبالتراضي': u'كَبِالتَّرَاضِي', #2
u'كبالسبق': u'كَبِالسَّبْقِ', #1
u'كبألفاظ': u'كَبِأَلْفَاظٍ', #1
u'كبألفين': u'كَبِأَلْفَيْنِ', #2
u'كبالقتل': u'كَبِالْقَتْلِ', #1
u'كبالكلام': u'كَبِالْكَلَامِ', #4
u'كبالله': u'كَبِاللَّهِ', #15
u'كبالمنكوحة': u'كَبِالْمَنْكُوحَةِ', #1
u'كبأمتعة': u'كَبِأَمْتِعَةٍ', #1
u'كبأمته': u'كَبِأَمَتِهِ', #1
u'كبامية': u'كَبَامِيَةٍ', #1
u'كبأنملة': u'كَبِأُنْمُلَةٍ', #1
u'كبآئر': u'كَبَآئِرَ', #1
u'كبايعوا': u'كَبَايِعُوا', #2
u'كبجعل': u'كَبِجُعْلٍ', #6
u'كبجليزك': u'كبجليزك', #1
u'كبحائطه': u'كَبِحَائِطِهِ', #1
u'كبحرة': u'كَبَحْرَةِ', #1
u'كبحيرا': u'كَبُحَيْرَا', #1
u'كبخاتي': u'كَبَخَاتِيِّ', #1
u'كبخاتي': u'كَبَخَاتِيٍّ', #9
u'كبخارى': u'كَبُخَارَى', #3
u'كبخشة': u'كَبَخْشَةٍ', #1
u'كبدرة': u'كَبُدْرَةٍ', #1
u'كبدرة': u'كَبَدْرَةٍ', #2
u'كبدونه': u'كَبُدُونِهٍ', #1
u'كبدونه': u'كَبِدُونِهِ', #1
u'كبدى': u'كَبِدِى', #4
u'كبذلت': u'كَبَذَلْتُ', #1
u'كبرالإمام': u'كَبَّرَالإِمَامُ', #1
u'كبرالسن': u'كِبَرِالسّنّ', #1
u'كبربط': u'كَبَرْبَطٍ', #2
u'كبرس': u'كُبْرُسَ', #1
u'كبرسام': u'كَبِرْسَامٍ', #2
u'كبرقة': u'كَبُرْقَةِ', #1
u'كبرقة': u'كَبَرْقَةَ', #3
u'كبركى': u'كبركى', #1
u'كبريتة': u'كِبْرِيتَةٌ', #1
u'كبز': u'كَبَزِّ', #1
u'كبسرجها': u'كَبِسَرْجِهَا', #4
u'كبشرط': u'كَبِشَرْطٍ', #1
u'كبشيء': u'كَبِشَيْءٍ', #1
u'كبع': u'كَبِعْ', #26
u'كبعامرة': u'كَبِعَامِرَةٍ', #1
u'كبعت': u'كَبِعْت', #21
u'كبعت': u'كَبِعْتُ', #51
u'كبعتك': u'كَبِعَّتِك', #1
u'كبعتك': u'كَبِعْتُكَ', #105
u'كبعتك': u'كَبِعْتُكِ', #2
u'كبعتك': u'كَبِعْتُك', #37
u'كبعتكما': u'كَبِعْتُكُمَا', #4
u'كبعتكه': u'كَبِعْتَكَهُ', #1
u'كبعتكها': u'كَبِعْتُكَهَا', #3
u'كبعتني': u'كَبِعْتَنِي', #3
u'كبعته': u'كَبِعْته', #1
u'كبعته': u'كَبِعْتَهُ', #1
u'كبعته': u'كَبِعْتُهُ', #1
u'كبعثني': u'كَبَعَثَنِي', #6
u'كبعدا': u'كَبُعْدًا', #1
u'كبعرض': u'كَبِعَرَضٍ', #1
u'كبعناك': u'كَبِعْنَاكَ', #5
u'كبعني': u'كَبِعْنِي', #16
u'كبعنيه': u'كَبِعْنِيهِ', #1
u'كبعه': u'كَبِعْهُ', #12
u'كبغصب': u'كَبِغَصْبٍ', #1
u'كبغضة': u'كَبِغْضَةٍ', #1
u'كبغير': u'كَبِغَيْرِ', #3
u'كبغيره': u'كَبِغَيْرِهِ', #6
u'كبفتة': u'كَبَفْتَةٍ', #2
u'كبقلة': u'كَبَقْلَةٍ', #1
u'كبقلة': u'كَبَقْلَةِ', #1
u'كبقم': u'كَبَقَّمٍ', #1
u'كبقم': u'كَبَقَّمَ', #1
u'كبكا': u'كَبُكَا', #2
u'كبكابن': u'كَبِكَابْنِ', #1
u'كبلغ': u'كَبَلَغَ', #1
u'كبلغ': u'كَبَلِّغْ', #1
u'كبلغم': u'كَبَلْغَمٍ', #1
u'كبلغم': u'كَبَلْغَمِ', #1
u'كبلى': u'كَبَلَى', #4
u'كبمثله': u'كبمثله', #1
u'كبمثله': u'كَبِمِثْلِهِ', #3
u'كبمسجد': u'كَبِمَسْجِدٍ', #1
u'كبموسر': u'كَبِمُوسِرٍ', #1
u'كبنتا': u'كَبِنْتَا', #1
u'كبنقد': u'كَبَنْقَدَ', #1
u'كبهذا': u'كَبِهَذَا', #1
u'كبهرام': u'كَبَهْرَامَ', #1
u'كبيتوتة': u'كَبَيْتُوتَةِ', #3
u'كبيس': u'كَبِيسٍ', #7
u'كبيسا': u'كَبِيسًا', #1
u'كبيشة': u'كُبَيْشَةَ', #3
u'كبيشة': u'كُبَيْشَةُ', #4
u'كتابتى؟': u'كِتَابَتِى؟', #1
u'كتابتى': u'كِتَابَتِى', #3
u'كتأبر': u'كَتَأَبُّرِ', #5
u'كتابهقوله': u'كِتَابِهِقَولُهُ', #1
u'كتابى': u'كِتَابِىٍّ', #1
u'كتابى': u'كِتَابِى', #70
u'كتاح': u'كَتَاحَ', #1
u'كتأذيك': u'كَتَأَذِّيك', #2
u'كتأذيه': u'كَتَأَذِّيهِ', #1
u'كتأذيه': u'كَتَأَذِّيه', #2
u'كتارة': u'كَتَارَةً', #1
u'كتأقيت': u'كَتَأْقِيتٍ', #1
u'كتالف': u'كَتَالِفٍ', #7
u'كتانة': u'كُتَانَةَ', #1
u'كتانة': u'كُتَانَةِ', #1
u'كتائبا': u'كَتَائِبًا', #1
u'كتباسط': u'كَتَبَاسُطِ', #1
u'كتبدئته': u'كَتَبْدِئَتِهِ', #1
u'كتبى': u'كُتُبِى', #2
u'كتبيع': u'كَتَبِيعٍ', #1
u'كتترسهم': u'كَتَتَرُّسِهِمْ', #1
u'كتجذيمه': u'كَتَجْذِيمِهِ', #2
u'كتجمير': u'كَتَجْمِيرِ', #5
u'كتجميرها': u'كَتَجْمِيرِهَا', #1
u'كتجوزت': u'كَتَجَوَّزْتُ', #3
u'كتحامد': u'كَتَحَامُدِ', #1
u'كتحققته': u'كَتَحَقَّقْتُهُ', #1
u'كتحلت': u'كَتَحَلَّتْ', #1
u'كتحملت': u'كَتَحَمَّلْتُ', #2
u'كتحميدتين': u'كَتَحْمِيدَتَيْنِ', #1
u'كتحنن': u'كَتَحَنّنِ', #1
u'كتحنن': u'كَتَحَنُّنِ', #2
u'كتخايرنا': u'كَتَخَايَرْنَا', #1
u'كتخايرنا': u'كَتَخَايُرِنَا', #1
u'كتخايرناه': u'كَتَخَايَرْنَاهُ', #1
u'كتخدا': u'كَتْخُدَا', #1
u'كتخدائي': u'كتخدائي', #1
u'كتخدائيته': u'كَتَخْدَائِيَّتِه', #2
u'كتدمر': u'كَتَدْمُرَ', #1
u'كتده': u'كَتَدُهْ', #2
u'كتر': u'كتر', #1
u'كترازين': u'كترازين', #1
u'كترضى': u'كَتَرْضَى', #1
u'كترمم': u'كَتَرَمُّمِ', #1
u'كتزوجت': u'كَتَزَوَّجْت', #1
u'كتزوجت': u'كَتَزَوَّجْتُ', #2
u'كتزوجتك': u'كَتَزَوَّجْتُك', #5
u'كتزوجتك': u'كَتَزَوَّجْتُكِ', #6
u'كتزوجتها': u'كَتَزَوَّجْتُهَا', #2
u'كتزوجتهما': u'كَتَزَوَّجْتُهُمَا', #1
u'كتزوجيني': u'كَتَزَوَّجِينِي', #1
u'كتزوجيني': u'كَتُزَوِّجِينِي', #2
u'كتسافه': u'كَتَسَافَهَ', #1
u'كتسب': u'كَتَسَبٍّ', #1
u'كتسعين': u'كَتِسْعِينَ', #5
u'كتسلفت': u'كَتَسَلَّفْتُ', #3
u'كتشحيذ': u'كَتَشْحِيذِ', #1
u'كتصدقت': u'كَتَصَدَّقْتُ', #5
u'كتصرية': u'كَتَصْرِيَةِ', #3
u'كتضرب': u'كَتَضْرِب', #2
u'كتطلاب': u'كَتِطْلَابِ', #1
u'كتطلقين': u'كَتَطْلُقِينَ', #2
u'كتطليقة': u'كَتَطْلِيقَةٍ', #2
u'كتعت': u'كَتّعَتْ', #1
u'كتعتقني': u'كَتَعْتُقُنِي', #1
u'كتعدى': u'كَتَعَدَّى', #1
u'كتعصية': u'كَتَعْصِيَةِ', #1
u'كتعيب': u'كَتَعَيُّبٍ', #2
u'كتعيب': u'كَتَعَيُّبِ', #2
u'كتعيبه': u'كَتَعَيُّبِهِ', #10
u'كتعيبها': u'كَتَعَيُّبِهَا', #1
u'كتعيرها': u'كَتَعَيُّرِهَا', #1
u'كتفترون': u'كَتَفْتَرُونَ', #1
u'كتفرحوا': u'كَتَفْرَحُوا', #1
u'كتفلة': u'كَتَفْلَةٍ', #1
u'كتفى': u'كَتِفَىِ', #1
u'كتفى': u'كَتِفَىْ', #1
u'كتفى': u'كَتِفِى', #2
u'كتفى': u'كَتِفَىَّ', #3
u'كتفيل': u'كَتَفَيَّلَ', #1
u'كتكريب': u'كَتَكْرِيبٍ', #1
u'كتمتينني': u'كَتَمْتِينَنِي', #1
u'كتمجس': u'كَتَمَجُّسٍ', #1
u'كتمجسها': u'كَتَمَجُّسِهَا', #1
u'كتملكت': u'كَتَمَلَّكْتُ', #17
u'كتملكت': u'كَتَمَلَّكْت', #6
u'كتملكته': u'كَتَمَلَّكْتُهُ', #2
u'كتميمي': u'كَتَمِيمِيٍّ', #2
u'كتناكلهما': u'كَتَنَاكُلِهِمَا', #6
u'كتنخ': u'كَتَنِخٍ', #1
u'كتنضيض': u'كَتَنْضِيضِ', #1
u'كتهامة': u'كَتِهَامَةَ', #1
u'كتهزأ': u'كَتَهَزَّأَ', #1
u'كتوثن': u'كَتَوَثُّنٍ', #2
u'كتوقته': u'كَتَوَقُّتِهِ', #1
u'كتولى': u'كَتَوَلَّى', #2
u'كتوماض': u'كَتَوْماض', #1
u'كتوماض': u'كَتَوْمَاضِ', #1
u'كتيفة': u'كَتِيفَةٍ', #1
u'كتيلة': u'كَتِيلَةِ', #1
u'كتيلة': u'كُتَيْلَةُ', #1
u'كتيميا': u'كَتَيْمِيَا', #2
u'كثائف': u'كَثَائِفِ', #1
u'كثبة': u'كَثُبَةٍ', #1
u'كثبة': u'كُثْبَة', #1
u'كثبة': u'كُثْبَةً', #9
u'كثغامة': u'كَثُغَامَةٍ', #1
u'كثكث': u'كَثْكَثٍ', #1
u'كثلاثا': u'كَثَلَاثًا', #1
u'كثلاثين': u'كَثَلَاثِينَ', #29
u'كثلثمائة': u'كَثَلَثِمِائَةٍ', #1
u'كثمانيا': u'كَثَمَانِيًا', #1
u'كثمانيا': u'كَثَمَانِيَا', #1
u'كثمانين': u'كَثَمَانِينَ', #11
u'كثنتين': u'كَثِنْتَيْنِ', #3
u'كثندوة': u'كَثَنْدُوَةِ', #1
u'كثندوتي': u'كَثُنْدُوَتَيْ', #1
u'كثؤاج': u'كَثُؤَاجِ', #3
u'كثيراوجعلوه': u'كَثِيرًاوَجَعَلُوهُ', #1
u'كثيوبة': u'كَثُيُوبَةِ', #1
u'كثيوبة': u'كَثُيُوبَةٍ', #2
u'كج': u'كَجٌّ', #1
u'كج': u'كَجِّ', #1
u'كج': u'كَجّ', #2
u'كج': u'كَجٍّ', #474
u'كج': u'كُجٍّ', #5
u'كج': u'كج', #6
u'كجا': u'كَجَا', #1
u'كجا': u'كجا', #2
u'كجاءني': u'كَجَاءَنِي', #7
u'كجاءوا': u'كَجَاءُوا', #2
u'كجاءوني': u'كَجَاءُونِي', #1
u'كجابابي': u'كجابابي', #1
u'كجابود': u'كجابود', #2
u'كجاست': u'كجاست', #1
u'كجالينوس': u'كَجَالِينُوسَ', #1
u'كجائفين': u'كَجَائِفَيْنِ', #1
u'كجبرانات': u'كَجُبْرَانَاتِ', #6
u'كجبيرة': u'كَجَبِيرَةٍ', #16
u'كجبيرة': u'كَجَبِيرَةِ', #5
u'كجة': u'كَجَّةَ', #1
u'كجة،': u'كَجَّةَ،', #1
u'كجحفة': u'كَجُحْفَةٍ', #1
u'كجدعا': u'كَجَدْعًا', #1
u'كجذعة': u'كَجَذَعَةٍ', #1
u'كجرائحي': u'كَجَرَائِحِيِّ', #2
u'كجرموق': u'كَجُرْمُوقٍ', #1
u'كجرول': u'كَجَرْوَلَ', #1
u'كجريال': u'كَجِرْيَالٍ', #1
u'كجريب': u'كَجَرِيبٍ', #3
u'كجريش': u'كَجَرِيشِ', #1
u'كجرين': u'كَجَرِينٍ', #1
u'كجزافين': u'كَجُزَافَيْنِ', #2
u'كجزاك': u'كَجَزَاكَ', #1
u'كجعالة': u'كَجِعَالَةٍ', #1
u'كجعالة': u'كَجَعَالَةٍ', #6
u'كجعفرين': u'كَجَعْفَرَيْنِ', #1
u'كجعلت': u'كَجَعَلْت', #1
u'كجعلت': u'كَجَعَلْتُ', #5
u'كجعلتك': u'كَجَعَلْتُكِ', #1
u'كجعلتك': u'كَجَعَلْتُكَ', #5
u'كجعلته': u'كَجَعَلْتُهُ', #19
u'كجعلتها': u'كَجَعَلْتهَا', #1
u'كجعلتها': u'كَجَعَلْتُهَا', #2
u'كجفير': u'كَجَفِيرٍ', #5
u'كجفيره': u'كَجَفِيرِهِ', #1
u'كجلاب': u'كَجُلَّابٍ', #1
u'كجلج': u'كجلج', #1
u'كجلجل': u'كَجُلْجُلٍ', #2
u'كجلدات': u'كَجَلَدَاتِ', #1
u'كجلس': u'كَجُلِسَ', #1
u'كجلس': u'كَجَلَسَ', #3
u'كجلست': u'كَجَلَسْت', #1
u'كجلست': u'كَجَلَسْتُ', #4
u'كجمزى': u'كَجَمَزَى', #1
u'كجملون': u'كَجَمَلُونٍ', #1
u'كجميزا': u'كَجُمَيْزَا', #1
u'كجميعا': u'كَجَمِيعًا', #2
u'كجنوس': u'كَجُنُوسِ', #1
u'كجه': u'كَجّه', #1
u'كجهينة': u'كَجُهَيْنَةَ', #2
u'كجواثى': u'كَجُوَاثَى', #2
u'كجوشن': u'كَجَوْشَنٍ', #4
u'كجئت': u'كَجِئْتُ', #3
u'كجئتك': u'كَجِئْتُك', #3
u'كجيحون': u'كَجَيْحُونٍ', #1
u'كجيحون': u'كَجَيْحُونَ', #10
u'كجين': u'كَجَيْنٍ', #1
u'كحاسن': u'كَحَاسِنٍ', #1
u'كحالا': u'كَحَّالًا', #7
u'كحالو': u'كَحَّالُو', #2
u'كحبست': u'كَحَبَسْتُ', #1
u'كحبهان': u'كَحَبَّهَانَ', #1
u'كحتى': u'كَحَتَّى', #12
u'كحجفة': u'كَحَجْفَةَ', #1
u'كحجنة': u'كَحُجْنَةِ', #3
u'كحدثني': u'كَحَدَّثَنِي', #1
u'كحذام': u'كَحَذَامِ', #1
u'كحرمت': u'كَحَرَّمْتُ', #1
u'كحرمت': u'كَحُرِّمَتْ', #1
u'كحرمت': u'كَحَرَّمْت', #2
u'كحزقة': u'كَحَزْقَةِ', #3
u'كحزنبل': u'كَحَزَنْبَلٍ', #3
u'كحصى': u'كَحَصًى', #2
u'كحضاجر': u'كَحَضَاجِرَ', #1
u'كحضت': u'كَحِضْتُ', #1
u'كحكمت': u'كَحَكَمْتَ', #1
u'كحكمت': u'كَحَكَمْت', #2
u'كحكمت': u'كَحَكَمْتُ', #2
u'كحلفت': u'كَحَلَفْت', #1
u'كحلفت': u'كَحَلَفْتُ', #1
u'كحمدت': u'كَحَمِدْتُ', #1
u'كحمران': u'كَحِمْرَانَ', #1
u'كحموشة': u'كَحُمُوشَةِ', #2
u'كحميلا': u'كَحَمِيلًا', #1
u'كحوارى': u'كَحُوَّارَى', #1
u'كحولان': u'كَحَوَلَانِ', #5
u'كحولانه': u'كَحَوَلَانِهِ', #2
u'كحيثما': u'كَحَيْثُمَا', #1
u'كخارص': u'كَخَارِصٍ', #1
u'كخاقان': u'كَخَاقَانِ', #1
u'كخالعني': u'كَخَالِعْنِي', #6
u'كخانقاه': u'كَخَانِقَاهْ', #1
u'كخداي': u'كخداي', #3
u'كخرء': u'كَخُرْءِ', #1
u'كخرء': u'كَخَرْءِ', #5
u'كخراش،': u'كَخِرَاشٍ،', #1
u'كخركاة': u'كَخَرْكَاةٍ', #1
u'كخزيمة': u'كَخُزَيْمَةَ', #1
u'كخسق': u'كَخَسْقٍ', #2
u'كخشكار': u'كَخِشْكَارٍ', #1
u'كخصصته': u'كَخَصَصْتُهُ', #2
u'كخلقى': u'كَخَلْقِى', #2
u'كخليت': u'كَخَلَّيْتُ', #12
u'كخليت': u'كَخَلَّيْت', #2
u'كخليص': u'كَخَلِيصٍ', #1
u'كخليص': u'كَخُلَيْصٍ', #3
u'كخنزب': u'كَخَنْزَبٍ', #1
u'كخنفسا': u'كَخُنْفُسَا', #1
u'كخواسق': u'كَخَوَاسِقَ', #1
u'كخواهر': u'كَخُوَاهَرْ', #1
u'كخوصة': u'كَخُوصَةٍ', #1
u'كخوصتين': u'كَخُوصَتَيْنِ', #1
u'كخيبر': u'كَخَيْبَرِ', #5
u'كدابضة': u'كَدَابِضَةٍ', #1
u'كداما': u'كِدَامًا', #1
u'كدانا': u'كَدَانًا', #1
u'كدانة': u'كَدَانَةُ', #1
u'كدانق': u'كَدَانَقٍ', #3
u'كدانق': u'كَدَانِقٍ', #4
u'كداين': u'كَدَايَنَ', #1
u'كدبا': u'كَدْبًا', #1
u'كدبرت': u'كَدَبَّرْتُ', #2
u'كدبورى': u'كدبورى', #1
u'كدحرج': u'كَدَحْرَج', #1
u'كدحرج': u'كَدَحْرَجَ', #1
u'كدحنى': u'كَدَحَنِى', #1
u'كدخدائي': u'كدخدائي', #1
u'كدخدائيته': u'كَدَخْدَائِيَّتِهِ', #4
u'كدرزيرا': u'كدرزيرا', #1
u'كدرهاقوله': u'كَدَرُهَاقَوْلُهُ', #1
u'كدعا': u'كَدَعَا', #1
u'كدعت': u'كَدَعَتْ', #1
u'كدعج': u'كَدَعَجٍ', #1
u'كدعوا': u'كَدَعَوَا', #1
u'كدعوت': u'كَدَعَوْتُ', #1
u'كدكا': u'كَدَكًا', #1
u'كدلم': u'كَدَلَمٍ', #2
u'كدمياط': u'كَدِمْيَاطِ', #1
u'كدمياط': u'كِدِمْيَاطَ', #2
u'كدمياط': u'كَدِمْيَاطَ', #3
u'كدنت': u'كَدَنْت', #2
u'كدوحا': u'كدوحا', #1
u'كدوحا': u'كُدُوحًا', #7
u'كدورة': u'كُدُورَةً', #3
u'كدوسا': u'كُدُوسًا', #1
u'كدوشا': u'كُدُوشًا', #4
u'كدويرة': u'كَدُوَيْرَةِ', #1
u'كديدا': u'كَدِيدًا', #2
u'كديده': u'كَدِيدِهِ', #2
u'كديرا': u'كُدَيْرًا', #3
u'كديز': u'كديز', #1
u'كديز': u'كَدَيْزٌ', #1
u'كديور': u'كَدُيُورِ', #1
u'كديور': u'كديور', #2
u'كديوران': u'كديوران', #2
u'كديوري': u'كديوري', #1
u'كديورى': u'كديورى', #1
u'كذاردن': u'كذاردن', #1
u'كذاشتن': u'كذاشتن', #2
u'كذاقالوا': u'كَذَاقَالُوا', #1
u'كذاكا': u'كَذَاكَا', #1
u'كذاكم': u'كَذَاكُمْ', #3
u'كذبانوى': u'كذبانوى', #2
u'كذبانوية': u'كَذْبَانُويَةَ', #1
u'كذبانويه': u'كذبانويه', #1
u'كذبتمونى': u'كَذَّبْتُمُونِى', #1
u'كذبتنى': u'كَذَبْتَنِى', #1
u'كذبتنى': u'كَذَّبَتْنِى', #1
u'كذبنى': u'كَذَبَنِى', #5
u'كذبون': u'كَذَّبُونِ', #3
u'كذشت': u'كذشت', #4
u'كذشتن': u'كذشتن', #1
u'كذشته': u'كذشته', #3
u'كذكرهلصلاة': u'كَذِكْرِهِلِصَلَاةٍ', #1
u'كذلكوالوجه': u'كَذَلِكَوَالْوَجْهُ', #1
u'كذواتا': u'كَذَوَاتَا', #1
u'كذى': u'كَذَى', #1
u'كذيب': u'كُذَيْبٍ', #1
u'كذيبة': u'كُذَيْبَةً', #2
u'كرءوس': u'كَرُءُوسِ', #37
u'كرءوس': u'كَرُءُوسٍ', #4
u'كرءوسه': u'كَرُءُوسِهِ', #2
u'كرابغ': u'كَرَابِغٍ', #2
u'كرابكار': u'كرابكار', #1
u'كرابيس': u'كرابيس', #1
u'كرابيس': u'كَرَابِيسَ', #14
u'كرابيس': u'كَرَابِيسُ', #4
u'كرابيسي': u'كَرَابِيسِيٌّ', #1
u'كرابيسيا': u'كَرَابِيسِيًّا', #1
u'كراجعت': u'كَرَاجَعْتُ', #7
u'كراديس،': u'كَرَادِيسَ،', #1
u'كراديس': u'كَرَادِيسُ', #3
u'كرازا': u'كِرَازًا', #1
u'كراسى': u'كَرَاسِىَّ', #1
u'كراغية': u'كَرَاغِيَةِ', #3
u'كراكر': u'كَرَاكِرِ', #3
u'كراكنم': u'كراكنم', #1
u'كرامهرمز': u'كَرَامَهُرْمُزَ', #1
u'كرآنك،': u'كُرْآنَكَ،', #1
u'كرآننا': u'كُرْآنَنَا', #1
u'كراهيتى': u'كَرَاهِيَتِى', #1
u'كرأيت': u'كَرَأَيْت', #5
u'كرأيت': u'كَرَأَيْتُ', #6
u'كرأيتك': u'كَرَأَيْتُك', #1
u'كرأيته': u'كَرَأَيْتُهُ', #1
u'كراين': u'كراين', #1
u'كرأيناه': u'كَرَأَيْنَاهُ', #2
u'كرب26500id': u'كرب26500id', #1
u'كرباس': u'كِرْبَاس', #1
u'كرباس': u'كِرْبَاسِ', #1
u'كرباس': u'كِرْبَاسَ', #15
u'كرباس': u'كِرْبَاسُ', #2
u'كرباس': u'كِرْبَاسٍ', #48
u'كرباس': u'كرباس', #5
u'كرباس': u'كِرْبَاسٌ', #5
u'كرباسا': u'كِرْبَاسًا', #39
u'كرباسه': u'كِرْبَاسِهِ', #2
u'كرباسي': u'كِرْبَاسِيٌّ', #1
u'كرباسيا': u'كِرْبَاسِيًّا', #1
u'كربال': u'كِرْبَالِ', #1
u'كربزان،': u'كربزان،', #2
u'كربيسي': u'كَرْبِيسِيٍّ', #1
u'كرتقاء': u'كَرَتْقَاءَ', #13
u'كرجح': u'كَرَجُحَ', #1
u'كرجعت': u'كَرَجَعْتُ', #18
u'كرحا': u'كَرَحًا', #2
u'كرحاة': u'كَرَحَاةٍ', #1
u'كرحى': u'كَرَحًى', #7
u'كرخدانية': u'كرخدانية', #1
u'كردء': u'كَرَدْءٍ', #2
u'كردء': u'كَرِدْءٍ', #2
u'كردا': u'كردا', #6
u'كردار': u'كِرْدَارٌ', #1
u'كردار': u'كِرْدَارُ', #2
u'كردار': u'كِرْدَار', #6
u'كردارا': u'كِرْدَارًا', #3
u'كرداند': u'كرداند', #2
u'كرداني': u'كرداني', #1
u'كردانيد': u'كردانيد', #2
u'كردانيدم': u'كردانيدم', #3
u'كردانيدوى': u'كَردانيدوى', #1
u'كردانيدي': u'كردانيدي', #4
u'كردانيديم': u'كردانيديم', #1
u'كرداين': u'كرداين', #1
u'كردايندم': u'كردايندم', #1
u'كردباي': u'كردباي', #1
u'كردباين': u'كردباين', #1
u'كردبر': u'كردبر', #1
u'كردبس': u'كردبس', #1
u'كردبى': u'كردبى', #1
u'كردجين': u'كردجين', #1
u'كردد': u'كردد', #10
u'كردد': u'كَرَدِّدِ', #2
u'كرددت': u'كَرَدَدْتُ', #1
u'كرددتك': u'كَرَدَدْتُك', #1
u'كرددته': u'كَرَدَدْتهُ', #1
u'كرددتها': u'كرددتها', #1
u'كرددتها': u'كَرَدَدْتُهَا', #1
u'كرددر': u'كرددر', #1
u'كردرجنين': u'كردرجنين', #1
u'كردست': u'كردست', #1
u'كردكه': u'كردكه', #2
u'كردمة': u'كُرْدُمَةَ', #1
u'كردمة': u'كَرْدَمَةَ', #6
u'كردمرا': u'كردمرا', #1
u'كردمرد': u'كردمرد', #1
u'كردمز': u'كردمز', #1
u'كردمش': u'كردمش', #2
u'كردن': u'كردن', #19
u'كردن': u'كَرَدَنَ', #2
u'كردن': u'كُرِدْنَ', #20
u'كردند': u'كردند', #3
u'كردنديا': u'كردنديا', #1
u'كردني': u'كَرَدَنِي', #1
u'كردهء': u'كردهء', #4
u'كردوبيس': u'كردوبيس', #1
u'كردوس': u'كَرْدُوسَ', #1
u'كردوس': u'كُرْدُوسُ', #1
u'كردوس،': u'كُرْدُوسٌ،', #1
u'كردوس': u'كَرْدُوسٍ', #2
u'كردوس': u'كُرْدُوسٍ', #20
u'كردوس': u'كُرْدُوسَ', #3
u'كردوس': u'كُرْدُوسِ', #3
u'كردوس،': u'كُرْدُوسٍ،', #3
u'كردوس': u'كُرْدُوسٌ', #6
u'كردوسا': u'كردوسا', #1
u'كردوسا': u'كُرْدُوسًا', #1
u'كردوسا،': u'كُرْدُوسًا،', #1
u'كردوشوي': u'كردوشوي', #1
u'كردوكواهان': u'كردوكواهان', #1
u'كرديد': u'كِرْدِيد', #2
u'كرديدش': u'كرديدش', #2
u'كررباس': u'كررباس', #1
u'كرسفا': u'كُرْسُفًا', #12
u'كرسفة': u'كُرُسُفَةً', #1
u'كرسفة': u'كُرْسُفَةَ', #1
u'كرسنة': u'كِرْسِنَّةُ', #2
u'كرسنة': u'كِرْسِنَّةٌ', #4
u'كرسوع': u'كُرْسُوعٌ', #4
u'كرسوعا': u'كُرْسُوعًا', #1
u'كرسوعه': u'كُرْسُوعِهِ', #2
u'كرسوعي': u'كُرْسُوعِي', #1
u'كرسى': u'كُرْسِىٍّ', #3
u'كرضوا': u'كَرَضُوا', #1
u'كرضى': u'كَرِضًى', #1
u'كرضيت': u'كَرَضِيَتْ', #1
u'كرضيت': u'كَرَضِيتُ', #15
u'كرضيت': u'كَرَضِيت', #4
u'كرفتند': u'كرفتند', #1
u'كرقيا': u'كَرُقْيَا', #3
u'كركاز': u'كَرِكَازٍ', #1
u'كركبان': u'كَرُكْبَانٍ', #1
u'كركسى': u'كركسى', #1
u'كرميت': u'كَرَمَيْتُ', #1
u'كرمينة': u'كرمينة', #2
u'كرمينة': u'كَرْمِينَةَ', #3
u'كرمينية': u'كَرْمِينِيَةَ', #1
u'كرمينية': u'كَرْمِينِيَةُ', #1
u'كرهتيني': u'كَرِهْتِينِي', #1
u'كرهنتني': u'كَرَهَنْتَنِي', #4
u'كرواشن': u'كَرَوَاشِنِ', #1
u'كروبرجندروزبداشت': u'كروبرجندروزبداشت', #1
u'كروثة': u'كَرَوْثَةِ', #1
u'كرؤس': u'كَرُؤْسِ', #1
u'كروسات': u'كَرْوَسَاتُ', #1
u'كروسات': u'كَرْوَسَاتِ', #1
u'كروسة': u'كَرْوَسَةٍ', #1
u'كروشن': u'كَرَوْشَنٍ', #3
u'كروكردى': u'كروكردى', #1
u'كروهة': u'كروهة', #1
u'كرويو': u'كَرَوْيَو', #1
u'كرويى': u'كَرَوْيَى', #4
u'كرياس': u'كرياس', #1
u'كرياس': u'كِرْيَاس', #1
u'كرياسا': u'كِرْيَاسًا', #2
u'كريبا': u'كريبا', #1
u'كريبا': u'كُرَيْبا', #2
u'كريبا': u'كُرَيْبًا', #40
u'كريبا،': u'كُرَيْبًا،', #6
u'كريتا': u'كَرِيتًا', #2
u'كريخت': u'كريخت', #1
u'كريد': u'كُرَيْدٍ', #1
u'كريد': u'كُرَيْدَ', #1
u'كرىدر': u'كرىدر', #1
u'كريز،': u'كريز،', #1
u'كريز': u'كُرَيز', #1
u'كريز': u'كُرَيزٍ', #1
u'كريز،': u'كَرِيزٍ،', #1
u'كريز،': u'كُرَيز،', #1
u'كريز': u'كَرِيْزٍ', #1
u'كريز': u'كُرَيْز', #1
u'كريز': u'كُرَيْزٌ', #1
u'كريز،': u'كُرَيْز،', #1
u'كريز': u'كَرِيزٍ', #15
u'كريز': u'كُرَيْزٍ', #27
u'كريز': u'كريز', #5
u'كريز': u'كُرَيْزِ', #7
u'كريز،': u'كُرَيْزٍ،', #7
u'كريزان': u'كُرْيَزَانُ', #1
u'كريكماه': u'كريكماه', #2
u'كريمتى': u'كَرِيمَتِى', #1
u'كريمقوله': u'كَرِيمٍقَوْلُهُ', #1
u'كزافا': u'كزافا', #1
u'كزال،': u'كَزَّالٍ،', #1
u'كزال،': u'كُزَالٍ،', #1
u'كزرجون': u'كَزَرَجُونَ', #1
u'كزعيفران': u'كَزُعَيْفَرَانَ', #1
u'كزكى': u'كَزَكَّى', #2
u'كزكيت': u'كزكيت', #1
u'كزلاطة': u'كَزَلَاطَةٍ', #1
u'كزلزل': u'كَزَلْزَلَ', #2
u'كزنا': u'كَزِنًا', #72
u'كزنأت': u'كَزَنَأْتِ', #1
u'كزنت': u'كَزَنَتْ', #3
u'كزنى': u'كَزِنًى', #6
u'كزنيت': u'كَزَنَيْتَ', #1
u'كزنيت': u'كَزَنَيْت', #2
u'كزنيت': u'كَزَنَيْتِ', #5
u'كزوجت': u'كَزَوَّجْت', #4
u'كزوجت': u'كَزَوَّجْتُ', #7
u'كزوجتاي': u'كَزَوْجَتَايَ', #1
u'كزوجتكها': u'كَزَوَّجْتُكَهَا', #1
u'كزوجني': u'كَزَوِّجْنِي', #39
u'كزوحم': u'كَزُوحِمَ', #1
u'كزيدا': u'كَزَيْدًا', #1
u'كساباط': u'كَسَابَاطٍ', #5
u'كسأل': u'كَسَأَلَ', #1
u'كسانى': u'كَسَانِى', #2
u'كسائرالأموال': u'كَسَائِرِالْأَمْوَال', #1
u'كسائى': u'كِسَائِى', #2
u'كسايس': u'كَسَايِسٍ', #1
u'كسبحان': u'كَسُبْحَانَ', #3
u'كسبوخة': u'كَسَبُوخَةِ', #1
u'كسبى': u'كَسْبِى', #1
u'كسبيت': u'كَسَبَيْت', #1
u'كسبيت': u'كَسَبَيْتُ', #1
u'كسبين': u'كَسْبَيْنِ', #1
u'كستين': u'كَسِتِّينَ', #23
u'كسجدت': u'كَسَجَدَتْ', #1
u'كسحنون': u'كَسَحْنُونِ', #1
u'كسحنون': u'كَسَحْنُونٍ', #5
u'كسخل': u'كَسَخْلٍ', #2
u'كسخلة': u'كَسَخْلَةٍ', #3
u'كسراحين': u'كَسَرَاحِينَ', #1
u'كسرتنى': u'كَسَرَتْنِى', #1
u'كسرحان': u'كَسَرْحَانُ', #1
u'كسرحان': u'كَسِرْحَانٍ', #1
u'كسرحان': u'كَسِرْحَانِ', #2
u'كسرحت': u'كَسَرَّحَتْ', #1
u'كسرقين': u'كَسِرْقِينٍ', #3
u'كسرقينه': u'كَسِرْقِينِهِ', #4
u'كسرقينها': u'كَسِرْقِينِهَا', #1
u'كسرموذة': u'كَسُرْمُوذَةٍ', #1
u'كسرواني': u'كِسْرَوَانِيِّ', #1
u'كسرواني،': u'كِسْرَوَانِيٍّ،', #1
u'كسروانى': u'كَسْرَوَانِىٍّ', #1
u'كسرواني': u'كِسْرَوَانِيٌّ', #2
u'كسرواني': u'كِسْرَوَانِيٍّ', #6
u'كسروانية': u'كِسْرَوَانِيَّةٌ', #1
u'كسروانية': u'كِسْرَوَانِيَّةٍ', #3
u'كسروانية': u'كِسْرَوَانِيَّةً', #4
u'كسرورى': u'كَسُرُورِى', #1
u'كسع': u'كسع', #2
u'كسع': u'كَسَعَ', #9
u'كسفتجة': u'كَسُفْتَجَةٍ', #1
u'كسفتجة': u'كَسَفْتَجَةٍ', #6
u'كسفوف': u'كَسَفُوفٍ', #1
u'كسقنقور': u'كَسَقَنْقُورٍ', #2
u'كسقية': u'كَسَقِيَّةٍ', #2
u'كسكنجبين': u'كَسَكَنْجَبِينَ', #1
u'كسكندرية': u'كَسَكَنْدَرِيَّةٍ', #1
u'كسكيت': u'كَسِكِّيتٍ', #2
u'كسلاليم': u'كَسَلَالِيمَ', #2
u'كسلانا': u'كَسْلَانًا', #3
u'كسلمان': u'كَسَلْمَانَ', #5
u'كسليما': u'كسليما', #1
u'كسماحيق': u'كَسَمَاحِيقَ', #1
u'كسماحيق': u'كَسَمَاحِيقِ', #1
u'كسمسمة': u'كَسِمْسِمَةٍ', #9
u'كسمعان': u'كَسَمْعَانَ', #1
u'كسمعت': u'كَسَمِعْت', #1
u'كسمعت': u'كَسَمِعْتُ', #1
u'كسمعت': u'كسمعت', #2
u'كسمعت': u'كَسَمِعَتْ', #2
u'كسمند': u'كَسَمَنْدٍ', #1
u'كسنى': u'كَسِنِى', #14
u'كسهمان': u'كَسُهْمَانِ', #4
u'كسوب': u'كَسُوبٌ', #12
u'كسوب': u'كَسُوبٍ', #13
u'كسوبا': u'كَسُوبَا', #1
u'كسوبا': u'كَسُوبًا', #107
u'كسوبهم': u'كُسُوبُهُمْ', #1
u'كسوبين': u'كَسُوبِينَ', #1
u'كسوتكها': u'كَسَوْتُكَهَا', #2
u'كسوتنيه': u'كَسَوْتنِيهِ', #3
u'كسوتنيه': u'كَسَوْتَنِيهِ', #5
u'كسوتنيها': u'كَسَوْتنِيهَا', #2
u'كسوتنيها،': u'كَسَوْتَنِيهَا،', #2
u'كسوتنيها': u'كَسَوْتَنِيهَا', #9
u'كسويق': u'كَسَوِيقٍ', #3
u'كسيء': u'كَسَيْءِ', #1
u'كسياس': u'كَسَيَّاسٍ', #1
u'كسيب': u'كَسِيبٍ', #1
u'كسيب': u'كُسَيْبٍ', #3
u'كسيلة،': u'كُسَيْلَةُ،', #2
u'كسيلة': u'كُسَيْلَةُ', #3
u'كشاجم': u'كُشَاجِمُ', #3
u'كشادم': u'كشادم', #1
u'كشادنامه': u'كشادنامه', #1
u'كشاديس': u'كشاديس', #1
u'كشاكش': u'كَشَاكِشٍ', #1
u'كشاورزي': u'كشاورزي', #1
u'كشاوزري': u'كشاوزري', #1
u'كشبا': u'كَشْبًا', #1
u'كشبابة': u'كَشَبَّابَةٍ', #2
u'كشبرا': u'كَشُبْرَا', #1
u'كشبوبية': u'كَشُبُوبِيَّةٍ', #1
u'كشتل': u'كَشَتْلِ', #2
u'كشتن': u'كشتن', #1
u'كشتوان': u'كَشَتْوَانٍ', #1
u'كشتواني': u'كشتواني', #1
u'كشتواني': u'كُشْتَوَانِيٍّ', #1
u'كشحاء': u'كَشْحَاءَ', #1
u'كشحاة': u'كَشَحَاةِ', #1
u'كشحات': u'كَشَحَّاتٍ', #1
u'كشخان': u'كشخان', #1
u'كشخان': u'كَشْخَان', #1
u'كشخان': u'كَشْخَانٌ', #1
u'كشخان': u'كَشْخَانَ', #1
u'كشخان': u'كَشْخَانُ', #13
u'كشداديان': u'كشداديان', #1
u'كشرابة': u'كَشُرَابَةِ', #1
u'كشرابة': u'كَشَرَابَةِ', #2
u'كشرابة': u'كَشِرَابَةِ', #2
u'كشرحبيل': u'كَشُرَحْبِيلَ', #1
u'كشريب': u'كَشِرِّيبٍ', #1
u'كشسع': u'كَشِسْعِ', #6
u'كشطة': u'كَشْطَةٍ', #1
u'كشعبذة': u'كَشَعْبَذَةٍ', #1
u'كشقص': u'كَشِقْصٍ', #7
u'كشمرد': u'كَشْمَرْدْ', #1
u'كشمرد': u'كَشْمُرْدُ', #1
u'كشمرد': u'كُشْمَرْدُ', #2
u'كشمرد': u'كَشْمَرْدُ', #4
u'كشمش': u'كِشْمِشٍ', #1
u'كشميرا': u'كَشْمِيرًا', #1
u'كشنبر': u'كَشَنْبَرٍ', #1
u'كشنبر': u'كَشَنْبَرِ', #1
u'كشنى': u'كُشْنَى', #1
u'كشهادتان': u'كَشَهَادَتَانِ', #1
u'كشهدت': u'كَشَهِدْتُ', #5
u'كشئت': u'كَشِئْت', #5
u'كشياع': u'كَشَيَاعٍ', #1
u'كشياع': u'كَشَيَاعِ', #4
u'كشياع': u'كَشِيَاعِ', #7
u'كص': u'كص', #1
u'كص': u'كَصّ', #1
u'كصبا': u'كَصِبًا', #8
u'كصببت': u'كَصَبَبْت', #1
u'كصدقت': u'كَصَدَقْتَ', #2
u'كصراصر': u'كَصَرَاصِرَ', #1
u'كصرائح': u'كَصَرَائِحِ', #3
u'كصلعم': u'كَصَلْعَمْ', #1
u'كصلقها': u'كَصَلْقِهَا', #1
u'كصنجة': u'كَصَنْجَةٍ', #3
u'كصه': u'كَصَهٍ', #1
u'كصه': u'كَصَهْ', #3
u'كصهار': u'كَصِهَارٍ', #1
u'كصوائف': u'كَصَوَائِفِ', #1
u'كصوتت': u'كَصَوَّتَتْ', #1
u'كصوموا': u'كَصُومُوا', #1
u'كصومين': u'كَصَوْمَيْنِ', #1
u'كصيال': u'كَصِيَالٍ', #1
u'كصيال': u'كَصِيَالِ', #1
u'كصيحاني': u'كَصَيْحَانِيِّ', #1
u'كصيحاني': u'كَصَيْحَانِيٍّ', #17
u'كصيدا': u'كَصَيْدَا', #1
u'كضحى': u'كَضُحًى', #1
u'كضربت': u'كَضَرَبْت', #3
u'كضربت': u'كَضَرَبْتُ', #4
u'كضعوا': u'كَضَعُوا', #1
u'كضمنت': u'كَضَمِنْت', #1
u'كضمنت': u'كَضَمِنْتُ', #23
u'كضيمران': u'كَضَيْمَرَانٍ', #1
u'كطاب': u'كَطَابَ', #2
u'كطاوس': u'كَطَاوُسٍ', #2
u'كطبت': u'كَطِبْت', #1
u'كطبرستان': u'كَطَبَرِسْتَانَ', #10
u'كطخاء': u'كَطَخَاءِ', #1
u'كطربة': u'كَطَرْبَةٍ', #1
u'كطرسوس': u'كَطَرَسُوسَ', #2
u'كطرو': u'كَطُرُّوِ', #1
u'كطرو': u'كَطُرُوِّ', #31
u'كطلبت': u'كَطَلَبْتُ', #4
u'كطلقت': u'كَطَلَّقْت', #2
u'كطلقت': u'كَطَلَّقْتُ', #2
u'كطلقني': u'كَطَلِّقْنِي', #21
u'كطنطن': u'كَطَنْطَنَ', #1
u'كطى': u'كَطَىِّ', #2
u'كظة': u'كِظَّةٌ', #1
u'كظننت': u'كَظَنَنْتُ', #3
u'كظهارين': u'كَظِهَارَيْنِ', #1
u'كظئر': u'كَظِئْرٍ', #2
u'كظيظ': u'كَظِيظُ', #1
u'كظيظ': u'كَظِيظٌ', #3
u'كظيظا': u'كَظِيظًا', #1
u'كع': u'كع', #1
u'كع': u'كَعِ', #1
u'كع': u'كَعَّ', #1
u'كع': u'كَعْ', #2
u'كعافاك': u'كَعَافَاك', #1
u'كعاقبت': u'كَعَاقَبْت', #1
u'كعاقبت': u'كَعَاقَبْتُ', #5
u'كعاوضتك': u'كَعَاوَضْتُكَ', #1
u'كعائن': u'كَعَائِنٍ', #1
u'كعباديد': u'كَعَبَادِيدَ', #1
u'كعبالبرق': u'كَعْبٌالْبَرْقُ', #1
u'كعبالة': u'كَعَبَالَةِ', #1
u'كعبأنهم': u'كَعْبٍأَنَّهُمْ', #1
u'كعباهاوالوجه': u'كَعْبَاهَاوَالْوَجْهُ', #1
u'كعبسألت': u'كَعْبٍسَأَلْتُ', #1
u'كعبفي': u'كَعْبٍفِي', #1
u'كعبما': u'كَعْبُمَا', #1
u'كعبمن': u'كَعْبٌمِنْ', #1
u'كعتقائه': u'كَعُتَقَائِهِ', #2
u'كعتقوا': u'كَعَتَقُوا', #1
u'كعتور': u'كَعَتْوَرٍ', #1
u'كعتور': u'كَعَتْوَرَ', #1
u'كعتور': u'كَعَتْوَرِ', #1
u'كعتيرة': u'كَعَتِيرَةٍ', #5
u'كعداس': u'كَعَدّاسِ', #1
u'كعدت': u'كَعُدْت', #1
u'كعدت': u'كَعُدْتُ', #1
u'كعديت': u'كَعَدَّيْت', #1
u'كعرقبتها': u'كَعَرْقَبَتِهَا', #1
u'كعزق': u'كَعَزْقِ', #1
u'كعسقلان': u'كَعَسْقَلَانَ', #3
u'كعسلهون': u'كَعَسْلَهُونٍ', #1
u'كعسلهون': u'كعسلهون', #4
u'كعسهلون': u'كعسهلون', #2
u'كعسى': u'كَعَسَى', #2
u'كعصا': u'كَعَصًا', #12
u'كعصرت': u'كَعَصَرْت', #1
u'كعصفر': u'كَعُصْفُرٍ', #4
u'كعصوان': u'كَعَصَوَانِ', #1
u'كعضاه': u'كَعِضَاهِ', #1
u'كعطن': u'كَعَطَنِ', #1
u'كعظمان': u'كَعَظْمَانِ', #1
u'كعفاصه': u'كَعِفَاصِهِ', #1
u'كعفص': u'كَعَفْصٍ', #6
u'كعفل': u'كَعَفَلٍ', #1
u'كعفوت': u'كَعَفَوْت', #1
u'كعفوت': u'كَعَفَوْتُ', #1
u'كعفى': u'كَعَفَى', #1
u'كعقدت': u'كَعَقَدْت', #7
u'كعكعت،': u'كَعْكَعْتَ،', #1
u'كعلابط': u'كَعُلَابِطٍ', #1
u'كعلاما': u'كَعَلَّامًا', #1
u'كعلس': u'كَعَلْسٍ', #1
u'كعلس': u'كَعَلَسٍ', #2
u'كعلفة': u'كَعَلَفَةٍ', #1
u'كعلقمة': u'كَعَلْقَمَةَ', #1
u'كعلمت': u'كَعَلِمَتْ', #1
u'كعلمت': u'كَعَلِمْت', #1
u'كعما': u'كَعْمًا', #1
u'كعمرويه': u'كَعَمْرَوَيْهِ', #1
u'كعموه': u'كَعَمُوهُ', #2
u'كعمى': u'كَعَمًى', #23
u'كعميان': u'كَعُمْيَانٍ', #1
u'كعنة': u'كَعُنَّةٍ', #5
u'كعنزروت': u'كَعَنْزَرُوتٍ', #1
u'كعنين': u'كَعِنِّينٍ', #7
u'كعوضتك': u'كَعَوَّضْتُكَ', #2
u'كعياض': u'كَعِيَاضٍ', #2
u'كعيبا': u'كُعَيْبًا', #1
u'كعيبة': u'كُعَيْبَةَ', #3
u'كعينت': u'كَعَيَّنْتُ', #1
u'كعينت': u'كَعَيَّنْت', #2
u'كعيينة': u'كَعُيَيْنَةٍ', #1
u'كغالط': u'كَغَالِطٍ', #2
u'كغرث': u'كَغَرِثَ', #1
u'كغرث': u'كَغَرَثٍ', #2
u'كغرث': u'كَغَرْثٍ', #2
u'كغرست': u'كَغَرَسْتُ', #2
u'كغرني': u'كَغَرْنَيْ', #1
u'كغزا': u'كَغَزَا', #1
u'كغزوت': u'كَغَزَوْتُ', #1
u'كغصبت': u'كَغَصَبْتُ', #2
u'كغصوب': u'كَغُصُوبٍ', #1
u'كغضنفر': u'كَغَضَنْفَرٍ', #1
u'كغلقت': u'كَغَلَّقْتِ', #1
u'كغلقت': u'كَغَلَّقَتْ', #3
u'كغنى': u'كَغِنًى', #2
u'كفء': u'كُفْءً', #12
u'كفاءة': u'كَفَاءَةً', #3
u'كفاتا': u'كِفَاتًا', #22
u'كفاثور': u'كَفَاثُورِ', #2
u'كفارةاليمين': u'كَفَّارَةِالْيَمِينِ', #1
u'كفارةقال': u'كَفَّارَةٌقَالَ', #1
u'كفارسا': u'كَفَارِسًا', #1
u'كفارقت': u'كَفَارَقْتُ', #1
u'كفأفاء': u'كَفَأْفَاءٍ', #2
u'كفآن': u'كُفْآنِ', #1
u'كفانى': u'كَفَانِى', #1
u'كفائف': u'كَفَائِفَ', #1
u'كفتا': u'كَفْتًا', #1
u'كفتال': u'كَفَتَّالٍ', #1
u'كفتند': u'كفتند', #2
u'كفتنى': u'كَفَتْنِى', #1
u'كفتى': u'كَفَتًى', #3
u'كفتياه': u'كَفُتْيَاهُ', #2
u'كفجء': u'كَفَجْءِ', #3
u'كفدك': u'كَفَدَكِ', #1
u'كفدك': u'كَفَدَكَ', #9
u'كفرهمقوله': u'كُفْرِهِمْقَولُهُ', #1
u'كفرواأئذا': u'كَفَرُواأَئِذَا', #1
u'كفسخت': u'كَفَسَخْتُ', #17
u'كفعيل': u'كَفَعِيلٍ', #1
u'كفعيلة': u'كَفَعِيلَةٍ', #3
u'كففوها': u'كَفّفُوهَا', #2
u'كفقء': u'كَفَقْءِ', #4
u'كفككت': u'كَفَكَكْتُ', #1
u'كفلسته': u'كَفَلَّسْتُهُ', #1
u'كفلو': u'كَفُلُوِّ', #1
u'كفنى': u'كَفَنِى', #2
u'كفو،': u'كُفُوٌ،', #1
u'كفو': u'كُفُوٌ', #2
u'كفوا': u'كَفُّوًا', #1
u'كفوا،': u'كُفْوًا،', #1
u'كفوا': u'كُفُوًا', #40
u'كفوائت': u'كَفَوَائِتَ', #1
u'كفوف': u'كُفُوفٌ', #1
u'كفويسة': u'كَفُوَيْسَةٍ', #1
u'كفئيته': u'كُفْئِيَّتُهُ', #1
u'كفيتكموه': u'كَفَيْتُكُمُوهُ', #1
u'كفيروزج': u'كَفَيْرُوزَجَ', #1
u'كق': u'كَقِ', #2
u'كقابيل': u'كَقَابِيلٍ', #1
u'كقابيل': u'كَقَابِيلَ', #1
u'كقاتلوا': u'كَقَاتِلُوا', #1
u'كقام': u'كَقَامَ', #12
u'كقامت': u'كَقَامَتْ', #5
u'كقامتا': u'كَقَامَتَا', #1
u'كقاموا': u'كَقَامُوا', #2
u'كقائف': u'كَقَائِفٍ', #2
u'كقبلت': u'كَقَبِلْتُ', #17
u'كقبلت': u'كَقَبِلْت', #6
u'كقتلت': u'كَقَتَلْتُ', #1
u'كقتلت': u'كَقَتَلْت', #2
u'كقرافة': u'كَقَرَافَةِ', #3
u'كقرأين': u'كَقُرْأَيْنِ', #1
u'كقرطقة': u'كَقُرْطَقَةٍ', #1
u'كقرظ': u'كَقَرَظٍ', #5
u'كقرنى': u'كَقَرْنَىِ', #2
u'كقرى': u'كَقُرًى', #4
u'كقريظة': u'كَقُرَيْظَةَ', #1
u'كقسمت': u'كَقَسَمْتُ', #1
u'كقصارين': u'كَقَصَّارَيْنِ', #1
u'كقضى': u'كَقَضَى', #1
u'كقطام': u'كَقَطَام', #1
u'كقطام': u'كَقَطَامٍ', #1
u'كقطام': u'كَقَطَامِ', #2
u'كقطعت': u'كَقَطَّعْتُ', #1
u'كقعاص': u'كَقُعَاصِ', #5
u'كقعد': u'كَقَعَدَ', #1
u'كقعدت': u'كَقَعَدْت', #1
u'كقفا': u'كَقَفًا', #1
u'كقفاء': u'كَقَفَاءِ', #1
u'كقفازة': u'كَقُفَّازَةٍ', #1
u'كقفيز': u'كَقَفِيزِ', #19
u'كقفيز': u'كَقَفِيزٍ', #30
u'كقفيزي': u'كَقَفِيزَيْ', #2
u'كقفيزين': u'كَقَفِيزَيْنِ', #3
u'كقلت': u'كَقُلْتُ', #1
u'كقلشانة': u'كَقَلْشَانَةَ', #1
u'كقم': u'كَقُمْ', #4
u'كقمت': u'كَقُمْتُ', #3
u'كقنسرين': u'كَقِنّسْرِينَ', #1
u'كقنين': u'كَقِنَّيْنِ', #1
u'كقوصرة': u'كَقَوْصَرَّةِ', #12
u'كقوصرة': u'كَقَوْصَرَةِ', #2
u'كقوصرة': u'كَقَوْصَرَّةٍ', #5
u'كقولنج': u'كَقُولَنْجِ', #1
u'كقولنج': u'كَقُولَنْجَ', #3
u'كقولى': u'كَقَوْلِى', #1
u'كقياسات': u'كَقِيَاسَاتِ', #1
u'ككاتبني': u'كَكَاتِبْنِي', #3
u'ككالئ': u'كَكَالِئٍ', #1
u'ككأن': u'كَكَأَنَّ', #1
u'ككان': u'كَكَانَ', #1
u'ككتبت': u'كَكَتَبْتُ', #6
u'ككحال': u'كَكَحَّالٍ', #4
u'ككحالين': u'كَكَحَّالَيْنِ', #3
u'ككذا': u'كَكَذَا', #15
u'ككرباس': u'كَكِرْبَاسٍ', #13
u'ككرباس': u'كَكِرْبَاسَ', #2
u'ككرس': u'كَكِرْسِ', #1
u'ككرناس': u'كَكِرْنَاسٍ', #1
u'ككسفرة': u'كَكُسْفَرَةٍ', #1
u'ككفت': u'كَكَفْتِ', #2
u'ككفلت': u'كَكَفَلْتُ', #3
u'ككفلت': u'كَكَفَلْت', #4
u'ككفى': u'كَكَفَى', #1
u'ككلا': u'كَكِلَا', #1
u'ككلاءة': u'كَكِلَاءَةِ', #3
u'ككلامين': u'كَكَلَامَيْنِ', #4
u'ككلما': u'كَكُلَّمَا', #10
u'ككما': u'كَكَمَا', #2
u'ككنا': u'ككُنّا', #1
u'ككنا': u'كَكُنّا', #1
u'ككنت': u'كَكُنْتُ', #3
u'ككوم': u'كَكَوْمِ', #1
u'كل': u'كُلًّ', #1
u'كلاءة': u'كَلَاءَةِ', #1
u'كلاءة': u'كِلَاءَةِ', #1
u'كلاءة': u'كِلَاءَةً', #3
u'كلاءته': u'كِلَاءَتِهِ', #2
u'كلأثلاث': u'كَلِأَثْلَاثٍ', #1
u'كلأحد': u'كَلِأَحَدِ', #3
u'كلأخذ': u'كَلِأَخْذِ', #1
u'كلأدخلن': u'كَلَأَدْخُلَنَّ', #2
u'كلإراحته': u'كَلِإِرَاحَتِهِ', #1
u'كلأشربن': u'كَلَأَشْرَبَنَّ', #1
u'كلأضربنه': u'كَلَأَضْرِبَنَّهُ', #1
u'كلاع': u'كلاع', #1
u'كلاع': u'كَلاعٍ', #1
u'كلاع': u'كَلاَعٍ', #1
u'كلاع،': u'كَلَاعٍ،', #1
u'كلاع': u'كَلَاعٍ', #5
u'كلأعطين': u'كَلَأُعْطِيَنَّ', #2
u'كلافا': u'كُلَافًا', #1
u'كلأفعلن': u'كَلَأَفْعَلَنَّ', #3
u'كلاكلا': u'كَلَاكِلًا', #1
u'كلألزمنك': u'كَلَأَلْزَمَنَّكَ', #1
u'كلام': u'كَلَامً', #1
u'كلامان': u'كَلَامَانِ', #7
u'كلاماه': u'كَلَامَاهُ', #2
u'كلاماهما': u'كَلَامَاهُمَا', #1
u'كلامنا': u'كُلًّامِنَّا', #1
u'كلامى': u'كَلاَمِى', #3
u'كلإه': u'كَلإِهِ', #1
u'كلبست': u'كَلَبِسْت', #1
u'كلبى': u'كَلْبِى', #11
u'كلتبان': u'كَلْتَبَانُ', #1
u'كلتداوني': u'كَلِتُدَاوِنِي', #2
u'كلتعتقني': u'كَلِتَعْتِقَنِي', #5
u'كلتقرأ': u'كَلِتَقْرَأَ', #1
u'كلتقرأ': u'كَلِتَقْرَأْ', #2
u'كلتمة': u'كَلْتَمَةُ', #1
u'كلحى': u'كَلِحًى', #1
u'كلخصمه': u'كَلِخَصْمِهِ', #5
u'كلخن': u'كَلَخْنِ', #1
u'كلدة': u'كِلْدَةُ', #1
u'كلدة،': u'كَلَدَة،', #1
u'كلدة': u'كِلْدَةَ', #18
u'كلدة': u'كَلْدَةَ', #2
u'كلدة،': u'كَلَدَةَ،', #2
u'كلدة': u'كَلَدَة', #4
u'كلدة': u'كلدة', #7
u'كلدة': u'كَلَدَةَ', #71
u'كلدة': u'كَلَدَةُ', #8
u'كلركعة': u'كُلِّرَكْعَةٍ', #1
u'كلزيد': u'كَلِزَيْدٍ', #2
u'كلسوق': u'كَلِسَوْقِ', #1
u'كلضوء': u'كَلِضَوْءٍ', #1
u'كلطت': u'كَلُطْتَ', #1
u'كلغيره': u'كَلِغَيْرِهِ', #2
u'كلفاء': u'كَلِفَاءِ', #1
u'كلفتكموه': u'كَلّفْتُكُمُوهُ', #2
u'كلفنى': u'كَلَّفَنِى', #2
u'كلقصاص': u'كَلِقِصَاصٍ', #1
u'كلقع': u'كَلَقْعِ', #1
u'كلقيت': u'كَلَقِيتُ', #1
u'كلكل': u'كَلْكَلِ', #1
u'كلكلها': u'كَلْكَلُهَا', #2
u'كلكلي': u'كَلْكَلِي', #2
u'كلكونه': u'كَلِكَوْنِهِ', #1
u'كللإحرام': u'كَلِلْإِحْرَامِ', #1
u'كللصبي': u'كَلِلصَّبِيِّ', #1
u'كللميت': u'كَلِلْمَيِّتِ', #1
u'كللنسا': u'كَلِلنِّسَا', #1
u'كلمتكا': u'كَلَّمْتُكَا', #1
u'كلمتى': u'كَلِمَتَىِ', #7
u'كلمتيني': u'كَلَّمْتِينِي', #4
u'كلمنى': u'كَلِّمْنِى', #1
u'كلمنى': u'كَلَّمَنِى', #2
u'كلندي': u'كلندي', #2
u'كلهاSمن': u'كُلّهَاSمِنْ', #1
u'كلهاوالوجه': u'كُلِّهَاوَالْوَجْهُ', #2
u'كلهدة': u'كَلْهَدَةُ', #1
u'كلهمقوله': u'كُلُّهُمْقَولُهُ', #1
u'كلهمو': u'كُلَّهُمُو', #2
u'كلهمو': u'كُلِّهِمُو', #2
u'كلهنه': u'كُلُّهُنَّهْ', #1
u'كلهوكذلك': u'كُلِّهِوَكَذَلِكَ', #2
u'كلو': u'كَلَوْ', #26
u'كلواحد': u'كَلِوَاحِدٍ', #2
u'كلواذى': u'كَلْوَاذَى', #1
u'كلوارثي': u'كَلِوَارِثِي', #1
u'كلوب': u'كَلُّوبٍ', #1
u'كلوب': u'كَلُّوبٌ', #3
u'كلوليمة': u'كَلِوَلِيمَةٍ', #1
u'كليبة': u'كُلَيْبَة', #1
u'كليبة': u'كُلَيْبَةٌ', #3
u'كليجة': u'كليجة', #3
u'كليدخلن': u'كَلَيَدْخُلَنَّ', #1
u'كليس': u'كَلِيسِ', #1
u'كليس': u'كَلَيْسَ', #12
u'كليست': u'كَلَيْسَتْ', #2
u'كليصلين': u'كَلَيُصَلِّيَنَّ', #1
u'كليطة': u'كَلِيطَةٍ', #1
u'كليطة': u'كَلِيطَةِ', #1
u'كليفعلن': u'كَلَيَفْعَلَنَّ', #2
u'كليقومن': u'كَلَيَقُومَنَّ', #4
u'كمأبور': u'كَمَأْبُورِ', #1
u'كماة': u'كُمَاةٌ', #1
u'كماة': u'كُمَاةَ', #2
u'كماة': u'كُمَاةٍ', #4
u'كماصدق': u'كَمَاصَدَقَ', #1
u'كمائن': u'كَمَائِنَ', #1
u'كمبرسم': u'كَمُبَرْسَمٍ', #1
u'كمبعض': u'كَمُبَعَّضٍ', #10
u'كمبعضة': u'كَمُبَعَّضَةٍ', #2
u'كمبقى': u'كَمُبَقًّى', #1
u'كمبقى': u'كَمُبْقًى', #1
u'كمتبدع': u'كَمُتَبَدِّعٍ', #1
u'كمتبر': u'كَمُتَبَرٍّ', #1
u'كمتمحض': u'كَمُتَمَحِّضِ', #5
u'كمتهب': u'كَمُتَّهَبٍ', #3
u'كمتوفى': u'كَمُتَوَفًّى', #4
u'كمتى': u'كَمَتَى', #90
u'كمثراة': u'كُمُّثْرَاة', #1
u'كمثراة': u'كُمَّثْرَاةٌ', #3
u'كمثمونه': u'كَمَثْمُونِهِ', #13
u'كمجاعلة': u'كَمُجَاعَلَةِ', #2
u'كمجبوب': u'كَمَجْبُوبٍ', #13
u'كمجذمة': u'كَمُجْذَمَةٍ', #1
u'كمحاصة': u'كَمُحَاصَّةِ', #1
u'كمحاويجهم': u'كَمَحَاوِيجِهِمْ', #1
u'كمحتفر': u'كَمُحْتَفَرٍ', #3
u'كمحصر': u'كَمُحْصِرٍ', #3
u'كمحصر': u'كَمُحْصَرٍ', #7
u'كمخاريق': u'كمخاريق', #1
u'كمخذل': u'كَمُخْذِلٍ', #1
u'كمخذل': u'كَمِخْذَلٍ', #1
u'كمخذل': u'كَمُخَذِّلٍ', #5
u'كمخفوضات': u'كَمَخْفُوضَاتٍ', #1
u'كمدحت': u'كَمَدَحْتُ', #1
u'كمدعوا': u'كَمَدْعُوًّا', #1
u'كمدهامتان': u'كَمُدْهَامَّتَانِ', #4
u'كمذروع': u'كَمَذْرُوعٍ', #3
u'كمذكى': u'كَمُذَكَّى', #2
u'كمذي': u'كَمَذْيِ', #1
u'كمذي': u'كَمَذْيٍ', #8
u'كمرا': u'كِمْرًا', #1
u'كمرأة': u'كَمَرْأَةٍ', #20
u'كمرأتين': u'كَمَرْأَتَيْنِ', #6
u'كمراطلة': u'كَمُرَاطَلَةِ', #1
u'كمرحم': u'كَمِرْحَمٍ', #1
u'كمررت': u'كَمَرَرْتُ', #1
u'كمرزبة': u'كَمِرْزَبَةٍ', #1
u'كمرزجوش': u'كَمَرْزَجُوشٍ', #1
u'كمروان': u'كَمَرْوَانَ', #2
u'كمريئا': u'كَمَرِيئًا', #1
u'كمزربة': u'كَمِزْرَبَةٍ', #1
u'كمزفوفة': u'كَمَزْفُوفَةٍ', #1
u'كمسبل': u'كَمُسَبَّلٍ', #1
u'كمستبرأة': u'كَمُسْتَبْرَأَةٍ', #12
u'كمستبضع': u'كَمُسْتَبْضِعٍ', #1
u'كمستبضع': u'كَمُسْتَبْضِعِ', #2
u'كمستبضع': u'كَمُسْتَبْضَعٍ', #3
u'كمستثنى': u'كَمُسْتَثْنًى', #1
u'كمستحاضة': u'كَمُسْتَحَاضَةِ', #1
u'كمستحاضة': u'كَمُسْتَحَاضَةٍ', #24
u'كمسحت': u'كَمَسَحْت', #1
u'كمسحت': u'كَمَسَحْتُ', #1
u'كمسطاح': u'كَمِسْطَاحٍ', #1
u'كمسلمانية': u'كَمَسْلَمَانِيَّةٍ', #1
u'كمسلمانية': u'كَمَسْلَمَانِيَّةِ', #2
u'كمسمند': u'كمسمند', #1
u'كمسمى': u'كَمُسَمًّى', #4
u'كمشارع': u'كَمَشَارِعِ', #1
u'كمشة': u'كَمْشَةٌ', #1
u'كمشة': u'كَمْشَةُ', #2
u'كمشترى': u'كَمُشْتَرَى', #1
u'كمشية': u'كَمِشْيَةِ', #4
u'كمشيتك': u'كَمِشْيَتِكَ', #1
u'كمضايفة': u'كَمُضَايَفَةِ', #1
u'كمعتاضه': u'كَمُعْتَاضِهِ', #1
u'كمعتجر': u'كَمُعْتَجَرِ', #1
u'كمعتقون': u'كَمُعْتَقُونَ', #1
u'كمعتمل': u'كَمُعْتَمَلٍ', #1
u'كمعجر': u'كَمِعْجَرِ', #1
u'كمعجوز': u'كَمَعْجُوزٍ', #4
u'كمعراض': u'كَمِعْرَاضٍ', #2
u'كمعسور': u'كَمَعْسُورٍ', #1
u'كمعض': u'كَمَعَضِّ', #1
u'كمعضوب': u'كَمَعْضُوبٍ', #3
u'كمعطوم': u'كَمَعْطُومِ', #1
u'كمعوان': u'كَمِعْوَانٍ', #1
u'كمعى': u'كَمِعًى', #3
u'كمغرة': u'كَمَغْرَةٍ', #3
u'كمغزول': u'كَمَغْزُولِ', #2
u'كمغطى': u'كَمُغَطًّى', #1
u'كمغفر': u'كَمِغْفَرٍ', #3
u'كمغمى': u'كَمُغْمًى', #12
u'كمفاخذة': u'كَمُفَاخَذَةٍ', #3
u'كمفادة': u'كَمُفَادَةِ', #1
u'كمقتديا': u'كَمُقْتَدِيًا', #1
u'كمقتنى': u'كَمُقْتَنَى', #1
u'كمقرد': u'كَمِقْرَدٍ', #1
u'كمقلش': u'كَمُقْلِشٍ', #1
u'كمكاس': u'كَمَكَّاسٍ', #1
u'كمكتراة': u'كَمُكْتَرَاةٍ', #2
u'كمكترى': u'كَمُكْتَرًى', #1
u'كمكحول': u'كَمَكْحُولٍ', #3
u'كمكنوز': u'كَمَكْنُوزٍ', #1
u'كملا': u'كَمُلًا', #5
u'كملا': u'كَمَلًا', #62
u'كملتوى': u'كَمُلْتَوَى', #2
u'كملزوم': u'كَمَلْزُومٍ', #1
u'كملكت': u'كملكت', #1
u'كملكت': u'كَمَلَكْتُ', #1
u'كملكتكه': u'كَمَلَّكْتُكَهُ', #1
u'كمنبوشة': u'كَمَنْبُوشَةٍ', #1
u'كمنتفل': u'كَمُنْتَفَلٍ', #1
u'كمنتهب': u'كَمُنْتَهِبٍ', #1
u'كمنخرق': u'كَمُنْخَرِقِ', #1
u'كمنخل': u'كَمُنْخُلٍ', #2
u'كمنوب': u'كَمَنُوبٍ', #1
u'كمنى': u'كَمِنًى', #15
u'كمهريق': u'كَمُهْرِيقٍ', #1
u'كمهزور': u'كَمَهْزُورٍ', #1
u'كمؤاجرة': u'كَمُؤَاجَرَةِ', #1
u'كمواجل': u'كمواجل', #1
u'كمواجل': u'كَمُوَاجَلِ', #1
u'كمواضعة': u'كَمُوَاضَعَةٍ', #3
u'كمؤتم': u'كَمُؤْتَمٍّ', #3
u'كموجوء': u'كَمَوْجُوءِ', #2
u'كموصى': u'كَمُوصًى', #14
u'كموطوءة': u'كَمَوْطُوءَةٍ', #6
u'كموطوءة': u'كَمَوْطُوءَةِ', #8
u'كموطوءتهما': u'كَمَوْطُوءَتِهِمَا', #2
u'كموقوفية': u'كَمَوْقُوفِيَّةِ', #1
u'كمؤل': u'كَمُؤْلٍ', #1
u'كمؤنة': u'كَمَؤُنَةِ', #1
u'كمؤنة': u'كَمُؤْنَةٍ', #1
u'كمؤنة': u'كَمُؤْنَةِ', #55
u'كمؤنته': u'كَمُؤْنَتِهِ', #5
u'كمؤنتها': u'كَمُؤْنَتِهَا', #2
u'كمؤنتهم': u'كَمُؤْنَتِهِمْ', #1
u'كمئونة': u'كَمَئُونَةِ', #1
u'كميشة': u'كَمِيشَةٌ', #1
u'كميضأة': u'كَمِيضَأَةِ', #1
u'كناثور': u'كَنَاثُورِ', #1
u'كناجنانكه': u'كناجنانكه', #1
u'كنارى': u'كنارى', #1
u'كناشا': u'كُنَاشًا', #1
u'كنانةأنه': u'كِنَانَةَأَنَّهُ', #1
u'كنانتى': u'كِنَانَتِى', #2
u'كنانى': u'كَنَّانِى', #1
u'كناولني': u'كَنَاوَلَنِي', #1
u'كنائيا': u'كِنَائِيًّا', #2
u'كنبوشا': u'كُنْبُوشًا', #1
u'كنبيب': u'كَنَبِيبِ', #13
u'كنبيت': u'كنُبَيِّتُ', #1
u'كنت': u'كُنْتً', #1
u'كنتزوجك': u'كَنَتَزَوَّجُكِ', #1
u'كنتمو': u'كُنْتُمُو', #1
u'كنتيا': u'كُنْتِيًّا', #3
u'كنجا': u'كَنَجَا', #2
u'كنجدبا': u'كنجدبا', #1
u'كنجيح': u'كَنَجِيحٍ', #2
u'كندار': u'كَنْدَار', #1
u'كندازين': u'كندازين', #1
u'كندة،': u'كندة،', #1
u'كندة': u'كِنْدَةٌ', #1
u'كندة،': u'كِنْدَة،', #1
u'كندة؟': u'كِنْدَةَ؟', #1
u'كندة،': u'كِنْدَةَ،', #12
u'كندة': u'كِنْدة', #2
u'كندة': u'كِنْدَة', #2
u'كندة،': u'كِنْدة،', #4
u'كندة': u'كِنْدَةُ', #6
u'كندة': u'كندة', #8
u'كندة': u'كِنْدَةَ', #96
u'كندةوروي': u'كِنْدَةَوَرُوِيَ', #1
u'كندس': u'كَنَدُسٍ', #1
u'كندست': u'كندست', #2
u'كندشا': u'كُنْدُشًا', #1
u'كندغارت': u'كندغارت', #1
u'كندكه': u'كندكه', #2
u'كندوا': u'كندوا', #2
u'كندوج': u'كَنْدُوجٍ', #1
u'كندوج': u'كُنْدُوجِ', #1
u'كندوج': u'كُنْدُوجٍ', #2
u'كندوح': u'كَنْدُوحِ', #1
u'كندير': u'كَنْدِيرَ', #1
u'كندير': u'كِنْدِيرَ', #2
u'كنذرت': u'كَنَذَرْتُ', #6
u'كنر': u'كنر', #1
u'كنسإ': u'كَنَسَإٍ', #1
u'كنسخت': u'كَنَسَخْتُ', #2
u'كنسيت': u'كَنَسِيتُ', #1
u'كنشا': u'كَنَشًا', #1
u'كنضوض': u'كَنُضُوضِ', #2
u'كنضوض': u'كَنَضُوضِ', #3
u'كنطرون': u'كَنَطْرُونٍ', #2
u'كنطقت': u'كَنَطَقَتِ', #1
u'كنعان': u'كَنْعَانَ', #17
u'كنعان': u'كَنْعَانُ', #2
u'كنعان،': u'كَنْعَانَ،', #2
u'كنعدا': u'كَنْعَدًا', #1
u'كنغف': u'كَنَغَفِ', #1
u'كنفتيه': u'كَنَفَتَيْهِ', #1
u'كنفعني': u'كَنَفَعَنِي', #1
u'كنفى': u'كَنَفَىْ', #1
u'كنقضت': u'كَنَقَضْتُ', #1
u'كنقضته': u'كَنِقْضَتِهِ', #1
u'كنقضته': u'كَنَقَضْتُهُ', #2
u'كنقلت': u'كَنَقَلْت', #1
u'كنقلت': u'كَنَقَلْتُ', #2
u'كنكحت': u'كَنَكَحْتُ', #1
u'كنمت': u'كنمت', #1
u'كنند': u'كنند', #2
u'كنندا': u'كنندا', #1
u'كننده': u'كننده', #1
u'كنندو': u'كنندو', #2
u'كنهدت': u'كَنَهَدَتْ', #1
u'كنواقض': u'كَنَوَاقِضِ', #1
u'كنوت': u'كَنَوْتُ', #1
u'كنوت': u'كَنَوْتِ', #1
u'كنود': u'كَنُودٌ', #1
u'كنودا': u'كَنُودًا', #1
u'كنورة': u'كَنُورَةِ', #2
u'كنورة': u'كَنُورَةٍ', #3
u'كنورة': u'كَنَوْرَةٍ', #5
u'كنوى': u'كَنَوًى', #3
u'كنويت': u'كَنَوَيْتُ', #12
u'كنياحة': u'كَنِيَاحَةٍ', #1
u'كنيتى': u'كُنْيَتِى', #2
u'كنيد': u'كُنيد', #1
u'كنيد': u'كنيد', #2
u'كنيز،': u'كُنَيْزٍ،', #1
u'كنيز': u'كَنِيزٍ', #3
u'كنيز': u'كُنَيْزٍ', #3
u'كنيفة': u'كَنَيِّفَةِ', #1
u'كنيلة': u'كَنِيلَةٍ', #1
u'كنيم': u'كنيم', #3
u'كنينا': u'كَنِينًا', #1
u'كه': u'كُهْ', #1
u'كه': u'كِهْ', #1
u'كه': u'كه', #279
u'كها': u'كَهَا', #1
u'كهات': u'كَهَاتِ', #1
u'كهاروت': u'كَهَارُوتَ', #14
u'كهاما': u'كَهَامًا', #1
u'كهذ': u'كهذ', #1
u'كهذ': u'كَهَذِّ', #17
u'كهراة': u'كَهَرَاةَ', #1
u'كهراش': u'كَهِرَاشِ', #1
u'كهرني،': u'كَهَرَنِي،', #1
u'كهرني': u'كَهَرَنِي', #10
u'كهرنى': u'كَهَرَنِى', #5
u'كهطلاء': u'كَهَطْلَاءَ', #1
u'كهلانية': u'كَهْلَانِيَّةٌ', #2
u'كهلوالوجه': u'كَهْلٍوَالْوَجْهُ', #1
u'كهلوف': u'كَهِلَّوْفٍ', #5
u'كهليلوي': u'كهليلوي', #1
u'كهمسا': u'كَهْمَسًا', #4
u'كهملاج': u'كَهِمْلَاجٍ', #1
u'كهميان': u'كَهِمْيَانٍ', #1
u'كهنا': u'كُهْنًا', #1
u'كهنام': u'كَهِنَامٍ', #1
u'كهندباء': u'كَهِنْدِبَاءَ', #1
u'كهوازن': u'كَهَوَازِنَ', #1
u'كهيعص': u'كهيعص', #22
u'كهيئتى': u'كَهَيْئَتِى', #1
u'كوا': u'كُوًا', #1
u'كوا': u'كَوَا', #3
u'كوابصة': u'كَوَابِصَةَ', #1
u'كوارات': u'كُوَّارَاتِ', #1
u'كوارات': u'كِوَارَاتٍ', #1
u'كوارات': u'كِوَارَاتُ', #1
u'كوارات': u'كُوَّارَاتُ', #2
u'كوارات': u'كُوَّارَاتٍ', #3
u'كواراته': u'كُوَّارَاتِهِ', #3
u'كواراتها': u'كِوَارَاتِهَا', #1
u'كواراتها': u'كُوَّارَاتِهَا', #2
u'كوارة': u'كُوَارَةُ', #1
u'كوارة': u'كُوَّارَةٌ', #1
u'كوارة': u'كِوَارَة', #1
u'كوارة': u'كِوَارَةً', #1
u'كوارة': u'كُوَّارَةُ', #2
u'كوارة': u'كُوَّارَةً', #4
u'كوارة': u'كِوَارَةٍ', #5
u'كوارة': u'كُوَّارَةٍ', #9
u'كوارت': u'كُوَّارِتُ', #1
u'كوارته': u'كَوَارَتِهِ', #3
u'كوارته': u'كِوَارَتِهِ', #3
u'كوارته': u'كُوَّارَتِهِ', #8
u'كوارتها': u'كُوَّارَتِهَا', #1
u'كوازه': u'كوازه', #1
u'كواكبا': u'كَواكِبًا', #1
u'كواكهفاه': u'كَوَاكَهْفَاهُ', #1
u'كوالحا': u'كَوَالِحَا', #2
u'كوالله': u'كوالله', #1
u'كوالله': u'كَوَاللَّهِ', #109
u'كوانى': u'كَوَانِى', #2
u'كواهان': u'كواهان', #2
u'كواهى': u'كَواهى', #1
u'كواهى': u'كواهى', #6
u'كوأواء': u'كَوَأْوَاءٍ', #1
u'كوائل': u'كَوَائِلِ', #2
u'كوبة': u'كُوبَةٍ', #5
u'كوتبنه': u'كُوتَبْنَهُ', #1
u'كوتبنه': u'كُوتَبْنَهْ', #1
u'كوثا،': u'كُوثَا،', #1
u'كوثقت': u'كَوَثِقْت', #1
u'كوثي': u'كُوثِي', #1
u'كوثى': u'كُوثَى', #4
u'كوجدت': u'كَوَجَدْت', #1
u'كوجدت': u'كَوَجَدْتُ', #1
u'كوحق': u'كَوَحَقِّ', #4
u'كوخش': u'كَوَخْشٍ', #2
u'كودنا': u'كَوْدَنًا', #1
u'كوذين': u'كُوذَيْنِ', #3
u'كورات': u'كُوَّرَاتُ', #1
u'كورات': u'كُورَاتُ', #2
u'كوراتها': u'كُورَاتِهَا', #1
u'كورايا': u'كورايا', #1
u'كوركان': u'كَوْرُكَانَ', #1
u'كوزبشت': u'كوزبشت', #1
u'كوزى': u'كَوْزَى', #1
u'كوساله': u'كوساله', #1
u'كوست': u'كوست', #8
u'كوسج': u'كَوْسَجَ', #1
u'كوسج': u'كَوْسَجٍ', #3
u'كوسج': u'كَوْسَجُ', #3
u'كوسج': u'كَوْسَجٌ', #4
u'كوسجا': u'كوسجا', #1
u'كوسجا،': u'كَوْسَجًا،', #1
u'كوسجا': u'كَوْسَجًا', #5
u'كوسفند': u'كوسفند', #4
u'كوسفنديكي': u'كوسفنديكي', #1
u'كوسيت': u'كوسيت', #1
u'كوسيند': u'كوسيند', #1
u'كوش': u'كوش', #1
u'كوش': u'كُوشُ', #1
u'كوش': u'كُوشَ', #2
u'كوش': u'كُوشِ', #2
u'كوشاد': u'كوشاد', #1
u'كوشاد': u'كُوشَادٍ', #1
u'كوشت': u'كوشت', #2
u'كوشن': u'كَوْشَنِ', #1
u'كوصيت': u'كَوَصَّيْتُ', #1
u'كوضوئى': u'كَوُضُوئِى', #1
u'كوعظمة': u'كَوَعَظَمَةِ', #12
u'كوعظمته': u'كَوَعَظَمَتِهِ', #2
u'كوفان': u'كَوْفَانُ', #1
u'كوفتن': u'كوفتن', #3
u'كوفى': u'كُوفِىٌّ', #16
u'كوقرة': u'كَوَقْرَةٍ', #1
u'كوقفت': u'كَوَقَفْت', #16
u'كوقفت': u'كَوَقَفْتُ', #38
u'كوكلت': u'كَوَكَّلْت', #3
u'كوكلتني': u'كَوَكَّلْتَنِي', #2
u'كوكيع': u'كَوَكِيعٍ', #1
u'كول': u'كُولِ', #1
u'كولاد': u'كَوِلَادٍ', #1
u'كولان': u'كُولَانِ', #1
u'كوليت': u'كَوَلَّيْتُ', #1
u'كوليتكه': u'كَوَلَّيْتُكَهُ', #1
u'كوما': u'كَوْمًا', #15
u'كوماء': u'كَوْمَاءَ', #10
u'كوماء': u'كَوْمَاء', #2
u'كوماوتين': u'كَوْمَاوَتَيْنِ', #1
u'كوماوين': u'كَوْمَاوَيْنِ', #2
u'كومئ': u'كومئ', #1
u'كومين': u'كَوْمَيْنِ', #8
u'كوهبت': u'كَوَهَبْت', #3
u'كوهبت': u'كَوَهَبْتُ', #6
u'كوهبتكه': u'كَوَهَبْتُكَهُ', #2
u'كوهبتكها': u'كَوَهَبْتُكَهَا', #1
u'كوهرستي': u'كوهرستي', #3
u'كوهكيلوني': u'كوهكيلوني', #2
u'كوهى': u'كَوَهَى', #1
u'كوئي': u'كوئي', #1
u'كويبة': u'كَوَيْبَةٍ', #4
u'كويددر': u'كويددر', #1
u'كويدش': u'كويدش', #1
u'كويم': u'كويم', #8
u'كى': u'كِى', #1
u'كى': u'كَىْ', #12
u'كئود': u'كَئُودٍ', #1
u'كئود': u'كَئُودٌ', #2
u'كئودا': u'كَئُودًا', #5
u'كئودها': u'كَئُودهَا', #1
u'كئودها': u'كَئُودُهَا', #1
u'كئى': u'كئى', #1
u'كيأجوج': u'كَيَأْجُوجَ', #1
u'كيادا': u'كِيَادًا', #1
u'كيجوز': u'كَيَجُوزُ', #1
u'كيحل': u'كَيَحِلُّ', #2
u'كيحيى': u'كَيَحْيَى', #4
u'كيخرج': u'كَيَخْرُجُ', #2
u'كيخرجون': u'كَيَخْرُجُونَ', #1
u'كيخص': u'كَيَخُصُّ', #1
u'كيدعو': u'كَيَدْعُو', #1
u'كيدون': u'كِيدُونِ', #1
u'كيذكر': u'كَيُذْكَرُ', #1
u'كيراونا': u'كيراونا', #1
u'كيربادشاه': u'كيربادشاه', #1
u'كيرحمك': u'كَيَرْحَمُكَ', #1
u'كيرد': u'كيرد', #3
u'كيرضى': u'كَيَرْضَى', #2
u'كيرفتم': u'كيرفتم', #2
u'كيرفته': u'كيرفته', #1
u'كيرم': u'كيرم', #20
u'كيرنده': u'كيرنده', #2
u'كيرو': u'كيرو', #1
u'كيروزن': u'كيروزن', #1
u'كيريد': u'كَيُرِيدُ', #1
u'كيزان': u'كِيزَانُ', #1
u'كيزان': u'كِيزَانِ', #11
u'كيزان': u'كِيزَانٌ', #2
u'كيزان': u'كِيزَانٍ', #3
u'كيزانا': u'كِيزَانًا', #2
u'كيزانه': u'كِيزَانه', #1
u'كيزانه': u'كِيزَانِهِ', #3
u'كيزك': u'كيزك', #1
u'كيزه': u'كيزه', #2
u'كيزيد': u'كَيَزِيدَ', #5
u'كيسانية': u'كَيْسَانِيَّةٌ', #1
u'كيسجدون': u'كَيَسْجُدُونَ', #1
u'كيسمع': u'كَيَسْمَعُ', #1
u'كيشاء': u'كَيَشَاءُ', #1
u'كيشكر': u'كَيَشْكُرُ', #2
u'كيضرب': u'كَيَضْرِب', #14
u'كيضرب': u'كَيَضْرِبُ', #2
u'كيطلب': u'كَيَطْلُبُ', #1
u'كيعد': u'كَيَعِدُ', #1
u'كيعملها': u'كَيَعْمَلُهَا', #1
u'كيفتيه': u'كِيفَتَيْهِ', #1
u'كيفرح': u'كَيَفْرَح', #1
u'كيفرح': u'كَيَفْرَحُ', #1
u'كيكرم': u'كَيُكْرِم', #1
u'كيكلدي': u'كيكلدي', #3
u'كيل': u'كَيْلً', #1
u'كيلجات': u'كِيلَجَاتٍ', #3
u'كيلجة': u'كَيْلَجَةُ', #1
u'كيلجة،': u'كَيْلَجَةُ،', #11
u'كيلجة': u'كِيلَجَةُ', #2
u'كيلجة،': u'كِيلَجَةَ،', #2
u'كيلجة،': u'كيلجة،', #3
u'كيلجة،': u'كَيْلَجَةَ،', #4
u'كيلزمك': u'كَيَلْزَمُكَ', #1
u'كيلزمني': u'كَيَلْزَمُنِي', #2
u'كيلملم': u'كَيَلَمْلَمُ', #1
u'كيلون': u'كِيلُونَ', #1
u'كيلون': u'كِيلُونٌ', #2
u'كيمحو': u'كَيَمْحُو', #1
u'كيمخت': u'كيمخت', #1
u'كيمخت': u'كَيْمَخْتٍ', #3
u'كيمل': u'كَيَمَلُّ', #1
u'كيمنع': u'كَيَمْنَع', #1
u'كيمنع': u'كَيَمْنَعُ', #1
u'كيموسات': u'كَيْمُوسَاتٍ', #1
u'كينة': u'كِينَةَ', #1
u'كينصر': u'كَيَنْصُرُ', #4
u'كينصر': u'كَيَنْصُر', #5
u'كيهك': u'كِيَهْكَ', #1
u'كيهك': u'كِيَهْكُ', #1
u'كيهك': u'كَيْهَكْ', #2
u'كيوشع': u'كَيُوشَعَ', #5
u'كيول': u'كَيّولُ', #1
u'لاSتأويل': u'لَاSتَأْوِيلُ', #1
u'لأ': u'لأَ', #1
u'لإ': u'لِإ', #1
u'لإ': u'لِإِ', #1
u'لاء': u'لَاءً', #1
u'لاء': u'لَاءٍ', #2
u'لاءك': u'لَاءَكَ', #1
u'لاأذان': u'لَاأَذَانَ', #1
u'لاإلا': u'لَاإِلَّا', #1
u'لاالصغير': u'لَاالصّغِيرَ', #1
u'لاالمورث': u'لاَالْمُوَرِّثَ', #1
u'لإبارتهم': u'لِإِبَارَتِهِمْ', #1
u'لاباس': u'لاباس', #1
u'لإباق': u'لِإِبَاقِ', #3
u'لإباقه': u'لِإِبَاقِهِ', #13
u'لآبائى': u'لآبَائِى', #1
u'لإباية': u'لِإِبَايَةِ', #3
u'لابتدرتموه': u'لاَبْتَدَرْتُمُوهُ', #2
u'لابتدرتموه': u'لَابْتَدَرْتُمُوهُ', #3
u'لابتدره': u'لَابْتَدَرَهُ', #1
u'لابتى': u'لابتى', #1
u'لابتى': u'لاَبَتَىْ', #1
u'لابتى': u'لاَبَتَىِ', #12
u'لابراهيم': u'لابْرَاهِيمَ', #1
u'لأبرهة': u'لِأَبْرَهَةَ', #2
u'لأبرويز': u'لأبرويز', #1
u'لإبريسم': u'لِإبْرَيْسَمٍ', #1
u'لأبشهما': u'لِأَبَشِّهِمَا', #2
u'لأبضاع': u'لِأَبْضَاعِ', #1
u'لإبضاع': u'لِإِبْضَاعِ', #1
u'لإبطانهم': u'لِإِبْطَانِهِمْ', #1
u'لإبعاضه': u'لِإِبْعَاضِهِ', #1
u'لابعثه': u'لِابْعَثْهُ', #1
u'لآبق': u'لِآبِقٍ', #3
u'لأبلغية': u'لِأَبْلَغِيَّةِ', #1
u'لإبن': u'لإِبْنِ', #1
u'لإبني': u'لإِبْنِي', #1
u'لابنى': u'لابنى', #1
u'لابنى': u'لاِبْنَىْ', #1
u'لابنى': u'لاِبْنِى', #7
u'لإبي': u'لإِبِي', #11
u'لاتأتنا': u'لاتأتنا', #1
u'لأتألفهم': u'لأَتَأَلَّفَهُمْ', #2
u'لأتألفهم': u'لِأَتَأَلَّفَهُمْ', #3
u'لاتخف': u'لاتخف', #1
u'لأتخولكم': u'لأتخولكم', #1
u'لأتخولكم': u'لَأَتَخَوَّلُكُمْ', #1
u'لاتدخلن': u'لاتدخلن', #1
u'لإتساع': u'لِإِتْسَاعِ', #1
u'لإتساعه': u'لِإِتْسَاعِهِ', #1
u'لأتعار': u'لأَتَعَارَّ', #1
u'لاتفعل': u'لَاتَفْعَلْ', #1
u'لاتمام': u'لاتمام', #1
u'لاتمان': u'لِاتِّمَانِ', #1
u'لاتمشي': u'لاتمشي', #1
u'لإتهامه': u'لِإِتْهَامِهِ', #7
u'لإتهامهما': u'لِإِتْهَامِهِمَا', #1
u'لاتين': u'لاتِيَنَّ', #1
u'لاثنان': u'لَاثْنَانِ', #1
u'لاجاج': u'لِاجاج', #1
u'لأجبتSالحلف': u'لَأَجَبْتSالْحِلْفُ', #1
u'لاجتزأ': u'لَاجْتَزَأَ', #2
u'لاجتزائه': u'لِاجْتِزَائِهِ', #1
u'لاجتنانه': u'لِاجْتِنَانِهِ', #1
u'لاجتنانهم': u'لِاجْتِنَانِهِمْ', #4
u'لاجرا': u'لاجْرًا', #1
u'لأجزأت': u'لأَجْزَأَتْ', #1
u'لأجزأت': u'لأَجْزَأْتَ', #1
u'لأجزأت': u'لَأَجْزَأَتْ', #6
u'لأجزأته': u'لَأَجْزَأَتْهُ', #9
u'لأجزأتهم': u'لَأَجْزَأَتْهُمْ', #2
u'لأجزاك': u'لَأَجْزَاك', #1
u'لأجزاه': u'لَأَجْزَاهُ', #1
u'لاجعلا': u'لِاجْعَلَا', #2
u'لإجل': u'لِإِجْلِ', #3
u'لإجنابها': u'لِإِجْنَابِهَا', #1
u'لاجون': u'لَاجُّونَ', #1
u'لاجين': u'لَاجِينٍ', #1
u'لاجين': u'لَاجِينِ', #1
u'لاجين': u'لَاجِينَ', #18
u'لاجين': u'لَاجِينُ', #2
u'لأجيئه': u'لأَجِيئَهُ', #1
u'لاحببت': u'لاَحْبَبْت', #1
u'لاحبة': u'لَاحِبَةً', #1
u'لاحتشاش': u'لِاحْتِشَاشِ', #3
u'لاحتواشه': u'لِاحْتِوَاشِهِ', #4
u'لإحد،': u'لإِحَدٍ،', #1
u'لإحد': u'لِإِحَدِ', #1
u'لإحد': u'لإِحَدٍ', #3
u'لأحدثنهموه': u'لأحدثنهموه', #1
u'لأحدثنهموه': u'لَأُحدّثُنّهموه', #1
u'لإحرامى': u'لإِحْرَامِى', #1
u'لأحروية': u'لِأَحْرَوِيَّةِ', #1
u'لأحرويتها': u'لِأَحْرَوِيَّتِهَا', #2
u'لاحسب': u'لاحْسَبَ', #1
u'لأحسنية': u'لِأَحْسَنِيَّةِ', #2
u'لإحصار': u'لِإِحْصَارِ', #1
u'لإحصار': u'لِإِحْصَارٍ', #4
u'لإحصاره': u'لِإِحْصَارِهِ', #8
u'لأحقيتها': u'لِأَحَقِّيَّتِهَا', #1
u'لاحمق': u'لاحْمَقٌ', #1
u'لإحيا': u'لِإِحْيَا', #1
u'لأحيحة': u'لِأُحَيْحَةَ', #1
u'لأخبرنى': u'لأَخْبَرَنِى', #1
u'لاختصاء': u'لِاخْتِصَاءٍ', #1
u'لاختلع': u'لَاخْتَلَعَ', #1
u'لأختى': u'لأُخْتِى', #1
u'لإخدام': u'لِإِخْدَامِ', #2
u'لإخدامها': u'لِإِخْدَامِهَا', #1
u'لأخدما': u'لِأُخْدَمَا', #3
u'لإخرابها': u'لِإِخْرَابِهَا', #2
u'لأخرجنى': u'لأَخْرَجَنِى', #1
u'لآخريته': u'لِآخِرِيَّتِهِ', #5
u'لأخصائه': u'لِأَخِصَّائِهِ', #1
u'لأخضناها': u'لأَخَضْنَاهَا', #1
u'لأخضناها،': u'لأَخَضْنَاهَا،', #2
u'لأخضناها': u'لَأَخَضْنَاهَا', #3
u'لأخواتى': u'لأَخَوَاتِى', #1
u'لإخي': u'لإِخِي', #1
u'لأخى': u'لأَخِى', #2
u'لأخيشن': u'لَأُخَيْشَنٌ', #1
u'لأخيشن': u'لَأُخَيْشِنٌ', #1
u'لإخيه': u'لإِخِيهِ', #1
u'لأخيهإذا': u'لِأَخِيهِإِذَا', #1
u'لإدخار': u'لِإِدْخَارِ', #1
u'لأدراصها': u'لِأَدْرَاصِهَا', #1
u'لادراك': u'لِادِّرَاكِ', #1
u'لأدردن': u'لَأَدْرَدَنَّ', #1
u'لإدلال': u'لِإِدْلَالِ', #2
u'لإدلاله': u'لِإِدْلَالِهِ', #1
u'لأدلنك': u'لَأَدُلَّنَّكَ', #1
u'لادم': u'لَادِمٍ', #1
u'لإذ': u'لَإِذْ', #1
u'لإذا': u'لِإِذَا', #5
u'لإذاية': u'لإذاية', #1
u'لإذاية': u'لِإذَايَةِ', #2
u'لإذاية': u'لِإِذَايَةِ', #5
u'لإذايته': u'لِإِذَايَتِهِ', #3
u'لإذايتها': u'لِإِذَايَتِهَا', #3
u'لإذايتهم': u'لِإِذَايَتِهِمْ', #1
u'لإذايتهما': u'لِإِذَايَتِهِمَا', #2
u'لاذن': u'لَاذَنٍ', #1
u'لاذن': u'لَاذَنُ', #1
u'لاذهبي': u'لِاذْهَبِي', #1
u'لإراءة': u'لِإِرَاءَةِ', #5
u'لاراكم': u'لاَرَاكُمْ', #1
u'لأرانى': u'لأَرَانِى', #1
u'لأربعينين': u'لِأَرْبَعِينَيْنِ', #1
u'لارتباع': u'لِارْتِبَاعِ', #1
u'لارتتاق': u'لِارْتِتَاقِ', #1
u'لارتجاس': u'لِارْتِجَاسِ', #2
u'لارتجع': u'لَارْتَجَعَ', #1
u'لأرتشى': u'لأَرْتَشِى', #1
u'لارتضاع': u'لِارْتِضَاعِ', #2
u'لارتضاعها': u'لِارْتِضَاعِهَا', #4
u'لارتفاض': u'لِارْتِفَاضِ', #5
u'لارتفاضه': u'لِارْتِفَاضِهِ', #2
u'لارتفاضهما': u'لِارْتِفَاضِهِمَا', #3
u'لارتفاق': u'لِارْتِفَاقِ', #13
u'لارتفاق': u'لِارْتِفَاقٍ', #3
u'لارتفاقه': u'لِارْتِفَاقِهِ', #13
u'لارتفاقهم': u'لِارْتِفَاقِهِمْ', #2
u'لارتقاق': u'لِارْتِقَاقِ', #1
u'لارجمنك': u'لارْجُمَنَّكَ', #2
u'لارجو': u'لارْجُو', #3
u'لأرسطاطاليس': u'لأرسطاطاليس', #1
u'لأرسطاطاليس': u'لأَرِسْطَاطَاليس', #1
u'لأرسطوطاليس': u'لِأَرِسْطُوطَالِيسَ', #1
u'لإرضاعة': u'لِإِرْضَاعَةِ', #1
u'لارضي': u'لَارضي', #1
u'لارفضت': u'لَارْفَضَّتْ', #1
u'لأرفضوا': u'لأَرْفَضُوا', #1
u'لإرقاق': u'لِإِرْقَاقِ', #4
u'لإرقاقه': u'لِإِرْقَاقِهِ', #2
u'لإرقاقهما': u'لِإِرْقَاقِهِمَا', #1
u'لإرقائه': u'لِإِرْقَائِهِ', #1
u'لأرياط': u'لِأَرْيَاطٍ', #1
u'لاريتكم': u'لاَرَيْتُكُمْ', #1
u'لأرينق': u'لِأُرَيْنِقَ', #1
u'لازاد': u'لازاد', #1
u'لازال': u'لَازَالَ', #5
u'لأزدشير': u'لِأَزْدَشِيرْ', #1
u'لازدلافها': u'لِازْدِلَافِهَا', #1
u'لاززته': u'لَازَزْتُهُ', #1
u'لازقة': u'لَازِقَةٍ', #1
u'لازمدر': u'لازمدر', #1
u'لإزواجك': u'لإِزْوَاجِك', #1
u'لاس': u'لاس', #1
u'لاس': u'لاسٍ', #2
u'لاس': u'لاَسٍ', #2
u'لاس': u'لَاسٍ', #5
u'لأسامة': u'لأسامة', #1
u'لأسامة': u'لِأُسَامَة', #2
u'لأسامة': u'لِأُسَامَةَ', #43
u'لأسامة': u'لأُسَامَةَ', #8
u'لإسامتها': u'لِإِسَامَتِهَا', #3
u'لاستار': u'لَاسْتَارٌ', #1
u'لأستأمنه،': u'لِأَسْتَأْمِنَهُ،', #1
u'لإستانبول': u'لِإِسْتَانْبُولَ', #1
u'لأستبحثن': u'لَأَسْتَبْحِثَنَّ', #2
u'لاستتابهم،': u'لاسْتَتَابَهَمْ،', #1
u'لاستتبته': u'لَاسْتَتَبْتُهُ', #1
u'لاستتمام': u'لِاسْتِتْمَامِ', #8
u'لاستثبت': u'لَاسْتَثْبَتَ', #2
u'لاستجازة': u'لِاسْتِجَازَةِ', #1
u'لاستجمار': u'لِاسْتِجْمَارِ', #1
u'لاستحاضة': u'لِاسْتِحَاضَةِ', #1
u'لاستحاضة': u'لِاسْتِحَاضَةٍ', #3
u'لاستحاضتها': u'لِاسْتِحَاضَتِهَا', #1
u'لأستحفين': u'لأَسْتَحْفِيَنَّ', #2
u'لاستحمقوه': u'لَاسْتَحْمَقُوهُ', #1
u'لأستحيى': u'لأَسْتَحْيِى', #5
u'لاستخار': u'لَاسْتَخَارَ', #1
u'لاستخباث': u'لِاسْتِخْبَاثِ', #3
u'لاستخباثه': u'لِاسْتِخْبَاثِهِ', #10
u'لاستخباثها': u'لِاسْتِخْبَاثِهَا', #11
u'لاستد': u'لَاسْتَدَّ', #2
u'لاستدخال': u'لِاسْتِدْخَالِ', #3
u'لاسترابته': u'لِاسْتِرَابَتِهِ', #1
u'لاسترار': u'لِاسْتِرَارِ', #1
u'لاستراضة': u'لِاسْتِرَاضَةِ', #2
u'لاسترقاق': u'لِاسْتِرْقَاقِ', #6
u'لاسترقاقها': u'لِاسْتِرْقَاقِهَا', #2
u'لاستزكائهم': u'لِاسْتِزْكَائِهِمْ', #1
u'لاستسعاء': u'لِاسْتِسْعَاءِ', #3
u'لاستسعائه': u'لِاسْتِسْعَائِهِ', #1
u'لاستسمانها': u'لِاسْتِسْمَانِهَا', #1
u'لاستشمام': u'لِاسْتِشْمَامِ', #2
u'لاستضرار': u'لِاسْتِضْرَارِ', #1
u'لاستطراق': u'لِاسْتِطْرَاقٍ', #3
u'لاستطراقه': u'لِاسْتِطْرَاقِهِ', #1
u'لاستعقاب': u'لِاسْتِعْقَابِ', #3
u'لاستعقابه': u'لِاسْتِعْقَابِهِ', #15
u'لاستعقابها': u'لِاسْتِعْقَابِهَا', #2
u'لاستغزار': u'لِاسْتِغْزَارِ', #1
u'لاستفراخه': u'لِاسْتِفْرَاخِهِ', #2
u'لاستفراخها': u'لِاسْتِفْرَاخِهَا', #1
u'لاستفراش': u'لِاسْتِفْرَاشِ', #1
u'لاستفصل': u'لَاسْتَفْصَلَ', #3
u'لاستفصله': u'لَاسْتَفْصَلَهُ', #1
u'لاستقاءة': u'لِاسْتِقَاءَةٍ', #1
u'لاستقذرته': u'لَاسْتَقْذَرْتَهُ', #1
u'لاستكافة': u'لِاسْتِكَافَةٍ', #1
u'لاستلحاقة': u'لِاسْتِلْحَاقَةِ', #1
u'لاستملك': u'لَاسْتَمْلَكَ', #1
u'لاستنانه': u'لِاسْتِنَانِهِ', #6
u'لاستنبت': u'لَاسْتُنْبِتَ', #1
u'لاستنبتت': u'لَاسْتُنْبِتَتْ', #3
u'لاستنقاعه': u'لِاسْتِنْقَاعِهِ', #1
u'لاستنكاح': u'لِاسْتِنْكَاحِ', #3
u'لاستنماء': u'لِاسْتِنْمَاءِ', #3
u'لاستهدام': u'لِاسْتِهْدَامٍ', #1
u'لاستهدامه': u'لِاسْتِهْدَامِهِ', #2
u'لاستهموا': u'لاسْتَهَمُوا', #1
u'لاستهموا،': u'لاسْتَهَمُوا،', #1
u'لاستهموا': u'لَاسْتَهَمُوا', #23
u'لاستهموا': u'لاَسْتَهَمُوا', #3
u'لاستي': u'لِاسْتِي', #1
u'لاستى': u'لاِسْتِى', #2
u'لاستئكال': u'لِاسْتِئْكَالِ', #1
u'لاستئنائها': u'لِاسْتِئْنَائِهَا', #1
u'لاستيجاه': u'لِاسْتِيجَاهِ', #1
u'لاستيفا': u'لِاسْتِيفَا', #1
u'لاستيفازه': u'لِاسْتِيفَازِهِ', #4
u'لاستيناء': u'لِاسْتِينَاءٍ', #1
u'لاستيهابه': u'لِاسْتِيهَابِهِ', #1
u'لأسراء': u'لِأُسَرَاءَ', #1
u'لأسراء': u'لِأُسَرَاءِ', #1
u'لإسرار': u'لِإِسْرَارِ', #2
u'لإسراره': u'لِإِسْرَارِهِ', #1
u'لإسرارها': u'لِإِسْرَارِهَا', #3
u'لإسرارهم': u'لِإِسْرَارِهِمْ', #1
u'لإسرافيل': u'لِإِسْرَافِيلَ', #1
u'لإسقاء': u'لِإِسْقَاءِ', #1
u'لإسقائه': u'لِإِسْقَائِهِ', #1
u'لاسقيناهم': u'لاسْقَيْنَاهُمْ', #1
u'لأسكي': u'لأسكي', #1
u'لاسمع': u'لاسْمَعُ', #1
u'لأسوأنك': u'لَأَسْوَأْنَك', #1
u'لأسوأنك': u'لَأَسُوأَنَّك', #3
u'لأسوأنك': u'لَأَسُوأَنَّكِ', #7
u'لأسيد': u'لِأُسَيْدِ', #3
u'لأسيد': u'لِأُسَيْدٍ', #5
u'لأسيفع': u'لِأُسَيْفِعِ', #1
u'لاشتفاء': u'لِاشْتِفَاءِ', #2
u'لاشتفاف': u'لِاشْتِفَافِ', #1
u'لأشتكيك': u'لَأَشْتَكِيك', #1
u'لاشتمار': u'لِاشْتِمَارِ', #1
u'لأشديته': u'لِأَشَدِّيَّتِهِ', #4
u'لأشرفيته': u'لِأَشْرَفِيَّتِهِ', #1
u'لأشمويل': u'لأَشْمَويلَ', #1
u'لأشهريته': u'لِأَشْهَرِيَّتِهِ', #1
u'لاصبرن': u'لاصْبِرَنَّ', #1
u'لأصبينه': u'لَأُصْبِيَنَّهُ', #1
u'لأصحابهإنكم': u'لأَصْحَابِهِإِنَّكُمُ', #1
u'لأصحابى': u'لأَصْحَابِى', #9
u'لأصحية': u'لِأَصَحِّيَّةِ', #1
u'لاصق': u'لاصِقً', #1
u'لاصلاة': u'لاصَلاةَ', #1
u'لأصلحيته': u'لِأَصْلَحِيَّتِهِ', #2
u'لأصوبية': u'لِأَصْوَبِيَّةِ', #1
u'لأضرت': u'لَأَضَرَّتْ', #1
u'لأضررنا': u'لَأَضْرَرْنَا', #9
u'لأضعفية': u'لِأَضْعَفِيَّةِ', #1
u'لإطراد': u'لِإِطْرَادِ', #1
u'لأطعمتكموه': u'لأَطْعَمْتُكُمُوهُ', #1
u'لأطعمتكموه': u'لَأَطْعَمْتُكُمُوهُ', #1
u'لأطعمتكموه،': u'لَأَطْعَمْتُكُمُوهُ،', #1
u'لاطلاقهم': u'لِاطِّلَاقِهِمْ', #1
u'لاطمع': u'لاطْمَعُ', #1
u'لأطؤها': u'لَأَطَؤُهَا', #1
u'لاطئ،': u'لَاطِئٌ،', #1
u'لاطئا': u'لَاطِئًا', #1
u'لاطئة': u'لاطِئَةٍ', #1
u'لاطئة': u'لاَطِئَةٍ', #1
u'لاطئة،': u'لَاطِئَةَ،', #1
u'لاطئة': u'لَاطِئَةً', #3
u'لاطئة': u'لَاطِئَةٍ', #8
u'لاطية': u'لَاطِيَةٌ', #1
u'لاطية': u'لاَطِيَةٌ', #1
u'لاعاقبهم': u'لاعَاقِبُهُمْ', #1
u'لاعتضاد': u'لِاعْتِضَادِ', #17
u'لاعتضاده': u'لَاعْتِضَادِهِ', #1
u'لاعتضاده': u'لِاعْتِضَادِهِ', #51
u'لاعتضادها': u'لِاعْتِضَادِهَا', #18
u'لاعتضادهما': u'لِاعْتِضَادِهِمَا', #3
u'لاعتضاضها': u'لِاعْتِضَاضِهَا', #1
u'لاعتقاقه': u'لِاعْتِقَاقِهِ', #1
u'لإعثاره': u'لِإِعْثَارِهِ', #1
u'لأعجام': u'لِأَعْجَامٍ', #1
u'لأعدلية': u'لِأَعْدَلِيَّةِ', #1
u'لأعدليتهما': u'لِأَعْدلِيَّتِهِما', #1
u'لأعرابى': u'لأَعْرَابِىٍّ', #4
u'لأعرفنكها': u'لِأُعَرِّفَنكهَا', #1
u'لأعرفنكها': u'لَأُعَرِّفَنَّكَهَا', #1
u'لأعرفنكها': u'لأُعَرِّفَنَّكَهَا', #2
u'لاعز': u'لاعَزَّ', #1
u'لأعضضته': u'لَأَعْضَضْتُهُ', #1
u'لأعضضته': u'لَأْعَضَضْتُهُ', #1
u'لأعطان': u'لأَعْطَانِ', #1
u'لأعطان': u'لِأَعْطَانِ', #1
u'لأعطيات': u'لِأُعْطِيَّاتِ', #1
u'لاعطينا': u'لاعْطَيْنَا', #1
u'لأعظميته': u'لِأَعْظَمِيَّتِهِ', #2
u'لاعقب': u'لاعقب', #2
u'لإعلاق': u'لِإِعْلَاقِ', #1
u'لإعلاقه': u'لِإِعْلَاقِهِ', #1
u'لأعلميته': u'لِأَعْلَمِيَّتِهِ', #2
u'لأعمى': u'لِأَعْمًى', #1
u'لاعي': u'لَاعِي', #1
u'لأعيت': u'لَأَعْيَتْ', #1
u'لأغادينهم': u'لَأُغَادِيَنهُمْ', #1
u'لأغادينهم': u'لَأُغَادِيَنّهُمْ', #1
u'لإغار': u'لإِغَارَ', #1
u'لأغذرت': u'لَأَغْذَرْتُ', #1
u'لأغشيتكيه': u'لَأَغْشَيْتَكِيهِ', #1
u'لاغفل': u'لاغْفَلَ', #1
u'لاغلب': u'لاغْلَبُ', #1
u'لأغيلمة': u'لأغَيلِمَةٍ', #1
u'لافتكاك': u'لِافْتِكَاكِ', #1
u'لافتكه': u'لَافْتَكَّهُ', #1
u'لافتياته': u'لِافْتِيَاتِهِ', #80
u'لافتياتها': u'لِافْتِيَاتِهَا', #1
u'لافتياتهم': u'لِافْتِيَاتِهِمْ', #2
u'لإفشي': u'لإِفْشِيَ', #1
u'لإفصاد': u'لِإِفْصَادٍ', #1
u'لافعلن،': u'لافْعَلَنَّ،', #2
u'لأفلعن': u'لَأَفْلَعَنَّ', #1
u'لاقا': u'لَاقًّا', #1
u'لاقال': u'لاَقَالَ', #1
u'لإقام': u'لِإِقَامِ', #2
u'لإقامه': u'لِإِقَامِهِ', #1
u'لإقباض': u'لِإِقْبَاضِ', #1
u'لإقباضه': u'لِإِقْبَاضِهِ', #3
u'لاقتال': u'لَاقْتَالَ', #1
u'لاقتلوا': u'لِاقْتُلُوا', #1
u'لأقدته': u'لأَقَدْتُهُ', #1
u'لأقدته': u'لَأَقَدْتُهُ', #1
u'لأقدتها': u'لأَقَدْتُهَا', #1
u'لاقرا': u'لَاقْرَا', #1
u'لأقراء': u'لِأَقْرَاءٍ', #1
u'لأقراء': u'لِأَقْرَاءِ', #1
u'لأقربية': u'لِأَقْرَبِيَّةِ', #6
u'لأقربيتهم': u'لأقربيتهم', #1
u'لأقربيتهما': u'لأقربيتهما', #1
u'لأقرحة': u'لِأَقْرِحَةٍ', #1
u'لإقضاء': u'لِإِقْضَاءِ', #1
u'لأقطعنيها': u'لأَقْطَعَنِيهَا', #1
u'لأقطعنيها': u'لَأَقْطَعَنِيهَا', #2
u'لاقعبان': u'لاقَعْبان', #2
u'لاقولن': u'لاقُولَنَّ', #1
u'لأقوميته': u'لِأَقْوَمِيَّتِهِ', #1
u'لأقوويته': u'لِأَقْوَوِيَّتِهِ', #1
u'لاقيس': u'لَاقِيسَ', #1
u'لاقيكا': u'لاقيكا', #1
u'لأكدرة': u'لِأَكْدَرَةَ', #1
u'لآكديته': u'لِآكَدِيَّتِهِ', #1
u'لآكديتها': u'لِآكَدِيِّتِهَا', #1
u'لآكديتها': u'لِآكَدِيَّتِهَا', #3
u'لأكسا': u'لأَكْسَا', #1
u'لأكساب': u'لِأَكْسَابِ', #1
u'لأكسابه': u'لِأَكْسَابِهِ', #2
u'لأكسابها': u'لِأَكْسَابِهَا', #2
u'لأكسوته': u'لَأَكْسَوْتُهُ', #1
u'لأكسوكها': u'لأَكْسُوَكَهَا', #1
u'لأكسوكها': u'لِأَكْسُوَكَهَا', #1
u'لاكشة': u'لاكشة', #1
u'لأكفيكموه': u'لَأَكْفِيكُمُوهُ', #1
u'لأكفيكنه،': u'لَأَكْفِيكَنَّهُ،', #1
u'لأكفينكنه': u'لأكْفِينّكُنّه', #2
u'لأكلنيSحديث': u'لَأَكَلَنِيSحَدِيثُ', #1
u'لإكلها': u'لإِكُلَهَا', #1
u'لأكلهقوله': u'لأَكْلِهِقَوْلُهُ', #1
u'لاكن': u'لَاكِنٍ', #1
u'لأكنو': u'لَأَكْنُو', #1
u'لأكيدر': u'لأُكَيْدِرِ', #1
u'لأكيدر': u'لِأُكَيْدِرَ', #2
u'لأكيدر': u'لِأُكَيْدِرِ', #2
u'لأكيدر': u'لِأُكَيْدِرٍ', #3
u'لأكيدن': u'لأَكِيدَنَّ', #3
u'لأكيدن': u'لَأَكِيدَنَّ', #9
u'لإل': u'لِإِلّ', #2
u'لال': u'لَالٍ', #5
u'لإلا': u'لِإِلَّا', #1
u'لالتمام': u'لِالْتِمَامِ', #1
u'لإلكيا': u'لِإِلْكِيَا', #2
u'لالم': u'لالَّم', #1
u'لالى': u'لالَى', #1
u'لأليس': u'لِأَلَيْسَ', #3
u'لإما': u'لِإِمَّا', #1
u'لأمامة': u'لِأُمَامَةَ', #1
u'لامتنى': u'لاَمَتْنِى', #1
u'لأمتى': u'لِأُمْتَى', #1
u'لإمتي': u'لإِمَّتِي', #2
u'لأمتى': u'لأُمَّتِى', #33
u'لامر،': u'لاَمْرٌ،', #1
u'لامرا': u'لامْرًا', #2
u'لإمرأة': u'لإمْرَأَةٍ', #1
u'لإمرأة': u'لإِمْرَأَةٍ', #1
u'لامرآته': u'لِامْرَآتِهِ', #1
u'لامرأتى': u'لاِمْرَأَتِى', #4
u'لأمرة': u'لِأَمَرَةٍ', #1
u'لامرتهم': u'لاَمَرْتُهُمْ', #1
u'لإمرئ': u'لإِمْرِئٍ', #1
u'لامش': u'لامش', #1
u'لامش': u'لَامِشَ', #2
u'لأمشير': u'لِأَمْشِيرْ', #1
u'لإمصار': u'لِإِمْصَارٍ', #1
u'لامكان': u'لَامِكَانِ', #3
u'لأملئنها': u'لأَمْلَئَنَّهَا', #1
u'لأمهة': u'لِأَمَّهَةٍ', #1
u'لامونا': u'لَامُونًا', #1
u'لأمى': u'لأُمِىِّ', #1
u'لإمي': u'لإِمِّي', #2
u'لأمى': u'لأُمِّى', #5
u'لانا': u'لَانًا', #1
u'لإنا': u'لِإِنَّا', #3
u'لأناثها': u'لِأُنَاثِهَا', #1
u'لإناس': u'لِإِنَاسٍ', #1
u'لاناصهم': u'لاناصهم', #1
u'لأنافتها': u'لِأَنَافَتِهَا', #1
u'لأنالإمام': u'لِأَنَّالْإِمَامَ', #1
u'لأنبابة': u'لِأُنْبَابَةَ', #1
u'لانبأتكم': u'لاَنْبَأْتُكُمْ', #1
u'لأنبأتكموه': u'لَأَنْبَأْتُكُمُوهُ', #1
u'لإنباه': u'لِإِنْبَاهِ', #1
u'لانبغى': u'لَانْبَغَى', #10
u'لانبهام': u'لِانْبِهَامِ', #3
u'لانبهامها': u'لِانْبِهَامِهَا', #6
u'لأنتجز': u'لِأَنْتَجِزَ', #1
u'لانتشاب': u'لِانْتِشَابِ', #1
u'لإنتظار': u'لإنتظار', #2
u'لانتغص': u'لَانْتَغَصَ', #1
u'لأنتنته': u'لَأَنْتَنَتْهُ', #1
u'لأنثى': u'لِأُنْثًى', #2
u'لانجرحا': u'لَانْجَرَحَا', #1
u'لانجزار': u'لِانْجِزَارِ', #1
u'لأنجشة': u'لِأَنْجَشَةَ', #3
u'لانجماد': u'لِانْجِمَادِ', #3
u'لانجمادها': u'لِانْجِمَادِهَا', #1
u'لانحتام': u'لِانْحِتَامِ', #1
u'لانخلاقه': u'لِانْخِلَاقِهِ', #2
u'لانخلاقهما': u'لِانْخِلَاقِهِمَا', #1
u'لانخناس': u'لِانْخِنَاسٍ', #1
u'لاندراء': u'لِانْدِرَاءِ', #1
u'لاندرائه': u'لِانْدِرَائِهِ', #2
u'لانذاب': u'لاَنْذَابَ', #1
u'لأنذركموه': u'لأُنْذِرُكُمُوهُ', #1
u'لأنذركموه': u'لَأُنْذِرُكُمُوهُ', #1
u'لإنزاء': u'لِإِنْزَاءِ', #3
u'لأنسأي': u'لأَنَسٍأَيُّ', #2
u'لانضجهم': u'لانْضَجَهُمُ', #1
u'لانضرت': u'لَانْضَرَّت', #1
u'لإنظر': u'لإِنْظُرَ', #1
u'لانظر': u'لاَنْظُرُ', #1
u'لإنفاء': u'لِإِنْفَاءِ', #1
u'لإنفحة': u'لِإِنْفَحَةٍ', #1
u'لانفذن': u'لانَفِّذَنَّ', #1
u'لانفرداهن': u'لِانْفِرَدِاهِنَّ', #1
u'لإنفسهم': u'لإِنْفُسِهِمْ', #1
u'لانفلح': u'لانُفْلِحُ', #1
u'لانفهام': u'لِانْفِهَامِ', #2
u'لانفهامه': u'لِانْفِهِامِهِ', #1
u'لانفهامه': u'لِانْفِهَامِهِ', #13
u'لانفهامها': u'لِانْفِهَامِهَا', #2
u'لانقداحها': u'لِانْقِدَاحِهَا', #1
u'لأنما': u'لِأَنَّمَا', #1
u'لإنما': u'لِإِنَّمَا', #3
u'لانه': u'لانه', #1
u'لانهدار': u'لِانْهِدَارِ', #1
u'لأنهلم': u'لِأَنَّهُلَمْ', #1
u'لانهم': u'لانَّهُمْ', #1
u'لأنهمالا': u'لِأَنَّهُمَالَا', #1
u'لأنهوقت': u'لِأَنَّهُوَقْتُ', #1
u'لأنوشروان': u'لِأَنُوشِرْوَان', #1
u'لأنوشروان': u'لِأَنُوشِرْوَانَ', #2
u'لاها': u'لَاهًا', #1
u'لأهابك،': u'لأهابُك،', #1
u'لإهالة': u'لِإِهَالَةِ', #1
u'لأهبيتها': u'لِأَهْبِيَتِهَا', #1
u'لإهل': u'لإِهْلِ', #6
u'لإهله': u'لإِهْلِهِ', #1
u'لأهلى': u'لأَهْلِى', #5
u'لاهم': u'لاهُمّ', #1
u'لاهم': u'لَاهُمّ', #3
u'لاهم': u'لَاهُمَّ', #8
u'لأهنيه': u'لِأُهَنِّيَهُ', #1
u'لأو': u'لِأَوْ', #6
u'لأواء': u'لَأْوَاءَ', #1
u'لأواء': u'لأْوَاءِ', #4
u'لأواء': u'لَأْوَاءِ', #6
u'لأوائها': u'لأْوَائِهَا', #13
u'لأوائها': u'لَأْوَائِهَا', #24
u'لأوائهن': u'لَأْوَائِهِنَّ', #2
u'لاوة،': u'َلاوة،', #1
u'لاوة': u'لَاوَةَ', #1
u'لأوجهية': u'لِأَوْجَهِيَّةِ', #1
u'لاودية': u'لاوْدِيَةً', #1
u'لاوذ': u'لَاوَذِ', #1
u'لاوذ': u'لَاوِذَ', #1
u'لاوذ': u'لَاوِذْ', #4
u'لاوصلهم،': u'لاوْصَلَهُمْ،', #1
u'لأوطاس': u'لِأَوْطَاسٍ', #1
u'لاوى': u'لاوى', #1
u'لاوى': u'لاَوِى', #1
u'لاوى': u'لَاوَى', #2
u'لأويس': u'لأُوَيْسٍ', #1
u'لأويس': u'لِأُوَيْسٍ', #1
u'لاي': u'لَاي', #1
u'لاي': u'لايِّ', #2
u'لأى': u'لأَىِّ', #6
u'لائتدام': u'لِائْتِدَامٍ', #2
u'لائتدمنا': u'لَائْتَدَمْنَا', #1
u'لائتمامهم': u'لِائْتِمَامِهِمْ', #2
u'لائتني': u'لِائْتِنِي', #1
u'لائث': u'لائث', #1
u'لائج': u'لَائِجٌ', #2
u'لائقية': u'لَائِقِيَّةِ', #2
u'لآئم': u'لآئِمٍ', #1
u'لإياد': u'لِإِيَادِ', #1
u'لإياس': u'لإِيَاسٍ', #1
u'لإياس': u'لإِيَاسِ', #1
u'لإياس': u'لِإِيَاسٍ', #1
u'لإياس': u'لِإِيَاسِ', #5
u'لإياسه': u'لِإِيَاسِهِ', #2
u'لإياسها': u'لِإِيَاسِهَا', #5
u'لإياك': u'لِإِيَّاكَ', #1
u'لأياه': u'لأياه', #1
u'لايبالون': u'لايُبَالُونَ', #1
u'لايبدؤا': u'لايبدؤا', #1
u'لايبلى': u'لايبلى', #1
u'لاية': u'لايَةً', #1
u'لاية': u'لاَيَةُ', #1
u'لايتكره': u'لايتكره', #1
u'لايتوضأ': u'لايَتَوَضَّأُ', #1
u'لايجتمع': u'لَايُجْتَمَعُ', #1
u'لايجوز': u'لاَيَجُوزُ', #1
u'لايخالط': u'لايخالط', #1
u'لايرى': u'لايرى', #1
u'لآيسة': u'لِآيِسَةٍ', #3
u'لايصل': u'لَايَصِلُ', #1
u'لأيضا': u'لِأَيْضًا', #1
u'لايضيعها،': u'لايضيعها،', #1
u'لايعلمه': u'لَايَعْلَمُهُ', #1
u'لايفسده': u'لاَيُفْسِدُهُ', #1
u'لايقرؤن': u'لَايَقْرَؤُنَ', #1
u'لايكون': u'لايكون', #1
u'لايكي': u'لَايَكِي', #1
u'لايلتفت': u'لَاُُُُيَلْتَفِتُ', #1
u'لأيلولته': u'لِأَيْلُولَتِهِ', #2
u'لإيلياء': u'لِإِيلِيَاء', #1
u'لايليه': u'لَايِلِيهِ', #1
u'لايمته': u'لَايَمَتْهُ', #1
u'لايمكم': u'لاَيَمَكُمْ', #1
u'لايمنع': u'لَايُمْنَعُ', #1
u'لايؤكل': u'لايؤكل', #1
u'لايؤمنون': u'لايُؤْمِنُونَ', #1
u'لبأ': u'لَبَأً', #1
u'لبأ': u'لِبَأً', #1
u'لبأ': u'لِبَأَ', #1
u'لبإ': u'لِبَإٍ', #1
u'لباعشن': u'لِبَاعَشَنٍ', #3
u'لبافضل': u'لِبَافَضْلٍ', #6
u'لباكير': u'لِبَاكِيرٍ', #1
u'لبأها': u'لَبَأَهَا', #1
u'لباية': u'لباية', #1
u'لباين': u'لَبَايَنَ', #1
u'لبثينة': u'لِبُثَيْنَةَ', #1
u'لبجيلة': u'لِبَجِيلَةَ', #1
u'لبحزج': u'لِبَحْزَجٍ', #2
u'لبداعة': u'لِبَدَاعَةِ', #2
u'لبذاذة': u'لِبَذَاذَةِ', #1
u'لبرآء': u'لَبُرَآءَ', #2
u'لبريدة': u'لِبُرَيْدَةَ', #5
u'لبريرة': u'لبَرِيرَةَ', #1
u'لبريرة': u'لَبَرِيرَةَ', #1
u'لبريرة': u'لِبَرِيرَةَ', #24
u'لبزرجمهر': u'لِبَزَرْجَمْهَرَ', #5
u'لبسوطة': u'لِبُسُوطَةِ', #1
u'لبسوطة': u'لِبُسُوطَةٍ', #2
u'لبعديتهما': u'لِبَعْدِيَّتِهِمَا', #1
u'لبكى': u'لِبُكًى', #4
u'لبلقين': u'لِبُلْقِينِ', #1
u'لبلى': u'لِبَلَى', #2
u'لبناتى': u'لِبَنَاتِى', #1
u'لبهادرآص': u'لِبَهَادِرْآصْ', #1
u'لبهرام': u'لِبَهْرَامَ', #40
u'لبولاق': u'لِبُولَاقَ', #1
u'لبون': u'لَبُونً', #2
u'لبئسما': u'لَبِئْسَمَا', #1
u'لبئسما': u'لِبِئْسَمَا', #1
u'لبيتوتة': u'لِبَيْتُوتَةٍ', #1
u'لبيتوتة': u'لِبَيْتُوتَةِ', #1
u'لبيري': u'لِبِيرِيِّ', #1
u'لبيري': u'لِبِيرِيٍّ', #2
u'لبيكاه،': u'لَبَّيْكَاهُ،', #1
u'لبيكاه': u'لَبَّيْكَاهُ', #4
u'لبينما': u'لَبَيْنَمَا', #1
u'لبينما': u'لِبَيْنَمَا', #12
u'لبينى5436id': u'لبينى5436id', #1
u'لبينى': u'لُبَيْنَى', #4
u'لة': u'لة', #1
u'لة': u'لَةِ', #1
u'لة': u'لَةُ', #2
u'لتات': u'لَتَّاتٍ', #1
u'لتات': u'لُتَاتَ', #1
u'لتات': u'لِتَاتٌ', #1
u'لتات': u'لُتَاتٌ', #3
u'لتاتا': u'لُتَاتًا', #1
u'لتأتفق': u'لِتَأتَّفِقَ', #1
u'لتأتموا': u'لِتَأْتَمُّوا', #9
u'لتاتها': u'لِتَاتِهَا', #1
u'لتأتينى': u'لَتَأْتِيَنِّى', #6
u'لتآجر': u'لِتَآجُرِ', #1
u'لتأدم': u'لَتَأْدِمُ', #1
u'لتأدي': u'لِتَأْدِي', #3
u'لتأدي': u'لِتَأَدِّي', #32
u'لتأدى': u'لَتَأَدَّى', #6
u'لتأديه': u'لِتَأَدِّيهِ', #9
u'لتأديها': u'لِتَأَدِّيهَا', #5
u'لتأذيه': u'لِتَأْذَيْهِ', #1
u'لتأذيه': u'لِتَأَذِّيه', #4
u'لتأذيه': u'لِتَأَذِّيهِ', #5
u'لتأذيها': u'لِتَأَذِّيهَا', #9
u'لتأذيهم': u'لِتَأَذِّيهمْ', #1
u'لتأذيهم': u'لِتَأَذِّيهِمْ', #2
u'لتأذيهما': u'لِتَأَذِّيهِمَا', #1
u'لتأشرن': u'لِتَأْشَرُنَّ', #1
u'لتأقيت': u'لِتَأْقِيتِ', #9
u'لتأقيته': u'لِتَأْقِيتِهِ', #6
u'لتأكليننه': u'لَتَأْكُلِينَنْهُ', #1
u'لتأكليننها': u'لَتَأْكُلِينَنَهَا', #1
u'لتالف': u'لَتَالِفُ', #1
u'لتأمرنى': u'لِتَأْمُرَنِى', #1
u'لتأولون': u'لَتُأَوِّلُونَ', #1
u'لتأيمها': u'لِتَأَيُّمِهَا', #6
u'لتبتدرنهم': u'لَتَبْتَدِرَنهُمْ', #1
u'لتبتدرنهم': u'لَتَبْتَدِرَنّهُمْ', #1
u'لتبدئة': u'لِتَبْدِئَةٍ', #1
u'لتبعض': u'لَتَبَعَّضَ', #1
u'لتبعض': u'لِتَبَعُّضِ', #18
u'لتبعضه': u'لِتَبَعُّضِهِ', #4
u'لتتأذى': u'لَتَتَأَذَّى', #1
u'لتتحذر': u'لِتَتَحَذَّرَ', #1
u'لتتريب': u'لِتَتْرِيبِ', #18
u'لتتريبه': u'لِتَتْرِيبِهِ', #4
u'لتتعير': u'لِتَتَعَيَّرَ', #1
u'لتتقلل': u'لِتَتَقَلَّلَ', #1
u'لتتمحض': u'لِتَتَمَحَّضَ', #1
u'لتتممة': u'لِتَتْمِمَةِ', #1
u'لتتواضعاها': u'لِتَتَوَاضَعَاهَا', #1
u'لتجاوزونى': u'لَتُجَاوِزُونِى', #1
u'لتجميرها': u'لِتَجْمِيرِهَا', #1
u'لتجيئني': u'لتجيئني', #1
u'لتحاصا': u'لَتَحَاصَّا', #2
u'لتحاصص': u'لِتَحَاصُصٍ', #1
u'لتحدثنى': u'لَتُحَدِّثَنِّى', #4
u'لتحدثونى': u'لَتُحَدِّثُونِّى', #1
u'لتحفدهم': u'لِتَحَفُّدِهِمْ', #1
u'لتحفيره': u'لِتَحْفِيرِهِ', #5
u'لتحملنى': u'لَتَحْمِلَنِّى', #2
u'لتحنيثه': u'لِتَحْنِيثِهِ', #2
u'لتخبرنى': u'لَتُخْبِرَنِّى', #4
u'لتخبرينى': u'لَتُخْبِرِينِى', #1
u'لتختلع': u'لِتَخْتَلِعَ', #13
u'لتخذت': u'لَتَخِذْتَ', #2
u'لتخططت': u'لَتَخَطَّطَتْ', #1
u'لتداؤم': u'لِتَدَاؤُمِ', #1
u'لتدخلنى': u'لِتُدْخِلَنِى', #1
u'لتدعنى': u'لَتَدَعَنِّى', #3
u'لتدعونى': u'لَتَدَعُونِّى', #1
u'لتدلنى': u'لتدلنى', #1
u'لترتاض': u'لِتَرْتَاضَ', #2
u'لترتفق': u'لِتَرْتَفِقَ', #1
u'لترشدنى': u'لَتُرْشِدَنِّى', #1
u'لتروث': u'لِتَرُوثَ', #1
u'لتزوجنيها': u'لِتُزَوِّجْنِيهَا', #1
u'لتساكر': u'لَتَسَاكُرِ', #1
u'لتساكر': u'لَتَسَاكَرَ', #2
u'لتستثفر': u'لْتَسْتَثْفِرْ', #1
u'لتستثفر': u'لِتَسْتَثْفِرْ', #8
u'لتستد': u'لِتَسْتَدَّ', #1
u'لتستغزر': u'لِتَسْتَغْزِرَ', #1
u'لتستفحله': u'لِتَسْتَفْحِلَهُ', #1
u'لتستن': u'لَتَسْتَنُّ', #1
u'لتستنفع': u'لِتَسْتَنْفِعَ', #1
u'لتسجيد': u'لِتَسْجِيدِ', #1
u'لتسقيم': u'لِتَسْقِيمِ', #1
u'لتسلفنى': u'لِتُسْلِفَنِى', #1
u'لتسليمة': u'لِتَسْلِيمَةِ', #3
u'لتسليمته': u'لِتَسْلِيمَتِهِ', #1
u'لتسئلن': u'لَتُسْئَلُنَّ', #1
u'لتشحيذ': u'لِتَشْحِيذِ', #5
u'لتشقص': u'لِتَشَقُّصِ', #1
u'لتشقيص': u'لِتَشْقِيصِ', #6
u'لتشوب': u'لِتَشُوبَ', #1
u'لتصاونه': u'لِتَصَاوُنِهِ', #1
u'لتصدقوننى': u'لَتُصَدِّقُونَنِى', #1
u'لتصقيل': u'لِتَصْقِيلِ', #1
u'لتطلقنى': u'لَتُطَلِّقَنِّى', #1
u'لتطليقة': u'لِتَطْلِيقَةٍ', #1
u'لتطيعنن': u'لَتُطِيعَنَّنِ', #1
u'لتعجبينى': u'لَتُعْجِبِينِى', #1
u'لتعرص': u'لِتَعَرُّصِ', #2
u'لتعطان': u'لَتُعْطَانَّ', #1
u'لتعطينيه': u'لَتُعْطِينِيهِ', #1
u'لتعلمنى': u'لِتُعَلِّمَنِى', #1
u'لتغبير': u'لِتَغْبِيرِ', #1
u'لتغربة': u'لِتَغْرُبَةٍ', #2
u'لتغربة': u'لِتَغْرِبَةٍ', #8
u'لتفركح': u'لِتَفَرْكُحٍ', #1
u'لتقرءون': u'لَتَقْرَءُونَ', #1
u'لتقرضنيه': u'لِتُقْرِضَنِيهِ', #1
u'لتقويمتين': u'لِتَقْوِيمَتَيْنِ', #1
u'لتكتفئ': u'لِتَكْتَفِئ', #1
u'لتكتفئ': u'لِتَكْتَفِئَ', #25
u'لتكستفئ': u'لِتَكْستَفِئَ', #1
u'لتكفونى': u'لَتَكْفُونِّى', #1
u'لتكلأت': u'لِتَكَلَّأْتُ', #1
u'لتلتقيان': u'لَتَلْتَقِيَانِ', #1
u'لتماضر': u'لِتُمَاضِرَ', #1
u'لتماضر،': u'لِتَمَاضِرَ،', #1
u'لتمجس': u'لِتَمَجُّسٍ', #4
u'لتمحيض': u'لِتَمْحِيضِ', #1
u'لتمصع': u'لَتَمْصَعُ', #1
u'لتمضمضة': u'لِتَمَضْمُضَةٍ', #1
u'لتمعشه': u'لِتَمَعُّشِهِ', #2
u'لتميمي': u'لِتَمِيمِيِّ', #1
u'لتميمي': u'لِتَمِيمِيٍّ', #2
u'لتنريلهم': u'لِتَنْرِيلِهِمْ', #1
u'لتنضيض': u'لِتَنْضِيضِ', #1
u'لتنفاق': u'لِتِنْفَاقِ', #1
u'لتنهير': u'لِتَنْهِيرِ', #1
u'لتنهيض': u'لِتَنْهِيضِ', #3
u'لتهارج': u'لِتَهَارَجَ', #1
u'لتهامة': u'لِتِهَامَةَ', #1
u'لتهراق': u'لِتُهْرَاقَ', #1
u'لتهرى': u'لَتَهَرَّى', #4
u'لتؤاجرها': u'لِتُؤَاجِرَهَا', #1
u'لتؤاخذه': u'لِتُؤَاخِذَهُ', #1
u'لتوقان': u'لِتَوَقَانٍ', #1
u'لتوقانه': u'لِتَوَقَانِهِ', #3
u'لتوقانها': u'لِتَوَقَانِهَا', #2
u'لتوكدة': u'لِتَوَكُّدَةِ', #1
u'لتوكفت': u'لَتَوَكَّفَتْ', #1
u'لتيمارهم': u'لِتَيْمَارِهِمْ', #1
u'لتيماري': u'لِتَيْمَارِيٍّ', #5
u'لتيماريها': u'لِتَيْمَارِيِّهَا', #1
u'لثبيتة': u'لِثُبَيْتَةَ', #5
u'لثخانة': u'لِثَخَانَةٍ', #2
u'لثخانته': u'لِثَخَانَتِهِ', #1
u'لثخنه': u'لِثِخَنِهِ', #1
u'لثفر': u'لِثُفْرِ', #1
u'لثق': u'لَثِقَ', #2
u'لثلثمائة': u'لِثَلَثِمِائَةِ', #1
u'لثمنيته': u'لِثَمَنِيَّتِهِ', #2
u'لثويبة': u'لِثُوَيْبَةَ', #1
u'لثيوبة': u'لِثُيُوبَةِ', #1
u'لجاءوا': u'لَجَاءُوا', #1
u'لجالينوس': u'لِجَالِينُوسَ', #7
u'لجبات': u'لَجَبَاتٍ', #1
u'لجبات': u'لَجَبَاتِ', #1
u'لجبايا': u'لجبايا', #1
u'لجبرانين': u'لِجُبْرَانَيْنِ', #6
u'لجبرائيل': u'لِجَبْرَائِيلَ', #1
u'لجبغا': u'لِجَبْغَا', #3
u'لجبهتى': u'لِجَبْهَتِى', #1
u'لجبير': u'لجبير', #1
u'لجبير': u'لِجُبَيْرِ', #9
u'لجبيرة': u'لِجَبِيرَةٍ', #2
u'لجثيت': u'لَجَثَيْتُ', #2
u'لجحفة': u'لِجُحْفَةَ', #1
u'لجدور': u'لِجُدُورِ', #1
u'لجرهد': u'لجرهد', #1
u'لجرهد': u'لِجَرْهَدٍ', #5
u'لجرىء': u'لَجَرِىءٌ', #4
u'لجريب': u'لِجَرِيبٍ', #1
u'لجريشه': u'لِجَرِيشِهِ', #1
u'لجريشها': u'لِجَرِيشِهَا', #1
u'لجساوته': u'لجساوته', #1
u'لجساوته': u'لِجَسَاوَتِهِ', #1
u'لجسوس': u'لِجَسُّوسٍ', #1
u'لجشيشتك': u'لِجَشِيشَتِك', #1
u'لجعال': u'لِجُعَالِ', #1
u'لجعدر': u'لِجَعْدَرٍ', #2
u'لجعرانه': u'لِجِعْرَانَهْ', #1
u'لجعيل': u'لَجُعَيْلُ', #3
u'لجليبيب': u'لِجُلَيْبِيبٍ', #9
u'لجليسى': u'لِجَلِيسِى', #1
u'لجنادة': u'لِجُنَادَةَ', #1
u'لجندار': u'لِجِنْدَارٍ', #1
u'لجندع': u'لِجَنْدَعٍ', #2
u'لجنف': u'لِجَنَفٍ', #1
u'لجهينة،': u'لِجُهَيْنَةَ،', #1
u'لجهينة': u'لِجُهَيْنَةَ', #2
u'لجويبر': u'لِجُوَيْبِرٍ', #2
u'لجويرية': u'لِجُوَيْرِيَةَ', #2
u'لحاجةالناس': u'لِحَاجَةِالنَّاسِ', #1
u'لحاصهم': u'لَحَاصَّهُمْ', #1
u'لحافيودليلنا': u'لِحَافِيوَدَلِيلُنَا', #1
u'لحبشى': u'لِحَبَشِىٍّ', #1
u'لحبلق': u'لْحَبَلّقُ', #1
u'لحتى': u'لِحَتَّى', #1
u'لحجى': u'لِحَجِّى', #1
u'لحديثى': u'لِحَدِيثِى', #1
u'لحديثيزيد': u'لِحَدِيثِيَزِيدَ', #1
u'لحذيم': u'لِحِذْيَمٍ', #3
u'لحرارير': u'لِحَرَارِيرَ', #1
u'لحربثا': u'لِحَرْبِثَا', #1
u'لحرقوص': u'لِحُرْقُوصٍ', #1
u'لحرملة': u'لِحَرْمَلَةَ', #11
u'لحروجة': u'لِحُرُوجَةِ', #1
u'لحروراء': u'لِحَرُورَاءَ', #1
u'لحزونة': u'لِحُزُونَةِ', #1
u'لحسيل': u'لِحُسَيْلٍ', #1
u'لحضير': u'لِحَضِيرِ', #1
u'لحضين': u'لِحُضَيْنِ', #1
u'لحقنى': u'لَحِقَنِى', #1
u'لحقيته': u'لِحَقِّيَّتِهِ', #4
u'لحقيتها': u'لِحَقِّيَّتِهَا', #1
u'لحلولو': u'لِحُلُولُو', #2
u'لحليس': u'لِحُلَيْسٍ', #1
u'لحمبمثله،': u'لَحْمٌبِمِثْلِهِ،', #1
u'لحمدون': u'لِحَمْدُونَ', #1
u'لحمديس': u'لحمديس', #1
u'لحمديس': u'لِحَمْدِيسَ', #2
u'لحمديس': u'لِحَمْدِيسٍ', #6
u'لحمنة': u'لِحَمْنَةَ', #21
u'لحنتمة': u'لِحَنْتَمَةَ', #1
u'لحوجاء': u'لَحَوْجَاءُ', #1
u'لحوحا': u'لَحُوحًا', #3
u'لحويصة': u'لِحُوَيِّصَة', #1
u'لحويصة،': u'لِحُوَيِّصَةَ،', #1
u'لحويصة': u'لِحُوَيِّصَةَ', #14
u'لحويصة': u'لِحُوَيّصَةَ', #2
u'لحياطة': u'لِحِيَاطَةٍ', #1
u'لحيانا': u'لِحْيَاناً', #1
u'لحيانا': u'لِحْيَانًا', #5
u'لحيح': u'لُحَيْحٍ', #1
u'لحيى': u'لَحْيَىِ', #1
u'لحيى': u'لَحْيَىْ', #1
u'لحيى': u'لِحُيَىِّ', #1
u'لخاخ': u'لِخَاخٍ', #1
u'لخالتى': u'لِخَالَتِى', #1
u'لختمة': u'لِخَتْمَةٍ', #1
u'لختمة': u'لِخَتْمَةَ', #1
u'لخثعم': u'لِخَثْعَمٍ', #2
u'لخثعم': u'لِخَثْعَمَ', #4
u'لخثعمة': u'لِخَثْعَمَةَ', #1
u'لخثيل': u'لِخُثَيْلٍ', #1
u'لخجندي': u'لِخُجَنْدِيٌّ', #1
u'لخراش': u'لِخِرَاشِ', #2
u'لخرباق': u'لِخِرْبَاقٍ', #1
u'لخرشة': u'لِخَرَشَةَ', #2
u'لخرئه': u'لِخُرْئِهِ', #1
u'لخزيمة': u'لِخُزَيْمَةَ', #1
u'لخسرو': u'لِخُسْرَوْ', #2
u'لخضخاض': u'لِخَضْخَاضٍ', #10
u'لخليد': u'لِخُلَيْدٍ', #1
u'لخليطين': u'لِخَلِيطَيْنِ', #1
u'لخندف': u'لِخِنْدِفٍ', #1
u'لخنيعة': u'لَخْنيعة', #3
u'لخنيعة': u'لخنيعة', #9
u'لخواجه': u'لِخَوَاجَهْ', #2
u'لخواهر': u'لخواهر', #1
u'لخواهر': u'لِخُوَاهَرْ', #3
u'لخوفى': u'لخوفى', #3
u'لخئولة': u'لَخَئُولَةٌ', #1
u'لخئولتهم': u'لِخُئُولَتِهِمْ', #1
u'لخيبر': u'لِخَيْبَرَ', #2
u'لخينعة': u'لخينعة', #1
u'لدات': u'لُدَّاتٍ', #1
u'لداتها': u'لِدَاتِهَا', #3
u'لداتها': u'لداتها', #4
u'لدادة': u'لَدَادَةٍ', #1
u'لداماد': u'لِدَامَادَ', #1
u'لدانق': u'لِدَانَقٍ', #3
u'لدة': u'لِدَةٌ', #1
u'لدة': u'لِدَةَ', #1
u'لدة': u'لِدَةُ', #1
u'لدتان': u'لِدَتَانِ', #1
u'لدته': u'لَدّتْهُ', #1
u'لدتين': u'لِدَتَيْنِ', #1
u'لدحداح': u'لَدَحْدَاحٌ', #1
u'لدحية': u'لِدِحْيَةَ', #19
u'لدحية': u'لِدَحْيَةَ', #2
u'لدحيم': u'لدُحَيْم', #1
u'لدخولى': u'لِدُخُولِى', #1
u'لدريد': u'لِدُرَيْدٍ', #2
u'لدريد': u'لِدُرَيْدِ', #5
u'لدعثور': u'لِدُعْثُور', #1
u'لدغتنى': u'لَدَغَتْنِى', #2
u'لدمة': u'لَدْمَةً', #2
u'لدمياط': u'لِدِمْيَاطَ', #2
u'لدنىء': u'لَدَنِىءٌ', #1
u'لدواد': u'لِدَوُادَ', #1
u'لدى': u'لُدًى', #1
u'لدياس': u'لِدَيَّاسِ', #1
u'لدياس': u'لِدِيَاسِ', #7
u'لدياسة': u'لِدِيَاسَةِ', #2
u'لديدي': u'لَدِيدِيِّ', #1
u'لديغ،': u'لَدِيغٌ،', #1
u'لديغ': u'لَدِيغٍ', #2
u'لديغ': u'لَدِيغٌ', #8
u'لديغا': u'لَدِيغًا', #13
u'لدينى': u'لَدَيْنِى', #2
u'لذاعة': u'لَذَّاعَةٍ', #1
u'لذريق،': u'لُذَرِيقَ،', #1
u'لذفرك': u'لِذَفَرِك', #1
u'لذوو': u'لَذَوُو', #1
u'لذويد': u'لِذُوَيْدٍ', #1
u'لرءوس': u'لِرُءُوسِ', #8
u'لرءوسكم': u'لِرُءُوسِكُمْ', #3
u'لرءوسها': u'لِرُءُوسِهَا', #1
u'لرءوسهم': u'لِرُءُوسِهِمْ', #1
u'لرءوسهن': u'لِرُءُوْسِهِنَّ', #1
u'لرءوف': u'لَرَءُوفٌ', #10
u'لرآنا': u'لَرَآنَا', #1
u'لرآه': u'لَرَآهُ', #19
u'لرآها': u'لَرَآهَا', #11
u'لرآهم': u'لَرَآهُمْ', #3
u'لرائيها': u'لِرَائِيهَا', #2
u'لربعى': u'لِرِبْعِىٍّ', #1
u'لرتقاء': u'لِرَتْقَاءَ', #4
u'لرحا': u'لِرَحًا', #2
u'لرحى': u'لِرَحًى', #1
u'لرزيق': u'لِرُزَيْقٍ', #3
u'لرسولى': u'لِرَسُولِى', #1
u'لرضعات': u'لِرَضَعَاتٍ', #1
u'لرمص': u'لِرَمَصٍ', #1
u'لرمضانها': u'لِرَمَضَانِهَا', #2
u'لرمييه': u'لِرَمْيَيْهِ', #1
u'لرؤبة': u'لِرُؤْبَةَ', #1
u'لرؤيت': u'لَرُؤيَتْ', #1
u'لرويفع': u'لِرُوَيْفُعٍ', #1
u'لرويم': u'لِرُوَيْمٍ', #1
u'لزادنى': u'لَزَادَنِى', #2
u'لزباء': u'لِزَبَّاءَ', #1
u'لزبيد': u'لِزُبَيْدِ', #1
u'لزروق': u'لِزَرُّوقٍ', #6
u'لزعبل': u'لِزَعْبَلٍ', #1
u'لزفورتها': u'لِزُفُورَتِهَا', #1
u'لزمنى': u'لَزِمَنِى', #1
u'لزمنى': u'لِزَمْنَى', #2
u'لزنباع': u'لِزِنْبَاعِ', #1
u'لزنباع': u'لِزِنْبَاعٍ', #3
u'لزنية': u'لِزَنْيَةٍ', #2
u'لزنية': u'لِزَنْيَةِ', #2
u'لزنية': u'لِزِنْيَةٍ', #4
u'لزوجتكها': u'لَزَوَّجْتُكهَا', #1
u'لزوجتكها': u'لِزَوَّجْتُكَهَا', #2
u'لزوجى': u'لِزَوْجِى', #2
u'لزيافتها': u'لِزِيَافَتِهَا', #3
u'لزيقة': u'لَزِيقَةٌ', #1
u'لس': u'لِسْ', #1
u'لس': u'لس', #2
u'لسابور': u'لِسَابُورَ', #2
u'لسانهوروي': u'لِسَانُهُوَرُوِيَ', #1
u'لسانى': u'لِسَانِى', #4
u'لسائم': u'لِسَائِمٍ', #1
u'لسبقيته': u'لِسَبْقِيَّتِهِ', #1
u'لسبوخة': u'لِسُبُوخَةِ', #3
u'لسبوق': u'لِسُبُوقِ', #1
u'لسبيع': u'لِسُبَيْعٍ', #1
u'لسبيعة': u'لِسُبَيْعَةَ', #7
u'لسحبان': u'لِسَحْبَانَ', #1
u'لسحنون': u'لِسَحْنُونٍ', #333
u'لسحول': u'لِسَحُولٍ', #1
u'لسخلة': u'لِسَخْلَةٍ', #1
u'لسرف': u'لِسَرَفٍ', #7
u'لسريج': u'لِسُرَيْجٍ', #2
u'لسطيح،': u'لِسَطِيحٍ،', #1
u'لسطيح': u'لِسَطِيحٍ', #2
u'لسطيح': u'لِسَطِيحِ', #6
u'لسعيد': u'لِسَعِيدً', #1
u'لسقية': u'لِسَقْيَةٍ', #1
u'لسقيتي': u'لِسَقْيَتَيْ', #2
u'لسقيتين': u'لِسَقْيَتَيْنِ', #1
u'لسلابة': u'لسلابة', #1
u'لسليك': u'لِسُلَيْكٍ', #4
u'لسليمى': u'لِسُلَيْمَى', #1
u'لسنمار': u'لِسِنِمَّارَ', #1
u'لسه': u'لسه', #1
u'لسوابغ': u'لِسَوَابِغِ', #2
u'لسودة،': u'لِسَوْدَةَ،', #1
u'لسودة': u'لِسَوْدَةِ', #15
u'لسودة': u'لِسَوْدَةَ', #18
u'لسوقة': u'لِسُوقَةٍ', #2
u'لسون': u'لسون', #1
u'لسويبط': u'لِسُوَيْبِطٍ', #1
u'لسئول': u'لَسَئُولٌ', #1
u'لشارفى': u'لِشَارِفَىَّ', #2
u'لشبابة،': u'لِشَبَابَةَ،', #1
u'لشتر': u'لِشَتْرٍ', #1
u'لشدخت': u'لَشَدَخْت', #1
u'لشدف': u'لِشَدَفٍ', #1
u'لشراحة': u'لِشُرَاحَة', #1
u'لشراحة': u'لِشَرَاحَةَ', #3
u'لشراحة': u'لِشُرَاحَةَ', #9
u'لشرجع': u'لِشَرْجَعِ', #1
u'لشرحبيل،': u'لِشُرَحْبِيلَ،', #1
u'لشرحبيل': u'لِشُرَحْبِيلَ', #5
u'لشريب': u'لِشَرِّيبٍ', #1
u'لشطونه': u'لِشُطُونِهِ', #1
u'لشقص': u'لِشِقْصٍ', #14
u'لشقص': u'لِشِقْصِ', #2
u'لشقصه': u'لِشِقْصِهِ', #1
u'لشمولة': u'لِشَمُولَةِ', #1
u'لشهريران': u'لشهريران', #1
u'لشومها': u'لِشُومِهَا', #1
u'لشىء': u'لِشَىْءٌ', #1
u'لشىء': u'لِشَىْءٍ', #38
u'لشىء': u'لَشَىْءٌ', #6
u'لشيرويه': u'لِشِيرَوَيْهِ', #1
u'لصاحبى': u'لِصَاحِبِى', #1
u'لصادقية': u'لِصَادِقِيَّةِ', #5
u'لصايغ': u'لِصَايِغٍ', #1
u'لصبى': u'لِصَبِىٍّ', #1
u'لصبى': u'لِصِبًى', #1
u'لصبى': u'لِصَبًى', #2
u'لصدائق': u'لِصَدَائِقِ', #1
u'لصرائح': u'لِصَرَائِحِ', #2
u'لصرائحه': u'لِصَرَائِحِهِ', #1
u'لصرورة': u'لِصَرُورَةٍ', #1
u'لصفاة': u'لِصَفَاةٍ', #1
u'لصفاقس': u'لِصَفَاقُسَ', #1
u'لصقوه': u'لَصِقُوهُ', #1
u'لصلاتى': u'لِصَلاَتِى', #1
u'لصنجات': u'لِصَنَجَاتِ', #1
u'لصنجة': u'لِصَنْجَةٍ', #1
u'لصواحباتها': u'لِصَوَاحِبَاتِهَا', #1
u'لصواحباتي': u'لصواحباتي', #1
u'لصوتي18467id': u'لصوتي18467id', #1
u'لصيال': u'لِصِيَالِ', #1
u'لصيال': u'لِصِيَالٍ', #14
u'لصيالته': u'لِصِيَالَتِهِ', #1
u'لصياله': u'لِصِيَالِهِ', #33
u'لصيالها': u'لِصِيَالِهَا', #2
u'لصيالهما': u'لِصِيَالِهِمَا', #1
u'لض': u'لض', #1
u'لضباعة': u'لِضُبَاعَةَ', #8
u'لضروة': u'لِضِرْوَةِ', #1
u'لضيزى': u'لِضِيزَى', #1
u'لطاخه': u'لَطَاخِّهِ', #1
u'لطالوت': u'لِطَالُوتَ', #2
u'لطاوس': u'لِطَاوُسٍ', #17
u'لطاوس،': u'لِطَاوُسٍ،', #2
u'لطحه': u'لَطَحَهُ', #1
u'لطرءان': u'لِطَرَءَانِ', #1
u'لطراسب': u'لطراسب', #1
u'لطرآن': u'لِطَرَآنِ', #2
u'لطرآنه': u'لِطُرْآنِهِ', #1
u'لطربة': u'لِطَرِبَةٍ', #4
u'لطرخون': u'لِطَرَخُونَ', #1
u'لطريانه': u'لِطَرَيَانِهِ', #2
u'لطريانها': u'لِطَرَيَانِهَا', #1
u'لطساس': u'لِطَسَّاسِ', #1
u'لطفى': u'لطفى', #10
u'لطندتا': u'لِطَنْدَتَا', #1
u'لطيء،': u'لِطَيْءٍ،', #1
u'لطيم': u'لَطِيمُ', #1
u'لطيم': u'لَطِيمَ', #2
u'لطيم': u'لَطِيمٌ', #6
u'لطيمة': u'لَطِيمَةَ', #1
u'لطيمة': u'لَطِيمَةً', #5
u'لطيئ': u'لِطَيِّئٍ', #2
u'لطيئ': u'لِطَيّئٍ', #3
u'لظهارين': u'لِظِهَارَيْنِ', #3
u'لظئر': u'لِظِئْرٍ', #1
u'لظئره': u'لِظِئْرِهِ', #1
u'لظئرين': u'لَظِئْرَيْنِ', #2
u'لعا': u'لَعًا', #11
u'لعاتكة': u'لِعَاتِكَةَ', #4
u'لعاعة': u'لُعَاعَةٍ', #4
u'لعالفها': u'لِعَالِفِهَا', #3
u'لعائن': u'لَعَائِنُ', #2
u'لعبادى': u'لِعِبَادِىَ', #3
u'لعبالة': u'لِعَبَالَةٍ', #3
u'لعبالة': u'لِعَبَالَةِ', #3
u'لعبالته': u'لِعَبَالَتِهِ', #3
u'لعبدى': u'لِعَبْدِى', #17
u'لعتقاء': u'لِعُتَقَاءِ', #1
u'لعتقائهم': u'لِعُتَقَائِهِمْ', #1
u'لعثمة': u'لَعْثَمَةٍ', #1
u'لعذا': u'لِعَذَا', #1
u'لعرباض': u'لِعِرْبَاضِ', #2
u'لعرفجة': u'لِعَرْفَجَةَ', #3
u'لعساء': u'لَعْسَاءَ', #4
u'لعساره': u'لِعِسَارِهِ', #1
u'لعسب': u'لِعَسْبِ', #3
u'لعسيب': u'لِعَسِيبٍ', #1
u'لعشقتني': u'لَعَشِقُتني', #1
u'لعصوبة': u'لِعُصُوبَةٍ', #1
u'لعصوبة': u'لِعُصُوبَةِ', #3
u'لعط': u'لُعْطٍ', #3
u'لعطن': u'لِعَطَنِ', #2
u'لعفاصها': u'لِعِفَاصِهَا', #2
u'لعكراش': u'لِعِكْرَاشٍ', #1
u'لعلالات': u'لَعُلَالَاتٍ', #2
u'لعلس': u'لِعَلَسٍ', #10
u'لعلقمة': u'لِعَلْقَمَةَ', #8
u'لعلوفتهم': u'لِعُلُوفَتِهِمْ', #1
u'لعلي': u'لِعَلِيًّ', #1
u'لعماكا': u'لِعَمَاكَا', #1
u'لعمديته': u'لِعَمْدِيَّتِهِ', #2
u'لعمرى': u'لَعَمْرِى', #12
u'لعنبسة،': u'لِعَنْبَسَةَ،', #1
u'لعنبسة': u'لِعَنْبَسَةَ', #4
u'لعندى': u'لَعِنْدِى', #1
u'لعهديتها': u'لِعَهْدِيَّتِهَا', #2
u'لعوانة': u'لِعَوَانَةَ', #1
u'لعوة': u'لَعْوَةَ', #1
u'لعياض': u'لِعِيَاضٍ', #54
u'لعيافة': u'لِعِيَافَةٍ', #1
u'لعيافته': u'لِعِيَافَتِهِ', #1
u'لعيافتها': u'لِعِيَافَتِهَا', #1
u'لعيالاتهم': u'لِعِيَالَاتِهِمْ', #1
u'لعيينة،': u'لِعُيَيْنَةَ،', #1
u'لعيينة': u'لِعُيَيْنَةَ', #14
u'لغامد': u'لِغَامِدِ', #1
u'لغبط': u'لِغِبْطٍ', #1
u'لغراثب': u'لغراثب', #1
u'لغرقد': u'لِغَرْقَدٍ', #1
u'لغوار': u'لِغَوَارِ', #1
u'لغوار': u'لِغِوَارِ', #1
u'لغوب': u'لُغُوبٍ', #1
u'لغوب،': u'لُغُوبٌ،', #1
u'لغوب': u'لُغُوبٌ', #6
u'لغوفيه': u'لَغْوَفِيهِ', #1
u'لغية': u'لُغَيَّة', #1
u'لغية': u'لِغِيّةِ', #1
u'لغية': u'لِغِيَّةِ', #1
u'لغية': u'لَغَيَّةً', #2
u'لغية': u'لَغِيَّةً', #2
u'لغية': u'لَغِيَّةٌ', #2
u'لغية': u'لُغَيَّةٌ', #2
u'لغية': u'لِغَيّةِ', #2
u'لغية': u'لِغِيَّةٍ', #3
u'لغية': u'لِغَيَّةٍ', #8
u'لغيرالقبلة': u'لِغَيْرِالْقِبْلَةِ', #1
u'لغيفه': u'لَغِيفُهُ', #1
u'لفاة': u'لُفَاةُ', #2
u'لفاة': u'لُفَاةَ', #4
u'لفاختة': u'لِفَاخِتَةَ', #2
u'لفاعها': u'لِفَاعِهَا', #1
u'لفاف': u'لِفَافٍ', #1
u'لفامي': u'لِفَامِيٍّ', #1
u'لفة': u'لَفَّةٍ', #2
u'لفتال': u'لِفَتَّالٍ', #2
u'لفجء': u'لِفَجْءِ', #5
u'لفخرى': u'لِفَخْرَى', #2
u'لفراهيته': u'لِفَرَاهِيَتِهِ', #1
u'لفريعة': u'لِفُرَيْعَةَ', #4
u'لفسوخ': u'لِفُسُوخِ', #1
u'لفسيل': u'لِفَسِيلٍ', #1
u'لفظرب': u'لَفْظٍرُبَّ', #1
u'لفعاء': u'لَفْعَاءَ', #1
u'لفعاء': u'لَفْعَاءُ', #3
u'لفعول': u'لِفَعُولٍ', #1
u'لفعيلة': u'لِفَعِيلَةٍ', #2
u'لفقة': u'لِفْقَةٌ', #1
u'لفقتين': u'لِفْقَتَيْنِ', #1
u'لفنج': u'لِفَنَّجَ', #2
u'لفنحاص': u'لِفِنْحَاصٍ', #1
u'لفنحاص': u'لِفِنْحَاصَ', #2
u'لفوريته': u'لِفَوْرِيَّتِهِ', #1
u'لفوعل': u'لِفَوْعَلٍ', #1
u'لفى': u'لَفِى', #14
u'لفى': u'لَفِىَّ', #2
u'لفيقين': u'لَفِيقَيْنِ', #1
u'لقاءة': u'لِقَاءَةً', #1
u'لقابيل': u'لِقَابِيلَ', #1
u'لقافة': u'لِقَافَةٍ', #1
u'لقائح': u'لَقَائِحَ', #1
u'لقائف': u'لِقَائِفٍ', #1
u'لقباث': u'لِقُبَاثِ', #1
u'لقباث': u'لِقَبَاثِ', #2
u'لقبيصة': u'لِقَبِيصَةَ', #6
u'لقثم': u'لِقُثَمَ', #3
u'لقرابتى': u'لِقَرَابَتِى', #1
u'لقراسنقر': u'لِقَرَاسُنْقُرَ', #2
u'لقرأين': u'لِقُرْأَيْنِ', #1
u'لقربوس': u'لِقَرَبُوسِ', #4
u'لقرم': u'لَقُرْمٌ', #1
u'لقريظة': u'لقريظة', #1
u'لقريظة': u'لِقُرَيْظَةَ', #1
u'لقزعة': u'لِقَزَعَةَ', #1
u'لقسة': u'لَقِسَةٌ', #1
u'لقصى': u'لِقُصَىِّ', #1
u'لقفصة': u'لِقَفْصَةَ', #1
u'لقفيز': u'لِقَفِيزِ', #1
u'لقلح': u'لِقَلَحٍ', #2
u'لقلح': u'لِقَلَحِ', #2
u'لقليب': u'لِقَلِيبٍ', #1
u'لقليلSإسلام': u'لَقَلِيلٌSإسْلَامُ', #1
u'لقليلوإن': u'لَقَلِيلٌوَإِنْ', #1
u'لقمتة': u'لُقْمَتَةً', #1
u'لقننى': u'لَقَّنَنِى', #1
u'لقوح': u'لَقُوحٍ', #1
u'لقوح': u'لَقُوحٌ', #3
u'لقوحا': u'لَقُوحًا', #1
u'لقولى': u'لِقَوْلِى', #1
u'لقيتنى': u'لَقِيتَنِى', #4
u'لقينقاع': u'لِقَيْنُقَاعِ', #1
u'لقينقاع': u'لِقَيْنُقَاعَ', #3
u'لقينى': u'لَقِيَنِى', #19
u'لكإباق': u'لِكَإِبَاقِ', #9
u'لكاعة': u'لَكَاعَةُ', #1
u'لكالجحفة': u'لَكَالْجُحْفَةِ', #1
u'لكالجحفة': u'لِكَالْجُحْفَةِ', #10
u'لكأنى': u'لَكَأَنِّى', #6
u'لكجعرانة': u'لِكَجِعْرَانَةَ', #1
u'لكزة': u'لَكْزَةٍ', #1
u'لكزة': u'لَكْزَةً', #2
u'لكسوب': u'لَكَسُوبُ', #2
u'لكظيظ': u'لَكَظِيظٌ', #1
u'لكمرأة': u'لِكَمَرْأَةٍ', #3
u'لكمرأة': u'لِكَمْرَأَةٍ', #3
u'لكنود': u'لَكَنُودٌ', #5
u'لكوارة': u'لِكُوَّارَةٍ', #1
u'لكيز': u'لُكَيْزٍ', #1
u'لكيز': u'لُكَيْزِ', #3
u'لكيع': u'لَكِيعٍ', #1
u'لكيعة': u'لَكِيعَةَ', #3
u'لل': u'لَلِ', #1
u'لل': u'لِل', #1
u'لل': u'لل', #2
u'لل': u'لِلْ', #3
u'للا': u'لِلَا', #11
u'للأباء': u'لِلْأَبَاءِ', #1
u'للإباق': u'لِلْإِبَاقِ', #5
u'للأبخر': u'لِلْأَبْخَرِ', #1
u'للإبراد': u'لِلْإِبْرَادِ', #27
u'للإبريسم': u'لِلْإِبْرَيْسَمِ', #1
u'للإبضاع': u'لِلْإِبْضَاعِ', #14
u'للأبضاع': u'لِلْأَبْضَاعِ', #37
u'للآبق': u'لِلْآبِقِ', #22
u'للأبلغية': u'لِلْأَبْلَغِيَّةِ', #1
u'للأبلي': u'لِلْأُبُلِّيِّ', #1
u'للأبنة': u'للأبنة', #2
u'للأبنيه': u'لِلْأَبْنِيَهْ', #1
u'للأبياري': u'لِلْأَبْيَارِيِّ', #1
u'للإبياني': u'لِلْإِبْيَانِيِّ', #5
u'للاتساء': u'لِلِاتِّسَاءِ', #1
u'للأتقاني': u'للأتقاني', #1
u'للأتقاني': u'لِلْأَتْقَانِيِّ', #6
u'للاتهاب': u'لِلِاتِّهَابِ', #1
u'للأثاني': u'لِلْأَثَانِي', #1
u'للأثانين': u'لِلْأَثَانِينَ', #1
u'للاثتين': u'لِلَّاثْتَيْنِ', #1
u'للإثمد': u'لِلْإِثْمِدِ', #1
u'للاثنتي': u'لِلِاثْنَتَيْ', #2
u'للاثنتين': u'لِلِاثْنَتَيْنِ', #11
u'للاثنين': u'لِلِاثْنَيْنِ', #104
u'للاثنين': u'لِلاِثْنَيْنِ', #2
u'للإجانات': u'لِلْإِجَّانَاتِ', #1
u'للاجتزاء': u'لِلِاجْتِزَاءِ', #5
u'للأجزا': u'لِلْأَجْزَا', #1
u'للأجزية': u'لِلْأَجْزِيَةِ', #1
u'للأجهوري': u'لِلْأُجْهُورِيِّ', #27
u'للأجودية': u'لِلْأَجْوَدِيَّةِ', #1
u'للاحتجام': u'لِلِاحْتِجَامِ', #1
u'للاحتزاز': u'لِلِاحْتِزَازِ', #1
u'للاحتشاش': u'لِلِاحْتِشَاشِ', #4
u'للإحجاج': u'لِلْإِحْجَاجِ', #2
u'للإحداد': u'لِلْإِحْدَادِ', #2
u'للأحرز': u'لِلْأَحْرَزِ', #1
u'للأحسنية': u'لِلْأَحْسَنِيَّةِ', #1
u'للإحصار': u'لِلْإِحْصَارِ', #21
u'للأحظ': u'لِلْأَحَظِّ', #3
u'للأحفظ': u'لِلْأَحْفَظِ', #3
u'للاختلاع': u'لِلِاخْتِلَاعِ', #1
u'للاختيارة': u'لِلِاخْتِيَارَةِ', #4
u'للاختين': u'لِلَّاخَّتَيْنِ', #1
u'للإخدام': u'لِلْإِخْدَامِ', #31
u'للأخرين': u'لِلْأَخِرَيْنِ', #1
u'للاخرين': u'للاخرين', #1
u'للأخس': u'لِلْأَخَسِّ', #1
u'للأخشم': u'لِلْأَخْشَمِ', #2
u'للأخصية': u'لِلْأَخَصِّيَّةِ', #1
u'للأدا': u'لِلْأَدَا', #1
u'للإدخار': u'لِلْإِدْخَارِ', #1
u'للادكار': u'لِلِادِّكَارِ', #1
u'للإدهان': u'للإدهان', #1
u'للادهان': u'لِلِادِّهَانِ', #3
u'للأدون': u'لِلْأَدْوَنِ', #2
u'للإذاية': u'لِلْإِذَايَةِ', #4
u'للإذخر': u'لِلْإِذْخِرِ', #1
u'للإراشي': u'لِلْإِرَاشِيّ', #2
u'للأربعين': u'لِلْأَرْبَعِينَ', #16
u'للأربعين': u'لِلْأَرْبَعَيْنِ', #8
u'للأرت': u'لِلْأَرَتِّ', #2
u'للارتضاع': u'لِلِارْتِضَاعِ', #1
u'للارتفاض': u'لِلِارْتِفَاضِ', #1
u'للارتفاق': u'لِلِارْتِفَاقِ', #46
u'للأردبيلي': u'لِلْأرْدَبِيلِيِّ', #2
u'للإردبين': u'لِلْإِرْدَبَّيْنِ', #1
u'للأرش': u'لِلْأَرْشِ', #64
u'للأرشين': u'لِلْأَرْشَيْنِ', #1
u'للإرقاق': u'لِلْإِرْقَاقِ', #2
u'للأروج': u'لِلْأَرْوَجِ', #1
u'للأزجي': u'لِلْأَزَجِيِّ', #1
u'للأزد': u'لِلْأَزْدِ', #2
u'للأسارى': u'لِلأُسَارَى', #1
u'للأسارى': u'لِلْأَسَارَى', #2
u'للأسارى': u'لِلْأُسَارَى', #4
u'للإسامة': u'لِلْإِسَامَةِ', #8
u'للإسبيجابي': u'لِلْإِسْبِيجَابِيّ', #1
u'للإسبيجابي': u'لِلْإِسْبِيجَابِيِّ', #17
u'للإسبيجابي': u'للإسبيجابي', #2
u'للإست': u'لِلْإِسْتِ', #1
u'للاستتابة': u'لِلِاسْتِتَابَةِ', #2
u'للاستثمان': u'لِلِاسْتِثْمَانِ', #1
u'للاستجمار': u'لِلِاسْتِجْمَارِ', #1
u'للاستحاضة': u'لِلِاسْتِحَاضَةِ', #10
u'للاستخباث': u'لِلِاسْتِخْبَاثِ', #1
u'للإستراباذي': u'للإستراباذي', #1
u'للاسترباح': u'لِلِاسْتِرْبَاحِ', #20
u'للاسترقاء': u'لِلِاسْتِرْقَاءِ', #1
u'للاسترقاق': u'لِلِاسْتِرْقَاقِ', #8
u'للأستروشني': u'للأستروشني', #2
u'للاستسعاء': u'لِلِاسْتِسْعَاءِ', #1
u'للاستشفاق': u'لِلِاسْتِشْفَاقِ', #3
u'للاستصناع': u'لِلِاسْتِصْنَاعِ', #10
u'للاستطراق': u'لِلِاسْتِطْرَاقِ', #32
u'للاستغنام': u'لِلِاسْتِغْنَامِ', #2
u'للاستفراش': u'لِلِاسْتِفْرَاشِ', #3
u'للاستفصال': u'لِلِاسْتِفْصَالِ', #2
u'للاستفضال': u'لِلِاسْتِفْضَالِ', #1
u'للاستقاءة': u'لِلِاسْتِقَاءَةِ', #3
u'للاستنجاء': u'لِلاِسْتِنْجَاءِ', #1
u'للاستنجاء': u'لِلِاسْتِنْجَاءِ', #56
u'للاستنكاح': u'لِلِاسْتِنْكَاحِ', #1
u'للاستنماء': u'لِلِاسْتِنْمَاءِ', #15
u'للاستياك': u'لِلِاسْتِيَاكِ', #8
u'للاستيناء': u'لِلِاسْتِينَاءِ', #8
u'للإسجال': u'لِلْإِسْجَالِ', #4
u'للأسراء': u'لِلْأُسَرَاءِ', #15
u'للإسرار': u'لِلْإِسْرَارِ', #3
u'للأسروشني': u'لِلْأُسْرُوشَنِيِّ', #18
u'للإسفراييني': u'للإسفراييني', #2
u'للإسقاء': u'لِلْإِسْقَاءِ', #1
u'للإسكندر': u'لِلْإِسْكَنْدَرِ', #3
u'للأسنوي': u'لِلْأَسْنَوِيِّ', #2
u'للإسنوي': u'لِلْإِسْنَوِيِّ', #255
u'للأسنى': u'لِلْأَسْنَى', #47
u'للإشاءتين': u'لِلْإِشَاءَتَيْنِ', #1
u'للأشتر': u'لِلْأَشْتَرِ', #1
u'للأشج': u'لِلأَشَجّ', #1
u'للأشج،': u'لِلأَشَجِّ،', #1
u'للأشج': u'لِلْأَشَجِّ', #1
u'للأشج': u'لِلأَشَجِّ', #4
u'للأشفق': u'لِلْأَشْفَقِ', #1
u'للأشقا': u'لِلْأَشِقَّا', #3
u'للأشقاص': u'لِلْأَشْقَاصِ', #2
u'للأشموني': u'لِلْأُشْمُونِيِّ', #3
u'للأشنان': u'لِلْأُشْنَانِ', #1
u'للأشيا': u'لِلْأَشْيَا', #1
u'للإصافة': u'لِلْإِصَافَةِ', #1
u'للأصبحي': u'لِلْأَصْبَحِيِّ', #2
u'للأصبهاني': u'لِلْأَصْبَهَانِيِّ', #1
u'للأصبهاني': u'لِلْأَصْبَهَانِيّ', #2
u'للاصطباح': u'لِلِاصْطِبَاحِ', #1
u'للإصطخري': u'لِلْإِصْطَخْرِيِّ', #20
u'للأصمعي': u'لَلْأَصْمَعِيِّ', #1
u'للأصمعي': u'لِلْأَصْمَعِيِّ', #6
u'للأصيرم': u'لَلْأُصَيْرِمُ', #3
u'للإضاقة': u'لِلْإِضَاقَةِ', #1
u'للأضعف': u'لِلْأَضْعَفِ', #20
u'للإضماء': u'لِلْإِضْمَاءِ', #1
u'للإطراد': u'لِلْإِطْرَادِ', #2
u'للإطهار': u'لِلْإِطْهَارِ', #2
u'للأظهرية': u'لِلْأَظْهَرِيَّةِ', #1
u'للاعتضاد': u'لِلِاعْتِضَادِ', #2
u'للأعدلية': u'لِلْأَعْدَلِيَّةِ', #2
u'للأعدم': u'لِلْأَعْدَمِ', #12
u'للأعرابى': u'لِلأَعْرَابِىِّ', #3
u'للأعضا': u'لِلْأَعْضَا', #1
u'للإعضال': u'لِلْإِعْضَالِ', #1
u'للأغبط': u'لِلْأَغْبَطِ', #2
u'للاغتلال': u'لِلِاغْتِلَالِ', #3
u'للإغياء': u'لِلْإِغْيَاءِ', #1
u'للأفحشية': u'لِلْأَفْحَشِيَّةِ', #1
u'للأفوه': u'لِلْأَفْوَهِ', #2
u'للإقباض': u'لِلْإِقْبَاضِ', #13
u'للإقتراب': u'للإقتراب', #1
u'للأقراء': u'لِلْأَقْرَاءِ', #13
u'للأقربية': u'لِلْأَقْرَبِيَّةِ', #5
u'للأقرعية': u'لِلْأَقْرَعِيَّةِ', #1
u'للأقصين': u'لِلْأَقْصَيْنِ', #1
u'للأقصين': u'لِلْأَقْصَيْنَ', #2
u'للأقط': u'لِلْأَقِطِ', #2
u'للأقفهسي': u'لِلْأَقْفَهْسِيِّ', #2
u'للأقلف': u'لِلْأَقْلَفِ', #3
u'للأقيس': u'لِلْأَقْيَسِ', #1
u'للإكاف': u'لِلْإِكَافِ', #1
u'للآكد': u'لِلْآكَدِ', #1
u'للأكدار': u'لِلْأَكْدَارِ', #1
u'للآكدية': u'لِلْآكَدِيَّةِ', #3
u'للأكساب': u'لِلْأَكْسَابِ', #1
u'للألهة': u'للألهة', #1
u'للأمات': u'لِلْأُمَّاتِ', #4
u'للآمدي': u'لِلْآمِدِيِّ', #37
u'للإمناء': u'لِلْإِمْنَاءِ', #1
u'للانبغاء': u'لِلِانْبِغَاءِ', #2
u'للأنبيا': u'لِلْأَنْبِيَا', #1
u'للانتقاب': u'لِلِانْتِقَابِ', #1
u'للانتقاع': u'لِلِانْتِقَاعِ', #1
u'للأنذل': u'لِلْأَنْذَلِ', #1
u'للإنزاء': u'لِلْإِنْزَاءِ', #13
u'للأنزع': u'لِلْأَنْزَعِ', #2
u'للأنصارى': u'لِلأَنْصَارِىِّ', #4
u'للأنكحة': u'لِلْأَنْكِحَةِ', #7
u'للأوجهية': u'لِلْأَوْجَهِيَّةِ', #1
u'للأورع': u'لِلْأَوْرَعِ', #3
u'للأوزاعي': u'لِلْأَوْزَاعِيِّ', #15
u'للأوزاعي': u'لِلْأَوْزَاعِيّ', #2
u'للأوزاعى': u'لِلأَوْزَاعِىِّ', #3
u'للأوسق': u'لِلْأَوْسُقِ', #1
u'للأولة': u'لِلْأَوَّلَةِ', #2
u'للأولتين': u'لِلْأُولَتَيْنِ', #1
u'للائتساء': u'لِلِائْتِسَاءِ', #3
u'للائتناس': u'لِلِائْتِنَاسِ', #1
u'للإياس': u'لِلْإِيَاسِ', #34
u'للآيسة': u'لِلْآيِسَةِ', #3
u'للآيل': u'لِلْآيِلِ', #3
u'للأيلولة': u'لِلْأَيْلُولَةِ', #1
u'للبأ': u'لِلِّبَأِ', #2
u'للبإ': u'لِلِبَإٍ', #2
u'للبادى': u'لِلْبَادِى', #1
u'للباذق': u'لِلْبَاذِقِ', #1
u'للبازري': u'لِلْبَازِرِيِّ', #1
u'للباغندي': u'لِلْبَاغَنْدِيِّ', #2
u'للباقاني': u'لِلْبَاقَانِيِّ', #8
u'للباقلاني': u'لِلْبَاقِلَّانِيِّ', #1
u'للباقى': u'لِلْبَاقِى', #3
u'للبالسي': u'لِلْبَالِسِيِّ', #1
u'للبتيراء': u'لِلْبُتَيْرَاءِ', #1
u'للبخاتي': u'لِلْبَخَاتِيِّ', #1
u'للبدار': u'لِلْبِدَارِ', #3
u'للبدخشي': u'لِلْبُدَخْشِيِّ', #4
u'للبرآء': u'لِلْبُرَآءِ', #9
u'للبرجندي': u'لِلْبُرْجُنْدِيِّ', #19
u'للبرزلي': u'لِلْبَرْزَلِيِّ', #10
u'للبركلي': u'لِلْبِرْكِلِيِّ', #1
u'للبركوي': u'للبركوي', #1
u'للبرلسي': u'لِلْبُرُلِّسِيِّ', #1
u'للبرلسي': u'لِلْبُرُلُّسِيِّ', #2
u'للبرماوي': u'لِلْبِرْمَاوِيِّ', #1
u'للبز': u'لِلْبَزِّ', #4
u'للبزدوي': u'لِلْبَزْدَوِيِّ', #10
u'للبسوطة': u'لِلْبُسُوطَةِ', #2
u'للبشت': u'لِلْبَشْتِ', #1
u'للبقار': u'لِلْبَقَّارِ', #2
u'للبقوم': u'لِلْبُقُومِ', #1
u'للبقير': u'لِلْبَقِيرِ', #1
u'للبكاره': u'لِلْبَكَارَهْ', #1
u'للبكى': u'لِلْبُكَى', #1
u'للبكير': u'لِلْبَكِيرِ', #1
u'للبلا': u'لِلْبِلَا', #1
u'للبلخي': u'لِلْبَلْخِيِّ', #4
u'للبلغم': u'لِلْبَلْغَمِ', #4
u'للبلقيني': u'لِلْبُلْقِينِيِّ', #204
u'للبلى': u'لِلْبِلَى', #4
u'للبندنيجي': u'لِلْبَنْدَنِيجِيِّ', #12
u'للبهنسي': u'لِلْبَهْنَسِيِّ', #7
u'للبهوتي': u'لِلْبُهُوتِيِّ', #1
u'للبهيتة': u'لِلْبَهِيتَةِ', #1
u'للبوذري': u'للبوذري', #1
u'للبوشنجي': u'لِلْبُوشَنْجِيِّ', #2
u'للبولاقي': u'لِلْبُولَاقِيِّ', #1
u'للبويطي': u'لِلْبُوَيْطِيِّ', #2
u'للبيتوتة': u'لِلْبَيْتُوتَةِ', #41
u'للبيري': u'لِلْبِيرِيِّ', #10
u'للبيهقي': u'للبيهقي', #1
u'للبيهقي': u'لِلْبَيْهَقِيِّ', #95
u'للتاجوري': u'لِلتَّاجُورِيِّ', #1
u'للتادلي': u'لِلتَّادَلِيِّ', #1
u'للتأدي': u'لَلتَّأَدِّي', #1
u'للتأدي': u'لِلتَّأَدِّي', #6
u'للتأذي': u'لِلتَّأَذِّي', #17
u'للتأقيت': u'لِلتَّأْقِيتِ', #33
u'للتالف': u'لِلتَّالِفِ', #14
u'للتبصرة': u'لِلتَّبْصِرَةِ', #4
u'للتبطخ': u'لِلتَّبَطُّخِ', #5
u'للتبطيخ': u'لِلتَّبْطِيخِ', #1
u'للتبعض': u'لِلتَّبَعُّضِ', #1
u'للتبوئة': u'لِلتَّبْوِئَةِ', #2
u'للتبيع': u'لِلتَّبِيعِ', #1
u'للتتارخانية': u'لِلتَّتَارْخَانِيَّةِ', #3
u'للتتائي': u'لِلتَّتَّائِيِّ', #23
u'للتتريب': u'لِلتَّتْرِيبِ', #6
u'للتجزي': u'لِلتَّجَزِّي', #8
u'للتجمير': u'لِلتَّجْمِيرِ', #1
u'للتجوير': u'لِلتَّجْوِيرِ', #1
u'للتحاصص': u'لِلتَّحَاصُصِ', #2
u'للتحتا': u'لِلتَّحْتَا', #1
u'للتحذيف': u'لِلتَّحْذِيفِ', #1
u'للتحرم': u'لِلتَّحَرُّمِ', #25
u'للتحفير': u'لِلتَّحْفِيرِ', #5
u'للتحلم': u'لِلتّحَلّمِ', #2
u'للتحيل': u'لِلتَّحَيُّلِ', #3
u'للتخاير': u'لِلتَّخَايُرِ', #1
u'للتخبيب': u'لِلتَّخْبِيبِ', #1
u'للتختم': u'لِلتَّخَتُّمِ', #1
u'للتخفف': u'لِلتَّخَفُّفِ', #1
u'للتدفي': u'لِلتَّدَفِّي', #1
u'للترخص': u'لِلتَّرَخُّصِ', #23
u'للترذيل': u'لِلتَّرْذِيلِ', #1
u'للترشيش': u'لِلتَّرْشِيشِ', #1
u'للتروك': u'لِلتُّرُوكِ', #1
u'للتزيد': u'لِلتَّزَيُّدِ', #3
u'للتسري': u'لِلتَّسَرِّي', #34
u'للتسعين': u'لِلتِّسْعَيْنِ', #1
u'للتسعين': u'لِلتِّسْعِينَ', #2
u'للتسعينا': u'لِلتِّسْعِينَا', #1
u'للتسليمة': u'لِلتَّسْلِيمَةِ', #1
u'للتسليمتين': u'لِلتَّسْلِيمَتَيْنِ', #3
u'للتسمن': u'لِلتَّسَمُّنِ', #1
u'للتشابب': u'لِلتَّشَابُبِ', #1
u'للتشاحح': u'لِلتَّشَاحُحِ', #1
u'للتشطر': u'لِلتَّشَطُّرِ', #3
u'للتشقيص': u'لِلتَّشْقِيصِ', #17
u'للتصاون': u'لِلتَّصَاوُنِ', #1
u'للتصرية': u'لِلتَّصْرِيَةِ', #4
u'للتصفيقة': u'لِلتَّصْفِيقَةِ', #1
u'للتطليقة': u'لِلتَّطْلِيقَةِ', #5
u'للتطليقتين': u'لِلتَّطْلِيقَتَيْنِ', #1
u'للتطيلس': u'لِلتَّطَيْلُسِ', #1
u'للتعريص': u'لِلتَّعْرِيصِ', #1
u'للتعزيل': u'لِلتَّعْزِيلِ', #2
u'للتعيب': u'لِلتَّعَيُّبِ', #6
u'للتعير': u'لِلتَّعَيُّرِ', #1
u'للتغبير': u'لِلتَّغْبِيرِ', #1
u'للتفتازاني': u'لِلتَّفْتَازَانِيِ', #7
u'للتفلة': u'لِلتَّفِلَةِ', #1
u'للتقادير': u'لِلتَّقَادِيرِ', #1
u'للتقاص': u'لِلتَّقَاصِّ', #5
u'للتقلل': u'لِلتَّقَلُّلِ', #1
u'للتلفيظ': u'لِلتَّلْفِيظِ', #1
u'للتمحل': u'لِلتَّمَحُّلِ', #1
u'للتمحيض': u'لِلتَّمْحِيضِ', #1
u'للتمرتاشي': u'لِلتُّمُرْتَاشِيِّ', #50
u'للتناجز': u'لِلتَّنَاجُزِ', #1
u'للتنبكتي': u'للتنبكتي', #1
u'للتنخم': u'لِلتَّنَخُّمِ', #1
u'للتنزية': u'لِلتَّنْزِيَةِ', #4
u'للتنضب': u'لِلتَّنَضُّبِ', #1
u'للتنعيل': u'لِلتَّنْعِيلِ', #1
u'للتوثقة': u'لِلتَّوْثِقَةِ', #2
u'للتوربشتى': u'للتوربشتى', #1
u'للتوريخ': u'لِلتَّوْرِيخِ', #1
u'للتوقان': u'لِلتَّوَقَانِ', #4
u'للتوقت': u'لِلتَّوَقُّتِ', #1
u'للتى': u'لِلَّتِى', #2
u'للتيماري': u'لِلتَّيْمَارِيِّ', #5
u'للثانى': u'لِلثَّانِى', #1
u'للثخانة': u'لِلثَّخَانَةِ', #1
u'للثقفى': u'لِلثَّقَفِىِّ', #1
u'للثلاثين': u'لِلثَّلاثِينَ', #1
u'للثلاثين': u'لِلثَّلَاثِينَ', #8
u'للثلثمائة': u'لِلثَّلَثِمِائَةِ', #2
u'للثمادة': u'لِلثَّمَادَةِ', #1
u'للثمانين': u'لِلثَّمَانِينَ', #6
u'للثنتين': u'لِلثِّنْتَيْنِ', #24
u'للثنيا': u'لِلثُّنْيَا', #1
u'للثنيات': u'لِلثَّنِيَّاتِ', #1
u'للثورى': u'لِلثَّوْرِىِّ', #3
u'للثيوبة': u'لِلثُّيُوبَةِ', #3
u'للجاجرمي': u'لِلْجَاجَرْمِيِّ', #1
u'للجارود،': u'لِلْجَارُودِ،', #1
u'للجارود': u'لِلْجَارُودِ', #4
u'للجبذة': u'لِلْجَبْذَةِ', #1
u'للجبغا': u'لِلْجَبْغَا', #1
u'للجبوب': u'لِلْجُبُوبِ', #2
u'للجبيرة': u'لِلْجَبِيرَةِ', #3
u'للجحادلة': u'لِلْجَحَادِلَةِ', #1
u'للجحفة': u'لِلْجُحْفَةِ', #11
u'للجدين': u'لِلْجَدَّيْنِ', #2
u'للجذعة': u'لِلْجَذَعَةِ', #3
u'للجراعي': u'لِلْجِرَاعِيِّ', #1
u'للجرجاني': u'للجرجاني', #1
u'للجرجاني،': u'لِلْجُرْجَانِيُّ،', #1
u'للجرجاني': u'لِلْجُرْجَانِيِّ', #24
u'للجرين': u'لِلْجَرِينِ', #7
u'للجزا': u'لِلْجِزَا', #1
u'للجزافين': u'لِلْجِزَافَيْنِ', #1
u'للجزولي': u'لِلْجُزُولِيِّ', #13
u'للجزيري': u'لِلْجَزِيرِيِّ', #1
u'للجعالة': u'لَلْجِعَالَةِ', #1
u'للجعالة': u'لِلْجِعَالَةِ', #3
u'للجعالة': u'لِلْجَعَالَةِ', #9
u'للجعبري': u'لِلْجَعْبَرِيِّ', #2
u'للجعرانة': u'لِلْجِعْرَانَةِ', #5
u'للجعفي': u'لِلْجُعْفِيِّ', #1
u'للجعول': u'لِلْجُعُولِ', #1
u'للجعيل': u'لِلْجَعِيلِ', #1
u'للجلاب': u'لِلْجَلَّابِ', #16
u'للجلابين': u'لِلْجَلَّابِينَ', #2
u'للجلحاء': u'لِلْجَلْحَاءِ', #1
u'للجلمين': u'لِلْجَلَمَيْنِ', #3
u'للجماء': u'لِلْجَمَّاءِ', #6
u'للجنيبة': u'لِلْجَنِيبَةِ', #2
u'للجنيد': u'لِلْجُنَيْدِ', #3
u'للجهضمى': u'لِلْجَهْضَمِىِّ', #1
u'للجهنية': u'لِلْجُهَنِيَّةِ', #5
u'للجهنيين': u'لِلْجُهَنِيِّينَ', #3
u'للجهينية': u'لِلْجُهَيْنِيَّةِ', #1
u'للجهينيين': u'لِلْجُهَيْنِيِّينَ', #2
u'للجوارى': u'لِلْجَوَارِى', #1
u'للجوجري': u'لِلْجَوْجَرِيِّ', #5
u'للجورق': u'لِلْجَوْرَقِ', #1
u'للجوزجاني': u'لِلْجُوزَجَانِيِّ', #1
u'للجويني': u'للجويني', #1
u'للجويني': u'لِلْجُوَيْنِيِّ', #18
u'للجيزي': u'لِلْجِيزِيِّ', #4
u'للحارثيين': u'لِلْحَارِثِيَّيْنِ', #4
u'للحاظر': u'لِلْحَاظِرِ', #4
u'للحافظية': u'لِلْحَافِظِيَّةِ', #1
u'للحجاح': u'لِلْحَجّاحِ', #1
u'للحجاح': u'لِلْحُجّاحِ', #1
u'للحجاوي': u'لِلْحَجَّاوِيِّ', #3
u'للحجنة': u'لِلْحُجُنَّةِ', #1
u'للحسين': u'للحسين', #1
u'للحسين': u'لِلْحُسَيْنِ', #13
u'للحسين،': u'لِلْحُسَيْنِ،', #3
u'للحصكفي': u'لِلْحَصْكَفِيِّ', #4
u'للحضرمى': u'لِلْحَضْرَمِىِّ', #7
u'للحطة': u'لَلْحِطَّةُ', #1
u'للحطة': u'لَلْحِطّةُ', #2
u'للحكرة': u'لِلْحُكْرَةِ', #2
u'للحلفSخبر': u'لِلْحِلْفِSخَبَرُ', #1
u'للحليفى': u'لِلْحُلَيْفَى', #1
u'للحموم': u'لِلْحُمُومِ', #4
u'للحميدى': u'لِلْحُمَيْدِىِّ', #1
u'للحنات': u'لِلْحِنَاتِ', #1
u'للحوبة': u'لِلْحَوْبَةِ', #1
u'للحوضى': u'لِلْحَوْضِىِّ', #1
u'للحويطات': u'لِلْحُوَيْطَاتِ', #1
u'للحويل': u'لِلْحَوِيلِ', #1
u'للحيط': u'لِلْحَيْطِ', #1
u'للحيولة': u'لِلْحُيُولَةِ', #2
u'للخارص': u'لِلْخَارِصِ', #1
u'للخالقية': u'لِلْخَالِقِيَّةِ', #1
u'للخآئنين': u'لِّلْخَآئِنِينَ', #1
u'للختانين': u'لِلْخِتَانَيْنِ', #2
u'للخثعمية': u'لِلْخَثْعَمِيَّةِ', #7
u'للخراسانى': u'لِلْخُرَاسَانِىِّ', #2
u'للخطيم': u'لِلْخَطِيمِ', #1
u'للخفاجي': u'لِلْخَفَاجِيِّ', #1
u'للخلا': u'لِلْخَلَا', #1
u'للخليطين': u'لِلْخَلِيطَيْنِ', #4
u'للخميصة': u'لِلْخَمِيصَةِ', #1
u'للخنيعة': u'للخنيعة', #3
u'للخوانيق': u'لِلْخَوَانِيقِ', #1
u'للخورنق': u'لِلْخَوَرْنَقِ', #1
u'للدارقطني،': u'لِلدَّارَقُطْنِيِّ،', #1
u'للدارقطني': u'لِلدّارَقُطْنِيّ', #3
u'للدارقطني': u'لِلدَّارَقُطْنِيِّ', #37
u'للداعى': u'لِلدَّاعِى', #1
u'للدافة': u'لِلدَّافَّةِ', #8
u'للدامغاني': u'لِلدَّامَغَانِيِّ', #1
u'للدانق': u'لِلدَّانَقِ', #1
u'للدانق': u'لِلدَّانِقِ', #2
u'للداودي': u'للداودي', #1
u'للداودي': u'لِلدَّاوُدِيِّ', #4
u'للدباء': u'لِلدُّبَّاءِ', #2
u'للدبيلي': u'لِلدَّبِيلِيِّ', #1
u'للدراوردى': u'لِلدَّرَاوَرْدِىِّ', #1
u'للدراوردي': u'لِلدَّرَاوَرْدِيِّ', #2
u'للدسومة': u'لِلدُّسُومَةِ', #5
u'للدماميني': u'لِلدَّمَامِينِيِّ', #5
u'للدميري': u'لِلدَّمِيرِيِ', #2
u'للدميري': u'لِلدَّمِيرِيِّ', #28
u'للدنيلس': u'للدنيلس', #1
u'للدنيلس': u'لِلدنيلس', #1
u'للدهلوي': u'لِلدِّهْلَوِيِّ', #1
u'للدوادمي': u'للدوادمي', #1
u'للدوامل': u'لِلدَّوَامِلِ', #2
u'للدولات': u'لِلدَّوْلَاتِ', #1
u'للدياسة': u'لِلدِّيَاسَةِ', #1
u'للدينوري': u'لِلدِّينَوَرِيِّ', #1
u'للدينوري': u'لِلدّينَوَرِيّ', #1
u'للديور': u'لِلدُّيُورِ', #1
u'للديورة': u'لِلدُّيُورَةِ', #3
u'للذاب': u'لِلذَّابِّ', #1
u'للرءوس': u'لِلرُّءُوسِ', #4
u'للرازي': u'لِلرَّازِيِّ', #13
u'للراوى': u'للراوى', #1
u'للرتقاء': u'لِلرَّتْقَاءِ', #7
u'للرحا': u'لِلرَّحَا', #1
u'للرحمةوروي': u'لِلْرَحْمَةِوَرُوِيَ', #1
u'للرحمن،': u'للرحمن،', #1
u'للرحمن': u'للرحْمنِ', #1
u'للرحمن': u'لِلرّحْمَنِ', #2
u'للرحمن': u'لِلرَّحْمَنِ', #77
u'للردء': u'لِلرِّدْءِ', #1
u'للرداد': u'لِلرَّدَّادِ', #1
u'للرساتيق': u'لِلرَّسَاتِيقِ', #2
u'للرستاق': u'لِلرُّسْتَاقِ', #3
u'للرستغفني': u'للرستغفني', #1
u'للرسنة': u'لِلرَّسَنَةِ', #1
u'للرصاع': u'لِلرَّصَّاعِ', #1
u'للرضعات': u'لِلرَّضَعَاتِ', #2
u'للرعى': u'للرعى', #1
u'للرعيني': u'لِلرُّعَيْنِيِّ', #2
u'للرقبى': u'لِلرُّقْبَى', #1
u'للرقيا': u'لِلرُّقْيَا', #2
u'للركاز': u'لِلرِّكَازِ', #6
u'للركوعونسي': u'لِلرُّكُوعِوَنَسِيَ', #1
u'للركية': u'لِلرّكِيّةِ', #4
u'للرماصي': u'لِلرَّمَاصِيِّ', #5
u'للرموح': u'لِلرَّمُوحِ', #1
u'للرمى': u'لِلرَّمْىِ', #1
u'للرهاويين': u'لِلرَّهَاوِيِّينَ', #2
u'للرهاويين': u'لِلرّهَاوِيّينَ', #3
u'للروشن': u'لِلرَّوْشَنِ', #2
u'للرويا': u'لَلرَّوِيَّا', #1
u'للروياني': u'لِلرُّويَانِيِّ', #112
u'للريس': u'لِلرَّيِّسِ', #1
u'للزبرقان': u'لِلزّبْرِقَانِ', #4
u'للزبيلي': u'لِلزَّبِيلِيِّ', #2
u'للزرقاني': u'لِلزَّرْقَانِيِّ', #15
u'للزريراني': u'لِلزَّرِيرَانِيِّ', #1
u'للزمخشري': u'لِلزَّمَخْشَرِيِ', #2
u'للزمخشري': u'لِلزَّمَخْشَرِيِّ', #9
u'للزمنى': u'لِلزَّمْنَى', #3
u'للزندوستي': u'للزندوستي', #2
u'للزندويستي': u'للزَّنْدَوِيستي', #1
u'للزنكلوني': u'لِلزَّنْكَلُونِيِّ', #1
u'للزنية': u'لِلزِّنْيَةِ', #2
u'للزهرى': u'لِلزُّهْرِىِّ', #11
u'للزهومة': u'لِلزُّهُومَةِ', #2
u'للزهيري': u'لِلزُّهَيْرِيِّ', #2
u'للزيافة': u'لِلزِّيَافَةِ', #1
u'للزيلعي': u'لِلزَّيْلَعِيِّ', #60
u'للساباط': u'لِلسَّابَاطِ', #3
u'للسائحاني': u'لِلسَّائِحَانِيِّ', #1
u'للسباهي': u'لِلسَّبَاهِيِّ', #3
u'للسبائية': u'للسّبائّية', #1
u'للسبيبة': u'لِلسَّبِيبَةِ', #1
u'للستين': u'لَلسِّتِّينَ', #1
u'للستين': u'لِلسِّتِّينَ', #18
u'للستين': u'لِلسِّتَّيْنِ', #4
u'للسخال': u'لِلسِّخَالِ', #1
u'للسخاوي': u'لِلسَّخَاوِيِّ', #3
u'للسرف': u'لِلسَّرَفِ', #36
u'للسرقين': u'لَلسِّرْقِينِ', #1
u'للسرقين': u'لِلسِّرْقِينِ', #1
u'للسعى': u'لِلَّسْعَى', #1
u'للسغناقي': u'لِلسِّغْنَاقِيِّ', #4
u'للسفتجة': u'لِلسُّفْتَجَةِ', #1
u'للسفلاني': u'لِلسُّفْلَانِيِّ', #1
u'للسقية': u'لِلسَّقِيَّةِ', #1
u'للسقية': u'لِلسَّقْيَةِ', #1
u'للسقيتين': u'لِلسَّقْيَتَيْنِ', #2
u'للسما': u'لِلسَّمَا', #1
u'للسمحاق': u'لِلسِّمْحَاقِ', #1
u'للسمعاني': u'لِلسَّمْعَانِيِّ', #3
u'للسمهودي': u'لِلسَّمْهُودِيِّ', #2
u'للسنباطي': u'لِلسَّنْبَاطِيِّ', #2
u'للسنجاري': u'لِلسِّنْجَارِيِّ', #1
u'للسنهوري': u'لِلسَّنْهُورِيِّ', #2
u'للسهروردي': u'لِلسُّهْرَوَرْدِيِ', #3
u'للسوال': u'لِلسُّوَالِ', #1
u'للسوقة': u'لِلسُّوقَةِ', #5
u'للسيامة': u'لِلسِّيَامَةِ', #2
u'للسيوري': u'لِلسُّيُورِيِّ', #20
u'للشادخ': u'لِلشَّادِخِ', #1
u'للشاذروان': u'لِلشَّاذَرْوَانِ', #7
u'للشاذكوني': u'لِلشَّاذَكُونِيِّ', #1
u'للشاغية': u'لِلشَّاغِيَةِ', #1
u'للشافعى': u'لِلشَّافِعِىِّ', #12
u'للشالوسي': u'لِلشَّالُوسِيِّ', #1
u'للشبراملسي': u'للشبراملسي', #3
u'للشبرخيتي': u'لِلشَّبْرَخِيتِيِّ', #1
u'للشبوبة': u'لِلشُّبُوبَةِ', #1
u'للشبيني': u'للشبيني', #1
u'للشجوج': u'للشجوج', #2
u'للشرا': u'لِلشِّرَا', #2
u'للشرة': u'لِلشِّرَّةِ', #1
u'للشركا': u'لِلشُّرَكَا', #1
u'للشرمساحي': u'لِلشَّرْمَسَاحِيِّ', #1
u'للشرنبلالي': u'لِلشُّرُنْبَلَالِيِّ', #1
u'للشرنبلالي': u'للشرنبلالي', #2
u'للشرنبلالي': u'لِلشُّرُنْبُلَالِيِّ', #48
u'للشرنبلالية': u'للشُّرُنبُلاليَّة', #4
u'للشعبى': u'لِلشَّعْبِىِّ', #10
u'للشقص': u'لِلشِّقْصِ', #61
u'للشلبي': u'لِلشَّلَبِيِّ', #3
u'للشمني': u'لِلشُّمُنِّيِّ', #6
u'للشنشوري': u'لِلشَّنْشُورِيِّ', #2
u'للشنئيين': u'لِلشَّنَئِيِّينَ', #1
u'للشهادةوالوجه': u'لِلشَّهَادَةِوَالْوَجْهُ', #1
u'للشواب': u'لِلشَّوَابِّ', #13
u'للشوبري': u'لِلشَّوْبَرِيِّ', #8
u'للشونيز': u'لِلشُّونِيزِ', #3
u'للشىء': u'للشىء', #1
u'للشيحين': u'لِلشِّيحَيْنِ', #1
u'للشيرازي': u'لِلشِّيرَازِيِّ', #11
u'للشيوخة': u'لِلشُّيُوخَةِ', #1
u'للصابئية': u'لِلصَّابِئِيَّةِ', #1
u'للصاغاني': u'لِلصَّاغَانِيِّ', #2
u'للصبى': u'لِلصَّبَى', #1
u'للصبى': u'لِلصَّبِىِّ', #1
u'للصدا': u'لِلصَّدَا', #1
u'للصرورة': u'للصرورة', #2
u'للصرورة': u'لِلصَّرُورَةِ', #5
u'للصغاني،': u'لِلصَّغَانِيُّ،', #1
u'للصغاني،': u'لِلصَّغَانِيِّ،', #1
u'للصغاني': u'لِلْصَغَانِيِّ', #1
u'للصغاني': u'لِلصَّغَانِيِّ', #2
u'للصفراوتين': u'لِلصَّفْراوَتَيْنِ', #1
u'للصقلبي': u'لِلصَّقْلَبِيِّ', #1
u'للصكاك': u'لِلصَّكَّاكِ', #13
u'للصلاةفأراد': u'لِلصَّلَاةِفَأَرَادَ', #1
u'للصلاتية': u'لِلصَّلَاتِيَّةِ', #3
u'للصنابحي': u'لِلصُّنَابِحِيِّ', #1
u'للصهرة': u'لِلصِّهْرَةِ', #1
u'للصواغين': u'لِلصَّوَّاغِينَ', #1
u'للصيال': u'لِلصِّيَالِ', #5
u'للصيمري': u'لِلصَّيْمَرِيِّ', #19
u'للضبطين': u'لِلضَّبْطَيْنِ', #1
u'للضروة': u'لِلضِّرْوَةِ', #6
u'للضروره': u'لِلضَّرُورَهْ', #1
u'للضنة': u'لِلضِّنَةِ', #4
u'للضيا': u'لِلضِّيَا', #2
u'للضيزن': u'لِلضّيْزَنِ', #1
u'للطابو': u'لَلطَّابُو', #2
u'للطارم': u'للطارم', #1
u'للطاوسي': u'لِلطَّاوُسِيِّ', #10
u'للطباهجة': u'لِلطَّبَاهِجَةِ', #1
u'للطبراني': u'لِلطَّبَرَانِيّ', #1
u'للطبراني،': u'لِلطَّبَرَانِيِّ،', #1
u'للطبراني': u'لِلطَّبَرَانِيِّ', #66
u'للطبري': u'لِلطَّبَرِيِّ', #12
u'للطبلاوي': u'لِلطَّبَلَاوِيِّ', #5
u'للطحاوي': u'لِلطَّحَاوِيّ', #1
u'للطحاوي': u'لِلطَّحَاوِيِّ', #22
u'للطحينة': u'لِلطَّحِينَةِ', #2
u'للطخيخي': u'لِلطِّخِّيخِيِّ', #3
u'للطراحة': u'لِلطَّرَّاحَةِ', #1
u'للطرار': u'لِلطَّرَّارِ', #1
u'للطرسوسي': u'لِلطَّرَسُوسِيِّ', #6
u'للطرطوشي': u'لِلطَّرْطُوشِيِّ', #1
u'للطرطوشي': u'لِلطُّرْطُوشِيِّ', #6
u'للطفيل': u'لِلطّفَيْلِ', #1
u'للطفيل': u'لِلطُّفَيْلِ', #1
u'للطلا': u'لِلطِّلَا', #1
u'للطندتائي': u'لِلطَّنْدَتَائِيِّ', #1
u'للطهرين': u'لِلطُّهْرَيْنِ', #1
u'للطواشي': u'لِلطَّوَاشِيِ', #1
u'للطواشي': u'لِلطَّوَاشِيِّ', #1
u'للطؤرة': u'لِلطُّؤْرَةِ', #1
u'للطوفة': u'لِلطَّوْفَةِ', #2
u'للظما': u'لِلظَّمَا', #1
u'للظهارين': u'لِلظِّهَارَيْنِ', #1
u'للظؤرة': u'لِلظُّؤْرَةِ', #1
u'للظئارة': u'لِلظِّئَارَةِ', #1
u'للظئر': u'لِلظِّئْرِ', #30
u'للظئرة': u'لِلظِّئْرَةِ', #1
u'للظئورة': u'لِلظَّئُورَةِ', #2
u'للظئورة': u'لِلظُّئُورَةِ', #2
u'للعامرى': u'لِلْعَامِرِىِّ', #1
u'للعائن': u'لِلْعَائِنِ', #12
u'للعبدري': u'للْعَبْدَرِيُّ', #1
u'للعبدوسي': u'لِلْعَبْدُوسِيِّ', #1
u'للعبديني': u'لِلْعَبْدِينِيِّ', #1
u'للعبلات': u'لِلْعَبَلاَتِ', #1
u'للعبيلي': u'لِلْعُبَيْلِيِّ', #1
u'للعتقاء': u'لِلْعُتَقَاءِ', #5
u'للعتقين': u'لِلْعِتْقَيْنِ', #2
u'للعتيرة': u'لِلْعَتِيرَةِ', #1
u'للعداوه': u'لِلْعَدَاوَهْ', #1
u'للعذرى': u'لِلْعُذْرِىِّ', #1
u'للعربى': u'لِلْعَرَبِىِّ', #1
u'للعرنيين': u'لِلْعُرَنِيِّينَ', #3
u'للعزايا': u'لِلْعَزَايَا', #2
u'للعزير': u'لِلْعُزَيْرِ', #1
u'للعسيلة': u'لِلْعُسَيْلَةِ', #1
u'للعصوبة': u'لِلْعُصُوبَةِ', #7
u'للعضيهة': u'لِلْعَضِيهَةِ', #1
u'للعطن': u'لِلْعَطِنِ', #1
u'للعطن': u'لِلْعَطَنِ', #12
u'للعكم': u'لِلْعَكْمِ', #2
u'للعلس': u'لِلْعَلَسِ', #2
u'للعمرى': u'لِلْعُمْرَى', #6
u'للعنوية': u'لِلْعَنَوِيَّةِ', #1
u'للعنين': u'لِلْعِنِّينِ', #9
u'للعوافى': u'لِلْعَوَافِى', #2
u'للعوانة': u'لِلْعَوَانَةِ', #1
u'للعياض': u'لِلْعِيَاضِ', #1
u'للعيافة': u'لِلْعِيَافَةِ', #2
u'للعيدسنة': u'لِلْعِيدِسُنَّةٌ', #1
u'للعيدينقبل': u'لِلْعِيدَيْنِقَبْلَ', #1
u'للعيسوي': u'لِلْعِيسَوِيِّ', #1
u'للغازى': u'لِلْغَازِى', #1
u'للغالط': u'لِلْغَالِطِ', #2
u'للغالطين': u'لِلْغَالِطِينَ', #2
u'للغامدية': u'لِلْغَامِدِيَّةِ', #18
u'للغرما': u'لِلْغُرَمَا', #6
u'للغرياني': u'لِلْغِرْيَانِيِّ', #2
u'للغزووالوجه': u'لِلْغَزْوِوَالْوَجْهُ', #1
u'للغلث': u'لِلْغَلِثِ', #1
u'للغلصمة': u'لِلْغُلْصُمَةِ', #1
u'للغموس': u'لِلْغَمُوسِ', #1
u'للفارابي': u'لِلْفَارَابِيِّ', #4
u'للفارقية': u'لِلْفَارِقِيَّةِ', #1
u'للفاقئ': u'لِلْفَاقِئِ', #3
u'للفامي': u'لِلْفَامِيِّ', #4
u'للفجيع': u'للفجيع', #1
u'للفرافصة': u'لِلْفُرَافِصَةِ', #1
u'للفرغانيين': u'لِلْفَرْغَانِيِّينَ', #1
u'للفريعة': u'لِلْفُرَيْعَةِ', #10
u'للفصولين': u'لِلْفُصُولَيْنِ', #2
u'للفقرا': u'لَلْفُقَرَا', #1
u'للفقرا': u'لِلْفُقَرَا', #3
u'للفلو': u'لِلْفُلُوِّ', #1
u'للفهري': u'لِلْفِهْرِيِّ', #1
u'للفهوم': u'لِلْفُهُومِ', #1
u'للفوائت': u'لِلْفَوَائِتِ', #14
u'للفئام': u'لِلْفِئَامِ', #4
u'للفيت': u'لِلُفَيْتٍ', #1
u'للفيصولة': u'لِلْفَيْصُولَة', #1
u'للفيصولة': u'لِلْفَيْصُولَةِ', #42
u'للفيومي': u'لِلْفَيُّومِيِّ', #1
u'للقاحة': u'لِلْقَاحَّةِ', #1
u'للقادف': u'لِلْقَادِفِ', #1
u'للقاضى': u'لِلْقَاضِى', #8
u'للقافة': u'لِلْقَافَةِ', #5
u'للقآني': u'لِلْقَآنِيِّ', #2
u'للقائف': u'لِلْقَائِفِ', #7
u'للقتبي': u'لِلْقِتْبَيَّ', #1
u'للقتبي': u'لِلْقُتَبِيّ', #3
u'للقتبي': u'لِلْقُتَبِيِّ', #3
u'للقذفين': u'لِلْقَذْفَيْنِ', #3
u'للقراءه': u'لِلْقِرَاءَهْ', #1
u'للقرافة': u'لِلْقَرَافَةِ', #1
u'للقرافي': u'لِلْقَرَافِيِّ', #73
u'للقرشى': u'لِلْقُرَشِىِّ', #2
u'للقرطالة': u'لِلْقِرْطَالَةِ', #1
u'للقرطم': u'لِلْقُرْطُمِ', #3
u'للقرماني': u'لِلْقَرْمَانِيِّ', #1
u'للقسطلاني': u'لِلْقَسْطَلَّانِيِّ', #2
u'للقشيري': u'لِلْقُشَيْرِيِّ', #1
u'للقصارين': u'لِلْقَصَّارَيْنِ', #1
u'للقصارين': u'لِلْقَصَّارِينَ', #8
u'للقصواء': u'لِلْقَصْوَاءِ', #8
u'للقضا': u'لِلْقَضَا', #1
u'للقضاءإلا': u'لِلْقَضَاءِإِلَّا', #1
u'للقضاب': u'لِلْقَضّابِ', #1
u'للقضامة': u'لِلْقُضَامَةِ', #1
u'للقطاط': u'لِلْقِطَاطِ', #1
u'للقطعات': u'لِلْقِطْعَاتِ', #1
u'للقعقاع': u'للقعقاع', #1
u'للقفاء': u'لِلْقَفَاءِ', #1
u'للقفيز': u'لِلْقَفِيزِ', #4
u'للقلح': u'لِلْقَلَحِ', #2
u'للقلشاني': u'لِلْقَلْشَانِيِّ', #1
u'للقلشاني': u'لِلْقَلَشَانِيِّ', #2
u'للقليس': u'لِلْقُلّيْسِ', #1
u'للقليوبي': u'لِلْقَلْيُوبِيِّ', #47
u'للقمائم': u'لِلْقَمَائِمِ', #2
u'للقمولي': u'لِلْقَمُولِيِّ', #29
u'للقنائين': u'لِلْقَنَّائِينَ', #1
u'للقهستاني': u'لِلْقُهُسْتَانِيِّ', #26
u'للقهوات،': u'للقهوات،', #1
u'للقوادح': u'لِلْقَوَادِحِ', #1
u'للقولنج': u'لِلْقُولَنْجِ', #3
u'للقونوي': u'لِلْقُونَوِيِّ', #9
u'للكازروني': u'لِلْكَازَرُونِيِّ', #1
u'للكاساني': u'لِلْكَاسَانِيِّ', #2
u'للكافيجي': u'لِلْكَافِيجِيِّ', #1
u'للكاكي': u'لِلْكَاكِيِّ', #4
u'للكالئ': u'لِلْكَالِئِ', #4
u'للكبيس': u'لِلْكَبِيسِ', #1
u'للكحال': u'لِلْكَحَّالِ', #6
u'للكديد': u'لِلْكَدِيدِ', #1
u'للكرابيس': u'لِلْكَرَابِيسِ', #1
u'للكرابيسي': u'لِلْكَرَابِيسِيِّ', #5
u'للكرباس': u'لِلْكِرْبَاسِ', #2
u'للكرخي': u'لِلْكَرْخِيِّ', #29
u'للكردري': u'لِلْكَرْدَرِيِّ', #526
u'للكرسف': u'لِلْكُرْسُفِ', #1
u'للكرماني': u'لِلْكَرْمَانِيِّ', #9
u'للكسبين': u'لِلْكَسْبَيْنِ', #1
u'للكسوب': u'لِلْكَسُوبِ', #1
u'للكفيري': u'لِلْكُفَيْرِيِّ', #1
u'للكلاباذي': u'لِلْكَلَابَاذِيِّ', #1
u'للكلامين': u'لِلْكَلَامَيْنِ', #5
u'للكلدة': u'لِلْكَلَدَةِ', #1
u'للكليبة': u'لِلْكُلَيْبَةِ', #1
u'للكمرة': u'لِلْكَمَرَةِ', #1
u'للكمل': u'لِلْكُمَّلِ', #1
u'للكندى': u'لِلْكِنْدِىِّ', #1
u'للكوارات': u'لِلْكُوَّارَاتِ', #2
u'للكوارة': u'لِلْكُوَّارَةِ', #3
u'للكواشي': u'لِلْكَوَاشِيِّ', #1
u'للكيزان': u'لِلْكِيزَانِ', #6
u'للكيع': u'لِلَكِيعِ', #1
u'للكيمخت': u'لِلْكَيْمَخْتِ', #1
u'للكيموسات': u'لِلْكَيْمُوسَاتِ', #1
u'للمأبور': u'لِلْمَأْبُورِ', #1
u'للماتريدية': u'لِلْمَاتُرِيدِيَّة', #1
u'للماتريدية': u'لِلْمَاتُرِيدِيَّةِ', #1
u'للمأتي': u'لِلْمَأْتِيِّ', #1
u'للمأتية': u'لِلْمَأْتِيَّةِ', #1
u'للماجرى': u'لِلْمَاجَرَى', #3
u'للمارديني': u'لِلْمَارْدِينِيِّ', #2
u'للمازري': u'لِلْمَازَرِيّ', #1
u'للمازري': u'لِلْمَازِرِيِّ', #93
u'للماسرجسي': u'لِلْمَاسَرْجِسِيِّ', #2
u'للماضى': u'لِلْمَاضِى', #1
u'للمألوم': u'لِلْمَأْلُومِ', #1
u'للمأمومية': u'لِلْمَأْمُومِيَّةِ', #1
u'للمانعية': u'لِلْمَانِعِيَّةِ', #2
u'للماوردي': u'لِلْمَاوَرْدِيِّ', #236
u'للمبارئة': u'لِلْمُبَارِئَةِ', #2
u'للمباضعة': u'لِلْمُبَاضَعَةِ', #6
u'للمبانة': u'لِلْمُبَانَةِ', #17
u'للمباهلة': u'لِلْمُبَاهَلَةِ', #1
u'للمباينة': u'لِلْمُبَايَنَةِ', #13
u'للمبتدي': u'لِلْمُبْتَدِي', #4
u'للمبتدين': u'لِلْمُبْتَدِينَ', #1
u'للمبتنى': u'لَلْمُبْتَنَى', #1
u'للمبتنى': u'لِلْمُبْتَنَى', #1
u'للمبتوتة': u'لِلْمَبْتُوتَةِ', #23
u'للمبرأ': u'لِلْمُبْرَأِ', #1
u'للمبعض': u'لِلْمُبَعِّضِ', #1
u'للمبعض': u'لِلْمُبَعَّضِ', #20
u'للمبعضة': u'لِلْمُبَعَّضَةِ', #4
u'للمبيعية': u'لِلْمَبِيعِيَّةِ', #2
u'للمتاركة': u'لِلْمُتَارَكَةِ', #7
u'للمتباذلين': u'لِلْمُتَبَاذِلِينَ', #8
u'للمتجالة': u'لِلْمُتَجَالَّةِ', #5
u'للمتجوه': u'لِلْمُتَجَوَّهِ', #1
u'للمتخفف': u'لِلْمُتَخَفِّفِ', #1
u'للمتسحر': u'لِلْمُتَسَحِّرِ', #1
u'للمتشرعة': u'لِلْمُتَشَرِّعَةِ', #2
u'للمتصارفين': u'للمتصارفين', #1
u'للمتعاوضين': u'لِلْمُتَعَاوِضَيْنِ', #2
u'للمتعمم': u'لِلْمُتَعَمِّمِ', #2
u'للمتفاحش': u'لِلْمُتَفَاحِشِ', #1
u'للمتقارضين': u'للمتقارضين', #1
u'للمتقارضين': u'لِلْمُتَقَارِضَيْنِ', #2
u'للمتكاري': u'لِلْمُتَكَارِي', #28
u'للمتكدي': u'لِلْمُتَكَدِّي', #1
u'للمتلابسين': u'لِلْمُتَلَابِسَيْنِ', #1
u'للمتلقط': u'لِلْمُتَلَقِّطِ', #1
u'للمتلقى': u'لِلْمُتَلَقَّى', #1
u'للمتهب': u'لِلْمُتَّهِبِ', #18
u'للمتهب': u'لِلْمُتَّهَبِ', #7
u'للمتهيئ': u'لِلْمُتَهَيِّئِ', #6
u'للمتولى': u'لِلْمُتَوَلَّى', #4
u'للمتيطي': u'لِلْمُتَيْطِيِّ', #34
u'للمتيطية': u'لِلْمُتَيْطِيَّةِ', #2
u'للمثلة': u'لِلْمَثُلَةِ', #1
u'للمثلة': u'لِلْمُثْلَةِ', #6
u'للمثمون': u'لِلْمَثْمُونِ', #1
u'للمجاعل': u'لِلْمُجَاعَلِ', #1
u'للمجاعل': u'لِلْمُجَاعِلِ', #3
u'للمجبوب': u'لِلْمَجْبُوبِ', #6
u'للمجبوبين': u'لِلْمَجْبُوبِينَ', #1
u'للمجتدي': u'لِلْمُجْتَدِي', #2
u'للمجحود': u'لِلْمَجْحُودِ', #2
u'للمجشي': u'لِلْمُجَشِّي', #1
u'للمحارسة': u'لِلْمُحَارَسَةِ', #1
u'للمحاز': u'لِلْمُحَازِ', #1
u'للمحاصة': u'لِلْمُحَاصَّةِ', #2
u'للمحاويج': u'لِلْمَحَاوِيجِ', #5
u'للمحتجر': u'لِلْمُحْتَجِرِ', #2
u'للمحجوج': u'لِلْمَحْجُوجِ', #19
u'للمحجوم': u'لِلْمَحْجُومِ', #1
u'للمحصر،': u'لِلْمُحْصَرِ،', #2
u'للمحصر': u'لِلْمُحْصَرِ', #26
u'للمحصرين': u'لِلْمُحْصَرِينَ', #1
u'للمحوج': u'لِلْمُحْوِجِ', #1
u'للمخارجة': u'لِلْمُخَارَجَةِ', #3
u'للمخالع': u'لِلْمُخَالِعِ', #1
u'للمخبت': u'لِلْمُخْبِتِ', #1
u'للمختلع': u'لِلْمُخْتَلَعِ', #4
u'للمختلعة': u'لِلْمُخْتَلِعَةِ', #21
u'للمخذل': u'لِلْمُخْذِلِ', #1
u'للمخرف': u'لِلْمِخْرَفِ', #1
u'للمخزوق': u'لِلْمَخْزُوقِ', #1
u'للمخصمة': u'لِلْمَخْصَمَةِ', #1
u'للمخفوض': u'لِلْمَخْفُوضِ', #1
u'للمخمصة': u'لِلْمَخْمَصَةِ', #2
u'للمداين': u'لِلْمُدَايِنِ', #1
u'للمداينين': u'لِلْمُدَايِنِينَ', #1
u'للمدفوق': u'لِلْمَدْفُوقِ', #1
u'للمدنف': u'لِلْمُدْنِفِ', #1
u'للمذادين': u'لِلْمُذَادِينَ', #1
u'للمذاكرين': u'لِلْمُذَاكِرِينَ', #1
u'للمذروع': u'لِلْمَذْرُوعِ', #2
u'للمذفف': u'لِلْمُذَفِّفِ', #1
u'للمذكاة': u'لِلْمُذَكَّاةِ', #6
u'للمذي': u'لِلْمَذْيِ', #5
u'للمراة': u'لِلْمُرَاةِ', #1
u'للمراطلة': u'لِلْمُرَاطَلَةِ', #1
u'للمراوزة': u'لِلْمَرَاوِزَةِ', #6
u'للمراوضة': u'لِلْمُرَاوِضَةِ', #1
u'للمراوضة': u'لِلْمُرَاوَضَةِ', #3
u'للمرائين': u'لِلْمُرَائِينَ', #3
u'للمرتضعة': u'لِلْمُرْتَضِعَةِ', #7
u'للمرقوق': u'لِلْمَرْقُوقِ', #2
u'للمرموس': u'لِلْمَرْمُوسِ', #2
u'للمروآت': u'لِلْمُرُوآتِ', #1
u'للمروذي': u'لِلْمَرُّوذِيِّ', #10
u'للمزابنة': u'لِلْمُزَابَنَةِ', #23
u'للمزبور': u'لِلْمَزْبُورِ', #1
u'للمزجد': u'لِلْمُزَجَّدِ', #4
u'للمزجورين': u'لِلْمَزْجُورِينَ', #4
u'للمزحوم': u'لِلْمَزْحُومِ', #4
u'للمزدلفه': u'لِلْمُزْدَلِفَهْ', #1
u'للمزنى': u'لِلْمُزَنِىِّ', #1
u'للمزنى؟': u'لِلْمُزَنِىِّ؟', #1
u'للمساقى': u'لِلْمُسَاقَى', #7
u'للمساوى': u'لِلْمُسَاوَى', #1
u'للمسبل': u'لِلْمُسَبَّلِ', #1
u'للمسبل': u'لِلْمُسْبَلِ', #1
u'للمسبل': u'لِلْمُسْبِلِ', #1
u'للمسبل': u'لِلْمُسَبِّلِ', #3
u'للمسبلة': u'لِلْمُسَبَّلَةِ', #4
u'للمستام': u'لِلْمُسْتَامِ', #6
u'للمستبرأة': u'لِلْمُسْتَبْرَأَةِ', #1
u'للمستبضع': u'لِلْمُسْتَبْضَعِ', #1
u'للمستبضع': u'لِلْمُسْتَبْضِعِ', #9
u'للمستحاضة': u'لِلْمُسْتَحَاضَةِ', #28
u'للمسترضع': u'لِلْمُسْتَرْضِعِ', #4
u'للمستسعي': u'لِلْمُسْتَسْعِي', #1
u'للمستسلف': u'للمستسلفِ', #1
u'للمستشكل': u'لِلْمُسْتَشْكِلِ', #1
u'للمستصفى': u'لِلْمُسْتَصْفَى', #1
u'للمستصنع': u'لِلْمُسْتَصْنَعِ', #1
u'للمستصنع': u'لِلْمُسْتَصْنِعِ', #24
u'للمستقذر': u'لِلْمُسْتَقْذَرِ', #5
u'للمستقرض': u'لِلْمُسْتَقْرَضِ', #2
u'للمستقرض': u'لِلْمُسْتَقْرِضِ', #68
u'للمستكري': u'لِلْمُسْتَكْرِي', #6
u'للمستلحق': u'لِلْمُسْتَلْحِقِ', #13
u'للمستلحق': u'لِلْمُسْتَلْحَقِ', #17
u'للمستلف': u'لِلْمُسْتَلِفِ', #2
u'للمستملي': u'لِلْمُسْتَمْلِيِّ', #1
u'للمستناب': u'لِلْمُسْتَنَابِ', #1
u'للمستنكح': u'لِلْمُسْتَنْكَحِ', #1
u'للمستنكح': u'لِلْمُسْتَنْكِحِ', #2
u'للمستنيب': u'لِلْمُسْتَنِيبِ', #11
u'للمستوفى': u'لِلْمُسْتَوْفَى', #3
u'للمسجديستحب': u'لِلْمَسْجِدِيُسْتَحَبُّ', #1
u'للمسدى': u'لِلْمُسَدَّى', #1
u'للمسدى': u'لِلْمُسْدَى', #1
u'للمسعي': u'لِلْمَسْعِيِّ', #3
u'للمسقفتين': u'لِلْمُسْقَفَتَيْنِ', #1
u'للمسمعى': u'لِلْمِسْمَعِىِّ', #1
u'للمسملين': u'لِلْمُسْمَلِينَ', #1
u'للمسناوي': u'لِلْمِسْنَاوِيِّ', #2
u'للمسوح': u'لِلْمُسُوحِ', #1
u'للمسين': u'لِلْمَسَّيْنِ', #1
u'للمشتراة': u'لِلْمُشْتَرَاةِ', #1
u'للمشترى': u'لَلْمُشْتَرَى', #1
u'للمشترى': u'لِلْمُشْتَرَى', #43
u'للمشدخ': u'لِلْمُشَدَّخِ', #1
u'للمشذالي': u'لِلْمَشَذَّالِيِّ', #3
u'للمشكى': u'لِلْمُشْكَى', #1
u'للمشية': u'لِلْمِشْيَةِ', #1
u'للمصراة': u'لِلْمُصَرَّاةِ', #3
u'للمصطرف': u'لِلْمُصْطَرِفِ', #3
u'للمصمودي': u'لِلْمَصْمُودِيِّ', #1
u'للمضاررة': u'لِلْمُضَارَرَةِ', #1
u'للمضحى': u'لِلْمُضَحَّى', #1
u'للمضرور': u'لِلْمَضْرُورِ', #4
u'للمطابقية': u'لِلْمُطَابِقِيَّةِ', #1
u'للمطرو': u'لِلْمَطْرُوِّ', #1
u'للمطروء': u'لِلْمَطْرُوءِ', #1
u'للمعاطاة': u'لِلْمُعَاطَاةِ', #6
u'للمعاقدين': u'لِلْمُعَاقِدِينَ', #2
u'للمعاوض': u'لِلْمُعَاوَضِ', #1
u'للمعبودية': u'لِلْمَعْبُودِيَّةِ', #1
u'للمعتاض': u'لِلْمُعْتَاضِ', #1
u'للمعتضد': u'لِلْمُعْتَضِدِ', #1
u'للمعتفي': u'لِلْمُعْتَفِي', #1
u'للمعتوق': u'لِلْمَعْتُوقِ', #4
u'للمعثور': u'لِلْمَعْثُورِ', #1
u'للمعجوز': u'لِلْمَعْجُوزِ', #4
u'للمعصفر': u'لِلْمُعَصْفَرِ', #1
u'للمعضوب': u'لِلْمَعْضُوبِ', #13
u'للمعلوك': u'لِلْمَعْلُوكِ', #1
u'للمغارسة': u'لِلْمُغَارَسَةِ', #3
u'للمغزول': u'لِلْمَغْزُولِ', #4
u'للمغصوص': u'لِلْمَغْصُوصِ', #1
u'للمغفره': u'للْمَغْفِرَهْ', #1
u'للمغلوبية': u'لِلْمَغْلُوبِيَّةِ', #3
u'للمغيا': u'لِلْمُغَيَّا', #2
u'للمفاريد': u'لِلْمَفَارِيدِ', #1
u'للمفاعلة': u'لِلْمُفَاعَلَةِ', #1
u'للمفاليس': u'لِلْمَفَالِيسِ', #5
u'للمفتصد': u'لِلْمُفْتَصَدِ', #1
u'للمفتصد': u'لِلْمُفْتَصِدِ', #1
u'للمفتوت': u'لِلْمَفْتُوتِ', #1
u'للمفصود': u'لِلْمَفْصُودِ', #2
u'للمفضولية': u'لِلْمَفْضُولِيَّةِ', #2
u'للمفقوء': u'لِلْمَفْقُوءِ', #1
u'للمفقوءة': u'لِلْمَفْقُوءَةِ', #6
u'للمقارض': u'لِلْمُقَارَضِ', #5
u'للمقارض': u'لِلْمُقَارِضِ', #9
u'للمقايل': u'لِلْمُقَايِلِ', #1
u'للمقتص': u'لِلْمُقْتَصِّ', #9
u'للمقثأة': u'لِلْمِقْثَأَةِ', #1
u'للمقدوم': u'لِلْمَقْدُومِ', #3
u'للمقروع': u'لِلْمَقْرُوعِ', #7
u'للمقضى': u'لِلْمُقَضَّى', #1
u'للمقضى': u'لِلْمُقْضَى', #12
u'للمقلش': u'لِلْمُقَلِّشِ', #2
u'للمقلش': u'لِلْمُقْلِشِ', #2
u'للمقلشين': u'لِلْمُقَلِّشِينَ', #1
u'للمقيس': u'لِلْمَقِيسِ', #12
u'للمكاس': u'لِلْمُكَّاسِ', #1
u'للمكاس': u'لِلْمَكَّاسِ', #2
u'للمكايسة': u'لِلْمُكَايَسَةِ', #1
u'للمكروم': u'لِلْمَكْرُومِ', #1
u'للمكرى': u'لِلْمُكْرَى', #1
u'للمكشف': u'لِلْمُكْشِفِ', #1
u'للملالة': u'لِلْمَلَالَةِ', #1
u'للملتذ': u'لِلْمُلْتَذِّ', #1
u'للملزوق': u'لِلْمَلْزُوقِ', #1
u'للملزوم': u'لِلْمَلْزُومِ', #16
u'للملوطة': u'لِلْمَلُوطَةِ', #2
u'للمماسكة': u'لِلْمُمَاسَكَةِ', #1
u'للممدوحية': u'لِلْمَمْدُوحِيَّةِ', #1
u'للممزج': u'لِلْمُمَزِّجِ', #1
u'للمملوح': u'لِلْمَمْلُوحِ', #1
u'للمناة': u'لِلْمَنَاةِ', #1
u'للمنافر': u'لِلْمُنَافِرِ', #1
u'للمناكرة': u'لِلْمُنَاكَرَةِ', #4
u'للمنبهم': u'لِلْمُنْبَهِمِ', #1
u'للمنبهم': u'لِلْمُنْبَهِمْ', #1
u'للمنتهبين': u'لِلْمُنْتَهِبِينَ', #1
u'للمنحول': u'للمنحول', #1
u'للمنحول': u'لِلْمَنْحُولِ', #2
u'للمنصورية': u'لِلْمَنْصُورِيَّةِ', #1
u'للمنفل': u'لِلْمُنَفِّلِ', #1
u'للمنفل': u'لِلْمُنَفَّلِ', #3
u'للمنفل': u'لِلْمُنْفَلِ', #7
u'للمنفلين': u'لِلْمُنَفَّلِينَ', #1
u'للمنفلين': u'لِلْمُنَفِّلِينَ', #1
u'للمنفوس': u'لِلْمَنْفُوسِ', #7
u'للمنقاش': u'لِلْمِنْقَاشِ', #1
u'للمنلا': u'لِلْمُنْلَا', #3
u'للمنهور': u'لِلْمَنْهُورِ', #1
u'للمنهى': u'لِلْمُنْهَى', #3
u'للمنوب': u'لِلْمَنُوبِ', #8
u'للمنوفي': u'لِلْمَنُوفِيِّ', #8
u'للمهاجرى': u'لِلْمُهَاجِرِىِّ', #2
u'للمهايأة': u'لِلْمُهَايَأَةِ', #12
u'للمهدوي': u'لِلْمَهْدَوِيِّ', #1
u'للمهلب': u'لِلْمُهَلَّبِ', #5
u'للمؤاجر': u'لَلْمُؤَاجَرِ', #1
u'للمؤاجر': u'لَلْمُؤَاجِرِ', #1
u'للمؤاجر': u'لِلْمُؤَاجِرِ', #20
u'للموادعين': u'لِلْمُوَادَعِينَ', #1
u'للمواضح': u'لِلْمَوَاضِحِ', #1
u'للمواضعة': u'لِلْمُوَاضَعَةِ', #17
u'للمواق': u'لِلْمَوَّاقِ', #14
u'للمؤب': u'لِلْمُؤَب', #2
u'للموبد': u'لِلْمُوبَدِ', #1
u'للمؤبر': u'لِلْمُؤَبَّرِ', #6
u'للمؤبرة': u'لِلْمُؤَبَّرَةِ', #1
u'للمؤبل': u'لِلْمُؤَبَّلِ', #1
u'للمؤبل': u'لِلْمُؤَبّلِ', #2
u'للمؤتسي': u'لِلْمُؤْتَسِي', #3
u'للمؤتم': u'لِلْمُؤْتَمِّ', #11
u'للمؤتمين': u'لِلْمُؤْتَمِّينَ', #2
u'للموجرة': u'لِلْمُوجِرَةِ', #1
u'للموجفين': u'لِلْمُوجِفِينَ', #1
u'للموطوء': u'لِلْمَوْطُوءِ', #2
u'للموطوءة': u'لِلْمَوْطُوءَةِ', #46
u'للموقوذة': u'لِلْمَوْقُوذَةِ', #2
u'للمؤلي': u'لِلْمُؤْلِي', #1
u'للمومي': u'لِلْمُومِي', #1
u'للمومئ': u'لِلْمُومِئِ', #3
u'للموميا': u'لِلْمُومْيَا', #1
u'للمؤنات': u'لِلْمُؤْنَاتِ', #1
u'للمؤنة': u'لِلْمُؤْنَةِ', #22
u'للموهب': u'لِلْمُوهَبِ', #1
u'للمؤوف': u'لِلْمَؤُوفِ', #1
u'للمئنة': u'لِلْمَئِنَّةِ', #1
u'للمئونة': u'لِلْمَئُونَةِ', #1
u'للميري': u'لِلْمِيرِيِّ', #1
u'للميرى': u'لِلْمَيْرَى', #1
u'للميضأة': u'لِلْمِيضَأَةِ', #1
u'للميولات': u'لِلْمُيُولَاتِ', #1
u'للناجش': u'لِلنَّاجِشِ', #2
u'للناسوالوجه': u'لِلنَّاسِوَالْوَجْهُ', #1
u'للنائرة': u'لِلنَّائِرَةِ', #1
u'للنبأة': u'لِلنَّبْأَةِ', #1
u'للنبى': u'للنبى', #1
u'للنبى': u'للنَّبِىِّ', #1
u'للنبى': u'لِلنَّبِىِّ', #208
u'للنبيت': u'للنّبيت', #1
u'للنبيت': u'لِلنّبِيتِ', #1
u'للنجاشى': u'لِلنَّجَاشِىِّ', #1
u'للنجش': u'لِلنَّجْشِ', #1
u'للنجوري': u'لِلنَّجُورِيِّ', #1
u'للنحمة': u'لِلنّحْمَةِ', #1
u'للنسإ': u'لِلنَّسَإِ', #1
u'للنساءليس': u'لِلنِّسَاءِلَيْسَ', #1
u'للنساخة': u'لِلنِّسَاخَةِ', #1
u'للنسيء': u'لِلنَّسِيءِ', #1
u'للنصرانى': u'لِلنَّصْرَانِىِّ', #1
u'للنضوض': u'لِلنَّضُوضِ', #1
u'للنفراوي': u'لِلنَّفْرَاوِيِّ', #2
u'للنفلة': u'لِلنَّفْلَةِ', #1
u'للنفيلي': u'لِلنُّفَيْلِيِّ', #1
u'للنقاية': u'لِلنُّقَايَةِ', #9
u'للنهشلي': u'لِلنَّهْشَلِيِّ', #1
u'للنواقض': u'لِلنَّوَاقِضِ', #2
u'للنويري': u'لِلنُّوَيْرِيِّ', #1
u'للنياحة': u'لِلنِّيَاحَةِ', #3
u'للنيه': u'لِلنِّيَّهْ', #1
u'للهاذم': u'لِلْهَاذِمِ', #1
u'للهثناء': u'لِلَّهِثَنَاءُ', #1
u'للهرادي': u'لِلْهَرَادِيِّ', #4
u'للهرمزان': u'للهرمُزَان', #1
u'للهرمزان': u'لِلْهُرْمُزَانِ', #2
u'للهملجة': u'لِلْهَمْلَجَةِ', #3
u'للهندواني': u'لِلْهِنْدُوَانِيِّ', #4
u'للهوالوجه': u'لِلَّهِوَالْوَجْهُ', #1
u'للهيجا': u'لِلْهَيْجَا', #3
u'للو': u'لِلَوْ', #11
u'للواذ': u'لِلِّوَاذِ', #1
u'للواقدي': u'للواقدي', #1
u'للواقدي': u'لِلْوَاقِدِيّ', #1
u'للواقدي': u'لِلْوَاقِدِيِّ', #7
u'للوالى': u'لِلْوَالِى', #3
u'للوانوغي': u'لِلْوَانُّوغِيِّ', #3
u'للوخش': u'لِلْوَخْشِ', #1
u'للوصى': u'لِلْوَصِىِّ', #1
u'للوضيمة': u'لِلْوَضِيمَةِ', #1
u'للولاد': u'لِلْوِلَادِ', #5
u'للولوالجي': u'لِلْوَلْوَالِجِيِّ', #1
u'للولوالجية': u'لِلْوَلْوالِجِيّةِ', #1
u'للولوالجية': u'للولوالجية', #4
u'للولى': u'لِلْوَلِىِّ', #4
u'للونشريسي': u'لِلْوَنْشَرِيسِيِّ', #4
u'للوهبانية': u'لِلْوَهْبَانِيَّةِ', #15
u'للؤي': u'لَلُؤَيّ', #1
u'للؤى': u'لَلُؤَىَ', #1
u'لليسية': u'لِلَّيْسِيَّةِ', #3
u'لليهودى': u'لِلْيَهُودِىِّ', #3
u'لليونيني': u'لِلْيُونِينِيِّ', #1
u'لماأسلم': u'لَمَّاأَسْلَمَ', #1
u'لماتم': u'لِمَاتم', #1
u'لمأذونيته': u'لِمَأْذُونِيَّتِهِ', #4
u'لمازر': u'لِمَازَرَ', #1
u'لمازر': u'لِمَازِرٍ', #1
u'لمازرة': u'لِمَازَرَةَ', #1
u'لماصعهم': u'لَمَاصَعَهُمْ', #2
u'لمألك': u'لَمَأْلُك', #1
u'لمانعية': u'لِمَانِعِيَّةِ', #3
u'لمائتى': u'لِمِائَتِى', #1
u'لمائتى': u'لِمِائَتِىْ', #1
u'لمائحها': u'لِمَائِحِهَا', #1
u'لمبانته': u'لِمُبَانَتِهِ', #5
u'لمباينة': u'لِمُبَايَنَةِ', #5
u'لمباينته': u'لِمُبَايِنَتِهِ', #1
u'لمباينته': u'لِمُبَايَنَتِهِ', #6
u'لمباينتها': u'لِمُبَايَنَتِهَا', #2
u'لمباينها': u'لِمُبَايِنِهَا', #1
u'لمبتدي': u'لِمُبْتَدِي', #1
u'لمبتنى': u'لِمُبْتَنًى', #2
u'لمبتها': u'لَمُبِتِّهَا', #1
u'لمبتها': u'لِمُبِتَّهَا', #1
u'لمبتها': u'لِمُبِتِّهَا', #3
u'لمبتوتة': u'لِمَبْتُوتَةٍ', #3
u'لمبعض': u'لِمُبَعِّضٍ', #1
u'لمبعض': u'لِمُبَعَّضٍ', #26
u'لمبعضة': u'لِمُبَعَّضَةِ', #1
u'لمبعضة': u'لِمُبَعَّضَةٍ', #7
u'لمبلسين': u'لَمُبْلِسِينَ', #1
u'لمبيونة': u'لِمَبْيُونَةٍ', #1
u'لمتاركة': u'لِمُتَارَكَةِ', #1
u'لمتجالة': u'لِمُتَجَالَّةٍ', #2
u'لمتجاهي': u'لِمُتَجَاهِي', #1
u'لمتجوه': u'لِمُتَجَوِّهٍ', #1
u'لمتمحضة': u'لِمُتَمَحِّضَةِ', #2
u'لمتهب': u'لِمُتَّهِبٍ', #1
u'لمتهب': u'لِمُتَّهَبٍ', #2
u'لمتى': u'لِمَتَى', #2
u'لمثغور': u'لِمَثْغُورٍ', #1
u'لمجاشع': u'لِمُجَاشِعٍ', #1
u'لمجاشع': u'لِمُجَاشِعِ', #1
u'لمجالد': u'لِمُجَالِدٍ', #2
u'لمجاولته': u'لِمُجَاوَلَتِهِ', #1
u'لمجبوب': u'لِمَجْبُوبِ', #1
u'لمجبوب': u'لَمَجْبُوبٌ', #2
u'لمجبوب': u'لِمَجْبُوبٍ', #3
u'لمجبولية': u'لِمَجْبُولِيَّةِ', #1
u'لمجلث': u'لِمِجْلَثَ', #1
u'لمجلث': u'لِمِجْلِثَ', #1
u'لمجماعته': u'لِمُجَمَاعَتِهِ', #1
u'لمجهولية': u'لِمَجْهُولِيَّةِ', #1
u'لمحاجيره': u'لِمَحَاجِيرِهِ', #1
u'لمحاصة': u'لِمُحَاصَّةِ', #1
u'لمحتجر': u'لِمُحْتَجِرٍ', #3
u'لمحجن': u'لِمِحْجَنٍ', #1
u'لمحجوج': u'لِمَحْجُوجٍ', #1
u'لمحدة': u'لِمُحِدَّةٍ', #3
u'لمحرب': u'لَمِحْرَبٌ', #1
u'لمحرميته': u'لِمَحْرَمِيَّتِهِ', #1
u'لمحصر': u'لِمُحْصَرٍ', #1
u'لمحصر': u'لِمُحْصَرِ', #1
u'لمحيصة': u'لِمُحَيّصَةَ', #1
u'لمحيصة': u'لِمُحَيِّصَةَ', #5
u'لمخاشن': u'لَمُخَاشِنُ', #1
u'لمخالعها': u'لِمُخَالِعِهَا', #1
u'لمختلع': u'لِمُخْتَلِعٍ', #1
u'لمختلعة': u'لِمُخْتَلِعَةٍ', #1
u'لمختلعته': u'لِمُخْتَلِعَتِهِ', #2
u'لمختلعها': u'لِمُخْتَلَعِهَا', #1
u'لمخذل': u'لِمُخَذِّلٍ', #2
u'لمخذل': u'لِمُخْذِلٍ', #2
u'لمخذوف': u'لِمَخْذُوفٍ', #1
u'لمخرمة': u'لِمَخْرَمَةَ', #2
u'لمخصمة': u'لِمَخْصَمَةٍ', #1
u'لمخضوب': u'لَمَخْضُوبٌ', #4
u'لمخمصة': u'لِمَخْمَصَةٍ', #9
u'لمخيسا': u'لِمُخَيِّسًا', #1
u'لمداينيه': u'لِمُدَايِنِيهِ', #1
u'لمذام': u'لِمَذَامَّ', #1
u'لمذحج': u'لِمَذْحِجَ', #1
u'لمذروع': u'لِمَذْرُوعٍ', #3
u'لمذي': u'لِمَذْيٍ', #10
u'لمرأة': u'لِمَرْأَةٍ', #26
u'لمرازبتهم': u'لِمَرَازِبَتِهِمْ', #2
u'لمراعات': u'لِمُرَاعَاتِ', #1
u'لمراغمة': u'لِمُرَاغَمَةِ', #1
u'لمرتاض': u'لِمُرْتَاضٍ', #1
u'لمرتضع': u'لِمُرْتَضِعِ', #2
u'لمرثد': u'لِمَرْثَدٍ', #1
u'لمرثد': u'لِمَرْثَدِ', #2
u'لمرجوحية': u'لِمَرْجُوحِيَّةِ', #2
u'لمرداس': u'لِمِرْدَاسٍ', #3
u'لمرزبان': u'لِمَرْزُبَانٍ', #4
u'لمزايل': u'لِمُزَايِلٍ', #1
u'لمزايل': u'لِمُزَايِلِ', #1
u'لمساسته': u'لِمِسَاسَتِهِ', #1
u'لمساغ': u'لِمَسَاغٍ', #1
u'لمسامتتها': u'لِمُسَامَتَتِهَا', #1
u'لمستبرأة': u'لِمُسْتَبْرَأَةٍ', #3
u'لمستبرئ': u'لِمُسْتَبْرِئٍ', #2
u'لمستحاضة': u'لِمُسْتَحَاضَةٍ', #6
u'لمسترضع': u'لِمُسْتَرْضِعٍ', #1
u'لمستقذر': u'لِمُسْتَقْذَرٍ', #2
u'لمستلحقه': u'لِمُسْتَلْحِقِهِ', #4
u'لمستنكح': u'لِمُسْتَنْكَحٍ', #1
u'لمستنكح': u'لِمُسْتَنْكِحٍ', #1
u'لمستنيبه': u'لِمُسْتَنِيبِهِ', #4
u'لمستوفزون': u'لِمُسْتَوْفِزُونَ', #1
u'لمستوفى': u'لِمُسْتَوْفًى', #1
u'لمسعط': u'لِمِسْعَطٍ', #1
u'لمسقف': u'لِمُسْقَفٍ', #1
u'لمسقف': u'لِمُسَقَّفٍ', #10
u'لمسيخ': u'لِمَسِيخٍ', #1
u'لمشهورية': u'لِمَشْهُورِيَّةِ', #1
u'لمشهوريته': u'لِمَشْهُورِيَّتِهِ', #1
u'لمشهوريتها': u'لِمَشْهُورِيَّتِهَا', #1
u'لمشية': u'لَمِشْيَةٍ', #1
u'لمشية': u'لَمِشْيَةٌ', #11
u'لمصاعه': u'لِمُصَاعِهِ', #1
u'لمصافع': u'لِمُصَافَعٍ', #3
u'لمضايفته': u'لِمُضَايَفَتِهِ', #1
u'لمطلوبية': u'لِمَطْلُوبِيَّةِ', #5
u'لمطلوبيته': u'لِمَطْلُوبِيَّتِهِ', #2
u'لمعات': u'لَمَعَاتِ', #1
u'لمعاطاة': u'لِمُعَاطَاةٍ', #2
u'لمعافر': u'لِمَعَافِرَ', #1
u'لمعاوض': u'لِمُعَاوَضٍ', #3
u'لمعاوض': u'لِمُعَاوِضٍ', #4
u'لمعتكر': u'لِمُعْتَكِرٍ', #1
u'لمعتكر': u'لِمُعْتَكِرِ', #1
u'لمعتوقه': u'لِمَعْتُوقِهِ', #1
u'لمعجوز': u'لِمَعْجُوزٍ', #1
u'لمعطنها': u'لِمَعْطِنِهَا', #1
u'لمعلومية': u'لِمَعْلُومِيَّةٍ', #1
u'لمعلومية': u'لِمَعْلُومِيَّةِ', #3
u'لمعيقيب': u'لِمُعَيْقِيبٍ', #1
u'لمغالب': u'لَمُغَالِبٍ', #1
u'لمفيت': u'لِمُفِيتِ', #1
u'لمقارضين': u'لِمُقَارِضَيْنِ', #3
u'لمقاعدة': u'لِمُقَاعَدَةِ', #1
u'لمقتص': u'لِمُقْتَصٍّ', #1
u'لمقتص': u'لِمُقْتَصِّ', #1
u'لمقتصه': u'لَمُقْتَصُّهُ', #1
u'لمقولية': u'لِمَقُولِيَّةِ', #1
u'لمقيس': u'لِمَقِيسٍ', #1
u'لمقيس': u'لِمِقْيَسٍ', #2
u'لمكاس': u'لِمُكَّاسٍ', #1
u'لمكاس': u'لِمَكَّاسٍ', #3
u'لمكتتم': u'لِمُكْتَتِمٍ', #1
u'لمكحول': u'لِمَكْحُولٍ', #1
u'لمكرز': u'لِمُكَرّزِ', #1
u'لمكرز': u'لِمِكْرَزٍ', #1
u'لمكرز': u'لِمِكْرِزٍ', #1
u'لملالة': u'لِمَلَالَةٍ', #1
u'لملالة': u'لِمَلَالَةِ', #2
u'لملثه': u'لَمَلْثه', #1
u'لملزوم': u'لِمَلْزُومٍ', #1
u'لملزومه': u'لِمَلْزُومِهِ', #4
u'لملزومها': u'لِمَلْزُومِهَا', #1
u'لملزومية': u'لِمَلْزُومِيَّةِ', #2
u'لملزوميته': u'لِمَلْزُومِيَّتِهِ', #2
u'لمناة': u'لِمَنَاة', #1
u'لمناة،': u'لِمَنَاةَ،', #4
u'لمناة': u'لِمَنَاةَ', #41
u'لمناكرة': u'لِمُنَاكَرَةِ', #1
u'لمنبذ': u'لِمُنْبَذٍ', #1
u'لمنتبذ': u'لِمُنْتَبِذٍ', #2
u'لمنتهب': u'لِمُنْتَهِبٍ', #1
u'لمنجدل': u'لَمُنْجَدِلٌ', #6
u'لمنذ': u'لَمُنْذُ', #1
u'لمنزلتى': u'لِمَنْزِلَتِى', #1
u'لمنعبته': u'لَمِنْعَبَته', #1
u'لمنفك': u'لِمُنْفَكٍّ', #1
u'لمنفوذة': u'لِمَنْفُوذَةِ', #2
u'لمنفوسة': u'لِمَنْفُوسَةِ', #1
u'لمنقود': u'لِمَنْقُودٍ', #1
u'لمنكورس': u'لِمِنْكَوْرَسٍ', #1
u'لمنلا': u'لِمُنْلَا', #24
u'لمهايأة': u'لِمُهَايَأَةٍ', #2
u'لمو': u'لمو', #1
u'لمواضعة': u'لِمُوَاضَعَةٍ', #2
u'لمواطئة': u'لِمُوَاطِئَةٍ', #1
u'لمؤتى': u'لَمُؤَتّى', #1
u'لمؤتى': u'لَمُؤَتًّى', #1
u'لمؤتى': u'لَمُؤْتًى', #1
u'لمؤتى': u'لِمُؤَتّى', #1
u'لموجدها': u'لِمُوجِدِهَا', #1
u'لمؤرج': u'لِمُؤَرِّجٍ', #1
u'لمؤزر': u'لِمُؤَزَّرٍ', #1
u'لموصفها': u'لِمُوصِفِهَا', #1
u'لموطوءة': u'لِمَوْطُوءَةٍ', #31
u'لموطوءته': u'لِمَوْطُوءَتِهِ', #19
u'لموطوءتيه': u'لِمَوْطُوءَتَيْهِ', #1
u'لموموق': u'لِمَوْمُوقٍ', #1
u'لمؤنة': u'لِمُؤْنَةٍ', #28
u'لمؤنة': u'لِمُؤْنَةِ', #32
u'لمؤنته': u'لِمُؤْنَتِهِ', #15
u'لمؤنتها': u'لِمُؤْنَتِهَا', #2
u'لمئنة': u'لِمَئِنَّةِ', #1
u'لمئونة': u'لِمَئُونَةٍ', #1
u'لمئونة': u'لِمَئُونَةِ', #1
u'لمياء': u'لَمْيَاءُ', #3
u'لميارة': u'لِمَيَّارَةَ', #2
u'لميرغني': u'لِمِيرِغْنِيٍّ', #1
u'لميكائيل': u'لميكائيل', #1
u'لميكائيل': u'لِمِيكَائِيلَ', #1
u'لمينو': u'لَمْيَنْوِ', #1
u'لناأن': u'لَنَاأَنَّ', #1
u'لناأنه': u'لَنَاأَنَّهُ', #1
u'لناأنها': u'لَنَاأَنَّهَا', #1
u'لناأنهم': u'لَنَاأَنَّهُمْ', #1
u'لنأوى': u'لَنَأْوِى', #1
u'لنائرة': u'لِنَائِرَةٍ', #3
u'لنبخله': u'لَنُبَخِّلُهُ', #1
u'لنبكتنه': u'لَنُبَكِّتَنَّهُ', #2
u'لنبي': u'لِنَبِيًّ', #1
u'لنبى': u'لنَّبِىُّ', #2
u'لنبى': u'لِنَبِىِّ', #2
u'لنبى': u'لِنَبِىٍّ', #23
u'لنبى': u'لَنَبِىٌّ', #3
u'لنبيرن': u'لَنُبِيرَنَّ', #1
u'لنترحل': u'لَنَتَرَحّلُ', #2
u'لنتزقمنها': u'لنتزقمنها', #1
u'لنتزقمنها': u'لَنتَزَقّمنّها', #1
u'لنتزقمنها': u'لَنَتَزَقّمَنّها', #1
u'لنحييبه': u'لِنُحْيِيَبِهِ', #2
u'لندورة': u'لِنُدُورَةِ', #1
u'لنراوضكم': u'لِنُرَاوِضَكُمْ', #1
u'لنراوضه': u'لِنُرَاوِضَهُ', #1
u'لنسائى': u'لِنِسَائِى', #7
u'لنسبائي': u'لِنُسَبَائِي', #1
u'لنستنفق': u'لِنَسْتَنْفِقَ', #1
u'لنسفعا': u'لَنَسْفَعًا', #4
u'لنشهدا': u'لَنَشْهَدَا', #1
u'لنضلة': u'لِنَضْلَةَ', #1
u'لنضوض': u'لِنَضُوضِ', #2
u'لنضوضه': u'لِنُضُوضِهِ', #1
u'لنضوضه': u'لِنَضُوضِهِ', #3
u'لنضوضها': u'لِنَضُوضِهَا', #1
u'لنعارا': u'لَنَعَّارًا', #1
u'لنعطينكها': u'لَنُعْطِيَنَّكَهَا', #1
u'لنفطويه': u'لِنِفْطَوَيْهِ', #1
u'لنفيع': u'لنفيع', #1
u'لنفيع': u'لِنُفَيْعِ', #1
u'لنك': u'لَنْك', #1
u'لنكك': u'لَنْكَكَ', #3
u'لنماز': u'لنماز', #1
u'لنمتار': u'لِنَمْتَارَ', #1
u'لنمرود': u'لِنُمْرُودَ', #2
u'لنمشدر': u'لنمشدر', #1
u'لنميوب': u'لنميوب', #1
u'لنؤاخذ': u'لَنُؤَاخَذُ', #1
u'لنواضعنه': u'لَنُوَاضِعَنَّهُ', #3
u'لنورمي': u'لنورمي', #3
u'لنياحة': u'لِنِيَاحَةٍ', #3
u'لنيركت': u'لنيركت', #1
u'لهS': u'لَهُS', #1
u'لهSحديث': u'لَهُSحَدِيثُ', #1
u'لهSحول': u'لَهُSحَوْلَ', #2
u'لهاSأبو': u'لَهَاSأَبُو', #1
u'لهابيل': u'لِهَابِيلَ', #2
u'لهاجعلا': u'لَهَاجُعْلًا', #1
u'لهاذما': u'لَهَاذِمَا', #2
u'لهإمام': u'لَهُإمَامٌ', #1
u'لهأن': u'لَهُأَنَّ', #1
u'لهإن': u'لَهُإِنَّ', #1
u'لهأنه': u'لَهُأَنَّهُ', #1
u'لهاهنا': u'لَهَاهُنَا', #2
u'لهاوالوجه': u'لَهَاوَالْوَجْهُ', #1
u'لهبار': u'لِهَبّارٍ', #1
u'لهبار': u'لِهَبّارِ', #1
u'لهبار': u'لِهَبَّارٍ', #1
u'لهبار': u'لِهَبَّارِ', #1
u'لهبيرة': u'لِهُبَيْرَةَ', #2
u'لهذال': u'لِهُذَالٍ', #1
u'لهذيل': u'لهُذَيْل', #1
u'لهذيل': u'لِهُذَيْلٍ', #11
u'لهراسب': u'لهراسب', #3
u'لهق': u'لَهْقُ', #1
u'لهق': u'لَهَقٍ', #3
u'لهقوله': u'لَهُقَوْلُهُ', #1
u'لهكذا': u'لَهَكَذَا', #6
u'لهلالاااا': u'لِهِلَالٍاااا', #1
u'لهلأن': u'لَهُلِأَنَّ', #1
u'لهمادخلوا': u'لَهُمُادْخُلُوا', #1
u'لهماقوله': u'لَهُمَاقَوْلُهُ', #1
u'لهمالله': u'لَهُمُاللّهَ', #1
u'لهماليج': u'لِهَمَالِيجَ', #1
u'لهمدانيين': u'لِهَمْدَانِيَّيْنِ', #1
u'لهمقد': u'لَهُمْقَدْ', #1
u'لهمو': u'لَهُمُو', #2
u'لهموروي': u'لَهُمْوَرُوِيَ', #2
u'لهن': u'لَهُنًّ', #5
u'لهنعم،': u'لَهُنَعَمْ،', #1
u'لهنفخص': u'لَهُنَّفَخَصَّ', #1
u'لههنا': u'لههنا', #1
u'لهوازن': u'لِهَوَازِنَ', #6
u'لهوازني': u'لِهَوَازِنِيّ', #1
u'لهوالوجه': u'لَهُوَالْوَجْهُ', #1
u'لهوب': u'لُهُوبُ', #1
u'لهوذة': u'لِهَوْذَةَ', #1
u'لهوذة،': u'لِهَوْذَةَ،', #1
u'لهوروي': u'لَهُوَرُوِيَ', #1
u'لهوعن': u'لَهُوَعَنْ', #1
u'لهية': u'لُهَّيةَ', #1
u'لهية': u'لَهِيّةَ', #1
u'لهية': u'لُهَيَّةَ', #1
u'لهية': u'لُهْيَةٌ', #1
u'لهيعة،': u'لَهيعة،', #1
u'لهيعة،': u'لَهِيعَةُ،', #1
u'لهيعة': u'لَهَيْعَةِ', #1
u'لهيعة': u'لهيعة', #13
u'لهيعة،': u'لهيعة،', #13
u'لهيعة': u'لَهِيعَةَ', #1767
u'لهيعة،': u'لَهِيعة،', #2
u'لهيعة': u'لَهِيعَةُ', #2
u'لهيعة،': u'لَهِيعَة،', #2
u'لهيعة،': u'لَهْيعَةَ،', #2
u'لهيعة': u'لَهِيعَة', #28
u'لهيعة': u'لَهِيعة', #3
u'لهيعة': u'لَهِيعَةِ', #3
u'لهيعة': u'لَهِيْعَةَ', #3
u'لهيعة': u'لَهَيْعَةَ', #9
u'لهيعة،': u'لَهِيعَةَ،', #907
u'لهيعةأن': u'لَهِيعَةَأَنَّ', #2
u'لهيعة،أن': u'لَهِيعَةَ،أَنَّ', #2
u'لوا': u'لَوًّا', #1
u'لواءالرسول': u'لِوَاءُالرّسُولِ', #1
u'لوابصة': u'لِوَابِصَةَ', #10
u'لواثلة': u'لِوَاثِلَةَ', #2
u'لوأخبرتكم': u'لَوأَخْبَرْتُكُمْ', #1
u'لواذا': u'لِوَاذًا', #21
u'لواقح': u'لواقح', #1
u'لواقح': u'لَوَاقِحُ', #1
u'لواقح': u'لَوَاقِحَ', #12
u'لواقح': u'لَوَاقِحِ', #2
u'لواقدة': u'لِوَاقِدَةَ', #2
u'لوالان': u'لِوَالانَ', #1
u'لوأنزل': u'لَوأُنْزِلَ', #1
u'لوائل': u'لِوَائِلٍ', #1
u'لوبا': u'لَوْبًا', #1
u'لوبان': u'لوبان', #1
u'لوبانا': u'لَوَبَانًا', #1
u'لوبة': u'لُوبَةٍ', #1
u'لوثين': u'لَوْثَيْنِ', #1
u'لوجاءت': u'لَوَجَاءَتْ', #1
u'لوجائب': u'لوجائب', #1
u'لوجدتنى': u'لَوَجَدْتَنِى', #1
u'لوحود': u'لِوُحُودِ', #1
u'لوخش': u'لِوَخَشٍ', #1
u'لوذهب': u'لَوَذَهَبَ', #1
u'لور': u'لور', #1
u'لوصبر': u'لوصبر', #1
u'لوطأي': u'لِوَطْأَيْ', #1
u'لوطأين': u'لوطأين', #1
u'لوطأين': u'لِوَطْأَيْنِ', #2
u'لوطى': u'لُوطِىُّ', #1
u'لوعلموا': u'لَوَعَلِمُوا', #1
u'لوقفيته': u'لِوَقْفِيَّتِهِ', #1
u'لوقفيتها': u'لِوَقْفِيَّتِهَا', #2
u'لوكانوا': u'لَوَكَانُوا', #1
u'لوكيع،': u'لِوَكِيعٍ،', #1
u'لوكيع': u'لِوَكِيعٍ', #4
u'لولدى': u'لِوَلَدِى', #2
u'لولديته': u'لِوَلَدِيَّتِهِ', #1
u'لؤلؤة': u'لُؤْلُؤَةً', #71
u'لؤلؤته': u'لُؤْلُؤَتَهُ', #1
u'لؤلؤتين': u'لُؤْلُؤَتَيْنِ', #3
u'لوليمتى': u'لِوَلِيمَتِى', #1
u'لؤمة': u'لُؤْمَةٍ', #1
u'لؤمة': u'لُؤَمَةٍ', #2
u'لونة': u'لِوْنَةٌ', #1
u'لونيم': u'لِوَنِيمِ', #1
u'لوهاء': u'لِوَهَاءٍ', #3
u'لوهائها': u'لِوَهَائِهَا', #1
u'لوهيب': u'لِوُهَيْبٍ', #1
u'لؤي': u'لُؤيّ', #1
u'لؤي،': u'لُؤي،', #1
u'لؤي،': u'لُؤيّ،', #1
u'لؤي': u'لُؤَي', #1
u'لؤي': u'لُؤَيٌّ', #1
u'لؤي،': u'لُؤَيّ،', #1
u'لؤى': u'لُؤَى', #1
u'لؤى': u'لُؤَىِ', #1
u'لؤي': u'لُؤَيَّ', #2
u'لؤي': u'لُؤَيُّ', #2
u'لؤى': u'لُؤَىٍّ', #24
u'لؤي': u'لؤي', #29
u'لؤي…': u'لُؤَيٍّ…', #3
u'لؤي': u'لُؤَيِّ', #32
u'لؤي': u'لُؤَيّ', #427
u'لؤي،': u'لُؤَيٍّ،', #7
u'لؤي': u'لُؤَيٍّ', #82
u'لؤى': u'لُؤَىِّ', #9
u'لؤيا': u'لُؤَيّا', #6
u'لويزات': u'لُوَيْزَاتٍ', #1
u'ليSقول': u'لِيSقَوْلٌ', #1
u'لى': u'لَىَّ', #1
u'لى': u'لّى', #1
u'لى': u'َلَى', #1
u'لى': u'َلِىُّ', #1
u'لى': u'لى', #2
u'لى': u'لَى', #2
u'لى': u'لَىُّ', #2
u'لى': u'َلَّى', #2
u'لى': u'لِى', #2001
u'لى؟': u'لِى؟', #4
u'لى': u'لِىَ', #81
u'لئلا': u'لئلًا', #2
u'ليأتى': u'لِيَأْتِىَ', #1
u'ليأتى': u'لَيَأْتِى', #2
u'ليأجوج': u'لِيَأْجُوجَ', #1
u'ليأخده': u'لِيَأْخُدَهُ', #1
u'ليأرز': u'لَيَأْرِزُ', #15
u'ليأرزن': u'لَيَأْرِزَنَّ', #2
u'لياطة': u'لِيَاطَةً', #2
u'ليالى': u'لَيَالِىَ', #29
u'ليالى': u'لَيَالِى', #5
u'ليأمرانى': u'لِيَأْمُرَانِى', #2
u'ليامين': u'لِيَامِينَ', #2
u'ليأنهم': u'لِيأَنَّهُمْ', #1
u'ليأوى': u'لِيَأْوِىَ', #1
u'ليباين': u'لِيُبَايِنَ', #1
u'ليبتدياه': u'لِيَبْتَدِيَاهُ', #1
u'ليبدإ': u'لِيَبْدَإِ', #2
u'ليبكتهم': u'لِيُبَكِّتَهُمْ', #1
u'لية': u'لية', #1
u'لية': u'لَيّةَ', #1
u'لية': u'لِيَةٌ', #1
u'لية': u'لِيَّةً', #1
u'لية': u'لِيَّةٍ', #1
u'لية': u'لِيَّةُ', #2
u'لية': u'لَيَّةَ', #3
u'لية': u'لَيَّةً', #4
u'لية': u'لِيّةَ', #4
u'لية': u'لِيَّةٌ', #4
u'لية': u'لِيَّةَ', #7
u'ليتأثل': u'لِيَتَأَثَّلَ', #1
u'ليتأدى': u'لِيَتَأَدَّى', #8
u'ليتأذى': u'لِيَتَأَذَّى', #1
u'ليتألفكم': u'لِيَتَأَلَّفَكُمْ', #1
u'ليتألفه': u'لِيَتَأَلَّفَهُ', #1
u'ليتألفهم': u'لِيَتَأَلَّفَهُمْ', #4
u'ليتان': u'لِيتان', #1
u'ليتتمر': u'لِيَتَتَمَّرَ', #1
u'ليتجلجل': u'لَيَتَجَلْجَلُ', #2
u'ليتجوزها': u'لِيَتَجَوَّزَهَا', #1
u'ليتحتم': u'لِيَتَحَتَّمَ', #1
u'ليتحذر': u'لِيَتَحَذَّرَ', #1
u'ليتحق': u'لِيَتَحَقَّ', #1
u'ليتحمدن': u'لَيَتَحَمَّدَنَّ', #1
u'ليتخالج': u'لَيَتَخَالَجُ', #1
u'ليتخضخض': u'لَيَتَخَضْخَضُ', #1
u'ليتراد': u'لِيَتَرَادَّ', #1
u'ليترآى': u'لَيَتَرَآى', #1
u'ليترخص': u'لِيَتَرَخَّصَ', #8
u'ليترس': u'لَيُتَرّسُ', #1
u'ليتزيف': u'لِيَتَزَيَّفَ', #1
u'ليتسرى': u'لِيَتَسَرَّى', #6
u'ليتسير': u'لِيُتَسَيَّرَ', #1
u'ليتصرفه': u'لِيَتَصَرَّفَهُ', #1
u'ليتفرخ': u'لِيَتَفَرَّخَ', #3
u'ليتفوتوا': u'لِيَتَفَوَّتُوا', #1
u'ليتفوتوا': u'لِيَتَفَوّتُوا', #2
u'ليتقايأ': u'لِيَتَقَايَأَ', #2
u'ليتقايأه': u'لِيَتَقَايَأَهُ', #1
u'ليتقربه': u'لِيَتَقَرَّبَهُ', #1
u'ليتكاه': u'لَيْتَكَاهُ', #2
u'ليتكيء': u'ليتكيء', #1
u'ليتمحض': u'لِيَتَمَحَّضَ', #2
u'ليتمزع': u'لَيَتَمَزَّعُ', #1
u'ليتمعش': u'لِيَتَمَعَّشَ', #1
u'ليتنخم': u'لِيَتَنَخَّمْ', #1
u'ليتنى': u'لَيْتَنِى', #15
u'ليتهيئوا': u'لِيَتَهَيَّئُوا', #3
u'ليتواعدونني': u'ليتواعدونني', #1
u'ليتواعدوني': u'لَيَتَوَاعَدُونِي', #1
u'ليتواعدونى': u'لَيَتَوَاعَدُونِى', #1
u'ليتوجهها': u'لِيَتَوَجَّهَهَا', #1
u'ليتوضئون': u'لَيَتَوَضَّئُونَ', #1
u'ليتوطنه': u'لِيَتَوَطَّنَهُ', #2
u'ليتين': u'لَيّتَيْنِ', #1
u'ليتين': u'لَيَّتَيْنِ', #3
u'ليجثو': u'لَيَجْثُو', #1
u'ليجنأ': u'لِيَجْنَأ', #1
u'ليجيئه': u'لِيَجِيئَهُ', #2
u'ليجيئها': u'لِيَجِيئَهَا', #1
u'ليجيئهم': u'لِيَجِيئَهُمْ', #1
u'ليحآجوكم': u'لِيُحَآجُّوكُم', #1
u'ليحتجم': u'لِيَحْتَجِمَ', #1
u'ليحتش': u'لِيَحْتَشَّ', #2
u'ليحثي': u'لِيُحْثِيَ', #1
u'ليحملنى': u'لِيَحْمِلَنِّى', #1
u'ليحملنى': u'لِيَحْمِلَنِى', #2
u'ليحنة': u'لِيَحْنَةَ', #1
u'ليحنة': u'لِيُحَنّةَ', #5
u'ليحيى': u'لِيَحْيَى', #136
u'ليحيى': u'ليحيى', #2
u'ليخبرنى': u'لَيُخْبِرَنِّى', #1
u'ليختلعها': u'لِيَخْتَلِعَهَا', #1
u'ليدخلنى': u'لِيُدْخِلَنِى', #1
u'ليراغم': u'لَيُرَاغِمُ', #1
u'ليراغم': u'لِيُرَاغِم', #1
u'ليرانى': u'ليرانى', #1
u'ليرانى': u'لَيَرَانِىَ', #1
u'ليرانى': u'لِيَرَانِى', #2
u'ليرائي': u'لِيُرَائِيَ', #1
u'ليرتاض': u'لِيَرْتَاضَ', #2
u'ليرتجع': u'لِيَرْتَجِعَ', #1
u'ليرتجع': u'لَيَرْتَجِعُ', #2
u'ليرتجعها': u'لِيَرْتَجِعَهَا', #1
u'ليرتدف': u'لِيَرْتَدِفَ', #4
u'ليرتضع': u'لِيَرْتَضِعَ', #2
u'ليرتفق': u'لِيَرْتَفِقَ', #13
u'ليرتفقا': u'لِيَرْتَفِقَا', #1
u'ليرتفقوا': u'لِيَرْتَفِقُوا', #2
u'ليرجدوا': u'لِيَرْجُدُوا', #1
u'ليرفؤه': u'لَيرْفَؤُه', #1
u'ليرفؤه': u'لَيُرَفِّؤُهُ', #1
u'ليرفؤه': u'لَيَرْفَؤُهُ', #2
u'ليرقأ': u'لِيَرْقَأْ', #1
u'ليروحنى': u'لِيُرَوِّحَنِى', #1
u'ليزكر': u'ليزكر', #1
u'ليسألنى': u'لَيَسْأَلُنِى', #1
u'ليستاسب': u'ليستاسب', #1
u'ليستاقها': u'لِيَسْتَاقَهَا', #1
u'ليستأمن': u'لِيَسْتَأْمِنَ', #4
u'ليستأمنك': u'لِيَسْتَأْمِنكَ', #1
u'ليستاهما': u'لِيسَتَاهُمَا', #1
u'ليستتاب': u'لِيُسْتَتَابَ', #1
u'ليستتبعنى': u'لِيَسْتَتْبِعَنِى', #4
u'ليستتم': u'لِيَسْتَتِمَّ', #1
u'ليستثبت': u'لِيَسْتَثْبِتَ', #1
u'ليستثبته': u'لِيَسْتَثْبِتَهُ', #1
u'ليستجمر': u'لِيَسْتَجْمِرَ', #3
u'ليستحد': u'لِيَسْتَحِدَّ', #1
u'ليستذل': u'لِيَسْتَذِلَّ', #1
u'ليستذله': u'لِيَسْتَذِلَّهُ', #1
u'ليسترقين،': u'لَيَسْتَرْقِيَنَّ،', #1
u'ليستسعيه': u'لِيَسْتَسْعِيَهُ', #1
u'ليستسلفه': u'لِيَسْتَسْلِفَهُ', #1
u'ليستصبح': u'لِيَسْتَصْبِحَ', #1
u'ليستطرق': u'لِيَسْتَطْرِقَ', #3
u'ليستفضل': u'لِيَسْتَفْضِلَ', #2
u'ليستقتل،': u'لِيَسْتَقْتِلَ،', #1
u'ليستقرض': u'لِيَسْتَقْرِضَ', #2
u'ليستقرضه': u'لِيَسْتَقْرِضَهُ', #4
u'ليستقيد': u'لِيَسْتَقِيدَ', #1
u'ليستكسبه': u'لِيَسْتَكْسِبَهُ', #1
u'ليستلحقه': u'لِيَسْتَلْحِقَهُ', #1
u'ليستنثر': u'لِيَسْتَنْثِرْ', #5
u'ليستنقع': u'لِيَسْتَنْقِعَ', #1
u'ليسجدها': u'لِيَسْجُدَهَا', #8
u'ليسرنى': u'لَيَسَرُّنِى', #1
u'ليسعيان': u'لَيَسْعَيَانِ', #1
u'ليسوءنى': u'لَيَسُوءُنِى', #1
u'ليسوءوا': u'لِيَسُوءُوا', #3
u'ليسئل': u'ليسئل', #1
u'ليشتار': u'لِيَشْتَارَ', #3
u'ليشتفي': u'لِيَشْتَفِيَ', #1
u'ليشتل': u'لِيُشْتَلَ', #1
u'ليص': u'لَيْصَ', #1
u'ليصليان': u'لَيُصَلِّيَانِ', #2
u'ليصيبنى': u'لَيُصِيبُنِى', #1
u'ليصيغ': u'لِيُصِيغَ', #1
u'ليصيغه': u'لِيُصِيغَهُ', #1
u'ليضربنى': u'لِيَضْرِبَنِى', #1
u'ليطة': u'لِيطَةً', #2
u'ليطة': u'لِيطَةٍ', #3
u'ليطؤها': u'لَيَطَؤُهَا', #1
u'ليظعننا': u'لِيَظْعَنَنَا', #1
u'ليظعننا': u'لِيُظْعِنَنَا', #2
u'ليعتاف': u'لِيَعْتَافَ', #1
u'ليعتلف': u'لِيَعْتَلِفَ', #2
u'ليعتمل': u'لِيَعْتَمِلْ', #1
u'ليعجبنى': u'لَيُعْجِبُنِى', #1
u'ليعذبنى': u'لَيُعَذِّبُنِى', #1
u'ليعطيكه': u'لِيُعْطِيَكَهُ', #2
u'ليعمأي': u'ليعمأي', #1
u'ليغازي': u'لِيُغَازِيَ', #1
u'ليغازى': u'لِيُغَازَى', #1
u'ليغان': u'لَيُغَانُ', #20
u'ليغبقون': u'لَيَغْبَقُونَ', #1
u'ليغبقون': u'لَيُغْبَقُونَ', #2
u'ليغزونى': u'لِيَغْزُونِى', #1
u'ليغنيان': u'لَيُغْنِيَانِ', #1
u'ليف': u'لِيفً', #1
u'ليفتضن': u'لَيَفْتَضِنَّ', #1
u'ليفتضن': u'لَيَفْتَضَّنَّ', #2
u'ليفوح': u'لِيَفُوحَ', #3
u'ليفى': u'لِيَفِىَ', #1
u'ليفيتها': u'لِيُفِيتَهَا', #1
u'ليقا': u'لَيْقًا', #1
u'ليقة': u'لِيقَةَ', #1
u'ليقة': u'لَيْقَةٌ', #1
u'ليقة': u'لَيْقَةُ', #1
u'ليقة': u'لِيقَةُ', #2
u'ليقتنت': u'لِيَقْتَنِتَ', #1
u'ليقرءوا': u'لِيَقْرَءُوا', #3
u'ليقرءوه': u'لِيَقْرَءُوهُ', #1
u'ليقلبنى': u'لِيَقْلِبَنِى', #1
u'ليقيت': u'لِيُقِيتَ', #1
u'ليكتمنى': u'لِيَكْتُمَنِى', #1
u'ليكفت': u'لِيَكْفِتَ', #2
u'ليكلمنى': u'لِيُكَلِّمْنِى', #1
u'ليلةالقدر': u'لَيْلَةُالْقَدْرِ', #1
u'ليلتقيان': u'لَيَلْتَقِيَانِ', #1
u'ليلتى': u'لَيْلَتَىِ', #1
u'ليلتى': u'لَيْلَتِىَ', #1
u'ليلتى': u'لَيْلَتِى', #2
u'ليلمة': u'لَيْلَمَةُ', #1
u'ليلنى': u'لِيَلِنِى', #2
u'ليليق': u'لِيَلِيقَ', #1
u'ليلينى': u'لِيَلِينِى', #1
u'ليلينى': u'لِيَلِيَنِّى', #3
u'ليمتار': u'لِيَمْتَارَ', #3
u'ليمنعنى': u'لَيَمْنَعُنِى', #1
u'ليمو': u'لَيْمُو', #3
u'ليمونة': u'لَيْمُونَةً', #1
u'ليمونة': u'لَيْمُونَةٍ', #1
u'ليمونة': u'لَيْمُونَةٌ', #2
u'ليناصي': u'لَيُناصي', #1
u'ليناولنى': u'لَيُنَاوِلُنِى', #1
u'لينبغي': u'لَيَنْبَغِي', #1
u'لينبغي': u'لِيَنْبَغِيَ', #1
u'لينتثر،': u'لِيَنْتَثِرْ،', #1
u'لينتثر': u'لْيَنْتَثِرْ', #2
u'لينتثر': u'لِيَنْتَثِرْ', #5
u'لينتكلوا': u'لِيَنْتَكِلُوا', #1
u'لينتهونن': u'لَيَنْتَهُونَنَّ', #1
u'ليندرئ': u'لِيَنْدَرِئَ', #2
u'لينزوها': u'لِيَنْزُوَهَا', #2
u'لينزيه': u'لِيُنْزِيَهُ', #4
u'لينقصر': u'لِيَنْقَصِرَ', #1
u'ليهراق': u'لِيُهْرَاقَ', #2
u'ليهراقن': u'لَيُهَرَاقَنَّ', #1
u'ليهراقن': u'لَيُهْرَاقَنَّ', #1
u'ليهريق': u'لِيُهَرِيقَ', #3
u'ليهريق': u'لِيُهْرِيقَ', #3
u'ليهنيكم': u'لِيَهْنِيكُمْ', #1
u'ليهودى': u'لِيَهُودِىٍّ', #1
u'ليؤاجر': u'لِيُؤَاجِرَ', #2
u'ليؤاجره': u'لِيُؤَاجِرَهُ', #4
u'ليؤاجرها': u'لِيُؤَاجِرَهَا', #5
u'ليؤاخذ': u'لِيُؤَاخَذَ', #2
u'ليواعدونى': u'لَيُوَاعِدُونِى', #1
u'ليؤامر': u'لِيُؤَامِرَ', #2
u'ليؤتسى': u'لِيُؤْتَسَى', #1
u'ليوحنس': u'لِيُوحَنَّسَ', #1
u'ليوشع': u'لِيُوشَعَ', #2
u'ليوقنالوجه': u'لِيُوقِنَالْوَجْهُ', #1
u'ليولن': u'لَيُوَلّنّ', #1
u'ليئط': u'لَيَئِطُّ', #2
u'ليئوس': u'ليئوس', #1
u'ليئوس': u'لَيَئُوسٌ', #3
u'ليئول': u'لِيَئُولَ', #2
u'مآء': u'مَآءً', #1
u'ماءا': u'مَاءًا', #1
u'ماءا،': u'مَاءًا،', #1
u'ماءوالوجه': u'مَاءٌوَالْوَجْهُ', #1
u'ماأراد': u'مَاأَرَادَ', #1
u'مابال': u'مابال', #1
u'مابسه': u'مابسه', #1
u'مابنا': u'مابنا', #1
u'مابهرام': u'مَابُهْرَامَ', #1
u'مأبور': u'مَأْبُورُ', #1
u'مأبور': u'مَأْبُورٍ', #4
u'مأبور': u'مَأْبُورٌ', #6
u'مأبورا': u'مَأْبُورًا', #4
u'مأبورة': u'مَأْبُورَةُ', #1
u'مأبورة': u'مَأْبُورَةٌ', #18
u'مأبورة': u'مَأْبُورَةٍ', #19
u'مأبورة': u'مَأْبُورَةً', #22
u'مأبورها': u'مَأْبُورَهَا', #1
u'مابوس': u'مَابُوسٌ', #1
u'مابوس؟': u'مَابُوسٌ؟', #1
u'مأبون': u'مَأْبُونٍ', #12
u'مأبون': u'مَأْبُونٌ', #2
u'مأبون': u'مَأْبُونُ', #9
u'مأبونا': u'مَأْبُونًا', #2
u'مابين': u'مابين', #1
u'مابين': u'مَابَيْنَ', #1
u'مأتاة': u'مَأْتَاةُ', #1
u'ماتأمرني': u'ماتأمرني', #1
u'ماتتSحول': u'مَاتَتْSحَوْلَ', #1
u'ماتجاوز': u'مَاتُجَاوِزُ', #1
u'ماتع': u'ماتع', #1
u'ماتع،': u'مَاتِعٍ،', #2
u'ماتع': u'مَاتِعٍ', #3
u'ماتع': u'مَاتِعٌ', #5
u'ماتقدم': u'ماتقدم', #1
u'مأتوا': u'مَأْتُوًّا', #1
u'ماتوبتنا،': u'ماتوبتنا،', #1
u'مأتي': u'مَأْتِيّ', #1
u'ماتى': u'ماتى', #1
u'ماتى،': u'مَاتَى،', #1
u'مأتي': u'مَأْتِيٍّ', #11
u'ماتى': u'مَاتِى', #9
u'مأتيا': u'مَأْتِيًّا', #3
u'ماثان': u'مَاثَانَ', #4
u'مأثوم': u'مأثوم', #1
u'مأثوم': u'مَأْثُومٌ', #13
u'مأثوم': u'مَأْثُومٍ', #5
u'مأثوما': u'مَأْثُومًا', #11
u'مأثومين': u'مَأْثُومَيْنِ', #1
u'ماجاء': u'مَاجَاءَ', #1
u'ماجة': u'ماجة', #2
u'ماجشون': u'مَاجِشُونَ', #1
u'ماجشون': u'مَاجِشُونِ', #2
u'ماجل': u'مَاجِلٍ', #1
u'ماجه': u'ماجه', #1
u'ماجه': u'مَاجَه', #1
u'ماجه،': u'مَاجَه،', #1
u'ماجه': u'مَاجَهُ', #3
u'ماجه': u'مَاجَهْ', #3526
u'ماجه،': u'مَاجَهْ،', #5
u'مأجورية': u'مَأْجُورِيَّةَ', #1
u'مأجوين': u'مَأْجُوَّينِ', #1
u'ماحة': u'مَاحَةٌ', #1
u'ماحة': u'مَاحَةُ', #1
u'ماحة': u'مَاحَةً', #3
u'ماحد': u'ماحد', #1
u'ماحرم': u'ماحرم', #1
u'ماحوز،': u'مَاحُوزٍ،', #1
u'ماحوز': u'مَاحُوزٍ', #2
u'مأحوز': u'مَأْحُوزٍ', #6
u'ماحوزنا': u'مَاحُوزَنَا', #1
u'ماختمت': u'ماختمت', #1
u'ماخلق': u'ماخلق', #1
u'مادامت': u'مَادَامَتِ', #1
u'مادامت': u'مَادَامَتْ', #7
u'ماداموا': u'مَادَامُوا', #1
u'مأدبات': u'مَأْدُبَاتٍ', #1
u'مادر،': u'مَادِرٍ،', #1
u'مادر': u'مادر', #2
u'مادر': u'مَادِر', #4
u'مادرأ': u'مَادرأ', #1
u'مادرت': u'مادرت', #1
u'مادرترايركردن': u'مادرترايركردن', #1
u'مادرتست': u'مادرتست', #1
u'مادرخودراازحقى': u'مادرخودراازحقى', #1
u'مادرزن': u'مادرزن', #1
u'مادرو': u'مَادِرُو', #1
u'مادروبدر': u'مادروبدر', #3
u'مادروغ': u'مادروغ', #1
u'مادمت': u'مَادُمْتَ', #3
u'مادمت': u'مَادُمْت', #5
u'مادمتما': u'مَادُمْتُمَا', #1
u'مأدوم': u'مَأْدُومٍ', #19
u'مأدوما': u'مَأْدُومًا', #21
u'مأدومي': u'مَأْدُومِي', #1
u'ماذاك': u'ماذاك', #1
u'ماذة': u'مَاذَةْ', #1
u'ماذكر': u'ماذكر', #2
u'ماذه': u'مَاذَهْ', #1
u'ماذونا': u'مَاذُونَا', #1
u'مأذونيته': u'مَأْذُونِيَّتِهِ', #2
u'مأذونيته': u'مَأْذُونِيَّتَهُ', #3
u'مأذونيته': u'مَأْذُونِيَّتُهُ', #3
u'مأذونيتهما': u'مَأْذُونِيَّتهمَا', #1
u'ماذي': u'مَاذِي', #1
u'ماذيان': u'مَاذِيَانٌ', #1
u'ماذيان': u'مَاذِيَانِ', #1
u'ماذيان': u'ماذيان', #2
u'ماذيانات': u'ماذيانات', #1
u'ماذيانات': u'مَاذِيَانَاتٍ', #1
u'ماذيانة': u'ماذِيَانَةُ', #1
u'ماذيانة': u'مَاذِيَانَةٌ', #1
u'ماذيانة': u'مَاذِيَانَةٍ', #1
u'ماذيانة': u'مَاذْيَانَةٌ', #1
u'ماراازتو': u'ماراازتو', #1
u'مارابتواين': u'مارابتواين', #1
u'ماراروبروى': u'ماراروبروى', #1
u'مارآه': u'مارآه', #1
u'مارب': u'مارِب', #2
u'مأربة': u'مَأْرَبَةٍ', #1
u'مارث': u'مَارِثٍ', #1
u'مارديني': u'مَارْدِينِيٌّ', #1
u'مأرز': u'مَأْرَزُ', #1
u'مارماهي': u'مارماهي', #1
u'مأروب': u'مَأْرُوبٌ', #2
u'مأروبة': u'مَأْرُوبَةٌ', #2
u'ماز': u'مَازَ', #5
u'مازادوا': u'مازادوا', #1
u'مازالوا،': u'مَازَالُوا،', #1
u'مآزب': u'مَآزِبُ', #1
u'مأزب': u'مَأْزَبٌ', #1
u'مازة': u'مَازَةَ', #1
u'مازرة': u'مَازِرَةَ', #1
u'مازلت': u'مَازِلْتُ', #2
u'مازلنا': u'مَازِلْنَا', #4
u'مازن،': u'مازن،', #1
u'مازن': u'مَازِن', #1
u'مازن': u'مازن', #13
u'مازن،': u'مَازِنٍ،', #3
u'مازن': u'مَازِنَ', #4
u'مازن': u'مَازِنُ', #4
u'مازن': u'مَازِنٍ', #62
u'مازن': u'مَازِنِ', #96
u'مازني': u'مازني', #1
u'مازني': u'مَازِنِيُّ', #1
u'مازه': u'مازه', #1
u'مازيار': u'مَازَيَارَ', #1
u'مازيار': u'مَازِيَارٍ', #1
u'مازيار،': u'مَازَيَارَ،', #1
u'مازيار،': u'مَازيَارَ،', #2
u'مازيار': u'مَازْيَارَ', #2
u'مازيار': u'مَازِيَارَ', #3
u'مازيان': u'مَازَيَانَ', #1
u'ماسآها': u'مَاسَآهَا', #2
u'ماسبذان،': u'مَاسَبَذَانَ،', #1
u'ماسر': u'مَاسِر', #1
u'ماسرجس': u'مَاسَرْجِسَ', #1
u'ماسرجس': u'مَاسِرْجِسٍ', #1
u'ماسفة': u'مَاسِفَةَ', #1
u'ماسويه': u'ماسويه', #1
u'ماسويه': u'مَاسَوَيْهِ', #5
u'ماسى': u'مَاسِىٍّ', #1
u'ماسى': u'مَاسِى', #4
u'ماشا': u'مَاشَا', #1
u'ماشاء': u'مَاشَاءُ', #1
u'ماشاء': u'ماشاء', #2
u'ماشتا': u'مَاشَتًا', #1
u'ماشجرة': u'ماشجرة', #1
u'ماشئت': u'ماشئت', #1
u'ماشئتم': u'ماشئتم', #1
u'ماصدفا': u'مَاصَدَفًا', #1
u'ماصدق': u'مَاصَدَق', #14
u'ماصدقا': u'مَاصَدَقًا', #12
u'ماصدقات': u'مَاصَدَقَاتٌ', #1
u'ماصدقات': u'مَاصَدَقَاتٍ', #1
u'ماصدقات': u'مَاصَدَقَاتُ', #2
u'ماصدقات': u'مَاصَدَقَاتِ', #33
u'ماصدقاته': u'ماصدقاته', #1
u'ماصدقاته': u'مَاصَدَقَاتِهِ', #15
u'ماصدقاتها': u'مَاصَدَقَاتِهَا', #5
u'ماصدقه': u'مَاصَدَقِهِ', #1
u'ماصدقه': u'مَاصَدُقِهِ', #1
u'ماصدقه': u'مَاصَدَقُهُ', #3
u'ماصدقه': u'مَاصَدَقَهُ', #6
u'ماصدقها': u'مَاصَدَقُهَا', #1
u'ماصدقها': u'مَاصَدَقِهِا', #1
u'ماصدقها': u'مَاصَدَقَهَا', #2
u'ماصدقها': u'مَاصَدَقِهَا', #2
u'ماصدقي': u'مَاصَدُقَيْ', #1
u'ماصر': u'مَاصُرّ', #1
u'ماصية': u'مَاصِيَةٍ', #2
u'ماصية': u'مَاصِيَةً', #3
u'ماعزة': u'مَاعِزَةً', #4
u'ماعزة': u'مَاعِزَةٍ', #7
u'ماعزة': u'مَاعِزَةٌ', #9
u'ماعزتان': u'مَاعِزَتَانِ', #1
u'ماعص': u'ماعص', #2
u'ماعص': u'مَاعِصِ', #7
u'ماعص': u'مَاعِصٍ', #9
u'ماعظموا': u'ماعظموا', #1
u'ماعلوا': u'ماعلوا', #1
u'ماعليها': u'ماعليها', #1
u'ماعندك': u'ماعندك', #1
u'ماعندي': u'ماعندي', #1
u'مافاته': u'مافاته', #2
u'مأفون': u'مَأْفُونٍ', #1
u'مأفون': u'مَأْفُونٌ', #3
u'مافي': u'مافي', #2
u'مأق': u'مَأَقَ', #1
u'مأق': u'مَأْقٌ', #1
u'مأق': u'مَأْقُ', #1
u'مأقا': u'مَأْقًا', #1
u'ماقالوا': u'ماقالوا', #1
u'ماقالوا،': u'ماقالوا،', #1
u'ماقالوا،': u'مَاقَالُوا،', #1
u'ماقبلها': u'ماقبلها', #1
u'ماقتلوا': u'ماقتلوا', #1
u'مأقط': u'مَأْقِطٍ', #3
u'مأقه': u'مَأْقِهِ', #1
u'ماقوله': u'ماقوله', #1
u'مآقي': u'مَآقِي', #1
u'مأقيه': u'مَأْقَيْهِ', #1
u'ماقيه': u'مَاقَيْهِ', #1
u'مآقيه': u'مَآقِيَهُ', #3
u'مآقيها': u'مَآقِيهَا', #2
u'مآقيها': u'مَآقِيُهَا', #3
u'ماكان': u'مَاكَانَ', #1
u'ماكان': u'ماكان', #4
u'ماكتب': u'ماكتب', #1
u'ماكسو': u'مَاكِسُو', #1
u'ماكشفت': u'مَاكَشَفْتُ', #1
u'ماكنهم': u'ماكنهم', #1
u'ماكولا،': u'مَاكُولا،', #1
u'ماكولا': u'مَاكُولَا', #23
u'ماكولا': u'ماكولا', #4
u'ماكويه': u'مَاكَوَيْهِ', #1
u'مال': u'مَالً', #3
u'مالاقالا': u'مَالاقَالا', #1
u'مالطاة': u'مَالْطَاةَ', #1
u'مألفة': u'مَأْلَفَةٌ', #2
u'مألك': u'مَأْلُك', #1
u'مالك': u'مَالِكً', #2
u'مالك،': u'مَالِكً،', #2
u'مألكا': u'مَأْلُكًا', #6
u'مالكاحدثه': u'مالكاحَدَّثَهُ', #1
u'مالكاحدثه،': u'مالكاحَدَّثَهُ،', #1
u'مالكاحدثه،': u'مَالِكاحَدَّثَهُ،', #1
u'مالكإلا': u'مَالِكٍإِلَّا', #2
u'مالكالطاغوت': u'مَالِكٌالطَّاغُوتُ', #1
u'مالكالعلم': u'مَالِكٌالْعِلْمُ', #1
u'مالكالفسوق': u'مَالِكٌالْفُسُوقُ', #1
u'مالكأن': u'مَالِكٍأَنَّ', #1
u'مالكأنه': u'مَالِكٍأَنَّهُ', #1
u'مألكة': u'مَأْلُكَةً', #1
u'مألكة': u'مَأْلُكَةٍ', #1
u'مالكعن': u'مَالِكٍعَنِ', #1
u'مالكفي': u'مَالِكٌفِي', #3
u'مالكفيمن': u'مَالِكٌفِيمَنْ', #1
u'مالكقال': u'مَالِكٌقَالَ', #1
u'مالكقوله': u'مَالِكٍقَوْلُهُ', #1
u'مالككأن': u'مَالِكٍكَأَنْ', #1
u'مالكلا': u'مَالِكٍلَا', #1
u'مالكليس': u'مَالِكٍلَيْسَ', #1
u'مالكوالشافعي': u'مَالِكٌوَالشَّافِعِيُّ', #1
u'مالكولم': u'مَالِكٍوَلَمْ', #1
u'مالكيضيف': u'مَالِكٍيُضِيفُ', #1
u'مالكيقول': u'مَالِكٌيَقُولُ', #1
u'مالم': u'مَالَمْ', #6
u'مالوجهك': u'مَالِوَجْهِكَ', #3
u'مألوس': u'مَأْلُوسُ', #1
u'مألوم': u'مَأْلُومٌ', #1
u'مألوما': u'مَأْلُومًا', #2
u'مألومة': u'مَأْلُومَةً', #1
u'مألوه': u'مَألُوهٌ', #1
u'مألوه': u'مَأْلُوهٍ', #3
u'مالى': u'مالى', #1
u'مالى؟': u'مَالِى؟', #6
u'مالى': u'مَالِى', #79
u'ماليدن': u'ماليدن', #1
u'ماما': u'مَامَا', #2
u'مامة': u'مَامَةَ', #2
u'مأملهما': u'مَأْمَلُهُمَا', #1
u'مامن': u'مامن', #1
u'مأمنة': u'مَأْمِنَةٌ', #1
u'مامنعك': u'مَامَنَعَكَ', #2
u'مامه': u'مَامَهْ', #1
u'مأمولية': u'مَأْمُولِيَّةُ', #1
u'مأمومية': u'مَأْمُومِيَّةٍ', #3
u'مأموميته': u'مَأْمُومِيَّتِهِ', #2
u'مأموميتهم': u'مَأْمُومِيَّتِهِمْ', #1
u'ماميتا': u'ماميتا', #2
u'ماميثا': u'ماميثا', #1
u'مآميم': u'مَآمِيمُ', #2
u'مأنا': u'مَأْنًا', #1
u'مانت': u'مَانَّتْ', #1
u'مأنت': u'مَأَنْت', #2
u'مأنته': u'مَأَنْته', #1
u'ماند': u'ماند', #9
u'مانداين': u'مانداين', #1
u'ماندتا': u'ماندتا', #1
u'ماندش': u'ماندش', #1
u'ماندفر': u'ماندفر', #1
u'مانده': u'مانده', #6
u'ماندو': u'ماندو', #1
u'ماندوشب': u'ماندوشب', #1
u'مانعى': u'مَانِعِى', #1
u'مانعية': u'مَانِعِيَّةً', #1
u'مانعية': u'مَانِعِيَّةُ', #1
u'مانعية': u'مَانِعِيَّةٌ', #12
u'مانعية': u'مَانِعِيَّةٍ', #2
u'مانعية': u'مَانِعِيَّةَ', #3
u'مانعية': u'مَانِعِيَّةِ', #8
u'مانعيته': u'مَانِعِيَّتَهُ', #3
u'مانعيته': u'مَانِعِيَّتُهُ', #3
u'مانعيته': u'مَانِعِيَّتِهِ', #5
u'مانعيتها': u'مَانِعِيَّتَهَا', #1
u'مانلومك': u'مانلومك', #1
u'مانوس': u'مَانُوسٌ', #1
u'مانوس': u'مَانُوسٍ', #1
u'مانوس،': u'مَانُوسَ،', #1
u'مانوس': u'مَانُوسَ', #4
u'مانيتها': u'مَانِّيَّتِهَا', #1
u'مانيذ': u'مانيذ', #1
u'ماهان': u'مَاهَان', #1
u'ماهان،': u'مَاهَانَ،', #14
u'ماهان،': u'ماهان،', #2
u'ماهان،': u'مَاهَانُ،', #2
u'ماهان': u'مَاهَانُ', #5
u'ماهان': u'مَاهَانَ', #52
u'ماهذا؟': u'مَاهَذَا؟', #1
u'ماهذا': u'ماهذا', #2
u'ماهم': u'ماهم', #1
u'مأوا': u'مَأْوًا', #1
u'ماوان': u'ماوان', #1
u'ماوان': u'مَاوَانَ', #1
u'ماورد': u'مَاوَرْدٍ', #1
u'ماوعدتني،': u'ماوعدتني،', #2
u'ماوقت': u'مَاوَقَتْ', #1
u'مأوي': u'مَأْوِيّ', #1
u'مأي': u'مُأَيٌّ', #1
u'مائةفلا': u'مِائَةًفَلَا', #1
u'مائتى': u'مِائَتَىْ', #20
u'مائتى': u'مِائَتَى', #3
u'مائح': u'مَائِح', #1
u'مائح': u'مَائِحُ', #1
u'مآئدة': u'مَآئِدَةً', #2
u'مائذ': u'مَائِذُ', #1
u'مائر': u'مَائِرٌ', #1
u'مائر': u'مَائِرُ', #2
u'مائعيته': u'مَائِعِيَّتِهِ', #2
u'مائل': u'مَائِلً', #1
u'مائن': u'مَائِنٌ', #1
u'مائنه': u'مَائِنُهُ', #1
u'مائنه': u'مَائِنِهِ', #2
u'مائهالا': u'مَائِهَاََََلَا', #1
u'مائى': u'مَائِى', #1
u'مائين': u'مَائِينَ', #2
u'مايأمرهم': u'مايأمرهم', #1
u'مأيت': u'مَأَيْت', #1
u'مايزيد': u'مايزيد', #1
u'مايشاء': u'مايشاء', #1
u'مايشغله': u'مَايَشْغَلُهُ', #1
u'مايقربهم': u'مايقربهم', #1
u'مايقول': u'مايقول', #1
u'مايليه،': u'مايليه،', #1
u'ماينقض': u'مَايَنْقُضُ', #1
u'مايه': u'مايه', #3
u'مأيوس': u'مَأْيُوسَ', #1
u'مأيوس': u'مَأْيُوسٍ', #14
u'مأيوس': u'مَأْيُوسٌ', #17
u'مأيوسا': u'مَأْيُوسًا', #14
u'مايى': u'مايى', #1
u'مبات': u'مَبَاتِ', #3
u'مباتة': u'مُبَاتَّةً', #1
u'مباح': u'مُبَاحً', #1
u'مباحو': u'مُبَاحُو', #1
u'مبادى': u'مُبَادَى', #1
u'مباديا': u'مُبَادِيًا', #1
u'مبارأة': u'مُبَارَأَةً', #1
u'مبارأة': u'مُبَارَأَةٌ', #1
u'مبارأة': u'مُبَارَأَةُ', #2
u'مبارأة': u'مُبَارَأَةِ', #2
u'مبارأة': u'مُبَارَأَةٍ', #4
u'مبارآت': u'مُبَارَآت', #1
u'مبارئة': u'مبارئة', #1
u'مبارئة': u'مُبَارِئَةٌ', #1
u'مباش': u'مباش', #3
u'مباشرت': u'مباشرت', #1
u'مباضعة': u'مُبَاضَعَةِ', #1
u'مباضعة': u'مُبَاضَعَةُ', #3
u'مباضعتك': u'مُبَاضَعَتِكَ', #2
u'مباضعته': u'مُبَاضَعَتِهِ', #1
u'مباطر': u'مُبَاطِر', #1
u'مباطنة': u'مُبَاطَنَةِ', #2
u'مباطنتهم': u'مُبَاطَنَتِهِمْ', #4
u'مباعلة': u'مُبَاعَلَةً', #1
u'مبالى': u'مُبَالًى', #3
u'مبانا': u'مُبَانًا', #14
u'مبانة': u'مُبَانَة', #1
u'مبانة': u'مُبَانَةً', #18
u'مبانة': u'مُبَانَةَ', #2
u'مبانة': u'مُبَانَةِ', #2
u'مبانة': u'مُبَانَةٌ', #33
u'مبانة': u'مُبَانَةٍ', #5
u'مبانتان': u'مُبَانَتَانِ', #2
u'مبانته': u'مُبَانَتَهُ', #13
u'مبانته': u'مُبَانَتِهِ', #15
u'مبانته': u'مُبَانَتُهُ', #4
u'مباه': u'مُبَاهٍ', #1
u'مباهتا': u'مُبَاهِتًا', #1
u'مباهي': u'مُبَاهِي', #1
u'مباين': u'مُبَايِنَ', #1
u'مباين': u'مُبَايِنُ', #1
u'مباين': u'مُبَايِنِ', #1
u'مباين': u'مُبَايِنٍ', #10
u'مباين': u'مُبَايِنٌ', #110
u'مباينا': u'مُبَايِنًا', #33
u'مباينان': u'مُبَايِنَانِ', #22
u'مباينة': u'مُبَايَنَة', #1
u'مباينة': u'مُبَايَنَةٍ', #1
u'مباينة': u'مُبَايِنَةَ', #1
u'مباينة': u'مُبَايِنَةِ', #1
u'مباينة': u'مُبَايَنَةً', #10
u'مباينة': u'مُبَايِنَةٍ', #11
u'مباينة': u'مُبَايَنَةُ', #4
u'مباينة': u'مُبَايَنَةٌ', #43
u'مباينة': u'مُبَايَنَةَ', #6
u'مباينة': u'مُبَايَنَةِ', #6
u'مباينة': u'مُبَايِنَةً', #6
u'مباينة': u'مُبَايِنَةٌ', #68
u'مباينته': u'مُبَايَنَتُهُ', #1
u'مباينته': u'مُبَايِنَتَهُ', #1
u'مباينته': u'مُبَايَنَتَهُ', #2
u'مباينته': u'مُبَايَنَتِهِ', #2
u'مباينتين': u'مُبَايِنَتَيْنِ', #1
u'مباينه': u'مباينه', #1
u'مباينه': u'مُبَايِنِهِ', #4
u'مباينهما': u'مُبَايِنِهِمَا', #1
u'مباينون': u'مُبَايِنُونَ', #2
u'مباينين': u'مُبَايِنِينَ', #1
u'مبتة': u'مُبَتَّةٍ', #1
u'مبتد': u'مُبْتَدٍ', #2
u'مبتدءا': u'مُبْتَدَءًا', #1
u'مبتدا': u'مُبْتَدًّا', #1
u'مبتدا': u'مُبْتَدَا', #3
u'مبتدرا': u'مُبْتَدِرَا', #1
u'مبتدرا': u'مُبْتَدِرًا', #2
u'مبتدى': u'مُبْتَدًى', #1
u'مبتدي': u'مُبْتَدِي', #3
u'مبتديا': u'مُبْتَدِيًا', #3
u'مبتديه': u'مُبْتَدِيهِ', #1
u'مبتر': u'مُبْتِرٌ', #1
u'مبتغا': u'مُبْتَغَا', #1
u'مبتغيني': u'مُبْتَغِينِي', #2
u'مبتنى': u'مُبْتَنًى', #1
u'مبتنى': u'مُبْتَنَى', #2
u'مبتوتة': u'مَبْتُوتَة', #1
u'مبتوتة': u'مَبْتُوتَةِ', #1
u'مبتوتة': u'مَبْتُوتَةً', #25
u'مبتوتة': u'مَبْتُوتَةٌ', #29
u'مبتوتة': u'مَبْتُوتَةٍ', #37
u'مبتوتته': u'مَبْتُوتَتَهُ', #1
u'مبتوته': u'مَبْتُوتِهِ', #1
u'مبتوعها': u'مَبْتُوعِهَا', #1
u'مبتوكة': u'مَبْتُوكَةٌ', #1
u'مبتول': u'مَبْتُولٌ', #1
u'مبحوثة': u'مَبْحُوثَةٍ', #4
u'مبحوثة': u'مَبْحُوثَةٌ', #5
u'مبخل': u'مُبَخّلٍ', #1
u'مبخوت': u'مَبْخُوتٍ', #1
u'مبدءون': u'مُبْدَءُونَ', #1
u'مبداة': u'مُبَدَّاةٌ', #1
u'مبديا': u'مُبْدِيًا', #1
u'مبدية': u'مُبْدِيَةً', #1
u'مبذيرا': u'مبذيرا', #1
u'مبرءون': u'مُبَرَّءُونَ', #27
u'مبرأ': u'مُبَرّأٌ', #2
u'مبرأ': u'مُبَرّأٍ', #2
u'مبرأ': u'مُبَرَّأ', #2
u'مبرأ': u'مُبَرَّأَ', #2
u'مبرإ': u'مُبْرَإٍ', #3
u'مبرأ': u'مُبَرَّأً', #7
u'مبرأ': u'مُبَرَّأٌ', #7
u'مبرأ': u'مُبْرَأً', #9
u'مبرأة': u'مُبَرَّأةٌ', #1
u'مبرأة': u'مُبَرَّأَةً', #1
u'مبرأة': u'مُبَرَّأَةٌ', #2
u'مبرأة': u'مُبْرَأَةٌ', #2
u'مبرآن': u'مُبَرَّآنِ', #1
u'مبرأها': u'مبرأها', #1
u'مبرس': u'مُبَرَّسٍ', #1
u'مبرسم': u'مُبَرْسِمٍ', #1
u'مبرسم': u'مُبَرْسَمٌ', #23
u'مبرسم': u'مُبَرْسَمٍ', #6
u'مبرسما': u'مُبَرْسَمًا', #12
u'مبركا': u'مَبْرَكًا', #1
u'مبركها': u'مَبْرَكُهَا', #1
u'مبركها': u'مَبْرَكِهَا', #3
u'مبرود': u'مَبْرُودٌ', #3
u'مبرودة': u'مَبْرُودَةً', #1
u'مبرئ': u'مُبَرِّئً', #2
u'مبرئى': u'مُبَرِّئِى', #1
u'مبسند': u'مبسند', #1
u'مبسور': u'مَبْسُورٍ', #2
u'مبسورا': u'مَبْسُورًا', #1
u'مبسورة': u'مبسورة', #1
u'مبصقا': u'مَبْصَقًا', #1
u'مبعثة': u'مَبْعَثَةٌ', #1
u'مبعثة': u'مَبْعَثُةُ', #1
u'مبعثة': u'مَبْعَثَةً', #2
u'مبعر': u'مَبْعَرٍ', #1
u'مبعض': u'مُبَعَّضَ', #1
u'مبعض': u'مُبْعِضٍ', #1
u'مبعض': u'مُبَعِّضٍ', #2
u'مبعض': u'مُبَعَّضٌ', #63
u'مبعض': u'مُبَعَّضٍ', #85
u'مبعضا': u'مُبْعِضًا', #1
u'مبعضا': u'مُبَعَّضًا', #222
u'مبعضة': u'مُبَعَّضَةِ', #1
u'مبعضة': u'مُبَعَّضَةٌ', #12
u'مبعضة': u'مُبَعَّضَةٍ', #17
u'مبعضة': u'مُبَعَّضَةً', #53
u'مبعضتين': u'مُبَعَّضَتَيْنِ', #2
u'مبعضه': u'مُبَعَّضَهُ', #1
u'مبعضه': u'مُبَعَّضِهِ', #1
u'مبعضون': u'مُبَعَّضُونَ', #1
u'مبعضين': u'مُبَعَّضَيْنِ', #9
u'مبغوضية': u'مَبْغُوضِيَّةً', #7
u'مبقاة': u'مُبَقَّاةٌ', #1
u'مبقاة': u'مُبْقَاةٍ', #1
u'مبقاة': u'مُبْقَاةٌ', #46
u'مبقاة': u'مُبْقَاةً', #8
u'مبقورا': u'مَبْقُورًا', #1
u'مبقورة': u'مَبْقُورَةٍ', #1
u'مبقى': u'مُبْقًى', #104
u'مبقى': u'مُبْقَى', #14
u'مبلسون': u'مُّبْلِسُونَ', #1
u'مبلسون': u'مُبْلِسُونَ', #14
u'مبلوغة': u'مَبْلُوغَةٍ', #6
u'مبني': u'مَبْنِيًّ', #1
u'مبول': u'مُبَوِّلِ', #1
u'مبيب': u'مَبِيبُ', #1
u'مبير': u'مُبِيرٍ', #1
u'مبير': u'مُبِيرُ', #1
u'مبير': u'مُبِيرٌ', #4
u'مبيرا': u'مُبِيرًا', #3
u'مبيرة': u'مُبِيرَةٍ', #1
u'مبيس': u'مُبَيّسٌ', #1
u'مبيكر': u'مُبَيْكِرٍ', #1
u'مبيوعة': u'مَبْيُوعَة', #1
u'مبيوعة': u'مَبْيُوعَةٍ', #1
u'مبيئس': u'مُبَيْئِسٌ', #1
u'مبييس': u'مُبَيّيسٌ', #1
u'مة': u'مَةِ', #3
u'متاب': u'مَتَابٌ', #2
u'متاب': u'مَتَابِ', #2
u'متابا': u'مَتَابًا', #4
u'متأبد': u'مُتَأَبَّدٌ', #1
u'متأبد': u'مُتَأَبِّدَ', #1
u'متأبد': u'مُتَأَبِّدٍ', #2
u'متأبد': u'مُتَأَبِّدٌ', #3
u'متأبد': u'مُتَأَبَّدٍ', #5
u'متأبدا': u'مُتَأَبّدًا', #1
u'متأبدا': u'مُتَأَبِّدًا', #2
u'متأبدة': u'مُتَأَبَّدَةٌ', #1
u'متأبدة': u'مُتَأَبِّدَةً', #2
u'متأبدة': u'مُتَأَبَّدَةٍ', #4
u'متأبدة': u'مُتَأَبِّدَةٌ', #4
u'متأبدة': u'مُتَأَبِّدَةٍ', #6
u'متأبر': u'مُتَأَبِّرٍ', #6
u'متأثل': u'مُتَأَثِّل', #2
u'متأثل': u'مُتَأَثِّلٍ', #21
u'متأثما': u'مُتَأَثِّمًا', #2
u'متأخرى': u'مُتَأَخِّرِى', #1
u'متأخمة': u'مُتَأَخِّمَةً', #1
u'متأديا': u'مُتَأَدِّيًا', #3
u'متأذ': u'مُتَأَذٍّ', #1
u'متأذيا': u'مُتَأَذِّيًا', #1
u'متاركة': u'مُتَارَكَةٍ', #12
u'متاركة': u'مُتَارَكَةُ', #18
u'متاركة': u'مُتَارَكَةِ', #18
u'متاركة': u'مُتَارَكَةً', #28
u'متاركة': u'مُتَارَكَةَ', #3
u'متاركة': u'مُتَارَكَةٌ', #30
u'متاركته': u'مُتَارَكَتُهُ', #1
u'متاركته': u'مُتَارَكَتِهِ', #1
u'متاركتها': u'مُتَارَكَتِهَا', #3
u'متاركتهم': u'مُتَارَكَتَهُمْ', #2
u'متاركتهما': u'مُتَارَكَتِهِمَا', #1
u'متأزر': u'مُتَأَزِّرٌ', #1
u'متاعة': u'مَتَاعَةِ', #1
u'متاعى': u'مَتَاعِى', #2
u'متأكل': u'مُتَأَكِّلٍ', #1
u'متأكلة': u'مُتَأَكِّلَةٍ', #2
u'متأكلة': u'مُتَأَكِّلَةً', #3
u'متالع': u'مُتَالِعَ', #1
u'متالع': u'مُتَالِعُ', #3
u'متأيم': u'مُتَأَيِّمٌ', #1
u'متأيمة': u'مُتَأَيِّمَةً', #1
u'متأيمة': u'مُتَأَيِّمَةٌ', #1
u'متباشرين': u'مُتَبَاشِرَيْنِ', #2
u'متبديا': u'مُتَبَدِّيًا', #1
u'متبديا': u'مُتَبَدّيًا', #1
u'متبذلا،': u'مُتَبَذِّلا،', #2
u'متبذلا': u'مُتَبَذِّلاً', #4
u'متبذلا': u'مُتَبَذِّلًا', #9
u'متبذلة،': u'مُتَبَذِّلة،', #1
u'متبذلة': u'مُتَبَذِّلَةٍ', #1
u'متبذلة': u'مُتَبَذِّلَةٌ', #2
u'متبذلة': u'مُتَبَذِّلَةً', #5
u'متبذللا': u'مُتَبَذِّلَلاً', #2
u'متبر': u'مُتَبَرٍّ', #3
u'متبر': u'مُتَبَّرٌ', #8
u'متبرأ': u'مُتَبَرَّأٌ', #1
u'متبرقعة،': u'مُتَبَرْقِعَةً،', #1
u'متبريا': u'مُتَبَرِّيًا', #2
u'متبرية': u'مُتَبَرِّيَةٌ', #1
u'متبعض': u'مُتَبَعِّضٌ', #3
u'متبعضا': u'مُتَبَعِّضًا', #5
u'متبعضة': u'مُتَبَعِّضَةً', #1
u'متبعضة': u'مُتَبَعِّضَةٌ', #1
u'متبوأ': u'متبوأ', #1
u'متبوأه': u'مُتَبَوَّأَهُ', #1
u'متبوعية': u'مَتْبُوعِيَّةِ', #1
u'متبوعيته': u'مَتْبُوعِيَّتِهِ', #1
u'متبولSوقوله': u'مَتْبُولُSوَقَوْلُهُ', #1
u'متبول': u'مَتْبولُ', #1
u'متبول': u'مُتَبْولُ', #1
u'متبول': u'مَتْبُولُ', #12
u'متترس': u'مُتَتَرِّسٌ', #2
u'متترسا': u'مُتَتَرِّسًا', #1
u'متجارحين': u'مُتَجَارِحَيْنِ', #2
u'متجالة': u'مُتَجَالَّةٍ', #22
u'متجالة': u'مُتَجَالَّةً', #37
u'متجالة': u'مُتَجَالَّةٌ', #7
u'متجانف': u'مُتَجَانِفٍ', #15
u'متجانفا': u'مُتَجَانِفًا', #1
u'متجدلا': u'مُتَجدّلًا', #1
u'متجدلا': u'مُتَجَدّلًا', #2
u'متجدلا': u'مُتَجَدِّلًا', #2
u'متجرى': u'مَتْجَرِى', #1
u'متجز': u'مُتَجَزٍّ', #21
u'متجزي': u'مُتَجَزِّي', #2
u'متجزيا': u'مُتَجَزِّيًا', #2
u'متجمر': u'مُتَجَمَّرٍ', #1
u'متجمر': u'مُتَجَمِّرٍ', #2
u'متجور': u'مُتَجَوِّرٌ', #1
u'متجوز': u'مُتَجَوَّزٌ', #1
u'متجوز': u'مُتَجَوِّزٌ', #8
u'متجوزا': u'مُتَجَوَّزًا', #2
u'متجوزا': u'مُتَجَوِّزًا', #4
u'متجوفة': u'مُتَجَوّفَةٌ', #1
u'متجوه': u'مُتَجَوَّه', #1
u'متجوه': u'مُتَجَوِّهٍ', #2
u'متجوه': u'مُتَجَوِّهٌ', #4
u'متجوها': u'مُتَجَوِّهًا', #4
u'متحاجزين': u'مُتَحَاجِزِينَ', #1
u'متحددة': u'مُتَحَدِّدَةٌ', #1
u'متحدى': u'مُتَحَدًّى', #2
u'متحذر': u'مُتَحَذِّرٍ', #2
u'متحرف': u'مُتَحَرِّفٍ', #11
u'متحرف': u'مُتَحَرِّفٌ', #8
u'متحرفا': u'مُتَحَرَّفًا', #1
u'متحرفا': u'مُتَحَرّفًا', #2
u'متحرفا': u'مُتَحَرِّفًا', #53
u'متحرفين': u'مُتَحَرِّفِينَ', #7
u'متحرفينا': u'مُتَحَرّفِينَا', #2
u'متحرم': u'مُتَحَرِّمٌ', #1
u'متحرما': u'مُتَحَرِّمًا', #2
u'متحرى': u'مُتَحَرًّى', #1
u'متحزن': u'مُتَحَزِّنٌ', #1
u'متحزيا': u'مُتَحَزّيًا', #1
u'متحشما': u'مُتَحَشِّمًا', #2
u'متحمدا': u'مُتَحَمِّدًا', #1
u'متحننا': u'مُتَحَنِّنًا', #1
u'متحوز': u'مُتَحَوّزٌ', #1
u'متحيل': u'مُتَحَيِّلٌ', #1
u'متحيل': u'مُتَحَيِّلٍ', #1
u'متحيلا': u'مُتَحَيِّلًا', #1
u'متحيلا': u'مُتَحَيَّلًا', #2
u'متخالعين': u'مُتَخَالِعَيْنِ', #3
u'متخاونون': u'مُتَخَاوِنُونَ', #2
u'متخت': u'مُتِخَتْ', #1
u'متختم': u'مُتَخَتِّمٌ', #1
u'متختما': u'مُتَخَتِّمًا', #1
u'متخدرة': u'مُتَخَدِّرَةً', #1
u'متخذانه': u'مُتَّخِذَانِهِ', #1
u'متخرب': u'مُتَخَرِّبٍ', #1
u'متخربة': u'مُتَخَرِّبَةٍ', #1
u'متخرصا': u'مُتَخَرِّصًا', #2
u'متخرصين': u'مُتَخَرِّصِينَ', #1
u'متخرق': u'مُتَخَرّقٌ', #1
u'متخرق': u'مُتَخَرِّقٌ', #3
u'متخرق': u'مُتَخَرِّقٍ', #6
u'متخرقا': u'مُتَخَرَّقًا', #1
u'متخرقا': u'مُتَخَرِّقًا', #10
u'متخرقة': u'متخرقة', #1
u'متخرقة': u'مُتَخَرِّقَةٌ', #1
u'متخصرا': u'مُتَخَصّرًا', #1
u'متخصرا': u'مُتَخَصِّرًا', #7
u'متخفف': u'مُتَخَفِّفٌ', #1
u'متخففا': u'مُتَخَفِّفًا', #19
u'متخففة': u'مُتَخَفِّفَةٌ', #1
u'متخما': u'مُتْخِمًا', #1
u'متخمة': u'مُتْخِمَةٌ', #1
u'متخمطون': u'مُتَخَمِّطُونَ', #1
u'متخمطون': u'مُتَخَمّطُونَ', #2
u'متخوض': u'مُتَخَوِّضٍ', #8
u'متدابرين': u'مُتَدَابِرَيْنِ', #1
u'متداحضة': u'مُتَدَاحِضَةُ', #1
u'متداني': u'مُتَدَانِيَ', #1
u'متدانيتين': u'مُتَدَانِيَتَيْنِ', #2
u'متدانين': u'مُتَدَانِينَ', #1
u'متدرع': u'مُتَدَرِّعَ', #1
u'متدرعا': u'مُتَدَرِّعًا', #1
u'متذنبات': u'مُتَذَنِّبَاتِ', #1
u'متراد': u'مُتَرَادٍّ', #1
u'متراضى': u'مُتَرَاضًى', #1
u'متراوضان': u'مُتَرَاوِضَانِ', #1
u'متربحا': u'مُتَرَبِّحًا', #1
u'مترخص': u'مُتَرَخِّصٌ', #2
u'مترخصا': u'مُتَرَخِّصًا', #16
u'مترسيت': u'مترسيت', #3
u'مترسيد': u'مترسيد', #1
u'مترفرفة': u'مُتَرَفْرِفَةٌ', #2
u'متزاملين': u'مُتَزَامِلَيْنِ', #1
u'متزر': u'مُتَّزِرَ', #1
u'متزر': u'مُتَّزِرٌ', #4
u'متزرا': u'مُتَّزِرًا', #9
u'متزرة': u'مُتَّزِرَةٌ', #1
u'متزيدين': u'مُتَزَيِّدَيْنِ', #1
u'متساخف': u'مُتَسَاخِفٌ', #1
u'متساقبة': u'مُتَسَاقِبَةٌ', #1
u'متسالفين': u'مُتَسَالِفَيْنِ', #1
u'متساومان': u'مُتَسَاوِمَانِ', #2
u'متساومين': u'مُتَسَاوِمَيْنِ', #2
u'متسبسبا': u'مُتَسَبْسِبًا', #1
u'متسجيا': u'مُتَسَجّيًا', #2
u'متسحبا': u'مُتَسَحَّبًا', #1
u'متسحرا': u'مُتَسَحِّرًا', #1
u'متسخط': u'مُتَسَخِّطٌ', #2
u'متسخطا': u'مُتَسَخِّطًا', #2
u'متسخن': u'مُتَسَخِّنٍ', #1
u'متسددا': u'مُتَسَدِّدًا', #1
u'متسر': u'مُتَّسِرٍ', #1
u'متسر': u'مُتَسَرٍّ', #2
u'متسرقا': u'مُتَسَرّقًا', #1
u'متسلخ': u'مُتَسَلِّخٌ', #2
u'متسلم': u'مُتَسَلِّمٌ', #2
u'متسلما': u'مُتَسَلِّمًا', #3
u'متسمع': u'مُتَسَمِّعٍ', #1
u'متسور': u'مُتَسَوِّرٌ', #1
u'متسورا': u'مُتَسَوِّرًا', #1
u'متشابههالوجه': u'مُتَشَابِهِهِالْوَجْهُ', #1
u'متشاحين': u'مُتَشَاحَّيْنِ', #1
u'متشالخ،': u'مِتْشَالِخَ،', #1
u'متشتما،': u'مُتَشَتِّمًا،', #1
u'متشتما': u'مُتَشَتّمًا', #4
u'متشدخين': u'مَتُشَدِّخِينَ', #1
u'متشرعا': u'مُتَشَرِّعًا', #1
u'متشطر': u'مُتَشَطِّرٌ', #2
u'متشعثا': u'مُتَشَعِّثًا', #1
u'متشوف': u'مُتَشَوِّفٍ', #2
u'متشوف': u'مُتَشَوِّفٌ', #70
u'متشوفا': u'مُتَشَوَّفًا', #1
u'متشوفا': u'مُتَشَوِّفًا', #6
u'متشوفة': u'مُتَشَوِّفَةٍ', #1
u'متشوفة': u'مُتَشَوِّفَةً', #3
u'متشوفين': u'مُتَشَوِّفِينَ', #1
u'متشيخي': u'مُتَشَيِّخِي', #1
u'متصارمان': u'مُتَصَارِمَانِ', #7
u'متصلاونوى': u'مُتَّصِلًاوَنَوَى', #1
u'متصيدا': u'مُتَصَيِّدًا', #2
u'متضايفة': u'مُتَضَايِفَةً', #1
u'متضايفين': u'مُتَضَايِفَيْنِ', #3
u'متضجعا': u'مُتَضَجِّعًا', #1
u'متضجعون': u'مُتَضَجّعُونَ', #1
u'متضع': u'مُتَّضِعُ', #1
u'متضعف': u'مُتَضَعَّفٍ', #4
u'متضعف': u'مُتَضَعِّفٍ', #8
u'متضمخ': u'مُتَضَمِّخٌ', #14
u'متضمخ': u'مُتَضَمِّخ', #3
u'متضمخا': u'مُتَضَمِّخًا', #3
u'متضمخة': u'مُتَضَمِّخَةٌ', #1
u'متطلسا': u'مُتَطَلِّسًا', #1
u'متطيلسا': u'مُتَطَيْلِسًا', #2
u'متطيلسين': u'مُتَطَيْلِسِينَ', #1
u'متعادا': u'مُتَعَادًّا', #1
u'متعارجا': u'مُتَعَارِجًا', #3
u'متعالنات': u'مُتَعَالِنَاتٌ', #1
u'متعالنات': u'مُتَعَالِنَاتٍ', #2
u'متعالنين': u'مُتَعَالِنِينَ', #1
u'متعاور': u'مُتَعَاوَرٌ', #2
u'متعتع': u'مُتَعْتَع', #1
u'متعتع': u'مُتَعْتَعٍ', #10
u'متعتع': u'مُتَعْتِعٍ', #2
u'متعدة': u'مُتَّعِدَةٍ', #1
u'متعشقات': u'مُتَعَشِّقَاتٍ', #1
u'متعلنات': u'مُتَعَلِّنَاتٍ', #1
u'متعمم': u'مُتَعَمِّمٌ', #4
u'متعمما': u'مُتَعَمِّمًا', #4
u'متعممي': u'مُتَعَمِّمِي', #1
u'متعممين': u'مُتَعَمِّمِينَ', #1
u'متعنى': u'مَتِّعْنِى', #1
u'متعور': u'مُتَعَوِّرٍ', #1
u'متعيب': u'مُتَعَيَّبٍ', #1
u'متعيب': u'مُتَعَيِّبٍ', #1
u'متعيب': u'مُتَعَيَّبٌ', #3
u'متعيب': u'مُتَعَيِّبٌ', #3
u'متعيبا': u'مُتَعَيِّبًا', #1
u'متغال': u'مُتَغَالٍ', #1
u'متغاليا': u'متغاليًا', #1
u'متغاليا': u'مُتَغَالِيًا', #1
u'متغر': u'مُتَّغِرٍ', #1
u'متغر': u'مُتَّغِرٌ', #6
u'متغشى': u'مُتَغَشًّى', #1
u'متغفرا': u'مُتَغَفَّرًا', #1
u'متغلظ': u'مُتَغَلِّظٌ', #1
u'متغلظ': u'مُتَغَلِّظُ', #1
u'متغلظة': u'مُتَغَلِّظَةً', #1
u'متغلظة': u'مُتَغَلِّظَةٌ', #3
u'متغلظة': u'مُتَغَلَّظَةٌ', #5
u'متغمطا': u'مُتَغَمِّطًا', #1
u'متفاحش': u'مُتَفَاحِشَ', #1
u'متفاحش': u'مُتَفَاحِشُ', #1
u'متفاحش': u'مُتَفَاحِشٍ', #16
u'متفاحش': u'مُتَفَاحِشِ', #5
u'متفاحش': u'مُتَفَاحِشٌ', #7
u'متفاحشا': u'مُتَفَاحِشًا', #33
u'متفاحشة': u'مُتَفَاحِشَةِ', #1
u'متفاحشة': u'مُتَفَاحِشَةٌ', #22
u'متفاحشة': u'مُتَفَاحِشَةً', #39
u'متفاحشة': u'مُتَفَاحِشَةٍ', #8
u'متفاحشه': u'مُتَفَاحِشَهُ', #1
u'متفاصل': u'مُتَفَاصِلٌ', #2
u'متفاصلا': u'مُتَفَاصِلًا', #3
u'متفاصلات': u'مُتَفَاصِلَاتٍ', #1
u'متفاصلة': u'مُتَفَاصِلَةٌ', #8
u'متفاصلة': u'مُتَفَاصِلَةٍ', #8
u'متفاصلة': u'مُتَفَاصِلَةً', #9
u'متفاصلتين': u'مُتَفَاصِلَتَيْنِ', #1
u'متفاعلن': u'مُتَفَاعِلُنْ', #2
u'متفاعلن': u'مُتَفَاعِلُن', #3
u'متفتشة': u'مُتَفَتِّشَة', #1
u'متفخذها': u'مُتَفَخِّذَهَا', #1
u'متفخذها': u'مُتَفَخِّذُهَا', #1
u'متفرق': u'مُتَفَرِّقً', #1
u'متفشفشة': u'مُتَفَشْفِشَةٌ', #2
u'متفعلا': u'مُتَفَعّلًا', #1
u'متفيعل': u'مُتَفَيْعِلٌ', #1
u'متقابضة': u'مُتَقَابِضَةٌ', #1
u'متقابضين': u'مُتَقَابَضَيْنِ', #1
u'متقابضين': u'مُتَقَابِضَيْنِ', #2
u'متقارضان': u'مُتَقَارِضَانِ', #1
u'متقارضين': u'مُتَقَارِضَيْنِ', #1
u'متقاصر': u'مُتَقَاصِرٌ', #1
u'متقاصر': u'مُتَقَاصِرٍ', #1
u'متقاصرة': u'مُتَقَاصِرَةٍ', #1
u'متقاطر': u'مُتَقَاطَرٍ', #1
u'متقاطر': u'مُتَقَاطِرٌ', #4
u'متقاطر': u'مُتَقَاطِرٍ', #6
u'متقاطرا': u'مُتَقَاطَرًا', #1
u'متقاطرا': u'مُتَقَاطِرًا', #25
u'متقاطرة': u'مُتَقَاطِرَةً', #4
u'متقاطرين': u'مُتَقَاطِرِينَ', #1
u'متقاومتان': u'مُتَقَاوِمَتَانِ', #1
u'متقاومين': u'مُتَقَاوِمَيْنِ', #1
u'متقسم': u'مُتَقَسِّمٌ', #1
u'متقسم': u'مُتَقَسِّمُ', #1
u'متقصفون': u'مُتَقَصِّفُونَ', #1
u'متقصفون': u'مُتَقَصّفُونَ', #2
u'متقلدى': u'مُتَقَلِّدِى', #4
u'متقلقلون': u'مُتَقَلْقِلُونَ', #1
u'متقلل': u'مُتَقَلِّلٌ', #1
u'متقللا': u'مُتَقَلِّلًا', #2
u'متقوبة': u'مُتَقَوِّبَةَ', #1
u'متقى': u'مُتَّقًى', #1
u'متقى': u'مُتَّقَى', #9
u'متقيئا': u'مُتَقَيِّئًا', #1
u'متكارهين': u'مُتَكَارِهَيْنِ', #1
u'متكاري': u'مُتَكَارِي', #5
u'متكاوس': u'مُتَكَاوِسٍ', #2
u'متكاوش،': u'متكاوش،', #1
u'متكره': u'مُتَكَرِّهٌ', #1
u'متكرها': u'مُتَكَرِّهًا', #2
u'متكرهة': u'مُتَكَرِّهَةً', #4
u'متكفرا': u'مُتَكَفِّرًا', #1
u'متكمهينا': u'مُتَكَمّهِينَا', #3
u'متكى': u'مُتَّكَى', #1
u'متكيء': u'متكيء', #1
u'متكيء': u'مُتَّكِيءٌ', #1
u'متلاحكة': u'مُتَلاَحِكَةً', #1
u'متلاحكة': u'مُتَلَاحِكَة', #2
u'متلازق': u'مُتَلَازِقٌ', #2
u'متلازقا': u'مُتَلَازِقًا', #1
u'متلازقات': u'مُتَلَازِقَاتٍ', #1
u'متلازقة': u'مُتَلَازِقَةً', #13
u'متلازقتين': u'مُتَلَازِقَتَيْنِ', #3
u'متلازقي': u'مُتَلَازِقَيْ', #1
u'متلازقين': u'مُتَلَازِقَيْنِ', #2
u'متلامسين': u'مُتَلَامِسَيْنِ', #1
u'متلب': u'مُتْلِبٌ', #1
u'متلبب': u'مُتَلَبِّبٌ', #2
u'متلببا': u'مُتَلَبِّبًا', #3
u'متلج': u'مُتّلِجٌ', #1
u'متلج': u'مُتّلِجٍ', #2
u'متلد': u'مُتْلَدٌ', #1
u'متلد': u'مُتْلَدُ', #1
u'متلددا': u'مُتَلَدّدًا', #2
u'متلقاة': u'مُتَلَقَّاةٌ', #10
u'متلقة': u'مُتَلَّقَةٌ', #1
u'متلقطها': u'مُتَلَقِّطِهَا', #1
u'متلقى': u'مُتَلَقًّى', #25
u'متلقى': u'مُتَلَقَّى', #5
u'متلمح': u'مُتَلَمَّحُ', #1
u'متلمح': u'مُتَلَمَّحِ', #2
u'متماحل': u'مُتَمَاحِلِ', #1
u'متمادحين': u'مُتَمَادَحِينَ', #1
u'متمالئون': u'مُتَمَالِئُونَ', #3
u'متمالئين': u'مُتَمَالِئَيْنِ', #1
u'متمالئين': u'مُتَمَالِئِينَ', #2
u'متمانعين': u'مُتَمَانِعَيْنِ', #1
u'متمحض': u'مُتَمَحَّضٌ', #1
u'متمحض': u'مُتَمَحِّضُ', #1
u'متمحض': u'مُتَمَحِّضٌ', #17
u'متمحض': u'مُتَمَحِّضٍ', #2
u'متمحض': u'مُتَمَحَّضَ', #3
u'متمحض': u'مُتَمَحِّضِ', #4
u'متمحضا': u'مُتَمَحِّضًا', #13
u'متمحضا': u'مُتَمَحَّضًا', #2
u'متمحضات': u'مُتَمَحِّضَاتٍ', #1
u'متمحضة': u'مُتَمَحِضَّةً', #1
u'متمحضة': u'مُتَمَحِّضَةٍ', #1
u'متمحضة': u'مُتَمَحِّضَةَ', #1
u'متمحضة': u'مُتَمَحِّضَةً', #10
u'متمحضة': u'مُتَمَحِّضَةٌ', #11
u'متمحل': u'مُتَمَحِّلٌ', #1
u'متمرض': u'مُتَمَرِّضٌ', #1
u'متمرضا،': u'مُتَمَرِّضًا،', #1
u'متمعط': u'مُتَمَعِّطٍ', #1
u'متمعطا': u'مُتَمَعِّطًا', #1
u'متمناهم': u'مُتَمَنَّاهُمْ', #2
u'متمنى': u'مُتَمَنَّى', #1
u'متناجز': u'مُتَنَاجِزٍ', #1
u'متناجزين': u'مُتَنَاجِزَيْنِ', #3
u'متناساة': u'مُتَنَاسَاةً', #1
u'متناعسا': u'مُتَنَاعِسًا', #1
u'متنافذة': u'مُتَنَافِذَةٌ', #3
u'متنافذين': u'مُتَنَافَذَيْنِ', #1
u'متناكرة': u'مُتَنَاكِرَةٌ', #1
u'متنايف': u'مُتَنَايِفٍ', #1
u'متنجز': u'مُتَنَجِّزِ', #1
u'متنجزة': u'مُتَنَجَّزَةٍ', #1
u'متنصد': u'مُتَنَصّدٌ', #1
u'متنعنع': u'مُتَنَعْنِعُ', #3
u'متنفر': u'مُتَنَفِّرُ', #1
u'متنفر': u'مُتَنَفِّرٌ', #3
u'متنفرا': u'مُتَنَفِّرًا', #1
u'متنفق': u'مُتَنَفّقِ', #2
u'متنمقا': u'مُتَنَمِّقًا', #1
u'متهاجران': u'مُتَهَاجِرَانِ', #1
u'متهاجرين': u'مُتَهَاجِرِينَ', #1
u'متهاجرين': u'مُتَهَاجِرَيْنِ', #1
u'متهب': u'مُتَّهَبِ', #1
u'متهب': u'مُتَّهِبٍ', #15
u'متهب': u'مُتَّهَبٍ', #17
u'متهب': u'مُتَّهَبٌ', #4
u'متهب': u'مُتَّهِبٌ', #5
u'متهبا': u'مُتَّهَبًا', #2
u'متهبطة': u'مُتَهَبِّطَةٌ', #1
u'متهبه': u'مُتَّهَبُهُ', #1
u'متهبه': u'مُتَّهِبُهُ', #1
u'متهدلة': u'مُتْهَدِّلَةٍ', #1
u'متهدلة': u'مُتَهَدِّلَةٌ', #2
u'متهرية': u'مُتَهَرِّيَةً', #1
u'متهمى': u'مُتَّهَمِى', #1
u'متهوم': u'مَتْهُومٍ', #2
u'متهوما': u'مُتَهَوِّمًا', #1
u'متهيأ': u'مُتَهَيَّأً', #5
u'متهيئ': u'مُتَهَيِّئٌ', #11
u'متهيئ': u'مُتَهَيِّئ', #3
u'متهيئ': u'مُتَهَيِّئٍ', #5
u'متهيئا': u'مُتَهَيَّئًا', #1
u'متهيئا': u'مُتَهَيِّئًا', #33
u'متهيئة': u'مُتَهَيِّئَةٌ', #2
u'متهيئة': u'مُتَهَيِّئَةً', #8
u'متهيئون': u'مُتَهَيِّئُونَ', #3
u'متهيئين': u'مُتَهَيَّئِينَ', #1
u'متهيئين': u'مُتَهَيِّئِينَ', #7
u'متو': u'مُتَو', #1
u'متواخيات': u'مُتَوَاخِيَاتٍ', #1
u'متواخين': u'مُتَوَاخِينَ', #1
u'متوادين': u'مُتَوَادِّينَ', #1
u'متوازرينا': u'مُتَوَازِرِينَا', #2
u'متواسطة': u'مُتَوَاسِطَةٍ', #1
u'متواطأ': u'مُتَوَاطَأٍ', #1
u'متوحها': u'مُتُوحَهَا', #1
u'متوزة': u'متوزة', #1
u'متوزة': u'مُتَوَّزَةٍ', #1
u'متوشلخ': u'مُتَوَشْلِخَ', #1
u'متوشلخ': u'مَتُّوشَلَخَ', #2
u'متوشلخ': u'مَتّوشَلَخ', #6
u'متوصيا': u'مُتَوَصِّيًا', #1
u'متوض': u'مُتَوَضٍّ', #3
u'متوضا': u'مُتَوَضَّا', #1
u'متوعرا': u'مُتَوَعِّرًا', #2
u'متوفزا': u'مُتَوَفِّزًا', #1
u'متولونها': u'مُتَوَلُّونَهَا', #1
u'متولى': u'متولى', #1
u'متوليسي': u'متوليسي', #2
u'متونة': u'مُتُونَةٍ', #2
u'متونته': u'مُتُونَتِهِ', #1
u'متويا': u'مُتْوِيًا', #2
u'متويه': u'مَتُّوَيْهِ', #1
u'متويه': u'مَتَّوَيْهِ', #2
u'متئب': u'مُتّئِبٍ', #1
u'متيخة': u'مِتِّيخَةً', #1
u'متيع': u'مُتَيّعٌ', #1
u'متيع': u'مُتَيِّعٌ', #1
u'متيع': u'مُتَيْعٌ', #1
u'متيعه': u'مُتَيّعَهُ', #2
u'مثاعب': u'مَثَاعِبُ', #1
u'مثافلين': u'مُثَافِلِينَ', #1
u'مثاكيل': u'مَثَاكِيلُ', #3
u'مثالات': u'مِثَالَاتِ', #1
u'مثالثة': u'مُثَالَثَةً', #14
u'مثالثة': u'مُثَالَثَةٌ', #2
u'مثالثته': u'مُثَالَثَتُهُ', #3
u'مثالثته': u'مُثَالَثَتَهُ', #4
u'مثالثها': u'مَثَالِثُهَا', #1
u'مثانين': u'مَثَانِينَ', #2
u'مثبجا': u'مُثَبِّجًا', #1
u'مثبرها': u'مَثْبِرُهَا', #1
u'مثبوت': u'مَثْبُوتٌ', #1
u'مثبوتة': u'مَثْبُوتَةً', #1
u'مثبوتة': u'مَثْبُوتَةَ', #1
u'مثبوتة': u'مَثْبُوتَةٌ', #2
u'مثبوتها': u'مَثْبُوتُهَا', #1
u'مثبور': u'مَثْبُورُ', #2
u'مثجا،': u'مَثِجًا،', #1
u'مثدن': u'مُثَدَّنُ', #1
u'مثدن': u'مُثْدَنُ', #1
u'مثدون': u'مَثْدُونُ', #13
u'مثراة': u'مِثْرَاةٍ', #1
u'مثراة': u'مَثْرَاةٌ', #5
u'مثرد': u'مُثَرِّدٍ', #1
u'مثرد': u'مُثْرَدٍ', #1
u'مثرى': u'مُثْرًى', #1
u'مثعبان': u'مِثْعَبَانِ', #1
u'مثعبان': u'مَثْعَبَانِ', #2
u'مثغر': u'مُثْغِرٌ', #2
u'مثغر': u'مُثْغِرٍ', #7
u'مثغور': u'مَثْغُورٌ', #12
u'مثغور': u'مَثْغُورٍ', #64
u'مثغورا': u'مَثْغُورًا', #6
u'مثغوران': u'مَثْغُورَانِ', #2
u'مثغورة': u'مَثْغُورَةٍ', #6
u'مثغورين': u'مَثْغُورَيْنِ', #2
u'مثفار': u'مِثْفَارٌ', #1
u'مثقالان': u'مِثْقَالَانِ', #4
u'مثقالين': u'مِثْقَالَيْنِ', #4
u'مثكله': u'مَثْكَلَهْ', #1
u'مثل': u'مِثْلً', #1
u'مثلة': u'مَثْلَةٌ', #1
u'مثلة': u'مُثْلَةُ', #1
u'مثلة': u'مِثْلَةَ', #1
u'مثلة،': u'مُثْلَةً،', #1
u'مثلة': u'مُثْلَةً', #104
u'مثلة': u'مُثْلَةٌ', #151
u'مثلة': u'مُثْلَةٍ', #17
u'مثلة': u'مَثُلَةٌ', #2
u'مثلة': u'مُثْلَة', #4
u'مثلة': u'مُثْلَةَ', #6
u'مثلة': u'مُثْلَةِ', #7
u'مثلعمل': u'مِثْلَعَمَلِ', #1
u'مثلمؤخرة': u'مِثْلَمُؤْخِرَةِ', #1
u'مثلهة': u'مِثْلَهُة', #1
u'مثلهولينبذوا': u'مِثْلَهُوَلْيُنْبَذُوا', #1
u'مثلهيطأ': u'مِثْلَهُيَطَأُ', #1
u'مثلهيييي': u'مِثْلَهُيييي', #1
u'مثلوم': u'مَثْلُومٌ', #1
u'مثلوما': u'مَثْلُومًا', #2
u'مثمون': u'مَثْمُونِ', #3
u'مثمون': u'مَثْمُونٌ', #5
u'مثمون': u'مَثْمُونٍ', #8
u'مثمونا': u'مَثْمُونًا', #5
u'مثمونه': u'مَثْمُونِهِ', #3
u'مثمونين': u'مَثْمُونَيْنِ', #4
u'مثناء': u'مَثْنَاءُ', #1
u'مثناتان': u'مُثَنَّاتَان', #1
u'مثناتين': u'مُثَنَّاتَيْن', #1
u'مثناتين': u'مُثَّنَاتَيْنِ', #2
u'مثناتين': u'مُثَنَّاتَيْنِ', #5
u'مثنود': u'مَثْنُودٌ', #1
u'مثنوية': u'مَثْنَوِيَّة', #1
u'مثنوية': u'مَثْنَوِيّةٌ', #2
u'مثنوية': u'مَثْنَوِيَّةٍ', #2
u'مثنوية': u'مَثْنَوِيَّةٌ', #3
u'مثنوية': u'مَثْنَوِيَّةَ', #3
u'مثواى': u'مَثْوَاىَ', #1
u'مثوب': u'مُثَوِّبٌ', #1
u'مثوب': u'مُثَوِّبٍ', #1
u'مثوبا': u'مَثُوبًا', #1
u'مجابرتهم': u'مُجَابَرَتِهِمْ', #1
u'مجاح': u'مَجَاحٍ', #1
u'مجاح': u'مُجَاحٌ', #1
u'مجاح': u'مُجَاحٍ', #1
u'مجاح،': u'مَجَاحٍ،', #1
u'مجاحا': u'مَجَاحًا', #1
u'مجاحا': u'مِجَاحًا', #1
u'مجاديح': u'مَجَادِيحُ', #1
u'مجاذب': u'مُجَاذِبٌ', #1
u'مجارك': u'مَجَارِكَ', #1
u'مجارهم': u'مَجَارَّهُمْ', #1
u'مجازى': u'مُجَازًى', #2
u'مجازيعا': u'مَجَازِيعًا', #4
u'مجاشع،': u'مُجَاشِع،', #1
u'مجاشع،': u'مُجَاشِعٌ،', #1
u'مجاشع': u'مُجَاشِعُ', #10
u'مجاشع': u'مُجَاشِعٍ', #22
u'مجاشع': u'مُجَاشِعِ', #24
u'مجاشع': u'مُجَاشع', #3
u'مجاشع': u'مجاشع', #4
u'مجاشع،': u'مُجَاشِعٍ،', #50
u'مجاشع،': u'مجاشع،', #8
u'مجاشع': u'مُجَاشِعٌ', #9
u'مجاعةوروي': u'مَجَاعَةٌوَرُوِيَ', #1
u'مجاعلة': u'مُجَاعَلَةً', #1
u'مجاعلة': u'مُجَاعَلَةٍ', #1
u'مجاعلة': u'مُجَاعَلَةَ', #1
u'مجاعلة': u'مُجَاعَلَةِ', #2
u'مجاعلته': u'مُجَاعَلَتِهِ', #1
u'مجاعلته': u'مُجَاعَلَتُهُ', #2
u'مجافا': u'مُجَافًا', #1
u'مجالد': u'مُجَالدِ', #1
u'مجالد': u'مُجَالَدٌ', #1
u'مجالد': u'مُجَالَدٍ', #1
u'مجالد': u'مُجَالِدَ', #1
u'مجالد': u'مُجَالِدِ', #12
u'مجالد': u'مُجَالِدٍ', #151
u'مجالد،': u'مُجالد،', #2
u'مجالد': u'مُجَالِد', #2
u'مجالد': u'مُجَالِدُ', #26
u'مجالد،': u'مُجَالِدٌ،', #27
u'مجالد': u'مجالد', #6
u'مجالد،': u'مُجَالِدٍ،', #61
u'مجالد': u'مُجَالِدٌ', #75
u'مجالد،': u'مجالد،', #8
u'مجالدا،': u'مُجَالِدًا،', #1
u'مجالدا': u'مُجَالِدًا', #6
u'مجالدنا': u'مَجَالِدُنَا', #1
u'مجالدنا': u'مُجَالَدُنَا', #7
u'مجالستى': u'مُجَالَسَتِى', #1
u'مجامد': u'مَجَامِدَ', #2
u'مجانيب': u'مَجَانِيبَ', #1
u'مجاهدإذا': u'مُجَاهِدٍإِذَا', #1
u'مجاهدالحكم': u'مُجَاهِدٍالْحُكْمُ', #1
u'مجاهدالرجس': u'مُجَاهِدٍالرِّجْسُ', #1
u'مجاهدالشمس': u'مُجَاهِدٌالشَّمْسُ', #1
u'مجاهدخلق': u'مُجَاهِدٌخَلَقَ', #1
u'مجاهدكان': u'مُجَاهِدٍكَانَ', #1
u'مجاهدوسألته': u'مُجَاهِدٍوَسَأَلْتُهُ', #1
u'مجاهدويشهد': u'مُجَاهِدٍوَيُشْهِدُ', #1
u'مجاولة': u'مجاولة', #1
u'مجاولة': u'مُجَاوَلَةٌ', #3
u'مجباة': u'مُجَبَّاةً', #1
u'مجببا': u'مُجَبّبًا', #1
u'مجبوا': u'مُجِبُوا', #1
u'مجبوب': u'مَجْبُوبَ', #18
u'مجبوب': u'مَجْبُوبِ', #3
u'مجبوب': u'مَجْبُوبُ', #7
u'مجبوب': u'مَجْبُوبٍ', #74
u'مجبوب': u'مَجْبُوبٌ', #78
u'مجبوبا': u'مَجْبُوبًا', #226
u'مجبوبة': u'مجبوبة', #1
u'مجبوبه': u'مَجْبُوبَهُ', #1
u'مجبوبين': u'مَجْبُوبَيْنِ', #2
u'مجبى': u'مُجَبّى', #1
u'مجة': u'مجة', #1
u'مجة': u'مَجَّة', #1
u'مجة': u'مَجَّةٌ', #14
u'مجة': u'مَجَّةً', #16
u'مجة': u'مَجَّةٍ', #7
u'مجتابة': u'مُجْتَابَةٌ', #1
u'مجتابي': u'مُجْتَابِي', #10
u'مجتابى': u'مُجْتَابِى', #5
u'مجتذرة': u'مُجْتَذَرَةٍ', #1
u'مجتلد': u'مُجْتَلَدِ', #3
u'مجتنا': u'مُجْتَنًّا', #10
u'مجتنحا': u'مُجْتَنِحًا', #1
u'مجثم': u'مَجْثَمٍ', #1
u'مجثمة': u'مُجَثَّمَةٍ', #1
u'مجثمها': u'مَجْثَمَهَا', #1
u'مجثمها': u'مَجْثَمُهَا', #1
u'مجح': u'مُجِحٌّ', #1
u'مجح،': u'مُجِحٌّ،', #1
u'مجح': u'مُجِحّ', #2
u'مجح': u'مُجِحٍّ', #3
u'مجحا': u'مُجِحًّا', #4
u'مجحفل': u'مُجَحْفَلِ', #1
u'مجحود': u'مَجْحُودٌ', #3
u'مجحود': u'مَجْحُودٍ', #3
u'مجحودا': u'مَجْحُودًا', #11
u'مجحودة': u'مَجْحُودَةً', #1
u'مجحودة': u'مَجْحُودَةٌ', #1
u'مجحودة': u'مَجْحُودَةٍ', #2
u'مجحورا': u'مَجْحُورًا', #1
u'مجحوشتان': u'مَجْحُوشَتَانِ', #1
u'مجحوشتين': u'مَجْحُوشَتَيْنِ', #1
u'مجخ': u'مُجِخٌّ', #1
u'مجخ': u'مُجِخٍّ', #1
u'مجخ': u'مُجَخٍّ', #2
u'مجخا': u'مُجِخًّا', #1
u'مجخيا': u'مُجَخِّيًا', #8
u'مجدعة': u'مَجْدَعَةٍ', #1
u'مجدعة': u'مجدعة', #2
u'مجدعة': u'مَجْدَعَةَ', #21
u'مجدنى': u'مَجَّدَنِى', #8
u'مجدود': u'مَجْدُودٍ', #5
u'مجدودا': u'مَجْدُودًا', #4
u'مجدودة': u'مَجْدُودَةً', #3
u'مجذم': u'مُجَذَّمٍ', #1
u'مجذم': u'مُجْذَمٌ', #1
u'مجذوذ': u'مَجْذُوذٌ', #1
u'مجذوذ': u'مَجْذُوذٍ', #19
u'مجذوذا': u'مَجْذُوذًا', #20
u'مجذوذة': u'مَجْذُوذَةٌ', #1
u'مجذوذة': u'مَجْذُوذَةٍ', #1
u'مجراة': u'مُجْرَاةً', #1
u'مجراة': u'مُجْرَاةِ', #1
u'مجراة': u'مُجْرَاةٍ', #2
u'مجراة': u'مُجْرَاةٌ', #3
u'مجرز': u'مُجَرِّزٍ', #1
u'مجرودة': u'مَجْرُودَةٌ', #1
u'مجرودة': u'مَجْرُودَةٍ', #1
u'مجزز': u'مجزّز', #1
u'مجزز': u'مُجزِّزٍ', #1
u'مجزز': u'مُجَزّزٌ', #1
u'مجزز': u'مُجَزِّزَ', #1
u'مجزز': u'مُجَزّزٍ', #16
u'مجزز': u'مُجَزِّزٌ', #18
u'مجزز': u'مُجَزِّز', #2
u'مجزز': u'مُجَزِّزٍ', #23
u'مجززا': u'مُجَزّزًا', #2
u'مجززا': u'مُجَزِّزًا', #28
u'مجزع': u'مَجْزَع', #1
u'مجزع': u'مُجَزّعٌ', #1
u'مجزع': u'مَجْزَعِ', #2
u'مجزفا': u'مُجَزَّفًا', #1
u'مجزفا': u'مُجْزِفًا', #1
u'مجزفا': u'مُجْزَفًا', #2
u'مجزل': u'مُجْزَلٍ', #1
u'مجزم': u'مُجَزَّمٍ', #1
u'مجزورا': u'مَجْزُورًا', #1
u'مجزوز': u'مَجْزُوزٌ', #2
u'مجزوز': u'مَجْزُوزٍ', #2
u'مجزوزا': u'مَجْزُوزًا', #7
u'مجزوزة': u'مَجْزُوزَةٌ', #1
u'مجزوزة': u'مَجْزُوزَةً', #4
u'مجزى': u'مَجْزَى', #1
u'مجسر': u'مِجْسَرُ', #2
u'مجشة': u'مَجِشّةً', #1
u'مجشر': u'مُجَشِّرٍ', #17
u'مجعرة': u'مَجْعَرَةٌ', #1
u'مجعل': u'مَجْعَلَ', #14
u'مجفرة': u'مَجْفَرَةٌ', #1
u'مجفو': u'مَجْفُوٌّ', #2
u'مجفوة': u'مَجْفُوَّةٍ', #1
u'مجفوة': u'مَجْفُوَّةٌ', #12
u'مجفوة': u'مَجْفُوَّةً', #2
u'مجفي': u'مَجْفِيٌّ', #1
u'مجلاة': u'مَجْلَاةٌ', #1
u'مجلت': u'مَجَلَتْ', #2
u'مجلت': u'مَجِلَتْ', #2
u'مجلث،': u'مِجْلَثُ،', #1
u'مجلث': u'مِجْلَثُ', #2
u'مجلحا': u'مُجَلَّحًا', #1
u'مجلحة': u'مُجَلّحَةٍ', #2
u'مجلحين': u'مُجَلّحِينَ', #2
u'مجلز': u'مجلز', #1
u'مجلز': u'مِجْلَزِ', #1
u'مجلز،': u'مِجْلَز،', #1
u'مجلز،': u'مِجْلَزَ،', #1
u'مجلز،': u'مِجْلِزٍ،', #1
u'مجلز': u'مِجْلَزٍ', #149
u'مجلز،': u'مجلز،', #3
u'مجلز،': u'مِجْلَزٍ،', #42
u'مجلز،في': u'مِجْلَزٍ،فِي', #1
u'مجلسى': u'مَجْلِسِى', #1
u'مجلعبا': u'مُجْلَعِبّا', #2
u'مجللا': u'مُجَلِّلا', #1
u'مجللا': u'مُجَلَّلًا', #10
u'مجللا': u'مُجَلِّلًا', #8
u'مجللات': u'مُجَلّلَاتٍ', #1
u'مجللة': u'مُجَلَّلَةٌ', #1
u'مجللة': u'مُجَلَّلَةٍ', #1
u'مجللة': u'مُجَلّلَةً', #2
u'مجللة': u'مُجَلَّلَةً', #3
u'مجلوبة': u'مَجْلُوبَةٌ', #1
u'مجلوبها': u'مَجْلُوبُهَا', #1
u'مجلوبهما': u'مَجْلُوبُهُمَا', #2
u'مجلوبهما': u'مَجْلُوبِهِمَا', #5
u'مجلوبون': u'مَجْلُوبُونَ', #1
u'مجما': u'مَجَمًّا', #1
u'مجمة': u'مَجَمَّة', #1
u'مجمة': u'مَجَمَّةٌ', #6
u'مجمجة': u'مَجْمَجَةٌ', #2
u'مجمجم': u'مُجَمْجَمٍ', #1
u'مجممة،': u'مُجَمَّمَةٌ،', #1
u'مجممة': u'مُجَمَّمَةٌ', #2
u'مجموعيا': u'مَجْمُوعِيًّا', #1
u'مجنأ': u'مُجْنَأً', #2
u'مجنإ': u'مُجْنَإِ', #3
u'مجنوز': u'مَجْنُوزٌ', #1
u'مجهودون': u'مَجْهُودُونَ', #1
u'مجهولية': u'مَجْهُولِيَّةَ', #1
u'مجهولية': u'مَجْهُولِيَّةِ', #1
u'مجوب': u'مَجُوبٌ', #1
u'مجوب': u'مُجَوِّبٌ', #2
u'مجوبا': u'مُجَوّبًا', #1
u'مجوسة': u'مَجُوسَةِ', #2
u'مجوسى': u'مَجُوسِىٍّ', #1
u'مجوسى': u'مَجُوسِىٌّ', #4
u'مجونة': u'مُجُونَةٌ', #1
u'مجىء': u'مَجِىءٌ', #1
u'مجىء': u'مَجِىءَ', #3
u'مجىء': u'مَجِىءِ', #3
u'مجيديا': u'مَجِيدِيًّا', #21
u'مجيديات': u'مَجِيدِيَّاتٍ', #4
u'مجيدية': u'مَجِيدِيَّةٌ', #2
u'مجيدية': u'مَجِيدِيَّةٍ', #2
u'مجيدية': u'مُجَيْدِيَّةً', #2
u'مجيدية': u'مُجَيْدِيَّةٍ', #2
u'مجيدية': u'مُجَيْدِيَّةٌ', #4
u'مجيئة': u'مَجِيئَةَ', #1
u'مجيئة': u'مَجِيئَةُ', #1
u'مجيئته': u'مَجِيئَتَهُ', #1
u'محاء': u'مَحَّاءٌ', #18
u'محاء': u'مَحَّاءُ', #2
u'محابى': u'مُحَابًى', #2
u'محابيب': u'مَحَابِيبُ', #3
u'محابيب': u'مَحَابِيبَ', #7
u'محاجزة': u'مُحَاجَزَةٌ', #1
u'محاجن': u'مَحَاجِنُ', #1
u'محاجن': u'مَحَاجِنَ', #2
u'محاجنهم': u'مَحَاجِنُهُمْ', #2
u'محاجيا': u'مُحَاجِيًا', #1
u'محاجير': u'مَحَاجِيرَ', #2
u'محاجير': u'مَحَاجِيرِ', #2
u'محاجيره': u'مَحَاجِيرِهِ', #9
u'محاجيرهم': u'مَحَاجِيرِهِمْ', #2
u'محاذات': u'مُحَاذَاتِ', #1
u'محاذى': u'مُحَاذَى', #1
u'محارس': u'مَحَارِسِ', #1
u'محارس': u'محارس', #2
u'محارسهم': u'مَحَارِسِهِمْ', #1
u'محاز': u'مُحَازٌ', #1
u'محاز': u'مُحَازُّ', #1
u'محازا': u'مُحَازًا', #2
u'محازاة': u'مُحَازَاةٍ', #1
u'محازيين': u'مُحَازِيَيْنِ', #1
u'محاصا': u'مُحَاصًّا', #10
u'محاصة': u'مُحَاصَّةً', #1
u'محاصة': u'مُحَاصَّةٍ', #1
u'محاصة': u'مُحَاصَّةُ', #10
u'محاصة': u'مُحَاصَّةَ', #12
u'محاصة': u'مُحَاصَّةِ', #2
u'محاصة': u'مُحَاصَّةٌ', #4
u'محاصته': u'مُحَاصَّتَهُ', #1
u'محاصته': u'مُحَاصَّتِهِ', #1
u'محاصته': u'مُحَاصَّتُهُ', #2
u'محاصتها': u'مُحَاصَّتِهَا', #1
u'محاصتهم': u'مُحَاصَّتَهُمْ', #1
u'محاصتهم': u'مُحَاصَّتِهِمْ', #1
u'محاصرى': u'مُحَاصِرِى', #1
u'محاصصة': u'مُحَاصَصَةِ', #1
u'محاصصته': u'مُحَاصَصَتُهُ', #3
u'محافد': u'مَحَافِدِ', #1
u'محاققة': u'مُحَاقَقَةُ', #1
u'محاقلة': u'مُحَاقَلَةٌ', #1
u'محاقلة': u'مُحَاقَلَةً', #6
u'محاكرة': u'مُحَاكَرَةً', #1
u'محاكرة': u'مُحَاكَرَةَ', #1
u'محاللتهم': u'محاللتهم', #1
u'محاويج': u'مَحَاوِيج', #1
u'محاويج': u'مَحَاوِيجَ', #10
u'محاويج': u'مَحَاوِيجُ', #15
u'محاويج': u'مَحَاوِيجِ', #18
u'محاويجهم': u'مَحَاوِيجِهِمْ', #3
u'محاويه': u'مَحَاوِيَهِ', #1
u'محائدي': u'مُحَائِدِي', #1
u'محائض': u'مَحَائِضٍ', #1
u'محائض': u'مَحَائِضُ', #2
u'محاير': u'مَحَايِرُ', #1
u'محاير': u'مَحَايِرِ', #1
u'محبتى': u'مَحَبَّتِى', #6
u'محبق': u'مُحَبِّقٍ', #1
u'محبنطئا': u'مُحْبَنْطِئًا', #5
u'محبنطئين': u'مُحْبَنْطِئِينَ', #1
u'محبوبية': u'مَحْبُوبِيَّةً', #2
u'محتبى': u'مُحْتَبِىٌّ', #1
u'محتبئ': u'مُحْتَبِئٌ', #1
u'محتبئا': u'مُحْتَبِئًا', #1
u'محتجره': u'مُحْتَجَرَهُ', #1
u'محتجم': u'مُحْتَجِمٍ', #1
u'محتجم': u'مُحْتَجِمٌ', #2
u'محتذا': u'مُحْتَذَا', #1
u'محتزم': u'مُحْتَزِمٌ', #4
u'محتزما': u'مُحْتَزِمًا', #8
u'محتزمات': u'مُحْتَزِمَاتٍ', #2
u'محتش': u'مُحْتَشٍّ', #1
u'محتشا': u'مُحْتَشًّا', #1
u'محتشى': u'مُحْتَشًى', #1
u'محتفا': u'مُحْتَفًّا', #1
u'محتفر': u'مُحْتَفِرُ', #1
u'محتفرا': u'مُحْتَفِرًا', #3
u'محتفرها': u'مُحْتَفِرِهَا', #1
u'محتفز': u'مُحْتَفِزٌ', #2
u'محتقب': u'مُحْتَقِبٌ', #1
u'محتمل': u'مُحْتَمَلً', #1
u'محتوش': u'مُحْتَوَشٌ', #11
u'محتوش': u'مُحْتَوِشٌ', #2
u'محتوش': u'مُحْتَوِشٍ', #2
u'محتوش': u'مُحْتَوَشٍ', #6
u'محتوشا': u'مُحْتَوَشًا', #1
u'محتوشا': u'مُحْتَوِشًا', #1
u'محتول': u'مُحْتَوَلٌ', #2
u'محتول': u'مُحْتَوِلٌ', #2
u'محثا': u'مُحِثًّا', #1
u'محجز': u'مِحْجَزِ', #1
u'محجلون': u'محجلون', #1
u'محجلون': u'مُحَجَّلُونَ', #9
u'محجن': u'مِحْجن', #1
u'محجن،': u'مِحْجَنٌ،', #1
u'محجن': u'مِحْجَنِ', #14
u'محجن': u'مِحْجَنٌ', #15
u'محجن': u'مِحْجَنَ', #2
u'محجن،': u'مِحْجَن،', #2
u'محجن': u'مِحْجَنُ', #3
u'محجن': u'محجن', #5
u'محجن': u'مِحْجَنٍ', #65
u'محجن': u'مِحْجَن', #8
u'محجنا': u'مِحْجَنًا', #2
u'محجنه': u'مِحْجَنِهِ', #1
u'محجنها': u'مِحْجَنُهَا', #1
u'محجوبية': u'مَحْجُوبِيَّةً', #1
u'محجوج': u'مَحْجُوجٍ', #2
u'محجوج': u'مَحْجُوجٌ', #70
u'محجوجا': u'مَحْجُوجًا', #13
u'محجوجان': u'مَحْجُوجَانِ', #1
u'محجوجة': u'مَحْجُوجَةٌ', #1
u'محجوجون': u'مَحْجُوجُونَ', #8
u'محجوجين': u'مَحْجُوجِينَ', #2
u'محجوريتهما': u'مَحْجُورِيَّتَهما', #1
u'محجون': u'مَحْجُونِ', #1
u'محد': u'مُحِدٌّ', #8
u'محدة': u'مُحَدَّةٌ', #1
u'محدة': u'مُحِدَّةٍ', #2
u'محدة': u'مُحِدَّةٌ', #7
u'محدثى': u'مُحَدِّثِى', #3
u'محدجا': u'مُحَدَّجًا', #1
u'محدرة': u'مُحْدِرَةٌ', #1
u'محدقون': u'مُحَدّقُونَ', #1
u'محدقون': u'مُحْدِقُونَ', #5
u'محدوبا': u'مَحْدُوبًا', #1
u'محدوج': u'مَحْدُوجٌ', #1
u'محدوج': u'مَحْدُوجٍ', #3
u'محدودد': u'محدودد', #1
u'محدودكه': u'محدودكه', #1
u'محدودون': u'مَحْدُودُونَ', #41
u'محدوديا': u'مَحْدُودِيًّا', #2
u'محدور': u'مَحْدُورٌ', #1
u'محدور': u'مَحْدُورُ', #3
u'محذفة': u'مُحْذَفَةٌ', #1
u'محذوقة': u'مَحْذُوقَة', #1
u'محرب': u'مِحْرَبٌ', #1
u'محرب': u'مِحْرَبٍ', #1
u'محربة': u'مُحَرّبَةَ', #1
u'محرث': u'محرّث', #1
u'محرث': u'مُحرّث', #1
u'محرث': u'مَحْرَثٍ', #1
u'محرث': u'مُحَرّثٍ', #11
u'محرث': u'مُحَرّثِ', #3
u'محرثات': u'مُحْرَثَاتُ', #1
u'محرثات': u'مَحْرِثَاتٍ', #2
u'محرز': u'مُحَرَّزً', #1
u'محرس': u'مَحْرَسٍ', #1
u'محرس': u'مَحْرَسُ', #1
u'محرس': u'مَحْرَسِ', #1
u'محرس': u'مُحَرِّسٌ', #1
u'محرس': u'مُحْرَسٍ', #1
u'محرسا': u'مَحْرَسًا', #1
u'محرسا': u'مُحْرَسًا', #1
u'محرص': u'مُحْرِصٌ', #2
u'محرقSمن': u'مُحَرّقِSمِنْ', #1
u'محرم': u'مُحَرَّمً', #1
u'محرميته': u'مَحْرَمِيَّتِهِ', #2
u'محرميته': u'مَحْرَمِيَّتَهُ', #3
u'محرميته': u'مَحْرَمِيَّتُهُ', #9
u'محرميتها': u'مَحْرَمِيَّتَهَا', #1
u'محرميتها': u'مَحْرَمِيَّتُهَا', #1
u'محرميتها': u'مَحْرَمِيَّتِهَا', #2
u'محره': u'مَحْرِهِ', #1
u'محرهن': u'مَحْرُهُنَّ', #1
u'محروب': u'مَحْرُوبٌ', #1
u'محروب': u'مَحْرُوبِ', #1
u'محروبين': u'مَحْرُوبِينَ', #1
u'محروز': u'مَحْرُوزٌ', #1
u'محروز': u'مَحْرُوزٍ', #1
u'محروزا': u'مَحْرُوزًا', #2
u'محروزة': u'مَحْرُوزَةً', #1
u'محروزة': u'مَحْرُوزَةٌ', #1
u'محروص': u'مَحْرُوصٌ', #1
u'محزز': u'مُحَزَّزٌ', #1
u'محزز': u'مُحَزِّزٍ', #1
u'محزورا': u'مَحْزُورًا', #2
u'محزئل': u'مُحْزَئِلٌّ', #1
u'محسبة': u'مَحْسَبَةً', #1
u'محسر': u'محسر', #1
u'محسر': u'مَحْسَرٌ', #1
u'محسر': u'مُحَسَّرٍ', #1
u'محسر': u'مُحَسِّر', #1
u'محسر': u'مُحَسِّرَ', #1
u'محسر': u'مُحَسِّرِ', #1
u'محسر': u'مُحْسِرٍ', #1
u'محسر،': u'محسر،', #2
u'محسر': u'مُحَسِّرٍ', #222
u'محسر': u'مُحَسّرٍ', #5
u'محسر': u'مُحَسِّرٌ', #5
u'محسر،': u'مُحَسِّرٍ،', #6
u'محسرا': u'مُحْسِرًا', #1
u'محسرا': u'مُحْسِّرًا', #1
u'محسرا': u'مُحَسِّرًا', #35
u'محشرجه': u'محشرجه', #1
u'محشوش': u'محشوشَ', #1
u'محصدات': u'مُحْصَدَاتٌ', #1
u'محصدات': u'مُحْصِدَاتٌ', #1
u'محصر': u'مَحْصِرٌ', #1
u'محصر': u'مُحَصَّرٌ', #1
u'محصر': u'مُحْصِرٍ', #1
u'محصر': u'مُحْصَرٍ', #22
u'محصر': u'مُحْصَرٌ', #42
u'محصرا': u'مُحَصَّرًا', #1
u'محصرا': u'مُحْصِرًا', #1
u'محصرا': u'مُحْصَرًا', #68
u'محصرة': u'مُحْصَرَةً', #10
u'محصرة': u'مُحْصَرَةٌ', #16
u'محصرة': u'مُحْصَرَةٍ', #2
u'محصرين': u'مُحْصِرِينَ', #1
u'محصرين': u'مُحْصَرَيْنِ', #1
u'محصرين': u'مُحْصَرِينَ', #3
u'محصوات': u'مَحْصُوَّاتٍ', #1
u'محضأ': u'مِحْضَأ', #1
u'محضأ': u'مِحْضَأً', #2
u'محضراين': u'محضراين', #1
u'محضوض': u'مَحْضُوضٌ', #2
u'محظوريته': u'مَحْظُورِيَّتَهُ', #1
u'محفرا': u'مَحْفَرَا', #1
u'محفرا': u'مُحْفَرَا', #2
u'محفود': u'مَحْفُودٌ', #3
u'محفودا': u'مَحْفُودًا', #1
u'محفوظه': u'مَحْفُوظَهً', #1
u'محقبها': u'مُحْقِبَهَا', #1
u'محقبين': u'مُحْقِبِينَ', #2
u'محقف': u'مُحَقَّفٍ', #1
u'محققوا': u'مُحَقِّقُوا', #4
u'محقوقة': u'مَحْقُوقَةً', #2
u'محكان': u'مَحْكَانَ', #1
u'محكرة': u'محكرة', #2
u'محكل': u'محكل', #1
u'محكماقال': u'مُحْكَمًاقَالَ', #1
u'محكميته': u'مُحَكَّمِيَّتِهِ', #1
u'محكول،': u'مَحْكُولٍ،', #1
u'محلال': u'مِحْلَالٌ', #1
u'محلالا': u'مِحْلَالًا', #1
u'محلالا': u'مِحْلَالَا', #2
u'محلاوي': u'مَحَلَّاوِيٍّ', #3
u'محلبة': u'مَحْلَبَةٍ', #1
u'محلبة': u'مُحْلَبَة', #1
u'محمارا': u'مُحْمَارًّا', #2
u'محماق': u'مِحْمَاقٌ', #1
u'محمة': u'مُحَمَّةٌ', #1
u'محمدSالفهر': u'مُحَمّدٌSالْفِهْرُ', #1
u'محمد،': u'مُحَمَّدً،', #1
u'محمدالأسدي،': u'مُحَمَّدٍالأَسَدِيِّ،', #1
u'محمدأنه': u'مُحَمَّدٍأَنَّهُ', #1
u'محمدبن': u'مُحَمَّدِبْنِ', #1
u'محمدشفيع': u'مُحَمَّدٌشَفِيعُ', #1
u'محمدعبد': u'مُحَمَّدٍعَبْدُ', #1
u'محمدعن': u'مُحَمَّدِعن', #1
u'محمدوالوجه': u'مُحَمَّدٍوَالْوَجْهُ', #1
u'محمدوتكلم': u'مُحَمَّدُوَتَكَلَّمْ', #1
u'محمش': u'مَحْمِشٍ', #21
u'محمش': u'مَحْمَشٍ', #5
u'محمش': u'مَحْمِشُ', #5
u'محمودية': u'محمودية', #1
u'محمودية': u'مَحْمُودِيَّةٌ', #2
u'محمودية': u'مَحْمُودِيَّةً', #3
u'محمودية': u'مَحْمُودِيَّةٍ', #4
u'محموديته': u'مَحْمُودِيَّتِهِ', #2
u'محموق': u'مَحْمُوقٌ', #1
u'محموي': u'مَحْمُوِيٌ', #2
u'محمويه': u'مَحْمُويَهِ', #1
u'محمويه': u'مَحْمُويَهْ', #1
u'محمويه': u'مَحْمَوَيْهِ', #19
u'محمويه': u'مَحْمُوَيْهِ', #66
u'محنج': u'مُحْنَجٌ', #1
u'محنج': u'مُحْنَجِ', #1
u'محنج': u'مُحْنَجْ', #1
u'محنوذ': u'مَحْنُوذٌ', #1
u'محنوذ،': u'مَحْنُوذٍ،', #2
u'محنوذ': u'مَحْنُوذٍ', #8
u'محنوذا': u'مَحْنُوذًا', #3
u'محنوذة': u'مَحْنُوذَةً', #1
u'محوج': u'مَحُوجٌ', #1
u'محوج': u'مُحْوِجَ', #10
u'محوج': u'مُحْوِجٍ', #11
u'محوج': u'مُحْوِجٌ', #19
u'محوجا': u'مُحْوِجًا', #8
u'محوجة': u'مُحْوِجَةً', #1
u'محوقلا': u'مُحَوْقِلًا', #1
u'محومة': u'مُحَوَّمَةً', #1
u'محومون': u'مَحُومُونَ', #1
u'محووز': u'مَحْوُوزٌ', #3
u'محياة': u'مُحَيَّاةً', #1
u'محياة': u'مُحْيَاةٌ', #1
u'محياة': u'مُحْيَاةٍ', #1
u'محياة': u'مُحَيَّاةٍ', #3
u'محياة': u'مُحَيَّاةَ', #3
u'محياة': u'مُحْيَاةً', #4
u'محيرز': u'مُحَيْرِزٍ', #1
u'محيريز': u'مُحَيْريز', #1
u'محيريز': u'مُحَيْرِيزَ', #1
u'محيريز': u'مُحَيْرِيزٍ', #102
u'محيريز،': u'مُحَيْرِيزٍ،', #19
u'محيريز،': u'مُحَيْريز،', #2
u'محيريز،': u'محيريز،', #5
u'محيريز': u'محيريز', #7
u'محيصة': u'محيصة', #1
u'محيصة': u'مُحَيصة', #1
u'محيصة،': u'مُحَيصة،', #1
u'محيصة': u'مَحِيصَةُ', #1
u'محيصة': u'مُحَيّصَةَ', #12
u'محيصة': u'مُحَيِّصَة', #2
u'محيصة': u'مُحَيّصَة', #23
u'محيصة': u'مُحَيّصَةُ', #23
u'محيصة،': u'مُحَيِّصَةَ،', #3
u'محيصة،': u'مُحَيِّصَةُ،', #4
u'محيصة': u'مُحَيِّصَةَ', #53
u'محيصة': u'مُحَيِّصَةُ', #65
u'محيصن': u'مُحَيْصِنٍ', #19
u'محيصن،': u'مُحَيْصِنٍ،', #2
u'محيفة': u'مُحَيْفَةٌ', #1
u'محيق': u'مُحِيقُ', #1
u'محيمد': u'مُحَيْمَدٌ', #1
u'محيى': u'مُحْيِى', #1
u'مخابرون': u'مُخَابِرُونَ', #1
u'مخاتم': u'مَخَاتِمَ', #1
u'مخاتيم': u'مخاتيم', #1
u'مخاتيم': u'مَخَاتِيمِ', #4
u'مخاتيم': u'مَخَاتِيمَ', #91
u'مخادر': u'مَخَادِرَ', #1
u'مخارجة': u'مُخَارَجِةِ', #1
u'مخارجة': u'مُخَارَجَةٍ', #2
u'مخارجة': u'مُخَارَجَةَ', #2
u'مخارجة': u'مُخَارَجَةُ', #4
u'مخارجته': u'مُخَارَجَتَهُ', #1
u'مخارجته': u'مُخَارَجَتِهِ', #1
u'مخارجته': u'مُخَارَجَتُهُ', #9
u'مخارجين': u'مخارجين', #1
u'مخارق': u'مُخَارِقَ', #1
u'مخارق': u'مُخَارِقُ', #1
u'مخارق،': u'مُخَارِقٌ،', #1
u'مخارق،': u'مُخَارِقٍ،', #12
u'مخارق': u'مُخَارِقٌ', #3
u'مخارق': u'مُخَارِقِ', #4
u'مخارق': u'مُخَارِقٍ', #40
u'مخارقه': u'مَخَارِقَهُ', #1
u'مخارقه': u'مَخَارِقُهُ', #2
u'مخارقه': u'مَخَارِقِهِ', #3
u'مخارم': u'مَخَارِمَ', #1
u'مخارم': u'مَخَارِمِ', #2
u'مخاريق': u'مخاريق', #1
u'مخاريق': u'مَخَارِيقَ', #2
u'مخاريق': u'مَخَارِيقُ', #6
u'مخازين': u'مَخَازِينَ', #1
u'مخاشاة': u'مُخَاشَاةَ', #1
u'مخاشن': u'مُخَاشِنٍ', #4
u'مخاص': u'مَخَاصٍ', #3
u'مخاصرا': u'مُخَاصِرًا', #2
u'مخاصيب': u'مَخَاصِيبُ', #1
u'مخاضة': u'مخاضة', #1
u'مخاضة': u'مَخَاضَةَ', #1
u'مخاضة': u'مَخَاضَةً', #2
u'مخاضة': u'مَخَاضَةٍ', #4
u'مخاف': u'مُخَافٌ', #2
u'مخافتا': u'مُخَافِتًا', #1
u'مخالبة': u'مُخَالِبَةً', #1
u'مخالس': u'مُخَالِسِ', #2
u'مخالصا': u'مُخَالِصًا', #1
u'مخالع': u'مُخَالَعٌ', #1
u'مخالع': u'مُخَالِعُ', #1
u'مخالع': u'مُخَالَعٍ', #12
u'مخالع': u'مُخَالِعٍ', #2
u'مخالع': u'مُخَالِعٌ', #4
u'مخالعا': u'مُخَالَعًا', #1
u'مخالعها': u'مُخَالِعِهَا', #1
u'مخالقا': u'مُخَالِقًا', #1
u'مخالل': u'مُخَالِلٍ', #1
u'مخامر': u'مُخَامِرٍ', #1
u'مخامر': u'مُخَامِرِ', #1
u'مخامر': u'مُخَامِرٌ', #2
u'مخامرا': u'مُخَامِرًا', #6
u'مخامرها': u'مُخَامِرُهَا', #2
u'مخائل': u'مخائل', #2
u'مخائل': u'مَخَائِلُ', #4
u'مخائله': u'مَخَائِلِهِ', #1
u'مخبتا،': u'مُخْبتًا،', #1
u'مخبتا': u'مُخْبِتًا', #3
u'مخبتين': u'مُخْبِتِينَ', #1
u'مخبث': u'مُخْبِث', #1
u'مخبث': u'مُخْبِثٌ', #1
u'مخبث': u'مُخْبِثٍ', #5
u'مخبثا': u'مُخْبِثًا', #1
u'مخبل': u'مُخَبَّلٌ', #1
u'مخبلا': u'مُخْبَلًا', #1
u'مخبلا': u'مُخَبَّلًا', #4
u'مخبورة': u'مَخْبُورَةً', #1
u'مخبى': u'مُخَبَّى', #1
u'مخبيا': u'مُخْبِيًا', #1
u'مختال': u'مُخْتَالٌ', #11
u'مختال': u'مُخْتَالٍ', #26
u'مختالا': u'مُخْتَالاً', #1
u'مختالا،': u'مُخْتَالا،', #1
u'مختالا': u'مُخْتَالا', #4
u'مختالا': u'مُخْتَالًا', #9
u'مختانا': u'مُخْتَانًا', #1
u'مختبط': u'مُخْتَبَطٌ', #1
u'مختبط': u'مُخْتَبَطٍ', #1
u'مختبط': u'مُخْتَبِطٍ', #2
u'مختبلا': u'مُخْتَبَلًا', #2
u'مختتن': u'مُخْتَتَنٍ', #1
u'مختتن': u'مُخْتَتِنٍ', #2
u'مختتنين': u'مُخْتَتَنِينَ', #3
u'مختدعا': u'مُخْتَدَعًا', #1
u'مخترجة،': u'مُخْتَرِجَةً،', #1
u'مخترمة': u'مُخْتَرِمَةٍ', #1
u'مختشع': u'مُخْتَشِعٍ', #1
u'مختضبا': u'مُخْتَضِبًا', #1
u'مختضبة': u'مُخْتَضِبَةً', #4
u'مختطمة': u'مُخْتَطَمَةٌ', #1
u'مختطمة': u'مُخْتَطِمَةٌ', #1
u'مختلج': u'مُخْتَلِجٍ', #1
u'مختلعة': u'مُخْتَلِعَةً', #16
u'مختلعة': u'مُخْتَلِعَةٌ', #5
u'مختلعة': u'مُخْتَلِعَةٍ', #7
u'مختلعته': u'مُخْتَلِعَتَهُ', #1
u'مختلعته': u'مُخْتَلِعَتِهِ', #4
u'مختلعه': u'مُخْتَلِعُهُ', #1
u'مختمة': u'مُخْتَمَةٌ', #1
u'مختمة': u'مُخْتَمَةٍ', #2
u'مختنا': u'مُخْتَنًا', #1
u'مختنين': u'مُخْتَنِينَ', #1
u'مختير': u'مُخْتَيَرٌ', #1
u'مختير': u'مُخْتِيرٌ', #3
u'مخثاني': u'مَخْثَانِيٌّ', #1
u'مخثرمة': u'مُخَثْرَمَةً', #1
u'مخجيا': u'مُخْجِيًا', #1
u'مخدا': u'مِخَدًّا', #8
u'مخدج': u'مُخْدَجٍ', #1
u'مخدج': u'مُخْدَجَ', #1
u'مخدج': u'مُخْدِجٍ', #1
u'مخدج': u'مُخْدَج', #2
u'مخدج': u'مُخْدَجُ', #21
u'مخدج': u'مُخْدَجٌ', #6
u'مخدجة': u'مُخْدَجَةٍ', #1
u'مخدجة': u'مُخْدِجَةً', #1
u'مخدجته': u'مُخْدَجَتِهِ', #1
u'مخدلا': u'مُخَدِّلًا', #1
u'مخدورة': u'مَخْدُورَةٌ', #1
u'مخدوش': u'مَخْدُوشٍ', #1
u'مخدوش،': u'مَخْدُوشٌ،', #1
u'مخدوش': u'مَخْدُوشٌ', #6
u'مخدوشا': u'مَخْدُوشًا', #1
u'مخذل': u'مُخَذِّلٌ', #1
u'مخذل': u'مُخْذِلٍ', #1
u'مخذل': u'مُخَذِّلٍ', #11
u'مخذلا': u'مُخْذِلًا', #3
u'مخذلا': u'مُخَذِّلًا', #5
u'مخذلة': u'مَخْذَلَةٌ', #1
u'مخذوف': u'مَخْذُوفٍ', #2
u'مخذولSشعر': u'مَخْذُولُSشِعْرِ', #1
u'مخذوما': u'مَخْذُومًا', #1
u'مخراق': u'مِخْرَاقِ', #1
u'مخراق،': u'مِخْرَاقٍ،', #1
u'مخراق': u'مِخْرَاقٍ', #24
u'مخراق': u'مِخْرَاقٌ', #5
u'مخرجوي': u'مُخْرِجُويَ', #1
u'مخرجوي': u'مُخْرِجُوِيَ', #1
u'مخرش،': u'مخرش،', #1
u'مخرش': u'مُخَرِّشٍ', #1
u'مخرش': u'مِخْرَشٌ', #2
u'مخرش': u'مُخَرِّشٌ', #4
u'مخرف': u'مَخْرَفٌ', #1
u'مخرف': u'مُخْرَفٌ', #1
u'مخرفا': u'مَخْرِفًا', #1
u'مخرفا': u'مُخَرِّفًا', #1
u'مخرفا،': u'مَخْرَفًا،', #1
u'مخرفا': u'مَخْرَفًا', #16
u'مخرفة': u'مُخْرَفَةِ', #1
u'مخرفة': u'مَخْرَفَةِ', #12
u'مخرق': u'مخرق', #1
u'مخرق': u'مُخْرِقٌ', #1
u'مخرق': u'مُخَرَّقَ', #2
u'مخرق': u'مُخَرَّقٌ', #6
u'مخرق': u'مُخَرَّقٍ', #8
u'مخرقا': u'مَخْرَقًا', #1
u'مخرقا': u'مُخَرَّقًا', #11
u'مخرقة': u'مُخَرَّقَةً', #1
u'مخرقة': u'مُخَرَّقَةٌ', #1
u'مخرقتين': u'مُخْرَقَتَيْنِ', #1
u'مخرقه': u'مُخْرِقُهُ', #1
u'مخرقين': u'مُخَرَّقَيْنِ', #2
u'مخرمة': u'مَخْرَمة', #1
u'مخرمة،': u'مَخْرَمَة،', #1
u'مخرمة،': u'مخرمة،', #10
u'مخرمة': u'مخرمة', #13
u'مخرمة': u'مَخْرَمَةُ', #137
u'مخرمة': u'مَخْرَمَةَ', #397
u'مخرمة،': u'مَخْرَمَةُ،', #4
u'مخرمة،': u'مَخْرَمَةَ،', #43
u'مخرمة': u'مَخْرَمَة', #6
u'مخرورا': u'مَخْرُورًا', #1
u'مخروز': u'مَخْرُوزٍ', #2
u'مخروز': u'مَخْرُوزٌ', #5
u'مخروزا': u'مَخْرُوزًا', #5
u'مخروزة': u'مَخْرُوزَةً', #1
u'مخروزة': u'مَخْرُوزَةٌ', #2
u'مخروزة': u'مَخْرُوزَةٍ', #4
u'مخروص': u'مَخْرُوصٍ', #2
u'مخروصا': u'مَخْرُوصًا', #1
u'مخروصها': u'مَخْرُوصُهَا', #1
u'مخروصها': u'مَخْرُوصِهَا', #4
u'مخرئ': u'مُخْرِئٌ', #7
u'مخزة': u'مَخَزَّةٌ', #1
u'مخزوع': u'مَخْزُوعٍ', #1
u'مخزومى': u'مَخْزُومِىٌّ', #1
u'مخزومية': u'مَخْزُومِيَّةً', #5
u'مخسب': u'مخسب', #1
u'مخسوفا': u'مَخْسُوفًا', #1
u'مخسوفين': u'مَخْسُوفَيْنِ', #1
u'مخشى': u'مَخْشَى', #1
u'مخشى': u'مُخَشَّى', #1
u'مخشى': u'مَخْشِىٍّ', #2
u'مخصوف': u'مَخْصُوفٍ', #1
u'مخصوفة': u'مَخْصُوفَةً', #3
u'مخصوفتين': u'مَخْصُوفَتَيْنِ', #4
u'مخصوفين': u'مَخْصُوفِينَ', #1
u'مخصوفين': u'مَخْصُوفَيْنِ', #2
u'مخصوم': u'مَخْصُومٍ', #3
u'مخصوما': u'مَخْصُومًا', #4
u'مخصومة': u'مَخْصُومَةً', #1
u'مخضخض': u'مُخَضْخِضُ', #1
u'مخضوب': u'مخضوب', #1
u'مخضوب': u'مَخْضُوبِ', #1
u'مخضوب': u'مَخْضُوبٍ', #3
u'مخضوب': u'مَخْضُوبَ', #3
u'مخضوب': u'مَخْضُوبٌ', #7
u'مخضوبا': u'مَخْضُوبًا', #11
u'مخضوبة': u'مَخْضُوبَةَ', #1
u'مخضوبة': u'مَخْضُوبَةً', #4
u'مخضوبتين': u'مَخْضُوبَتَيْنِ', #3
u'مخضوبين': u'مَخْضُوبُينَ', #1
u'مخضود': u'مَخْضُودٍ', #2
u'مخطرا': u'مُخْطَرًا', #2
u'مخطرة': u'مُخَطَّرَةٍ', #1
u'مخطرة': u'مُخْطِرَةٌ', #1
u'مخطرة': u'مُخْطِرَةٍ', #6
u'مخطمات': u'مُخَطّمَاتٍ', #2
u'مخطوم': u'مَخْطُومُ', #3
u'مخطوم': u'مَخْطُومٍ', #6
u'مخطومة': u'مخطومةٍ', #1
u'مخطومة': u'مَخْطُومَةً', #1
u'مخطومة،': u'مَخْطُومَةٍ،', #1
u'مخطومة': u'مَخْطُومَةٌ', #3
u'مخطومة': u'مَخْطُومَةٍ', #9
u'مخفوض': u'مَخْفُوض', #1
u'مخفوض': u'مَخْفُوضٍ', #2
u'مخفوض': u'مَخْفُوضٌ', #21
u'مخفوضا': u'مَخْفُوضًا', #9
u'مخفوضة': u'مَخْفُوضَةً', #4
u'مخفوضة': u'مَخْفُوضَةٌ', #4
u'مخفوضة': u'مَخْفُوضَةٍ', #4
u'مخفوقا': u'مَخْفُوقًا', #1
u'مخلابه': u'مِخْلَابَهُ', #1
u'مخلاق': u'مِخْلَاقٍ', #1
u'مخلبط': u'مُخَلْبَطٌ', #1
u'مخلج': u'مُخْلَجِ', #1
u'مخلج': u'مُخْلَجْ', #1
u'مخلس': u'مُخْلِسٌ', #1
u'مخلفى': u'مخلفى', #1
u'مخلول': u'مَخْلُولٍ', #2
u'مخلولا': u'مَخْلُولًا', #2
u'مخلى': u'مُخَلَّى', #2
u'مخلى': u'مُخْلًى', #2
u'مخلى': u'مُخَلًّى', #5
u'مخماص': u'مِخْمَاصِ', #2
u'مخمصة': u'مخمصة', #1
u'مخمصة': u'مَخْمَصَة', #1
u'مخمصة،': u'مَخْمَصَةٌ،', #2
u'مخمصة': u'مَخْمَصَةٍ', #23
u'مخمصة': u'مَخْمَصَةٌ', #41
u'مخمصتها': u'مَخْمَصَتَهَا', #1
u'مخموس': u'مَخْمُوسٌ', #2
u'مخموس': u'مَخْمُوسٍ', #6
u'مخموسا': u'مَخْمُوسًا', #2
u'مخموسة': u'مَخْمُوسَةٍ', #1
u'مخموم': u'مَخْمُوم', #1
u'مخموم': u'مَخْمُومُ', #1
u'مخندا': u'مخندا', #1
u'مخنف،': u'مخنف،', #1
u'مخنف': u'مِخْنَفَ', #1
u'مخنف': u'مِخْنَفِ', #10
u'مخنف': u'مِخْنَفٍ', #18
u'مخنف': u'مخنف', #2
u'مخنف': u'مِخْنَفُ', #3
u'مخنف،': u'مِخْنَفٍ،', #4
u'مخنونا': u'مَخْنُونًا', #1
u'مخوص': u'مُخَوّصٍ', #1
u'مخوص': u'مُخَوّصٌ', #2
u'مخوص': u'مُخَوَّصٌ', #2
u'مخوصا': u'مَخُوصًا', #1
u'مخوصا': u'مُخَوَّصًا', #3
u'مخيريق،': u'مُخَيْرِيقٌ،', #1
u'مخيريق': u'مُخَيْرِيقٌ', #10
u'مخيريق': u'مُخَيْرِيقٍ', #15
u'مخيريق': u'مُخَيْرِيق', #2
u'مخيريق': u'مُخَيْرِيقُ', #2
u'مخيريقا': u'مُخَيْرِيقًا', #1
u'مخيس': u'مُخَيَّسٌ', #1
u'مخيس': u'مُخَيَّسُ', #1
u'مخيس': u'مُخَيِّسٌ', #1
u'مخيس': u'مُخَيِّسَ', #1
u'مخيس': u'مُخَيِّسِ', #1
u'مخيسا': u'مُخَيِّسًا', #1
u'مخيسا': u'مُخَيِّسَا', #1
u'مخيسا': u'مَخِيسًا', #3
u'مخيسا': u'مُخَيَّسَا', #5
u'مخيسا': u'مُخَيَّسًا', #7
u'مخيسة': u'مَخِيسَة', #1
u'مخيسة': u'مُخَيّسَةٌ', #2
u'مخيسة': u'مُخَيّسَةً', #3
u'مخيفوا': u'مُخِيفُوا', #2
u'مخيلصات': u'مُخَيْلِصَاتٍ', #1
u'مخيمرة،': u'مُخَيْمَرة،', #1
u'مخيمرة،': u'مُخَيْمرَةَ،', #1
u'مخيمرة': u'مُخَيْمِرَة', #1
u'مخيمرة،': u'مُخَيْمَرَةَ،', #1
u'مخيمرة،': u'مُخَيْمِرَةَ،', #12
u'مخيمرة': u'مخيمرة', #3
u'مخيمرة،': u'مخيمرة،', #3
u'مخيمرة': u'مُخَيْمِرَةَ', #58
u'مداخلا': u'مُدَاخِلًا', #1
u'مداخلون': u'مُدَاخِلُونَ', #1
u'مداخلين': u'مُدَاخَلِينَ', #1
u'مدادة': u'مِدَادَةٍ', #1
u'مدارأة': u'مُدَارَأَةٌ', #2
u'مدارعة': u'مُدَارَعَةً', #1
u'مدارى': u'مُدَارَى', #1
u'مداش': u'مَدَاشٍ', #2
u'مداعي': u'مَدَاعِي', #2
u'مداعيين': u'مُدَّاعِيَيْنِ', #2
u'مداكا': u'مَدَاكًا', #1
u'مدانق': u'مَدَانِقَ', #1
u'مدانيا': u'مُدَانِيًا', #1
u'مدانيا': u'مُدَانِيَا', #2
u'مداودها': u'مَدَاوِدِهَا', #1
u'مداوى': u'مُدَاوًى', #1
u'مدائده': u'مَدَائِدُهُ', #1
u'مداين': u'مَدَايِنُ', #1
u'مداين': u'مُدَايَن', #1
u'مداينهم': u'مُدَايَنهمْ', #1
u'مدب': u'مَدَبُّ', #1
u'مدب': u'مُدِبّ', #2
u'مدبغا': u'مَدْبَغًا', #1
u'مدحاة': u'مِدْحَاةٌ', #1
u'مدحج': u'مَدْحِجٍ', #2
u'مدخلى': u'مَدْخَلِى', #1
u'مدخليته': u'مَدْخَلِيَّتُهُ', #1
u'مدخليته': u'مَدْخَلِيَّتِهِ', #1
u'مددتنى': u'مَدَدْتَنِى', #1
u'مددى': u'مَدَدِىٌّ', #2
u'مدراسها': u'مِدْرَاسُهَا', #1
u'مدراسهم،': u'مِدْراسهم،', #1
u'مدراسهم': u'مِدْرَاسِهِمُ', #1
u'مدراسهم': u'مِدْرَاسِهِمْ', #2
u'مدرناه': u'مَدَرْنَاهُ', #1
u'مدرها': u'مِدْرَهًا', #2
u'مدرهنا': u'مِدْرَهُنَا', #2
u'مدروء': u'مَدْرُوءٌ', #1
u'مدرى': u'مِدْرَى', #1
u'مدرى': u'مِدْرًى', #11
u'مدسورا': u'مَدْسُورَا', #2
u'مدعا': u'مدعا', #1
u'مدعا': u'مَدْعًا', #1
u'مدعات': u'مُدَّعَاتٌ', #1
u'مدعس': u'مِدْعَسُ', #2
u'مدعيست': u'مدعيست', #2
u'مدفوق': u'مَدْفُوقُ', #1
u'مدفوق': u'مَدْفُوقٌ', #3
u'مدفوق': u'مَدْفُوقٍ', #5
u'مدقاق': u'مِدْقَاقَ', #1
u'مدكر': u'مُدَّكِرٍ', #21
u'مدكور': u'مَدْكُورٍ', #1
u'مدلاج': u'مِدْلَاجٌ', #1
u'مدلاج': u'مِدْلَاجُ', #3
u'مدلجيا': u'مُدْلِجِيَّا', #1
u'مدلجيا': u'مُدْلِجِيًّا', #7
u'مدلما': u'مُدْلِمًا', #1
u'مدلوكا': u'مَدْلُوكًا', #1
u'مدما': u'مُدَمًّا', #1
u'مدماكا': u'مِدْمَاكًا', #1
u'مدماكين': u'مِدْمَاكَيْنِ', #3
u'مدمومة': u'مَدْمُومَةٌ', #1
u'مدنة': u'مَدْنَةِ', #1
u'مدنف': u'مُدْنِفٍ', #3
u'مدنف': u'مُدْنِفٌ', #4
u'مدنفا': u'مُدْنَفًا', #2
u'مدنفا': u'مُدْنِفًا', #6
u'مدنفة': u'مُدْنَفَةً', #1
u'مدنى': u'مَدَنِىُّ', #1
u'مدنى': u'مَدَنِىٌّ', #5
u'مدهامتان': u'مُدْهَامّتَانِ', #2
u'مدهامتان': u'مُدْهَامَّتَانِ', #28
u'مدهان': u'مُدْهَانُّ', #1
u'مدوفا': u'مَدُوفَا', #3
u'مديانة': u'مِدْيَانَةٍ', #1
u'مدينى': u'مَدِينِىٌّ', #1
u'مذءوما': u'مَذْءُومًا', #11
u'مذاء': u'مَذَّاءٌ', #1
u'مذاء': u'مِذَاءً', #1
u'مذاء': u'مَذَّاء', #2
u'مذاء،': u'مَذَّاءً،', #2
u'مذاء': u'مَذَّاءً', #35
u'مذارعة': u'مُذَارَعَةٍ', #1
u'مذارعة': u'مُذَارَعَةً', #42
u'مذاكر': u'مُذَاكِرٍ', #1
u'مذاكرك': u'مَذَاكِرِكَ', #1
u'مذاكي': u'مَذَاكِي', #1
u'مذال': u'مُذَالِ', #1
u'مذام': u'مَذَامَّ', #1
u'مذامها': u'مَذَامِّهَا', #1
u'مذانب': u'مَذَانِبَ', #3
u'مذاويد': u'مَذَاوِيدُ', #2
u'مذبب': u'مُذَبّبٍ', #4
u'مذبة': u'مَذَبَّةٌ', #1
u'مذبة': u'مُذِبَّةٌ', #1
u'مذبة': u'مِذَبَّةٌ', #3
u'مذبل': u'مُذَبَّلِ', #1
u'مذجج': u'مَذْجِجَ', #1
u'مذحج': u'مَذْحجُ', #1
u'مذحج': u'مُذْحِجٍ', #1
u'مذحج': u'مُذْحِجَ', #1
u'مذحج': u'مُذْحِجُ', #1
u'مذحج': u'مُذْحِجِ', #1
u'مذحج': u'مَذْحِجٍ', #18
u'مذحج': u'مَذْحِجٌ', #2
u'مذحج': u'مُذْحَجٍ', #2
u'مذحج': u'مَذْحِجِ', #3
u'مذحج': u'مَذْحِجَ', #36
u'مذحج': u'مَذْحِج', #4
u'مذحج': u'مذحج', #5
u'مذحج': u'مَذْحِجُ', #5
u'مذحجا': u'مَذْحِجًا', #1
u'مذحجا': u'مُذْحِجًا', #1
u'مذحجان': u'مُذْحِجَانِ', #1
u'مذحجيان': u'مَذْحِجِيَّانِ', #1
u'مذخور': u'مَذْخُورٍ', #1
u'مذخور': u'مَذْخُورٌ', #2
u'مذخورا': u'مَذْخُورًا', #4
u'مذخورة': u'مَذْخُورَةً', #1
u'مذخورة': u'مَذْخُورَةٍ', #2
u'مذربة': u'مُذَرّبَةٍ', #2
u'مذرع': u'مُذَرَّعٌ', #1
u'مذرعا': u'مُذَرَّعًا', #1
u'مذرعة': u'مُذْرَعَةٌ', #1
u'مذروع': u'مَذْرُوعِ', #2
u'مذروع': u'مَذْرُوعٍ', #20
u'مذروع': u'مَذْرُوعٌ', #4
u'مذروعا': u'مَذْرُوعًا', #17
u'مذروعات': u'مَذْرُوعَاتٍ', #1
u'مذروعة': u'مَذْرُوعَةً', #1
u'مذروعة': u'مَذْرُوعَةٍ', #1
u'مذروف': u'مذْرُوفُ', #1
u'مذروف': u'مَذْرُوفٌ', #1
u'مذعرة': u'مَذْعَرَةٌ', #1
u'مذعرة': u'مُذْعِرَةٌ', #1
u'مذفف': u'مُذَفَّفٌ', #1
u'مذفف': u'مُذَفِّفَ', #1
u'مذفف': u'مُذَفِّفٌ', #11
u'مذفف': u'مُذَفِّفٍ', #31
u'مذفف': u'مُذَفَّفٍ', #6
u'مذففا': u'مُذَفِّفًا', #28
u'مذففا': u'مُذَفَّفًا', #4
u'مذففان': u'مُذَفِّفَانِ', #16
u'مذففة': u'مُذَفَّفَةً', #1
u'مذففة': u'مُذَفَّفَةٍ', #1
u'مذففة': u'مُذَفَّفَةٌ', #2
u'مذففة': u'مُذَفِّفَةً', #2
u'مذففة': u'مُذَفِّفَةٌ', #7
u'مذففه': u'مُذَفِّفِهِ', #1
u'مذففين': u'مُذَفِّفَيْنِ', #8
u'مذكا': u'مُذَكًّا', #2
u'مذكاة': u'مُذَكَّاة', #1
u'مذكاة': u'مُذْكَاةٌ', #1
u'مذكاة': u'مُذَكَّاةٌ', #14
u'مذكاة': u'مُذَكَّاةِ', #2
u'مذكاة': u'مُذَكَّاةً', #23
u'مذكاة': u'مُذَكَّاةٍ', #45
u'مذكاه': u'مُذَكَّاهُ', #2
u'مذكاها': u'مُذَكَّاهَا', #5
u'مذكاهم': u'مُذَكَّاهُمْ', #3
u'مذكى': u'مُذْكَى', #1
u'مذكى': u'مُذَكًّى', #125
u'مذكى': u'مُذَكَّى', #23
u'مذلج': u'مَذْلِجَ', #1
u'مذمومية': u'مَذْمُومِيَّةُ', #1
u'مذمومية': u'مَذْمُومِيَّةِ', #2
u'مذمومية': u'مَذْمُومِيَّةَ', #3
u'مذموميته': u'مَذْمُومِيَّتُهُ', #1
u'مذموميته': u'مَذْمُومِيَّتِهِ', #4
u'مذه': u'مَذِّهِ', #1
u'مذهبمالك': u'مَذْهَبَمَالِكٍ', #1
u'مذواق': u'مِذْوَاقٍ', #1
u'مذي': u'مَذْيُ', #1
u'مذي': u'مَذْيٌ', #127
u'مذى': u'مَذَى', #16
u'مذي': u'مَذْيِ', #3
u'مذي': u'مَذْيَ', #4
u'مذي': u'مَذْيٍ', #74
u'مذيا': u'مَذْيًا', #72
u'مذيت': u'مَذَيْتُ', #1
u'مذيه': u'مَذْيُهُ', #1
u'مذيها': u'مَذْيِهَا', #5
u'مرءوس': u'مَرْءُوسٍ', #2
u'مرءون': u'مَرْءُونُ', #1
u'مرءون': u'مُرْءُونَ', #1
u'مراءون': u'مُرَاءُونَ', #3
u'مرااز': u'مرااز', #1
u'مراازين': u'مراازين', #1
u'مرابا': u'مُرَابًا', #3
u'مراباشيدي': u'مراباشيدي', #1
u'مراباين': u'مراباين', #2
u'مرابتوجيزى': u'مرابتوجيزى', #1
u'مرابتوسبردنى': u'مرابتوسبردنى', #1
u'مرابحل': u'مرابحل', #2
u'مرابخش': u'مرابخش', #1
u'مرابدين': u'مرابدين', #1
u'مرابر': u'مرابر', #2
u'مرابصين': u'مرابصين', #1
u'مرابكا': u'مرابكا', #1
u'مرابوده': u'مرابوده', #1
u'مرابيخش': u'مرابيخش', #1
u'مرابيكناه': u'مرابيكناه', #1
u'مراة': u'مِرَاةُ', #1
u'مرأة': u'مَرْأَةً', #13
u'مراتSسرية': u'مَرّاتٍSسَرِيّةُ', #1
u'مراتا': u'مراتا', #1
u'مراتازيان': u'مراتازيان', #1
u'مراثد': u'مَرَاثِدَ', #2
u'مراثل': u'مَرَاثِلَ', #1
u'مراجرا': u'مراجرا', #1
u'مراجزسه': u'مراجزسه', #1
u'مراجعتهنإياه': u'مُرَاجَعَتِهِنَّإِيَّاهُ', #1
u'مراجندان': u'مراجندان', #1
u'مراجنك': u'مراجنك', #1
u'مراجه': u'مراجه', #2
u'مراحات،': u'مَرَاحَاتٌ،', #1
u'مراحان': u'مَرَاحَانِ', #1
u'مراحب': u'مَرَاحِبِ', #2
u'مراحين': u'مُرَاحِينَ', #1
u'مراحين': u'مَرَاحَيْنِ', #1
u'مراخبر': u'مراخبر', #1
u'مراخوش': u'مراخوش', #1
u'مرادادي': u'مرادادي', #1
u'مرادل': u'مرادل', #2
u'مرادون': u'مُرَادُونَ', #2
u'مراربة': u'مَرَاربةً', #1
u'مراروزهاي': u'مراروزهاي', #2
u'مراروزى': u'مراروزى', #1
u'مرازب': u'مَرَازِبُ', #1
u'مرازبة': u'مَرَازِبَةً', #1
u'مرازبة': u'مَرَازِبَةٍ', #1
u'مرازبته': u'مَرَازِبَتِهِ', #2
u'مرازبته': u'مَرَازِبَتَهُ', #4
u'مرازبها': u'مَرَازِبُهَا', #2
u'مرازتو': u'مرازتو', #1
u'مرازمان': u'مرازمان', #1
u'مرازيب': u'مَرَازِيبَ', #1
u'مراست': u'مراست', #1
u'مراسراز': u'مراسراز', #1
u'مراسو': u'مراسو', #1
u'مراسوكند': u'مراسوكند', #3
u'مراسيس': u'مراسيس', #1
u'مراشد': u'مَرَاشِدِ', #1
u'مراشده': u'مَرَاشِدِهِ', #1
u'مراصة': u'مراصة', #1
u'مراضايع': u'مراضايع', #1
u'مراطلة': u'مُرَاطَلَةِ', #2
u'مراطلة': u'مُرَاطَلَةً', #22
u'مراطلة': u'مُرَاطَلَةُ', #28
u'مراطلة': u'مُرَاطَلَةٌ', #5
u'مراطلة': u'مُرَاطَلَةَ', #5
u'مراطلة': u'مُرَاطَلَةٍ', #6
u'مراطلته': u'مُرَاطَلَتُهُ', #1
u'مراعا': u'مُرَاعًا', #5
u'مراعات': u'مُرَاعَاتِ', #2
u'مراعاه': u'مُرَاعَاهُ', #1
u'مراعتها': u'مُرَاعَتُهَا', #1
u'مراعتهما': u'مُرَاعَتُهُمَا', #1
u'مراعى': u'مُرَاعًى', #185
u'مراعى': u'مُرَاعَى', #9
u'مراغ': u'مَرَاغِ', #1
u'مراغا': u'مَرَاغًا', #1
u'مراغما': u'مُرَاغَمًا', #17
u'مراغما': u'مُرَاغِمًا', #33
u'مراغما': u'مُرَاغَماً', #7
u'مراغمة': u'مُرَاغَمَةٍ', #1
u'مراغمة': u'مُرَاغَمَةُ', #1
u'مراغمة': u'مُرَاغِمَةٍ', #1
u'مراغمة': u'مُرَاغَمَةِ', #10
u'مراغمة': u'مُرَاغَمَةً', #4
u'مراغمة': u'مُرَاغِمَةً', #5
u'مراغمة': u'مُرَاغَمَةَ', #7
u'مراغمة': u'مُرَاغَمَةٌ', #8
u'مراغمين': u'مراغمين', #1
u'مراغمين': u'مُرَاغِمِينَ', #4
u'مراغمين': u'مُرَاغِمَيْنِ', #4
u'مرافعت': u'مرافعت', #1
u'مراقة': u'مُرَاقَةً', #4
u'مراكنة': u'مُرَاكَنَةِ', #1
u'مرامر': u'مرامر', #1
u'مرامر': u'مُرَامِرُ', #2
u'مرامى': u'مرامى', #1
u'مرانة': u'مِرَانَةَ', #1
u'مرانداده': u'مرانداده', #1
u'مرآنر': u'مرآنر', #1
u'مرآنرا': u'مرآنرا', #1
u'مرانشا': u'مرانشا', #2
u'مرانماز': u'مرانماز', #1
u'مرانمي': u'مرانمي', #1
u'مرانيزازتو': u'مرانيزازتو', #1
u'مراهيج': u'مراهيج', #1
u'مراوزة': u'مَرَاوِزَةٌ', #1
u'مراوضة': u'مُرَاوَضَة', #1
u'مراوضة': u'مُرَاوَضَةٌ', #1
u'مراوضة': u'مُرَاوَضَةٍ', #5
u'مرائى؟': u'مُرَائِى؟', #1
u'مرائى': u'مُرَائِى', #2
u'مراياد': u'مراياد', #1
u'مراية': u'مِرَايَةَ', #4
u'مراين': u'مراين', #11
u'مراينج': u'مراينج', #1
u'مراينخانه': u'مراينخانه', #1
u'مرباب': u'مِرْبَابِ', #3
u'مربادا': u'مُرْبَادًّا', #4
u'مربدى': u'مِرْبَدِى', #1
u'مربر': u'مربر', #1
u'مربسرويرا': u'مربسرويرا', #1
u'مربوب': u'مَرْبُوبَ', #1
u'مربوب': u'مَرْبُوبٌ', #3
u'مربوب': u'مَرْبُوبٍ', #5
u'مربوبا': u'مَرْبُوبًا', #3
u'مربوبة': u'مَرْبُوبَة', #1
u'مربوبة': u'مَرْبُوبَةً', #1
u'مربوبة': u'مَرْبُوبَةٍ', #2
u'مربوعة': u'مَرْبُوعَةُ', #2
u'مربئد': u'مُرْبَئِدّ', #1
u'مرةالأشجعي': u'مُرَّةَالْأَشْجَعِيَّ', #1
u'مرةوالوجه': u'مَرَّةٍوَالْوَجْهُ', #1
u'مرتاض': u'مُرْتَاضٌ', #1
u'مرتاضا': u'مُرْتَاضًا', #1
u'مرتاضي': u'مُرْتَاضِي', #1
u'مرتتقا': u'مُرْتَتِقًا', #1
u'مرتث': u'مُرْتَثٌّ', #10
u'مرتثا': u'مُرْتَثّا', #1
u'مرتثا': u'مُرْتَثًّا', #39
u'مرتجز': u'مُرْتَجِزٍ', #1
u'مرتجزا': u'مُرْتَجِزًا', #1
u'مرتدف': u'مُرْتَدِفٌ', #1
u'مرتدفان': u'مُرْتَدِفَانِ', #5
u'مرتدفين': u'مُرْتَدِفَيْنِ', #2
u'مرتضاه': u'مُرْتَضَاهُ', #1
u'مرتضع': u'مُرْتَضِعِ', #1
u'مرتضع': u'مُرْتَضِعٍ', #23
u'مرتضع': u'مُرْتَضِعٌ', #4
u'مرتضعا': u'مُرْتَضِعًا', #3
u'مرتضعة': u'مُرْتَضِعَةٍ', #2
u'مرتضعه': u'مُرْتَضِعُهُ', #1
u'مرتضعيها': u'مُرْتَضِعَيْهَا', #1
u'مرتضى': u'مُرْتَضًى', #6
u'مرتفق': u'مُرْتَفَقٍ', #1
u'مرتفق': u'مُرْتَفَقَ', #1
u'مرتفق': u'مُرْتَفَقُ', #1
u'مرتفق': u'مُرْتَفِقٍ', #1
u'مرتفق': u'مُرْتَفَقٌ', #2
u'مرتفق': u'مُرْتَفِقٌ', #4
u'مرتفقا': u'مُرْتَفِقًا', #5
u'مرتفقا': u'مُرْتَفَقًا', #6
u'مرتفقة': u'مُرْتَفِقَةً', #1
u'مرتفقها': u'مُرْتَفَقِهَا', #1
u'مرتفقون': u'مرتفقون', #1
u'مرتين': u'مَرَّتَيْنًًًًِ', #1
u'مرثد،': u'مرثد،', #1
u'مرثد': u'مَرْثد', #1
u'مرثد': u'مَرثَد', #1
u'مرثد،': u'مَرْثدٍ،', #1
u'مرثد': u'مِرْثَدَ', #1
u'مرثد': u'مِرْثَدِ', #1
u'مرثد،': u'مَرْثَدَ،', #1
u'مرثد؟': u'مَرْثَدٌ؟', #1
u'مرثد': u'مَرْثَدٍ', #249
u'مرثد،': u'مَرْثَد،', #3
u'مرثد،': u'مَرْثَدٌ،', #3
u'مرثد': u'مَرْثَدٌ', #30
u'مرثد': u'مَرْثَدُ', #36
u'مرثد': u'مَرْثَد', #4
u'مرثد': u'مَرْثَدَ', #7
u'مرثد': u'مَرْثَدِ', #78
u'مرثد': u'مرثد', #8
u'مرثد،': u'مَرْثَدٍ،', #81
u'مرثدا': u'مَرْثَدًا', #1
u'مرثمة': u'مَرْثَمَةَ', #1
u'مرجأ': u'مُرْجَأً', #1
u'مرجأ؟': u'مُرْجَأً؟', #1
u'مرجأ': u'مُرْجَأٌ', #5
u'مرجزا': u'مُرَجَّزًا', #1
u'مرجوبي': u'مَرْجُوبَيْ', #1
u'مرجوحية': u'مَرْجُوحِيَّةٌ', #1
u'مرجوحية': u'مَرْجُوحِيَّةُ', #1
u'مرجوحية': u'مَرْجُوحِيَّةَ', #3
u'مرجوحية': u'مَرْجُوحِيَّةٍ', #6
u'مرجوحية': u'مَرْجُوحِيَّةِ', #6
u'مرجوحيته': u'مَرْجُوحِيَّتَهُ', #1
u'مرجوحيته': u'مَرْجُوحِيَّتُهُ', #1
u'مرجوحيته': u'مَرْجُوحِيَّتِهِ', #2
u'مرجى': u'مُرْجًى', #1
u'مرجى': u'مُرَجَّى', #8
u'مرحجة': u'مُرَحِّجَةٌ', #1
u'مرحضة': u'مُرَحَّضَةٌ', #1
u'مرحم': u'مُرَحّمٌ', #1
u'مرخاة': u'مُرْخَاةً', #1
u'مرخاة': u'مُرْخَاةٍ', #1
u'مرخاة': u'مُرْخَاةٌ', #4
u'مرخوا': u'مَرْخُوًّا', #6
u'مرداته': u'مرداته', #1
u'مرداته': u'مِرْدَاتُهُ', #1
u'مردار': u'مردار', #2
u'مرداز': u'مرداز', #1
u'مرداس،': u'مرداس،', #1
u'مرداس': u'مِرْدَاسَ', #13
u'مرداس': u'مِرْدَاسٍ', #202
u'مرداس،': u'مِرْدَاسٍ،', #22
u'مرداس': u'مرداس', #3
u'مرداس': u'مِرْدَاس', #3
u'مرداس': u'مِرْدَاسُ', #5
u'مرداس': u'مِرْدَاسِ', #6
u'مرداس': u'مِرْدَاسٌ', #8
u'مرداسا،': u'مِرْدَاسًا،', #1
u'مرداسا': u'مِرْدَاسًا', #2
u'مرداست': u'مرداست', #1
u'مردانبة': u'مردانَبَةَ', #1
u'مردانبة': u'مِرْدَانْبَةَ', #1
u'مردانبة،': u'مَرْدَانَبَةَ،', #1
u'مردانبة': u'مَرْدَانُبَةَ', #2
u'مردانبة،': u'مَرْدَانُبَةَ،', #2
u'مردانة': u'مِرْدَانَةَ', #1
u'مردانشاه،': u'مردانشاه،', #1
u'مرداين': u'مرداين', #1
u'مردرا': u'مردرا', #1
u'مردغة': u'مَرْدَغَةَ', #1
u'مردفى': u'مُرْدِفِى', #2
u'مردم': u'مردم', #1
u'مردمان': u'مُرَدَّمَانِ', #1
u'مردنا': u'مِرْدَنًا', #1
u'مردند': u'مردند', #1
u'مردوجان': u'مَرْدُوجَانِ', #1
u'مردود': u'مَرْدُودً', #1
u'مردويه': u'مَرْدِوِيهِ', #1
u'مردويه': u'مَرْدُوَيْهِ', #53
u'مردى': u'مُرْدًى', #1
u'مردى': u'مردى', #11
u'مردى': u'مُرْدَى', #3
u'مرديست': u'مرديست', #1
u'مرذبة': u'مَرْذُبَةَ', #1
u'مرذبة': u'مَرْذَبَةَ', #2
u'مرذة': u'مُرَذّةٌ', #1
u'مرذلة': u'مَرْذَلَةٌ', #1
u'مرذوذة': u'مَرْذُوذَةٌ', #1
u'مررر': u'مررر', #1
u'مرزاب': u'مِرْزَابٌ', #2
u'مرزاق': u'مِرْزَاقٍ', #1
u'مرزبان': u'مرزبان', #1
u'مرزبان': u'مَرْزُبَانِ', #1
u'مرزبان': u'مَرْزُبَانَ', #11
u'مرزبان': u'مَرْزُبَانُ', #2
u'مرزبانها،': u'مَرْزُبَانُهَا،', #1
u'مرزبة': u'مِرْزبَّةٌ', #1
u'مرزبة': u'مِرْزَبَةٌ', #1
u'مرزبة': u'مِرْزَبَّةً', #1
u'مرزبة': u'مِرْزَبَّةٌ', #4
u'مرزبى': u'مَرْزَبَى', #1
u'مرزق،': u'مَرْزُقٍ،', #1
u'مرزن': u'مُرِزْنَ', #2
u'مرزنجوش': u'مَرْزَنْجُوشُ', #1
u'مرزنكوش': u'مَرْزَنْكُوشَ', #1
u'مرزوقية': u'مَرْزُوقِيَّةَ', #1
u'مرسوس': u'مَرْسُوسٌ', #1
u'مرسوع': u'مَرْسُوعٍ', #1
u'مرسول': u'مَرْسُولٍ', #1
u'مرشل': u'مُرَشَّلِ', #1
u'مرشل،': u'مُرْشِلٍ،', #1
u'مرشوة': u'مَرْشُوَّةٍ', #1
u'مرصودون': u'مَرْصُودُونَ', #1
u'مرضات': u'مَرْضَات', #1
u'مرضات': u'مَرْضَاتِ', #25
u'مرضات': u'مَرِضَاتِ', #4
u'مرضات': u'مَرْضَاتَ', #5
u'مرضاتى': u'مَرْضَاتِى', #1
u'مرضاحه': u'مِرْضَاحِهِ', #1
u'مرضة': u'مَرِضَةِ', #1
u'مرضة': u'مِرْضَةً', #1
u'مرضة': u'مِرْضَةٍ', #1
u'مرضة': u'مَرْضَةٍ', #2
u'مرضخة': u'مرضخة', #1
u'مرضخة': u'مِرْضَخَةَ', #2
u'مرضخة': u'مِرْضَخَةِ', #3
u'مرضخة': u'مَرْضَخَةَ', #6
u'مرضم': u'مُرَضّمِ', #1
u'مرضوض': u'مَرْضُوضٌ', #1
u'مرضوض': u'مَرْضُوضَ', #1
u'مرضوض': u'مَرْضُوضُ', #2
u'مرضوضة': u'مَرْضُوضَةً', #2
u'مرضوفين': u'مَرْضُوفَيْنِ', #1
u'مرضى': u'مُرْضًى', #1
u'مرط': u'مرطٍ', #1
u'مرط': u'مِرْطُ', #1
u'مرط': u'مِرْطٍ', #12
u'مرط': u'مِرْط', #3
u'مرط': u'مِرْطٌ', #32
u'مرط': u'مِرْطِ', #4
u'مرط': u'مِرْطَ', #6
u'مرطا': u'مِرْطًا', #3
u'مرطك': u'مِرْطَك', #1
u'مرطها،': u'مِرْطِهَا،', #2
u'مرطها': u'مِرْطِهَا', #23
u'مرطها': u'مِرْطَهَا', #4
u'مرطوش': u'مرطوش', #1
u'مرطى': u'مِرْطِى', #1
u'مرطى': u'مَرْطَى', #2
u'مرطي': u'مِرْطِي', #3
u'مرعري': u'مَرْعَرِيٍّ', #1
u'مرعز': u'مرعز', #1
u'مرعزاء': u'مَرْعَزَاءُ', #1
u'مرعزاء': u'مَرْعِزَاءُ', #1
u'مرعزي': u'مَرْعَزِيٌّ', #1
u'مرعزى': u'مِرْعِزَّى', #2
u'مرعزيا': u'مَرْعَزِيًّا', #1
u'مرعزين': u'مِرْعِزَيْنِ', #1
u'مرعل': u'مرعل', #1
u'مرعل': u'مَرْعَلٌ', #1
u'مرعوفا': u'مَرْعُوفًا', #1
u'مرغابى': u'مرغابى', #1
u'مرغامة': u'مِرْغَامَةٌ', #1
u'مرغمتى': u'مُرْغِمَتَىِ', #1
u'مرغوش': u'مَرْغُوشٍ', #1
u'مرغوم': u'مَرْغُومٌ', #1
u'مرفضة': u'مُرْفَضَّةٌ', #1
u'مرفوءا': u'مَرْفُوءًا', #1
u'مرفوا': u'مَرْفُوًّا', #6
u'مرفودا': u'مَرْفُودًا', #1
u'مرفوع': u'مَرْفُوعً', #1
u'مرقبة': u'مَرْقَبَةٌ', #2
u'مرقسي': u'مَرْقَسِيّ', #1
u'مرقوب': u'مَرْقُوبٌ', #1
u'مرقوبا': u'مَرْقُوبًا', #1
u'مرقوع': u'مرقوع', #1
u'مرقوع': u'مَرْقُوعٌ', #1
u'مرقوع': u'مَرْقُوعٍ', #2
u'مرقوع': u'مَرْقُوعُ', #2
u'مرقوعا': u'مرقوعًا', #2
u'مرقوعا': u'مَرْقُوعًا', #2
u'مرقوق': u'مَرْقُوقُ', #1
u'مرقوق': u'مَرْقُوقٍ', #10
u'مرقوق': u'مَرْقُوقٌ', #7
u'مرقوقا': u'مَرْقُوقًا', #4
u'مرقوقة': u'مَرْقُوقَةٍ', #1
u'مرقوقة': u'مَرْقُوقَةً', #2
u'مرقوقة': u'مَرْقُوقَةٌ', #3
u'مرقوقه': u'مَرْقُوقِهِ', #1
u'مرقوقين': u'مَرْقُوقِينَ', #1
u'مرقوقين': u'مَرْقُوقَيْنِ', #1
u'مركد': u'مَرْكَدِ', #1
u'مرم': u'مُرِمّ', #1
u'مرماة': u'مِرْمَاةً', #1
u'مرماة': u'مِرْمَاةٌ', #2
u'مرماتان': u'مِرْمَاتَانِ', #2
u'مرماتين': u'مِرْمَاتَيْنِ', #22
u'مرمول': u'مَرْمُولٌ', #1
u'مرمول': u'مَرْمُولٍ', #1
u'مرمولة': u'مَرْمُولَةٌ', #1
u'مرمومة': u'مَرْمُومَةً', #1
u'مرموي': u'مَرْمَوِيٌّ', #2
u'مرمئ': u'مُرْمِئٍ', #1
u'مرنى': u'مُرْنِى', #3
u'مرهج': u'مُرْهَجِ', #1
u'مرهج': u'مُرْهَجْ', #1
u'مرهد': u'مَرْهَدٍ', #1
u'مرهوف': u'مَرْهُوفٌ', #1
u'مرهونية': u'مَرْهُونِيَّةٍ', #1
u'مروآت': u'مُرُوآتٌ', #1
u'مروآتنا': u'مُرُوآتِنَا', #1
u'مروآتهم': u'مُرُوآتِهِمْ', #1
u'مروالروذ': u'مَرْوِالرَّوْذِ', #1
u'مرواني': u'مَرْوَانِيٍّ', #1
u'مروانية': u'مَرْوَانِيَّةً', #1
u'مروت': u'مروت', #1
u'مروذي': u'مَرُّوذِيٍّ', #1
u'مروذي': u'مَرُّوذِيٌّ', #2
u'مروذية': u'مَرُّوذِيَّةٌ', #1
u'مروراة': u'مَرَوْرَاةٍ', #1
u'مروروذ': u'مَرْوَرُّوذِ', #2
u'مروروذي': u'مَرْوَرُّوذِيّ', #1
u'مروزدارم': u'مروزدارم', #1
u'مروط': u'مُرُوطِ', #2
u'مروطهن': u'مُرُوطَهُنَّ', #3
u'مروطهن': u'مُرُوطِهِنَّ', #3
u'مرى': u'مَرًى', #1
u'مريت': u'مَرَيْتُ', #2
u'مريت': u'مَرَيْت', #4
u'مريج': u'مَرِيجٍ', #2
u'مريحى': u'مُرِيحِى', #1
u'مريطاؤك': u'مُرْيَطَاؤُكَ', #1
u'مريطاؤك': u'مُرَيْطَاؤُك', #2
u'مريطاؤك': u'مُرَيْطَاؤُكَ', #4
u'مريطاؤه': u'مُرَيْطَاؤُهُ', #1
u'مريمأنكر': u'مَرْيَمَأَنْكَرَ', #1
u'مزابنة': u'مُزَابَنَةٌ', #16
u'مزابنة': u'مُزَابَنَة', #2
u'مزابنة': u'مُزَابَنَةً', #4
u'مزابنة': u'مُزَابَنَةٍ', #4
u'مزابنة': u'مُزَابَنَةَ', #5
u'مزاجر': u'مَزَاجِرَ', #1
u'مزاجره': u'مَزَاجِرِهِ', #1
u'مزاحملا': u'مزاحملا', #1
u'مزادان': u'مُزَادَانِ', #1
u'مزادتى': u'مَزَادَتَىِ', #1
u'مزاريق': u'مَزَارِيق', #1
u'مزاريق': u'مَزَارِيقَ', #2
u'مزاريق': u'مَزَارِيقُ', #4
u'مزاناته': u'مُزَانَاتُهُ', #1
u'مزاوحهم': u'مُزَاوِحُهُمْ', #1
u'مزايل': u'مُزَايَلٍ', #1
u'مزايل': u'مُزَايِلَ', #1
u'مزايل': u'مُزَايِلِ', #1
u'مزايل': u'مُزَايَلِ', #2
u'مزايل': u'مُزَايِلٍ', #4
u'مزايلا': u'مُزَايِلًا', #1
u'مزايلا': u'مُزَايَلًا', #5
u'مزبا': u'مزبا', #1
u'مزبا،': u'مزبا،', #1
u'مزبور': u'مَزْبُورٌ', #1
u'مزبوري': u'مزبوري', #3
u'مزبولة': u'مَزْبُولَةً', #1
u'مزجاة': u'مُزْجَاةٍ', #13
u'مزجاة': u'مُزْجَاةٌ', #5
u'مزجتيها': u'مَزَجْتِيهَا', #1
u'مزجر': u'مَزْجَرُ', #1
u'مزجر': u'مُزْجَرَ', #1
u'مزجر': u'مَزْجَرَ', #5
u'مزجرة': u'مَزْجَرَةَ', #2
u'مزجرة': u'مَزْجَرَةُ', #2
u'مزجرة': u'مَزْجَرَةٌ', #3
u'مزجرة': u'مَزْجَرَةً', #5
u'مزجور': u'مَزْجُورٌ', #2
u'مزجورا': u'مَزْجُورًا', #3
u'مزجوراتهم': u'مَزْجُورَاتِهِمْ', #2
u'مزحم': u'مُزْحِم', #1
u'مزحم': u'مِزْحَمُ', #1
u'مزحوم': u'مَزْحُومٌ', #3
u'مزحوم': u'مَزْحُومٍ', #3
u'مزحوما': u'مَزْحُومًا', #4
u'مزد': u'مزد', #1
u'مزدجر': u'مُزْدَجَرٌ', #1
u'مزدجرا': u'مُزْدَجَرًا', #2
u'مزدداد': u'مزدداد', #1
u'مزدرع': u'مُزْدَرِعُ', #1
u'مزدرع': u'مُزْدَرِعٌ', #2
u'مزدرعا': u'مُزْدَرَعًا', #2
u'مزدشانه': u'مزدشانه', #1
u'مزدك': u'مَزْدَكَ', #1
u'مزدك': u'مَزْدَكُ', #1
u'مزدم': u'مزدم', #1
u'مزر': u'مِزْرٌ', #1
u'مزر': u'مُزْرٍ', #11
u'مزرا': u'مَزِرًا', #1
u'مزرا': u'مِزْرًا', #1
u'مزراق': u'مِزْرَاقٌ', #1
u'مزراق': u'مِزْرَاقِ', #1
u'مزراق': u'مِزْرَاقٍ', #3
u'مزراقي': u'مِزْرَاقِي', #1
u'مزرد': u'مُزَرَّدٍ', #1
u'مزرد،': u'مُزَرِّدٍ،', #4
u'مزرد': u'مُزَرِّدٍ', #7
u'مزرر': u'مُزَرَّرٍ', #2
u'مزررة': u'مُزَرَّرَة', #1
u'مزررة': u'مُزَرَّرَةً', #2
u'مزررة': u'مُزَرَّرَةٌ', #3
u'مزرعا': u'مُزْرَعًا', #1
u'مزرعا،': u'مَزْرَعًا،', #1
u'مزرعه': u'مَزْرَعَهُ', #1
u'مزرور': u'مَزْرُورٍ', #17
u'مزرورا': u'مَزْرُورًا', #8
u'مزرورة': u'مَزْرُورَةٌ', #2
u'مزرورة': u'مَزْرُورَةٍ', #4
u'مزرورة': u'مَزْرُورَةً', #5
u'مزعة': u'مَزْعَةً', #1
u'مزعة': u'مُزْعَةٌ', #1
u'مزعة': u'مِزْعَةُ', #1
u'مزعة': u'مُزْعَةُ', #10
u'مزعة': u'مُزْعَة', #2
u'مزعفر': u'مُزَعْفَرُ', #1
u'مزعفر': u'مُزَعْفَرٌ', #4
u'مزعفر': u'مُزَعْفَرٍ', #9
u'مزعفرا': u'مُزَعْفَرًا', #3
u'مزعوجا': u'مَزْعُوجًا', #1
u'مزعوجة': u'مَزْعُوجَةً', #1
u'مزفوفة': u'مَزْفُوفَةً', #1
u'مزكأ': u'مَزْكَأً', #1
u'مزكات': u'مُزَكَّاتٍ', #1
u'مزكون': u'مُزَكُّونً', #1
u'مزمارة': u'مِزْمَارَةُ', #2
u'مزمزوه': u'مَزْمِزُوهُ', #3
u'مزنة': u'مُزْنَةٌ', #1
u'مزنخا': u'مُزَنِّخًا', #1
u'مزند': u'مُزَنّدِ', #2
u'مزنى': u'مُزَنِىٌّ', #1
u'مزنى': u'مُزْنًى', #1
u'مزهق': u'مُزْهَقِ', #1
u'مزهق': u'مُزْهِقٍ', #12
u'مزهق': u'مُزْهِقٌ', #9
u'مزهقا': u'مُزْهِقًا', #11
u'مزهقان': u'مُزْهِقَانِ', #10
u'مزهقة': u'مُزْهِقَةٍ', #1
u'مزهقة': u'مُزْهِقَةً', #2
u'مزهقة': u'مُزْهِقَةٌ', #3
u'مزهئر': u'مُزْهَئِرّ', #1
u'مزهئرا': u'مُزْهَئِرّا', #1
u'مزودى': u'مِزْوَدَىْ', #1
u'مزوق': u'مُزَوَّقً', #1
u'مزيز': u'مَزِيزٍ', #1
u'مزيقيا': u'مَزِيقِيًّا', #2
u'مزيقيا': u'مُزَيْقِيَا', #2
u'مزيقياء': u'مُزَيقياء', #1
u'مزيقياء': u'مُزَيْقِيَاءُ', #3
u'مزيقياء': u'مُزَيْقِيَاءَ', #6
u'مساءة': u'مَسَاءَةً', #1
u'مسابة': u'مُسَابَّةٍ', #1
u'مساتقهم': u'مَسَاتِقِهِمْ', #1
u'مساجدوروي': u'مَسَاجِدَوَرُوِيَ', #1
u'مساجن': u'مَسَاجِنُ', #1
u'مساخرة': u'مُسَاخَرَةِ', #1
u'مسارج': u'مَسَارِجُ', #1
u'مساررته': u'مُسَارَرْتُهُ', #1
u'مساطير': u'مَسَاطِيرُ', #1
u'مساغ': u'مَسَاغ', #1
u'مساغ': u'مَسَاغٍ', #1
u'مساغ': u'مُسَاغ', #1
u'مساغ': u'مُسَاغٍ', #1
u'مساغ': u'مَسَاغُ', #2
u'مساغ': u'مَسَاغِ', #2
u'مساغ': u'مُسَاغَ', #2
u'مساغ': u'مَسَاغٌ', #31
u'مساغ': u'مَسَاغَ', #40
u'مساغا': u'مُسَاغًا', #4
u'مساغا': u'مَسَاغًا', #43
u'مساغه': u'مَسَاغَهُ', #1
u'مساغه': u'مَسَاغِهِ', #1
u'مساف': u'مَسَافِ', #1
u'مسافةالقصر': u'مَسَافَةَالْقَصْرِ', #1
u'مسافحين': u'مَسَافِحِينَ', #1
u'مسافحين': u'مُسَافِحِينَ', #25
u'مسافع': u'مُسافع', #1
u'مسافع': u'مُسَافع', #1
u'مسافع،': u'مُسَافِعٌ،', #1
u'مسافع': u'مُسَافِعُ', #12
u'مسافع': u'مُسَافِعِ', #16
u'مسافع': u'مسافع', #2
u'مسافع': u'مُسَافِعَ', #2
u'مسافع': u'مُسَافِعٍ', #26
u'مسافع،': u'مُسَافِعٍ،', #3
u'مسافع': u'مُسَافِعٌ', #9
u'مسافعا': u'مُسَافِعًا', #1
u'مساقة': u'مُسَاقَةِ', #1
u'مساقى': u'مُسَاقَى', #1
u'مساقى': u'مُسَاقًى', #12
u'مسألتى': u'مَسْأَلَتِى', #2
u'مسالقرآن': u'مَسِّالْقُرْآنِ', #1
u'مسأله': u'مَسْأَلَهُ', #1
u'مسأله': u'مَسْأَلَهْ', #1
u'مسأله': u'مسأله', #2
u'مسامة': u'مُسَامَةُ', #1
u'مسامة': u'مُسَامَةِ', #1
u'مسامت': u'مُسَامِتٍ', #1
u'مسامت': u'مُسَامِتٌ', #10
u'مسامتا': u'مُسَامَتًا', #3
u'مسامتا': u'مُسَامِتًا', #63
u'مسامتة': u'مُسَامَتَةً', #1
u'مسامتة': u'مُسَامِتَةٌ', #1
u'مسامتة': u'مُسَامَتَةِ', #19
u'مسامتة': u'مُسَامَتَةٌ', #2
u'مسامتة': u'مُسَامَتَةٍ', #3
u'مسامتة': u'مُسَامِتَةً', #6
u'مسامتة': u'مُسَامِتَةٍ', #6
u'مسامتة': u'مُسَامَتَةُ', #9
u'مسامتته': u'مُسَامَتَتُهُ', #4
u'مسامتته': u'مُسَامَتَتِهِ', #6
u'مسامتتها': u'مُسَامَتَتِهَا', #10
u'مسامتتها': u'مُسَامَتَتُهَا', #5
u'مسامته': u'مُسَامَتِهِ', #1
u'مسامته': u'مُسَامِتُهُ', #1
u'مسامته': u'مُسَامَتُهُ', #3
u'مسامتها': u'مُسَامَتِهَا', #1
u'مسامتها': u'مُسَامِتَهَا', #1
u'مسامتها': u'مُسَامِتِهَا', #1
u'مسامتين': u'مُسَامِتِينَ', #2
u'مسامم': u'مَسَامِمُ', #1
u'مساميرا': u'مَسَامِيرًا', #1
u'مساناة': u'مُسَانَاةً', #10
u'مسانهة': u'مُسَانَهَةٌ', #1
u'مسانهة': u'مُسَانَهَةَ', #1
u'مسانهة': u'مُسَانَهَة', #2
u'مسانهة': u'مُسَانَهَةٍ', #2
u'مسانهة': u'مُسَانَهَةً', #67
u'مساهل': u'مُسَاهِلٍ', #1
u'مساوقة': u'مُسَاوَقَةِ', #1
u'مساوقته': u'مُسَاوَقَتَهُ', #1
u'مساوقتها': u'مُسَاوَقَتُهَا', #1
u'مساولج': u'مساولج', #1
u'مساوى': u'مَسَاوِى', #1
u'مساوى': u'مُسَاوًى', #1
u'مساويكا': u'مَسَاوِيكَا', #5
u'مسائح': u'مَسَائِحُ', #1
u'مسائح': u'مَسَائِحِ', #5
u'مسائحه': u'مَسَائِحِهِ', #3
u'مسايح': u'مَسَايِحِ', #1
u'مسايسا': u'مُسَايِسًا', #1
u'مسايقة': u'مُسَايَقَةٍ', #1
u'مسبدا': u'مُسَبِّدًا', #1
u'مسبطر': u'مُسْبَطِرّ', #1
u'مسبل': u'مُسَبَّل', #1
u'مسبل': u'مُسَبَّلِ', #1
u'مسبل': u'مُسَبِّلٌ', #1
u'مسبل': u'مُسْبِلٌ', #14
u'مسبل': u'مُسَبَّلٌ', #15
u'مسبل': u'مُسْبِلٍ', #15
u'مسبل': u'مُسَبَّلٍ', #32
u'مسبل': u'مُسْبَلٌ', #4
u'مسبل': u'مُسْبَلٍ', #8
u'مسبلا': u'مُسْبِلاً', #1
u'مسبلا': u'مُسَبّلًا', #1
u'مسبلا': u'مُسَبَّلًا', #19
u'مسبلا': u'مُسْبَلًا', #2
u'مسبلا': u'مُسْبِلًا', #5
u'مسبلات': u'مُسَبَّلَاتِ', #2
u'مسبلة': u'مُسْبَلَةٌ', #1
u'مسبلة': u'مُسْبِلَةً', #1
u'مسبلة': u'مُسْبِلَةٍ', #1
u'مسبلة': u'مُسَبَّلَةٌ', #14
u'مسبلة': u'مُسَبَّلَةً', #37
u'مسبلة': u'مُسَبَّلَةٍ', #68
u'مسبلة': u'مُسْبَلَةً', #8
u'مسبلة': u'مُسْبَلَةٍ', #9
u'مسبله': u'مُسَبِّلَهُ', #1
u'مسبوط': u'مَسْبُوطٌ', #1
u'مسبوقيته': u'مَسْبُوقِيَّتَهُ', #1
u'مسبوقيته': u'مَسْبُوقِيَّتُهُ', #1
u'مسبوقيته': u'مَسْبُوقِيَّتِهِ', #3
u'مسبولا': u'مَسْبُولًا', #1
u'مسة': u'مُسَّةُ', #1
u'مسة': u'مُسَّةَ', #10
u'مسة': u'مَسَّةِ', #3
u'مستأخر': u'مستأخر', #1
u'مستأخر': u'مُسْتَأْخِرُ', #1
u'مستأخر،': u'مُسْتَأْخِرٌ،', #1
u'مستأخر': u'مُسْتَأْخَرٍ', #2
u'مستأخر': u'مُسْتَأْخَرٌ', #4
u'مستأخر': u'مُسْتَأْخِرٍ', #6
u'مستأخر': u'مُسْتَأْخِرٌ', #7
u'مستأخرا': u'مُسْتَأْخَرًا', #3
u'مستأخرا': u'مُسْتَأْخِرًا', #7
u'مستأسرا': u'مُسْتَأْسَرًا', #1
u'مستام': u'مُسْتَامٍ', #5
u'مستاما': u'مُسْتَامًا', #1
u'مستامة': u'مُسْتَامَةِ', #1
u'مستامة': u'مُسْتَامَةٍ', #5
u'مستان': u'مستان', #1
u'مستبانه': u'مُسْتَبَانَهْ', #2
u'مستبحر': u'مُسْتَبْحِرٍ', #2
u'مستبحر': u'مُسْتَبْحَرٍ', #4
u'مستبحرا': u'مُسْتَبْحَرًا', #1
u'مستبحرا': u'مُسْتَبْحِرًا', #7
u'مستبرأة': u'مُسْتَبْرَأَةِ', #1
u'مستبرأة': u'مُسْتَبْرَأَةً', #20
u'مستبرأة': u'مُسْتَبْرَأَةٌ', #20
u'مستبرأة': u'مُسْتَبْرَأَةٍ', #24
u'مستبرئ': u'مُسْتَبْرِئٍ', #3
u'مستبرئها': u'مُسْتَبْرَئِهَا', #1
u'مستبضع': u'مُسْتَبْضَعٌ', #1
u'مستبضع': u'مُسْتَبْضَعٍ', #1
u'مستبضع': u'مُسْتَبْضِعٌ', #1
u'مستبضع': u'مُسْتَبْضِعٍ', #2
u'مستبضعا': u'مُسْتَبْضَعًا', #1
u'مستبضعا': u'مُسْتَبْضِعًا', #6
u'مستبهمة': u'مُسْتَبْهِمَةً', #1
u'مستبهمه': u'مُسْتَبْهَمَهْ', #1
u'مستتم': u'مُسْتَتَمٍّ', #1
u'مستتم': u'مُسْتَتِمٍّ', #1
u'مستتما': u'مُسْتَتَمًّا', #1
u'مستتمة': u'مُسْتَتِمَّةً', #1
u'مستتمة': u'مُسْتَتِمَّةِ', #1
u'مستتمة': u'مُسْتَتَمَّةٌ', #2
u'مستتمة': u'مُسْتَتِمَّةٌ', #6
u'مستتيبه': u'مُسْتَتِيبَهُ', #1
u'مستثبت': u'مُسْتَثْبَتٍ', #1
u'مستثبت': u'مُسْتَثْبِتٌ', #2
u'مستثفرا': u'مُسْتَثْفِرًا', #2
u'مستثفرة': u'مُسْتَثْفِرَةً', #1
u'مستجاز': u'مُسْتَجَازٌ', #4
u'مستجر': u'مُسْتَجْرٍ', #1
u'مستجسد': u'مُسْتَجْسِدٌ', #1
u'مستجسد': u'مُسْتَجْسِدٍ', #2
u'مستجسدا': u'مُسْتَجْسِدًا', #2
u'مستجسدة': u'مُسْتَجْسِدَةً', #1
u'مستجمر': u'مُسْتَجْمِرٍ', #10
u'مستجمر': u'مُسْتَجْمَرٍ', #2
u'مستجمر': u'مُسْتَجْمِرٌ', #3
u'مستجمرا': u'مُسْتَجْمِرًا', #35
u'مستجمرا': u'مُسْتَجْمَرًا', #8
u'مستجمرة': u'مُسْتَجْمِرَةً', #1
u'مستجهلين': u'مُسْتَجْهَلِينَ', #1
u'مستجيزا،': u'مُسْتَجِيزًا،', #1
u'مستجيزا': u'مُسْتَجِيزًا', #6
u'مستحاضة': u'مُسْتَحَاضَةِ', #1
u'مستحاضة': u'مُسْتَحَاضَةٌ', #125
u'مستحاضة': u'مُسْتَحَاضَةً', #151
u'مستحاضة': u'مُسْتَحَاضَةٍ', #38
u'مستحاضتان': u'مُسْتَحَاضَتَانِ', #1
u'مستحثة': u'مُسْتَحِثَّةٍ', #1
u'مستحجر': u'مستحجر', #1
u'مستحجر': u'مُسْتَحْجِرٌ', #1
u'مستحجر': u'مُسْتَحْجَرٍ', #2
u'مستحجر': u'مُسْتَحْجِرٍ', #3
u'مستحجر': u'مُسْتَحْجَرٌ', #8
u'مستحجزا': u'مُسْتَحْجَزًا', #1
u'مستحشف': u'مُسْتَحْشَفٍ', #1
u'مستحشفة': u'مُسْتَحْشِفَةٌ', #1
u'مستحشفة': u'مُسْتَحْشِفَةٍ', #1
u'مستحشفة': u'مُسْتَحْشِفَةً', #2
u'مستحصد': u'مُسْتَحْصِدٌ', #1
u'مستحصد': u'مُسْتَحْصِدٍ', #2
u'مستحصد': u'مُسْتَحْصَدٍ', #3
u'مستحصدا': u'مُسْتَحْصَدًا', #1
u'مستحصدة': u'مُسْتَحْصِدَة', #1
u'مستحفظ': u'مُسْتَحْفِظٌ', #2
u'مستحفظا': u'مُسْتَحْفَظًا', #1
u'مستحفظا': u'مُسْتَحْفِظًا', #1
u'مستحفظة': u'مُسْتَحْفَظَةً', #1
u'مستحق': u'مُسْتَحِقًّ', #1
u'مستحقب': u'مُسْتَحْقِبِ', #1
u'مستحقر': u'مُسْتَحْقَرٍ', #1
u'مستحقرا': u'مُسْتَحْقِرًا', #2
u'مستحقرة': u'مُسْتَحْقَرَةً', #1
u'مستحيزة': u'مُسْتَحِيزَةٌ', #1
u'مستخبث': u'مُسْتَخْبَثٌ', #20
u'مستخبث': u'مُسْتَخْبَثٍ', #6
u'مستخبثا': u'مُسْتَخْبَثًا', #2
u'مستخبثان': u'مُسْتَخْبَثَانِ', #1
u'مستخبثة': u'مُسْتَخْبَثَةٍ', #1
u'مستخبثة': u'مُسْتَخْبَثَةُ', #1
u'مستخبثة': u'مُسْتَخْبَثَةٌ', #6
u'مستخسفة': u'مُسْتَخْسَفَةٍ', #1
u'مستخفى': u'مُسْتَخْفًى', #1
u'مستخليا': u'مُسْتَخْلِيًا', #2
u'مستخير': u'مُسْتَخِيرٌ', #1
u'مستخير': u'مُسْتَخِيرَ', #1
u'مستخيرا': u'مُسْتَخِيرًا', #3
u'مستدا': u'مُسْتَدًّا', #2
u'مستدار': u'مُسْتَدَارُ', #4
u'مستدارها': u'مُسْتَدَارُهَا', #1
u'مستدانة': u'مُسْتَدَانَةٍ', #5
u'مستدانة': u'مُسْتَدَانَةً', #7
u'مستدة': u'مُسْتَدَّةً', #5
u'مستدخلة': u'مُسْتَدْخِلَةٌ', #1
u'مستدخلة': u'مُسْتَدْخِلَةً', #2
u'مستدخلة': u'مُسْتَدْخِلَةُ', #2
u'مستدخلة': u'مُسْتَدْخِلَةٍ', #3
u'مستدن': u'مُسْتَدَنْ', #4
u'مستذفر': u'مُسْتَذْفِرٍ', #1
u'مستذفرا': u'مُسْتَذْفِرًا', #2
u'مستذل': u'مُسْتَذَلٌّ', #1
u'مستذلا': u'مُسْتَذَلًّا', #1
u'مستذلين': u'مُسْتَذَلِّينَ', #6
u'مستر': u'مُسْتَرٍ', #1
u'مستر': u'مُسْتِرٍ', #3
u'مسترا': u'مُسَتَّرًا', #1
u'مستراب': u'مُسْتَرَابٌ', #1
u'مسترابة': u'مُسْتَرَابَةٌ', #1
u'مسترابة': u'مُسْتَرَابَةُ', #1
u'مسترابة': u'مُسْتَرَابَةً', #2
u'مسترذلة': u'مُسْتَرْذَلَةٍ', #1
u'مسترذلين': u'مُسْتَرْذَلِينَ', #1
u'مسترضع': u'مُسْتَرْضِعٌ', #1
u'مسترضعا': u'مسترضعًا', #1
u'مسترضعا': u'مُسْتَرْضَعًا', #19
u'مسترضعا': u'مُسْتَرْضِعًا', #9
u'مسترضعة': u'مُسْتَرْضَعَةٌ', #1
u'مسترضعة،': u'مُسْتَرْضَعَةٌ،', #1
u'مسترعى': u'مُسْتَرْعى', #1
u'مسترعى': u'مُسْتَرْعًى', #1
u'مسترقوا': u'مُسْتَرِقُوا', #1
u'مسترهب': u'مُسْتَرْهَبٍ', #1
u'مستزاد': u'مُسْتَزَادٌ', #1
u'مستسر': u'مُسْتَسِرٍّ', #6
u'مستسرا': u'مُسْتَسِرًّا', #14
u'مستسعاة': u'مُسْتَسْعَاةً', #12
u'مستسعاة': u'مُسْتَسْعَاةٌ', #4
u'مستسعاه': u'مُسْتَسْعَاهُ', #1
u'مستسعدا': u'مُسْتَسْعَدًا', #1
u'مستسعى': u'مُسْتَسْعًى', #18
u'مستسقى': u'مُسْتَسْقَى', #1
u'مستسند': u'مُسْتَسْنِدً', #1
u'مستشكل': u'مُسْتَشْكِلٍ', #1
u'مستشكل': u'مُسْتَشْكَلٌ', #3
u'مستشكل': u'مُسْتَشْكِلٌ', #3
u'مستشكلا': u'مُسْتَشْكِلًا', #8
u'مستشنع': u'مُسْتَشْنَعٌ', #1
u'مستشنع': u'مُسْتَشْنَعٍ', #1
u'مستشنعا': u'مُسْتَشْنَعًا', #2
u'مستشنعة': u'مُسْتَشْنَعَةٌ', #1
u'مستشنعة': u'مُسْتَشْنَعَةً', #4
u'مستشور': u'مُسْتَشْوِرٌ', #1
u'مستصفاه': u'مُسْتَصْفَاهُ', #4
u'مستصفى': u'مُسْتَصْفَى', #27
u'مستصفى': u'مُسْتَصْفًى', #5
u'مستصنع': u'مُسْتَصْنِعٌ', #2
u'مستصوبا': u'مُسْتَصْوِبًا', #1
u'مستضجرا': u'مُسْتَضْجِرًا', #1
u'مستضر': u'مُسْتَضِرٍّ', #2
u'مستضلعون': u'مُسْتَضْلِعُونَ', #1
u'مستطر': u'مُسْتَطَرْ', #1
u'مستطر': u'مُسْتَطِرٍ', #1
u'مستطر': u'مُسْتَطَرٌ', #2
u'مستطرفا': u'مُسْتَطْرَفًا', #1
u'مستطرق': u'مُسْتَطْرَقٌ', #1
u'مستطرق': u'مُسْتَطْرَقٍ', #1
u'مستطرق': u'مُسْتَطْرِقٌ', #1
u'مستطرقا': u'مُسْتَطْرَقًا', #1
u'مستطرقة': u'مُسْتَطْرَقَةً', #3
u'مستظرف': u'مُسْتَظْرَفُ', #1
u'مستظرف': u'مُسْتَظْرَفٌ', #8
u'مستظرفا': u'مُسْتَظْرَفًا', #1
u'مستعاف': u'مُسْتَعَافٍ', #1
u'مستعبر': u'مُسْتَعْبَرٌ', #1
u'مستعتب': u'مُسْتَعْتَبٍ', #13
u'مستعتب': u'مُسْتَعْتَبٌ', #2
u'مستعتبا': u'مُسْتَعْتَبًا', #1
u'مستعتبا': u'مُسْتَعْتِبًا', #2
u'مستعدى': u'مُسْتَعْدِى', #1
u'مستعدى': u'مُسْتَعْدًى', #5
u'مستعطشا': u'مُسْتَعْطِشًا', #2
u'مستعفيا': u'مُسْتَعْفِيًا', #1
u'مستعقب': u'مُسْتَعْقِبٌ', #1
u'مستعقب': u'مُسْتَعْقِبٍ', #2
u'مستعقبا': u'مُسْتَعْقِبًا', #3
u'مستعقبا': u'مُسْتَعْقَبًا', #4
u'مستعقبة': u'مُسْتَعْقِبَةً', #2
u'مستعلنا': u'مُسْتَعْلِنًا', #1
u'مستغنما': u'مُسْتَغْنِمًا', #1
u'مستغو': u'مُسْتَغْوٍ', #2
u'مستفاضا': u'مُسْتَفَاضًا', #2
u'مستفاضة': u'مُسْتَفَاضَةٌ', #1
u'مستفتى': u'مُسْتَفْتًى', #1
u'مستفحش': u'مُسْتَفْحَشٌ', #1
u'مستفرش': u'مُسْتَفْرَشٌ', #1
u'مستفرش': u'مُسْتَفْرِشٌ', #12
u'مستفرشا': u'مُسْتَفْرِشًا', #2
u'مستفرشة': u'مُسْتَفْرَشَةٌ', #1
u'مستفرشة': u'مُسْتَفْرَشَةَ', #1
u'مستفرشة': u'مُسْتَفْرَشَةً', #13
u'مستفرشة': u'مُسْتَفْرَشَةِ', #2
u'مستفرشة': u'مُسْتَفْرَشَةٍ', #3
u'مستفرشتان': u'مُسْتَفْرَشَتَانِ', #1
u'مستفرشته': u'مُسْتَفْرِشَتَهُ', #1
u'مستفرشتين': u'مُسْتَفْرَشَتَيْنِ', #3
u'مستفرشها': u'مُسْتَفْرِشِهَا', #2
u'مستفرق': u'مُسْتَفْرِقَ', #1
u'مستفضلا': u'مُسْتَفْضِلًا', #1
u'مستفعل': u'مُسْتَفْعِلٌ', #1
u'مستفعل': u'مُسْتَفْعِلٍ', #1
u'مستفعلن': u'مُسْتَفْعِلُنْ', #2
u'مستفل': u'مُسْتَفْلٌ', #1
u'مستفلا': u'مُسْتَفِلًا', #2
u'مستفلة': u'مُسْتَفِلَةً', #1
u'مستفلة': u'مُسْتَفِلَةٌ', #1
u'مستقام': u'مُسْتَقَامٍ', #1
u'مستقبس': u'مُستَقْبِسُ', #1
u'مستقبس': u'مُسْتَقْبِسُ', #1
u'مستقبلى': u'مُسْتَقْبِلِى', #3
u'مستقة': u'مُسْتَقَةٍ', #1
u'مستقة': u'مُسْتُقَةً', #1
u'مستقة': u'مُسْتَقَةً', #2
u'مستقدر': u'مُسْتَقْدَرٌ', #1
u'مستقدرات': u'مُسْتَقْدَرَاتِ', #1
u'مستقذر': u'مُسْتَقْذِرٌ', #1
u'مستقذر': u'مُسْتَقْذَر', #3
u'مستقذر': u'مُسْتَقْذَرٍ', #60
u'مستقذر': u'مُسْتَقْذَرٌ', #66
u'مستقذرا': u'مُسْتَقْذِرًا', #1
u'مستقذرا': u'مُسْتَقْذَرًا', #20
u'مستقذرة': u'مُسْتَقْذَرَةٌ', #14
u'مستقذرة': u'مُسْتَقْذَرَةٍ', #2
u'مستقذرة': u'مُسْتَقْذَرَةً', #6
u'مستقذرون': u'مُسْتَقْذَرُونَ', #3
u'مستقذرين': u'مُسْتَقْذَرَيْنِ', #2
u'مستقرأ': u'مُسْتَقْرَأٍ', #1
u'مستقرأة': u'مُسْتَقْرَأَةٌ', #1
u'مستقرآت': u'مُسْتَقْرَآتٌ', #1
u'مستقرض': u'مُسْتَقْرَضٌ', #1
u'مستقرض': u'مُسْتَقْرِضٍ', #1
u'مستقرض': u'مُسْتَقْرِضَ', #1
u'مستقرض': u'مُسْتَقْرِضُ', #1
u'مستقرض': u'مُسْتَقْرِضٌ', #8
u'مستقرضا': u'مُسْتَقْرَضًا', #1
u'مستقرضا': u'مُسْتَقْرِضًا', #44
u'مستقرضة': u'مُسْتَقْرِضَةً', #2
u'مستقرضه': u'مُسْتَقْرِضُهُ', #1
u'مستقرضه': u'مُسْتَقْرِضِهِ', #1
u'مستقرضين': u'مُسْتَقْرِضَيْنِ', #2
u'مستقرؤه': u'مُسْتَقْرَؤُهُ', #1
u'مستقصاة': u'مُسْتَقْصَاةٌ', #4
u'مستقصى': u'مُسْتَقْصَى', #1
u'مستقصى': u'مُسْتَقْصًى', #14
u'مستقضيا': u'مُسْتَقْضِيًا', #2
u'مستقضية': u'مُسْتَقْضِيَةٍ', #1
u'مستقن': u'مُسْتَقْنٍ', #1
u'مستكرمة': u'مُسْتَكْرَمَةٍ', #1
u'مستكرى': u'مُسْتَكْرِى', #1
u'مستكي': u'مُسْتَكِي', #2
u'مستلحق': u'مُسْتَلْحَق', #1
u'مستلحق': u'مُسْتَلْحَقٌ', #1
u'مستلحق': u'مُسْتَلْحَقُ', #1
u'مستلحق': u'مُسْتَلْحَقِ', #1
u'مستلحق': u'مُسْتَلْحِقٌ', #1
u'مستلحق': u'مُسْتَلْحَقٍ', #7
u'مستلحقا': u'مُسْتَلْحَقًا', #3
u'مستلحقا': u'مُسْتَلْحِقًا', #3
u'مستلحقة': u'مُسْتَلْحَقَةً', #1
u'مستلحقه': u'مُسْتَلْحَقُهُ', #2
u'مستلحقه': u'مُسْتَلْحَقِهِ', #2
u'مستلحقه': u'مُسْتَلْحِقَهُ', #4
u'مستلحقه': u'مُسْتَلْحِقُهُ', #4
u'مستلحقه': u'مُسْتَلْحَقَهُ', #6
u'مستلحقه': u'مُسْتَلْحِقِهِ', #9
u'مستلحقيه': u'مُسْتَلْحِقَيْهِ', #1
u'مستلحقيه': u'مُسْتَلْحِقِيهِ', #2
u'مستمكن': u'مُسْتَمْكِنٌ', #1
u'مستملي': u'مُسْتَمْلِيَ', #1
u'مستملين': u'مُسْتَمْلِينَ', #3
u'مستمليه': u'مُسْتَمْلِيهِ', #1
u'مستميحا': u'مُسْتَمِيحًا', #1
u'مستنا،': u'مُسْتَنًّا،', #1
u'مستنا': u'مُسْتَنًّا', #2
u'مستنابا': u'مُسْتَنَابًا', #1
u'مستنابه': u'مُسْتَنَابُهُ', #1
u'مستناخ': u'مُسْتَنَاخٍ', #3
u'مستنبلا': u'مُسْتَنْبِلًا', #1
u'مستنبه': u'مُسْتَنْبِهٌ', #1
u'مستنتل': u'مُسْتَنْتِلٌ', #4
u'مستنجى': u'مُسْتَنْجًى', #2
u'مستنشئة': u'مُسْتَنْشِئَةٌ', #1
u'مستنصل': u'مُسْتَنْصِلٌ', #4
u'مستنظر': u'مُسْتَنْظَرٍ', #1
u'مستنظرا': u'مُسْتَنْظَرًا', #1
u'مستنقذ': u'مُسْتَنْقِذٌ', #3
u'مستنقذا': u'مُسْتَنْقِذًا', #1
u'مستنقذها': u'مُسْتَنْقِذُهَا', #3
u'مستنقص': u'مُسْتَنْقِصٍ', #1
u'مستنقص': u'مُسْتَنْقِصٌ', #5
u'مستنقصا': u'مُسْتَنْقِصًا', #9
u'مستنقصة': u'مُسْتَنْقِصَةً', #1
u'مستنقلا': u'مُسْتَنْقَلًا', #1
u'مستنكح': u'مُسْتَنْكَحِ', #1
u'مستنكح': u'مُسْتَنْكَحٍ', #17
u'مستنكح': u'مُسْتَنْكِحِ', #2
u'مستنكح': u'مُسْتَنْكِحٍ', #37
u'مستنكح': u'مُسْتَنْكَحٌ', #4
u'مستنكح': u'مُسْتَنْكِحٌ', #9
u'مستنكحا': u'مُسْتَنْكَحًا', #21
u'مستنكحا': u'مُسْتَنْكِحًا', #51
u'مستنكحة': u'مُسْتَنْكَحَةٍ', #1
u'مستنكحة': u'مُسْتَنْكَحَةً', #2
u'مستنكه': u'مُسْتَنْكِهٌ', #1
u'مستنهي': u'مُسْتَنْهِي', #1
u'مستنون': u'مُسْتَنُّونَ', #1
u'مستنيب': u'مُسْتَنِيبٌ', #2
u'مستنيب': u'مُسْتَنِيبٍ', #9
u'مستنيبا': u'مُسْتَنِيبًا', #2
u'مستنيبة': u'مُسْتَنِيبَةُ', #1
u'مستنيبه': u'مُسْتَنِيبُهُ', #21
u'مستنيبه': u'مُسْتَنِيبَهُ', #3
u'مستنيبه': u'مُسْتَنِيبِهِ', #45
u'مستنيبهم': u'مُسْتَنِيبِهِمْ', #2
u'مستنين': u'مُسْتَنِّينَ', #2
u'مستها': u'مُسْتَهًا', #1
u'مستهانة': u'مُسْتَهَانَةٌ', #1
u'مستهدما': u'مُسْتَهْدِمًا', #1
u'مستهدما': u'مُسْتَهْدَمًا', #4
u'مستهدمة': u'مُسْتَهْدَمَةٌ', #1
u'مستهدمة': u'مُسْتَهْدَمَةٍ', #1
u'مستهزمين': u'مُسْتَهْزَمِينَ', #1
u'مستوثقا': u'مُسْتَوْثَقًا', #1
u'مستوثقا': u'مُسْتَوْثِقًا', #6
u'مستوثقة': u'مُسْتَوْثِقَةً', #1
u'مستوطئا': u'مُسْتَوْطِئًا', #1
u'مستوغرا': u'مُسْتَوْغِرًا', #1
u'مستوفاة': u'مُسْتَوْفَاةَ', #1
u'مستوفاة': u'مُسْتَوْفَاةُ', #1
u'مستوفاة': u'مُسْتَوْفَاةٌ', #29
u'مستوفاة': u'مُسْتَوْفَاةٍ', #3
u'مستوفاة': u'مُسْتَوْفَاةً', #33
u'مستوفز': u'مُسْتَوْفِزٌ', #8
u'مستوفزا': u'مستوفزا', #1
u'مستوفزا': u'مُسْتَوْفِزًا', #14
u'مستوفزون': u'مُسْتَوْفِزُونَ', #6
u'مستوفزين': u'مُسْتَوْفِزِينَ', #2
u'مستوفى': u'مُسْتَوْفَى', #12
u'مستوفى': u'مُسْتَوْفًى', #245
u'مستوق': u'مَسْتُوقٌ', #1
u'مستوها': u'مَسْتُوهًا', #2
u'مستوهب': u'مُسْتَوْهِبٌ', #1
u'مستوهبا': u'مُسْتَوْهِبًا', #1
u'مستيسرا': u'مُسْتَيْسَرًا', #1
u'مسجا': u'مسجا', #1
u'مسجحا': u'مُسْجِحًا', #4
u'مسجداSتحلحل': u'مَسْجِدًاSتَحَلْحَلَ', #1
u'مسجدقباء': u'مَسْجِدَقُبَاءَ', #1
u'مسجدوروي': u'مَسْجِدٌوَرُوِيَ', #1
u'مسجدى': u'مَسْجِدِى', #17
u'مسجديته': u'مَسْجِدِيَّتُهُ', #1
u'مسجديته': u'مَسْجِدِيَّتِهِ', #3
u'مسجديتها': u'مَسْجِدِيَّتَهَا', #1
u'مسجديتها': u'مَسْجِدِيَّتِهَا', #1
u'مسجديتهما': u'مَسْجِدِيَّتَهُمَا', #1
u'مسجع': u'مُسْجَعٌ', #2
u'مسجع': u'مُسَجَّعٍ', #3
u'مسجع': u'مُسَجَّعٌ', #5
u'مسجعا': u'مَسْجَعًا', #2
u'مسجعا': u'مُسَجَّعًا', #2
u'مسجفا': u'مُسْجَفًا', #1
u'مسجفا': u'مُسَجَّفًا', #7
u'مسجفة': u'مُسَجَّفَةٌ', #1
u'مسجن': u'مَسْجَنُ', #1
u'مسجى': u'مُسَجَّى', #1
u'مسجى،': u'مُسَجًّى،', #1
u'مسجى': u'مُسَجًّى', #26
u'مسجى': u'مسجى', #3
u'مسجى': u'مُسَجّى', #7
u'مسحاج': u'مِسْحَاجٌ', #1
u'مسحاج': u'مِسْحَاجُ', #1
u'مسحاج،': u'مِسْحَاجٌ،', #1
u'مسحسحة': u'مُسَحْسَحَةٍ', #1
u'مسحسحة': u'مُسْحْسَحَةٍ', #1
u'مسحنفر': u'مُسْحَنْفَرٍ', #1
u'مسحنفر': u'مُسْحَنْفِرُ', #1
u'مسحول': u'مَسْحُولٌ', #1
u'مسحول': u'مَسْحُولٍ', #2
u'مسحولا': u'مَسْحُولًا', #1
u'مسحين': u'مَسْحَيْنِ', #1
u'مسحين': u'مِسْحَيْنِ', #1
u'مسخطا': u'مُسْخِطًا', #1
u'مسخطة': u'مَسْخَطَةٌ', #2
u'مسخفيا': u'مُسْخَفِيًا', #1
u'مسخمة': u'مُسَخَّمَةُ', #3
u'مسخوطة': u'مَسْخُوطَةٍ', #1
u'مسخوطون': u'مَسْخُوطُونَ', #1
u'مسخوطين': u'مَسْخُوطَيْنِ', #1
u'مسخوطين': u'مَسْخُوطِينَ', #2
u'مسدة': u'مَسَدَةٌ', #2
u'مسدى': u'مُسَدًّى', #3
u'مسدى': u'مُسْدًى', #3
u'مسراى': u'مَسْرَاىَ', #1
u'مسربل': u'مُسَرْبَلٍ', #1
u'مسرعينوروي': u'مُسْرِعَيْنِوَرُوِيَ', #1
u'مسرهد،': u'مُسَرْهَدٍ،', #14
u'مسرهد': u'مُسَرْهَدٍ', #17
u'مسرهد،': u'مسرهد،', #4
u'مسروجة': u'مَسْرُوجَةً', #1
u'مسروح؟': u'مسروح؟', #1
u'مسروح': u'مَسْرُوحُ', #1
u'مسروح': u'مَسْرُوحٍ', #19
u'مسروح': u'مسروح', #3
u'مسروح': u'مَسْرُوح', #3
u'مسروح': u'مَسْرُوحٌ', #5
u'مسرود': u'مَسْرُودٍ', #10
u'مسرود': u'مَسْرُودٌ', #2
u'مسرودا': u'مَسْرُودًا', #1
u'مسرودة': u'مَسْرُودَةً', #2
u'مسرودتان': u'مَسْرُودَتَانِ', #3
u'مسروق': u'مَسْرُوقً', #1
u'مسروقأن': u'مَسْرُوقٍأَنَّ', #1
u'مسرى': u'مِسْرَى', #4
u'مسرى': u'مَسْرَى', #7
u'مسطاح': u'مِسْطَاحٍ', #2
u'مسطبا': u'مُسَطَّبًا', #2
u'مسطوحا': u'مَسْطُوحًا', #1
u'مسطوحتان': u'مَسْطُوحَتَانِ', #1
u'مسعط': u'مِسْعَطِ', #1
u'مسعط': u'مِسْعَطٌ', #2
u'مسعط': u'مُسْعَطٍ', #3
u'مسعط': u'مِسْعَطٍ', #3
u'مسعطا': u'مِسْعَطًا', #2
u'مسعودالقائل': u'مَسْعُودٍالْقَائِلِ', #1
u'مسعودأن': u'مَسْعُودٍأَنْ', #1
u'مسعودأن': u'مَسْعُودٍأَنَّ', #2
u'مسعودأنه': u'مَسْعُودٍأَنَّهُ', #1
u'مسعودثم': u'مَسْعُودٍثُمَّ', #1
u'مسعودلا': u'مَسْعُودٍلا', #1
u'مسعودما': u'مَسْعُودٍمَا', #1
u'مسعوطا': u'مَسْعُوطًا', #1
u'مسقط': u'مُسْقِطً', #1
u'مسقف': u'مُسَقَّفٌ', #12
u'مسقف': u'مُسْقَفٍ', #18
u'مسقف': u'مُسَقَّفٍ', #21
u'مسقف': u'مُسْقَفٌ', #4
u'مسقفا': u'مُسْقَفًا', #23
u'مسقفا': u'مُسَقَّفًا', #26
u'مسقفاته': u'مُسَقَّفَاتِهِ', #1
u'مسقفة': u'مُسْقَفَةً', #1
u'مسقفة': u'مُسَقَّفَةً', #3
u'مسقفة': u'مُسَقَّفَةٌ', #3
u'مسقفتين': u'مُسَقَّفَتَيْنِ', #2
u'مسقفتين': u'مُسْقَفَتَيْنِ', #2
u'مسقفين': u'مُسْقَفَيْنِ', #1
u'مسقلة': u'مُسْقِلَةٍ', #1
u'مسقلة': u'مَسْقَلَةُ', #3
u'مسقلة،': u'مَسْقَلَةَ،', #4
u'مسقلة': u'مَسْقَلَةَ', #5
u'مسقم': u'مُسَقَّمٌ', #1
u'مسقمة': u'مُسْقَمَةٌ', #1
u'مسقمة': u'مُسْقِمَةً', #1
u'مسقمة': u'مَسْقَمَةٌ', #5
u'مسقوطة': u'مَسْقُوطَةٍ', #2
u'مسقوف': u'مَسْقُوفٍ', #1
u'مسقوفا': u'مَسْقُوفًا', #5
u'مسقوفة': u'مَسْقُوفَةٍ', #1
u'مسقوفة،': u'مَسْقُوفَةٍ،', #1
u'مسقوفة': u'مَسْقُوفَةً', #2
u'مسقوفة': u'مَسْقُوفَةٌ', #8
u'مسكفة': u'مُسْكِفَةٍ', #1
u'مسكورا': u'مَسْكُورًا', #2
u'مسكورة': u'مَسْكُورَةٌ', #1
u'مسكويه': u'مَسْكَوَيْهِ', #1
u'مسلاخه،': u'مِسْلاخِهِ،', #1
u'مسلاخها': u'مِسْلاخِهَا', #1
u'مسلاخها': u'مِسْلاَخِهَا', #2
u'مسلان': u'مُسْلَانٌ', #1
u'مسلبا': u'مُسْلَبَا', #1
u'مسلبا': u'مُسْلِبَا', #1
u'مسلبة': u'مَسْلَبَةٌ', #1
u'مسلبة': u'مُسْلِبَةٌ', #2
u'مسلبة': u'مُسَلّبَةً', #3
u'مسلحبا': u'مُسْلَحِبّا', #2
u'مسلق': u'مُسْلِقٌ', #1
u'مسلق': u'مِسْلَقٌ', #1
u'مسلم': u'مُسْلِمً', #1
u'مسلمانم': u'مسلمانم', #2
u'مسلماني': u'مُسْلِمَانِيٌّ', #1
u'مسلماني': u'مسلماني', #10
u'مسلمانيا': u'مَسْلَمَانِيًّا', #1
u'مسلمةعندي': u'مَسْلَمَةَعِنْدِي', #1
u'مسلمدر': u'مسلمدر', #1
u'مسلمفي': u'مُسْلِمٍفِي', #1
u'مسلمفى': u'مُسْلِمٌفِى', #1
u'مسلموث': u'مُسْلِمُوث', #1
u'مسلنطح': u'مُسْلَنْطِحٌ', #1
u'مسلوماء': u'مَسْلُومَاءَ', #1
u'مسمطا': u'مُسَمَّطًا', #1
u'مسمور': u'مَسْمُورٍ', #3
u'مسمورة': u'مَسْمُورَةٍ', #2
u'مسموطا': u'مَسْمُوطًا', #4
u'مسموطة،': u'مَسْمُوطَةٍ،', #1
u'مسموطة': u'مَسْمُوطَةً', #2
u'مسمول': u'مَسْمُولَ', #1
u'مسمول': u'مَسْمُولٍ', #4
u'مسمونة': u'مَسْمُونَةٌ', #2
u'مسنأة': u'مُسَنَّأَةٌ', #1
u'مسناة': u'مَسْنَاةً', #1
u'مسناة': u'مُسْنَاةً', #1
u'مسناة': u'مُسَنَّاةً', #10
u'مسناة': u'مُسَنَّاةٍ', #13
u'مسناة': u'مُسَنَّاةُ', #2
u'مسناة': u'مُسَنَّاةٌ', #23
u'مسناة': u'مُسْنَاةٌ', #3
u'مسناة': u'مُسْنَاةٍ', #3
u'مسناة': u'مُسْنَاةُ', #3
u'مسناة': u'مُسَنَّاةِ', #4
u'مسنبل': u'مُسَنْبَلٍ', #1
u'مسنبلة': u'مُسَنْبَلَةٍ', #1
u'مسنتون،': u'مُسْنَتُونَ،', #1
u'مسنديته': u'مُسْنَدِيَّتِهِ', #1
u'مسنفات': u'مُسْنَفَاتٍ', #1
u'مسنفات': u'مُسْنِفَاتٌ', #2
u'مسنم': u'مُسَنَّمٌ', #11
u'مسنم': u'مُسَنَّمٍ', #3
u'مسنما': u'مُسَنَّمًا', #38
u'مسنمة': u'مُسَنَّمَةٍ', #1
u'مسنمة': u'مُسَنَّمَةُ', #1
u'مسنمة': u'مُسَنَّمَةً', #5
u'مسنمة': u'مُسَنَّمَةٌ', #6
u'مسنونية': u'مَسْنُونِيَّةَ', #1
u'مسنونية': u'مَسْنُونِيَّةِ', #2
u'مسنونيته': u'مَسْنُونِيَّتِهِ', #1
u'مسنى': u'مَسَّنِىَ', #1
u'مسنى': u'مَسَّنِى', #2
u'مسهر،': u'مُسْهَرٍ،', #1
u'مسهر،': u'مُسْهِرٍ،', #113
u'مسهر،': u'مسهر،', #12
u'مسهر': u'مسهر', #16
u'مسهر': u'مُسْهر', #2
u'مسهر': u'مُسْهَرٍ', #2
u'مسهر': u'مُسْهِرِ', #2
u'مسهر': u'مِسْهَرٍ', #2
u'مسهر': u'مُسْهِرٍ', #359
u'مسهر': u'مُسْهِرُ', #5
u'مسهر': u'مُسْهِر', #9
u'مسوءة': u'مَسْوَءَةٌ', #1
u'مسوأ': u'مَسْوَأٌ', #1
u'مسوح': u'مُسُوحٌ', #2
u'مسوح': u'مُسُوحٍ', #2
u'مسوحا': u'مُسُوحًا', #1
u'مسىء': u'مُسِىءٌ', #1
u'مسىء': u'مُسِىءُ', #6
u'مسئر': u'مُسْئِرٌ', #1
u'مسئره': u'مُسْئِرِهِ', #1
u'مسيجد': u'مُسَيْجِدٌ', #3
u'مسيجدا': u'مُسَيْجِدًا', #1
u'مسيحة': u'مَسِيحَةٍ', #1
u'مسيخ': u'مَسِيخُ', #1
u'مسيخ': u'مَسِيخٌ', #2
u'مسيخة': u'مَسِيخَةٌ', #1
u'مسيخة': u'مُسِيخَةٌ', #2
u'مسيرى': u'مَسِيرِى', #1
u'مسيكة،': u'مُسَيْكَةَ،', #2
u'مسيكة': u'مُسَيْكَةُ', #6
u'مسيكة': u'مُسَيْكَةَ', #9
u'مسيئ': u'مُسِيئٌ', #2
u'مشاتم': u'مَشَاتِمِ', #1
u'مشاتم': u'مُشَاتِمٌ', #1
u'مشاح': u'مُشَاحٍّ', #1
u'مشاحح': u'مُشَاحِحٌ', #1
u'مشاححة': u'مُشَاحَحَةٌ', #3
u'مشاححته': u'مُشَاحَحَتُهُ', #1
u'مشاحطة': u'مُشَاحَطَةَ', #1
u'مشاربا': u'مُشَارِبًا', #1
u'مشاررة': u'مُشَارَرَةٍ', #1
u'مشارس،': u'مُشَارِسٍ،', #3
u'مشارع': u'مَشَارِعُ', #1
u'مشارع': u'مَشَارِعَ', #3
u'مشارع': u'مَشَارِعِ', #7
u'مشارعة': u'مُشَارَعَةً', #1
u'مشارعه': u'مَشَارِعُهْ', #1
u'مشارفا': u'مَشَارِفًا', #1
u'مشارفا': u'مُشَارِفًا', #3
u'مشاش': u'مُشَاشٌ', #1
u'مشاش': u'مُشَاشٍ', #1
u'مشاش': u'مُشَاشِ', #1
u'مشاشك': u'مُشَاشِك', #1
u'مشاشه': u'مشاشه', #1
u'مشاشه': u'مُشَاشه', #3
u'مشاشه': u'مُشَاشِهِ', #4
u'مشاعية': u'مَشَاعِيَّةَ', #1
u'مشاعيته': u'مشاعيته', #1
u'مشاقص': u'مَشَاقِص', #1
u'مشاقص': u'مَشَاقِصَ', #10
u'مشاقصه': u'مُشَاقِصُهُ', #1
u'مشاقصها': u'مَشَاقِصِهَا', #1
u'مشاكلا': u'مُشَاكِلًا', #3
u'مشالة': u'مُشَالَةٌ', #1
u'مشالة': u'مُشَالَةٍ', #6
u'مشالتين': u'مُشَالَتَيْنِ', #2
u'مشاهرا': u'مُشَاهَرًا', #1
u'مشايخى': u'مَشَايِخِى', #1
u'مشبه': u'مُشَبَّهً', #1
u'مشتات': u'مُشِتَّاتٍ', #2
u'مشتات': u'مُشْتَاتٍ', #2
u'مشتاره': u'مُشْتَارَهُ', #1
u'مشتة': u'مُشِتَّةٍ', #2
u'مشتجر': u'مُشْتَجَرُ', #1
u'مشتجر': u'مُشْتَجِرُ', #1
u'مشتراة': u'مُشْتَرَاةَ', #1
u'مشتراة': u'مُشْتَرَاةُ', #1
u'مشتراة': u'مُشْتَرَاةٌ', #18
u'مشتراة': u'مُشْتَرَاةً', #36
u'مشتراة': u'مُشْتَرَاةٍ', #9
u'مشتراته': u'مُشْتَرَاتَهُ', #2
u'مشتراته': u'مُشْتَرَاتُهُ', #2
u'مشتراه': u'مُشْتَرَاهُ', #31
u'مشتراها': u'مُشْتَرَاهَا', #3
u'مشترف': u'مُشْتَرَف', #1
u'مشترف': u'مُشْتَرَفٍ', #1
u'مشترى': u'مُشْتَرَى', #16
u'مشترى': u'مُشْتَرًى', #172
u'مشترى': u'مشترى', #2
u'مشجج': u'مُشَجَّجٌ', #1
u'مشحل': u'مِشْحَلٍ', #1
u'مشخاصها': u'مِشْخَاصُهَا', #2
u'مشد': u'مَشَدِّ', #1
u'مشد': u'مِشَدُّ', #40
u'مشد': u'مِشَدِّ', #42
u'مشد': u'مِشَدَّ', #6
u'مشدة': u'مِشَدَّةٍ', #1
u'مشدخ': u'مُشَدَّخٍ', #7
u'مشدخا': u'مُشَدَّخًا', #5
u'مشدخين': u'مُشَدَّخِينَ', #1
u'مشده': u'مِشَدِّهِ', #1
u'مشدها': u'مِشَدُّهَا', #1
u'مشدها': u'مِشَدِّهَا', #1
u'مشدهم': u'مُشِدُّهُمْ', #2
u'مشدوخ': u'مَشْدُوخٍ', #1
u'مشدوخا': u'مَشْدُوخًا', #1
u'مشدي': u'مشدي', #1
u'مشدي': u'مِشَدِّي', #1
u'مشرب': u'مُشْرَبً', #1
u'مشرخا': u'مُشَرَّخًا', #1
u'مشرز': u'مُشَرَّزٌ', #2
u'مشرز': u'مُشَرَّزٍ', #2
u'مشرس': u'مِشْرَسٌ', #1
u'مشركوا': u'مشركوا', #3
u'مشركوا': u'مُشْرِكُوا', #6
u'مشركى': u'مُشْرِكِى', #6
u'مشرور': u'مَشْرُورٍ', #1
u'مشروطية': u'مَشْرُوطِيَّةَ', #1
u'مشروطية': u'مَشْرُوطِيَّةِ', #3
u'مشروف': u'مَشْرُوفٍ', #1
u'مشرى': u'مُشْرَى', #1
u'مشريته': u'مَشْرِيَّتَهُ', #1
u'مشريه': u'مُشْرِيه', #2
u'مشريه': u'مُشْرِيهِ', #2
u'مشريه': u'مَشْرِيِّهِ', #5
u'مشزور': u'مَشْزُورٍ', #2
u'مشطاح': u'مِشْطَاحٌ', #1
u'مشطح': u'مِشْطَحٌ', #1
u'مشطيشا': u'مشطيشا', #1
u'مشعار': u'مِشْعَارٌ', #3
u'مشعبة': u'مُشَعَّبَةٌ', #2
u'مشعشعا': u'مُشَعْشَعًا', #2
u'مشعشعة': u'مُشَعْشَعَةً', #1
u'مشعور': u'مَشْعُورٌ', #2
u'مشعور': u'مَشْعُورٍ', #3
u'مشعورا': u'مَشْعُورًا', #2
u'مشغولية': u'مَشْغُولِيَّةُ', #2
u'مشف': u'مُشْفٍ', #1
u'مشفا': u'مُشِفًّا', #1
u'مشفوعة': u'مَشْفُوعَةً', #1
u'مشفوعه': u'مَشْفُوعَهُ', #2
u'مشفوفا': u'مَشْفُوفًا', #2
u'مشفوها': u'مَشْفُوهًا', #7
u'مشقص': u'مُشَقَّصٍ', #1
u'مشقص': u'مِشْقَصٌ', #1
u'مشقص': u'مشقص', #2
u'مشقص': u'مِشْقَص', #2
u'مشقص': u'مِشْقَصٍ', #3
u'مشقصا': u'مُشَقَّصًا', #10
u'مشقصا': u'مُشَقِّصًا', #2
u'مشقصا': u'مِشْقَصًا', #9
u'مشقصة': u'مُشَقَّصَةٍ', #1
u'مشقصى': u'مِشْقَصِى', #1
u'مشكدانة': u'مشكدانة', #1
u'مشكدانة': u'مُشْكُدَانَةَ', #1
u'مشكدانة،': u'مُشْكُدَانَةَ،', #1
u'مشكدانه': u'مُشْكَدَانَهْ', #1
u'مشمخة': u'مَشْمَخَةَ', #1
u'مشمعل': u'مُشْمَعِلُّ', #1
u'مشمعل': u'مُشْمِعَلّ', #1
u'مشنة': u'مِشَنَّةِ', #1
u'مشندخ': u'مُشَنْدَخٌ', #2
u'مشنق': u'مُشْنِقٌ', #1
u'مشنق': u'مُشَنَّقُ', #2
u'مشنق': u'مُشْنِق', #6
u'مشنو': u'مَشْنُوّ', #2
u'مشنوء': u'مَشْنُوءِ', #3
u'مشهوريته': u'مَشْهُورِيَّتِهِ', #1
u'مشوف': u'مَشُوفٌ', #1
u'مشوف': u'مُشَوَّفٌ', #3
u'مشوم': u'مَشُومُ', #1
u'مشيء': u'مَشِيءٌ', #1
u'مشيء': u'مُشِيءٍ', #1
u'مشيء': u'مُشِيءٌ', #2
u'مشئوم،': u'مشئوم،', #1
u'مشئوم': u'مَشْئُوم', #1
u'مشئوم': u'مَشْئُومٍ', #1
u'مشئوم': u'مَشْئُومٌ', #16
u'مشئوم': u'مَشْئُومُ', #2
u'مشئوما': u'مَشْئُومًا', #3
u'مشئومة': u'مَشْئُومَةً', #3
u'مشئومة': u'مَشْئُومَةٌ', #6
u'مشئومين': u'مَشْئُومَيْنِ', #1
u'مشياته': u'مَشَيَاتِهِ', #1
u'مشية': u'مشية', #1
u'مشية': u'مِشْيَةٍ', #1
u'مشية': u'مِشْيَةَ', #10
u'مشية': u'مِشْيَةٌ', #12
u'مشية': u'مِشْيَةُ', #13
u'مشية': u'مِشْيَة', #2
u'مشية': u'مِشْيَةً', #3
u'مشية': u'مِشْيَةِ', #3
u'مشيح': u'مَشِيحٍ', #1
u'مشيح': u'مُشِيحٌ', #1
u'مشيح': u'مُشِيحٍ', #1
u'مشيحا': u'مُشِيحًا', #1
u'مشيش': u'مُشَيْشٍ', #34
u'مشيش': u'مشيش', #4
u'مشيقة': u'مَشِيقَةَ', #1
u'مشيوا،': u'مَشْيُوا،', #1
u'مشيى': u'مَشْيِى', #1
u'مصابر': u'مُصَابِرٌ', #1
u'مصابر': u'مُصَابِرِ', #1
u'مصادة': u'مُصَادَةٍ', #1
u'مصارما': u'مُصَارِمًا', #1
u'مصاري': u'مَصَارِيٌّ', #1
u'مصاري': u'مِصَارِي', #1
u'مصاطب': u'مَصَاطِبَ', #1
u'مصاطب': u'مَصَاطِبِ', #6
u'مصافا': u'مُصَافًّا', #3
u'مصافع': u'مُصَافِعٍ', #1
u'مصافو': u'مُصَافُو', #1
u'مصافو': u'مُصَافُّو', #2
u'مصافوا': u'مُصَافُّوا', #1
u'مصافون': u'مُصَافُّونَ', #1
u'مصافوه': u'مُصَافُوهُ', #1
u'مصافى': u'مُصَافِّى', #1
u'مصاقعة': u'مُصَاقَعَةِ', #1
u'مصالا': u'مَصَالًا', #4
u'مصاليت': u'مصاليت', #1
u'مصاليت': u'مَصَالِيتُ', #1
u'مصاليت': u'مَصَالِيتَ', #3
u'مصاما': u'مَصَامًا', #1
u'مصاوب': u'مَصَاوِبُ', #3
u'مصبحوا': u'مُصَبِّحُوا', #1
u'مصتكى': u'مُصْتَكَى', #1
u'مصحبات': u'مُصْحبات', #1
u'مصحمة': u'مَصْحَمَةُ', #1
u'مصحمة،': u'مَصْحَمَةَ،', #1
u'مصد': u'مَصَدِّ', #1
u'مصد': u'مُصِدٌّ', #1
u'مصدرانية': u'مَصْدَرَانِيَّةً', #1
u'مصدريته': u'مَصْدَرِيَّتُهُ', #1
u'مصدريته': u'مَصْدَرِيَّتِهِ', #13
u'مصدريتها': u'مَصْدَرِيَّتِهَا', #3
u'مصدريتهما': u'مَصْدَرِيَّتهمَا', #1
u'مصدريتهما': u'مَصْدَرِيَّتِهِمَا', #1
u'مصدقى': u'مُصَدِّقِىَّ', #1
u'مصدقى؟': u'مُصَدِّقِىَّ؟', #1
u'مصدم': u'مصدم', #1
u'مصدم': u'مَصْدَمِ', #2
u'مصدي': u'مُصَدِّيٍّ', #1
u'مصراة': u'مُصَرَّاةِ', #1
u'مصراة': u'مُصْرَاةٌ', #1
u'مصراة': u'مُصَرَّاةً', #111
u'مصراة': u'مُصَرَّاةٌ', #18
u'مصراة': u'مُصَرَّاة', #2
u'مصراة': u'مُصَرَّاةَ', #2
u'مصراة': u'مُصَرَّاةٍ', #31
u'مصراة': u'مُصْرَاةً', #4
u'مصراة،': u'مُصَرَّاةً،', #8
u'مصررة': u'مُصْرَرَةً', #1
u'مصررة': u'مُصَرَّرَةً', #2
u'مصررة': u'مُصَرَّرَةٌ', #5
u'مصرعون': u'مُصَرّعُونَ', #1
u'مصرعى': u'مَصْرَعِى', #1
u'مصرمة': u'مُصَرِّمَةٌ', #1
u'مصرمة': u'مُصَرّمَةً', #2
u'مصرور': u'مَصْرُورٌ', #2
u'مصرورا': u'مَصْرُورًا', #3
u'مصرورة': u'مَصْرُورَة', #1
u'مصرورة': u'مَصْرُورَةٌ', #11
u'مصرورة': u'مَصْرُورَةً', #22
u'مصرورة': u'مَصْرُورَةٍ', #3
u'مصرورين': u'مَصْرُورِينَ', #3
u'مصرى': u'مِصْرِىٍّ', #1
u'مصرى': u'مِصْرِىٌّ', #2
u'مصرى': u'مِصْرِىُّ', #2
u'مصطارا': u'مِصْطَارًا', #1
u'مصطبحا': u'مُصْطَبِحًا', #1
u'مصطح': u'مِصْطَحُ', #1
u'مصطخدا': u'مُصْطَخِدًا', #2
u'مصطك': u'مُصْطَكِّ', #2
u'مصطكا': u'مُصْطَكَا', #1
u'مصطلاهما': u'مُصْطَلَاهُمَا', #1
u'مصع': u'مَصَعَ', #1
u'مصع': u'مَصْعُ', #1
u'مصع': u'مَصْعِ', #6
u'مصعته': u'مَصَعَتْهُ', #2
u'مصفارا،': u'مِصْفَارًا،', #1
u'مصفودان': u'مَصْفُودَانِ', #1
u'مصفور': u'مَصْفُورٌ', #1
u'مصقور': u'مَصْقُور', #1
u'مصلتا': u'مُصْلِتًا', #8
u'مصلتين': u'مُصْلِتين', #1
u'مصلتين،': u'مُصْلِتِينَ،', #1
u'مصلتين': u'مُصْلِتِينَ', #2
u'مصلتينا': u'مُصَلّتِينَا', #1
u'مصلتينا': u'مُصْلِتِينَا', #1
u'مصلحت': u'مصلحت', #3
u'مصلق': u'مَصْلَقٍ', #1
u'مصلم': u'مُصَلَّمُ', #1
u'مصلم': u'مُصَلَّمِ', #1
u'مصلمة': u'مُصَلَّمَةُ', #1
u'مصلوحا': u'مَصْلُوحًا', #2
u'مصلوق': u'مَصْلُوقٌ', #3
u'مصلوقا': u'مَصْلُوقًا', #1
u'مصوفة': u'مُصَوَّفَةٌ', #1
u'مصيبت': u'مصيبت', #1
u'مصيبتى': u'مُصِيبَتِى', #4
u'مصيح': u'مُصَيَّحٍ', #1
u'مصيحف': u'مُصَيْحِفٌ', #5
u'مصيحفا': u'مُصَيْحِفًا', #1
u'مصيخا': u'مُصِيخًا', #1
u'مصيخة': u'مُصِيخَة', #2
u'مصيخة': u'مُصِيخَةٌ', #8
u'مصيقلا': u'مُصَيْقَلًا', #1
u'مضآر': u'مُضَآرٍّ', #1
u'مضارا': u'مَضَارًّا', #1
u'مضارا': u'مُضَارًّا', #19
u'مضاررا': u'مُضَارِرًا', #1
u'مضاررتها': u'مُضَارَرَتُهَا', #1
u'مضاعة': u'مُضَاعَةً', #2
u'مضاعين': u'مُضَاعِينَ', #1
u'مضاغي': u'مَضَاغِي', #2
u'مضائق': u'مَضَائِقِ', #2
u'مضايعهم': u'مَضَايِعِهِمْ', #3
u'مضايفة': u'مُضَايَفَةً', #1
u'مضايفة': u'مُضَايَفَةُ', #1
u'مضبب': u'مُضَبَّبَ', #2
u'مضبب': u'مُضَبَّبٍ', #4
u'مضبب': u'مُضَبَّبٌ', #9
u'مضببا': u'مُضَبَّبًا', #6
u'مضببة': u'مَضْبَبَة', #1
u'مضببة': u'مُضَبَّبَةٌ', #1
u'مضببة': u'مُضَبَّبَةً', #3
u'مضبر': u'مُضَبّرُ', #2
u'مضبورا': u'مَضْبُورًا', #1
u'مضترر': u'مُضْتَرَرٌ', #3
u'مضجعة': u'مُضَّجِعَةً', #1
u'مضجعة': u'مُضْجَعَةٍ', #1
u'مضجعة': u'مُضْجِعَةٌ', #1
u'مضجعة': u'مُضْجَعَةً', #14
u'مضحى': u'مُضَحًّى', #1
u'مضحى': u'مُضَحٍّى', #1
u'مضحى': u'مُضْحًى', #1
u'مضروبية': u'مَضْرُوبِيَّةُ', #1
u'مضروبية': u'مَضْرُوبِيَّةِ', #1
u'مضرور': u'مَضْرُورِ', #1
u'مضرور': u'مَضْرُورٍ', #3
u'مضرور': u'مَضْرُورٌ', #4
u'مضرورا': u'مَضْرُورًا', #2
u'مضطبع': u'مُضْطَبِعٌ', #4
u'مضطبعا': u'مُضْطَبِعًا', #23
u'مضطردا': u'مُضْطَرِدًا', #1
u'مضطمر': u'مُضْطَمِرُ', #1
u'مضعوف': u'مَضْعُوفٌ', #1
u'مضعوف': u'مَضْعُوفَ', #1
u'مضعوفين': u'مَضْعُوفِينَ', #1
u'مضعوفين': u'مَضْعُوفَيْنِ', #1
u'مضفر': u'مُضَفَّرٌ', #1
u'مضفر': u'مُضَفَّرَ', #1
u'مضفر': u'مُضَفِّرٍ', #1
u'مضفرا': u'مُضَفِّرًا', #2
u'مضفرا': u'مُضَفَّرًا', #3
u'مضمان': u'مِضْمَانٌ', #2
u'مضمان': u'مِضْمَانٍ', #4
u'مضمخ': u'مُضَمَّخٌ', #2
u'مضمخا': u'مُضَمَّخًا', #1
u'مضمخان': u'مُضَمَّخَانِ', #1
u'مضمخة': u'مُضَمَّخَةٌ', #1
u'مضمونيتها': u'مَضْمُونِيَّتِهَا', #2
u'مضنك': u'مُضْنَكٌ', #1
u'مضىء': u'مُضِىءٌ', #1
u'مضيرة': u'مَضِيرَةً', #1
u'مضيرة': u'مَضِيرَةٌ', #1
u'مضيما': u'مُضِيمًا', #2
u'مضيوف': u'مَضْيُوفٌ', #1
u'مطابقيا': u'مُطَابِقِيًّا', #1
u'مطابقية': u'مُطَابَقِيَّة', #1
u'مطابقية': u'مُطَابَقِيَّةً', #1
u'مطابقية': u'مُطَابِقِيَّةً', #1
u'مطابقية': u'مُطَابِقِيَّةٌ', #1
u'مطارة': u'مُطَارَةٌ', #1
u'مطارة': u'مَطَارَةٌ', #2
u'مطاطئا': u'مُطَاطِئًا', #1
u'مطاليب': u'مَطَالِيب', #1
u'مطاول': u'مُطَاوِلٌ', #1
u'مطبوب': u'مَطْبُوب', #1
u'مطبوب': u'مَطْبُوبٍ', #1
u'مطبوب،': u'مَطْبُوبٌ،', #1
u'مطبوب': u'مَطْبُوبٌ', #13
u'مطبوبا': u'مَطْبُوبًا', #1
u'مطبوبة': u'مَطْبُوبَةٍ', #2
u'مطبوق': u'مَطْبُوقٌ', #1
u'مطبوقا': u'مَطْبُوقًا', #1
u'مطبوقة': u'مَطْبُوقَةً', #7
u'مطحولين': u'مَطْحُولِينَ', #1
u'مطراة': u'مُطَرَّاة', #2
u'مطراة': u'مُطَرَّاةٍ', #3
u'مطرخم': u'مُطَرَخِمّ', #2
u'مطرخمي': u'مُطْرَخِمي', #1
u'مطرخمي': u'مُطْرَخِمّي', #2
u'مطرس': u'مَطْرَسْ', #1
u'مطرس': u'مُطَرَّسٌ', #1
u'مطرس': u'مطرس', #2
u'مطرفعن': u'مُطَرِّفٌعَنْ', #1
u'مطرور': u'مَطْرُورٌ', #1
u'مطرورة': u'مَطْرُورَةٍ', #1
u'مطرورة': u'مَطْرُورَةِ', #1
u'مطرى': u'مُطَرِّى', #1
u'مطعم': u'مُطْعِمً', #1
u'مطعوميتها': u'مَطْعُومِيَّتَهَا', #1
u'مطغ': u'مُطْغٍ', #2
u'مطغيا': u'مُطْغِيًا', #3
u'مطغيات': u'مُطْغِيَاتِ', #2
u'مطفل': u'مُطْفِلٌ', #2
u'مطلق': u'مُطْلَقً', #2
u'مطلوب': u'مَطْلُوبً', #1
u'مطلوبية': u'مَطْلُوبِيَّةً', #1
u'مطلوبية': u'مَطْلُوبِيَّةَ', #10
u'مطلوبية': u'مَطْلُوبِيَّةِ', #13
u'مطلوبيته': u'مَطْلُوبِيَّتَهُ', #1
u'مطلوبيته': u'مَطْلُوبِيَّتِهِ', #5
u'مطلوبيتها': u'مَطْلُوبِيَّتُهَا', #1
u'مطلوبيتها': u'مَطْلُوبِيَّتَهَا', #3
u'مطلوبيتها': u'مَطْلُوبِيَّتِهَا', #3
u'مطلوة': u'مَطْلُوَّةً', #1
u'مطلوع': u'مَطْلُوع', #1
u'مطلوقة': u'مَطْلُوقَةٌ', #5
u'مطلول': u'مَطْلُولٌ', #1
u'مطلول': u'مَطْلُولُ', #2
u'مطلولة': u'مَطْلُولَةٌ', #1
u'مطلوي': u'مَطْلُويٌ', #1
u'مطلى': u'مُطْلًى', #1
u'مطلى': u'مَطْلِىٍّ', #2
u'مطليا': u'مُطَّلِيًا', #1
u'مطليا': u'مَطْلِيًّا', #2
u'مطلية': u'مَطْلِيَّةٌ', #1
u'مطلية': u'مَطْلِيَّة', #2
u'مطلية': u'مَطْلِيَّةٍ', #2
u'مطلية': u'مَطْلِيَّةً', #3
u'مطليق': u'مِطْلِيقٌ', #1
u'مطليقهن': u'مُطَلِّيقِهِنَّ', #1
u'مطموع': u'مَطْمُوعٌ', #2
u'مطموعا': u'مَطْمُوعًا', #2
u'مطموم': u'مَطْمُومٌ', #1
u'مطموم': u'مَطْمُومٍ', #1
u'مطموم': u'مَطْمُومِ', #1
u'مطموم': u'مَطْمُوم', #2
u'مطموم': u'مَطْمُومُ', #6
u'مطموما': u'مَطْمُومًا', #2
u'مطمومة': u'مَطْمُومَةٌ', #2
u'مطيعهذه': u'مُطِيعٍهَذِهِ', #1
u'مطيفا': u'مُطِيفًا', #1
u'مطيفون': u'مُطِيفُونَ', #1
u'مطيلسين': u'مطيلسين', #1
u'مطيلسين': u'مُطَيْلَسِينَ', #1
u'مطينة': u'مُطَيَّنَةً', #3
u'مطينة': u'مُطَيَّنَةٍ', #5
u'مظانا': u'مَظَانًّا', #1
u'مظاهرا': u'مُظَاهِرًا', #401
u'مظاهرا': u'مُظَاهَرًا', #7
u'مظاهرين': u'مُظَاهِرِينَ', #3
u'مظطلم': u'مُظْطَلِمٍ', #1
u'مظعون،': u'مظعون،', #1
u'مظعون،': u'مظْعُون،', #1
u'مظعون': u'مَظْعُونَ', #1
u'مظعون،': u'مَظْعُونٍ،', #11
u'مظعون': u'مظعون', #16
u'مظعون': u'مَظْعُونِ', #19
u'مظعون': u'مَظْعُونٍ', #236
u'مظعون': u'مَظْعُون', #3
u'مظعونة': u'مَظْعُونَةٌ', #1
u'مظفور': u'مَظْفُورٍ', #1
u'مظلمون': u'مُظْلِمُونَ', #2
u'مظلوميته': u'مَظْلُومِيَّتَهُ', #2
u'مظلوميته': u'مَظْلُومِيَّتِهِ', #2
u'مظنونية': u'مَظْنُونِيَّةً', #1
u'مظهور': u'مَظْهُورٌ', #2
u'معاتيقهم': u'مَعَاتِيقِهِمْ', #1
u'معاتيقهن': u'مَعَاتِيقَهُنَّ', #1
u'معاتيقهن': u'مَعَاتِيقُهُنَّ', #1
u'معاجزين': u'مُعَاجِزِينَ', #6
u'معاجلا': u'مُعَاجِلَا', #2
u'معاجيمه': u'مَعَاجِيمِهِ', #1
u'معادد': u'مُعَادِدٌ', #1
u'معاددة': u'مُعَادَدَةً', #1
u'معادى': u'مَعَادِى', #1
u'معاذSمن': u'مُعَاذٍSمِنْ', #1
u'معاذ،': u'مُعَاذً،', #1
u'معاذأيضا': u'مُعَاذٌأَيْضًا', #1
u'معاذيرا': u'مَعَاذِيرَا', #1
u'معارفة': u'مُعَارَفَةً', #1
u'معارية': u'مُعَارِيَةٌ', #1
u'معاشى': u'مَعَاشِى', #1
u'معاصى': u'مَعَاصِى', #1
u'معاطاة': u'مُعَاطَاةَ', #1
u'معاطاة': u'مُعَاطَاةً', #15
u'معاطاة': u'مُعَاطَاةٍ', #16
u'معاطاة': u'مُعَاطَاةِ', #2
u'معاطاة': u'مُعَاطَاةُ', #3
u'معاطاة': u'مُعَاطَاةٌ', #5
u'معاطنا': u'مَعَاطِنًا', #1
u'معاطيف': u'مَعَاطِيفٌ', #1
u'معافا': u'مُعَافًا', #1
u'معافر': u'معافر', #1
u'معافر': u'مَعَافِرٌ', #1
u'معافر': u'مَعَافِرَِِِِ', #1
u'معافر': u'مَعَافِرِ', #1
u'معافر': u'مَعَافِرُ', #2
u'معافر،': u'مَعَافِرَ،', #2
u'معافر': u'مَعَافِرَ', #24
u'معافري': u'مَعَافِرِيّ', #1
u'معافري': u'مَعَافِرِيٍّ', #1
u'معافري': u'مَعَافِرِيَّ', #1
u'معافرى': u'مَعَافِرِىٌّ', #1
u'معافري': u'مَعَافِرِيٌّ', #3
u'معافريا': u'مَعَافِرِيًّا', #1
u'معافرية': u'مَعَافِرِيّةٌ', #1
u'معافريك': u'مَعَافِرِيَّكَ', #1
u'معافريه': u'مَعَافِرِيَّهُ', #1
u'معافصة': u'مُعَافَصَةً', #2
u'معاقبني': u'مُعَاقِبَنِي', #1
u'معاقبى': u'مُعَاقِبِى', #1
u'معاقد': u'معاقد', #1
u'معاقد': u'مُعَاقَد', #1
u'معاقد': u'مُعَاقَدِ', #1
u'معاقد': u'مَعَاقِدَ', #3
u'معاقد': u'مَعَاقِدِ', #3
u'معاقد': u'مَعَاقِدُ', #8
u'معاقده': u'مَعَاقِده', #1
u'معاقده': u'مَعَاقِدَهُ', #1
u'معاقده': u'مَعَاقِدُهُ', #1
u'معاقده': u'مُعَاقَدُهُ', #1
u'معاقده': u'مُعَاقِدُهُ', #4
u'معاقده': u'مُعَاقِدِهِ', #4
u'معاقدها': u'مَعَاقِدَهَا', #1
u'معاقرا': u'مُعَاقِرًا', #1
u'معاكمة': u'مُعَاكَمَةٌ', #1
u'معالقا': u'مَعَالِقًا', #1
u'معالنبي': u'مَعَالنَّبِيِّ', #1
u'معالى': u'مَعَالِىَ', #1
u'معاليم': u'مَعَالِيمُ', #1
u'معاليم': u'مَعَالِيمَ', #4
u'معاليم': u'مَعَالِيمِ', #5
u'معاليمهم': u'مَعَالِيمِهِمْ', #2
u'معاليمهم': u'مَعَالِيمَهُمْ', #4
u'معاماة': u'مُعَامَاةً', #1
u'معانى': u'مَعَانِىَ', #13
u'معانى': u'معانى', #1635
u'معانى': u'مَعَانِى', #18
u'معانيق': u'مَعَانِيقَ', #2
u'معانيق': u'مَعَانِيقُ', #2
u'معاوض': u'مُعَاوِضٌ', #1
u'معاوض': u'مُعَاوِضٍ', #1
u'معاوض': u'مُعَاوِضَ', #2
u'معاوضا': u'مُعَاوَضًا', #2
u'معاوضه': u'مُعَاوَضَهُ', #1
u'معاوضه': u'مُعَاوِضُهُ', #1
u'معاوي': u'مُعَاوِيّ', #1
u'معاوي': u'مُعَاوِي', #2
u'معاوي': u'مُعَاوِيَ', #3
u'معاويا': u'مُعَاوِيَا', #1
u'معاويه': u'مُعَاوِيَهْ', #4
u'معايبة': u'مُعَايَبَةً', #1
u'معبابا': u'مُعْبَابَا', #1
u'معبسا': u'مُعَبِّسًا', #1
u'معبط': u'مُعْبَطٍ', #1
u'معبوداء': u'مَعْبُودَاءُ', #1
u'معبودية': u'مَعْبُودِيَّةِ', #1
u'معبى': u'مُعَبًّى', #1
u'معة': u'معة', #2
u'معتار': u'معتار', #1
u'معتاض': u'مُعْتَاضٍ', #1
u'معتاض': u'مُعْتَاضٌ', #2
u'معتاط': u'مُعْتَاط', #1
u'معتاط': u'مُعْتَاطٍ', #3
u'معتبد': u'مُعْتَبَدٌ', #1
u'معتبره': u'مُعْتَبَرَهً', #1
u'معتجر': u'مُعْتَجِرٍ', #1
u'معتجر': u'مُعْتَجِرٌ', #4
u'معتجرا': u'مُعْتَجِراً', #1
u'معتجرا': u'مُعْتَجِرًا', #19
u'معتجرات': u'مُعْتِجِرَاتٍ', #1
u'معتجزا': u'مُعْتَجِزًا', #2
u'معترا': u'مُعَتّرًا', #1
u'معتره': u'مُعَتَّرَهُ', #1
u'معتسل': u'معتسل', #1
u'معتص': u'مُعْتَصٍ', #2
u'معتضد': u'مُعْتَضَدٌ', #1
u'معتضد': u'مُعْتَضِدٌ', #2
u'معتضدا': u'مُعْتَضَدًا', #3
u'معتضدا': u'مُعْتَضِدًا', #4
u'معتضدة': u'مُعْتَضِدَةٌ', #1
u'معتضدة': u'مُعْتَضَدَةٌ', #2
u'معتقد': u'مُعْتَقِدً', #1
u'معتقون': u'مُعْتَقُونً', #1
u'معتقية': u'مُعْتَقِيَّةُ', #1
u'معتقين': u'مُعْتَقِينً', #1
u'معتلث': u'مُعْتَلِثِ', #3
u'معتلج': u'مُعْتَلِجُ', #3
u'معتلف': u'مُعْتَلَفٍ', #1
u'معتلف': u'مُعْتَلَفٌ', #4
u'معتلفة': u'مَعْتَلَفَةٍ', #1
u'معتلفة': u'مُعْتَلِفَةٌ', #1
u'معتلفة': u'مُعْتَلِفَةٍ', #1
u'معتمل': u'مُعْتَمَلٍ', #1
u'معتمل': u'مُعْتَمِلٍ', #25
u'معتمل': u'مُعْتَمِلٌ', #5
u'معتملا': u'مُعْتَمَلًا', #3
u'معتملا': u'مُعْتَمِلًا', #9
u'معتمله': u'مُعْتَمَلَهْ', #1
u'معتنزا': u'مُعْتَنِزًا', #2
u'معتوبا': u'مَعْتُوبًا', #1
u'معتوران': u'مُعْتَوِرَانِ', #1
u'معتوق': u'مَعْتُوقٌ', #13
u'معتوق': u'مَعْتُوقٍ', #2
u'معتوقا': u'مَعْتُوقًا', #2
u'معتوقة': u'مَعْتُوقَةً', #2
u'معتوقة': u'مَعْتُوقَةٌ', #2
u'معتوقته': u'مَعْتُوقَتَهُ', #1
u'معتوقته': u'مَعْتُوقَتُهُ', #1
u'معتوقته': u'مَعْتُوقَتِهِ', #1
u'معتوقي': u'مَعْتُوقِي', #1
u'معج': u'مَعْجِ', #3
u'معجر': u'مِعْجَرِ', #1
u'معجزى': u'مُعْجِزِى', #1
u'معجوز': u'مَعْجُوزُ', #1
u'معجوز': u'مَعْجُوزٌ', #17
u'معجوز': u'مَعْجُوزٍ', #17
u'معجوز': u'مَعْجُوزِ', #3
u'معجوز': u'مَعْجُوزَ', #6
u'معجوزا': u'مَعْجُوزًا', #9
u'معجوزه': u'مَعْجُوزُهُ', #1
u'معجوزه': u'مَعْجُوزَهُ', #10
u'معدمS': u'مُعْدِمِS', #1
u'معدومون': u'مَعْدُومُونَ', #1
u'معدى': u'مَعْدِىُّ', #2
u'معدى': u'مُعْدًى', #2
u'معدى': u'مَعْدِى', #3
u'معدى': u'مُعَدًّى', #6
u'معديكرب،': u'مَعْدِيكَرِبَ،', #1
u'معديكرب': u'مَعْدِيكَرِبَ', #19
u'معذار': u'مِعْذَارٌ', #1
u'معذبيته': u'مَعْذَبِيَّتُهُ', #1
u'معراض': u'مِعْرَاضٌ', #3
u'معراض': u'مِعْرَاضٍ', #8
u'معراضا': u'مِعْرَاضًا', #2
u'معراقا': u'مِعْرَاقًا', #1
u'معرج': u'مَعْرَجٍ', #1
u'معرج': u'مُعَرِّجٍ', #1
u'معرجا': u'مُعَرَّجًا', #1
u'معرد': u'معرد', #1
u'معرص': u'مُعَرَّصٌ', #1
u'معرص': u'مُعَرَّصُ', #2
u'معرص': u'مُعَرِّصُ', #2
u'معرص': u'مُعَرِّصٍ', #3
u'معرما': u'مُعَرَّمًا', #1
u'معروة': u'مَعْرُوَّةٌ', #1
u'معروج': u'مَعْرُوجٍ', #1
u'معرودة': u'مَعْرُودَةٌ', #1
u'معرور': u'مَعْرُورٌ', #1
u'معرور': u'مَعْرُورُ', #1
u'معرور،': u'مَعْرُور،', #1
u'معرور': u'مَعْرُورِ', #12
u'معرور': u'معرور', #3
u'معرور،': u'مَعْرُورٍ،', #6
u'معرور': u'مَعْرُورٍ', #89
u'معرورا': u'مَعْرُورًا', #5
u'معروري': u'مُعْرَوْرِيّ', #1
u'معرورى': u'مُعْرَورًى', #1
u'معرورى': u'مُعْرَوْرَى', #1
u'معرورى': u'مُعْرَوْرًى', #11
u'معروريا': u'مَعْرُورِيًّا', #1
u'معروريا': u'مُعْرَوْرِيًا', #14
u'معروريا': u'مُعْرَوْرِيًّا', #3
u'معروش': u'مَعْرُوشٍ', #1
u'معروشات': u'مَعْرُوشَاتٍ', #8
u'معروضية': u'مَعْرُوضِيَّةِ', #1
u'معروضيتها': u'مَعْرُوضِيَّتِهَا', #1
u'معروفست': u'معروفست', #1
u'معروفية': u'مَعْرُوفِيَّةِ', #2
u'معروق': u'معروق', #2
u'معزور': u'مَعْزُورٌ', #1
u'معزورا': u'مَعْزُورًا', #1
u'معزوم': u'مَعْزُومٌ', #10
u'معزوم': u'مَعْزُومٍ', #6
u'معزوما': u'مَعْزُومًا', #2
u'معزومات': u'مَعْزُومَاتِ', #1
u'معزوماتها': u'مَعْزُومَاتِهَا', #3
u'معزومها': u'مَعْزُومِهَا', #3
u'معزى': u'مُعْزًى', #1
u'معزى': u'مِعْزًى', #1
u'معزى': u'مُعَزًّى', #3
u'معسفه': u'مَعْسَفُهُ', #1
u'معسود': u'معسود', #3
u'معشرالمسلمين': u'مَعْشَرَالْمُسْلِمِينَ', #1
u'معشقة': u'مُعَشَّقَةً', #1
u'معشور': u'مَعْشُورٌ', #2
u'معشورا': u'مَعْشُورًا', #2
u'معشورة': u'مَعْشُورَةً', #1
u'معشورة': u'مَعْشُورَةٍ', #2
u'معصت': u'مَعِصَتْ', #1
u'معصفر': u'مُعَصْفَرٍ', #14
u'معصفر': u'مُعَصْفَرٌ', #2
u'معصفرا،': u'معصفرًا،', #1
u'معصفرا': u'مُعَصْفَرًا', #13
u'معصفران،': u'مُعَصْفَرَانِ،', #2
u'معصفران': u'مُعَصْفَرَانِ', #3
u'معصفرة': u'معصفرة', #1
u'معصفرة': u'مُعَصْفَرَةً', #1
u'معصفرة': u'مُعَصْفَرَةٍ', #1
u'معصفرة،': u'مُعَصْفَرَةٌ،', #1
u'معصفرة،': u'مُعَصْفَرَةٍ،', #1
u'معصفرة': u'مُعَصْفَرَةٌ', #10
u'معصفرين': u'مُعَصْفَرَيْنِ', #14
u'معصفرين،': u'مُعَصْفَرَيْنِ،', #3
u'معصمون': u'مُعْصَمُونَ', #1
u'معصوصب': u'مُعْصَوْصَبٍ', #2
u'معض': u'مَعَضَّ', #1
u'معض': u'مَعَضُّ', #1
u'معض': u'مَعَضِّ', #3
u'معضا': u'مَعْضًا', #2
u'معضالا': u'مِعْضَالا', #1
u'معضه': u'مَعَضَّهَ', #1
u'معضه': u'مَعَضِّهِ', #1
u'معضه': u'مَعَضَّهُ', #4
u'معضوب': u'مَعْضُوبَ', #1
u'معضوب': u'مَعْضُوبٍ', #29
u'معضوب': u'مَعْضُوبٌ', #8
u'معضوبا': u'مَعْضُوبًا', #29
u'معضوبين': u'مَعْضُوبِينَ', #3
u'معضولة': u'مَعْضُولَةٍ', #1
u'معطال': u'مِعْطَالٌ', #1
u'معطن': u'مَعْطِنِ', #1
u'معطن': u'مَعْطِنٌ', #3
u'معطن': u'مَعْطِنٍ', #6
u'معطنها': u'مَعْطَنَهَا', #1
u'معطوشة': u'مَعْطُوشَةٌ', #1
u'معطونة': u'مَعْطُونَةٌ', #1
u'معفو': u'مَعْفُوًّ', #1
u'معفوج': u'مَعْفُوجٌ', #1
u'معفوج': u'مَعْفُوجَ', #1
u'معفوج': u'مَعْفُوجُ', #9
u'معفور': u'مَعْفُورٌ', #2
u'معفوريا': u'معفوريا', #1
u'معفونا': u'مَعْفُونًا', #1
u'معفونة': u'مَعْفُونَةٍ', #1
u'معفونة': u'مَعْفُونَةً', #4
u'معقة': u'مَعْقَةِ', #1
u'معقة': u'مَعَقّةِ', #2
u'معقص': u'مُعَقِّصٍ', #1
u'معقف': u'مُعَقَّفٍ', #1
u'معقف': u'مُعَقَّفُ', #1
u'معقفة': u'معقفة', #4
u'معقوص': u'مَعْقُوص', #1
u'معقوص': u'مَعْقُوصٍ', #1
u'معقوص': u'مَعْقُوصَ', #1
u'معقوص،': u'مَعْقُوصٌ،', #1
u'معقوص': u'مَعْقُوصٌ', #26
u'معقوصا': u'مَعْقُوصًا', #13
u'معقوق': u'مَعْقُوقٌ', #1
u'معكل': u'مَعَكُلِّ', #2
u'معكوفين': u'معكوفين', #2
u'معكومة': u'مَعْكُومَةٌ', #1
u'معلة': u'مُعَلَّةٍ', #1
u'معلمى': u'مُعَلِّمِى', #2
u'معلوق': u'مُعْلُوقٍ', #9
u'معلولية': u'مُعْلَوْلِيَةَ', #1
u'معلولية': u'مَعْلُولِيَّةِ', #3
u'معلوليته': u'مَعْلُولِيَّتُهُ', #1
u'معلوليته': u'مَعْلُولِيَّتِهِ', #1
u'معلومةقوله': u'مَعْلُومَةٌقَوْلُهُ', #1
u'معلومون': u'مَعْلُومُونَ', #19
u'معلومية': u'مَعْلُومِيَّةَ', #14
u'معلومية': u'مَعْلُومِيَّةُ', #19
u'معلومية': u'مَعْلُومِيَّةِ', #35
u'معلوميته': u'مَعْلُومِيَّتِهِ', #1
u'معلوميته': u'مَعْلُومِيَّتُهُ', #4
u'معمسة': u'مُعَمّسَةٌ', #1
u'معمسة': u'مُعَمّسَةٍ', #1
u'معملة': u'مُعْمَلَةً', #1
u'معمودة': u'مَعْمُودَةً', #1
u'معنة': u'مَعْنَةٌ', #1
u'معنتا': u'مُعْنِتًا', #1
u'معنتا': u'مُعَنِّتًا', #4
u'معنسة': u'مُعَنَّسَةٍ', #1
u'معنسة': u'مُعَنَّسَةً', #2
u'معنعن': u'مُعَنْعَنِ', #1
u'معنعن': u'مُعَنْعَنٌ', #3
u'معنعنا': u'مُعَنْعَنًا', #6
u'معنق': u'مُعْنِقُ', #1
u'معنقا': u'مُعْنِقًا', #2
u'معنقون': u'مُعْنِقُونَ', #2
u'معنيى': u'مَعْنَيَىْ', #1
u'معهإذا': u'مَعَهُإِذَا', #1
u'معهالثانية': u'مَعَهُالثَّانِيَةَ', #1
u'معهودون': u'مَعْهُودُونَ', #2
u'معهودية': u'مَعْهُودِيَّةَ', #1
u'معهوديتهم': u'مَعْهُودِيَّتِهِمْ', #1
u'معوك': u'مَعُوكٌ', #1
u'معيز': u'مُعَيْزٍ', #3
u'معيشتى': u'مَعِيشَتِى', #1
u'معيص': u'مَعِيصَ', #1
u'معيص': u'مَعِيصِ', #18
u'معيص': u'مَعِيصٍ', #3
u'معيط': u'مُعِيطٍ', #1
u'معيط': u'مُعيْط', #1
u'معيط': u'مُعَيْطٍ', #128
u'معيط،': u'مُعَيْطٍ،', #20
u'معيط': u'مُعَيْط', #4
u'معيط': u'معيط', #5
u'معيط': u'مُعَيْطِ', #5
u'معيقب': u'مُعَيْقِبٍ', #3
u'معيقيب': u'معيقيب', #1
u'معيقيب': u'مُعَيْقِيبٌ', #14
u'معيقيب': u'مُعَيْقِيبُ', #2
u'معيقيب،': u'مُعَيْقِيبٌ،', #2
u'معيقيب': u'مُعَيْقِيب', #3
u'معيقيب': u'مُعَيْقِيبٍ', #37
u'معيقيب،': u'مُعَيْقِيبٍ،', #4
u'معيوب': u'مَعْيُوبٍ', #1
u'معيوب': u'مَعْيُوبُ', #2
u'معيوبا': u'مَعْيُوبًا', #4
u'معيوبة': u'مَعْيُوبَةً', #1
u'مغ': u'مغ', #6
u'مغاب': u'مَغَابَ', #1
u'مغابن': u'مَغَابِنُ', #3
u'مغابن': u'مَغَابِنَ', #5
u'مغابن': u'مَغَابِنِ', #5
u'مغابنة': u'مُغَابَنَةٍ', #5
u'مغابنه،': u'مَغَابِنَهُ،', #1
u'مغابنه': u'مَغَابِنُهُ', #2
u'مغابنه': u'مَغَابِنِهِ', #3
u'مغابنه': u'مَغَابِنَهُ', #5
u'مغاثير': u'مَغَاثِير', #1
u'مغارسة': u'مُغَارَسَةُ', #1
u'مغارسة': u'مُغَارَسَةٌ', #5
u'مغارسة': u'مُغَارَسَةً', #7
u'مغارسته': u'مُغَارَسَتِهِ', #1
u'مغارستهم': u'مُغَارَسَتِهِمْ', #1
u'مغارما': u'مُغَارِمَا', #2
u'مغازى': u'مَغَازِىَّ', #1
u'مغازى': u'مَغَازِى', #11
u'مغازية': u'مُغَازِيَةِ', #1
u'مغازية،': u'مغازية،', #3
u'مغافر': u'مَغَافِرَ', #2
u'مغافرهم': u'مَغَافِرِهِمْ', #1
u'مغافصة': u'مُغَافِصَةٍ', #1
u'مغافصة': u'مُغَافَصَةً', #13
u'مغافير،': u'مَغَافِيرَ،', #1
u'مغافير': u'مَغَافِيرَ', #16
u'مغافير': u'مَغَافِير', #3
u'مغافير؟': u'مَغَافِيرَ؟', #3
u'مغاك': u'مغاك', #1
u'مغالب': u'مَغَالِبَ', #1
u'مغالب': u'مُغَالَبٌ', #1
u'مغالب': u'مُغَالِبٌ', #1
u'مغالب': u'مُغَالِبٍ', #1
u'مغالب': u'مُغَالِبَ', #1
u'مغالب': u'مُغَالِبُ', #9
u'مغالبا': u'مُغَالِبًا', #1
u'مغالبين': u'مُغَالِبِينَ', #1
u'مغالة': u'مُغَالَةَ', #1
u'مغالة،': u'مَغَالَةَ،', #1
u'مغالة': u'مَغَالَة', #2
u'مغالة': u'مَغَالَةَ', #7
u'مغالية': u'مُغَالِيَةً', #1
u'مغالية': u'مُغَالِيَةَ', #1
u'مغالية': u'مُغَالِيَةٍ', #15
u'مغامزة': u'مغامزة', #1
u'مغانما': u'مَغَانِمَا', #1
u'مغائر': u'مَغَائِرَ', #1
u'مغائر': u'مَغَائِرُ', #1
u'مغايبة': u'مُغَايَبَةً', #3
u'مغايص': u'مَغَايِصِ', #1
u'مغايض': u'مَغَايِضَ', #1
u'مغايظة': u'مُغَايَظَةً', #16
u'مغايظة': u'مُغَايَظَةٍ', #2
u'مغايظة': u'مُغَايَظَةُ', #2
u'مغايظة': u'مُغَايَظَةِ', #3
u'مغايظة': u'مُغَايَظَةَ', #5
u'مغايظتها': u'مُغَايَظَتَهَا', #1
u'مغبا': u'مُغَبَّا', #1
u'مغبا': u'مُغِبًّا', #2
u'مغبط': u'مُغْبَطٍ', #1
u'مغبوبا': u'مَغْبُوبًا', #1
u'مغتبق': u'مُغْتَبِقْ', #1
u'مغترس،': u'مغترِس،', #1
u'مغترسه': u'مُغْتَرِسِهْ', #1
u'مغترق': u'مُغْتَرِقِ', #1
u'مغترقة': u'مُغْتَرِقَةٌ', #1
u'مغتفلا': u'مغتفلا', #1
u'مغتلما': u'مُغْتَلَمًا', #1
u'مغتلما': u'مُغْتَلِمًا', #3
u'مغتلمة': u'مُغْتَلِمَةُ', #4
u'مغث': u'مَغْثُ', #1
u'مغث': u'مُغِثُّ', #1
u'مغث': u'مُغِثَ', #2
u'مغث': u'مَغْثٌ', #3
u'مغدان': u'مَغْدَانُ', #1
u'مغدق': u'مُغْدِقٌ', #1
u'مغدقا': u'مُغْدِقًا', #2
u'مغدقة': u'مُغْدِقَةً', #1
u'مغذا': u'مُغِذّا', #2
u'مغذا': u'مُغِذًّا', #4
u'مغرا': u'مَغْرًا', #1
u'مغراء،': u'مغراء،', #1
u'مغراء': u'مَغْرَاءٍ', #1
u'مغراء،': u'مَغْرَاءَ،', #13
u'مغراء': u'مَغْرَاءَ', #17
u'مغراء': u'مَغْرَاءُ', #2
u'مغراء': u'مِغْرَاءَ', #2
u'مغرانج': u'مغرانج', #3
u'مغرة': u'مَغَرَّةً', #1
u'مغرة': u'مَغْرَةً', #1
u'مغرة': u'مَغْرَةٍ', #5
u'مغرف': u'مَغْرَفِ', #1
u'مغرف': u'مُغْرِفٍ', #1
u'مغرف': u'مُغْرِفِ', #4
u'مغرفه': u'مَغْرَفِهِ', #1
u'مغروز': u'مَغْرُوزُ', #2
u'مغروز': u'مَغْرُوزٌ', #4
u'مغروزا': u'مَغْرُوزًا', #1
u'مغروزة': u'مَغْرُوزَةٍ', #12
u'مغروزة': u'مَغْرُوزَةٌ', #3
u'مغروزة': u'مَغْرُوزَةً', #4
u'مغروم': u'مَغْرُومٌ', #1
u'مغروم': u'مَغْرُومَ', #1
u'مغرومة': u'مَغْرُومَةٌ', #1
u'مغرومه': u'مَغْرُومَهْ', #1
u'مغرومه': u'مَغْرُومِهِ', #1
u'مغزا': u'مَغْزَا', #2
u'مغزر': u'مُغَزَّرٍ', #1
u'مغزول': u'مَغْزُولِ', #2
u'مغزول': u'مَغْزُولٍ', #7
u'مغزولا': u'مَغْزُولًا', #4
u'مغزولة': u'مَغْزُولَةٍ', #1
u'مغزولك': u'مَغْزُولِك', #6
u'مغزولها': u'مَغْزُولِهَا', #1
u'مغسولية': u'مَغْسُولِيَّةِ', #1
u'مغصوبيته': u'مَغْصُوبِيَّتَهُ', #1
u'مغض': u'مُغْضٍ', #1
u'مغضغضة': u'مُغَضْغَضَةٌ', #1
u'مغضورون': u'مَغْضُورُونَ', #1
u'مغضيا': u'مُغْضِيًا', #1
u'مغضية': u'مُغْضِيَةٍ', #1
u'مغضين': u'مُغِضِّينَ', #1
u'مغفر': u'مِغْفَرٌ', #19
u'مغفر': u'مِغْفَرَ', #2
u'مغفر': u'مُغْفَرٍ', #3
u'مغفر': u'مِغْفَرٍ', #4
u'مغفرا': u'مِغْفَرًا', #6
u'مغفره': u'مِغْفَرَهُ', #1
u'مغفره': u'مِغْفَرِه', #1
u'مغفره': u'مِغْفَرِهِ', #3
u'مغفلرأى': u'مُغَفَّلٍرَأَى', #2
u'مغفورون': u'مَغْفُورُونَ', #1
u'مغفورية': u'مَغْفُورِيَّةَ', #1
u'مغفول': u'مَغْفُولٌ', #2
u'مغلس،': u'مغلس،', #1
u'مغلس،': u'مُغَلِّسٍ،', #1
u'مغلس': u'مُغَلِّسٍ', #3
u'مغلسا': u'مُغْلِسًا', #1
u'مغلسا': u'مُغَلِّسًا', #9
u'مغلسين': u'مُغَلّسِينَ', #1
u'مغلسين': u'مُغَلّسَيْنِ', #1
u'مغلسين': u'مُغْلِسِينَ', #2
u'مغلسين': u'مُغَلِّسِينَ', #5
u'مغلصم': u'مُغَلْصَمٌ', #1
u'مغلصمة': u'مُغَلْصِمَةٌ', #1
u'مغللة': u'مُغَلّلَةً', #2
u'مغللين': u'مُغَلَّلِينَ', #1
u'مغلوبية': u'مَغْلُوبِيَّةُ', #1
u'مغلوت': u'مَغْلُوتٍ', #1
u'مغلوث': u'مَغْلُوثٍ', #3
u'مغلوث': u'مَغْلُوثٌ', #5
u'مغلوثا': u'مَغْلُوثًا', #2
u'مغلوثة': u'مَغْلُوثَةً', #3
u'مغلولب': u'مُغْلَوْلِبْ', #1
u'مغلولب': u'مُغْلَوْلِبِ', #3
u'مغلى': u'مُغَلَّى', #1
u'مغلى': u'مُغْلَى', #1
u'مغلى': u'مُغْلًى', #14
u'مغمر': u'مُغَمّر', #1
u'مغمر': u'مُغَمّرٍ', #1
u'مغمر': u'مُغْمَرٌ', #1
u'مغمرا': u'مَغْمَرًا', #1
u'مغمس': u'مُغَمّسٌ', #1
u'مغموس': u'مَغْمُوسٌ', #5
u'مغموسا': u'مَغْمُوسًا', #3
u'مغموسة': u'مَغْمُوسَةٌ', #1
u'مغموسة': u'مَغْمُوسَةٍ', #2
u'مغموص': u'مَغْمُوصٍ', #1
u'مغموصا': u'مَغْمُوصًا', #9
u'مغنوم': u'مَغْنُومٍ', #3
u'مغنوم': u'مَغْنُومٌ', #6
u'مغنوما': u'مَغْنُومًا', #21
u'مغنومة': u'مَغْنُومَةٌ', #1
u'مغنومة': u'مَغْنُومَةٍ', #1
u'مغنومة': u'مَغْنُومَةً', #8
u'مغنومون': u'مَغْنُومُونَ', #1
u'مغنومين': u'مَغْنُومِينَ', #1
u'مغوثا': u'مُغَوِّثًا', #1
u'مغوثين': u'مُغَوِّثِينَ', #1
u'مغور': u'مُغَوِّرٌ', #1
u'مغور': u'مُغْوِرٌ', #1
u'مغور': u'مُغْوِرٍ', #1
u'مغورين': u'مُغْوِرِينَ', #1
u'مغولا': u'مَغُولًا', #1
u'مغولا': u'مِغْوَلًا', #5
u'مغوي': u'مُغْوِي', #1
u'مغوية': u'مُغْوِيَةٍ', #1
u'مغوية': u'مُغْوِيَةَ', #4
u'مغي': u'مُغَيٌّ', #1
u'مغي': u'مُغَيٍّ', #1
u'مغيا': u'مَغْيًا', #1
u'مغيا': u'مُغَيَّا', #19
u'مغيا': u'مُغَيًّا', #34
u'مغياة': u'مُغَيَّاةٍ', #1
u'مغياة': u'مُغْيَاةٍ', #1
u'مغياة': u'مُغَيَّاةً', #12
u'مغياة': u'مُغَيَّاةٌ', #16
u'مغياها': u'مُغَيَّاهَا', #1
u'مغيربان': u'مُغَيْرِبَانِ', #5
u'مغيرةو': u'مُغِيرَةُوَ', #1
u'مغيل': u'مُغْيِلِ', #1
u'مفاتنة': u'مُفَاتَنَة', #1
u'مفاتنة': u'مُفَاتَنَةً', #4
u'مفاجر': u'مَفَاجِرُ', #1
u'مفاجيا': u'مُفَاجِيَا', #1
u'مفاح': u'مُفَاحٌ', #1
u'مفادة': u'مُفَادَةً', #1
u'مفادة': u'مُفَادَةِ', #2
u'مفاريح': u'مَفَارِيحَ', #3
u'مفاريد': u'مَفَارِيدَ', #1
u'مفاسحه': u'مَفَاسِحُهُ', #1
u'مفاض': u'مُفَاضَ', #2
u'مفاضة': u'مُفَاضَةً', #1
u'مفاضة': u'مُفَاضَةٌ', #2
u'مفاعلة': u'مُفَاعَلَةَ', #1
u'مفاعلة': u'مُفَاعِلَةٍ', #1
u'مفاعلة': u'مُفَاعَلَةٌ', #128
u'مفاعلة': u'مُفَاعَلَةٍ', #3
u'مفاعلة': u'مُفَاعَلَة', #4
u'مفاعلة': u'مُفَاعَلَةً', #4
u'مفاعلة': u'مُفَاعِلَةٌ', #5
u'مفاعلتن': u'مَفَاعَلَتُنْ', #1
u'مفاعلتن': u'مُفَاعَلَتَنْ', #1
u'مفاعلتن': u'مُفَاعَلَتُنْ', #1
u'مفاعلتن': u'مُفَاعَلْتُنْ', #1
u'مفاعلن': u'مَفَاعِلُنْ', #3
u'مفاعيلن': u'مَفَاعِيلُنْ', #10
u'مفاقره': u'مَفَاقِرُهُ', #1
u'مفاقره': u'مَفَاقِرِهِ', #1
u'مفاقره': u'مَفَاقِرَهُ', #2
u'مفاقرهم': u'مَفَاقِرِهِمْ', #1
u'مفاليس': u'مَفَالِيسُ', #2
u'مفاهميه': u'مُفَاهَمِيهِ', #1
u'مفاوت': u'مُفَاوِتٌ', #1
u'مفاوتا': u'مُفَاوِتًا', #4
u'مفتات': u'مُفْتَاتٍ', #1
u'مفتاتا': u'مُفْتَاتًا', #1
u'مفتاق': u'مِفْتَاقُ', #1
u'مفتداة': u'مُفْتَدَاةٌ', #1
u'مفترعة': u'مُفْتَرِعَةً', #1
u'مفتصد': u'مُفْتَصِدٍ', #2
u'مفتصدا': u'مُفْتَصِدًا', #4
u'مفتضة': u'مُفْتَضَّةً', #11
u'مفتضة': u'مُفْتَضَّةٍ', #4
u'مفتعلن': u'مُفْتَعِلُنْ', #1
u'مفتوح': u'مَفْتُوحً', #1
u'مفتوحون': u'مفتوحون', #1
u'مفدح': u'مُفْدِحِ', #1
u'مفدحة': u'مُفْدِحَةٌ', #1
u'مفدم': u'مُفْدَمٌ', #1
u'مفدما': u'مُفْدَمًا', #1
u'مفدمة': u'مُفَدَّمَةً', #1
u'مفدمة': u'مُفَدَّمَةٌ', #1
u'مفدمة': u'مُفَدَّمَةٍ', #1
u'مفدمة': u'مُفْدَمَةٌ', #1
u'مفدوي': u'مَفْدَوِيٌّ', #1
u'مفدوي': u'مَفْدَوِيٌ', #2
u'مفدى': u'مُفْدًى', #2
u'مفدى': u'مُفَدًّى', #4
u'مفرادته': u'مِفْرَادَتِهِ', #1
u'مفرس': u'مُفَرّسُ', #2
u'مفرقةفحدثنيه': u'مُفَرَّقَةٌفَحَدَّثَنِيهِ', #1
u'مفروج': u'مَفْرُوجٍ', #1
u'مفروجتان': u'مَفْرُوجَتَانِ', #1
u'مفروح': u'مَفْرُوحٌ', #1
u'مفروح': u'مَفْرُوحٍ', #6
u'مفروز': u'مَفْرُوزٌ', #1
u'مفروزا': u'مَفْرُوزًا', #4
u'مفروزة': u'مَفْرُوزَةً', #2
u'مفروسة': u'مَفْرُوسَةٍ', #1
u'مفروص': u'مَفْرُوصٌ', #1
u'مفروقة': u'مفروقة', #2
u'مفروقهما': u'مَفْرُوقُهُمَا', #2
u'مفروقين': u'مَفْرُوقَيْنِ', #1
u'مفزورا': u'مَفْزُورًا', #5
u'مفسريته': u'مُفَسَّرِيَّتِهِ', #1
u'مفشلة': u'مَفْشَلَةٌ', #1
u'مفصص': u'مُفَصَّصٍ', #1
u'مفصصا': u'مُفَصَّصًا', #4
u'مفضاة': u'مُفْضَاةً', #23
u'مفضاة': u'مُفْضَاةٌ', #4
u'مفضاة': u'مُفْضَاةٍ', #6
u'مفضوخ': u'مَفْضُوخ', #1
u'مفضولية': u'مَفْضُولِيَّةِ', #1
u'مفضولية': u'مَفْضُولِيَّةَ', #2
u'مفضى': u'مُفْضَى', #3
u'مفطار': u'مِفْطَارِ', #1
u'مفطورا': u'مَفْطُورًا', #4
u'مفطورة': u'مَفْطُورَةٌ', #1
u'مفظع،': u'مُفْظِعٍ،', #1
u'مفظع': u'مُفْظِعٍ', #10
u'مفعال': u'مِفْعَالٍ', #1
u'مفعال': u'مِفْعَالٌ', #11
u'مفعالا': u'مِفْعَالًا', #1
u'مفعوج': u'مَفْعُوجٍ', #1
u'مفعيل': u'مِفْعِيلٌ', #3
u'مفقأة': u'مُفَقَّأَةٍ', #1
u'مفقوء': u'مَفْقُوءِ', #1
u'مفقوء': u'مَفْقُوءَ', #6
u'مفقوءة': u'مَفْقُوءَةً', #1
u'مفقوءة': u'مَفْقُوءَةٌ', #6
u'مفقور': u'مَفْقُورٍ', #2
u'مفلاحا': u'مِفْلَاحًا', #2
u'مفلتا': u'مُفْلَتًا', #4
u'مفلتا': u'مُفْلِتًا', #4
u'مفلتة': u'مُفْلَتَةُ', #1
u'مفلج': u'مُفْلَجُ', #1
u'مفلج': u'مُفَلَّجُ', #4
u'مفلج': u'مُفَلَّجِ', #4
u'مفلجا': u'مُفَلَّجًا', #1
u'مفلجة': u'مُفَلَّجَةٍ', #1
u'مفلكا': u'مُفَلَّكًا', #1
u'مفلوتا': u'مَفْلُوتًا', #3
u'مفلول': u'مَفْلُولُ', #4
u'مفلولة،': u'مَفْلُولَةً،', #1
u'مفلولين': u'مَفْلُولِينَ', #1
u'مفهوهه': u'مَفْهُوهُهُ', #1
u'مفوز': u'مُفَوِّزٍ', #5
u'مفول': u'مَفُولٌ', #2
u'مفئود': u'مَفْئُودٌ', #2
u'مفئودا': u'مَفْئُودًا', #2
u'مفيت': u'مُفِيتُ', #1
u'مفيت': u'مُفِيتٍ', #11
u'مفيت': u'مُفِيتِ', #2
u'مفيت': u'مُفِيتٌ', #44
u'مفيتا': u'مُفِيتًا', #31
u'مفيتات': u'مُفِيتَاتٍ', #1
u'مفيتات': u'مُفِيتَاتِ', #2
u'مفيتة': u'مُفِيتَةٌ', #1
u'مفيتة': u'مُفِيتَةٍ', #1
u'مفيتة': u'مُفِيتَةً', #6
u'مفيته': u'مُفِيتِهِ', #1
u'مقابحا': u'مُقَابِحًا', #1
u'مقابحة': u'مُقَابَحَةٌ', #1
u'مقابحة': u'مُقَابَحَةُ', #1
u'مقابحة': u'مُقَابَحَةٍ', #2
u'مقابحة': u'مُقَابَحَةِ', #2
u'مقابيس': u'مَقَابِيسُ', #1
u'مقاثئ': u'مَقَاثِئَ', #1
u'مقاد': u'مُقَادٍ', #1
u'مقادا': u'مُقَادًا', #1
u'مقادة': u'مَقَادَةٌ', #1
u'مقادة': u'مُقَادَةً', #1
u'مقادم': u'مَقَادِمُ', #1
u'مقادم': u'مَقَادِمِ', #2
u'مقادم': u'مَقَادِمَ', #3
u'مقاده': u'مُقَادَهُ', #1
u'مقاذيره': u'مَقَاذِيرُهُ', #1
u'مقارض': u'مُقَارَضٍ', #1
u'مقارض': u'مُقَارِضٍ', #3
u'مقارض': u'مُقَارِضٌ', #4
u'مقارضا': u'مُقَارِضًا', #11
u'مقارضا': u'مُقَارَضًا', #4
u'مقارضه': u'مُقَارِضِهِ', #1
u'مقارف': u'مُقَارِفُ', #1
u'مقارئا': u'مُقَارِئًا', #1
u'مقاريرها': u'مَقَارِيرَهَا', #1
u'مقاسة': u'مُقَاسَةً', #1
u'مقاسة': u'مُقَاسَةٌ', #1
u'مقاصص': u'مُقَاصِصٌ', #1
u'مقاصصا': u'مُقَاصِصًا', #1
u'مقاصصة': u'مُقَاصَصَةٌ', #1
u'مقاصصة': u'مُقَاصَصَةٍ', #2
u'مقاصفة': u'مُقَاصَفَةً', #1
u'مقاصيص': u'مَقَاصِيصُ', #2
u'مقاصيص': u'مَقَاصِيصَ', #4
u'مقاعدة': u'مُقَاعَدَةً', #2
u'مقاعدته': u'مُقَاعَدَتِهِ', #1
u'مقالتى': u'مَقَالَتِى', #2
u'مقامسته': u'مُقَامَسَتِهِ', #1
u'مقامى': u'مَقَامِى', #17
u'مقامى': u'مُقَامِى', #4
u'مقاوات': u'مُقَاوَاتٍ', #1
u'مقايلة': u'مُقَايَلَةً', #1
u'مقايلة': u'مُقَايَلَةٍ', #2
u'مقايلته': u'مُقَايَلَتُهُ', #1
u'مقبوة': u'مَقْبُوَّةٌ', #1
u'مقبوح': u'مَقْبُوح', #1
u'مقبوح': u'مَقْبُوحُ', #2
u'مقبوحا': u'مقبوحًا', #1
u'مقبوحا': u'مَقْبُوحًا', #1
u'مقبوحين': u'مَقْبُوحِينَ', #1
u'مقبوحين': u'مَقْبُوحَيْنِ', #5
u'مقبولية': u'مَقْبُولِيَّةِ', #2
u'مقبيا': u'مَقْبِيًّا', #4
u'مقتب': u'مَقْتَبٍ', #1
u'مقتب': u'مُقَتَّبٍ', #5
u'مقتب': u'مُقَتَّبٌ', #6
u'مقتص': u'مُقْتَصٍّ', #15
u'مقتص': u'مُقْتَصٌّ', #6
u'مقتصا': u'مُقْتَصًّا', #1
u'مقتصه': u'مُقْتَصَّهُ', #1
u'مقتض': u'مُقْتَضًّ', #1
u'مقتناة': u'مُقْتَنَاةٌ', #1
u'مقتناة': u'مُقْتَنَاةً', #2
u'مقتناة': u'مُقْتَنَاةٍ', #6
u'مقتنى': u'مَقَتَنِى', #1
u'مقتنى': u'مُقْتَنًى', #25
u'مقتنى': u'مُقْتَنَى', #3
u'مقتوت': u'مَقْتُوتٌ', #1
u'مقتوت': u'مَقْتُوتٍ', #1
u'مقتوتا': u'مَقْتُوتًا', #3
u'مقتور': u'مَقْتُورٌ', #6
u'مقثأة': u'مَقْثَأَةٌ', #1
u'مقثأة': u'مِقْثَأَةً', #1
u'مقثأة': u'مِقْثَأَةٍ', #1
u'مقثأة': u'مَقْثَأَةً', #10
u'مقثأة': u'مَقْثَأَةٍ', #9
u'مقدارالقراءة': u'مِقْدَارُالْقِرَاءَةِ', #1
u'مقدوراق': u'مَقْدُورًاق', #1
u'مقدوع': u'مَقْدُوعٌ', #1
u'مقذر': u'مُقَذِّرٌ', #2
u'مقذر': u'مُقَذِّرٍ', #2
u'مقذرا': u'مُقَذِّرًا', #1
u'مقذرة': u'مَقْذَرَةٌ', #1
u'مقذوعة': u'مَقْذُوعَةٌ', #1
u'مقراة': u'مَقْرَاةُ', #1
u'مقراة': u'مِقْرَاةٍ', #1
u'مقراة': u'مَقْرَاةٍ', #2
u'مقرطا': u'مُقْرَطًا', #2
u'مقرطا': u'مُقَرَّطًا', #3
u'مقرطة': u'مُقَرّطَةٌ', #1
u'مقرطة': u'مُقَرَّطَةً', #1
u'مقرطس': u'مُقَرْطَسَ', #1
u'مقرطس': u'مُقَرْطِسَ', #1
u'مقرقرة': u'مُقَرْقِرَةً', #2
u'مقروب': u'مَقْرُوبِ', #1
u'مقروظ': u'مَقْرُوظٌ', #2
u'مقروظ': u'مَقْرُوظٍ', #2
u'مقروعة': u'مَقْرُوعَة', #1
u'مقرى': u'مَقْرَى', #5
u'مقسئن': u'مَقْسَئِنّ', #1
u'مقشور': u'مَقْشُورٍ', #5
u'مقشورا': u'مَقْشُورًا', #4
u'مقشورة': u'مَقْشُورَةُ', #1
u'مقشورة': u'مَقْشُورَةٍ', #2
u'مقشوطا': u'مَقْشُوطًا', #1
u'مقشي': u'مُقَشّي', #1
u'مقصدون': u'مَقْصُدُونَ', #1
u'مقصصة': u'مُقَصَّصَةً', #1
u'مقصصة': u'مِقْصَصَةً', #1
u'مقصود153id': u'مقصود153id', #1
u'مقصود': u'مَقْصُودً', #2
u'مقصودية': u'مَقْصُودِيَّةِ', #1
u'مقصوديته': u'مَقْصُودِيَّتَهُ', #1
u'مقصوديته': u'مَقْصُودِيَّتُهُ', #1
u'مقصورون': u'مَقْصُورُونَ', #1
u'مقصوع': u'مَقْصُوعِ', #1
u'مقصول': u'مَقْصُولٍ', #1
u'مقضوب': u'مَقْضُوبٍ', #2
u'مقضى': u'مُقْضًى', #2
u'مقضى': u'مَقْضِىٌّ', #3
u'مقطاع': u'مِقْطَاعُ', #1
u'مقطم': u'مِقْطَمِ', #1
u'مقطوط': u'مَقْطُوطٌ', #1
u'مقطوعوروي': u'مَقْطُوعٍوَرُوِيَ', #1
u'مقع': u'مُقْعٍ', #8
u'مقعدى': u'مَقْعَدِى', #1
u'مقعصا': u'مُقْعَصًا', #2
u'مقعودته': u'مَقْعُودَتَهُ', #1
u'مقعيا': u'مُقْعِيًا', #10
u'مقعية': u'مُقْعِيَةٌ', #2
u'مقعيين': u'مُقْعِيَيْنِ', #1
u'مقفول': u'مَقْفُولٍ', #1
u'مقفولا': u'مَقْفُولًا', #6
u'مقفولة': u'مَقْفُولَةً', #2
u'مقلاص': u'مِقْلَاصٍ', #2
u'مقلاص': u'مِقْلاَصٍ', #3
u'مقلاص،': u'مِقْلاصٍ،', #6
u'مقلش': u'مُقَلِّشٌ', #1
u'مقلفطا': u'مُقَلْفَطًا', #1
u'مقلقل': u'مُقَلْقَلٍ', #2
u'مقلقل': u'مُقَلْقَلِ', #3
u'مقلقلة': u'مُقَلْقَلَةٍ', #2
u'مقلوا': u'مَقْلُوًّا', #3
u'مقلوة': u'مَقْلُوَّةٍ', #1
u'مقلوة': u'مَقْلُوَّةً', #4
u'مقلوة': u'مَقْلُوَّةٌ', #7
u'مقلوليا،': u'مُقْلَوْلِيًا،', #1
u'مقمحة': u'مُقْمَحَةٌ', #1
u'مقمحون': u'مُقْمَحُونَ', #4
u'مقمع': u'مَقْمَعٌ', #1
u'مقمعا': u'مقمعاً', #1
u'مقمعا': u'مِقْمَعًا', #2
u'مقنوة': u'مَقْنُوَةٍ', #3
u'مقنى': u'مُقَنَّى', #1
u'مقنى': u'مُقْنَى', #1
u'مقهرا': u'مُقْهَرًا', #1
u'مقهقرا': u'مُقَهْقِرًا', #1
u'مقهى': u'مَقْهًى', #1
u'مقوتات': u'مُقَوِّتَاتِ', #1
u'مقوليته': u'مَقُولِيَّتِهِ', #1
u'مقيد': u'مُقَيَّدً', #1
u'مقير': u'مُقَيَّرٍ', #8
u'مقيرا': u'مُقَيَّرًا', #1
u'مقيرة': u'مُقَيَّرَةٌ', #1
u'مقيرة،': u'مُقَيَّرَةٌ،', #1
u'مقيس': u'مَقِيس', #1
u'مقيس': u'مَقِيسُ', #1
u'مقيس': u'مِقْيس', #1
u'مقيس،': u'مِقْيسٍ،', #1
u'مقيس': u'مَقْيَسٍ', #1
u'مقيس': u'مِقْيَسُ', #11
u'مقيس': u'مَقِيسٌ', #111
u'مقيس': u'مَقِيسٍ', #18
u'مقيس': u'مَقِيسَ', #2
u'مقيس': u'مَقِيسِ', #2
u'مقيس': u'مَقْيَسُ', #2
u'مقيس': u'مِقْيَسِ', #3
u'مقيس': u'مِقْيَسٍ', #6
u'مقيس': u'مِقْيَسٌ', #7
u'مقيسا': u'مِقيسًا', #1
u'مقيسا': u'مِقْيسًا', #1
u'مقيسا': u'مِقْيَسًا', #1
u'مقيسا': u'مَقِيسًا', #62
u'مقيسات': u'مَقِيسَاتٌ', #1
u'مقيسة': u'مَقِيسَةً', #10
u'مقيسة': u'مَقِيسَةٌ', #24
u'مقيسة': u'مَقِيسَةٍ', #3
u'مقيستان': u'مَقِيسَتَانِ', #1
u'مقيسون': u'مَقِيسُونَ', #1
u'مكابلة': u'مُكَابَلَةَ', #1
u'مكاتبى': u'مُكَاتَبِى', #1
u'مكاتل': u'مَكَاتِلَ', #1
u'مكاتلهم': u'مَكَاتِلُهُمْ', #2
u'مكاتيل': u'مَكَاتِيلَ', #1
u'مكاث': u'مَكَاثِ', #1
u'مكاس': u'مُكَّاسٍ', #2
u'مكاس': u'مَكَّاسٌ', #3
u'مكاس': u'مَكَّاسٍ', #6
u'مكاسا': u'مَكَّاسًا', #3
u'مكاسح': u'مَكَاسِحُ', #1
u'مكاسر': u'مَكَاسِرُ', #1
u'مكاسر': u'مَكَاسِرِ', #1
u'مكاسر': u'مُكَاسِرِ', #1
u'مكاشرا': u'مُكَاشِرًا', #1
u'مكاشفا': u'مُكَاشِفًا', #2
u'مكاشفون': u'مُكَاشِفُونَ', #1
u'مكاعب': u'مَكَاعِبَ', #1
u'مكاعبنا': u'مَكَاعِبِنَا', #2
u'مكاعبهم': u'مَكَاعِبَهُمْ', #1
u'مكاعبهم': u'مَكَاعِبُهُمْ', #4
u'مكاف': u'مُكَافٍ', #1
u'مكافيا': u'مُكَافِيًا', #2
u'مكاكى': u'مَكَاكِىَّ', #2
u'مكالها': u'مَكَالُهَا', #1
u'مكامعة': u'مُكَامَعَةَ', #1
u'مكامعة': u'مُكَامَعَة', #2
u'مكامعة': u'مُكَامَعَةِ', #6
u'مكان': u'مَكَانً', #1
u'مكانى': u'مَكَانِى', #10
u'مكايسة': u'مُكَايَسَةً', #1
u'مكايسة': u'مُكَايَسَةٌ', #1
u'مكايسة': u'مُكَايَسَةٍ', #18
u'مكايسة': u'مُكَايَسَةِ', #2
u'مكايسة': u'مُكَايَسَةَ', #7
u'مكايله': u'مُكَايَلَهْ', #1
u'مكاييك': u'مَكَايِيكَ', #1
u'مكبابا': u'مِكْبَابًا', #2
u'مكببة': u'مُكَبَّبَةً', #1
u'مكبتل': u'مكبتل', #1
u'مكبول': u'مَكْبولُ', #1
u'مكبول': u'مَكْبُولٌ', #1
u'مكبول': u'مَكْبُولُ', #5
u'مكبولا': u'مَكْبُولًا', #1
u'مكة': u'مَكَّةً', #1
u'مكةحتى': u'مَكَّةَحَتَّى', #1
u'مكةقالت': u'مَكَّةَقَالَتْ', #1
u'مكةليأتوا': u'مَكَّةَلِيَأْتُوا', #1
u'مكةومن': u'مَكَّةَوَمِنْ', #1
u'مكتابا': u'مِكْتَابًا', #1
u'مكتتفا': u'مُكْتَتِفًا', #1
u'مكتتم': u'مُكْتَتَمٌ', #1
u'مكتتما': u'مُكتَتِمًا', #1
u'مكتتمون': u'مُكْتَتِمُونَ', #2
u'مكتراة': u'مُكْتَرَاةً', #26
u'مكتراة': u'مُكْتَرَاةٌ', #4
u'مكتراة': u'مُكْتَرَاةٍ', #5
u'مكتراه': u'مُكْتَرَاهُ', #1
u'مكترى': u'مُكْتَرًى', #23
u'مكترى': u'مُكْتَرَى', #3
u'مكتفى': u'مُكْتَفًى', #2
u'مكتن': u'مَكْتَنٌّ', #1
u'مكتن': u'مُكْتَنٌّ', #3
u'مكتنع': u'مُكْتَنَعُ', #1
u'مكتنع': u'مُكْتَنِعٌ', #3
u'مكثتها': u'مَكَثَتْهَا', #3
u'مكثور': u'مَكْثُورٌ', #9
u'مكثورا': u'مَكْثُورًا', #1
u'مكحول': u'مَكْحول', #1
u'مكحول': u'مَكْحُولِ', #1
u'مكحول': u'مكحول', #10
u'مكحول': u'مَكْحُولٌ', #139
u'مكحول،': u'مَكْحُولٌ،', #22
u'مكحول': u'مَكْحُول', #3
u'مكحول': u'مَكْحُولٍ', #414
u'مكحول،': u'مَكْحُولٍ،', #50
u'مكحول': u'مَكْحُولُ', #8
u'مكحول،': u'مكحول،', #9
u'مكحولا': u'مكحولا', #1
u'مكحولا،': u'مَكْحُولاً،', #1
u'مكحولا': u'مَكْحُولاً', #12
u'مكحولا': u'مَكْحُولًا', #17
u'مكحولا،': u'مَكْحُولا،', #2
u'مكحولا،': u'مَكْحُولًا،', #2
u'مكحولا': u'مَكْحُولا', #5
u'مكحول،أن': u'مَكْحُولٍ،أَنَّ', #1
u'مكحول،في': u'مَكْحُولٍ،فِي', #3
u'مكد': u'مُكِدٍّ', #1
u'مكد': u'مَكَدَ', #2
u'مكدم': u'مُكَدّمٌ', #2
u'مكدم': u'مُكَدّمٍ', #2
u'مكدوس': u'مكدوس', #1
u'مكدوس': u'مَكْدُوسٌ', #1
u'مكدون': u'مُكِدُّونَ', #1
u'مكديا': u'مُكْدِيًا', #1
u'مكذا': u'مكذا', #2
u'مكرب': u'مُكْرِبٌ', #1
u'مكرز': u'مَكْرَزُ', #1
u'مكرز': u'مِكْرَزِ', #1
u'مكرز': u'مِكْرِزٌ', #1
u'مكرز،': u'مِكْرَزٍ،', #1
u'مكرز،': u'مِكْرَزِ،', #1
u'مكرز': u'مِكْرَزٌ', #14
u'مكرز': u'مِكْرَزٍ', #18
u'مكرز': u'مكرز', #2
u'مكرز': u'مُكَرِّزٍ', #2
u'مكرز': u'مِكْرَزُ', #26
u'مكرز': u'مِكْرَز', #3
u'مكرز': u'مِكْرَزَ', #5
u'مكرزا': u'مِكْرِزًا', #1
u'مكرزا': u'مِكْرَزًا', #2
u'مكركه': u'مُكَرِّكه', #1
u'مكروم': u'مَكْرُومٍ', #1
u'مكرى': u'مُكْرًى', #17
u'مكزوز': u'مَكْزُوز', #1
u'مكسة': u'مَكَسَةً', #1
u'مكسلة': u'مَكْسَلَةٌ', #1
u'مكسلة': u'مُكَسِّلَةٌ', #1
u'مكسلة': u'مُكْسِلَةٌ', #2
u'مكشف': u'مُكَشِّفٌ', #1
u'مكشف': u'مُكْشِفُ', #1
u'مكشفات': u'مُكَشَّفَاتِ', #1
u'مكشفات': u'مُكَشِّفَاتِ', #1
u'مكشفة': u'مُكَشّفَةَ', #4
u'مكشوح': u'مكشوح', #1
u'مكشوح،': u'مكشوح،', #1
u'مكشوح': u'مَكْشُوحٌ', #1
u'مكشوح': u'مَكْشوُح', #1
u'مكشوح': u'مَكْشُوحٍ', #14
u'مكشوحا': u'مَكْشُوحًا', #1
u'مكشوطة': u'مَكْشُوطَةً', #1
u'مكعوم': u'مَكْعُومُ', #1
u'مكعوم': u'مَكْعُومٌ', #2
u'مكفأة': u'مُكَفَّأَةٍ', #1
u'مكفت': u'مُكَفَّتٌ', #1
u'مكفت': u'مُكَفَّتٍ', #2
u'مكفتا': u'مُكَفَّتًا', #1
u'مكفتة': u'مُكَفَّتَةً', #1
u'مكفرية': u'مَكْفَرِيَّةِ', #1
u'مكفف،': u'مكفّف،', #1
u'مكفف': u'مُكَفَّفٍ', #1
u'مكفف': u'مُكَفِّفٍ', #2
u'مكففة': u'مُكَفَّفَةٌ', #2
u'مكفوت': u'مَكْفُوتٍ', #1
u'مكفوت': u'مَكْفُوتٌ', #4
u'مكفوي': u'مَكْفَوِيٌّ', #2
u'مكفى': u'مَكْفِىٌّ', #1
u'مكفى': u'مُكْفًى', #1
u'مكفى': u'مُكَفًّى', #2
u'مكفى': u'مُكَفَّى', #2
u'مكفى': u'مَكْفِىٍّ', #4
u'مكلب': u'مُكَلَّبٍ', #2
u'مكلب': u'مُكَلَّبٌ', #3
u'مكلبا': u'مُكَلِّبًا', #1
u'مكلبا،': u'مُكَلَّبًا،', #1
u'مكلبين': u'مُكَلِّبِينِ', #1
u'مكلبين،': u'مُكَلِّبِينَ،', #1
u'مكلبين': u'مُكَلِّبِينَ', #58
u'مكلت': u'مَكَلْت', #1
u'مكلثمة': u'مُكَلْثَمَةٌ', #1
u'مكلسا': u'مُكَلَّسًا', #2
u'مكلسة': u'مُكَلَّسَةٌ', #1
u'مكلوء': u'مَكْلُوءٍ', #2
u'مكلوء': u'مَكْلُوءٌ', #5
u'مكلوم': u'مَكْلُومٌ', #2
u'مكلوم': u'مَكْلُومٍ', #3
u'مكنسه': u'مَكْنَسَهُ', #1
u'مكنف': u'مُكْنِف', #1
u'مكنف،': u'مِكْنَفٌ،', #1
u'مكنف': u'مَكْنَفٍ', #2
u'مكنف': u'مِكْنَفٍ', #2
u'مكنف': u'مُكْنِفٍ', #3
u'مكنوزا': u'مَكْنُوزًا', #2
u'مكوجه': u'مكوجه', #1
u'مكويس': u'مكويس', #1
u'مكى': u'مكى', #1
u'مكى': u'مَكِّىِّ', #17
u'مكى': u'مَكِّىُّ', #45
u'مكى': u'مَكِّىٍّ', #7
u'مكى': u'مَكِّىٌّ', #8
u'مكيالة': u'مُكَيَالَةً', #1
u'مكيتل': u'مُكَيْتَلٌ', #1
u'مكيتل': u'مُكَيْتِل', #1
u'مكيتل،': u'مُكَيْتِلٌ،', #1
u'مكيتل': u'مُكَيْتِلٌ', #3
u'مكيث،': u'مَكِيثٍ،', #1
u'مكيث': u'مُكَيْثٍ', #1
u'مكيث': u'مكيث', #3
u'مكيث': u'مَكِيثٍ', #30
u'مكيثا،': u'مَكِيثًا،', #1
u'مكيثا': u'مَكِيثًا', #5
u'مكيثر': u'مُكَيْثِرٌ', #2
u'مكير': u'مَكِيرُ', #1
u'مكير': u'مُكِيرُ', #1
u'مكيس': u'مُكَيَّسٌ', #1
u'مكيس،': u'مُكَيَّسٍ،', #1
u'مكيسا': u'مُكَيِّسَا', #1
u'مكيسا': u'مُكَيَّسًا', #3
u'مكيسا': u'مُكَيَّسَا', #4
u'ملابسا': u'مُلَابِسًا', #22
u'ملابسون': u'مُلَابِسُونَ', #1
u'ملاة': u'مَلَاةِ', #1
u'ملأة': u'مِلْأَةً', #2
u'ملاثمة': u'مُلَاثَمَةِ', #4
u'ملاحيها': u'مَلَّاحِيهَا', #2
u'ملاحيهما': u'مَلَّاحِيهِمَا', #1
u'ملاخه': u'مِلَاخِهِ', #1
u'ملازق': u'مُلَازِقُ', #3
u'ملازق': u'مُلَازِقٌ', #6
u'ملازقا': u'مُلَازِقًا', #3
u'ملازقون': u'مُلَازِقُونَ', #1
u'ملازقين': u'مُلَازِقِينَ', #1
u'ملاص': u'مِلاصِ', #1
u'ملاص': u'مِلَاصِ', #1
u'ملاقات': u'مُلَاقَاتِ', #1
u'ملاقوا': u'مُلَاقُوا', #1
u'ملاقوا': u'مُّلاَقُوا', #1
u'ملاقوا': u'مُلاقُوا', #3
u'ملاقى': u'مُلاَقِىَّ', #2
u'ملالة': u'مَلَالَةٌ', #1
u'ملالة': u'مَلَالَةِ', #1
u'ملالة': u'مَلَالَةً', #3
u'ملالته': u'مَلَالَتِهِ', #2
u'ملامت': u'ملامت', #2
u'ملأمر': u'مِلْأَمْرِ', #1
u'ملأمه': u'مَلْأَمَهْ', #2
u'ملآنا': u'مَلْآنًا', #9
u'ملأوا': u'مَلأُوا', #1
u'ملأوا': u'مَلَأُوا', #1
u'ملاوثة': u'مَلَاوِثَة', #1
u'ملاوثة': u'مَلَاوِثَةٌ', #1
u'ملاوثة': u'مَلَاوِثَةٍ', #2
u'ملأوه': u'مَلأُوهُ', #1
u'ملأوه': u'مُلْأَوْهُ', #1
u'ملاويث': u'مَلَاوِيثٌ', #1
u'ملاويث': u'مَلَاوِيثُ', #1
u'ملائكةبالليل': u'مَلَائِكَةٌبِاللَّيْلِ', #1
u'ملائكةبالنهار': u'مَلَائِكَةٌبِالنَّهَارِ', #1
u'ملائكتى': u'مَلاَئِكَتِى', #1
u'ملائكتيوالوجه': u'مَلائِكَتِيوَالْوَجْهُ', #1
u'ملاية': u'مِلَايَةٌ', #1
u'ملببا': u'مُلَبَّبًا', #2
u'ملبث': u'مُلَبَّثٍ', #1
u'ملبقة': u'مُلَبَّقَةٍ', #1
u'ملبونة': u'مَلْبُونَةٌ', #2
u'ملتاث': u'مُلْتَاثٍ', #3
u'ملتحدا': u'مُلْتَحَدًا', #4
u'ملتذ': u'مُلْتَذٌّ', #6
u'ملتذا': u'مُلْتَذًّا', #2
u'ملتذة': u'مُلْتَذَّةٌ', #1
u'ملتذة': u'مُلْتَذَّةً', #2
u'ملتذقين': u'مُلْتَذِقَيْنِ', #1
u'ملتزة': u'مُلْتَزَّةٌ', #1
u'ملتززة': u'مُلْتَزِزَةٌ', #1
u'ملتسا': u'ملتساً', #1
u'ملتصص': u'مُلْتَصِصٌ', #1
u'ملتفعا': u'مُلْتَفِعَا', #1
u'ملتفعة': u'مُلْتَفِعَةً', #1
u'ملتوت': u'مَلْتُوتٍ', #12
u'ملتوت': u'مَلْتُوتٌ', #6
u'ملتوتا': u'مَلْتُوتًا', #28
u'ملثق': u'مُلْثِقِ', #3
u'ملج': u'مَلَجَ', #1
u'ملجا': u'ملجاً', #1
u'ملجا': u'مَلْجًا', #1
u'ملجا': u'مَلْجَا', #1
u'ملجأة': u'مُلْجَأَةً', #1
u'ملجأة': u'مُلْجَأَةٌ', #7
u'ملجاج': u'مِلْجَاجِ', #3
u'ملجان،': u'مِلْجَانَ،', #1
u'ملجج': u'مُلْجِجٍ', #2
u'ملجج': u'مُلَجِّجٍ', #3
u'ملججة': u'مُلَجِّجَةً', #1
u'ملجوم': u'مَلْجُومٌ', #1
u'ملجوما': u'مَلْجُومًا', #1
u'ملجيش': u'مِلْجَيْشِ', #1
u'ملحب': u'مَلْحَبُ', #2
u'ملحب': u'مُلَحّبٍ', #2
u'ملحبش': u'مِلْحبِش', #1
u'ملحبش': u'مِلْحُبْشِ', #1
u'ملحبش': u'مِلْحِبْشِ', #1
u'ملحوب': u'مَلْحُوبٌ', #3
u'ملحوب': u'مَلْحُوبٍ', #9
u'ملحوبا': u'مَلْحُوبًا', #1
u'ملحود': u'مَلْحُودٍ', #1
u'ملحوقون': u'مَلْحُوقُونَ', #1
u'ملخبط': u'مُلَخْبَطٌ', #1
u'ملدم،': u'مِلْدَمٍ،', #1
u'ملدم': u'مِلْدَمٍ', #14
u'ملدم': u'مَلْدَمٍ', #4
u'ملدود': u'مَلْدُودٌ', #1
u'ملذوذات': u'مَلْذُوذَاتِ', #1
u'ملزوزا': u'مَلْزُوزًا', #1
u'ملزوق': u'مَلْزُوقٌ', #3
u'ملزوقة': u'مَلْزُوقَةٌ', #1
u'ملزوم': u'مَلْزُومِ', #2
u'ملزوم': u'مَلْزُومُ', #23
u'ملزوم': u'مَلْزُومٍ', #48
u'ملزوم': u'مَلْزُومَ', #5
u'ملزوم': u'مَلْزُومٌ', #75
u'ملزوما': u'مَلْزُومًا', #38
u'ملزومان': u'مَلْزُومَانِ', #1
u'ملزومة': u'مَلْزُومَةٌ', #5
u'ملزومة': u'مَلْزُومَةً', #8
u'ملزومه': u'مَلْزُومُهُ', #12
u'ملزومه': u'مَلْزُومِهِ', #25
u'ملزومه': u'مَلْزُومَهُ', #4
u'ملزومها': u'مَلْزُومَهَا', #1
u'ملزومها': u'مَلْزُومُهَا', #3
u'ملزومها': u'مَلْزُومِهَا', #4
u'ملزومهما': u'مَلْزُومِهِمَا', #1
u'ملزومهما': u'مَلْزُومُهُمَا', #3
u'ملزومية': u'مَلْزُومِيَّةَ', #1
u'ملزومية': u'مَلْزُومِيَّةِ', #2
u'ملزومين': u'مَلْزُومَيْنِ', #1
u'ملسكا': u'مَلْسَكًا', #1
u'ملصوقة': u'مَلْصُوقَةً', #1
u'ملصوقة': u'مَلْصُوقَةٍ', #1
u'ملصوقين': u'مَلْصُوقَيْنِ', #1
u'ملطاة': u'مِلْطَاةٌ', #1
u'ملطية،': u'مَلَطْية،', #1
u'ملطية،': u'مَلَطْيَةَ،', #1
u'ملطية': u'مَلَطْيَةَ', #5
u'ملغضا': u'مِلْغَضَا', #1
u'ملغيظ': u'مِلْغَيِظٍ', #1
u'ملغيظ': u'مِلْغَيْظِ', #1
u'ملفج': u'مُلْفِجٌ', #1
u'ملفج': u'مُلْفَجٌ', #4
u'ملفجا': u'مُلْفَجًا', #2
u'ملفع': u'مُلَفّعِ', #2
u'ملفع': u'مُلَفَّعٌ', #4
u'ملقام': u'مِلْقَامُ', #1
u'ملقف': u'مَلْقَفُ', #1
u'ملقما': u'مُلْقِمًا', #1
u'ملقمة': u'مُلَقِّمَةً', #1
u'ملقمة': u'مُلْقِمَةً', #2
u'ملقمة': u'مُلْقِمَةٌ', #2
u'ملقوح': u'مَلْقُوحٌ', #1
u'ملقوح': u'مَلْقُوحٍ', #10
u'ملقوحة': u'مُلْقُوحَةٍ', #1
u'ملقوحة': u'مَلْقُوحَةٌ', #2
u'ملقوحة': u'مَلْقُوحَةٍ', #6
u'ملكتكه': u'مَلَّكْتُكَهُ', #22
u'ملكتكها': u'مَلَّكْتُكَهَا', #14
u'ملكتكها': u'مَلَّكْتُكهَا', #15
u'ملككا': u'مِلْكِكَا', #1
u'ملككها': u'مَلَّكَكَهَا', #1
u'ملكمهما': u'مِلْكَمِهِمَا', #1
u'ملكناكها': u'مَلَّكْنَاكَهَا', #1
u'ملكنيه': u'مَلِّكْنِيهِ', #1
u'ملكنيه': u'مَلَّكَنِيهِ', #2
u'ملكنيها': u'مَلَّكَنِيهَا', #4
u'ملكوم': u'مَلْكُومٌ', #1
u'ملكى': u'مِلْكِى', #1
u'ملكى': u'مُلْكِى', #5
u'ملمحارب': u'مِلْمُحَارِبٍ', #1
u'ملمحارب': u'مِلْمُحَارِبِ', #1
u'ملموح': u'مَلْمُوحٍ', #1
u'ملهاشميين': u'مِلْهاشِمِيّينِ', #1
u'ملهاشميين': u'مَلْهَاشِمَيّيْنِ', #1
u'ملهج': u'مَلْهَجَ', #1
u'ملواث': u'مِلْوَاثٍ', #1
u'ملواح': u'مِلْوَاحٍ', #2
u'ملواهما': u'مَلَوَاهُمَا', #3
u'ملوط': u'مُلُوطٌ', #1
u'ملوط': u'مُلَوَّطٍ', #1
u'ملوط': u'مَلُوطٌ', #2
u'ملوط': u'مَلُوطٍ', #2
u'ملوطا': u'مُلُوطًا', #1
u'ملوطا': u'مَلُوطًا', #2
u'ملوطة': u'مَلُوطَةً', #2
u'ملى': u'مَلّى', #2
u'ملى': u'مَلِىٍّ', #8
u'ملىء': u'مَلِىءٍ', #1
u'ملئوم': u'مَلْئُومُ', #1
u'ملئوه،': u'مَلَئُوهُ،', #1
u'ملئوه': u'مَلَئُوهُ', #5
u'ملئوها': u'مَلَئُوهَا', #3
u'مليان': u'مَلِيَّانِ', #1
u'مليب': u'مُلَيْبٍ', #1
u'مليبار': u'مِلِيبَار', #1
u'مليبار': u'مِليِبَارَ', #1
u'مليبار': u'مَلِيبَارَ', #5
u'مليبار': u'مِلِيبَارَ', #7
u'مليخا': u'مَلِيخًا', #1
u'مليص': u'مُلَيْصِ', #1
u'مليص': u'مُلَيْصٍ', #6
u'مليقا': u'مُلِيقًا', #1
u'مليكة،': u'مليكة،', #1
u'مليكة،': u'مُلَيكة،', #1
u'مليكة،': u'مُليْكَةَ،', #1
u'مليكة': u'مُلَيْكَةِ', #1
u'مليكة،': u'مُلَيْكَةِ،', #1
u'مليكة': u'مُلَيْكة', #10
u'مليكة،': u'مُلَيْكَةَ،', #156
u'مليكة،': u'مُلَيْكة،', #2
u'مليكة': u'مليكة', #4
u'مليكة': u'مُلَيْكَةَ', #583
u'مليكة': u'مُلَيْكَة', #6
u'مليكة': u'مُلَيْكَةُ', #9
u'مليل': u'مُلَيْلِ', #11
u'مليل': u'مُلَيْلٍ', #20
u'مليل،': u'مُلَيْلٍ،', #3
u'مليل': u'مليل', #4
u'مليين': u'مليين', #1
u'مليين': u'مَلِيَّيْنِ', #4
u'مماتنا': u'مُمَاتِنًا', #1
u'مماذا': u'مِمَّاذَا', #2
u'ممازج': u'مُمَازِجٍ', #1
u'ممازج': u'مُمَازَجٍ', #2
u'ممازجا': u'مُمَازِجًا', #1
u'ممازجه': u'مُمَازِجِهِ', #1
u'ممالة': u'مُمَالَةٌ', #2
u'ممان': u'مُمَانٍ', #1
u'ممايلة': u'مُمَايَلَةٌ', #1
u'ممايلة': u'مُمَايَلَةُ', #1
u'ممايلة': u'مُمَايَلَةِ', #3
u'ممتشطة': u'مُمْتَشِطَةً', #2
u'ممحق': u'مُمْحِقٌ', #3
u'ممحقة': u'مَمْحَقَة', #1
u'ممحقة': u'مَمْحَقَةٌ', #12
u'ممحقة': u'مُمْحِقَةٌ', #4
u'ممحل': u'مُمْحِلٍ', #1
u'ممحل': u'مُمْحِلِ', #1
u'ممحلا،': u'مُمْحِلا،', #1
u'ممحلا': u'مُمْحِلًا', #1
u'ممحلين': u'مُمْحِلِينَ', #4
u'ممدحا': u'ممدحًا', #1
u'ممدحا': u'مُمَدَّحًا', #3
u'ممدحا،': u'مُمَدَّحًا،', #5
u'ممدوحية': u'مَمْدُوحِيَّةَ', #1
u'ممدوحيته': u'مَمْدُوحِيَّتِهِ', #1
u'ممرد': u'مُمَرَّدً', #1
u'ممرد': u'مُمَرَّدٍ', #1
u'ممرد': u'مُمَرَّدٌ', #7
u'ممردا': u'مُمَرَّدًا', #2
u'ممرع': u'مُمْرِعَ', #1
u'ممرعا': u'مُمْرَعًا', #1
u'ممرعا': u'مُمْرِعًا', #1
u'ممروق': u'مَمْرُوقٌ', #1
u'ممروقا': u'مَمْرُوقًا', #6
u'ممرئ': u'مُمْرِئٌ', #1
u'ممزع': u'مُمَزّعِ', #2
u'ممزع': u'مُمَزَّعِ', #5
u'ممسود': u'مَمْسُودٍ', #1
u'ممشاة': u'مَمْشَاةٍ', #3
u'ممشاة': u'مَمْشَاةُ', #4
u'ممشاد': u'مَمْشَادُ', #1
u'ممشاكا': u'مَمْشَاكَا', #1
u'ممشاى': u'مَمْشَاىَ', #1
u'ممشق،': u'ممشق،', #1
u'ممشق': u'مُمَشَّقٌ', #4
u'ممشقا': u'مُمَشَّقًا', #1
u'ممشقين': u'مُمَشَّقَيْنِ', #1
u'ممصر': u'مُمَصَّرِ', #1
u'ممصران': u'مُمَصَّرَانِ', #1
u'ممصرتين': u'مُمَصَّرَتَيْنِ', #2
u'ممصمصة': u'مُمَصْمِصَةٌ', #1
u'ممطور،': u'ممطور،', #1
u'ممطور،': u'مَمْطُورٌ،', #1
u'ممطور': u'مَمْطُور', #2
u'ممطور،': u'مَمْطُورٍ،', #2
u'ممطور': u'مَمْطُورٌ', #5
u'ممطور': u'مَمْطُورٍ', #6
u'ممطورة،': u'مَمْطُورَةَ،', #1
u'ممطورتين': u'مَمْطُورَتَيْنِ', #1
u'ممطول': u'مَمْطُولٌ', #1
u'ممطول': u'مَمْطُولٍ', #1
u'ممعط': u'مُمَعَّطَ', #1
u'ممكس': u'مُمَكَّسٍ', #1
u'ممكس': u'مُمَكَّسٌ', #3
u'ممكسة': u'مُمَكَّسَةٌ', #2
u'ممكنون': u'مُمَكَّنُونَ', #1
u'ممكورا': u'مَمْكُورًا', #2
u'ممكول': u'مَمْكُولٌ', #2
u'مملأة': u'مُمْلأَةٌ', #1
u'مملق': u'مُمْلِقٌ', #1
u'مملوء': u'مَمْلُوءً', #1
u'مملوح': u'مَمْلُوحٌ', #1
u'مملوح': u'مَمْلُوحٍ', #1
u'مملوحا': u'مملوحاً', #1
u'مملوحا': u'مَمْلُوحًا', #7
u'مملوحه': u'مَمْلُوحُهُ', #1
u'مملوسا': u'مَمْلُوسًا', #1
u'ممنشهد': u'مِمَّنْشَهِدَ', #1
u'ممنوء': u'مَمْنُوءٌ', #1
u'ممه،': u'مِمَّهْ،', #1
u'ممه؟': u'مِمَّهْ؟', #1
u'ممهور': u'مَمْهُورِ', #1
u'ممهورة': u'مَمْهُورَةٍ', #1
u'ممهى': u'مُمَهّى', #1
u'مموس': u'مُمَوَّسٌ', #1
u'مناااا': u'مِنْاااا', #1
u'منابذا': u'مُنَابَذًا', #1
u'منابذا': u'مُنَابِذًا', #1
u'منابذون': u'مُنَابِذُونَ', #1
u'منابذين': u'مُنَابِذِينَ', #2
u'منابط': u'مُنَابِطٍ', #1
u'مناة': u'َمنَاةَ', #1
u'مناة،': u'مَناةُ،', #1
u'مناة': u'مَنْاةَ', #1
u'مناة،': u'مَنَاةَ،', #1
u'مناة': u'مناة', #11
u'مناة': u'مَنَاةَ', #170
u'مناة': u'مَنَاةُ', #19
u'مناة': u'مَنَاةٍ', #2
u'مناة': u'مَنَاة', #3
u'مناة': u'مَنَاةِ', #6
u'مناتان': u'مَنَاتَانِ', #1
u'مناجزا': u'مُنَاجَزًا', #1
u'مناجمة': u'مُنَاجَمَةً', #1
u'مناحبته': u'مُنَاحَبَتِهِ', #1
u'مناخات': u'مُنَاخَاتٍ', #1
u'مناخان': u'مُنَاخَانِ', #1
u'مناخة،': u'منَاخَةَ،', #1
u'مناخة': u'مُنَاخَةً', #2
u'مناخة': u'مُنَاخَةٌ', #2
u'مناختان': u'مُنَاخَتَانِ', #2
u'مناخل': u'مَنَاخِلَ', #1
u'مناخل': u'مَنَاخِلُ', #3
u'منادح': u'مَنَادِحٌ', #1
u'منادح': u'مَنَادِحْ', #1
u'منادخ': u'مَنَادِخْ', #1
u'منادلنا': u'مَنَادِلُنَا', #1
u'منآدها': u'مُنْآدَهَا', #1
u'مناديح': u'مَنَادِيحُ', #1
u'مناس': u'مَنَاسٍ', #17
u'مناس': u'مَنَّاسٍ', #2
u'مناس': u'مُنَاسٍ', #4
u'منأسلم': u'مِنْأَسْلَمَ', #1
u'مناصح': u'مُنَاصِحٍ', #2
u'مناصيب': u'مَنَاصِيبُ', #1
u'مناصيب': u'مَنَاصِيبِ', #11
u'مناصيص': u'مَنَاصِيصِ', #1
u'مناطاة': u'مُنَاطَاةُ', #1
u'مناعص': u'مناعص', #1
u'مناغلمان': u'مِنَّاغِلْمَانٌ', #1
u'منافSوعبد': u'مَنَافSوَعَبْدُ', #1
u'منافأنا': u'مَنَافٍأَنَا', #1
u'منافاه': u'مَنَافَاهْ', #1
u'منافاه': u'مُنَافَاهُ', #1
u'منافاه': u'مَنَافَاهُ', #3
u'منافبن': u'مَنَافِبْنِ', #1
u'منافر': u'مُنَافِرٍ', #1
u'منافر': u'مُنَافِرٌ', #3
u'منافرا': u'مُنَافِرًا', #2
u'منافعا': u'مَنَافِعَا', #1
u'منافقفأخرجهم': u'مُنَافِقٌفَأَخْرَجَهُمْ', #1
u'منافلة': u'مُنَافَلَةً', #1
u'منافها': u'مَنَافِهَا', #2
u'منافو': u'مَنَافٍوَ', #1
u'مناقرا': u'مُنَاقِرًا', #2
u'مناقصا': u'مُنَاقِصًا', #1
u'مناقلا': u'مُنَاقِلًا', #1
u'مناقلا': u'مُنَاقَلًا', #7
u'مناكح': u'مَنَاكِحَ', #1
u'مناكح': u'مُنَاكِحَ', #1
u'مناكح': u'مَنَاكِحِ', #3
u'مناكحه': u'مَنَاكِحِهِ', #1
u'مناكحه': u'مُنَاكَحَهُ', #1
u'مناكحه': u'مُنَاكِحَهُ', #1
u'مناكحه': u'مُنَاكِحِهِ', #2
u'مناكحهم': u'مَنَاكِحِهِمْ', #1
u'مناكر': u'مُنَاكِرُ', #1
u'مناكرة': u'مُنَاكَرَةً', #1
u'مناكرة': u'مُنَاكَرَةُ', #10
u'مناكرة': u'مُنَاكَرَةِ', #2
u'مناكرة': u'مُنَاكَرَةَ', #39
u'مناكرة': u'مُنَاكَرَةٌ', #6
u'مناكرة': u'مُنَاكَرَةٍ', #9
u'مناكرته': u'مُنَاكَرَتَهُ', #1
u'مناكرته': u'مُنَاكَرَتُهُ', #5
u'مناكرتها': u'مُنَاكَرَتَهَا', #2
u'مناكرتها': u'مُنَاكَرَتِهَا', #2
u'مناكرتها': u'مُنَاكَرَتُهَا', #20
u'مناكل': u'مَنَاكِلُ', #1
u'منالأنصار': u'مِنْالْأَنْصَارِ', #1
u'منالحاجة': u'مِنْالْحَاجَةِ', #1
u'منالمدينة': u'مِنْالْمَدِينَةِ', #1
u'منالمسلمين': u'مِنْالْمُسْلِمِينَ', #1
u'منامى': u'مَنَامِى', #2
u'مناهبها': u'مَنَاهِبِهَا', #1
u'مناهجا': u'مَنَاهِجًا', #2
u'مناهر': u'مَنَاهِرِ', #2
u'مناهز': u'مُنَاهِزٌ', #1
u'مناهز': u'مُنَاهِزٍ', #2
u'منأهل': u'مِنْأَهْلِ', #1
u'مناهمة': u'مُنَاهَمَةَ', #1
u'مناهيج': u'مَنَاهِيجَ', #1
u'مناهيد،': u'مَنَاهِيدُ،', #1
u'مناو': u'مُنَاوٍ', #1
u'مناواة': u'مُنَاوَاةً', #1
u'مناواة': u'مُنَاوَاةُ', #1
u'مناوروي': u'مِنَّاوَرُوِيَ', #1
u'منائح': u'مَنَائِحُ', #3
u'منائحهم': u'مَنَائِحَهُمْ', #1
u'منائحهم،': u'مَنَائِحَهُمْ،', #1
u'منائحهم': u'مَنَائِحَهُمُ', #2
u'مناير': u'مَنَايِرُ', #1
u'منبج': u'مَنْبِج', #1
u'منبج': u'منبج', #2
u'منبج': u'مَنْبِجٍ', #2
u'منبجاني': u'منبجاني', #1
u'منبجاني': u'مَنْبَجَانِيٌّ', #1
u'منبجانية': u'مَنْبِجَانِيَّةٌ', #1
u'منبجي': u'منبجي', #1
u'منبرالنبي': u'مِنْبَرِالنَّبِيِّ', #1
u'منبرد': u'منبرد', #1
u'منبرى': u'مِنْبَرِى', #9
u'منبلج': u'مُنْبَلَجِ', #1
u'منبلع': u'مُنْبَلِعٌ', #1
u'منبهعن': u'مُنَبِّهٍعَنْ', #1
u'منبهفلما': u'مُنَبِّهٍفَلَمَّا', #1
u'منبهم': u'مُنْبَهِمٌ', #1
u'منبهم': u'مُنْبَهِمٍ', #3
u'منبهيذكر': u'مُنَبِّهٍيَذْكُرُ', #1
u'منبوحا': u'منبوحًا', #1
u'منبوحا': u'مَنْبُوحًا', #1
u'منبوش': u'مَنْبُوشٍ', #1
u'منبوش': u'مَنْبُوشٌ', #2
u'منبوشا': u'مَنْبُوشًا', #3
u'منبوشة': u'مَنْبُوشَةٍ', #3
u'منبوشة': u'مَنْبُوشَةً', #9
u'منبيات': u'مُنْبِيَاتٌ', #1
u'منتات': u'منتات', #1
u'منتبذ': u'مُنْتَبِذٍ', #1
u'منتبذ': u'مِنْتَبِذٌ', #1
u'منتبذ': u'مُنْتَبِذٌ', #2
u'منتبذا': u'مُنْتَبِذًا', #1
u'منتبذا': u'مُنْتَبَذًا', #2
u'منتبذتين': u'مُنْتَبَذَتَيْنِ', #1
u'منتبرا': u'مُنْتَبِرًا', #6
u'منتبزا': u'مُنْتَبِزًا', #1
u'منتتفا': u'مُنْتَتَفًا', #2
u'منتثر': u'مُنْتَثِرٍ', #1
u'منتثر': u'مُنْتَثِرُ', #2
u'منتثرا': u'مُنْتَثِرًا', #2
u'منتجب': u'مُنْتَجِبِ', #1
u'منتحلى': u'مُنْتَحِلِى', #1
u'منتخلا': u'مُنْتَخَلًا', #1
u'منتخلا': u'مُنْتَخَلَا', #1
u'منتز': u'مُنْتَزٍ', #2
u'منتسجة': u'مُنْتَسِجَةٌ', #1
u'منتشب': u'مُنْتَشِبْ', #1
u'منتشبا': u'مُنْتَشِبًا', #2
u'منتضح': u'مُنْتَضَحٌ', #1
u'منتطقا': u'مُنْتَطِقًا', #2
u'منتقبات': u'مُنْتَقِبَاتٍ', #1
u'منتقبة': u'مُنْتَقِبَةٌ', #21
u'منتقبة': u'مُنْتَقِبَةٍ', #27
u'منتقبة': u'مُنْتَقِبَةً', #43
u'منتقبون': u'مُنْتَقِبُونَ', #1
u'منتقش': u'منتقش', #1
u'منتقع': u'مُنْتَقَع', #1
u'منتقع': u'مُنْتَقَعٌ', #1
u'منتقع': u'مُنْتَقَعُ', #2
u'منتقع': u'مُنْتَقِعَ', #2
u'منتقع': u'مُنْتَقِعُ', #3
u'منتقعا': u'مُنْتَقَعَا', #1
u'منتقعا': u'مُنْتَقَعًا', #2
u'منتقعا': u'مُنْتَقِعًا', #6
u'منتكث': u'مُنْتَكِثِ', #2
u'منتهب': u'مُنْتَهَبٍ', #1
u'منتهب': u'مُنْتَهِب', #1
u'منتهب': u'مُنْتَهِبِ', #1
u'منتهب': u'مُنْتَهَبِ', #2
u'منتهب': u'مُنْتَهِبٍ', #37
u'منتهب': u'مُنْتَهِبٌ', #7
u'منتهبا': u'مُنْتَهِبًا', #4
u'منتهبون': u'مُنْتَهِبُونَ', #5
u'منتوف': u'مَنْتُوفَ', #1
u'منتوفا': u'مَنْتُوفًا', #6
u'منتوفها': u'مَنْتُوفُهَا', #1
u'منثر': u'مُنَثَّرٌ', #1
u'منثعبه': u'مُنْثَعِبَهْ', #2
u'منثلما': u'مُنْثَلِمًا', #1
u'منثنى': u'مُنْثَنَى', #1
u'منجا': u'مَنْجَا', #29
u'منجا': u'مُنَجَّا', #873
u'منجاب': u'مِنْجَابٌ', #11
u'منجاب،': u'مِنْجَابٌ،', #145
u'منجاب': u'مِنْجَابِ', #2
u'منجاب،': u'مِنْجَابُ،', #2
u'منجاب': u'مِنْجَابُ', #235
u'منجاب': u'منجاب', #3
u'منجاب،': u'منجاب،', #3
u'منجاب،': u'مِنْجَابٍ،', #4
u'منجاب': u'مِنْجَابٍ', #8
u'منجابا': u'منجابا', #1
u'منجاب،أنبأ': u'مِنْجَابٌ،أَنْبَأَ', #2
u'منجحرا': u'مُنْجَحِرًا', #1
u'منجدل': u'مُنْجَدَلٌ', #1
u'منجدل': u'مُنْجَدِلٌ', #3
u'منجدلا': u'مُنْجَدِلًا', #2
u'منجدم': u'مُنْجَدِمٍ', #1
u'منجذم': u'مُنْجَذِمٍ', #3
u'منجردا': u'مُنْجَرِدًا', #1
u'منجنوق': u'مَنْجَنُوقٌ', #1
u'منجنون': u'مَنْجَنُونٍ', #1
u'منجنونا': u'مَنْجَنُونًا', #1
u'منجنين': u'مَنْجَنِينُ', #1
u'منجه': u'منجه', #2
u'منجوسات': u'مَنْجُوسَاتٌ', #1
u'منجوف،': u'منجوف،', #1
u'منجوف': u'مَنْجُوفِ', #1
u'منجوف،': u'مَنْجُوفٍ،', #3
u'منجوف': u'مَنْجُوفٍ', #5
u'منجوفة': u'مَنْجُوفَةٌ', #2
u'منجويه': u'مَنْجَوَيْهِ', #2
u'منحتكه': u'مَنَحْتُكَهُ', #4
u'منحتكها': u'مَنَحْتُكَهَا', #1
u'منحديث': u'مِنْحَدِيثِ', #1
u'منحذف': u'مُنْحَذِفْ', #4
u'منحرة': u'مُنَحَّرَةً', #1
u'منحرة،': u'مُنَحَّرَةً،', #1
u'منحسم': u'مُنْحَسِمٍ', #1
u'منحصرون': u'مُنْحَصِرُونَ', #1
u'منحور': u'مَنْحُورٌ', #1
u'منحور': u'مَنْحُورٍ', #1
u'منحورا': u'مَنْحُورًا', #11
u'منحورة': u'مَنْحُورَةً', #1
u'منحورة': u'مَنْحُورَةٌ', #1
u'منحورة': u'مَنْحُورَةٍ', #1
u'منحوره': u'مَنْحُورَهُ', #1
u'منحوره': u'مَنْحُورِهِ', #10
u'منخرق': u'مُنْخَرِقٍ', #7
u'منخرقا': u'مُنْخَرِقًا', #2
u'منخرقة': u'مُنْخَرِقَةً', #2
u'منخسف': u'مُنْخَسَفِ', #1
u'منخسف': u'مُنْخَسِفُ', #1
u'منخسف': u'مُنْخَسِفٌ', #2
u'منخسف': u'مُنْخَسِفِ', #4
u'منخسفا': u'مُنْخَسِفًا', #5
u'منخسفة': u'مُنْخَسِفَةٌ', #1
u'منخسفة': u'مُنْخَسِفَةٍ', #2
u'منخل': u'مُنْخُلٌ', #1
u'منخل': u'مُنْخُلٍ', #2
u'منخلا': u'مُنْخُلًا', #2
u'منخور': u'مُنْخُورٌ', #1
u'منخول': u'مَنْخُولٍ', #3
u'منخولا': u'مَنْخُولًا', #8
u'منخولان': u'مَنْخُولَانِ', #1
u'منخوله': u'مَنْخُولِهِ', #2
u'مندا': u'مندا', #1
u'منداد': u'مِنْدَادَ', #2
u'منداد': u'مِنْدَادٍ', #3
u'منداد': u'مَنْدَادٍ', #64
u'مندبة': u'مَنْدَبَةً', #1
u'مندة': u'مَنْدَةَ', #2
u'مندحة': u'مَنْدَحَةٍ', #1
u'منددر': u'منددر', #1
u'مندرا': u'مُنْدِرًا', #1
u'مندرئ': u'مُنْدَرِئٌ', #1
u'مندمل': u'مُنْدَمِلٍ', #9
u'مندملا': u'مُنْدَمِلًا', #4
u'مندملة': u'مُنْدَمِلَةٌ', #1
u'مندملة': u'مُنْدَمِلَةً', #4
u'مندملة': u'مُنْدَمِلَةٍ', #8
u'منده': u'منده', #1
u'منده': u'مَنْده', #1
u'منده': u'مَنْدَهْ', #145
u'منده،': u'مَنْدَه،', #2
u'منده': u'مَنْدَه', #3
u'منده،': u'مَنْدَهْ،', #7
u'مندوس': u'منْدُوسٌ', #1
u'مندوس': u'منْدُوسٍ', #2
u'مندوف': u'مَنْدُوفٍ', #1
u'مندوف': u'مَنْدُوفٌ', #2
u'مندويه': u'مَنْدَوَيْهِ', #2
u'مندى': u'مُنَدًّى', #1
u'مندى': u'مُنْدًى', #1
u'مندى': u'مُنَدَّى', #3
u'منرسول': u'مِنْرَسُولٍ', #1
u'منزعات': u'مَنْزَعَاتِ', #1
u'منزفينا': u'مُنزفِينا', #1
u'منزفينا': u'مُنْزِفِينَا', #1
u'منزلتى': u'مَنْزِلَتِى', #1
u'منزلهرجع': u'مَنْزِلِهِرَجَعَ', #1
u'منزلى': u'مَنْزِلِى', #15
u'منزوح': u'مَنْزُوحٌ', #1
u'منزور': u'مَنْزُورِ', #3
u'منزولات': u'مَنْزُولَاتٌ', #2
u'منزولة': u'مَنْزُولَةً', #1
u'منساة': u'مُنْسَاةٌ', #1
u'منست': u'منست', #13
u'منسجف': u'مُنْسَجِفٌ', #1
u'منسر': u'مَنْسَرٌ', #1
u'منسر': u'مَنْسِرٌ', #2
u'منسر': u'مِنْسَرٌ', #2
u'منسرا': u'مَنْسَرًا', #1
u'منسولة': u'مَنْسُولَةٍ', #1
u'منسى': u'مُنْسَى', #1
u'منشج': u'مَنْشجِ', #1
u'منشج': u'مَنْشِجِ', #1
u'منشزا': u'مُنْشِزًا', #3
u'منشعب': u'مُنْشَعِبٍ', #2
u'منشم': u'مَنْشَمَ', #1
u'منشم': u'مَنْشَمُ', #1
u'منشم': u'مَنْشَمِ', #6
u'منشوش': u'مَنْشُوشٍ', #1
u'منشوشا': u'مَنْشُوشًا', #1
u'منشىء': u'مُنْشِىءُ', #1
u'منشئية': u'مَنْشَئِيَّةِ', #4
u'منصص': u'مُنَصِّصَ', #1
u'منصصا': u'مُنَصِّصًا', #1
u'منصوبون': u'مَنْصُوبُونَ', #1
u'منصورقربزان،': u'مَنْصُورٍقُرْبُزَانَ،', #1
u'منضج': u'مُنْضِجٌ', #5
u'منضجة': u'مُنْضِجَةٌ', #2
u'منضضا': u'مُنَضَّضًا', #1
u'منضول': u'مَنْضُولَ', #2
u'منضول': u'مَنْضُولٍ', #3
u'منضولا': u'مَنْضُولًا', #6
u'منطرق': u'مُنْطَرِقٍ', #1
u'منطفة': u'مُنَطّفَةٌ', #1
u'منطورة': u'مَنْطُورَةً', #1
u'منظراني': u'منظراني', #1
u'منعايا': u'منعايا', #1
u'منعتنى': u'مَنَعَتْنِى', #1
u'منعتنى': u'مَنَعْتَنِى', #1
u'منعكسون': u'مُنْعَكِسُونَ', #1
u'منعل': u'مُنْعَلٍ', #1
u'منعل': u'مُنْعَلُ', #1
u'منعل': u'مُنَعَّلٌ', #2
u'منعل': u'مُنَعَّلٍ', #5
u'منعلا': u'مَنْعَلًا', #1
u'منعلا': u'مُنَعَّلًا', #15
u'منعلا': u'مُنْعَلًا', #4
u'منعلة': u'مُنَعَّلَةً', #1
u'منعلة': u'مُنَعَّلَةٌ', #1
u'منعلين': u'منعلين', #1
u'منعلين': u'مُنَعَّلَيْنِ', #15
u'منعلين': u'مُنْعَلَيْنِ', #3
u'منعنى': u'مَنَعَنِى', #7
u'منعنيه': u'مَنَعَنِيهِ', #2
u'منعوشا': u'مَنْعُوشًا', #1
u'منعوشة': u'مَنْعُوشَةً', #2
u'منعولة': u'مَنْعُولَةً', #5
u'منعولين': u'مَنْعُولَيْنِ', #3
u'منعونى': u'مَنَعُونِى', #12
u'منغلا': u'مُنْغَلًا', #1
u'منغلة': u'مُنْغَلَّةً', #1
u'منف،': u'مَنْفٌ،', #1
u'منفحة': u'مِنْفَحَةً', #1
u'منفحة': u'مِنْفَحَةٌ', #4
u'منفخة': u'مَنْفَخَةٌ', #1
u'منفخة': u'مَنْفَخَةُ', #1
u'منفعةااا': u'مَنْفَعَةًااا', #1
u'منفك': u'مُنْفَكٍّ', #12
u'منفك': u'مُنْفَكٌّ', #13
u'منفك': u'مُنْفَكَّ', #18
u'منفك': u'مُنْفَكِّ', #2
u'منفك': u'مُنْفَكُّ', #22
u'منفكا': u'مُنْفَكًّا', #9
u'منفكان': u'مُنْفَكَّانِ', #1
u'منفكة': u'مُنْفَكَّةً', #11
u'منفكة': u'مُنْفَكَّةٍ', #17
u'منفكة': u'مُنْفَكَّةٌ', #19
u'منفكتان': u'مُنْفَكَّتَانِ', #1
u'منفكين': u'مُنْفَكَّيْنِ', #1
u'منفكين': u'مُنفَكِّينَ', #4
u'منفكين': u'مُنْفَكِّينَ', #6
u'منفل': u'مُنَفِّلُ', #1
u'منفل': u'مُنْفَلٌ', #1
u'منفلوط': u'مَنْفَلُوطَ', #2
u'منفهم': u'مُنْفَهِمٌ', #1
u'منفهم': u'مُنْفَهِمٍ', #2
u'منفو': u'مَنْفُوَّ', #1
u'منفوذ': u'مَنْفُوذٌ', #1
u'منفوذ': u'مَنْفُوذٍ', #2
u'منفوذ': u'مَنْفُوذِ', #35
u'منفوذ': u'مَنْفُوذَ', #39
u'منفوذ': u'مَنْفُوذُ', #8
u'منفوذا': u'مَنْفُوذًا', #1
u'منفوذة': u'مَنْفُوذَةٌ', #1
u'منفوذة': u'مَنْفُوذَةُ', #1
u'منفوذة': u'مَنْفُوذَةٍ', #3
u'منفوذة': u'مَنْفُوذَةِ', #5
u'منفوذة': u'مَنْفُوذَةَ', #6
u'منفوذتها': u'مَنْفُوذَتِهَا', #1
u'منفوذه': u'مَنْفُوذِهِ', #1
u'منفوذها': u'مَنْفُوذَهَا', #1
u'منفوذها': u'مَنْفُوذُهَا', #1
u'منفوذها': u'مَنْفُوذِهَا', #3
u'منفوس': u'مَنْفُوسِ', #2
u'منفوس': u'مَنْفُوسٌ', #3
u'منفوس': u'مَنْفُوسٍ', #3
u'منفوسا': u'مَنْفُوسًا', #1
u'منفوسة': u'مَنْفُوسَةً', #1
u'منفوسة': u'مَنْفُوسَةُ', #1
u'منفوسة،': u'مَنْفُوسَةٍ،', #1
u'منفوسة': u'مَنْفُوسَةٌ', #12
u'منفوسة': u'مَنْفُوسَةٍ', #23
u'منقاس': u'مُنْقَاسٌ', #11
u'منقاس': u'مُنْقَاسٍ', #2
u'منقاسا': u'مُنْقَاسًا', #2
u'منقاسة': u'مُنْقَاسَةٌ', #1
u'منقاض': u'مُنْقَاضُ', #1
u'منقتاله': u'منقتاله', #1
u'منقد': u'مُنْقِدُ', #1
u'منقد': u'مُنْقِدِ', #1
u'منقد': u'مُنْقِدٍ', #2
u'منقدح': u'مُنْقَدِحٍ', #1
u'منقدح': u'مُنْقَدِحُ', #1
u'منقدح': u'مُنْقَدِحٌ', #10
u'منقدحا': u'مُنْقَدِحًا', #3
u'منقر': u'مِنْقَرٍ', #1
u'منقر': u'مِنْقَرِ', #4
u'منقش': u'مُنَقَّشٌ', #1
u'منقش': u'مُنَقَّشٍ', #6
u'منقشا': u'مُنَقَّشًا', #4
u'منقشة': u'مُنَقَّشَة', #1
u'منقشة': u'مُنَقَّشَةً', #3
u'منقلبى': u'مُنْقَلَبِى', #1
u'منقود': u'مَنْقُودُ', #1
u'منقود': u'مَنْقُودٌ', #20
u'منقود': u'مَنْقُودٍ', #55
u'منقودا': u'مَنْقُودًا', #90
u'منقودة': u'مَنْقُودَةٌ', #1
u'منقودة': u'مَنْقُودَةٍ', #1
u'منقودين': u'مَنْقُودَيْنِ', #1
u'منقول': u'مَنْقُولً', #1
u'منكا': u'مِنْكَا', #1
u'منكاب': u'مِنْكَابٌ', #3
u'منكبى': u'مَنْكِبَىِ', #1
u'منكبى': u'مَنْكِبَىْ', #2
u'منكبى': u'مَنْكِبِى', #4
u'منكراست': u'منكراست', #1
u'منكرم': u'منكرم', #1
u'منكرية': u'مُنْكَرِيَّةِ', #1
u'منكشطة': u'مُنْكَشِطَةٍ', #1
u'منكمو': u'مِنْكُمُو', #1
u'منكورس': u'مِنْكَوْرَسٍ', #23
u'منكورس': u'مِنْكَوْرَسٌ', #3
u'منكولة': u'مَنْكُولَةٍ', #1
u'منكيا': u'مُنْكِيًا', #1
u'منلا': u'مُنْلَا', #220
u'منماة': u'مَنْمَاةٌ', #1
u'منمر': u'مُنَمَّرٍ', #2
u'منمكة': u'مِنْمَكَّةَ', #1
u'منه': u'مِنْهًًًًُ', #1
u'منهاSوذكر': u'مِنْهَاSوَذَكَرَ', #1
u'منهاسجدة': u'مِنْهَاسَجْدَةٌ', #1
u'منهاما': u'مِنْهَامَا', #1
u'منهب': u'مُنْهِبِ', #1
u'منهب،': u'مَنْهَبٍ،', #1
u'منهب،': u'مُنْهِبٍ،', #1
u'منهب': u'مُنْهِبٍ', #3
u'منهد': u'مُنْهِدٌ', #1
u'منهد': u'مُنْهَدّ', #2
u'منهر': u'مَنْهَرٍ', #1
u'منهر': u'مُنْهَر', #1
u'منهر': u'مُنْهِرٌ', #1
u'منهرا': u'مَنْهَرًا', #3
u'منهرة': u'مَنْهَرَةٍ', #1
u'منهسا': u'مِنْهَسَا', #1
u'منهفعجبت': u'مِنْهُفَعَجِبْتُ', #1
u'منهمالوجه': u'مِنْهُمْالْوَجْهُ', #1
u'منهمثم': u'مِنْهُمْثُمَّ', #1
u'منهمقال': u'مِنْهُمْقَالَ', #1
u'منهمقوله': u'مِنْهُمْقَوْلُهُ', #2
u'منهممن': u'مِنْهُمْمَنْ', #1
u'منهمو': u'مِنْهُمُو', #3
u'منهنإلى': u'مِنْهُنَّإِلَى', #1
u'منهوات': u'مُنْهَوَاتُ', #1
u'منهوات': u'مُنْهَوَاتِ', #5
u'منهواته': u'مَنْهُوَّاتِهِ', #3
u'منهوس': u'مَنْهُوسُ', #3
u'منهوس': u'مَنْهُوسَ', #9
u'منهوم': u'مَنْهُومٌ', #3
u'منهومان': u'مَنْهُومَانِ', #6
u'منهى': u'منهى', #1
u'منهى': u'مَنْهِىٌّ', #3
u'منهى': u'مُنْهًى', #4
u'منوا': u'مَنْوًا', #1
u'منواب': u'منواب', #1
u'منوان': u'مَنَوَانِ', #11
u'منوب': u'منوب', #5
u'منوبه': u'مَنُوبُهُ', #1
u'منوبه': u'مُنَوِّبِهِ', #2
u'منوبه': u'مَنُوبِهِ', #3
u'منوجهر': u'مَنُوجَهْرُ', #1
u'منوشهر': u'مِنُوشِهْرُ', #1
u'منوشهر': u'منوشهر', #4
u'منوفي': u'مَنُوفِيٌّ', #1
u'منوقة': u'مُنَوَّقَةٌ', #3
u'منويل': u'منويل', #1
u'منويل': u'منْوِيل', #1
u'مني': u'مِنًي', #2
u'منىء': u'منىء', #1
u'منيح': u'مَنِيحَ', #1
u'منيحة': u'منيحة', #1
u'منيحة': u'مَنِيحَةٍ', #1
u'منيحة': u'مَنِيحَةَ', #10
u'منيحة': u'مَنِيحَة', #2
u'منيحة': u'مَنِيحَةِ', #2
u'منيحة': u'مُنَيْحَةَ', #2
u'منيحة': u'مَنِيحَةُ', #4
u'منيحة': u'مَنِيحَةً', #6
u'منيخ': u'منيخ', #1
u'منيخ': u'مُنِيخ', #1
u'منيخ': u'مُنِيخٌ', #10
u'منيخان': u'مُنِيخَانِ', #1
u'منيذر': u'مُنَيْذِرٌ', #1
u'منيراSقصيدة': u'مُنِيرَاSقَصِيدَةٌ', #1
u'منيس': u'مُنِيس', #1
u'منيلة': u'مُنَيَّلَةٍ', #1
u'منيم': u'مُنِيمٌ', #1
u'منيوك': u'مَنْيُوكُ', #3
u'منيوكة': u'مَنْيُوكَةً', #1
u'منيوكة': u'مَنْيُوكَةَ', #3
u'منيوكة': u'مَنْيُوكَةُ', #4
u'منيئة': u'مَنِيئَةٌ', #1
u'منيئة': u'مَنِيئَةً', #9
u'منيئتي': u'مَنِيئَتِي', #1
u'منييعني': u'مِنِّييَعْنِي', #1
u'مهاجريا': u'مهاجريا', #1
u'مهاجريا': u'مُهَاجِرِيًّا', #2
u'مهارش': u'مُهَارِشٍ', #4
u'مهارشة': u'مُهَارَشَةِ', #3
u'مهاريج': u'مَهَارِيجَ', #1
u'مهازيل': u'مَهَازِيلَ', #10
u'مهازيل': u'مَهَازِيل', #2
u'مهازيل': u'مَهَازِيلُ', #7
u'مهاصر،': u'مُهَاصِر،', #1
u'مهانأة': u'مُهَانَأَةٌ', #1
u'مهانأة': u'مُهَانَأَةٍ', #1
u'مهايأة': u'مُهَايَأَةُ', #1
u'مهايأة': u'مُهَايَأَةً', #164
u'مهايأة': u'مُهَايَأَةِ', #2
u'مهايأة': u'مُهَايَأَةٌ', #204
u'مهايأة': u'مُهَايَأَةٍ', #24
u'مهايأة': u'مُهَايَأَةَ', #38
u'مهايات': u'مُهَايَاتٌ', #1
u'مهايأتها': u'مُهَايَأَتُهَا', #2
u'مهايأتهم': u'مُهَايَأَتُهُمْ', #1
u'مهايأه': u'مُهَايَأَهُ', #1
u'مهبود': u'مَهْبُودٌ', #2
u'مهتجرين': u'مُهْتَجِرَيْنِ', #1
u'مهتدلة': u'مُهْتَدِلَةٌ', #1
u'مهتر': u'مُهْتَرُ', #1
u'مهتضم': u'مُهْتَضَمَ', #1
u'مهتضم': u'مُهْتَضِمٌ', #1
u'مهتضم': u'مُهْتَضِمٍ', #1
u'مهتضم': u'مُهْتَضَمٍ', #2
u'مهتوما،': u'مَهْتُومًا،', #1
u'مهجاة': u'مُهَجَّاةٌ', #22
u'مهجات': u'مُهُجَاتِ', #2
u'مهجى': u'مُهَجًّى', #2
u'مهجى': u'مُهْجًى', #3
u'مهذم': u'مِهْذَمٌ', #1
u'مهركان': u'مهركان', #3
u'مهرماه': u'مهرماه', #1
u'مهرمة': u'مَهْرَمَةٌ', #2
u'مهروب': u'مَهْرُوبٌ', #3
u'مهرودتين': u'مَهْرُودَتَيْنِ', #5
u'مهروذ': u'مَهْرُوذٌ', #1
u'مهروذتين': u'مَهْرُوذَتَيْنِ', #1
u'مهرويه': u'مَهْرَوَيْهِ', #1
u'مهرويه': u'مِهْرُوَيْهِ', #1
u'مهرويه': u'مِهْرَوَيْهِ', #5
u'مهرويه': u'مَهْرُوَيْهِ', #8
u'مهرى': u'مُهْرِى', #1
u'مهريق': u'مُهَرِيقٌ', #3
u'مهريقين': u'مُهْرِيقِينَ', #1
u'مهزاق': u'مِهْزَاقُ', #1
u'مهزم': u'مهْزَمٍ', #1
u'مهزم': u'مُهَزِّمٍ', #1
u'مهزم': u'مِهْزَمٌ', #1
u'مهزم': u'مِهْزَمٍ', #5
u'مهزور': u'مَهْزُور', #1
u'مهزور': u'مَهْزُورِ', #1
u'مهزور': u'مَهْزُورٌ', #3
u'مهزور': u'مَهْزُورٍ', #5
u'مهسع': u'مهسع', #1
u'مهسع': u'مِهْسَعَ', #2
u'مهسع': u'مِهْسَعِ', #2
u'مهشوم': u'مَهْشُومٍ', #1
u'مهشوما': u'مَهْشُومًا', #3
u'مهضم': u'مُهَضِّمٌ', #1
u'مهلائيل': u'مَهْلاَئِيلَ', #1
u'مهلائيل': u'مهْلائِيل', #3
u'مهلايل': u'مِهْلَايِلَ', #1
u'مهلايل': u'مهلايل', #2
u'مهلايل': u'مَهْلَايِلَ', #2
u'مهلاييل': u'مِهْلَايِيلَ', #1
u'مهلاييل،': u'مِهْلَايِيلَ،', #1
u'مهلب': u'مُهَلَّبِ', #1
u'مهلكتى': u'مُهْلِكَتِى', #2
u'مهلملة': u'مهلملة', #1
u'مهليل': u'مِهْلِيلَ', #1
u'مهليل': u'مهْلَيِل', #2
u'مهملج': u'مُهَمْلَجٌ', #1
u'مهملج': u'مُهَمْلِجٌ', #1
u'مهملج': u'مُهَمْلِجٍ', #1
u'مهملجا': u'مُهَمْلِجًا', #4
u'مهملجة': u'مُهَمْلِجَةً', #3
u'مهنى': u'مُهَنَّى', #1
u'مهوذل': u'مُهَوْذِلٍ', #1
u'مهيابه': u'مهيابه', #1
u'مهيار': u'مِهْيَارِ', #1
u'مهيرة': u'مَهِيرَةً', #2
u'مهيرة': u'مَهِيرَةَ', #2
u'مهيع': u'مَهِيعٌ', #1
u'مهيع': u'مَهِيعٍ', #1
u'مهيع': u'مَهِيعَ', #1
u'مهيع': u'مَهْيَعٍ', #1
u'مهيع': u'مَهْيَعُ', #1
u'مهيع': u'مَهْيَعٌ', #2
u'مهيعا': u'مَهِيعًا', #1
u'مهيعة': u'مَهْيَعَةُ', #11
u'مهيعة': u'مَهْيَعَةَ', #17
u'مهيعة': u'مَهْيَعَةٍ', #2
u'مهيعة': u'مَهْيَعَةٌ', #3
u'مهيعه': u'مَهِيعِهِ', #1
u'مهيعهم': u'مَهِيعِهِمْ', #1
u'مهيلا': u'مَهِيلًا', #3
u'مهينم': u'مُهَيْنِمٍ', #1
u'مهينم': u'مُهَيْنِمٌ', #2
u'مهيومة': u'مَهْيُومَةٌ', #2
u'مو': u'مو', #1
u'موءودا': u'مَوْءُودًا', #1
u'موءودة': u'مَوْءُودَةٍ', #1
u'موءودة': u'مَوْءُودَةً', #20
u'مؤاب': u'مُؤَابٌ', #1
u'مؤاب': u'مُؤَابٍ', #1
u'مؤابا': u'مُؤَابًا', #2
u'موابأة': u'مُوَابَأَةُ', #1
u'مواتم': u'مَوَاتِمُ', #1
u'مؤاتى': u'مُؤَاتًى', #1
u'مواجب': u'مَوَاجِبِ', #12
u'مواجب': u'مُوَاجِبِ', #3
u'مواجب': u'مُوَاجَبِ', #4
u'مواجبه': u'مَوَاجِبَهُ', #1
u'مواجبه': u'مُوَاجِبَهُ', #1
u'مواجبه': u'مَوَاجِبِهِ', #11
u'مواجبه': u'مَوَاجِبُهُ', #2
u'مواجبه': u'مُوَاجَبِهِ', #2
u'مواجبه': u'مُوَاجِبِهِ', #3
u'مؤاجر': u'مُؤَاجَرٌ', #1
u'مؤاجر': u'مُؤَاجِرٍ', #1
u'مؤاجر': u'مُؤَاجِرِ', #1
u'مؤاجر': u'مُؤَاجِرُ', #11
u'مؤاجر': u'مُؤَاجِرٌ', #17
u'مؤاجرا': u'مُؤَاجَرًا', #1
u'مؤاجرا': u'مُؤَاجِرًا', #6
u'مؤاجرة': u'مُؤَاجَرَةَ', #2
u'مؤاجرة': u'مُؤَاجَرَةِ', #2
u'مؤاجرة': u'مُؤَاجَرَةُ', #7
u'مؤاجرته': u'مُؤَاجَرَتُهُ', #1
u'مؤاجرتها': u'مؤاجرتها', #1
u'مؤاجرتها': u'مُؤَاجَرَتُهَا', #1
u'مؤاجرتهم': u'مُؤَاجَرَتُهُمْ', #1
u'مؤاجره': u'مُؤَاجِرِهِ', #4
u'مؤاجرين': u'مُؤَاجَرِينَ', #1
u'مواجل': u'مَوَاجِلَ', #1
u'مواجل': u'مَوَاجِلِ', #8
u'مواجيز': u'مَوَاجِيزِ', #1
u'مواخ': u'مُوَاخٍ', #1
u'مواخاة': u'مُوَاخَاةً', #1
u'مواخض': u'مَوَاخِضَ', #1
u'مواخما': u'مُوَاخِمًا', #1
u'مؤادة': u'مُؤَادَة', #1
u'مؤادة': u'مُؤَادَّةً', #2
u'موادعا': u'مُوَادِعًا', #3
u'موادعون': u'مُوَادَعُونَ', #1
u'موادعون': u'مُوَادِعُونَ', #4
u'موادعيكم': u'مُوَادِعِيكُمْ', #1
u'موادعين': u'مُوَادِعِينَ', #15
u'موادعينا': u'مُوَادِعِينَا', #8
u'مؤاده': u'مُؤَادَهُ', #1
u'مؤادهما': u'مُؤَادَهُمَا', #1
u'موارتهما': u'مَوَّارَتُهُمَا', #1
u'موارث': u'مَوَارِثُ', #1
u'موارثاته': u'مُوَارَثَاتِهِ', #1
u'موارثة': u'مُوَارَثَةٌ', #1
u'موارثة': u'مُوَارَثَةَ', #1
u'موارثته': u'مُوَارَثَتُهُ', #2
u'مواره': u'مَوَّارُهُ', #1
u'مواره': u'مَوّارُهُ', #3
u'موازروه': u'مُوَازِرُوهُ', #2
u'موازى': u'مُوَازِىَ', #2
u'موازى': u'مُوَازِى', #6
u'مواشك': u'مُوَاشِكٌ', #1
u'مواضح': u'مَوَاضِحَ', #11
u'مواضح': u'مَوَاضِحُ', #9
u'مواضعات': u'مُوَاضَعَاتِ', #1
u'مواضعة': u'مُوَاضِعَةٍ', #1
u'مواضعة': u'مُوَاضَعَةِ', #2
u'مواضعة': u'مُوَاضَعَةٌ', #26
u'مواضعة': u'مُوَاضَعَةً', #28
u'مواضعة': u'مُوَاضَعَةٍ', #38
u'مواضعة': u'مُوَاضَعَةُ', #4
u'مواضعة': u'مُوَاضَعَةَ', #70
u'مواضعتها': u'مُوَاضَعَتَهَا', #1
u'مواضعتها': u'مُوَاضَعَتُهَا', #13
u'مواضعتها': u'مُوَاضَعَتِهَا', #17
u'مواضعتهم': u'مُوَاضَعَتِهِمْ', #2
u'مواضعيها': u'مَوَاضِعِيهَا', #1
u'مواعيظ': u'مَوَاعِيظٌ', #4
u'موافات': u'مُوَافَاتِ', #1
u'مواق': u'مَوَّاقٌ', #11
u'مواق': u'مواق', #2
u'مواقعا': u'مُوَاقِعًا', #1
u'مواقعوها': u'مُوَاقِعُوهَا', #5
u'مواقعيها': u'مُوَاقِعِيهَا', #1
u'مواقفا': u'مُوَاقِفًا', #1
u'مواقفين': u'مُوَاقِفِينَ', #1
u'مواقير': u'مَوَاقِيرُ', #1
u'مواكرة': u'مُوَاكَرَةَ', #1
u'مواكل': u'مُوَاكِلِ', #2
u'مواكليه': u'مُوَاكِلِيهِ', #1
u'مؤالف': u'مُؤَالِفٍ', #1
u'مؤامنا': u'مُؤَامَنَا', #1
u'مؤامية': u'مُؤَامِية', #1
u'موامية': u'مُوَامِيَة', #1
u'مواميه': u'مُوَامِيَهْ', #4
u'موانح': u'مَوَانِحَ', #1
u'موانيذ': u'مَوَانِيذُ', #1
u'مواه': u'مِوَاهٌ', #1
u'مواهقة': u'مُوَاهَقَةً', #5
u'موبذان؟': u'مُوبَذَانُ؟', #1
u'مؤبر': u'مُؤَبَّرٍ', #33
u'مؤبر': u'مُؤَبَّرٌ', #42
u'مؤبرا،': u'مُؤَبَّرًا،', #1
u'مؤبرا': u'مُؤَبَّرًا', #36
u'مؤبرة': u'مُؤَبَّرَةَ', #1
u'موبرة': u'مُوَبَّرَةً', #1
u'مؤبرة': u'مُؤَبَّرَةٌ', #17
u'مؤبرة': u'مُؤَبَّرَةٍ', #54
u'مؤبرة': u'مُؤَبَّرَةً', #62
u'موبص': u'موبص', #2
u'مؤبلة': u'مُؤَبّلَةً', #1
u'مؤبلة': u'مُؤَبّلَةٌ', #1
u'مؤبلة': u'مُؤَبَّلَةٌ', #1
u'مؤبلة': u'مُؤَبَّلَةٍ', #1
u'مؤبلة': u'مُؤَبَّلَةً', #6
u'مؤتة': u'مُؤْتة', #1
u'مؤتة': u'مُؤْتَةً', #1
u'مؤتة،': u'مُؤْتَة،', #1
u'مؤتة،': u'مُؤْتَةَ،', #11
u'مؤتة': u'مُؤْتَةَ', #124
u'مؤتة،': u'مُؤَتَةَ،', #2
u'مؤتة': u'مُؤْتَة', #3
u'مؤتة': u'مؤتة', #5
u'مؤتة': u'مُؤْتَةُ', #7
u'مؤتةحتى': u'مُؤْتَةَحَتّى', #1
u'مؤتةشهيدا': u'مُؤْتَةَشَهِيدًا', #1
u'مؤتجرا': u'مُؤْتَجِرًا', #13
u'مؤتدما': u'مُؤْتَدَمًا', #1
u'مؤتدما': u'مُؤْتَدِمًا', #5
u'موتر': u'مُوتِرٌ', #1
u'موترا': u'مُوتِرًا', #1
u'موترة': u'مُوتِرَةٌ', #1
u'موترة': u'مُوتِرَةً', #5
u'مؤتس': u'مُؤْتَسٍ', #1
u'مؤتس': u'مُؤْتَسِ', #1
u'مؤتسيا': u'مُؤْتَسِيًا', #1
u'مؤتشب': u'مُؤْتَشَبْ', #1
u'مؤتشب': u'مُؤْتَشِبِ', #2
u'مؤتصل': u'مُؤتَصِلٌ', #1
u'مؤتصل': u'مُؤْتَصِلٌ', #1
u'موتصلا': u'مُوتَصِلاً', #2
u'موتصلتان': u'مُوتَصِلَتَانِ', #1
u'مؤتفق': u'مُؤْتَفِقٌ', #1
u'مؤتفقان': u'مُؤْتَفِقَانِ', #1
u'مؤتفكة': u'مُؤْتَفِكَةِ', #1
u'مؤتل': u'مُؤْتَلِ', #2
u'مؤتما': u'مُؤْتَمًّا', #60
u'مؤتمة': u'مُؤْتِمَةٌ', #2
u'مؤتمة،': u'مُؤْتِمَةٌ،', #3
u'مؤتمة': u'مُؤْتَمَّةٌ', #9
u'مؤتمه': u'مُؤْتَمُّهُ', #11
u'مؤتمون': u'مُؤْتَمُّونَ', #2
u'مؤتمين': u'مُؤْتَمِّينَ', #9
u'مؤتنف': u'مُؤَتَنَفٌ', #1
u'مؤتنف': u'مُؤْتَنَف', #1
u'مؤتنف': u'مُؤْتَنَفْ', #1
u'مؤتنف': u'مُؤْتَنِفِ', #1
u'مؤتنف؟': u'مُؤْتَنِفٍ؟', #1
u'مؤتنف': u'مُؤْتَنِفٍ', #2
u'مؤتنف': u'مُؤْتَنَفٌ', #34
u'مؤتنف': u'مُؤْتَنِفٌ', #7
u'مؤتنف': u'مُؤْتَنَفٍ', #9
u'مؤتنفا': u'مُؤْتَنَفًا', #19
u'مؤتنفة': u'مُؤْتَنَفَةٍ', #1
u'مؤتنفة': u'مُؤْتَنَفَةٌ', #2
u'مؤتنفين': u'مُؤْتَنَفَيْنِ', #1
u'مؤته': u'مؤته', #1
u'موتورون': u'مَوْتُورُونَ', #3
u'موثبان': u'مَوْثَبَانُ', #1
u'موثرا': u'مُوَثِّرًا', #1
u'موثرة': u'مِوْثَرَةٌ', #2
u'مؤثل': u'مُؤَثّلِ', #2
u'مؤثم': u'مُؤْثَمٌ', #1
u'مؤثم': u'مُؤْثِمٌ', #1
u'مؤثم': u'مُؤْثِمٍ', #1
u'مؤثم': u'مُؤَثِّمٌ', #2
u'مؤثم': u'مُؤَثِّمٍ', #4
u'مؤثما': u'مُؤَثِّمًا', #1
u'مؤثما': u'مُؤْثِمًا', #1
u'مؤثمة': u'مُؤَثِّمَةٌ', #1
u'موثوءة': u'مَوْثُوءَة', #1
u'موثورة': u'مَوْثُورَةٌ', #1
u'موثوقون': u'مَوْثُوقُونَ', #2
u'موجأين': u'مُوجَأَيْنِ', #1
u'موجبية': u'مُوجِبِيَّةَ', #1
u'موجبية': u'مُوجِبِيَّةِ', #1
u'موجبيته': u'مُوجِبِيَّتُهُ', #1
u'موجبيتها': u'مُوجِبِيَّتِهَا', #1
u'موجحا': u'مُوجَحَا', #2
u'موجدا': u'مُوجَدًا', #1
u'موجدا': u'مُوجِدًا', #8
u'موجده': u'مُوجِدِهِ', #2
u'موجدها': u'مُوجِدُهَا', #1
u'موجدها': u'مُوجِدِهَا', #1
u'موجر': u'مُوجِرٍ', #1
u'موجرا': u'مُوجِرَا', #1
u'موجرا': u'مُوجَرًا', #2
u'موجفين': u'مُوجِفِينَ', #2
u'موجل': u'مَوْجِلٌ', #1
u'موجلا': u'مَوْجَلًا', #1
u'موجنة': u'مُوجَنَةٌ', #1
u'موجوء': u'مَوْجُوءٌ', #1
u'موجوء': u'مَوْجُوءَ', #1
u'موجوء': u'مَوْجُوء', #2
u'موجوءا': u'مَوْجُوءًا', #7
u'موجوءة': u'مَوْجُوءَةٍ', #1
u'موجوءين': u'مَوْجُوءَيْنِ', #24
u'موجوأين': u'مَوْجُوأَيْنِ', #6
u'موجوم': u'مَوْجُومٌ', #1
u'موجوئين': u'مَوْجُوئَيْنِ', #1
u'موجئا': u'مُوجِئًا', #1
u'موحامد': u'مُوحَامَدُ', #4
u'موحوين': u'مَوْحُوَيْنِ', #1
u'مؤخذا': u'مُؤْخَذًا', #1
u'موخرا': u'مُوخِرًا', #1
u'مودش': u'مودش', #1
u'مودن': u'مُودَن', #1
u'مودن': u'مُودَنٍ', #1
u'مودن': u'مُودَنَ', #1
u'مودن': u'مُودَنُ', #15
u'مودود': u'مَوْدُودٍ', #18
u'مودود،': u'مَوْدُودٍ،', #3
u'مودى': u'مُودَى', #1
u'موراث': u'مِوْرَاثٌ', #1
u'مؤربا': u'مُؤْرَبًا', #1
u'موربا': u'مُوَرِّبًا', #2
u'مؤرج،': u'مُؤَرِّجٍ،', #1
u'مورسة': u'مُوَرّسَةٍ', #1
u'مورسة': u'مُوَرَّسَةً', #1
u'مورسة،': u'مُوَرَّسَةٍ،', #1
u'مورع،': u'مُوَرِّعٍ،', #1
u'مورع': u'مُوَرِّعٍ', #2
u'موركا': u'مُوَرِّكًا', #2
u'مورود': u'مَوْرُودٌ', #2
u'مورود': u'مَوْرُودِ', #2
u'مورودا': u'مَوْرُودًا', #5
u'مورودة': u'مَوْرُودَةً', #1
u'مورودة': u'مَوْرُودَةٌ', #1
u'مورى': u'مُورًى', #1
u'موريا': u'مُورِيًا', #1
u'موريا': u'مُوَرِّيًا', #1
u'موزان': u'مِوْزَانٌ', #1
u'موزاين': u'مَوَزِاينُ', #1
u'مؤزر': u'مُؤَزّرَ', #1
u'مؤزر': u'مُؤْزَرَ', #1
u'مؤزرا': u'مُؤَزِّرًا', #1
u'مؤزرا،': u'مُؤَزَّرًا،', #1
u'مؤزرا': u'مُؤَزَّرًا', #14
u'مؤزرا': u'مُؤَزّرًا', #2
u'موزل': u'موزل', #1
u'موزموندان': u'موزموندان', #1
u'موزور': u'مَوْزُورٌ', #2
u'موزورات': u'مَوْزُورَات', #1
u'موزورات': u'مَوْزُورَاتٍ', #3
u'موزورة': u'مَوْزُورَةً', #1
u'موسد': u'مُوَسَّدٍ', #1
u'موسد': u'مُوَسّدٍ', #2
u'موسدا': u'مُوَسَّداً', #1
u'موسدا': u'مُوَسَّدًا', #1
u'مؤسرة': u'مُؤْسِرَةٌ', #1
u'موسق،': u'مُوسَقٍ،', #1
u'موسقة': u'مُوسَقَةً', #1
u'موسقة': u'مُوسَقَةٌ', #1
u'موسمة': u'مُوَسّمَةٌ', #1
u'موسمة': u'مُوَسّمَةُ', #6
u'موسوق': u'مَوْسُوقٌ', #1
u'موسوقة': u'مَوْسُوقَةٍ', #1
u'موسىادنه،': u'مُوسَىادْنُهْ،', #1
u'موسىأنه': u'مُوسَىأَنَّهُ', #1
u'موسىقوله': u'مُوسَىقَولُهُ', #1
u'موسىمولى': u'مُوسَىمَوْلَى', #1
u'مؤصدة': u'مُؤْصَدَةٌ', #4
u'موصف': u'مُوصَفٌ', #1
u'موصوليتها': u'مَوْصُولِيَّتَهَا', #1
u'موضإ': u'مُوَضَّإٍ', #1
u'موضع': u'مَوْضِعً', #2
u'موضعالدعاء': u'مَوْضِعِالدُّعَاءِ', #1
u'موضعتوضع': u'مَوْضِعٍتُوضَعُ', #1
u'موضعى': u'مَوْضِعِى', #1
u'موضونة': u'مَوْضُونَةٍ', #2
u'موضئ': u'مُوَضِّئٌ', #2
u'موضئ': u'مُوَضِّئٍ', #2
u'موضئا': u'مُوَضِّئًا', #2
u'موطوء': u'مَوْطُوءٌ', #1
u'موطوءا': u'مَوْطُوءًا', #9
u'موطوءات': u'مَوْطُوءَاتِ', #1
u'موطوءات': u'مَوْطُوءَاتٍ', #3
u'موطوءات': u'مَوْطُوءَاتُ', #7
u'موطوءة': u'مَوْطُوءَةً', #131
u'موطوءة': u'مَوْطُوءَةٍ', #177
u'موطوءة': u'مَوْطُوءَةِ', #19
u'موطوءة': u'مَوْطُوءَةٌ', #49
u'موطوءة': u'مَوْطُوءَةُ', #51
u'موطوءة': u'مَوْطُوءَةَ', #65
u'موطوءتك': u'مَوْطُوءَتَك', #2
u'موطوءتك': u'مَوْطُوءَتِك', #2
u'موطوءته': u'مَوْطُوءَته', #1
u'موطوءته': u'مَوْطُوءَتَهُ', #23
u'موطوءته': u'مَوْطُوءَتُهُ', #28
u'موطوءته': u'مَوْطُوءَتِهِ', #87
u'موطوءتهما': u'مَوْطُوءَتِهِمَا', #2
u'موطوءتي': u'مَوْطُوءَتِي', #1
u'موطوآت': u'مَوْطُوآتٌ', #1
u'موطوآت': u'مَوْطُوآتِ', #1
u'موطوآت': u'مَوْطُوآت', #2
u'موطوآت': u'مَوْطُوآتٍ', #4
u'موطوآت': u'مَوْطُوآتُ', #6
u'موطوآته': u'مَوْطُوآته', #2
u'موطوآته': u'مَوْطُوآتِهِ', #2
u'موطوئه': u'مَوْطُوئِهِ', #1
u'موظبة': u'مُوَظَّبَةٌ', #1
u'موعبة': u'مُوعِبَةً', #1
u'موعبة': u'مُوعِبَةٍ', #3
u'موعى': u'مُوعًى', #9
u'موغر': u'مُوغِرٌ', #5
u'موغرين': u'مُوغِرِينَ', #10
u'مؤف': u'مُؤَفِّ', #1
u'مؤفة': u'مُؤَفَّةً', #1
u'موفى': u'مُوَفَّى', #1
u'موفى': u'مُوَفِّى', #1
u'موفى': u'مُوَفًّى', #6
u'موقات': u'مُوقَاتُ', #1
u'موقات': u'مِوْقَاتٌ', #3
u'موقود': u'مَوْقُودٍ', #1
u'موقودا': u'مَوْقُودًا', #2
u'موقودة': u'مَوْقُودَةً', #7
u'موقوذ': u'مَوْقُوذ', #1
u'موقوذا': u'مَوْقُوذًا', #2
u'موقوذة': u'مَوْقُوذَةً', #2
u'موقوذة': u'مَوْقُوذَةَ', #2
u'موقوذة': u'مَوْقُوذَةِ', #3
u'موقوذة': u'مَوْقُوذَةٌ', #5
u'موقورة': u'مَوْقُورَةٍ', #6
u'موقوص': u'مَوْقُوص', #1
u'موقوفية': u'موقوفية', #1
u'موقوفية': u'مَوْقُوفِيَّةَ', #1
u'موقوقا': u'مُوَقْوِقًا', #1
u'موقوقة': u'مُوَقْوِقَةً', #1
u'موقى': u'مَوْقَى', #1
u'موكأ،': u'مُوكَأً،', #1
u'موكدا': u'مُوَكَّدًا', #1
u'موكدة': u'مُوكَدَةً', #1
u'موكف': u'مُوكَفٍ', #6
u'موكفا': u'مُوَكَّفًا', #1
u'موكفا': u'مُوكَفًا', #8
u'موكفه': u'مُوكَفَهْ', #1
u'موكوء': u'مَوْكُوءٍ', #2
u'موكوف،': u'مَوْكُوفٍ،', #1
u'موكولان': u'مَوْكُولَانِ', #1
u'موكولة': u'مَوْكُولَةً', #1
u'موكولة': u'مَوْكُولَةٍ', #1
u'موكولة': u'مَوْكُولَةُ', #1
u'موكولة': u'مَوْكُولَةٌ', #30
u'موكولون': u'مَوْكُولُونَ', #1
u'موكى': u'مُوكًى', #1
u'مؤل': u'مُؤْلٍ', #30
u'مولات': u'مَوْلَاتٍ', #1
u'مولاتى': u'مَوْلاَتِى', #3
u'مولاكاSالضحاك': u'مَوْلَاكَاSالضّحّاكُ', #1
u'مولاكا': u'مَوْلَاكَا', #1
u'مولاى': u'مَوْلاَى', #2
u'مولاى': u'مَوْلاَىَ', #9
u'مولائي': u'مَوْلَائِي', #1
u'مولايه': u'مَوْلَايَهْ', #1
u'مولة،': u'مَوَلَةَ،', #2
u'مولة': u'مَوَلَةَ', #6
u'مؤلك': u'مُؤْلَكٌ', #1
u'مولم': u'مُولِمٍ', #1
u'مولما': u'مُولِمًا', #1
u'مولود': u'مَوْلُودً', #1
u'مؤلى': u'مُؤْلِى', #1
u'مؤليا': u'مُؤْلِيًا', #16
u'موم': u'مُومٍ', #10
u'مؤمنوالوجه': u'مُؤْمِنٌوَالْوَجْهُ', #1
u'مومه': u'مُومِهِ', #1
u'مومى': u'مُومًى', #2
u'مومئ': u'مُومِئٌ', #3
u'مومئ': u'مُومِئٍ', #7
u'مومئا': u'مُومِئًا', #19
u'مومئة': u'مُومِئَةٍ', #1
u'مومئين': u'مُومِئِينَ', #1
u'موميا': u'مُومِيَا', #1
u'مؤميا': u'مُؤَمِّيًا', #3
u'موميا': u'مُومِيًا', #49
u'مؤنات': u'مُؤْنَاتُ', #1
u'مؤنات': u'مُؤْنَاتِ', #5
u'مؤناته': u'مُؤْنَاتِهِ', #9
u'مؤناتها': u'مُؤْنَاتُهَا', #1
u'مؤناتهم': u'مُؤْنَاتِهِمْ', #2
u'مؤنة': u'مَؤْنَةِ', #1
u'مؤنة،': u'مُؤْنَةٍ،', #1
u'مؤنة': u'مُؤْنَة', #11
u'مؤنة': u'مُؤْنَةً', #149
u'مؤنة': u'مُؤْنَةٍ', #221
u'مؤنة': u'مُؤْنَةٌ', #426
u'مؤنة': u'مُؤْنَةِ', #508
u'مؤنة': u'مُؤْنَةَ', #555
u'مؤنة': u'مُؤْنَةُ', #782
u'مؤنتك': u'مُؤْنَتُك', #1
u'مؤنتك': u'مُؤْنَتَك', #2
u'مؤنته': u'مُؤْنَتِهِ', #156
u'مؤنته': u'مُؤْنَتُهُ', #306
u'مؤنته': u'مُؤْنَته', #4
u'مؤنته': u'مُؤْنَتَهُ', #90
u'مؤنتها': u'مُؤْنَتهَا', #1
u'مؤنتها،': u'مَؤُنَتُهَا،', #1
u'مؤنتها': u'مُؤْنَتَهَا', #29
u'مؤنتها': u'مُؤْنَتِهَا', #42
u'مؤنتها': u'مُؤْنَتُهَا', #57
u'مؤنتهم': u'مُؤْنَتهمْ', #1
u'مؤنتهم': u'مَؤُنَتَهُمْ', #1
u'مؤنتهم': u'مُؤْنَتَهُمْ', #14
u'مؤنتهم': u'مُؤْنَتِهِمْ', #27
u'مؤنتهم': u'مُؤْنَتُهُمْ', #48
u'مؤنتهما': u'مُؤْنَتُهُمَا', #18
u'مؤنتهما': u'مُؤْنَتِهِمَا', #7
u'مؤنتهن': u'مُؤْنَتُهُنَّ', #1
u'مؤنتي': u'مُؤْنَتِي', #2
u'مونق': u'مُونِقٍ', #2
u'مونقا': u'مُوَنَّقًا', #1
u'موهب،': u'موهب،', #1
u'موهب،': u'موْهب،', #1
u'موهب': u'مُوهَبٍ', #1
u'موهب': u'مُوهِبٍ', #1
u'موهب': u'مَوْهِب', #1
u'موهب': u'مَوْهِبِ', #1
u'موهب': u'مَوْهَبٍ', #126
u'موهب': u'مَوْهَبٌ', #2
u'موهب': u'مَوْهِبٌ', #2
u'موهب': u'مَوْهِبُ', #2
u'موهب،': u'مَوْهَبٌ،', #2
u'موهب': u'مَوْهِبٍ', #4
u'موهب،': u'مَوْهِبٍ،', #6
u'موهب': u'مَوْهَبُ', #7
u'موهب،': u'مَوْهَبٍ،', #81
u'موهبا': u'مُوهِبًا', #1
u'مؤوي': u'مُؤْوِيَ', #4
u'مؤويا': u'مُؤْوِيًا', #1
u'موى': u'موى', #2
u'موئل': u'مَوْئِلٌ', #1
u'موئلا': u'مَوْئِلا', #4
u'مؤيديا': u'مُؤَيَّدِيًّا', #1
u'مؤيدية': u'مُؤَيَّدِيَّةً', #1
u'مؤيدية': u'مُؤَيِّدِيَّةٌ', #2
u'مؤيسا': u'مُؤَيِّسًا', #1
u'مؤيسة': u'مُؤَيِّسَةٌ', #1
u'مويه': u'مُوَيْهٌ', #1
u'مويه': u'مُوَيْهٍ', #1
u'مويهبة': u'مويهبة', #1
u'مويهبة،': u'مُوَيْهِبَةَ،', #1
u'مويهبة': u'مُوَيْهِبَةَ', #23
u'مي': u'مَيْ', #1
u'مي': u'مي', #1644
u'مي': u'مِي', #2
u'مى': u'مى', #23
u'مي': u'مَيّ', #3
u'مئتثر': u'مُئْتَثِرُ', #1
u'مئتزرا': u'مُئْتَزِرًا', #1
u'مئتزرات': u'مُئْتَزِرَاتٍ', #1
u'مئثر': u'مِئْثَرٍ', #1
u'مئزاب': u'مِئْزَابٍ', #2
u'مئلاة': u'مِئْلَاةً', #1
u'مئلاة': u'مِئْلَاةٌ', #1
u'مئلات': u'مِئْلَاتٍ', #1
u'مئلاثا': u'مِئْلَاثًا', #1
u'مئنة': u'مَئِنَّةٌ', #13
u'مئنة': u'مَئِنَّةُ', #2
u'مئوفا': u'مَئُوفًا', #2
u'مئونة،': u'مَئُونَةً،', #1
u'مئونة': u'مَئُونَةِ', #17
u'مئونة': u'مَئُونَةَ', #22
u'مئونة': u'مَئُونَةُ', #27
u'مئونة': u'مَئُونَةً', #3
u'مئونة': u'مَئُونَةٌ', #4
u'مئونة': u'مَئُونَة', #6
u'مئونة': u'مَئُونَةٍ', #8
u'مئونتك': u'مَئُونَتَك', #1
u'مئونته': u'مَئُونَتَهُ', #5
u'مئونته': u'مَئُونَتُهُ', #5
u'مئونته': u'مَئُونَتِهِ', #7
u'مئونتها': u'مَئُونَتِهَا', #2
u'مئونتها': u'مَئُونَتَهَا', #5
u'مئونتهم': u'مَئُونَتَهُمْ', #1
u'مئونتهم': u'مَئُونَتُهُمْ', #1
u'مئونتهم،': u'مَئُونَتَهُمْ،', #1
u'مئونتهما': u'مَئُونَتَهُمَا', #1
u'مئوى': u'مُئْوِىَ', #1
u'مئى': u'مِئًى', #5
u'مئيا': u'مِئْيًا', #1
u'مئية': u'مِئْيَةٍ', #3
u'مئينا': u'مِئِينَا', #3
u'ميا': u'مَيًّا', #1
u'مياثر': u'مَيَاثِرَ', #1
u'مياثر': u'مَيَاثِر', #3
u'مياثر': u'مَيَاثِرُ', #4
u'مياثر': u'مَيَاثِرِ', #5
u'ميارة': u'ميارة', #1
u'ميارة': u'مَيَّارَةٍ', #1
u'ميارة': u'مَيَّارَةَ', #16
u'ميارة': u'مَيَّارَةُ', #30
u'ميازار': u'ميازار', #1
u'ميازر': u'ميازر', #1
u'ميافارقين': u'ميافارقين', #1
u'ميان': u'مَيَّان', #4
u'ميان': u'ميان', #8
u'ميانه': u'ميانه', #1
u'مياه': u'مِيَاهً', #2
u'ميبا': u'ميبا', #2
u'ميباشم': u'ميباشم', #1
u'ميبايد': u'ميبايد', #2
u'ميبسة': u'مُيَبَّسَةٌ', #1
u'مية': u'مَيّةَ', #2
u'مية': u'مَيَّةُ', #2
u'مية': u'مَيَّةَ', #7
u'ميتاء': u'مِيتَاءَ', #1
u'ميتاء': u'مِيتَاءٌ', #3
u'ميتاء': u'مِيتَاءٍ', #3
u'ميتةقوله': u'مَيْتَةٌقَولُهُ', #1
u'ميتتى': u'مِيتَتِى', #1
u'ميته': u'مَيْتَهً', #1
u'ميث': u'مَيْثٌ', #1
u'ميثاء': u'مَيْثَاءَ', #1
u'ميثاقاوروي': u'مِيثَاقًاوَرُوِيَ', #1
u'ميثرة': u'مِيثَرَةً', #1
u'ميثرة': u'مِيثَرَةَ', #1
u'ميثرة': u'مِيْثَرَةٍ', #1
u'ميثرة': u'مِيْثَرَةِ', #1
u'ميثرة': u'مِيثَرَةُ', #10
u'ميثرة': u'مِيثَرَةٍ', #2
u'ميثرة': u'مِيثَرَةِ', #2
u'ميثرة': u'مِيثَرَة', #3
u'ميثم': u'مِيثَمٍ', #1
u'ميثم': u'ميثم', #2
u'ميخ': u'ميخ', #1
u'ميخوا': u'ميخوا', #1
u'ميخوانند': u'ميخوانند', #1
u'ميخواهم': u'ميخواهم', #1
u'ميخورم': u'ميخورم', #8
u'ميدارجون': u'ميدارجون', #1
u'ميدارد': u'ميدارد', #1
u'ميدارم': u'ميدارم', #1
u'ميداري': u'ميداري', #1
u'ميداند': u'ميداند', #1
u'ميدعة': u'مَيْدَعَةَ', #1
u'ميدهي': u'ميدهي', #1
u'ميدهيم': u'ميدهيم', #4
u'ميراثى': u'مِيرَاثِى', #3
u'ميرباد': u'ميرباد', #1
u'ميرة': u'مِيرَةٌ', #1
u'ميرة': u'مِيرَةَ', #2
u'ميرة': u'مِيرَةً', #3
u'ميرة': u'مِيرَةٍ', #4
u'ميرتنا': u'مِيرَتَنَا', #2
u'ميرتهم': u'مِيرَتَهُمْ', #1
u'ميرغني': u'مِيرْغَنِيّ', #1
u'ميرغني': u'مِيرْغَنِيٌّ', #2
u'ميرغني': u'مِيرْغَنِيٍّ', #3
u'ميرفت': u'ميرفت', #1
u'ميرك': u'ميرك', #1
u'ميرك': u'مَيْرَكٍ', #1
u'ميروم': u'ميروم', #2
u'ميروندوا': u'ميروندوا', #1
u'ميري': u'مِيرِي', #1
u'ميرى': u'ميرى', #1
u'ميرية': u'مِيرِيَّةٌ', #1
u'ميرية': u'مِيرِيَّةٍ', #7
u'ميريرنذ': u'ميريرنذ', #1
u'ميزابى': u'مِيزَابِى', #1
u'ميزباد': u'مِيزْبَادْ', #1
u'ميسرالوجه': u'مَيْسِرٌالْوَجْهُ', #1
u'ميسع': u'ميسع', #1
u'ميسون': u'مَيْسَونَ', #1
u'ميسون': u'مَيْسُونَ', #1
u'ميشو': u'ميشو', #1
u'ميشود': u'ميشود', #2
u'ميشومة': u'مَيْشُومَةٌ', #1
u'ميشوند': u'ميشوند', #1
u'ميشوندو': u'ميشوندو', #1
u'ميشوندواز': u'ميشوندواز', #1
u'ميشويم': u'ميشويم', #1
u'ميضأة،': u'مِيضَأَةٌ،', #1
u'ميضأة': u'مَيْضَأَةٌ', #1
u'ميضأة': u'مَيْضَأَةٍ', #1
u'ميضأة': u'مِيضَأَةً', #2
u'ميضأة': u'مِيضَأَةٌ', #2
u'ميضأة': u'مِيضَأَةٍ', #4
u'ميضأتك': u'مِيضَأَتَكَ', #1
u'ميضاتك': u'مِيضَاتَكَ', #1
u'ميضأته': u'مِيضَأَتِهِ', #1
u'ميفر': u'ميفر', #1
u'ميفرشى': u'ميفرشى', #1
u'ميفروشم': u'ميفروشم', #2
u'ميفعة': u'مَيْفَعَةَ', #1
u'ميقاتا': u'مِيقَاتًا', #153
u'ميقدة': u'مِيقَدَةٍ', #1
u'ميقدة': u'مِيقَدَةٌ', #2
u'ميكال': u'مِيكَالٍ', #1
u'ميكال': u'مِيكَالَ', #3
u'ميكال': u'مِيكَالُ', #5
u'ميكائيل': u'ميكائيل', #1
u'ميكائيل،': u'ميكائيل،', #1
u'ميكائيل': u'مِيَكَائِيلُ', #1
u'ميكائيل،': u'مِيكَائِيلُ،', #2
u'ميكائيل،': u'مِيكَائِيلَ،', #3
u'ميكائيل': u'مِيكَائِيلَ', #36
u'ميكائيل': u'مِيكَائِيلُ', #36
u'ميكر': u'ميكر', #1
u'ميكرد': u'ميكرد', #2
u'ميكرددا': u'ميكرددا', #1
u'ميكردوخداونددو': u'ميكردوخداونددو', #1
u'ميكردى': u'ميكردى', #1
u'ميكند': u'ميكند', #10
u'ميكنداين': u'ميكنداين', #1
u'ميكندباين': u'ميكندباين', #1
u'ميكندكه': u'ميكندكه', #1
u'ميكنم': u'ميكنم', #5
u'ميكنند': u'ميكنند', #9
u'ميكنى': u'ميكنى', #2
u'ميكني': u'ميكني', #3
u'ميكو': u'ميكو', #2
u'ميكوئى': u'ميكوئى', #2
u'ميكويد': u'ميكويد', #2
u'ميكويند': u'ميكويند', #3
u'ميكوييم': u'ميكوييم', #1
u'ميلادكا': u'مِيلَادِكَا', #5
u'ميلة': u'ميلة', #1
u'ميلة،': u'ميلة،', #1
u'ميلة': u'مَّيْلَةً', #1
u'ميلة،': u'مَيْلَةً،', #1
u'ميلة': u'مَيْلَةً', #13
u'ميلغة': u'مَيْلَغَةِ', #1
u'ميلغة': u'مِيلَغَةِ', #2
u'ميلغة': u'مِيلَغَةَ', #6
u'ميلقه': u'مَيْلَقِهِ', #1
u'ميلنم': u'ميلنم', #1
u'ميمات': u'مِيمَاتٍ', #5
u'مين': u'مين', #1
u'مين': u'مِينَ', #1
u'مين': u'مَيْنٍ', #2
u'مين': u'مَيْنِ', #6
u'مينا،': u'مينا،', #1
u'مينا،': u'مِينَا،', #11
u'مينا': u'مِينَا', #29
u'ميناس': u'مِينَاسٍ', #1
u'ميناس،': u'مِينَاسَ،', #1
u'مينة': u'مِينَةَ', #1
u'ميورقة،': u'مَيُورْقَةَ،', #1
u'ميولات': u'مُيُولَاتِ', #2
u'ميولاته': u'مُيُولَاتِهِ', #2
u'ميولاتها': u'مُيُولَاتِهَا', #2
u'ميولاتي': u'مُيُولَاتِي', #1
u'ميون': u'مُيُونُ', #1
u'ميوه': u'ميوه', #1
u'ميئوس': u'مَيْئُوسٍ', #10
u'ميئوس': u'مَيْئُوسٌ', #6
u'ميئوسا': u'مَيْئُوسًا', #20
u'ميئوسة': u'مَيْئُوسَةٌ', #1
u'نا': u'نًا', #1
u'نا': u'نِا', #1
u'نا': u'نَا', #1439
u'نا': u'نُا', #2
u'نا': u'ِنَّا', #2
u'نا': u'نا', #249
u'ناءون': u'نَاءُونَ', #1
u'ناأميدم': u'ناأميدم', #1
u'ناباشيده': u'ناباشيده', #1
u'نأبد': u'نَأْبُدُ', #1
u'نابزه': u'نابزه', #1
u'نأبنه': u'نَأْبِنُهُ', #4
u'نابئ': u'نَابِئِ', #1
u'نات': u'نَاتِ', #1
u'نات': u'نَاتٍ', #3
u'ناترابحل': u'ناترابحل', #1
u'ناتق': u'نَاتِق', #1
u'ناتق': u'نَاتِقٌ', #3
u'ناتل': u'نَاتِلُ', #2
u'ناتل': u'نَاتِلٌ', #3
u'نأتمه': u'نَأْتَمُّهُ', #1
u'نأتنفه': u'نَأْتَنِفُهُ', #1
u'ناتي': u'نَاتِّي', #1
u'نأتى': u'نَأْتِى', #15
u'نأتى': u'نَأْتِىَ', #9
u'ناجش': u'نَاجِشٌ', #5
u'ناجشا': u'نَاجِشًا', #4
u'ناحفاظي': u'ناحفاظي', #1
u'نآحها': u'نَآحَهَا', #1
u'ناحور،': u'نَاحُورَ،', #1
u'ناحور': u'ناحورَ', #2
u'ناحور': u'نَاحُورُ', #2
u'ناحور': u'نَاحُورِ', #3
u'ناحور': u'نَاحُورٍ', #4
u'ناحور': u'نَاحُورَ', #9
u'ناحيتى': u'نَاحِيَتَىْ', #1
u'ناخنه': u'ناخنه', #2
u'نادا': u'نَادًّا', #8
u'ناداشته': u'ناداشته', #1
u'نادانى': u'نَادَانِى', #5
u'نادة': u'نَادَّةً', #2
u'نار': u'نَارً', #1
u'ناراالوجه': u'نَارًاالْوَجْهُ', #1
u'ناراقوله': u'نَارًاقَوْلُهُ', #1
u'نارنج': u'نَارِنْجٍ', #1
u'نارنجا': u'نَارِنْجًا', #1
u'نأرنجيلة': u'نَأْرَنْجِيلَةٌ', #1
u'ناروسا': u'نَارُوسًا', #1
u'نارى': u'نَارِى', #3
u'نازعنيها': u'نَازَعَنِيهَا', #3
u'نازنج': u'نازنج', #1
u'ناشم،': u'ناشم،', #1
u'ناشيء': u'نَاشِيءٌ', #1
u'ناصبيا': u'نَاصِبِيًّا', #2
u'ناصرى': u'نَاصِرِى', #1
u'ناصور': u'نَاصُورٌ', #1
u'ناصولا': u'نَاصُولًا', #1
u'ناصيت': u'نَاصَيْتَ', #2
u'ناصيتى': u'نَاصِيَتِى', #1
u'ناضا': u'نَاضًّا', #68
u'ناضة': u'نَاضَّةٍ', #1
u'ناضة': u'نَاضَّةٌ', #2
u'ناضة': u'نَاضَّةً', #5
u'ناضحى': u'نَاضِحِى', #1
u'ناضه': u'نَاضِّهِ', #4
u'ناضهم': u'نَاضِّهِمْ', #4
u'ناطق': u'نَاطِقً', #2
u'ناطه': u'نَاطَهُ', #1
u'ناظرنى': u'نَاظَرَنِى', #1
u'ناعور': u'نَاعُورٍ', #1
u'ناعوس': u'نَاعُوسَ', #2
u'ناغض': u'نَاغِضِ', #2
u'نافج': u'نَافِجٌ', #1
u'نافجة': u'نَافِجَةً', #2
u'نافجة': u'نَافِجَةٍ', #2
u'نافجة': u'نَافِجَةِ', #3
u'نافجة': u'نَافِجَةُ', #4
u'نافجة': u'نَافِجَةَ', #9
u'نافجته': u'نَافِجَتِهِ', #1
u'نافجته': u'نَافِجَتُهُ', #2
u'نافخت': u'نَافَخْتَ', #1
u'نافصا': u'نَافِصًا', #1
u'نافععن': u'نَافِعٍعَنْ', #1
u'نافعفي': u'نَافِعٍفِي', #1
u'نافلةولا': u'نَافِلَةٍوَلَا', #1
u'ناقتى': u'نَاقَتَى', #1
u'ناقتى': u'نَاقَتِى', #1
u'ناقتى؟': u'نَاقَتِى؟', #1
u'ناقتى': u'نَاقَتَىَّ', #2
u'ناقصني': u'نَاقَصَنِي', #1
u'ناقصوا': u'نَاقِصُوا', #1
u'ناقضية': u'نَاقِضِيَّةَ', #1
u'ناقضية': u'نَاقِضِيَّةِ', #1
u'نآك': u'نَآك', #1
u'ناكرت': u'نَاكَرَتْ', #1
u'ناكردني': u'ناكردني', #1
u'ناكرده': u'ناكرده', #1
u'ناكشية': u'نَاكِشِيَّةٌ', #1
u'ناكوارد': u'ناكوارد', #1
u'ناكور،': u'ناكور،', #1
u'ناكور': u'نَاكُورٌ', #2
u'ناكوفته': u'ناكوفته', #1
u'ناكير': u'نَاكِيرٌ', #1
u'نالندبية': u'نالندبية', #1
u'نامبرده': u'نامبرده', #1
u'نأمتك': u'نَأْمَتَك', #1
u'نامجامه': u'نامجامه', #1
u'نامهاي': u'نامهاي', #1
u'ناميست': u'ناميست', #1
u'نان': u'نان', #6
u'ناوءوه': u'نَاوَءُوهُ', #1
u'ناواه': u'نَاوَاهُ', #2
u'ناواهم': u'نَاوَاهُمْ', #1
u'ناوق': u'نَاوِقٍ', #2
u'ناوقا': u'ناوقا', #1
u'ناوقا': u'نَاوِقًا', #2
u'ناوقة': u'ناوقة', #1
u'ناوقها': u'نَاوِقِهَا', #1
u'ناولتكها': u'نَاوَلْتُكهَا', #2
u'ناولتنى': u'نَاوَلْتَنِى', #1
u'ناولتنيه': u'نَاوَلْتَنِيهِ', #1
u'ناولتنيها،': u'نَاوَلَتْنِيهَا،', #1
u'ناولنى': u'نَاوِلْنِى', #2
u'ناولنى': u'نَاوَلَنِى', #4
u'ناولنيه': u'نَاوَلَنِيهِ', #1
u'ناولنيه': u'نَاوِلْنِيهِ', #6
u'ناولنيها': u'نَاوِلْنِيهَا', #3
u'ناولونى': u'نَاوِلُونِى', #5
u'ناولونيه': u'نَاوِلُونِيهِ', #1
u'ناولونيه،': u'نَاوِلُونِيهِ،', #1
u'ناولينها': u'نَاوِلِينِهَا', #1
u'ناولينها،': u'نَاوِلِينِهَا،', #1
u'ناولينى': u'نَاوِلِينِى', #7
u'ناولينيه': u'نَاوِلِينِيهِ', #1
u'ناوه': u'ناوه', #1
u'ناووس': u'نَاوُوسُ', #1
u'ناووسا': u'نَاوُوسًا', #2
u'ناوى': u'ناوى', #1
u'ناوى': u'نَاوَى', #1
u'نائرة': u'نَائِرَةَ', #1
u'نائرة': u'نَائِرَةٍ', #11
u'نائرة': u'نَائِرَةٌ', #5
u'نائرة': u'نَائِرَةِ', #8
u'نائسا': u'نَائِسًا', #1
u'نائع': u'نَائِعٌ', #1
u'نايل': u'نَايِلٍ', #2
u'نباج': u'نُبَاجٍ', #1
u'نباج،': u'نُبَاجٍ،', #1
u'نباذا': u'نَبَّاذًا', #2
u'نباشد': u'نباشد', #4
u'نباشم': u'نباشم', #1
u'نباشى': u'نَبَّاشِى', #1
u'نباطي': u'نَبَاطِيٌّ', #2
u'نباعة': u'نَبَّاعَةٌ', #1
u'نبأنى': u'نَبَّأَنِى', #1
u'نباهله': u'نُبَاهِلُهُ', #1
u'نبايتكم': u'نُبَايِتُكُمْ', #2
u'نبايد': u'نبايد', #2
u'نبتدر': u'نَبْتَدِرُ', #3
u'نبتدرهما': u'نَبْتَدِرُهُمَا', #2
u'نبتديه': u'نَبْتَدِيهِ', #1
u'نبخله': u'نُبَخّلُهُ', #1
u'نبخله': u'نُبَخِّلُهُ', #1
u'نبدؤكم': u'نَبْدَؤُكُمْ', #9
u'نبدؤهم': u'نَبْدَؤُهُمْ', #3
u'نبذات': u'نُبْذَاتٍ', #1
u'نبرحا': u'نَبْرَحَا', #1
u'نبزترا': u'نبزترا', #1
u'نبزى': u'نُبْزَى', #7
u'نبشربه': u'نُبَشِّرُبِهِ', #1
u'نبطس،': u'نَبْطَسَ،', #1
u'نبطس': u'نَبْطَسَ', #3
u'نبطى': u'نَبَطِىٌّ', #3
u'نبعجهم': u'نَبْعَجَهُمْ', #1
u'نبعض': u'نُبَعِّضُ', #1
u'نبعضها': u'نُبَعِّضْهَا', #6
u'نبلوا': u'نَبّلُوا', #1
u'نبلوا': u'نَبِّلُوا', #1
u'نبهرة': u'نَبْهَرَةٌ', #1
u'نبهرجة': u'نَبَهْرَجَةٍ', #19
u'نبهرجة': u'نَبَهْرَجَةَ', #3
u'نبهرجة': u'نَبَهْرَجَةٌ', #61
u'نبهرجة': u'نَبَهْرَجَةً', #93
u'نبود': u'نبود', #4
u'نبودكه': u'نبودكه', #1
u'نبوده': u'نبوده', #3
u'نبودى': u'نبودى', #1
u'نبوذا': u'نبوذا', #1
u'نبؤس': u'نَبْؤُسُ', #1
u'نبوشم': u'نبوشم', #1
u'نبى': u'نَبِىُّ', #174
u'نبي': u'نَبِيًّ', #2
u'نبى؟': u'نَبِىٌّ؟', #2
u'نبى': u'نَبِىَّ', #292
u'نبى': u'نَبِىٌّ', #51
u'نبى': u'نَبِىٍّ', #53
u'نبى': u'نَبِىِّ', #72
u'نبيء': u'نبيء', #1
u'نبيء': u'نَبِيءٌ', #1
u'نبىء': u'نبىء', #2
u'نبىالله': u'نَبِىَاللَّهِ', #1
u'نبىالله': u'نَّبِىُّاللَّهِ', #1
u'نبيب': u'نَبيبَ', #1
u'نبيب': u'نَبِيبٌ', #12
u'نبيب': u'نَبِيبَ', #2
u'نبيب': u'نَبِيبُ', #2
u'نبيتة': u'نُبَيْتَةَ', #1
u'نبيثة': u'نَبِيثَةِ', #1
u'نبيذة': u'نَبِيذَة', #1
u'نبير': u'نُبِيرُ', #1
u'نبيرة،': u'نبيرَةَ،', #1
u'نبيشة': u'نبيشة', #1
u'نبيشة،': u'نُبَيَّشَةَ،', #1
u'نبيشة': u'نُبَيْشَةَ', #39
u'نبيشة': u'نُبَيْشَةُ', #9
u'نبيط': u'نُبَيْطٍ', #17
u'نبيط': u'نُبَيْطِ', #18
u'نبيط': u'نَبِيطٍ', #2
u'نبيط': u'نَبِيطِ', #3
u'نبيط': u'نُبَيْطُ', #3
u'نبيط': u'نبيط', #4
u'نبيط،': u'نُبَيْطٍ،', #8
u'نبيعكها': u'نَبِيعُكِهَا', #11
u'نبيقته': u'نَبِيقَتُهُ', #1
u'نتأخره': u'نَتَأَخَّرَهُ', #1
u'نتأذى': u'نَتَأَذَّى', #8
u'نتارككم': u'نُتَارِكُكُمْ', #2
u'نتباءس': u'نَتَبَاءَسُ', #1
u'نتباهل': u'نَتَبَاهَلَ', #2
u'نتبايعها': u'نَتَبَايَعُهَا', #1
u'نتجار': u'نَتَجَارّ', #1
u'نتجاعل': u'نَتَجَاعَلُ', #1
u'نتجب': u'نَتّجَبُ', #1
u'نتحارس': u'نَتَحَارَسُ', #3
u'نتحاشا': u'نَتَحَاشَا', #1
u'نتحرف': u'نَتَحَرَّف', #1
u'نترايا': u'نَتَرَايَا', #1
u'نترة': u'نَتْرَةُ', #1
u'نتزارع': u'نَتَزَارَعُ', #1
u'نتزوده،': u'نَتَزَوَّدُهُ،', #1
u'نتزوده': u'نَتَزَوَّدُهُ', #2
u'نتزودها': u'نَتَزَوَّدُهَا', #1
u'نتسحر': u'نَتَسَحَّر', #1
u'نتسحر': u'نَتَسَحَّرَ', #6
u'نتضحى': u'نتضحى', #1
u'نتضحى': u'نَتَضَحَّى', #6
u'نتعاقل': u'نَتَعَاقَلُ', #1
u'نتقا': u'نَتْقًا', #1
u'نتقابض': u'نَتَقَابَضَ', #4
u'نتقار': u'نَتَقَارُّ', #2
u'نتقاص': u'نَتَقَاصَّ', #7
u'نتقال': u'نْتِقَالٌ', #1
u'نتقنا': u'نَتَقْنَا', #8
u'نتلة': u'نَتْلَةٍ', #1
u'نتلوا': u'نَتْلُوا', #3
u'نتماشا': u'نَتَمَاشَا', #1
u'نتواضعاها': u'نَتَوَاضَعَاهَا', #1
u'نتواند': u'نتواند', #1
u'نتوجا': u'نَتُوجًا', #4
u'نتوقص': u'نَتَوَقَّصُ', #1
u'نتوكف': u'نَتَوَكّفُ', #2
u'نتوميكوبي': u'نتوميكوبي', #1
u'نتئر': u'نَتّئِرْ', #2
u'نتيلة': u'نتيلة', #1
u'نتيلة': u'نُتَيْلَةَ', #1
u'نتيلة': u'نُتَيْلَةُ', #3
u'نتيئة': u'نَتِيئَةَ', #1
u'نثقنهم': u'نَثْقِنَهُمْ', #1
u'نثهت': u'نَثِهَتْ', #1
u'نثى': u'نْثَى', #1
u'نثيل': u'نَثِيلٌ', #1
u'نجانى': u'نَجَّانِى', #4
u'نجبة': u'نَجَبَةُ', #1
u'نجبة،': u'نَجَبَةَ،', #5
u'نجبة': u'نَجَبَةَ', #8
u'نجتديكم': u'نَجْتَدِيكُمْ', #2
u'نجتزي': u'نَجْتَزِي', #1
u'نجتزئ': u'نجتزئ', #1
u'نجتزئ': u'نَجْتَزِئَ', #1
u'نجتزئ': u'نَجْتَزِئُ', #2
u'نجتمعا': u'نَجْتَمِعَا', #1
u'نجرانى': u'نَجْرَانِىٌّ', #1
u'نجرانى': u'نَجْرَانِىٍّ', #1
u'نجرانية': u'نَجْرَانِيَّةٌ', #1
u'نجرانية': u'نَجْرَانِيَّةِ', #2
u'نجرانية': u'نَجْرَانِيَّةٍ', #4
u'نجرة': u'نَجْرَةَ', #1
u'نجشا': u'نَجْشًا', #2
u'نجشت': u'نَجَشْتُ', #5
u'نجشه': u'نَجْشِهِ', #1
u'نجهان': u'نجهان', #2
u'نجىء': u'نَجِىءُ', #2
u'نجيج': u'نجيج', #1
u'نجيج': u'نَجِيجٍ', #1
u'نجيج،': u'نَجِيجٍ،', #1
u'نجيحا،': u'نَجِيحًا،', #1
u'نجيحا': u'نُجَيْحًا', #1
u'نجيحا': u'نَجِيحًا', #14
u'نجيحة': u'نَجِيحَةَ', #1
u'نجيحقوله': u'نَجِيحٍقَوْلُهُ', #1
u'نجيم': u'نَجِيمٍ', #12
u'نجيم': u'نُجَيْمٍ', #202
u'نجيئك': u'نَجِيئُكَ', #1
u'نحاصصك': u'نُحَاصِصُك', #1
u'نحاصصك': u'نُحَاصِصُكَ', #1
u'نحاقل': u'نُحَاقِلُ', #12
u'نحاقل': u'نُحَاقِلَ', #5
u'نحامل': u'نُحَامِلُ', #2
u'نحتاجه': u'نَحْتَاجُهُ', #1
u'نحتجرها': u'نَحْتَجِرُهَا', #1
u'نحثوا': u'نحثوا', #1
u'نحثي': u'نَحْثِيَ', #1
u'نحدثكموه': u'نُحَدِّثُكُمُوهُ', #1
u'نحطة': u'نَحْطَةٌ', #1
u'نحفد': u'نَحْفِدُ', #10
u'نحلنى': u'نَحَلَنِى', #6
u'نحلنيه': u'نَحَلَنِيهِ', #1
u'نحلنيه،': u'نَحَلَنِيهِ،', #1
u'نحلى': u'نِحْلًى', #1
u'نحمة': u'نَحْمَةَ', #1
u'نحمة': u'نِحْمَةً', #1
u'نحمة': u'نَحْمَةً', #3
u'نحوالجبل': u'نَحْوَالْجَبَلِ', #1
u'نحوب': u'نُحُوبٌ', #2
u'نحوسة': u'نُحُوسَةٌ', #2
u'نحوكا': u'نَحْوَكَا', #1
u'نحيبة': u'نَحِيبَةٌ', #1
u'نحيبة': u'نَحِيبَةٍ', #1
u'نحيبة': u'نُحَيْبَةُ', #1
u'نحيى': u'نَحْيَى', #1
u'نحيى': u'نُحْيِىَ', #1
u'نخاطرك': u'نُخَاطِرَك', #1
u'نخاورة': u'نَخَاوَرَةً', #1
u'نخاورة': u'نَخَاوَرَةٌ', #1
u'نخاورة': u'نَخَاوِرَةٌ', #2
u'نخة': u'نَخَّةِ', #1
u'نختبط': u'نختبط', #2
u'نختبط': u'نَخْتَبِطُ', #3
u'نختصي': u'نَخْتَصِي', #1
u'نختصي،': u'نَخْتَصِي،', #1
u'نختصي؟': u'نَخْتَصِي؟', #1
u'نختصى': u'نَخْتَصِىَ', #1
u'نخراء': u'نَخَرَاءَ', #1
u'نخسات': u'نَخَسَاتٍ', #4
u'نخلةخمس': u'نَخْلَةَخَمّسَ', #1
u'نخماس': u'نَخْماس', #1
u'نخماس': u'نَخْمَاس', #3
u'نخواهي': u'نخواهي', #1
u'نخورد': u'نخورد', #1
u'نخورم': u'نُخَوْرِم', #1
u'نخورم': u'نخورم', #5
u'نخوري': u'نخوري', #1
u'نخيزي': u'نخيزي', #1
u'نخيس': u'نُخَيّسُ', #1
u'نخيس': u'نُخَيْسٍ', #1
u'نخيضها': u'نُخِيضَهَا', #6
u'نخيلات': u'نُخَيْلَاتٌ', #1
u'نخيلة': u'نَخِيلَةَ', #1
u'نخيلة': u'نُخَيْلَةَ', #3
u'نداده': u'نداده', #1
u'ندارد': u'ندارد', #2
u'ندارم': u'ندارم', #2
u'ندارمي': u'ندارمي', #2
u'ندانست': u'ندانست', #1
u'ندانسته': u'ندانسته', #1
u'ندبيته': u'نَدْبِيَّتُهُ', #2
u'ندبيته': u'نَدْبِيَّتِهِ', #5
u'ندحت': u'نَدَحْت', #1
u'ندخداوند': u'ندخداوند', #1
u'ندرويت': u'ندرويت', #1
u'ندعوا': u'ندعوا', #1
u'ندغفقه،': u'نُدَغْفِقُهُ،', #1
u'ندغفقه': u'نُدَغْفِقُهُ', #2
u'ندكري': u'ندكري', #1
u'ندمني': u'نَدَّمَنِي', #1
u'ندمنى': u'نَدَّمَنِى', #1
u'ندنيز': u'ندنيز', #1
u'ندهد': u'ندهد', #2
u'ندهمين': u'ندهمين', #1
u'ندوشو': u'ندوشو', #1
u'نذار': u'نَذَارٍ', #1
u'نذيرى': u'نَذِيرِى', #1
u'نرا': u'نرا', #3
u'نرابتور': u'نرابتور', #1
u'نراكه': u'نراكه', #1
u'نرامجل': u'نرامجل', #1
u'نرانا': u'نَرَانَا', #1
u'نرانا': u'نُرَانَا', #1
u'نرانمي': u'نرانمي', #1
u'نراهنك': u'نُرَاهِنُك', #1
u'نراوضكم': u'نُرَاوِضَكُمْ', #2
u'نراوضهم': u'نُرَاوِضَهُمْ', #3
u'نرائي': u'نُرَائِي', #1
u'نرتجز': u'نَرْتَجِزُ', #1
u'نرتهنه': u'نَرْتَهِنْهُ', #1
u'نرجوا': u'نرجوا', #1
u'نرجوا': u'نَرْجُوا', #1
u'نردبان': u'نردبان', #1
u'نرددايكي': u'نرددايكي', #1
u'نردشير': u'نَرْدَشِيرَ', #2
u'نردشير': u'نَرْدَشِيرُ', #3
u'نرسانم': u'نرسانم', #1
u'نرسد': u'نرسد', #1
u'نرضىوالوجه': u'نَرْضَىوَالْوَجْهُ', #1
u'نرمقا': u'نُرْمُقًا', #1
u'نرنذبس': u'نرنذبس', #1
u'نريمها': u'نَرِيمُهَا', #3
u'نزارا': u'نِزَارًا', #1
u'نزاز': u'نِزَازٌ', #1
u'نزازة': u'نَزَّازَةً', #1
u'نزازة': u'نِزَازَةٌ', #1
u'نزازة': u'نِزَازَةَ', #1
u'نزائها': u'نِزَائِهَا', #1
u'نزدم': u'نزدم', #1
u'نزديك': u'نزديك', #4
u'نزديكتر': u'نزديكتر', #1
u'نزديكنز': u'نزديكنز', #1
u'نزعاء': u'نَزْعَاءُ', #1
u'نزكوه': u'نزكوه', #1
u'نزكوه': u'نَزَكُوهُ', #4
u'نزى': u'نَزَى', #1
u'نزى': u'نَزَّى', #3
u'نسأ': u'نَسَأً', #1
u'نساسيب': u'نَسَاسِيبُ', #1
u'نسامة': u'نَسَامَةٍ', #1
u'نسانى': u'نَسَّانِىَ', #1
u'نسآؤكم': u'نِسَآؤُكُمْ', #1
u'نساؤهمقال': u'نِسَاؤُهُمْقَالَ', #1
u'نسائكا': u'نِسَائِكَا', #7
u'نسآئكم': u'نِّسَآئِكُمُ', #1
u'نسآئكم': u'نِّسَآئِكُمْ', #1
u'نسآئكم': u'نِسَآئِكُمْ', #2
u'نسآئهم': u'نِّسَآئِهِمْ', #1
u'نسائههل': u'نِسَائِهِهَلْ', #1
u'نسائى': u'نِسَائِى', #10
u'نسب': u'نَسَبً', #1
u'نسباؤه': u'نُسَبَاؤُهُ', #2
u'نستأمن': u'نَسْتَأْمِنَ', #1
u'نستأمنه': u'نَسْتَأْمِنُهْ', #1
u'نستثبت': u'نَسْتَثْبِتَ', #1
u'نستجز': u'نَسْتَجِزْ', #1
u'نستحرم': u'نَسْتَحْرِمُ', #1
u'نستحى': u'نَسْتَحِى', #1
u'نستخصي؟': u'نستخصي؟', #1
u'نستخصى؟': u'نَسْتَخْصِى؟', #1
u'نستخصي؟': u'نَسْتَخْصِي؟', #2
u'نستخصى': u'نَسْتَخْصِى', #4
u'نستخصي': u'نَسْتَخْصِي', #9
u'نستخير': u'نَسْتَخِير', #1
u'نستخير': u'نَسْتَخِيرُ', #8
u'نسترقى': u'نَسْتَرْقِى', #1
u'نسترقي': u'نَسْتَرْقِيَ', #2
u'نسترقي': u'نَسْتَرْقِي', #6
u'نسترقيها': u'نَسْتَرْقِيهَا', #2
u'نستشفعهم': u'نَسْتَشْفِعُهُمْ', #1
u'نستشفى': u'نَسْتَشْفِى', #1
u'نستفدها': u'نَسْتَفِدْهَا', #1
u'نستفيده': u'نَسْتَفِيدُهُ', #1
u'نستقرض': u'نَسْتَقْرِضْ', #1
u'نستكفى': u'نَسْتَكْفِى', #1
u'نستمطر': u'نَسْتَمْطِرُ', #1
u'نستمطرها': u'نَسْتَمْطِرُهَا', #1
u'نستنجى': u'نَسْتَنْجِىَ', #8
u'نستوضعه': u'نَسْتَوْضِعُهُ', #2
u'نستوفز': u'نَسْتَوْفِزَ', #2
u'نستوفق': u'نَسْتَوْفِقُ', #1
u'نستئين': u'نَسْتَئِينُ', #1
u'نسجدها': u'نَسْجُدُهَا', #9
u'نسخان': u'نَسْخَانِ', #1
u'نسختى': u'نُسْخَتِى', #2
u'نسخم': u'نُسَخِّمُ', #1
u'نسطاس': u'نِسْطَاس', #1
u'نسطاس،': u'نِسْطَاسَ،', #1
u'نسطاس': u'نِسْطَاسٍ', #14
u'نسطاس،': u'نِسْطَاسٍ،', #3
u'نسطاس': u'نِسْطَاسٌ', #4
u'نسطاس': u'نِسْطَاسُ', #4
u'نسطورا': u'نَسْطُورًا', #1
u'نسطورا': u'نُسْطُورًا', #1
u'نسعة': u'نِسْعَة', #1
u'نسعة،': u'نِسْعَةٌ،', #1
u'نسعة': u'نِسْعَةٍ', #3
u'نسعة': u'نِسْعَةٌ', #5
u'نسعته،': u'نِسْعَتَهُ،', #3
u'نسعته': u'نِسْعَتَهُ', #9
u'نسكنى': u'نسكنى', #1
u'نسوتيا': u'نِسْوَتِيَا', #1
u'نسوؤك': u'نَسُوؤكَ', #1
u'نسيبة': u'نسيبة', #1
u'نسيبة': u'نَسِيبَةَ', #1
u'نسيبة،': u'نُسَيْبَةُ،', #1
u'نسيبة': u'نَسِيبَةً', #10
u'نسيبة': u'نُسَيْبَةُ', #16
u'نسيبة': u'نَسِيبَةٍ', #4
u'نسيبة': u'نَسِيبَةُ', #5
u'نسيبة': u'نُسَيْبَةَ', #7
u'نسيبة': u'نَسِيبَةٌ', #9
u'نسيتنى': u'نَسِيتَنِى', #2
u'نسيكتى': u'نَسِيكَتِى', #3
u'نسيئا': u'نَسِيئا', #1
u'نسيئا': u'نَسِيئًا', #3
u'نشادرا': u'نَشَادِرًا', #2
u'نشارعهم': u'نُشَارِعُهُمْ', #2
u'نشاطوروي': u'نِشَاطٍوَرُوِيَ', #1
u'نشامه': u'نُشَامُّهُ', #2
u'نشأوا': u'نَشَأُوا', #1
u'نشاواتها': u'نَشَاوَاتِهَا', #1
u'نشائح': u'نُشَائِحُ', #1
u'نشايح': u'نُشَايِحُ', #2
u'نشايد': u'نشايد', #3
u'نشايذ': u'نشايذ', #1
u'نشدتنى': u'نَشَدْتَنِى', #2
u'نشصت': u'نَشَصَتْ', #1
u'نشكوا': u'نَشْكُوا', #1
u'نشكيبم': u'نشكيبم', #1
u'نشوانا': u'نَشْوَانًا', #3
u'نشود': u'نشود', #4
u'نشودو': u'نشودو', #1
u'نشويند': u'نشويند', #1
u'نشيمها': u'نَشيِمُها', #1
u'نشيمها': u'نَشِيمُهَا', #2
u'نصالشيخ': u'نَصَّالشَّيْخُ', #1
u'نصبرقال': u'نَصْبِرَقَالَ', #1
u'نصرانة': u'نَصْرَانَةٌ', #1
u'نصرانى': u'نَصْرَانِىُّ', #1
u'نصرانى': u'نَصْرَانِىٌّ', #15
u'نصرانى': u'نَصْرَانِىٍّ', #4
u'نصرانين': u'نَصْرَانِيَّنِ', #1
u'نصرويه': u'نَصْرُوَيْهِ', #12
u'نصرويه': u'نَصْرَوَيْهِ', #6
u'نصرى': u'نَصْرَى', #7
u'نصطبح': u'نَصْطَبِحُ', #1
u'نصطلم': u'نُصْطَلَمُ', #1
u'نصفاء': u'نَصْفَاءَ', #1
u'نصيبة': u'نصيبة', #1
u'نصيبى': u'نَصِيبِى', #5
u'نضابه': u'نِضَابُهُ', #1
u'نضاجه': u'نِضَاجُهُ', #1
u'نضرةقال': u'نَضْرَةَقَالَ', #1
u'نضضه': u'نَضَّضَهُ', #1
u'نضلة،': u'نضلة،', #1
u'نضلة': u'نَضَلَةَ', #1
u'نضلة': u'نضلة', #11
u'نضلة': u'نَضْلَةَ', #129
u'نضلة': u'نَضْلَة', #2
u'نضلة': u'نَضْلَةُ', #4
u'نضلة،': u'نَضْلَةَ،', #7
u'نضوة': u'نِضْوَة', #1
u'نضوة': u'نِضْوَةُ', #1
u'نضوة': u'نِضْوَةً', #2
u'نضوة': u'نِضْوَةَ', #6
u'نضوده': u'نُضُودِهِ', #1
u'نضوض': u'نَضُوضُ', #1
u'نضوض': u'نَضُوضِ', #11
u'نضوض': u'نُضُوضٍ', #2
u'نضوض': u'نَضُوضَ', #3
u'نضوض': u'نَضُوضٍ', #5
u'نضوض': u'نُضُوضِ', #7
u'نضوضه': u'نُضُوضُهُ', #1
u'نضوضه': u'نَضُوضُهُ', #2
u'نضوضه': u'نَضُوضَهُ', #3
u'نضوضه': u'نَضُوضِهِ', #5
u'نضوضه': u'نُضُوضِهِ', #5
u'نضوضها': u'نَضُوضِهَا', #1
u'نضيج': u'نضيج', #1
u'نضيج': u'نَضِيجٌ', #1
u'نضيج': u'نَضِيجٍ', #1
u'نضيجا': u'نَضِيجًا', #12
u'نضيجة': u'نَضِيجَة', #1
u'نضيجة': u'نَضِيجَةٌ', #1
u'نضيلة': u'نُضَيْلَةَ', #17
u'نضيلة،': u'نُضَيْلَةَ،', #4
u'نطاة': u'نَطَاةٌ', #1
u'نطاة': u'نَطَاةَ', #2
u'نطاة': u'نَطَاةُ', #7
u'نطة': u'نَطَّةٍ', #2
u'نطرونا': u'نَطْرُونًا', #1
u'نطشان': u'نَطْشَانَ', #2
u'نطشان': u'نَطْشَانُ', #2
u'نطوحا': u'نطوحا', #1
u'نطوحا': u'نَطُوحًا', #4
u'نطؤكم': u'نَطَؤُكُمْ', #2
u'نطؤها': u'نَطَؤُهَا', #1
u'نطية': u'نَطِيَّةً', #1
u'نطيسا': u'نِطّيسًا', #1
u'نظر': u'نَظَرً', #1
u'نظرالى': u'نظرالى', #1
u'نظرانا': u'نُظْرَانًا', #1
u'نظرو': u'نظرو', #1
u'نظعنه': u'نَظَعْنَهُ', #1
u'نظير': u'نَظِيرً', #1
u'نعبدالله': u'نَعْبُدَاللَّهَ', #1
u'نعتقبه،': u'نَعْتَقِبُهُ،', #1
u'نعتقبه': u'نَعْتَقِبُهُ', #6
u'نعتمل': u'نَعْتَمِلُ', #1
u'نعتيته': u'نَعْتِيَّتُهُ', #1
u'نعثل': u'نَعْثَل', #1
u'نعثل': u'نَعْثَلُ', #1
u'نعثلا': u'نَعْثَلًا', #1
u'نعثلا،': u'نَعْثَلًا،', #1
u'نعدوا': u'نَعْدُوا', #1
u'نعضي': u'نَعْضِي', #1
u'نعطهيم': u'نُعطهيم', #2
u'نعطيكاهن': u'نُعْطِيكَاهُنَّ', #1
u'نعطيكه': u'نُعْطِيكَهُ', #3
u'نعطيكهن': u'نُعْطِيكَهُنَّ', #1
u'نعلمكموهن': u'نُعَلِّمُكُمُوهُنَّ', #1
u'نعمSمن': u'نَعَمْSمَنْ', #1
u'نعمتكوروي': u'نِعْمَتَكَوَرُوِيَ', #1
u'نعمتى': u'نِعْمَتِى', #7
u'نعمقالوا': u'نَعَمْقَالُوا', #1
u'نعمقوله': u'نَعَمْقَولُهُ', #1
u'نعموروي': u'نَعَمْوَرُوِيَ', #1
u'نعموروى': u'نَعَمْوَرَوَى', #1
u'نعوش': u'نُعُوشٍ', #1
u'نعولا': u'نُعَوِّلَا', #1
u'نعيلة': u'نُعَيْلَةَ', #3
u'نغاش': u'نُغَاشٍ', #1
u'نغاشي': u'نَغَاشِيٍّ', #1
u'نغاشيا': u'نُغَاشِيًّا', #2
u'نغانغ': u'نَغَانِغَ', #1
u'نغانغ': u'نَغَانِغُ', #1
u'نغاور': u'نُغَاوِرُ', #2
u'نغاورهم': u'نُغَاوِرهُمْ', #1
u'نغاورهم': u'نُغَاوِرُهُمْ', #1
u'نغتبق': u'نَغْتَبِقُ', #2
u'نغدوا': u'نَغْدُوا', #1
u'نغرة': u'نَغِرَةً', #1
u'نغضوا': u'نَغَضُوا', #1
u'نغفا': u'نَغَفًا', #3
u'نغفة': u'نَغَفَة', #1
u'نغنغ': u'نُغْنُغٌ', #1
u'نغنغ': u'نُغْنُغُ', #1
u'نفارة': u'نُفَارَةٍ', #1
u'نفاوت': u'نُفَاوِتَ', #2
u'نفائسا': u'نَفَائِسًا', #1
u'نفجة': u'نَفْجَةُ', #1
u'نفديكموها': u'نُفْدِيكُمُوهَا', #2
u'نفزتم': u'نَفَزْتُمْ', #1
u'نفسهSحول': u'نَفْسَهُSحَوْلَ', #1
u'نفسهالوجه': u'نَفْسَهُالْوَجْهُ', #1
u'نفصة': u'نُفْصَة', #1
u'نفصلفنبين': u'نُفَصِّلُفَنُبَيِّنُ', #1
u'نفضتين': u'نَفْضَتَيْنِ', #6
u'نفطويه': u'نِفْطَوَيْهِ', #8
u'نفعتين': u'نَفِعَتَيْنِ', #1
u'نفعنى': u'نَفَعَنِى', #3
u'نفعين': u'نَفْعَيْنِ', #1
u'نفقاتكمقوله': u'نَفَقَاتِكُمْقَوْلُهُ', #1
u'نفكهم': u'نَفُكُّهُمْ', #2
u'نفلتكها': u'نَفَّلْتُكهَا', #1
u'نفلنى': u'نَفِّلْنِى', #1
u'نفلنيه': u'نَفَلَنِيهِ', #1
u'نفلنيه': u'نَفّلْنِيهِ', #1
u'نفلنيه': u'نَفِّلْنِيهِ', #11
u'نفلنيه،': u'نَفِّلْنِيهِ،', #3
u'نفلنيه': u'نَفَّلَنِيهِ', #6
u'نفليته': u'نَفْلِيَّتُهُ', #1
u'نفليته': u'نَفْلِيَّتَهُ', #2
u'نفليته': u'نَفْلِيَّتِهِ', #3
u'نفهت': u'نفهت', #2
u'نفوسة': u'نَفُوسَةَ', #1
u'نفوع': u'نَفُوع', #1
u'نفوع': u'نَفُوعُ', #1
u'نفيطة': u'نَفِيطَةٌ', #1
u'نفيع': u'نَفِيعٍ', #1
u'نفيع': u'نُفَيع', #1
u'نفيع': u'نُفَيْعَ', #1
u'نفيع،': u'نُفَيْعٌ،', #1
u'نفيع': u'نُفَيْعٌ', #10
u'نفيع': u'نُفَيْعٍ', #12
u'نفيع،': u'نفيع،', #2
u'نفيع،': u'نُفَيْعٍ،', #2
u'نفيع': u'نفيع', #3
u'نفيع': u'نُفَيْع', #3
u'نفيع': u'نُفَيْعِ', #4
u'نفيع': u'نُفَيْعُ', #9
u'نفيعا': u'نُفَيْعًا', #11
u'نفيقة': u'نَفِيقَةً', #1
u'نفيقة': u'نُفَيْقَة', #1
u'نفيلا': u'نُفَيْلًا', #1
u'نفيلة': u'نُفَيْلَةُ', #2
u'نفيلة': u'نُفَيْلَةَ', #8
u'نقا': u'نَقًا', #1
u'نقاخ': u'نُقَاخٍ', #1
u'نقآد': u'نَقآدِ', #1
u'نقاية': u'نُقَايَةٌ', #1
u'نقاية': u'نُقَايَةُ', #1
u'نقدات': u'نَقْدَاتٍ', #1
u'نقدعهم': u'نَقْدَعْهُمْ', #1
u'نقرنى': u'نَقَرَنِى', #3
u'نقرؤه،': u'نَقْرَؤُهُ،', #1
u'نقرؤه': u'نَقْرَؤُهُ', #20
u'نقرؤها': u'نقرؤها', #3
u'نقرؤها': u'نَقْرَؤُهَا', #3
u'نقرئكه': u'نُقْرِئَكَهُ', #1
u'نقريسا': u'نِقْرِيسًا', #1
u'نقصوروي': u'نَقَصَوَرُوِيَ', #1
u'نقعل': u'نُقعلَ', #1
u'نقمتهوروي': u'نِقْمَتِهِوَرُوِيَ', #1
u'نقمهSمالك': u'نِقْمَهْSمَالِكُ', #1
u'نقمى': u'نَقَمَى', #2
u'نقمى': u'نَقْمَى', #9
u'نقولات': u'نُقُولَاتٍ', #1
u'نقولهقوله': u'نَقُولُهُقَوْلُهُ', #1
u'نقى': u'نِقًى', #1
u'نقيرات': u'نَقِيرَاتٍ', #1
u'نقيف': u'نَقِيفُ', #4
u'نقيلة': u'نقيلة', #2
u'نقيما': u'نُقِيمَا', #2
u'نقيمهاقوله': u'نُقِيمُهَاقَوْلُهُ', #1
u'نقييع': u'نَقِييعُ', #1
u'نك': u'نَكُ', #23
u'نكباء': u'نَكْبَاءُ', #1
u'نكتات': u'نَكَتات', #1
u'نكتات': u'نَكَتَاتُ', #1
u'نكتفى': u'نَكْتَفِى', #2
u'نكتيل': u'نَكْتَيِلُ', #1
u'نكثو': u'نَكَثُو', #1
u'نكردة': u'نكردة', #1
u'نكردستم': u'نكردستم', #1
u'نكردم': u'نكردم', #2
u'نكرده': u'نكرده', #5
u'نكركار': u'نكركار', #1
u'نكركان': u'نَكْرَكَانُ', #2
u'نكروم': u'نكروم', #1
u'نكشايد': u'نكشايد', #1
u'نكفكهم': u'نَكْفِكَهُمْ', #2
u'نكلؤك': u'نَكْلَؤُك', #1
u'نكلؤك': u'نَكْلَؤُكَ', #1
u'نكنم': u'نكنم', #20
u'نكوئى': u'نكوئى', #1
u'نكويم': u'نكويم', #6
u'نكيبا': u'نَكِيبًا', #2
u'نكيرم': u'نكيرم', #1
u'نكيلة': u'نُكَيْلَةُ', #1
u'نلتا': u'نِلْتَا', #1
u'نلتعن': u'نَلْتَعِنُ', #2
u'نماذ': u'نماذ', #1
u'نمارة': u'نمارة', #1
u'نمارة': u'نُمَارَةَ', #4
u'نمارية': u'نَمَّارِيَّةٌ', #1
u'نماز': u'نماز', #12
u'نمازاز': u'نمازاز', #1
u'نمازرابر': u'نمازرابر', #1
u'نمازشام': u'نمازشام', #1
u'نمازي': u'نمازي', #2
u'نمانده': u'نمانده', #1
u'نمتار': u'نَمْتَارُ', #1
u'نمتري': u'نَمْتَرِي', #2
u'نمر': u'نَمِرً', #1
u'نمرقة': u'نُمْرَقَةً', #1
u'نمرقة': u'نُمْرُقَة', #1
u'نمرقة': u'نُمْرُقَةٌ', #1
u'نمرقة': u'نُمْرُقَةٍ', #1
u'نمرقة': u'نُمْرُقَةً', #11
u'نمرقتين': u'نِمْرِقَتَيْنِ', #1
u'نمرقتين': u'نُمْرُقَتَيْنِ', #4
u'نمرود': u'نمرود', #1
u'نمرود': u'نَمْرُودَ', #1
u'نمرود': u'نُمْرُودَ', #15
u'نمرود': u'نُمْرُودُ', #9
u'نمروذ': u'نمروذ', #1
u'نمروذ': u'نُمْرُوذُ', #1
u'نمروذ،': u'نُمْرُوذٌ،', #1
u'نمروذ': u'نُمْرُوذَ', #2
u'نمنعكموه': u'نَمْنَعْكُمُوهُ', #1
u'نموة': u'نَمْوَةَ', #1
u'نمود': u'نمود', #2
u'نموده': u'نموده', #1
u'نموذه': u'نموذه', #1
u'نموذه': u'نَمُوذَهْ', #1
u'نموم': u'نَمُومٌ', #1
u'نميباشم': u'نميباشم', #2
u'نميخوا': u'نميخوا', #1
u'نميربن': u'نميربن', #1
u'نميرود': u'نميرود', #1
u'نميكويد': u'نميكويد', #1
u'نميلة': u'نميلة', #1
u'نميلة': u'نُمَيْلَة', #1
u'نميلة': u'نُمَيْلَةُ', #12
u'نميلة': u'نُمَيْلَةَ', #21
u'نناولكه': u'نُنَاوِلُكَهُ', #1
u'نناولكه،': u'نُنَاوِلُكَهُ،', #1
u'ننتصل': u'نَنْتَصِلُ', #1
u'ننتضل': u'نَنْتَضِلُ', #3
u'ننتهى': u'نَنَتَهِى', #1
u'ننتهى': u'نَنْتَهِى', #3
u'نندا': u'نَنْدَا', #1
u'ننزي': u'نُنَزِّيَ', #1
u'ننزي': u'نُنْزِيَ', #12
u'ننزي': u'نُنْزِي', #2
u'ننزى': u'نُنْزِى', #2
u'ننزى': u'نُنْزِىَ', #3
u'نهابر': u'نَهَابِرَ', #1
u'نهادبا': u'نهادبا', #1
u'نهادكه': u'نهادكه', #7
u'نهادم': u'نهادم', #5
u'نهادهمين': u'نهادهمين', #1
u'نهادوبيراهن': u'نهادوبيراهن', #1
u'نهار': u'نَهَارً', #1
u'نهاسا': u'نَهَّاسًا', #1
u'نهالين': u'نهالين', #1
u'نهأنا': u'نَهَأنا', #1
u'نهانى': u'نَهَانِى', #30
u'نهاوند': u'نهَاوَنْد', #1
u'نهاوند،': u'نَهَاونْد،', #1
u'نهاوند': u'نَهَاوَنْد', #1
u'نهاوند،': u'نَهَاوَنْد،', #1
u'نهاوند،': u'نَهَاوَنْدَ،', #1
u'نهاوند': u'نَهَاوَنْدَ', #15
u'نهاوند': u'نهاوند', #2
u'نهاوند،': u'نهاوند،', #2
u'نهبرة': u'نَهْبَرَةٌ', #1
u'نهبرة': u'نَهْبَرَةَ', #1
u'نهبرة': u'نَهْبَرَةً', #2
u'نهبى': u'نَهْبِى', #2
u'نهبى': u'نُهْبَى', #3
u'نهثت': u'نَهِثَتْ', #1
u'نهدة': u'نَهْدَةٍ', #2
u'نهر': u'نَهْرً', #1
u'نهروان': u'نَهْرَوَانَ', #3
u'نهريق': u'نُهَرِيقَ', #1
u'نهريق': u'نُهَرِيقُ', #3
u'نهريقها': u'نُهَرِيقُهَا', #1
u'نهريقها': u'نُهْرِيقَهَا', #1
u'نهسا': u'نَهْسَا', #2
u'نهسا': u'نَهْسًا', #4
u'نهسا': u'نُهَسًا', #5
u'نهسة،': u'نهسةً،', #1
u'نهسة': u'نَهْسَةِ', #2
u'نهسة': u'نَهْسَةً', #8
u'نهشة': u'نَهْشَةَ', #1
u'نهشة': u'نَهْشَةً', #2
u'نهشة': u'نَهْشَةِ', #2
u'نهشل': u'نهشل', #1
u'نهشل،': u'نهشل،', #1
u'نهشل': u'نَهْشَل', #1
u'نهشل': u'نَهْشَلٌ', #1
u'نهشل،': u'نَهْشَلٍ،', #1
u'نهشل': u'نَهْشَلٍ', #10
u'نهشل': u'نَهْشِلْ', #2
u'نهشل': u'نَهْشَلِ', #4
u'نهشل': u'نَهْشَلُ', #5
u'نهصل': u'نَهْصَلٍ', #1
u'نهقات': u'نَهْقَاتٍ', #4
u'نهلSشرح': u'نَهَلْSشَرْحُ', #1
u'نهملان': u'نَهْمُلَانَ', #1
u'نهنهت': u'نَهْنَهْت', #1
u'نهنهها': u'نَهْنَههَا', #1
u'نهنهها': u'نَهْنَهَهَا', #3
u'نهيتيني': u'نَهَيْتِينِي', #2
u'نهيرة': u'نَهِيرَةً', #1
u'نهيسة': u'نُهَيْسَةَ', #1
u'نهيية': u'نَهْيِيَّةٌ', #1
u'نواتية': u'نَوَاتِيَةً', #1
u'نواتية': u'نَوَاتِيَّةً', #1
u'نواتية': u'نَوَاتِيَّةٌ', #2
u'نؤاجرها': u'نُؤَاجِرُهَا', #8
u'نواحى': u'نَوَاحِى', #5
u'نؤاخذ': u'نُؤَاخِذُ', #1
u'نؤاخذ': u'نُؤَاخَذْ', #3
u'نؤاخذ': u'نُؤَاخَذُ', #4
u'نؤاخذكم': u'نُؤَاخِذُكُمْ', #1
u'نؤاخذه': u'نُؤَاخِذْهُ', #1
u'نؤاخذه': u'نُؤَاخِذُهُ', #9
u'نؤاخذهم': u'نُؤَاخِذُهُمْ', #1
u'نؤاخذهم': u'نُؤَاخِذْهُمْ', #3
u'نواشغ': u'نَوَاشِغَ', #1
u'نواشغه': u'نَوَاشِغُهُ', #1
u'نواصى': u'نَوَاصِىَ', #1
u'نواصى': u'نَوَاصِى', #5
u'نواضله': u'نَوَاضِلُهُ', #1
u'نوافج': u'نَوَافِجَ', #1
u'نوافجها': u'نَوَافِجِهَا', #1
u'نواقض': u'نَوَاقِضُ', #12
u'نواقض': u'نَوَاقِضِ', #125
u'نواقض': u'نَوَاقِضَ', #4
u'نواقضه': u'نَوَاقِضِهِ', #10
u'نوأك': u'نَوْأَك', #1
u'نوالة': u'نوالة', #1
u'نؤامر': u'نُؤَامِرُ', #1
u'نوأها': u'نَوْأَهَا', #4
u'نوائحا': u'نَوَائِحًا', #1
u'نوائحا': u'نَوَائِحَا', #1
u'نواية': u'نَوَايَةُ', #1
u'نوباغي': u'نُوبَاغِيٍّ', #1
u'نوبتى': u'نَوْبَتِى', #5
u'نوديها': u'نُودِيهَا', #1
u'نورSالنجاشي': u'نُورٌSالنّجَاشِيّ', #1
u'نورة': u'نُورَةُ', #1
u'نورة': u'نُورَةِ', #1
u'نورة': u'نَوْرَةِ', #1
u'نورة': u'نَوْرَةْ', #1
u'نورة': u'نَوْرَةٍ', #11
u'نورة': u'نَوْرَةً', #2
u'نورة': u'نَوْرَةُ', #2
u'نورة': u'نُورَةٍ', #23
u'نورة': u'نَوْرَةٌ', #3
u'نورة': u'نُورَةً', #4
u'نورزونا': u'نَوْرِزُونَا', #1
u'نورهوذكر': u'نُورِهِوَذَكَرَ', #1
u'نوشته': u'نوشته', #3
u'نوقات': u'نَوْقَاتَ', #1
u'نوكرده': u'نوكرده', #1
u'نوكه': u'نوكه', #1
u'نوكي': u'نُوكِي', #1
u'نوكى': u'نَوْكَى', #2
u'نوكئ': u'نُوكِئَ', #2
u'نومتى': u'نَوْمَتِى', #2
u'نومى': u'نَوِّمِى', #1
u'نومين': u'نَوْمَيْنِ', #2
u'نونيته': u'نُونِيَّتِهِ', #1
u'نوهست': u'نوهست', #1
u'نؤومة': u'نُؤُومَةٌ', #1
u'نوئى': u'نوئى', #2
u'نويبتة': u'نُوَيْبِتَةٌ', #2
u'نويبتة': u'نُوَيْبِتَةُ', #6
u'نوير': u'نوير', #1
u'نويرة،': u'نُوَيْرة،', #1
u'نويرة': u'نِوَيْرَةَ', #1
u'نويرة،': u'نويرة،', #2
u'نويرة،': u'نُوَيْرَةَ،', #3
u'نويرة': u'نُوَيْرَةَ', #32
u'نويفع،': u'نُوَيْفِعٍ،', #1
u'نويفع': u'نُوَيْفِعٍ', #10
u'نى': u'َنِى', #1
u'نى': u'نى', #2
u'نيء': u'نِيءً', #1
u'نئوب': u'نَئُوبَ', #1
u'نئوم': u'نَئُومُ', #1
u'نئوم': u'نَئُومٌ', #2
u'نئوما': u'نَئُومًا', #1
u'نئوما،': u'نَئُومًا،', #1
u'نئويكم': u'نُئْوِيكُمْ', #1
u'نئيج': u'نَئِيجٌ', #1
u'نئيج': u'نَئِيجُ', #1
u'نيأ': u'نِيأً', #1
u'نيا': u'نِيًّا', #6
u'نيابد': u'نيابد', #2
u'نياحة': u'نِيَاحَةً', #1
u'نياحة': u'نِيَاحَةٍ', #11
u'نياحة': u'نِيَاحَةٌ', #22
u'نيادل': u'نيادل', #1
u'نيافته': u'نِيَافَته', #1
u'نياق': u'نِيَاقٌ', #1
u'نياق': u'نِيَاقٍ', #1
u'نياقك': u'نِيَاقُك', #1
u'نيامده': u'نيامده', #1
u'نيان': u'نِيَّانِ', #1
u'نيائي': u'نِيَائِي', #1
u'نيايد': u'نيايد', #3
u'نيت': u'نِيَّتَ', #1
u'نيت': u'نِيَّتِ', #1
u'نيتة': u'نِيتَةِ', #1
u'نيخاب': u'نِيخَابٍ', #1
u'نيخاب': u'نِيخَابَ', #2
u'نيخورم': u'نيخورم', #1
u'نيدبر': u'نيدبر', #1
u'نيدند': u'نيدند', #1
u'نيذم': u'نيذم', #1
u'نيذى': u'نيذى', #1
u'نيروجات': u'نَيْرُوجَاتٍ', #1
u'نيز': u'نيز', #3
u'نيزاز': u'نيزاز', #1
u'نيزبحل': u'نيزبحل', #1
u'نيزداده': u'نيزداده', #1
u'نيزر': u'نَيْزَرٍ', #1
u'نيزر': u'نيزر', #3
u'نيزراهي': u'نيزراهي', #1
u'نيزهزاردادم': u'نيزهزاردادم', #1
u'نيسابور،': u'نيْسابور،', #1
u'نيسابور': u'نَيْسابور', #1
u'نيسابور': u'نيْسَابور', #1
u'نيسابور': u'نيْسابُور', #1
u'نيسابور،': u'نَيْسَابُور،', #1
u'نيسابور،': u'نَيْسَابُورَ،', #1
u'نيسابور': u'نيسابور', #2
u'نيسابور،': u'نَيْسابور،', #2
u'نيسابور': u'نَيْسَابُورَ', #49
u'نيسابوري': u'نَيْسَابُورِيّ', #1
u'نيسابوري': u'نَيْسَابُورِيٌّ', #1
u'نيسابورى': u'نَيْسَابُورِىٌّ', #2
u'نيسابوري': u'نَيْسَابُورِيُّ', #3
u'نيسابوريا': u'نَيْسَابُورِيًّا', #3
u'نيسابورية': u'نَيْسَابُورِيَّةُ', #1
u'نيسابورية': u'نَيْسَابُورِيَّةً', #10
u'نيسابورية': u'نَيْسَابُورِيَّةٍ', #6
u'نيسابورية': u'نَيْسَابُورِيَّةٌ', #7
u'نيسابوريين': u'نَيْسَابُورِيِّينَ', #2
u'نيستان': u'نيستان', #1
u'نيستي': u'نيستي', #1
u'نيفتد': u'نيفتد', #1
u'نيق': u'نِيق', #1
u'نيق': u'نِيقُ', #1
u'نيق': u'نِيقِ', #2
u'نيك': u'نيك', #1
u'نيك': u'نَيْكٌ', #1
u'نيك': u'نَيْكٍ', #1
u'نيكا': u'نَيْكًا', #1
u'نيكؤا': u'نيكؤا', #1
u'نيكوبكو': u'نيكوبكو', #1
u'نيكوتر': u'نيكوتر', #2
u'نيكوئى': u'نيكوئى', #1
u'نيكويى': u'نيكويى', #1
u'نيلة': u'نِيلَةٍ', #13
u'نيلة': u'نِيلَةً', #2
u'نيمر،': u'نيمر،', #1
u'نيمرشت': u'نِيمَرِشْتُ', #1
u'نيمي': u'نِيمِي', #4
u'نينوفر': u'نَيْنَوْفَرَ', #1
u'نينوى': u'نِينْوَى', #1
u'نينوى': u'نِينَوَى', #16
u'نينوى،': u'نِينَوَى،', #2
u'نيي': u'نِيِّي', #1
u'نيىء': u'نيىء', #1
u'نيئات': u'نِيئَاتٍ', #1
u'نيئة': u'نِيئَة', #1
u'نيئة،': u'نِيئَةً،', #1
u'نيئة': u'نِيئَةً', #22
u'نيئة': u'نِيئَةٍ', #4
u'نيئة': u'نَيِّئَةً', #4
u'نيئين': u'نِيئَيْنِ', #1
u'ها': u'هًا', #1
u'هاأنتم': u'هَاأَنتُمْ', #3
u'هاأنذا': u'هَاأَنَذَا', #1
u'هابى': u'هَابَى', #1
u'هابيل': u'هَابِيلِ', #1
u'هابيل': u'هَابِيلَ', #18
u'هابيل': u'هَابِيل', #2
u'هاتا': u'هَاتَا', #3
u'هاتها': u'هَاتِهَا', #5
u'هاتور': u'هَاتُورُ', #1
u'هاتور': u'هَاتُورْ', #1
u'هاتور': u'هَاتُورَ', #3
u'هاتوه': u'هَاتُوهُ', #3
u'هاتوه،': u'هَاتُوهُ،', #4
u'هاتوها': u'هَاتُوهَا', #1
u'هاتى': u'هَاتِى', #2
u'هاتيه': u'هاتيه', #1
u'هاتيه': u'هَاتِيهِ', #6
u'هاتيها': u'هَاتِيهَا', #1
u'هادونكم': u'هَادُونَكُمْ', #1
u'هاذاك': u'هَاذَاكَ', #1
u'هاذم': u'هَاذِمٌ', #1
u'هاذم': u'هَاذِمِ', #20
u'هاذم': u'هَاذِم', #3
u'هاذم': u'هَاذِمَ', #3
u'هاذم': u'هَاذِمُ', #3
u'هاران': u'هَارَانَ', #3
u'هاران': u'هَارَانِ', #5
u'هاروت،': u'هَارُوتَ،', #1
u'هاروت،': u'هَارُوتُ،', #1
u'هاروت': u'هَارُوَت', #1
u'هاروت': u'هَارُوتُ', #12
u'هاروت': u'هَارُوتَ', #30
u'هاست': u'هاست', #1
u'هاشكست': u'هاشكست', #1
u'هاع': u'هَاعَ', #5
u'هاعان': u'هَاعَانِ', #1
u'هاعان': u'هَاعَانَ', #21
u'هاعان،': u'هَاعَانَ،', #5
u'هاكه': u'هاكه', #1
u'هالع': u'هَالِعٌ', #8
u'هالك': u'هَالِكً', #1
u'هأمة': u'هَأْمَةُ', #1
u'هامج': u'هَامِجٌ', #1
u'هامج': u'هَامِجٍ', #1
u'هامشة': u'هَامِشَةً', #1
u'هأنذا': u'هَأَنَذَا', #5
u'هاني': u'هانيّ', #1
u'هاني': u'هانِي', #2
u'هاني': u'هاني', #4
u'هاني،': u'هَانِي،', #6
u'هاني': u'هَانِي', #8
u'هانىء': u'هَانِىءٍ', #3
u'هاه': u'هاه', #1
u'هاه': u'هَاهْ', #36
u'هاه': u'هَاه', #4
u'هاهنابالقنوت': u'هَاهُنَابِالْقُنُوتِ', #1
u'هاههنا': u'هَاهَهُنَا', #1
u'هاي': u'هَايْ', #1
u'هاي': u'هاي', #2
u'هائعة': u'هَائِعَةً', #1
u'هايأ': u'هَايَأَ', #17
u'هايا': u'هَايَا', #2
u'هايأت': u'هَايَأَتْ', #4
u'هايأه': u'هَايَأَهُ', #2
u'هايأها': u'هَايَأَهَا', #1
u'هايب،': u'هَايِبٌ،', #1
u'هايم': u'هَايْمُ', #1
u'هبادبز': u'هبادبز', #5
u'هبار': u'هَبّار', #1
u'هبار': u'هَبّارَ', #1
u'هبار': u'هَبَّار', #1
u'هبار،': u'هَبَّارٍ،', #1
u'هبار': u'هَبّارُ', #12
u'هبار': u'هَبَّارَ', #13
u'هبار': u'هَبّارٍ', #2
u'هبار': u'هَبَّارٍ', #3
u'هبار': u'هَبّارٌ', #4
u'هبار': u'هَبَّارِ', #4
u'هبار': u'هَبَّارُ', #7
u'هبارا': u'هَبّارًا', #1
u'هبذرة': u'هَبْذَرَةَ', #1
u'هبرزي': u'هَبْرَزِيّ', #1
u'هبرزي': u'هِبْرَزِيّ', #1
u'هبرزيا': u'هِبْرَزِيّا', #1
u'هبرزيا': u'هِبْرِزِيّا', #1
u'هبط': u'هَبَطً', #1
u'هبع': u'هَبَعَ', #1
u'هبعا': u'هُبَعًا', #2
u'هبعة': u'هُبَعَةٌ', #1
u'هبنيها': u'هَبْنِيهَا', #1
u'هبير': u'هُبَيْرٍ', #1
u'هبيرة': u'هُبَيرة', #1
u'هبيرة': u'هُبَيرةَ', #1
u'هبيرة،': u'هُبَيْرة،', #1
u'هبيرة،': u'هُبَيْرَةُ،', #1
u'هبيرة،': u'هبيرة،', #2
u'هبيرة': u'هُبَيْرة', #2
u'هبيرة': u'هُبَيْرَةُ', #27
u'هبيرة': u'هُبيرة', #3
u'هبيرة،': u'هُبَيْرَةَ،', #36
u'هبيرة': u'هُبَيْرَةَ', #531
u'هبيرة': u'هبيرة', #9
u'هبيرة': u'هُبَيْرَة', #9
u'هبيره': u'هبيره', #1
u'هتيم': u'هُتَيْمٍ', #3
u'هجرتى': u'هِجْرَتِى', #1
u'هجرتى؟': u'هِجْرَتِى؟', #1
u'هجمين': u'هجمين', #2
u'هجهجة': u'هَجْهَجَةٍ', #2
u'هجهجت': u'هَجْهَجْت', #1
u'هجول': u'هُجُولُ', #1
u'هجيرى': u'هَجِيرَى', #1
u'هجيرى': u'هِجِّيرَى', #2
u'هجيم': u'هُجَيْمٍ', #1
u'هجيمة': u'هُجَيْمَةُ', #2
u'هجيمة،': u'هُجَيْمَةُ،', #2
u'هدءوا': u'هَدَءُوا', #1
u'هداء': u'هِدَاءً', #3
u'هدابد': u'هَدَابِدُ', #1
u'هداكا': u'هُدَاكَا', #2
u'هدانى': u'هَدَانِى', #4
u'هداهمقوله': u'هَدَاهُمْقَوْلُهُ', #1
u'هداين': u'هداين', #1
u'هدبد': u'هُدَبِدٍ', #1
u'هدرمة': u'هَدْرَمَةُ', #1
u'هدريته': u'هَدَرِيَّتِهِ', #1
u'هدمى': u'هَدْمَى', #2
u'هدهاد': u'هَدْهَادَ', #1
u'هدو': u'هدو', #1
u'هدو': u'هُدُوُّ', #1
u'هدو': u'هُدُوِّ', #1
u'هدو': u'هُدُوٍّ', #6
u'هدوا': u'هُدُوًّا', #1
u'هدوة': u'هُدْوَةٍ', #1
u'هديتنى': u'هَدَيْتَنِى', #1
u'هديتى': u'هَدِيَّتِى', #3
u'هديم': u'هُدَيْمٌ', #1
u'هديى': u'هَدْيِىَ', #1
u'هديى': u'هَدْيِى', #17
u'هذ': u'هذ', #1
u'هذ': u'هَذًّ', #1
u'هذ': u'هَذَّ', #1
u'هذ': u'هَذِّ', #1
u'هذ': u'هَذّ', #3
u'هذاSهجرة': u'هَذَاSهِجْرَةُ', #1
u'هذا': u'هَذَاًًًً', #1
u'هذا': u'هَذًّا', #15
u'هذأ': u'هَذَأ', #2
u'هذاأبو': u'هَذَاأَبُو', #1
u'هذاالأمر': u'هَذَاِِِِالْأَمْرِ', #1
u'هذاالحديث': u'هَذَاالْحَدِيثَ', #1
u'هذاالذى': u'هَذَاالَّذِى', #1
u'هذاالموضع': u'هَذَاالْمَوْضِعِ', #1
u'هذاعى': u'هَذَاعَى', #1
u'هذاقوله': u'هَذَاقَولُهُ', #1
u'هذام': u'هُذَامٍ', #1
u'هذاوالوجه': u'هَذَاوَالْوَجْهُ', #2
u'هذاوإني': u'هَذَاوَإِنِّي', #1
u'هذة': u'هذة', #2
u'هذة': u'هَذَّة', #2
u'هذذت': u'هَذَذْتَ', #1
u'هذرمة': u'هَذْرَمَةٌ', #1
u'هذرمة': u'هَذْرَمَةِ', #1
u'هذرمة': u'هَذْرَمَةً', #2
u'هذرمة': u'هَذْرَمَةَ', #2
u'هذلول': u'هُذْلُولٍ', #1
u'هذلي': u'هُذَلِيُّ', #2
u'هذلية': u'هُذَلَيّة', #1
u'هذلية': u'هُذَلِيَّة', #1
u'هذم': u'هَذَمَ', #1
u'هذهااااا': u'هَذِهِااااا', #1
u'هذهدون': u'هذهدُونِ', #1
u'هذيل': u'هُذَيْلِ', #11
u'هذيل،': u'هُذَيْلٍ،', #11
u'هذيل': u'هُذَيْلٍ', #159
u'هذيل': u'هذيل', #2
u'هذيل': u'هُذَيْل', #2
u'هذيل،': u'هُذَيْلٌ،', #2
u'هذيل': u'هُذَيل', #3
u'هذيل': u'هُذَيْلٌ', #39
u'هذيل': u'هُذَيْلَ', #5
u'هذيل': u'هُذَيْلُ', #8
u'هذيلا': u'هُذيَلًا', #1
u'هذيلا،': u'هُذَيْلًا،', #1
u'هذيلا': u'هُذَيْلًا', #16
u'هذيم': u'هذيم', #1
u'هذيم': u'هُذَيْمٌ', #1
u'هذيم': u'هُذَيْمُ', #2
u'هذيم': u'هُذَيْمٍ', #24
u'هذيما': u'هُذَيْمًا', #1
u'هذينك': u'هَذَيْنِكَ', #2
u'هراة': u'هَرَاةٍ', #1
u'هراة': u'هَرَاةُ', #1
u'هراة،': u'هَرَاة،', #1
u'هراة': u'هَرَاة', #3
u'هراة،': u'هَرَاةَ،', #3
u'هراة': u'هَرَاةَ', #45
u'هرادي': u'هَرَادِيُّ', #10
u'هرادي': u'هَرَادِيّ', #2
u'هرادي': u'هَرَادِيٌّ', #9
u'هراسية': u'هراسية', #1
u'هراش': u'هَرَاشٍ', #1
u'هراش': u'هِرَاشٍ', #1
u'هراشا': u'هِرَاشًا', #1
u'هراق': u'هراق', #1
u'هراق': u'هَرَاقَ', #18
u'هراقة': u'هِرَاقَةً', #2
u'هراقة': u'هِرَاقَةٍ', #2
u'هراقة': u'هِرَاقَةُ', #2
u'هراقة': u'هِرَاقَةِ', #4
u'هراقت': u'هَرَاقَتْ', #2
u'هراقه': u'هِرَاقَهُ', #1
u'هراقه': u'هَرَاقَهُ', #3
u'هرامزة': u'هُرَامِزِةِ', #1
u'هرامسة': u'هَرَامِسَةُ', #2
u'هراميدي': u'هراميدي', #1
u'هرايكي': u'هرايكي', #1
u'هراينه': u'هراينه', #1
u'هربل': u'هَرْبَلٍ', #1
u'هرجاب': u'هِرْجَابَ', #1
u'هردو': u'هردو', #1
u'هردودرين': u'هردودرين', #1
u'هردى': u'هَرْدَى', #2
u'هردية': u'هَرْدِيَّةٍ', #3
u'هرديس': u'هرديس', #1
u'هرزنى': u'هرزنى', #1
u'هرزني': u'هرزني', #3
u'هرشاء': u'هَرْشَاءَ', #2
u'هرشى': u'هَرْشَى', #7
u'هرقلة': u'هِرْقَلَةَ', #1
u'هركاه': u'هركاه', #12
u'هركز': u'هركز', #1
u'هركس': u'هركس', #1
u'هركه': u'هركه', #4
u'هرماس': u'هِرْمَاسٌ', #1
u'هرماس': u'هِرْمَاسٍ', #1
u'هرماس': u'هِرْمَاسُ', #2
u'هرمز،': u'هُرمز،', #1
u'هرمز،': u'هُرْمز،', #1
u'هرمز': u'هَرْمُزَ', #1
u'هرمز': u'هُرْمُز', #1
u'هرمز': u'هُرْمُزْ', #1
u'هرمز،': u'هُرْمُزُ،', #1
u'هرمز': u'هُرْمُزٍ', #13
u'هرمز': u'هرمز', #2
u'هرمز،': u'هُرْمُزٍ،', #2
u'هرمز': u'هُرْمُزَ', #221
u'هرمز،': u'هرمز،', #3
u'هرمز؟': u'هُرْمُزَ؟', #3
u'هرمز،': u'هُرْمُزَ،', #69
u'هرمز': u'هُرْمُزُ', #8
u'هرمزان': u'هُرْمُزَانَ', #4
u'هرمس': u'هَرْمَسَ', #1
u'هرمس': u'هُرْمُسَ', #1
u'هرمس': u'هُرْمُسُ', #2
u'هروز': u'هروز', #1
u'هروشيد': u'هروشيد', #1
u'هروقت': u'هروقت', #1
u'هريت': u'هَرَّيْت', #2
u'هريرةرضى': u'هُرَيْرَةَرَضِىَ', #1
u'هريرةلولا': u'هُرَيْرَةَلَوْلا', #1
u'هريق': u'هُرِيقَ', #7
u'هريقوا': u'هَريقُوا', #1
u'هريقوا': u'هَرِيقُوا', #7
u'هريكى': u'هريكى', #2
u'هريم،': u'هريم،', #1
u'هريم': u'هُرَيْم', #1
u'هريم': u'هُرَيْمُ', #19
u'هريم،': u'هُرَيْمٍ،', #2
u'هريم': u'هُرَيْمِ', #3
u'هريم،': u'هُرَيْمٌ،', #3
u'هريم': u'هُرَيْمٌ', #9
u'هزارتن': u'هزارتن', #1
u'هزاردردم': u'هزاردردم', #1
u'هزاردرم': u'هزاردرم', #1
u'هزارديكر': u'هزارديكر', #1
u'هزارنيف': u'هِزَارَنِيفْ', #3
u'هزب': u'هَزَبِ', #1
u'هزوا': u'هزواً', #1
u'هزوا': u'هُزُواً', #1
u'هزؤا': u'هُزُؤًا', #2
u'هزوا': u'هُزُوًا', #64
u'هستم': u'هُسْتُمْ', #2
u'هستي': u'هِسَتِي', #2
u'هشامح': u'هِشَامٍح', #1
u'هشامحدثنا': u'هِشَامٍحَدَّثَنَا', #1
u'هشامكان': u'هِشَامٍكَانَ', #1
u'هشبل': u'هشبل', #1
u'هشة': u'هَشَّةً', #1
u'هشة': u'هَشَّةَ', #1
u'هشتاد': u'هشتاد', #1
u'هشتي': u'هشتي', #1
u'هشتى': u'هشتى', #1
u'هصان': u'هِصَّانُ', #1
u'هصان': u'هِصَّانَ', #3
u'هصيص': u'هَصِيصِ', #1
u'هصيص': u'هُصَيْصَ', #1
u'هصيص،': u'هُصَيْصُ،', #1
u'هصيص': u'هُصَيْص', #10
u'هصيص': u'هَصِيص', #2
u'هصيص': u'هُصَيْصِ', #55
u'هصيص': u'هصيص', #7
u'هصيص': u'هُصَيْصٍ', #8
u'هضاض': u'هَضَّاضٍ', #3
u'هطى': u'هطى', #2
u'هفصد': u'هفصد', #2
u'هق': u'هق', #42
u'هق': u'هَقّ', #6
u'هقط': u'هِقِطْ', #1
u'هقل': u'هَقْلُ', #1
u'هقل': u'هِقْلٍ', #1
u'هقل': u'هِقْلُ', #10
u'هقل': u'هِقْلٌ', #12
u'هقل،': u'هِقْلٌ،', #2
u'هقل': u'هِقْلِ', #3
u'هكذ': u'هَكَذَ', #1
u'هلاكو': u'هُلَاكُو', #1
u'هلال': u'هًلالٍ', #1
u'هلاني': u'هِلَانِي', #1
u'هلب': u'هلب', #1
u'هلب': u'هَلَّبَ', #1
u'هلب': u'هُلْبٌ', #1
u'هلب': u'هُلْبٍ', #26
u'هلباء': u'هَلْبَاءُ', #1
u'هلباء،': u'هَلْبَاءَ،', #1
u'هلباء': u'هَلْبَاءَ', #3
u'هلبات': u'هُلْبَاتٍ', #1
u'هلباك': u'هَلْبَاك', #1
u'هلبة': u'هُلْبَةُ', #1
u'هلبت': u'هَلَبْت', #1
u'هلبه': u'هُلْبَهُ', #1
u'هلبها': u'هَلَبَهَا', #1
u'هلف': u'هَلَفَ', #2
u'هلكاS': u'هَلَكًاS', #1
u'هلما': u'هَلُمَّا', #5
u'هلمه': u'هَلُمَّهُ', #1
u'هلمه،': u'هَلُمَّهُ،', #1
u'هلموا،': u'هَلُمُّوا،', #1
u'هلموا': u'هلموا', #4
u'هلموا': u'هَلُمُّوا', #52
u'هلموا': u'هَلُمّوا', #6
u'هلمي': u'هَلُمِّي', #18
u'هلمى': u'هَلُمِّى', #6
u'هلميه': u'هَلُمّيهِ', #1
u'هلميها': u'هَلُمِّيهَا', #1
u'هليصليها': u'هَلْيُصَلِّيهَا', #1
u'هليكبر': u'هَلْيُكَبِّرُ', #1
u'هليلجة': u'هَلِيلِجَةٌ', #1
u'هليلجة': u'هِلِيلِجَةً', #1
u'هماذا': u'هَمَاذَا', #1
u'هماذي': u'هَمَاذِي', #1
u'همار': u'همار', #1
u'همار': u'هَمِّارٍ', #1
u'همار': u'هَمَّارٍ', #12
u'همار،': u'هَمَّارٍ،', #3
u'همال': u'هَمّالِ', #1
u'همالة': u'هَمَّالَةً', #1
u'هماليهود،': u'هُمُالْيَهُودُ،', #1
u'همانست': u'همانست', #1
u'همتى': u'هِمَّتِى', #2
u'همجنين': u'همجنين', #9
u'همجنينم': u'همجنينم', #4
u'همدانيا': u'هَمْدَانيًا', #1
u'همدانية': u'هَمْدَانِيَّةٌ', #1
u'همدانية': u'هَمْدَانِيَّةُ', #2
u'همساية': u'همساية', #1
u'همسايه': u'همسايه', #1
u'همط': u'هَمَطَ', #2
u'هملاج': u'هِمْلَاجَ', #1
u'هملاج': u'هِمْلَاجُ', #1
u'هملاج': u'هِمْلَاجٌ', #18
u'هملاج': u'هِمْلَاجٍ', #8
u'هملاجا': u'هِمْلَاجًا', #3
u'هملاجة': u'هملاجة', #1
u'هملاجة': u'هِمْلَاجَةَ', #1
u'هملاجة': u'هَمْلَاجَةً', #2
u'هملاجة': u'هِمْلَاجَةً', #5
u'هملج': u'هَمْلَجَ', #1
u'هملجة': u'هَمْلَجَةً', #2
u'هملجت': u'هَمْلَجَتْ', #1
u'هملجت': u'هَمْلَجْت', #1
u'همنشينان': u'همنشينان', #1
u'همنى': u'هَمَّنِى', #1
u'همو': u'هُمُو', #10
u'هميانا': u'هَمَيَانًا', #1
u'هميانا': u'هِمْيَانًا', #1
u'هميانه': u'هِمْيَانَهُ', #1
u'هميانه': u'هِمْيَانِهِ', #1
u'هميانها': u'هِمْيَانِهَا', #1
u'همياني': u'هِمْيَانِي', #1
u'هميانى': u'هِمْيَانِى', #1
u'هميسا': u'هَمِيسًا', #10
u'هميسع': u'همَيْسع', #1
u'هميسع': u'هَمَيْسع', #1
u'هميسع': u'هميسع', #2
u'هميسع': u'همَيْسَع', #4
u'همينة': u'هُمَيْنَةُ', #6
u'هناة': u'هَنَاةٍ', #1
u'هناكم': u'هُنَاكُمُ', #1
u'هناكم': u'هُنَاكُمْ', #35
u'هنالكا': u'هُنَالِكَا', #3
u'هنب': u'هِنْبٌ', #1
u'هنب': u'هِنْبٍ', #1
u'هنب': u'هِنْبِ', #14
u'هنب': u'هنب', #2
u'هنبا': u'هنبا', #1
u'هنبل': u'هَنْبَلُ', #1
u'هنتموني،': u'هِنْتُمُونِي،', #1
u'هندباء': u'هِنْدِبَاءَ', #1
u'هندرة': u'هَنْدَرَةً', #1
u'هندرة': u'هَنْدَرَةٌ', #1
u'هندرة': u'هَنْدَرَةَ', #1
u'هندكى': u'هندكى', #1
u'هندكية': u'هِنْدِكيّة', #1
u'هندكية': u'هِنْدِكِيّةٍ', #1
u'هندويرا': u'هندويرا', #1
u'هنكامه': u'هنكامه', #1
u'هنهة': u'هَنْهَةٌ', #1
u'هنوة': u'هَنْوَةٌ', #1
u'هنوك': u'هَنُوكِ', #1
u'هنى': u'هُنَىُّ', #1
u'هنى': u'هُنَىِّ', #3
u'هنىء': u'هنىء', #1
u'هنياتك': u'هُنَيّاتِك', #1
u'هنياتك': u'هُنَيَّاتِكَ', #2
u'هنياتك،': u'هُنَيَّاتِكَ،', #2
u'هنيته': u'هَنَّيْتَهُ', #1
u'هنيد': u'هنيد', #1
u'هنيد': u'هُنَيْد', #1
u'هنيد': u'هُنَيْدٌ', #1
u'هنيد': u'هُنَيْدٍ', #4
u'هنيد': u'هُنَيْدُ', #4
u'هنيدة': u'هنيدة', #1
u'هنيدة': u'هُنَيْدَةٌ', #1
u'هنيدة': u'هُنَيْدَةُ', #2
u'هنيدة،': u'هُنَيْدَةَ،', #3
u'هنيدة': u'هُنَيْدَةَ', #33
u'هنييا': u'هنييا', #2
u'ههو': u'هَهُوَ', #1
u'هواءة': u'هَوَاءَةُ', #1
u'هوابن': u'هُوَابْنُ', #1
u'هوأحد': u'هُوَأَحَدُ', #1
u'هوأحق': u'هُوَأَحَقُّ', #1
u'هوازن،': u'هوازن،', #1
u'هوازن': u'هَوازن', #1
u'هوازن،': u'هَوازِن،', #1
u'هوازن': u'هَوَازِنَََََ', #1
u'هوازن': u'هُوَازِنَ', #1
u'هوازن،': u'هَوَازِنُ،', #1
u'هوازن،': u'هَوَازِنَ،', #11
u'هوازن': u'هوازن', #16
u'هوازن': u'هَوَازِنَ', #305
u'هوازن': u'هَوَازِن', #5
u'هوازن': u'هَوَازِنُ', #52
u'هوازني': u'هَوَازِنِيّ', #1
u'هوالذي': u'هُوَالَّذِي', #1
u'هوالزرع': u'هُوَالزَّرْعُ', #1
u'هوالكافر،': u'هُوَالْكَافِرُ،', #1
u'هوالمشهور': u'هُوَالْمَشْهُورُ', #1
u'هوامى': u'هَوَامِىَ', #1
u'هوبالركعة': u'هُوَبِالرَّكْعَةِ', #1
u'هوبر': u'هَوْبَرُ', #2
u'هوبر': u'هَوْبَرٍ', #3
u'هوبملآن': u'هُوَبِمَلْآنَ', #1
u'هوثر': u'هَوْثَرَ', #1
u'هودة': u'هُودَةَ', #1
u'هودة': u'هَوْدَةَ', #2
u'هودجى': u'هَوْدَجِى', #2
u'هودية': u'هُودِيَّةً', #1
u'هوذة،': u'هَوْذَةُ،', #19
u'هوذة': u'هوذة', #2
u'هوذة،': u'هَوْذَةَ،', #2
u'هوذة': u'هَوْذَةُ', #59
u'هوذة': u'هَوْذَةَ', #67
u'هوذل': u'هَوْذَل', #1
u'هوقوله': u'هُوَقَوْلُهُ', #1
u'هؤلا': u'هَؤُلَا', #6
u'هؤلاءاليهود': u'هَؤُلاءِالْيَهُودُ', #1
u'هؤلاءأهدى': u'هَؤُلاءِأَهْدَى', #1
u'هؤلائك': u'هَؤُلَائِكَ', #1
u'هوليظهر': u'هُوَلِيُظْهِرَ', #1
u'هؤولاء': u'هؤولاء', #1
u'هويل': u'هُوَيْلٍ', #2
u'هويئ': u'هُويِئَ', #1
u'هويئت': u'هُويِئَتْ', #1
u'هى': u'َهِىَ', #1
u'هى': u'هى', #11
u'هى؟': u'هِىَ؟', #16
u'هى': u'هِىَ', #623
u'هى': u'هِى', #7
u'هئية': u'هَئْيَةِ', #1
u'هية': u'هَيَةً', #1
u'هية': u'هِيَةِ', #2
u'هيتا': u'هِيتًا', #2
u'هيذام،': u'هَيْذَامٌ،', #1
u'هيزم': u'هيزم', #1
u'هيشة': u'هَيْشَةَ', #12
u'هيصم': u'هَيْصَمٍ', #4
u'هيصم،': u'هَيْصَمٍ،', #4
u'هيضة': u'هَيْضَةٌ', #1
u'هيضة': u'هَيْضَةٍ', #3
u'هيضم،': u'هَيْضَمٍ،', #1
u'هيضم': u'هَيْضَمٍ', #4
u'هيعة': u'هَيْعَة', #1
u'هيعة': u'هَيْعَةٌ', #1
u'هيعة': u'هَيْعَةَ', #1
u'هيعة': u'هَيْعَةً', #9
u'هيه؟': u'هِيهِ؟', #1
u'هيه': u'هِيَهْ', #12
u'هيه،': u'هِيهِ،', #2
u'هيه': u'هِيهِ', #31
u'هيه': u'هِيهْ', #8
u'هيئى': u'هَيِّئِى', #1
u'و18': u'و18ْ', #1
u'وأ': u'وَأَ', #1
u'وأ': u'وأ', #6
u'واأخاه': u'وَاأَخَاهُ', #2
u'واأخاه': u'وَاأَخَاهْ', #3
u'وأأمن': u'وَأَأْمَنُ', #1
u'واباحة': u'وَابَاحَةٌ', #1
u'واباحة': u'وَابَاحَةَ', #1
u'واباحة': u'وَابَاحَةُ', #1
u'واباحة': u'واباحة', #2
u'وإباحه': u'وإباحه', #2
u'وأبآر': u'وَأَبْآرٍ', #1
u'وأبآر': u'وَأَبْآرُ', #1
u'وإبار': u'وَإِبَّارُ', #1
u'وأبآر': u'وَأَبْآرٌ', #2
u'وإبار': u'وَإِبَارِ', #4
u'وإبار': u'وَإِبَارُ', #7
u'وإباق': u'وَإِبَاقُ', #10
u'وإباق': u'وَإِبَاقِ', #11
u'وإباق': u'وَإِبَاقٍ', #17
u'وإباق': u'وَإِبَاقٌ', #3
u'وإباقا': u'وَإِبَاقًا', #1
u'وإباقه': u'وَإِبَاقُهُ', #10
u'وإباقه': u'وَإِبَاقِهِ', #17
u'وآبآؤكم': u'وَآبَآؤُكُمْ', #1
u'وأبائر': u'وَأَبَائِرُ', #1
u'وإباية': u'وَإِبَايَةَ', #1
u'وإباية': u'وَإِبَايَةِ', #1
u'وإبايته': u'وإبايته', #1
u'وإبايتهم': u'وَإِبَايَتِهِمْ', #2
u'وآبة': u'وَآبَةَ', #1
u'وإبتال': u'وَإِبْتَالٍ', #1
u'وابتدا': u'وَابْتِدَا', #5
u'وابتداه': u'وَابْتَدَاهُ', #1
u'وابتدر': u'وابتَدَرَ', #1
u'وابتدر': u'وَابْتَدَرَ', #4
u'وابتدرنا': u'وَابْتَدَرْنَا', #3
u'وابتدرناه': u'وابتدرناه', #1
u'وابتدرناه': u'وَابْتَدَرْنَاهُ', #2
u'وابتدره': u'وَابْتَدَرَهُ', #2
u'وابتدرها': u'وَابْتَدَرَهَا', #2
u'وابتدروا': u'وَابْتَدَرُوا', #4
u'وابتدروه': u'وَابْتَدَرُوهُ', #1
u'وابتدي': u'وَابْتَدِي', #1
u'وأبتوا': u'وَأَبِتُّوا', #3
u'وأبثثت': u'وَأَبْثَثْتُ', #1
u'وأبثثتك': u'وَأَبْثَثْتُكَ', #1
u'وإبخاس': u'وَإِبْخَاسُ', #2
u'وإبخاسا': u'وَإِبْخَاسًا', #1
u'وابدءوا': u'وَابْدَءُوا', #3
u'وإبدا': u'وَإِبْدًا', #1
u'وابداء': u'وَابَدَاءُ', #1
u'وابداء': u'وَابَدَاءِ', #1
u'وأبدلنى': u'وَأَبْدِلْنِى', #1
u'وأبدؤهم': u'وَأَبْدَؤُهُمْ', #1
u'وابدئى': u'وَابْدَئِى', #2
u'وأبذيتهم': u'وَأَبْذَيْتَهُمْ', #1
u'وآبر': u'وَآبُرٌ', #1
u'وآبر': u'وَآبِرٌ', #2
u'وأبرءوا': u'وَأَبْرَءُوا', #6
u'وابراء': u'وَابَرَاءً', #1
u'وابراء': u'وَابَرَاءُ', #1
u'وابراء': u'وَابَرَاءِ', #1
u'وإبراهيمي': u'وَإِبْرَاهِيمِيٌّ', #1
u'وإبراهيمي': u'وَإِبْرَاهِيمِيِّ', #1
u'وإبراهيمي': u'وَإِبْرَاهِيمِيٍّ', #4
u'وأبراؤه': u'وَأَبْرَاؤُهُ', #1
u'وأبركها': u'وَأَبْرَكَهَا', #1
u'وأبركها': u'وَأَبْرَكُهَا', #1
u'وابرنتيت': u'وَابْرَنُتَيْتُ', #1
u'وابرنذعت': u'وَابْرَنُذَعْتُ', #1
u'وأبرهة': u'وَأَبْرَهَةَ', #3
u'وأبرهة': u'وَأَبْرَهَةُ', #5
u'وأبرؤه': u'وَأَبْرَؤُهُ', #1
u'وأبرويز': u'وأبرويز', #1
u'وإبريسم': u'وَإِبْرَيْسَمٌ', #2
u'وإبريسم': u'وَإِبْرَيْسَمَ', #3
u'وإبريسم': u'وَإِبْرَيْسَمٍ', #9
u'وإبريسما': u'وَإِبْرَيْسَمًا', #2
u'وابزار': u'وابزار', #1
u'وابزد': u'وابزد', #1
u'وأبسست': u'وَأَبْسَسْت', #1
u'وأبشارا': u'وَأَبْشَارًا', #2
u'وأبشاركم': u'وَأَبْشَارَكُمْ', #2
u'وأبشاركم': u'وَأَبْشَارُكُمْ', #6
u'وأبشارهم': u'وَأَبْشَارِهِمْ', #1
u'وأبشرى': u'وَأَبْشِرِى', #1
u'وابصة،': u'وَابِصَةَ،', #1
u'وابصة': u'وَابِصَةُ', #21
u'وابصة': u'وابصة', #4
u'وابصة،': u'وابصة،', #4
u'وابصة': u'وَابِصَةَ', #48
u'وأبصع': u'وَأَبْصَعَ', #3
u'وابصه': u'وَابِصه', #1
u'وأبضاع': u'وَأَبْضَاعٍ', #1
u'وإبضاع': u'وَإِبْضَاعٌ', #1
u'وإبضاع': u'وَإِبْضَاعُ', #2
u'وأبضاع': u'وَأَبْضَاعُ', #4
u'وإبضاع': u'وَإِبْضَاعٍ', #6
u'وأبضاعا': u'وَأَبْضَاعًا', #1
u'وإبضاعا': u'وَإِبْضَاعًا', #2
u'وأبضاعهم': u'وَأَبْضَاعِهِمْ', #3
u'وأبضاعهن': u'وَأَبْضَاعِهِنَّ', #1
u'وأبضعة': u'وَأَبْضَعَةَ', #3
u'وأبطا': u'وَأَبْطَا', #1
u'وابطال': u'وابطال', #1
u'وأبعته': u'وَأَبَعْته', #1
u'وأبعثته': u'وَأَبْعَثْتُهُ', #1
u'وابعد': u'وَابْعُدْ', #1
u'وابعدي': u'وَابْعَدِي', #1
u'وابعدي': u'وَابْعُدِي', #3
u'وأبعرة': u'وَأَبْعِرَةٌ', #1
u'وأبعرة': u'وَأَبْعِرَةٍ', #1
u'وآبق': u'وَآبِقٍ', #29
u'وآبق': u'وَآبِقٌ', #6
u'وأبقا': u'وَأَبَقَا', #1
u'وآبقا': u'وَآبِقًا', #13
u'وابقاء': u'وَابَقَاءً', #1
u'وابقاء': u'وَابَقَاءَ', #1
u'وآبقة': u'وَآبِقَةً', #1
u'وأبقراط': u'وَأُبُقْرَاطُ', #1
u'وأبقل': u'وَأَبْقَلَ', #1
u'وابقه': u'وَابِقِهِ', #1
u'وابقه': u'وَابْقِهِ', #1
u'وأبلست': u'وَأَبْلَسَتْ', #1
u'وأبلغية': u'وَأَبْلَغِيَّةَ', #1
u'وأبلغية': u'وَأَبْلَغِيَّةُ', #4
u'وأبلوجة': u'وَأُبْلُوجَةً', #1
u'وابنالماجشون': u'وَابْنُالْمَاجِشُونِ', #3
u'وأبنآئنا': u'وَأَبْنَآئِنَا', #1
u'وأبنة': u'وَأُبْنَةٍ', #1
u'وابنتا': u'وَابْنَتًا', #1
u'وابنم': u'وَاِبْنُم', #1
u'وأبنوس': u'وَأَبَنُوسٍ', #1
u'وأبنوهم': u'وَأَبَنُوهُمْ', #3
u'وابنى': u'وَابْنِى', #1
u'وابنى': u'وَابْنَىْ', #2
u'وأبنياتهم': u'وَأَبْنِيَاتِهِمْ', #1
u'وابنيتاه': u'وَابُنَيّتَاهُ', #1
u'وأبوالعباس': u'وَأَبُوالْعَبَّاسِ', #1
u'وأبواى': u'وَأَبَوَاىَ', #1
u'وأبؤر': u'وَأَبْؤُرٌ', #1
u'وأبوعامر': u'وَأَبُوعَامِرِ', #1
u'وأبوعلي': u'وَأَبُوعَلِيٍّ', #1
u'وأبوعلي': u'وَأَبُوعَلِيِّ', #1
u'وإبول': u'وَإِبّوْلٌ', #1
u'وإبيان،': u'وَإِبْيَانُ،', #1
u'وإبيزا': u'وَإِبِيزَا', #1
u'وأبيعكها': u'وَأَبِيعُكهَا', #1
u'وأبيعكها': u'وَأَبِيعُكَهَا', #1
u'وإبيل': u'وَإِبّيلٌ', #1
u'وأتاتين': u'وَأَتَاتِينِ', #1
u'واتأد': u'وَاتَّأَدَ', #1
u'وأتأذى': u'وَأَتَأَذَّى', #1
u'وأتاركك': u'وَأُتَارِكُك', #1
u'وأتألفهم': u'وَأَتَأَلَّفَهُمْ', #3
u'واتاهم': u'وَاتَاهُمْ', #4
u'وأتأيم': u'وَأَتَأَيَّمْ', #1
u'وأتبارهما': u'وَأَتْبَارِهِمَا', #1
u'وأتبانهم': u'وَأَتْبَانَهُمْ', #1
u'وأتبعة': u'وَأَتْبِعَةً', #1
u'وأتبعة': u'وَأَتْبِعَةٌ', #1
u'وأتبعة': u'وَأَتْبِعَةٍ', #2
u'واتبعون': u'وَاتّبِعُونِ', #4
u'واتت': u'وَاتَتْ', #1
u'واتديت': u'وَاتَّدَيْت', #1
u'واترع': u'وَاُتْرعُ', #1
u'واترعي': u'وَاتْرَعِي', #1
u'وأترمى': u'وَأَتَرَمَّى', #1
u'وأترنج': u'وَأُتْرُنْجٍ', #1
u'وأترنجا': u'وَأَتْرُنْجًا', #1
u'واتضاع': u'وَاتِّضَاعُ', #1
u'واتضع': u'وَاتَّضَعَ', #1
u'واتعدوا': u'وَاتَّعَدُوا', #1
u'واتعدوا': u'واتَّعَدُوا', #2
u'واتعدوا': u'وَاتّعَدُوا', #5
u'واتغر': u'وَاتَّغَرَ', #1
u'وأتقاء': u'وَأَتْقَاءً', #1
u'وأتقاني': u'وَأَتْقَانِيٌّ', #2
u'واتقون': u'وَاتَّقُونِ', #5
u'وأتمنوا': u'وَأْتُمِنُوا', #1
u'واتن': u'وَاتِنٌ', #6
u'واتنا': u'وَاتِنًا', #2
u'وأتنفت': u'وَأْتَنَفَتْ', #2
u'واتهاب': u'وَاتِّهَابُ', #1
u'واتهاب': u'وَاتِّهَابِ', #3
u'واتهاب': u'وَاتِّهَابٍ', #5
u'واتهابه': u'وَاتِّهَابِهِ', #1
u'واتهابه': u'وَاتِّهَابُهُ', #4
u'واتهابها': u'وَاتِّهَابُهَا', #1
u'واتهابهم': u'وَاتِّهَابُهُمْ', #1
u'واتهابهما': u'وَاتِّهَابُهُمَا', #1
u'واتهب': u'وَاتَّهَبَ', #2
u'واتهبت': u'وَاتَّهَبْتُ', #1
u'واتهبت': u'وَاتَّهَبْت', #3
u'واتهبه': u'وَاتَّهَبَهُ', #2
u'وأتواب': u'وَأَتْوَابِ', #1
u'وأتونى': u'وَأْتُونِى', #1
u'واتئد': u'وَاتَّئِدْ', #1
u'واتيان': u'وَاتَيَانِ', #1
u'وأتيانهم': u'وَأتْيَانَهُمْ', #1
u'وإثاف': u'وَإِثَافٍ', #1
u'وأثاني': u'وَأَثَانِيِّ', #1
u'وإثبانا': u'وَإِثْبَانًا', #1
u'واثبوراه': u'وَاثُبُورَاهُ', #1
u'واثتثباتها': u'وَاثْتِثْبَاتِهَا', #1
u'وأثربي': u'وَأَثْرِبِيٌّ', #1
u'وأثرم': u'وَأَثْرَمُ', #2
u'وأثط': u'وَأَثْطُ', #1
u'وأثعل': u'وَأَثْعَلُ', #1
u'وأثفالهم': u'وَأَثْفَالِهِمْ', #1
u'وأثقبتها': u'وَأَثْقَبِتهَا', #1
u'وأثقبتها': u'وَأَثْقَبْتُهَا', #1
u'وإثكال': u'وَإِثْكَالٌ', #3
u'واثكلياه': u'وَاثُكْلَيَاهُ', #1
u'وأثلة': u'وأثلة', #1
u'واثلة،': u'وَاثِلَةِ،', #1
u'واثلة،': u'وَاثِلَةَ،', #10
u'واثلة': u'واثلة', #12
u'واثلة': u'وَاثِلَة', #2
u'واثلة': u'وَاثِلَةَ', #230
u'واثلة': u'وَاثِلَةُ', #41
u'واثله': u'وَاثِلَهْ', #1
u'وإثمد': u'وَإِثْمِدٍ', #2
u'وإثمدا': u'وَإِثْمِدَا', #1
u'واثنى': u'وَاثْنَى', #1
u'واثنى': u'وَاثْنَىْ', #1
u'وأثيث': u'وَأَثِيثٍ', #1
u'وأجأ': u'وَأَجَأً', #2
u'واجابة': u'وَاجَابَةِ', #1
u'وأجازفهم': u'وَأُجَازِفُهُمْ', #1
u'وأجاص': u'وَأَجَاصٍّ', #1
u'وآجالهمالوجه': u'وَآجَالِهِمْالْوَجْهُ', #1
u'وأجائز': u'وَأَجَائِزٌ', #1
u'واجب': u'وَاجِبً', #1
u'واجبأو': u'وَاجِبٌأَوْ', #1
u'واجبرنى': u'وَاجْبُرْنِى', #3
u'واجبوروي': u'وَاجِبٌوَرُوِيَ', #1
u'واجتال': u'وَاجْتَالَ', #1
u'واجتددتيه': u'وَاجْتَدَدْتِيهِ', #1
u'واجترءوا': u'وَاجْتَرَءُوا', #5
u'واجترم': u'وَاجْتَرَمَ', #1
u'واجتزأ': u'وَاجْتَزَأَ', #2
u'واجتزاء': u'وَاجْتِزَاءٍ', #1
u'واجتزأت': u'وَاجْتَزَأَتْ', #1
u'واجتزأت': u'وَاجْتَزَأْتَ', #2
u'واجتزر': u'وَاجْتَزَرَ', #1
u'واجتزى': u'وَاجْتَزَى', #2
u'واجتزئ': u'وَاجْتُزِئَ', #12
u'واجتزئ': u'وَاجْتَزِئْ', #4
u'واجتسه': u'وَاجْتَسَّهُ', #1
u'واجتلد': u'وَاجْتَلَدَ', #3
u'واجتلدوا': u'وَاجْتَلَدُوا', #4
u'واجتهر': u'وَاجْتَهَرَ', #1
u'واجتهرت': u'وَاجْتَهَرْتُ', #1
u'واجتووا': u'وَاجْتَوَوُا', #1
u'واجتووا': u'وَاجْتَوَوْا', #1
u'واجتويناها': u'وَاجْتَوَيْنَاهَا', #1
u'واجثوا': u'وَاجْثُوا', #1
u'وأجحار': u'وَأَجْحَارٌ', #1
u'وأجحفها': u'وَأَجْحَفَهَا', #1
u'وأجدموا': u'وَأَجْدَمُوا', #2
u'وأجدنى': u'وَأَجِدُنِى', #1
u'وأجذعة': u'وَأَجْذِعَةٌ', #1
u'وأجذعة': u'وَأَجْذِعَةٍ', #2
u'وأجرأهم': u'وَأَجْرَأَهُمْ', #1
u'واجرت': u'وَاجَرْت', #1
u'وآجرتكها': u'وَآجَرْتُكهَا', #1
u'وأجرتكها': u'وَأَجَرْتُكَهَا', #1
u'واجرته': u'وَاجَرْتَهُ', #2
u'وأجرفة': u'وَأَجْرِفَةٍ', #1
u'وأجرنة': u'وَأَجِرْنَةٍ', #1
u'وأجرنة': u'وَأَجْرِنَةُ', #1
u'وأجرنة': u'وَأَجْرِنَةٍ', #3
u'واجره': u'وَاجَرَهُ', #1
u'واجره': u'وَاجْرِهِ', #1
u'واجروه': u'وَاجَرُوهُ', #2
u'واجروه': u'وَاجْرُوهُ', #4
u'وأجزا': u'وَأَجْزَا', #1
u'وأجزأت': u'وَأَجْزَأَتْ', #42
u'وأجزأتا': u'وَأَجْزَأَتَا', #1
u'وأجزأتك': u'وَأَجْزَأَتْكَ', #2
u'وأجزأتك': u'وَأَجْزَأَتْك', #3
u'وأجزأته': u'وَأَجْزَأْته', #2
u'وأجزأته': u'وَأَجْزَأَتْهُ', #66
u'وأجزأتها': u'وَأَجْزَأَتْهَا', #1
u'وأجزأتهم': u'وَأَجْزَأَتْهُمْ', #7
u'وأجزأتهما': u'وَأَجْزَأَتْهُمَا', #1
u'وأجزاع': u'وَأَجْزَاعِ', #1
u'وأجزاه': u'وَأَجْزَاهُ', #4
u'وأجزرتموه': u'وَأَجْزَرْتُمُوهُ', #1
u'وأجزية': u'وَأَجْزِيَةُ', #1
u'وأجعال': u'وَأَجْعَالَ', #1
u'وأجعلت': u'وَأَجْعَلْتُ', #1
u'واجعلنى': u'وَاجْعَلْنِى', #7
u'واجعلى': u'وَاجْعَلِى', #2
u'وإجلا': u'وَإِجْلًا', #1
u'وأجلسنى': u'وَأَجْلَسَنِى', #1
u'واجماع': u'وَاجِمَاعِ', #2
u'وأجمال': u'وَأَجْمَالٍ', #5
u'وأجمريها': u'وَأَجْمِرِيهَا', #1
u'وإجناء': u'وَإِجْنَاءٍ', #1
u'وأجنادين': u'وَأَجْنَادِينَ', #1
u'واجنبني': u'وَاجْنُبْنِي', #6
u'وأجنبيون': u'وَأَجْنَبِيُّونَ', #1
u'وأجهال': u'وَأَجْهَالٍ', #1
u'وإجهال': u'وَإِجْهَالٍ', #1
u'وأجهدS': u'وَأَجْهَدُS', #1
u'وأجهوري': u'وَأُجْهُورِيٌّ', #2
u'واجيا': u'وَاجِيًا', #1
u'واجية': u'وَاجِيَةً', #1
u'وأجيحت': u'وَأُجِيحَتْ', #10
u'وأجيفوا': u'وَأَجِيفُوا', #4
u'وأحاديثا': u'وَأَحَادِيثًا', #1
u'واحبنطى': u'وَاحْبَنْطَى', #2
u'واحتاجه': u'وَاحْتَاجَهُ', #2
u'واحتاجها': u'وَاحْتَاجَهَا', #1
u'واحتازها': u'وَاحْتَازَهَا', #3
u'واحتجبى': u'وَاحْتَجِبِى', #5
u'واحتجر': u'وَاحْتَجِرْ', #1
u'واحتجم': u'وَاحْتَجَمَ', #28
u'واحتجمت': u'وَاحْتَجَمْت', #1
u'واحتجموا': u'وَاحْتَجِمُوا', #1
u'واحترثوا': u'وَاحْتَرِثُوا', #1
u'واحتز': u'وَاحْتَزّ', #1
u'واحتز': u'وَاحْتَزَّ', #5
u'واحتزام': u'وَاحْتِزَامٌ', #1
u'واحتزام': u'وَاحْتِزَامٍ', #2
u'واحتزب': u'وَاحْتَزَبَ', #1
u'واحتزتيه': u'وَاحْتَزْتِيهِ', #4
u'واحتزز': u'وَاحْتَزِزْ', #1
u'واحتززت': u'وَاحْتَزَزْتُ', #1
u'واحتش': u'وَاحْتَشَّ', #1
u'واحتشاش': u'وَاحْتِشَاشٍ', #14
u'واحتشاشه': u'وَاحْتِشَاشِهِ', #2
u'واحتشاشهما': u'وَاحْتِشَاشَهُمَا', #1
u'واحتشت': u'وَاحْتَشَتْ', #1
u'واحتصد': u'وَاحْتَصِدْ', #1
u'واحتضننى': u'وَاحْتَضَنَنِى', #1
u'واحتفر': u'وَاحْتَفَرَ', #6
u'واحتفرت': u'وَاحْتَفَرَتْ', #1
u'واحتفره': u'وَاحْتَفَرَهُ', #1
u'واحتواشا': u'وَاحْتِوَاشًا', #1
u'واحتوش': u'وَاحْتَوَشَ', #3
u'واحتياز': u'وَاحْتِيَازُ', #1
u'وإحثاء': u'وَإِحْثَاءُ', #1
u'وإحجاج': u'وَإِحْجَاجٍ', #1
u'وإحجاج': u'وَإِحْجَاجُ', #4
u'وإحجاجه': u'وَإِحْجَاجُهُ', #3
u'وإحجاجها': u'وَإِحْجَاجُهَا', #1
u'وإحجاجها': u'وَإِحْجَاجِهَا', #2
u'وأحججته': u'وَأَحْجَجْتُهُ', #1
u'وأحجوا': u'وَأَحْجُوا', #1
u'واحد': u'وَاحِدً', #10
u'واحداتها': u'وَاحِدَاتُهَا', #1
u'وإحداد': u'وَإِحْدَادٌ', #1
u'وإحداد': u'وَإِحْدَادُ', #4
u'وإحداده': u'وَإِحْدَادِهِ', #2
u'وإحداده': u'وَإِحْدَادُهُ', #5
u'وإحدادهن': u'وَإِحْدَادِهِنَّ', #1
u'وإحدارها': u'وَإِحْدَارُهَا', #1
u'واحدةففيها': u'وَاحِدَةًُُُُفَفِيهَا', #1
u'واحدى': u'وَاحِدِى', #1
u'وأحذاهم': u'وَأَحْذَاهُمْ', #1
u'وإحرارها': u'وَإِحْرَارهَا', #1
u'وأحرقنى': u'وَأَحْرَقَنِى', #2
u'وأحرموه': u'وَأَحْرَمُوهُ', #1
u'وأحرمى': u'وَأَحْرِمِى', #2
u'وأحزننى': u'وَأَحْزَنَنِى', #1
u'واحزنى': u'وَاحَزَنَى', #1
u'وأحسبني': u'وَأَحْسِبُنِي', #1
u'وأحسبنى': u'وَأَحْسِبُنِى', #2
u'وأحسبني': u'وَأَحْسَبُنِي', #4
u'واحسرتاه': u'وَاحَسْرَتَاه', #1
u'وأحسنى': u'وَأَحْسِنِى', #3
u'واحسيناه': u'وَاحُسَيْنَاه', #1
u'وإحشافها': u'وَإِحْشَافُهَا', #1
u'وإحشافها': u'وَإِحْشَافِهَا', #1
u'وأحشت': u'وَأُحِشّتْ', #1
u'واحشرنى': u'وَاحْشُرْنِى', #2
u'وأحشمته': u'وَأَحْشَمْته', #1
u'وأحشمته': u'وَأَحْشَمْتُهُ', #3
u'وإحصار': u'وَإِحْصَارٍ', #9
u'وإحصارها': u'وَإِحْصَارِهَا', #1
u'واحصان': u'وَاحَصَانٍ', #1
u'وأحصرت': u'وَأُحْصِرْتُ', #1
u'وأحصرني': u'وَأَحْصَرَنِي', #2
u'وإحضان': u'وَإِحْضَانُ', #2
u'وأحظل': u'وَأَحْظَلَ', #1
u'وإحفاء': u'وَإِحْفَاءُ', #2
u'وأحفد': u'وَأَحْفَدَ', #6
u'وأحفوا': u'وَأَحْفُوا', #5
u'واحلولقوا،': u'وَاحْلَوْلِقُوا،', #1
u'وأحمش': u'وَأَحْمَش', #1
u'وأحمش': u'وَأَحْمَشُ', #1
u'وأحمشته': u'وَأَحْمَشْتُهُ', #1
u'وأحنثت': u'وَأَحْنَثَتْ', #1
u'وأحنثته': u'وَأَحْنَثَتْهُ', #1
u'وأحنقوا': u'وَأُحْنِقُوا', #2
u'وأحوطيته': u'وَأَحْوَطِيَّتُهُ', #1
u'وأحى': u'وَأَحْىِ', #1
u'وأحيحة': u'وَأُحَيْحَةُ', #3
u'وأحينى': u'وَأَحْيِنِى', #1
u'وأحيى': u'وَأَحْيَى', #1
u'واخ': u'وَاخٍ', #1
u'وأخاشبها': u'وَأَخَاشِبِهَا', #1
u'واخاك': u'واخاك', #2
u'وإخال': u'وَإِخَالُ', #2
u'وأخاميس': u'وَأخَامِيسُ', #1
u'واخاه': u'وَاخَاهُ', #1
u'وأخباز': u'وَأَخْبَازٍ', #2
u'وأخبرانيه': u'وَأَخْبَرَانِيهِ', #1
u'وأخبرتنى': u'وَأَخْبَرَتْنِى', #3
u'وأخبرناأبو': u'وَأَخْبَرَنَاأَبُو', #1
u'وأخبرنى': u'وأخبرنى', #1
u'وأخبرنى': u'وَأَخْبَرَنِى', #220
u'وأخبرنيه': u'وَأَخْبَرَنِيهِ', #10
u'وأختاى': u'وَأُخْتَاىَ', #1
u'واختبط': u'وَاخْتَبَطَ', #1
u'واختداع': u'وَاخْتِدَاعٌ', #1
u'واختدامهم': u'وَاخْتِدَامَهُمْ', #1
u'واخترط': u'وَاخْتَرَطَ', #2
u'واخترمته': u'وَاخْتَرَمَتْهُ', #2
u'واختشى': u'وَاخْتَشَى', #1
u'واختصاؤه': u'وَاخْتِصَاؤُهُ', #1
u'واختصمه': u'وَاخْتَصَمَهُ', #1
u'واختصيت': u'وَاخْتَصَيْت', #1
u'واختفضت': u'وَاخْتَفَضَتْ', #1
u'واختك': u'واختك', #2
u'واختلاع': u'وَاخْتِلَاعٍ', #1
u'واختلاع': u'وَاخْتِلَاعُ', #1
u'واختلاع': u'وَاخْتِلَاعِ', #2
u'واختلاعها': u'وَاخْتِلَاعُهَا', #1
u'واختلعت': u'وَاخْتَلَعْتُ', #2
u'واختلعت': u'وَاخْتَلَعَتْ', #9
u'واختلفوه': u'وَاخْتَلَفُوهُ', #1
u'واختناث': u'وَاخْتِنَاثَ', #1
u'واختناث': u'وَاخْتِنَاثُ', #1
u'واختناث': u'وَاخْتِنَاثِ', #1
u'واختناثها': u'وَاخْتِنَاثُهَا', #3
u'واختنثته': u'وَاخْتَنَثْتُهُ', #1
u'وأختى': u'وَأُخْتِى', #2
u'واختيارى': u'وَاخْتِيَارِى', #1
u'وإخدام': u'وَإِخْدَامٍ', #2
u'وإخدام': u'وَإِخْدَامُ', #6
u'وإخدام': u'وَإِخْدَامِ', #9
u'وإخداما': u'وَإِخْدَامًا', #3
u'وإخدامه': u'وَإِخْدَامُهُ', #2
u'وإخدامه': u'وَإِخْدَامِهِ', #5
u'وإخدامها': u'وَإِخْدَامُهَا', #1
u'وأخدجت': u'وَأَخْدَجَتْ', #2
u'وأخدمتك': u'وَأَخْدَمْتُكَ', #1
u'وأخدمتك': u'وَأَخْدَمْتُك', #11
u'وأخدموه': u'وَأَخْدَمُوهُ', #2
u'وآخذبه': u'وَآخُذُبِهِ', #1
u'وأخذتنى': u'وَأَخَذَتْنِى', #1
u'وأخذعلى': u'وأخذعَلِىِّ', #1
u'واخذه': u'وَاخَذَهُ', #3
u'وأخذو': u'وَأَخْذُو', #3
u'وإخراب': u'وَإِخْرَابُ', #1
u'وإخراب': u'وَإِخْرَابِ', #1
u'وإخرابه': u'وَإِخْرَابِهِ', #2
u'واخراج': u'وَاخَرَاجُ', #1
u'وإخراق': u'وَإِخْرَاقِ', #1
u'وآخرتى': u'وَآخِرَتِى', #2
u'وأخرجنى': u'وَأَخْرِجْنِى', #1
u'وأخرقته': u'وَأَخْرَقْتُهُ', #1
u'وأخرين': u'وَأَخِرِينَ', #1
u'وأخزة': u'وَأَخِزَّةٌ', #1
u'وأخسئ': u'وَأَخْسِئْ', #2
u'وأخشانا': u'وأخشانا', #1
u'واخشوشبوا': u'وَاخْشَوْشِبُوا', #1
u'واخشون': u'وَاخْشَوْنِ', #12
u'وإخصاء': u'وَإِخْصَاءَ', #1
u'وإخصاء': u'وَإِخْصَاءِ', #2
u'وإخصاء': u'وَإِخْصَاءُ', #3
u'وأخصائه': u'وَأَخِصَّائِهِ', #2
u'وإخصائها': u'وَإِخْصَائِهَا', #1
u'وأخصية': u'وَأَخَصِّيَّةِ', #1
u'وأخصية': u'وَأَخَصِّيَّةٌ', #2
u'وأخضل': u'وَأَخْضَلَ', #1
u'وأخطأوا،': u'وَأَخْطَأُوا،', #1
u'وأخطيت': u'وَأَخْطَيْت', #1
u'وإخفات': u'وإخفات', #1
u'وإخفات': u'وَإِخْفَاتٌ', #1
u'وإخفات': u'وَإِخْفَاتٍ', #5
u'وإخفار': u'وَإِخْفَارِ', #1
u'وإخفاره': u'وَإِخْفَارِهِ', #1
u'وإخفاره': u'وَإِخْفَارُهُ', #2
u'وإخفاض': u'وَإِخْفَاضَ', #1
u'وأخفرته': u'وَأَخْفَرْتُهُ', #1
u'وأخفروا': u'وَأَخْفَرُوا', #1
u'وإخلاط': u'وَإِخْلَاطُ', #1
u'وإخلاقا': u'وَإِخْلَاقًا', #1
u'وأخلقت': u'وَأَخْلَقْت', #1
u'وأخلقت': u'وَأَخْلَقْتُ', #1
u'وأخلقته': u'وَأَخْلَقْتُهُ', #2
u'واخليلاه': u'واخليلاه', #1
u'واخليلاه': u'وَاخَلِيلاهُ', #1
u'واخليلاه،': u'وَاخَلِيلَاهُ،', #1
u'وإخمال': u'وَإِخْمَالِ', #2
u'وأخميمية': u'وأخميمية', #1
u'وأخنثته': u'وَأَخْنَثْتُهُ', #1
u'وإخوانى': u'وَإِخْوَانِى', #1
u'وأخى': u'وَأُخَىَّ', #1
u'واخى': u'وَاخَى', #1
u'وأخى': u'وَأَخِى', #6
u'وأخيضر': u'وَأُخَيْضِرُ', #1
u'وأداخ': u'وأَدَاخ', #1
u'وأداخ': u'وَأَدَاخَ', #1
u'وإدبارى': u'وَإِدْبَارِى', #2
u'وادجوجى': u'وَادْجَوْجَى', #1
u'وادخال': u'وَادِخَالِ', #1
u'وأدخلتنى': u'وَأَدْخَلَتْنِى', #1
u'وأدخلى': u'وَأَدْخِلِى', #1
u'وادخلى': u'وَادْخُلِى', #1
u'وادرءوا': u'وَادْرَءُوا', #10
u'وادرءوهم': u'وَادْرَءُوهُمْ', #1
u'وأدراع': u'وَأَدْرَاعٌ', #1
u'وأدراعا': u'وَأَدْرَاعًا', #2
u'وأدربوا': u'وَأَدْرَبُوا', #1
u'وأدرد': u'وَأَدْرَدُ', #2
u'وأدرده': u'وَأَدْرَدَهُ', #1
u'وآدرهم': u'وَآدُرُهُمْ', #1
u'وادعنى': u'وَادَعَنِى', #1
u'وأدفر': u'وَأَدْفَرَ', #1
u'وادفراه': u'وَادَفْرَاهُ', #1
u'وادفراه،': u'وَادَفْرَاهُ،', #1
u'وادفنونى': u'وادفنونى', #1
u'وادق': u'وَادِقُ', #1
u'وادقا': u'وَادِقًا', #1
u'وادكر': u'وَادَّكَرَ', #9
u'وإدلا': u'وَإِدْلَا', #1
u'وإدلاله': u'وَإِدْلَالِهِ', #1
u'وإدلالها': u'وَإِدْلَالِهَا', #1
u'وأدلية': u'وَأَدْلِيَةٍ', #3
u'وإدناف': u'وَإِدْنَافٌ', #1
u'وأدنفه': u'وَأَدْنَفَهُ', #2
u'وإدهان': u'وَإِدْهَانٌ', #2
u'وإدهان': u'وَإِدْهَانٍ', #2
u'وإدهانه': u'وَإِدْهَانِهِ', #1
u'وادهانه': u'وَادِّهَانُهُ', #1
u'وادهانه': u'وَادِّهَانِهِ', #1
u'وأدهنوا': u'وَأَدْهِنُوا', #1
u'وادى': u'وَادِى', #21
u'وادى': u'وَادِىَ', #9
u'واديح': u'واديح', #1
u'واذا': u'وَاذَا', #102
u'وأذاخر': u'وَأَذَاخِرُ', #1
u'وإذاصلاها': u'وَإِذَاصَلَّاهَا', #1
u'وإذاية': u'وَإِذَايَةِ', #1
u'وإذاية': u'وَإِذَايَةً', #2
u'وإذاية': u'وَإِذَايَةٌ', #2
u'وإذاية': u'وَإِذَايَةُ', #3
u'وإذايته': u'وإذايته', #1
u'وإذايته': u'وَإِذَايَتِهِ', #3
u'وإذايتهم': u'وَإِذَايَتُهُمْ', #1
u'وإذايتهم': u'وَإِذَايَتِهِمْ', #1
u'وأذبة': u'وَأَذِبَّةٍ', #1
u'وأذبة': u'وَأَذِبَّةٌ', #3
u'وإذخر': u'وَإِذْخِرٌ', #1
u'وإذخر': u'وَإِذْخِرٍ', #4
u'وأذرعات،': u'وَأَذْرِعَاتِ،', #1
u'وأذرعات': u'وَأَذْرِعَاتُ', #2
u'وأذرعتهم': u'وَأَذْرِعَتِهِمْ', #2
u'واذرونى': u'وَاذْرُونِى', #1
u'وأذريت': u'وَأَذْرَيْتُ', #2
u'وإذكار': u'وَإِذْكَارٍ', #1
u'وإذكارا': u'وَإِذْكَارًا', #1
u'وإذكاره': u'وَإِذْكَارَهُ', #1
u'وأذكرني': u'وَأَذْكَرَنِي', #1
u'واذناه': u'وَاذُنَاه', #1
u'واذهبى': u'وَاذْهَبِى', #1
u'وأذواب': u'وَأَذْوَابٌ', #1
u'وآذواست': u'وآذواست', #1
u'وإراءة': u'وَإِرَاءَةِ', #1
u'وإراءة': u'وَإِرَاءَةُ', #2
u'وإراءته': u'وَإِرَاءَتِهِ', #1
u'وإراءته': u'وَإِرَاءَتُهُ', #2
u'وإراءتها': u'وَإِرَاءَتِهَا', #1
u'وأرآد': u'وَأَرْآدٍ', #1
u'وإراشة': u'وَإِرَاشَةَ', #1
u'وإراشة': u'وَإِرَاشَةُ', #1
u'وأراميض': u'وَأَرَامِيضُ', #3
u'وأرانى': u'وَأُرَانِى', #1
u'وأرانى': u'وَأَرَانِى', #2
u'وأرانيه': u'وَأَرَانِيهِ', #1
u'وأراهط': u'وَأَرَاهِطُ', #5
u'وأراهيط': u'وَأَرَاهِيطُ', #5
u'وأرأيتك': u'وَأَرَأَيْتُكَ', #1
u'وأرأيتكم': u'وَأَرَأَيْتُكُمْ', #1
u'وأربان': u'وَأُرْبَانٌ', #1
u'وإربة': u'وَإِرْبَةٌ', #1
u'وإربد': u'وإربد', #1
u'وأربعت': u'وَأَرْبَعَتْ', #1
u'واربعين': u'وَارْبَعِينِ', #2
u'واربندن': u'واربندن', #1
u'واربيب': u'وَارَبِيبَ', #1
u'وارة،': u'وارة،', #1
u'وارة': u'وَارَةَ', #13
u'وارة': u'وارة', #2
u'وارة،': u'وَارَةَ،', #5
u'وارتث': u'وارْتُثَّ', #1
u'وارتث': u'وَارْتَثَّ', #1
u'وارتث': u'وَارْتُثَّ', #3
u'وارتث': u'وَارْتُثّ', #5
u'وارتثاث': u'وَارْتِثَاثُ', #1
u'وأرتجز،': u'وَأَرْتَجِزُ،', #1
u'وارتجز': u'وَارْتَجَزَ', #3
u'وأرتجز': u'وَأَرْتَجِزُ', #7
u'وارتجزوا': u'وَارْتَجَزُوا', #2
u'وارتجع': u'وَارْتَجِعْ', #1
u'وارتجع': u'وَارْتَجَعَ', #18
u'وارتجعت': u'وَارْتَجَعْت', #1
u'وارتجعت': u'وَارْتَجَعْتُ', #1
u'وارتجعتك': u'وَارْتَجَعَتْك', #1
u'وارتجعتك': u'وَارْتَجَعْتُكِ', #3
u'وارتجعتك': u'وَارْتَجَعْتُك', #7
u'وارتجعتها': u'وَارْتَجَعْتهَا', #2
u'وارتجعتها': u'وَارْتَجَعْتُهَا', #4
u'وارتجعه': u'وَارْتَجَعَهُ', #3
u'وأرتجعها': u'وَأَرْتَجِعُهَا', #1
u'وارتجعها': u'وَارْتَجَعَهَا', #3
u'وارتجعهما': u'وَارْتَجِعْهُمَا', #1
u'وارتداف': u'وَارْتِدَافِ', #5
u'وارتضاعها': u'وَارْتِضَاعُهَا', #1
u'وارتضاعها': u'وَارْتِضَاعِهَا', #1
u'وارتضخ': u'وَارْتَضِخْ', #1
u'وارتضع': u'وَارْتَضَعَ', #6
u'وارتضعت': u'وَارْتُضِعَتْ', #1
u'وارتضعت': u'وَارْتَضَعَتْ', #8
u'وارتغب': u'وَارْتَغَبَ', #1
u'وارتفاق': u'وَارْتِفَاقٍ', #1
u'وارتفاق': u'وَارْتِفَاقُ', #3
u'وارتفاق': u'وَارْتِفَاقٌ', #7
u'وارتفاقا': u'وَارْتِفَاقًا', #1
u'وارتفض': u'وَارْتُفِضَ', #1
u'وارتفض': u'وَارْتَفَضَ', #3
u'وارتكمت': u'وارْتَكَمَتْ', #1
u'وارتهست': u'وَارْتَهَسَتْ', #1
u'وارتهشت': u'وارْتَهَشَتْ', #1
u'وارتهنته': u'وَارْتَهَنْته', #2
u'وارتهنه': u'وَارْتَهَنَهُ', #1
u'وارتياض': u'وَارْتِيَاضٌ', #1
u'وارتياض': u'وَارْتِيَاضٍ', #1
u'وارجاع': u'وَارِجَاعُ', #1
u'وارجعى': u'وَارْجِعِى', #2
u'وارجمونى': u'وَارْجُمُونِى', #1
u'وأرجيت': u'وَأَرْجَيْت', #1
u'وأرحبية': u'وَأَرْحَبِيَّةٌ', #1
u'وأرحبية': u'وَأَرْحَبِيَّةٍ', #3
u'وارحمنى': u'وَارْحَمْنِى', #12
u'وأرخصتم': u'وَأَرْخَصْتُمْ', #1
u'وإردب': u'وَإِرْدَبٍّ', #3
u'وإردب': u'وَإِرْدَبَّ', #3
u'وإردب': u'وَإِرْدَبِّ', #5
u'وإردبها': u'وَإِرْدَبَّهَا', #1
u'وإردبي': u'وَإِرْدَبَّيْ', #2
u'وأردبيل': u'وَأَرْدَبِيلُ', #1
u'وإرذالا': u'وَإِرْذَالًا', #1
u'وارر': u'وارر', #1
u'وإرزامها': u'وَإِرْزَامُهَا', #1
u'وارزقنى': u'وَارْزُقْنِى', #9
u'وارزقنيه': u'وَارْزُقْنِيهِ', #2
u'وارزقون': u'وَارْزُقُونِ', #1
u'وأرزمت': u'وَأَرْزَمْت', #1
u'وارسال': u'وَارِسَالِ', #2
u'وإرسالة': u'وَإِرْسَالَةٍ', #1
u'وأرسلنى': u'وَأَرْسَلَنِى', #1
u'وأرشا': u'وَأَرْشًا', #3
u'وأرضيهمو': u'وَأُرْضِيهُمُو', #1
u'وأرطا': u'وَأَرْطَا', #1
u'وأرطاة': u'وَأَرْطَاةُ', #4
u'وأرطى': u'وَأَرْطًى', #1
u'وأرطى': u'وَأَرْطَى', #15
u'وارعهموا': u'وَارْعَهُمُوا', #1
u'وإرفاء': u'وَإِرْفَاءً', #1
u'وأرفخشذ': u'وأرفخشذ', #1
u'وارفعنى': u'وَارْفَعْنِى', #4
u'وأرقأ': u'وَأَرْقَأَ', #1
u'وارقأ': u'وَارْقَأْ', #4
u'وإرقابه': u'وَإِرْقَابُهُ', #1
u'وإرقاق': u'وَإِرْقَاقٌ', #1
u'وإرقاق': u'وَإِرْقَاقٍ', #1
u'وإرقاق': u'وَإِرْقَاقُ', #1
u'وإرقاق': u'وَإِرْقَاقِ', #2
u'وإرقاقه': u'وَإِرْقَاقُهُ', #3
u'وإرقاقها': u'وَإِرْقَاقِهَا', #1
u'وإرقاقهم': u'وَإِرْقَاقُهُمْ', #2
u'وأرقبتك': u'وَأَرْقَبْتُك', #2
u'وأرقبتك': u'وَأَرْقَبْتُكَ', #3
u'وأرقبته': u'وَأَرْقَبْته', #1
u'وأرقلوا': u'وَأَرْقَلُوا', #1
u'وأرقنى': u'وَأَرَّقَنِى', #1
u'واركار': u'واركار', #1
u'واركناه': u'وَارُكْنَاه', #1
u'وأركيس': u'وأركيس', #1
u'وارمسونى': u'وَارْمِسُونِى', #1
u'وأرمص': u'وَأَرْمَصُ', #1
u'وأرمضة': u'وَأَرْمِضَةٌ', #3
u'وأرمضك': u'وَأَرْمَضَكَ', #1
u'وأرمضه': u'وَأَرْمَضَهُ', #1
u'وأرملوا': u'وَأَرْمَلُوا', #1
u'وارمى': u'وَارْمِى', #1
u'وإرمينية': u'وَإِرْمِينْيَةُ', #1
u'وارنج': u'وارنج', #2
u'وأرهنت': u'وَأَرْهَنْت', #1
u'وأرهنته': u'وَأَرْهَنْتُهُ', #6
u'وأرهنتهم': u'وَأَرْهَنْتَهُمْ', #1
u'وأرهنتهم': u'وَأَرْهَنْتُهُمْ', #1
u'واروب': u'واروب', #1
u'واروب': u'وَارَوْب', #1
u'وأروحت': u'وَأَرْوَحَتْ', #1
u'وأروزا': u'وَأُرُوزًا', #1
u'وارئى': u'وارئى', #1
u'وأرىإسماعيل': u'وَأَرَىإسْمَاعِيلَ', #1
u'وأريحاء': u'وَأَرْيِحَاءَ', #3
u'وأريحاء': u'وَأَرِيحَاءَ', #6
u'وإزاد': u'وَإِزَادُ', #1
u'وازاد': u'وازاد', #2
u'وآزادو': u'وآزادو', #1
u'وازاز': u'وازاز', #1
u'وازان': u'وازان', #1
u'وأزانه': u'وَأَزَانَهُ', #1
u'وأزبأرت': u'وَأَزْبَأَرَّتْ', #1
u'وازتواين': u'وازتواين', #1
u'وازتويا': u'وازتويا', #1
u'وازحد': u'وازحد', #1
u'وازدراع': u'وَازْدِرَاعِ', #2
u'وازدرع': u'وَازْدَرَعَ', #3
u'وازدلف': u'وَازْدَلَفَ', #4
u'وازدهاه': u'وَازْدَهَاهُ', #1
u'وأزرة': u'وَأَزْرَةٌ', #2
u'وإزرة': u'وَإِزْرَةُ', #2
u'وأزرة': u'وَأُزْرَةٌ', #5
u'وازرره': u'وَازْرُرْهُ', #4
u'وأزرعوها': u'وَأَزْرِعُوهَا', #1
u'وأزرمه': u'وَأَزْرَمَهُ', #2
u'وازشهرت': u'وازشهرت', #1
u'وأزعب': u'وَأَزْعَبُ', #1
u'وازفرتي': u'وَازَفْرَتِي', #1
u'وازمال': u'وازمال', #1
u'وازهأر': u'وَازْهَأَرّ', #1
u'وأزوجكها': u'وَأُزَوِّجُكهَا', #1
u'وأزوجكها': u'وَأُزَوِّجُكَهَا', #1
u'وازودوا': u'وَازَّوِّدُوا', #1
u'وازوى': u'وازوى', #2
u'وأزيب': u'وَأَزْيَبُ', #1
u'وأزيبة': u'وَأَزْيَبَةُ', #1
u'وازينت': u'وَازَّيَّنَتْ', #3
u'وأساءوا': u'وَأَسَاءُوا', #14
u'وأساب': u'وَأَسَابَ', #1
u'وأساتذ': u'وأَسَاتِذٍ', #1
u'وإسادة': u'وَإِسَادَةٍ', #1
u'وأساراهم': u'وَأُسَارَاهُمْ', #1
u'وإساف': u'وَإِسَافٌ', #1
u'وإساف': u'وَإِسَافٍ', #1
u'وإساف': u'وَإِسَافَ', #1
u'وإساف': u'وَإِسَافُ', #2
u'وأسامة': u'وَأُسَامَةِ', #1
u'وإسامة': u'وَإِسَامَةِ', #1
u'وأسامة': u'وَأُسَامَةَ', #113
u'وأسامة': u'وَأُسَامَةُ', #155
u'وأسامة': u'وَأُسَامَة', #2
u'وإسامة': u'وَإِسَامَةُ', #2
u'وأسامة': u'وأسامة', #3
u'وأسامة،': u'وَأُسَامَةُ،', #5
u'وأسباعافي': u'وَأَسْبَاعًافِي', #1
u'واسباهية': u'وَاِسْبَاهِيَّةٌ', #1
u'واسبطرت': u'وَاسْبَطَرَّتْ', #1
u'واسبنديار': u'وَاسْبِنْدِيَارَ', #1
u'واسبنديار': u'واسبنديار', #2
u'واستأجل': u'وَاسْتَأْجَلَ', #1
u'واستاد': u'وَاسْتَادَ', #1
u'واستأدى': u'وَاسْتَأَدَّى', #1
u'وأستاذونا': u'وَأُسْتَاذُونَا', #2
u'واستأسر': u'وَاسْتَأْسَرَ', #5
u'واستأسروا': u'وَاسْتَأْسَرُوا', #1
u'واستاق': u'وَاسْتَاقَ', #2
u'واستاقوا': u'واستاقوا', #2
u'واستاقوا': u'وَاسْتَاقُوا', #46
u'واستاقوها': u'وَاسْتَاقُوهَا', #2
u'واستأكلوا': u'وَاسْتَأْكَلُوا', #1
u'واستام': u'وَاسْتَامَ', #1
u'واستأمن': u'وَاسْتَأْمَنَ', #5
u'واستأمنا،': u'وَاسْتَأْمَنَا،', #1
u'واستأمناه': u'وَاسْتَأْمَنَاهُ', #1
u'واستأمنتك': u'وَاسْتَأْمَنْتُك', #1
u'واستأمنه': u'وَاسْتَأْمَنَهُ', #1
u'واستأمنوا': u'وَاسْتَأْمَنُوا', #1
u'واستأمنوهم': u'وَاسْتَأْمَنُوهُمْ', #1
u'واستأنسوها': u'وَاسْتَأْنَسُوهَا', #1
u'واستأنهم،': u'وَاسْتَأَنِّهِمْ،', #1
u'وأستأني': u'وَأَسْتَأْنِي', #1
u'واستأنى': u'وَاسْتَأْنَى', #1
u'وإستاها': u'وَإِسْتَاهَا', #1
u'وأستاههم،': u'وَأَسْتَاهَهُمْ،', #1
u'واستبا،': u'واستبا،', #1
u'واستبحر': u'وَاسْتَبْحَرَ', #4
u'واستبذل': u'وَاسْتَبْذَلَ', #1
u'واستبر': u'وَاسْتَبْرِ', #3
u'واستبرقي': u'واستبرقي', #1
u'واستبري': u'وَاسْتَبِرِي', #1
u'واستبري': u'وَاسْتَبْرِي', #4
u'واستبغى': u'وَاسْتَبْغَى', #1
u'واستبكى': u'وَاسْتَبْكَى', #1
u'واستبلغ': u'وَاسْتَبْلَغَ', #1
u'واستبوا': u'وَاسْتَبُّوا', #1
u'واستبى': u'واستبى', #1
u'واستتاب': u'وَاسْتَتَابَ', #1
u'واستتابته': u'وَاسْتِتَابَتُهُ', #1
u'واستتابته': u'وَاسْتِتَابَتِهِ', #6
u'واستتابتهم': u'وَاسْتِتَابَتُهُمْ', #2
u'واستتابه': u'وَاسْتَتَابَهُ', #1
u'واستتابهم': u'وَاسْتَتَابَهُمْ', #1
u'واستتبتك': u'وَاسْتَتَبْتُك', #1
u'واستتبتموه': u'وَاسْتَتَبْتُمُوهُ', #6
u'واستتبنا': u'وَاسْتَتَبْنَا', #4
u'واستتبهم': u'وَاسْتَتِبْهُمْ', #1
u'واستترك': u'وَاسْتَتْرَكَ', #1
u'واستتم': u'وَاسْتُتِمَّ', #1
u'واستتم': u'وَاسْتَتَمَّ', #2
u'واستتمام': u'وَاسْتِتْمَام', #1
u'واستتمامه': u'وَاسْتِتْمَامُهُ', #1
u'واستتيب': u'وَاسْتُتِيبَ', #28
u'واستتيبت': u'وَاسْتُتِيبَتْ', #3
u'واستثبات': u'وَاسْتِثْبَاتٌ', #1
u'واستثبات': u'وَاسْتِثْبَاتُ', #1
u'واستثباتها': u'وَاسْتِثْبَاتِهَا', #1
u'واستثفار': u'وَاسْتِثْفَارٍ', #1
u'واستثفارا': u'وَاسْتِثْفَارًا', #1
u'واستثفرت': u'وَاسْتَثْفَرَتْ', #1
u'واستثفري': u'وَاسْتَثْفِري', #1
u'واستثفرى': u'وَاسْتَثْفِرِى', #1
u'واستثفري': u'وَاسْتَثْفِرِي', #14
u'واستثنا': u'وَاسْتَثْنَا', #1
u'واستجادته': u'وَاسْتِجَادَتِهِ', #2
u'واستجاده': u'وَاسْتَجَادَهُ', #1
u'واستجازته': u'وَاسْتِجَازَتُهُ', #1
u'واستجازتها': u'وَاسْتِجَازَتِهَا', #1
u'واستجاشوا': u'وَاسْتَجَاشُوا', #1
u'واستجراء': u'وَاسْتِجْرَاءً', #2
u'واستجريت': u'وَاسْتَجْرَيْتُ', #1
u'واستجسوا': u'وَاسْتَجْسُوا', #1
u'واستجلاد': u'وَاسْتِجْلادَ', #1
u'واستجلاد': u'وَاسْتِجْلَادِ', #2
u'واستجمار': u'وَاسْتِجْمَارٌ', #1
u'واستجمار': u'وَاسْتِجْمَارٍ', #2
u'واستجمارا': u'وَاسْتِجْمَارًا', #1
u'واستجماره': u'وَاسْتِجْمَارُهُ', #1
u'وأستجمر': u'وَأَسْتَجْمِرُ', #1
u'واستجمر،': u'وَاسْتَجْمَرَ،', #1
u'واستجمر': u'وَاسْتَجْمَرَ', #9
u'واستجن': u'وَاسْتُجِنَّ', #1
u'واستجوده': u'وَاسْتَجْوَدَهُ', #1
u'واستح': u'وَاسْتَحِ', #1
u'واستحار': u'وَاسْتَحَارَ', #1
u'واستحاضة': u'وَاسْتِحَاضَةٌ', #12
u'واستحاضة': u'وَاسْتِحَاضَةً', #2
u'واستحاضة': u'وَاسْتِحَاضَةٍ', #32
u'واستحاضتها': u'وَاسْتِحَاضَتَهَا', #1
u'واستحبابيته': u'واستحبابيته', #1
u'واستحد': u'وَاسْتَحَدَّ', #1
u'واستحداد': u'وَاسْتِحْدَادٌ', #1
u'واستحداد': u'وَاسْتِحْدَادٍ', #6
u'واستحداده': u'وَاسْتِحْدَادُهُ', #1
u'واستحداده': u'وَاسْتِحْدَادِهِ', #1
u'واستحدادها': u'وَاسْتِحْدَادِهَا', #1
u'واستحدادها': u'وَاسْتِحْدَادُهَا', #2
u'واستحر': u'واستحر', #1
u'واستحر': u'وَاسْتَحَرَّ', #2
u'واستحر': u'وَاسْتَحَرّ', #5
u'واستحروهم': u'وَاسْتَحَرُّوهُمْ', #1
u'واستحشاف': u'وَاسْتِحْشَافٍ', #9
u'واستحصن': u'وَاسْتَحْصَنَ', #1
u'وإستحقوا': u'وإستحقوا', #1
u'واستحكر': u'وَاسْتَحْكَرَ', #2
u'وإستحلال': u'وإستحلال', #1
u'واستحلب': u'وَاسْتَحْلَبَ', #1
u'واستحلبي': u'وَاسْتَحْلِبِي', #2
u'واستحلسنا': u'وَاسْتَحْلَسْنَا', #2
u'واستحمدوا': u'وَاسْتَحْمَدُوا', #2
u'واستحمدوا': u'وَاسْتُحْمِدُوا', #2
u'واستحمق': u'وَاسْتُحْمِقَ', #1
u'واستحمق': u'وَاسْتَحْمَقَ', #16
u'واستحمق؟': u'وَاسْتَحْمَقَ؟', #3
u'واستحمقت': u'وَاسْتَحْمَقْت', #1
u'واستحمقت': u'وَاسْتَحْمَقْتُ', #6
u'واستحمقته': u'وَاسْتَحْمَقْته', #2
u'واستحى': u'وَاسْتَحَى', #2
u'واستحيت': u'وَاسْتَحَيْتُ', #1
u'واستحيت': u'وَاسْتَحْيَتْ', #4
u'واستحيضت': u'وَاسْتُحِيضَتْ', #9
u'واستحيى': u'وَاسْتَحْيَى', #1
u'واستخار': u'وَاسْتَخَارَ', #1
u'واستخبأ': u'وَاسْتَخْبَأَ', #1
u'واستخباث': u'وَاسْتِخْبَاثِ', #1
u'واستخباثه': u'وَاسْتِخْبَاثِهِ', #1
u'واستخبثت': u'وَاسْتَخْبَثْتُ', #1
u'واستخبثه': u'وَاسْتَخْبَثَهُ', #3
u'واستخرت': u'وَاسْتَخَرْت', #1
u'واستخرت': u'وَاسْتَخَرْتُ', #1
u'واستخرته': u'وَاسْتَخَرْته', #2
u'واستخرطا': u'وَاسْتَخْرِطَا', #2
u'واستخرطي': u'وَاسْتَخْرِطِي', #2
u'واستخشنت': u'وَاسْتَخْشَنَتْ', #1
u'واستدت': u'وَاسْتَدَّتْ', #3
u'واستدخال': u'وَاسْتِدْخَالُ', #10
u'واستدخال': u'وَاسْتِدْخَالِ', #10
u'واستدخال': u'وَاسْتِدْخَالٌ', #2
u'واستدخاله': u'وَاسْتِدْخَالِهِ', #5
u'واستدخالها': u'وَاسْتِدْخَالُهَا', #5
u'واستدخل': u'وَاسْتَدْخَلَ', #1
u'واستدخلت': u'وَاسْتَدْخَلَتْ', #1
u'واستدخلته': u'وَاسْتَدْخَلَتْهُ', #12
u'واستدخله': u'وَاسْتَدْخَلَهُ', #1
u'واستدماج': u'وَاسْتِدْمَاجِ', #1
u'واستذفر': u'وَاسْتَذْفَرَ', #1
u'واستذفرى': u'وَاسْتَذْفِرِى', #2
u'واستذل': u'وَاسْتَذَلَّ', #3
u'واستذلالهم': u'وَاسْتِذْلالِهِمُ', #1
u'واستراب': u'وَاسْتَرَابَ', #1
u'واسترابه': u'وَاسْتَرَابَهُ', #1
u'واستراش': u'وَاسْتَرَاشَ', #1
u'واسترباحها': u'وَاسْتِرْبَاحِهَا', #1
u'واستربح': u'وَاسْتَرْبِحْ', #1
u'وأسترة': u'وَأَسْتِرَةُ', #1
u'واسترحام': u'وَاسْتِرْحَامٌ', #1
u'واسترحمك': u'وَاسْتَرْحَمَكَ', #1
u'واسترحموا': u'وَاسْتُرْحِمُوا', #3
u'واسترذالا': u'وَاسْتِرْذَالًا', #1
u'واسترذالهم': u'وَاسْتِرْذَالِهِمْ', #1
u'واسترذل': u'وَاسْتُرْذِلَ', #1
u'واسترذله': u'وَاسْتَرْذَلَهُ', #1
u'واسترذلوا': u'وَاسْتَرْذَلُوا', #1
u'واسترشى': u'وَاسْتَرْشَى', #1
u'واسترفاد': u'وَاسْتِرْفَاد', #1
u'واسترفاقه': u'وَاسْتِرْفَاقِهِ', #1
u'واسترقاق': u'وَاسْتِرْقَاقَ', #1
u'واسترقاق': u'وَاسْتِرْقَاقٍ', #12
u'واسترقاق': u'وَاسْتِرْقَاقُ', #4
u'واسترقاق': u'وَاسْتِرْقَاقِ', #4
u'واسترقاقا': u'وَاسْتِرْقَاقًا', #1
u'واسترقاقه': u'وَاسْتِرْقَاقِهِ', #11
u'واسترقاقه': u'وَاسْتِرْقَاقُهُ', #15
u'واسترقاقها': u'وَاسْتِرْقَاقُهَا', #2
u'واسترقاقها': u'وَاسْتِرْقَاقِهَا', #3
u'واسترقاقهم': u'وَاسْتِرْقَاقُهُمْ', #11
u'واسترقاقهم': u'وَاسْتِرْقَاقَهُمْ', #2
u'واسترقاقهم': u'وَاسْتِرْقَاقِهِمْ', #6
u'واسترقى': u'وَاسْتَرْقَى', #5
u'واستركه': u'وَاسْتَرَكَّهُ', #1
u'واستريب': u'وَاسْتُرِيبَ', #2
u'واستريبت': u'وَاسْتُرِيبَتْ', #1
u'واستزبنه': u'وَاسْتَزْبَنَهُ', #1
u'واستسرها': u'وَاسْتَسَرّهَا', #1
u'واستسعاء': u'وَاسْتِسْعَاءُ', #5
u'واستسعاء': u'وَاسْتِسْعَاءِ', #6
u'واستسعاءه': u'وَاسْتِسْعَاءَهُ', #2
u'واستسعاه': u'وَاسْتَسْعَاهُ', #7
u'واستسعاها': u'وَاسْتَسْعَاهَا', #1
u'واستسعاؤه': u'وَاسْتِسْعَاؤُهُ', #2
u'واستسعائه': u'وَاسْتِسْعَائِهِ', #1
u'واستسعت': u'وَاسْتَسْعَتْ', #3
u'واستسعوا': u'وَاسْتَسْعَوْا', #4
u'واستسعوه': u'وَاسْتَسْعَوْهُ', #1
u'واستسعي': u'وَاسْتُسْعِيَ', #1
u'واستسعى': u'وَاسْتَسْعَى', #7
u'واستسلف': u'واستسلف', #1
u'واستسلف': u'وَاسْتَسْلَفَ', #3
u'واستسلفنا': u'وَاسْتَسْلَفْنَا', #1
u'واستسمانه': u'وَاسْتِسْمَانِهِ', #1
u'واستسمانها': u'وَاسْتِسْمَانِهَا', #1
u'واستسمن': u'وَاسْتَسْمِنْ', #1
u'واستشراه': u'وَاسْتَشْرَاهِ', #1
u'واستشكت': u'وَاسْتَشْكَتْ', #1
u'واستشكله': u'وَاسْتَشْكَلَهُ', #291
u'واستشكلها': u'وَاسْتَشْكَلَهَا', #5
u'واستشكلهما': u'وَاسْتَشْكَلَهُمَا', #2
u'واستشناعه': u'وَاسْتِشْنَاعِهِ', #1
u'واستشنع': u'وَاسْتَشْنَعَ', #1
u'واستشنعتم': u'وَاسْتَشْنَعْتُمْ', #1
u'واستصبح': u'وَاسْتُصْبِحَ', #2
u'واستصبحوا': u'وَاسْتَصْبِحُوا', #1
u'واستصرف': u'وَاسْتَصْرَفَ', #1
u'واستصفاه': u'وَاسْتَصْفَاهُ', #1
u'واستصفاها': u'وَاسْتَصْفَاهَا', #2
u'واستصنع': u'وَاسْتَصْنَعَ', #1
u'واستضاءوا': u'وَاسْتَضَاءُوا', #1
u'واستضاموهم': u'وَاسْتَضَامُوهُمْ', #1
u'واستضحكنا': u'وَاسْتَضْحَكْنَا', #1
u'واستضر': u'وَاسْتَضَرَّ', #4
u'واستضراره': u'وَاسْتِضْرَارِهِ', #3
u'واستضرارها': u'وَاسْتِضْرَارِهَا', #1
u'واستطبابه': u'وَاسْتِطْبَابِهِ', #1
u'واستطراق': u'وَاسْتِطْرَاقٍ', #1
u'واستطراقه': u'وَاسْتِطْرَاقُهُ', #1
u'واستطرق': u'وَاسْتَطْرَقَ', #2
u'واستطهارها': u'وَاسْتِطْهَارِهَا', #2
u'واستعبر': u'وَاسْتَعْبَرَ', #1
u'واستعتموا': u'وَاسْتَعْتَمُوا', #2
u'واستعز': u'وَاسْتَعَزّ', #1
u'واستعصمته': u'وَاسْتَعْصَمْتُهُ', #1
u'واستعفى': u'وَاسْتَعْفَى', #4
u'واستعقاب': u'وَاسْتِعْقَابِ', #1
u'واستعقاب': u'وَاسْتِعْقَابَ', #2
u'واستعقاب': u'وَاسْتِعْقَابُ', #5
u'واستعقابه': u'وَاسْتِعْقَابِهِ', #1
u'واستعقابه': u'وَاسْتِعْقَابُهُ', #2
u'واستعقبه': u'وَاسْتَعْقَبَهُ', #4
u'واستعقلت': u'وَاسْتُعْقِلَتْ', #1
u'واستعلجن': u'واستعلجن', #1
u'واستعما': u'وَاسْتَعَمَّا', #1
u'واستعملنى': u'وَاسْتَعْمِلْنِى', #1
u'واستعملنى': u'وَاسْتَعْمَلَنِى', #2
u'وأستعيذك': u'وَأَسْتَعِيذُكَ', #1
u'واستغبن': u'وَاسْتَغْبَنَ', #1
u'واستغزلن': u'وَاسْتَغْزَلْنَ', #1
u'واستغضب': u'وَاسْتَغْضَبَ', #1
u'واستغفرلهم': u'وَاسْتَغْفَرَلَهُمْ', #1
u'واستغنام': u'وَاسْتِغْنَامُ', #1
u'وأستغنى': u'وَأَسْتَغْنِى', #1
u'واستغواه': u'وَاسْتَغْوَاهُ', #1
u'واستغوتنا': u'وَاسْتَغْوَتْنَا', #1
u'واستغوى': u'وَاسْتَغْوَى', #2
u'واستفاده': u'وَاسْتَفَادَهُ', #5
u'واستفده': u'وَاسْتَفِدْهُ', #3
u'واستفراخها': u'وَاسْتِفْرَاخِهَا', #3
u'واستفراش': u'وَاسْتِفْرَاشُ', #3
u'واستفرشها': u'وَاسْتَفْرَشَهَا', #1
u'واستفسد': u'وَاسْتَفْسَدَ', #1
u'واستفصال': u'وَاسْتِفْصَالٍ', #1
u'واستفصل': u'وَاسْتَفْصَلَ', #2
u'وأستفضل': u'وَأَسْتَفْضِلُ', #1
u'واستفضل': u'وَاسْتَفْضَلَ', #1
u'واستقاد': u'وَاسْتَقَادَ', #1
u'واستقادت': u'وَاسْتَقَادَتْ', #1
u'واستقتل': u'واستقتل', #1
u'وأستقدرك': u'وَأْسَتْقْدِرُكَ', #1
u'وأستقدرك': u'وَأَسْتَقْدِرك', #3
u'وأستقدرك': u'وَأَسْتَقْدِرُك', #7
u'وأستقدرك': u'وَأَسْتَقْدِرُكَ', #8
u'واستقذف': u'وَاسْتَقْذَفَ', #1
u'واستقرب': u'وَاسْتُقْرِبَ', #2
u'واستقرب': u'وَاسْتَقْرَبَ', #33
u'واستقربه': u'وَاسْتَقْرَبَهُ', #1
u'واستقرض': u'وَاسْتَقْرِضْ', #2
u'واستقرض': u'وَاسْتَقْرَضَ', #24
u'واستقرضت': u'وَاسْتَقْرَضَتْ', #3
u'واستقرضت': u'وَاسْتَقْرَضْت', #3
u'واستقرضته': u'وَاسْتَقْرَضْتُهُ', #1
u'واستقرضوا': u'وَاسْتَقْرَضُوا', #4
u'واستقضائه': u'وَاسْتِقْضَائِهِ', #1
u'واستقضائها': u'وَاسْتِقْضَائِهَا', #1
u'واستقضوا': u'وَاسْتَقْضَوْا', #1
u'واستقضي': u'وَاسْتُقْضِيَ', #3
u'واستقضى': u'وَاسْتَقْضَى', #9
u'واستقضيته': u'وَاسْتَقْضَيْتُهُ', #1
u'واستقضيته': u'وَاسْتَقْضَيْته', #2
u'واستكاك': u'وَاسْتِكَاكِ', #1
u'واستكتم': u'وَاسْتَكْتَمَ', #4
u'واستكتمه،': u'وَاسْتَكْتَمَهُ،', #1
u'واستكتمه': u'وَاسْتَكْتَمَهُ', #6
u'واستكراء': u'وَاسْتِكْرَاءُ', #4
u'واستكرى': u'وَاسْتَكْرَى', #1
u'واستكريتك': u'وَاسْتَكْرَيْتُكَ', #1
u'واستكساب': u'وَاسْتِكْسَابُ', #1
u'واستكسابها': u'وَاسْتِكْسَابَهَا', #1
u'واستكسابهم': u'وَاسْتِكْسَابَهُمْ', #1
u'واستكسب': u'وَاسْتَكْسَبَ', #2
u'واستكسباه': u'وَاسْتَكْسَبَاهُ', #1
u'واستكسبه': u'وَاسْتَكْسَبَهُ', #7
u'واستكسوني': u'وَاسْتَكْسُونِي', #1
u'واستكف': u'وَاسْتَكَفَّ', #1
u'واستكفاء': u'وَاسْتِكْفَاءُ', #3
u'واستكفت': u'واسْتَكَفَّت', #1
u'واستكفوا': u'وَاسْتَكَفّوْا', #1
u'واستلانتها': u'وَاسْتَلَانَتْهَا', #1
u'واستلبث': u'وَاسْتَلْبَثَ', #1
u'واستلحق': u'وَاسْتُلْحِقَ', #1
u'واستلحق': u'وَاسْتَلْحَقَ', #11
u'واستلحقته': u'وَاسْتَلْحَقَتْهُ', #1
u'واستلحقك': u'وَاسْتَلْحَقَك', #1
u'واستلحقك': u'وَاسْتَلْحَقَكَ', #1
u'واستلحقه': u'وَاسْتَلْحَقَهُ', #7
u'واستلحقها': u'وَاسْتَلْحَقَهَا', #2
u'واستلحقهم': u'وَاسْتَلْحَقَهُمْ', #1
u'واستمانة': u'وَاسْتِمَانَةٍ', #1
u'واستمانه': u'وَاسْتِمَانِهِ', #1
u'واستمته': u'وَاسْتَمْته', #1
u'واستمخروا': u'وَاسْتَمْخِرُوا', #1
u'واستمريت': u'وَاسْتَمَرَّيْت', #1
u'واستمسكوها': u'وَاسْتَمْسَكُوهَا', #1
u'واستمشى': u'وَاسْتَمْشَى', #1
u'واستمكان': u'وَاسْتِمْكَانِ', #1
u'واستملكها': u'وَاسْتَمْلَكَهَا', #1
u'واستن،': u'وَاسْتَنَّ،', #2
u'واستن': u'وَاسْتَنَّ', #20
u'واستناب': u'وَاسْتَنَابَ', #8
u'واستنابه': u'وَاسْتَنَابَهُ', #5
u'واستنام': u'وَاسْتَنَامَ', #2
u'واستنامة': u'وَاسْتِنَامَةٌ', #2
u'واستنان': u'وَاسْتِنَانِ', #4
u'واستنان': u'وَاسْتِنَانُ', #6
u'واستنانا': u'وَاسْتِنَانًا', #2
u'واستنانه': u'وَاسْتِنَانه', #2
u'واستنبتك': u'وَاسْتَنْبَتُك', #1
u'واستنبتك': u'وَاسْتَنَبْتُك', #2
u'واستنبتك': u'وَاسْتَنَبْتُكَ', #5
u'واستنبتها': u'وَاسْتَنْبَتَهَا', #1
u'واستنبنا': u'وَاِسْتَنَبْنَا', #1
u'واستنتر': u'وَاسْتَنْتَرَ', #1
u'واستنثار': u'وَاسْتِنْثَارٍ', #2
u'واستنثار': u'وَاسْتِنْثَارٌ', #9
u'واستنثارة': u'واستنثارة', #2
u'واستنثر': u'وَاسْتَنْثِرْ', #1
u'واستنثر،': u'وَاسْتَنْثَرَ،', #1
u'واستنثر': u'وَاسْتَنْثَرَ', #53
u'واستنجاء': u'وَاسْتِنْجَاء', #1
u'واستنجاء': u'وَاسْتِنْجَاءً', #1
u'واستنجاء': u'وَاسْتِنْجَاءُ', #1
u'واستنجاء': u'وَاسْتِنْجَاءٍ', #10
u'واستنجاء': u'وَاسْتِنْجَاءٌ', #11
u'واستنجاءه': u'وَاسْتِنْجَاءَهُ', #1
u'واستنجاز': u'وَاسْتِنْجَازٌ', #1
u'واستنجاؤه': u'وَاسْتِنْجَاؤُهُ', #2
u'واستنجاؤهم': u'وَاسْتِنْجَاؤُهُمْ', #3
u'واستنجائه': u'وَاسْتِنْجَائِهِ', #1
u'واستنزعه': u'وَاسْتَنْزَعَهُ', #1
u'واستنسجن': u'وَاسْتَنْسَجْنَ', #1
u'واستنسر': u'وَاسْتَنْسَرَ', #1
u'واستنشاره': u'وَاسْتِنْشَارُهُ', #1
u'واستنصح': u'وَاسْتَنْصَحَ', #1
u'واستنصلت': u'وَاسْتَنْصَلْتُ', #1
u'واستنظر': u'وَاسْتَنْظَرَ', #1
u'واستنظرته': u'وَاسْتَنْظَرْتُهُ', #1
u'واستنفاقها': u'واستنفاقها', #1
u'واستنفع': u'وَاسْتَنْفِعْ', #1
u'واستنفعوا': u'وَاسْتَنْفَعُوا', #1
u'واستنفق': u'وَاسْتَنْفَقَ', #1
u'واستنفق': u'وَاسْتَنْفِقْ', #1
u'واستنفقها': u'وَاسْتَنْفَقَهَا', #2
u'واستنفقوه': u'وَاسْتَنْفَقُوهُ', #1
u'واستنقأت': u'وَاسْتَنْقَأْتِ', #3
u'واستنقع': u'وَاسْتَنْقَعَ', #4
u'واستنكاح': u'وَاسْتِنْكَاحُ', #1
u'واستنكاه': u'وَاسْتِنْكَاهِ', #2
u'واستنكحها،': u'واستنكحها،', #1
u'واستنكحها': u'وَاسْتَنْكَحَهَا', #1
u'واستنكهوه': u'وَاسْتَنْكِهُوهُ', #8
u'واستنماء': u'وَاسْتِنْمَاءٌ', #1
u'واستنماء': u'وَاسْتِنْمَاءٍ', #1
u'واستنماء': u'وَاسْتِنْمَاءُ', #1
u'واستنماء': u'وَاسْتِنْمَاءِ', #3
u'واستنماؤه': u'وَاسْتِنْمَاؤُهُ', #5
u'واستنمائه': u'واسْتِنْمائِهِ', #1
u'واستنوا': u'وَاسْتَنُّوا', #1
u'واستهام': u'وَاسْتِهَامُ', #1
u'واستهانها': u'وَاسْتَهَانَهَا', #1
u'واستهدام': u'وَاسْتِهْدَامِ', #1
u'واستهدم': u'وَاسْتَهْدَمَ', #1
u'واستهزءوا': u'وَاسْتَهْزَءُوا', #6
u'واستهمنا': u'وَاسْتَهَمْنَا', #1
u'واستوجه': u'وَاسْتَوْجَهُ', #1
u'واستوجه': u'وَاسْتُوْجِهَ', #1
u'واستوجه': u'وَاسْتَوْجَهَ', #35
u'واستوجها': u'وَاسْتَوْجَهَا', #1
u'واستوجهه': u'وَاسْتَوْجَهَهُ', #20
u'واستوخموا': u'وَاسْتَوْخَمُوا', #6
u'واستوسق': u'وَاسْتُوسِقَ', #1
u'واستوسق': u'وَاسْتَوْسَقَ', #3
u'واستوسقوا': u'وَاسْتَوْسَقُوا', #3
u'واستوطأ': u'وَاسْتَوْطَأَ', #1
u'واستوعى': u'وَاسْتَوْعَى', #3
u'واستوفزت': u'وَاسْتَوْفَزَتْ', #1
u'واستوكف': u'وَاسْتَوْكَفَ', #4
u'واستؤني': u'وَاِسْتُؤْنِيَ', #4
u'واستؤني': u'وَاسْتُؤْنِيَ', #59
u'واستوهب': u'وَاسْتَوْهَبَ', #2
u'واستوهبناه': u'وَاسْتَوْهَبْنَاهُ', #1
u'واستوهبه': u'وَاسْتَوْهَبَهُ', #2
u'واستويتا': u'وَاسْتَوَيَتَا', #2
u'واستئكالهم': u'وَاسْتِئْكَالِهِمْ', #1
u'واستياك': u'وَاسْتِيَاكٌ', #1
u'واستياكه': u'وَاسْتِيَاكُهُ', #2
u'واستيخار': u'وَاسْتِيخَارَ', #1
u'واستيصاله': u'وَاسْتِيصَالُهُ', #1
u'واستيفاز': u'وَاسْتِيفَازِ', #1
u'واستين': u'وَاسْتَيْنِ', #1
u'واستيناء': u'وَاسْتِينَاءٍ', #1
u'واستيهاب': u'وَاسْتِيهَابُ', #1
u'واستيهاب': u'وَاسْتِيهَابٌ', #2
u'وأسجدت': u'وَأَسْجَدَتْ', #1
u'وأسجلت': u'وَأَسْجَلْتُ', #1
u'واسجما': u'وَاسْجُمَا', #4
u'واسحار': u'وَاسْحَارّ', #1
u'واسحاق': u'واسحاق', #1
u'واسحام': u'وَاسْحَامّ', #1
u'وإسحق': u'وَإِسْحَق', #1
u'وإسحق': u'وَإِسْحَقُ', #1
u'وإسحق': u'وَإِسْحَقَ', #2
u'واسحنفرا': u'وَاسْحَنْفِرَا', #2
u'واسحنفري': u'وَاسْحَنْفِرِي', #2
u'وأسدام': u'وَأَسْدَامٌ', #1
u'وأسراء': u'وَأُسَرَاءِ', #1
u'وأسراج': u'وَأَسْرَاجٍ', #1
u'وإسرار': u'وَإِسْرَارٌ', #1
u'وإسرار': u'وَإِسْرَارٍ', #1
u'وإسرار': u'وَإِسْرَارَ', #1
u'وإسرار': u'وَإِسْرَارُ', #11
u'وإسرار': u'وَإِسْرَارِ', #2
u'وإسرارا': u'وَإِسْرَارًا', #2
u'وإسراره': u'وَإِسْرَارِهِ', #1
u'وإسراره': u'وَإِسْرَارُهُ', #5
u'وإسرارها': u'وَإِسْرَارُهَا', #2
u'وإسرارهم': u'وَإِسْرَارِهِمْ', #1
u'وإسرارهم': u'وَإِسْرَارُهُمْ', #3
u'وإسرافى': u'وَإِسْرَافِى', #1
u'وإسرافيل': u'وَإِسْرَافِيل', #1
u'وإسرافيل': u'وِإِسْرَافِيلُ', #1
u'وإسرافيل؟': u'وَإِسْرَافِيلَ؟', #1
u'وإسرافيل؟،': u'وَإِسْرَافِيلُ؟،', #1
u'وإسرافيل': u'وَإِسْرَافِيلَ', #16
u'وإسرافيل،': u'وَإِسْرَافِيلَ،', #2
u'وإسرافيل،': u'وَإِسْرَافِيلُ،', #4
u'وإسرافيل': u'وَإِسْرَافِيلُ', #8
u'وأسرياء': u'وَأَسْرِيَاءُ', #1
u'وأسطار': u'وَأَسْطَارُ', #1
u'واسطاع': u'وَاسْطَاعَ', #1
u'وأسطحة': u'وَأَسْطُحَةِ', #1
u'وأسطحته': u'وَأَسْطِحَتِهِ', #1
u'وأسطحتها': u'وَأَسْطُحَتِهَا', #1
u'وأسطحتها': u'وَأَسْطِحَتِهَا', #1
u'وأسطوانها': u'وأسطوانها', #2
u'وأسطوانها': u'وَأُسْطُوَانِهَا', #2
u'وإسعاطها': u'وَإِسْعَاطِهَا', #2
u'وأسعط': u'وَأَسْعَطَ', #1
u'وأسعط': u'وَأُسْعِطَ', #1
u'وأسعطته': u'وَأَسْعَطْتُهُ', #1
u'وأسعطه': u'وَأَسْعَطَهُ', #2
u'وإسفرايين': u'وَإِسْفَرَايِينَ', #1
u'وإسفندياذ': u'وإسفندياذ', #4
u'وإسفندياز': u'وإسفندياز', #2
u'وأسفى': u'وَأَسْفَى', #2
u'وإسفيداج': u'وَإِسْفِيدَاجٍ', #1
u'وإسفيذاج': u'وإسفيذاج', #1
u'وإسفيذاج': u'وَإِسْفِيذَاجٍ', #1
u'وإسقاء': u'وَإِسْقَاءُ', #1
u'واسقاء': u'وَاسِقَاءِ', #1
u'وإسقاء': u'وَإِسْقَاءِ', #2
u'واسقاط': u'وَاسِقَاطٌ', #1
u'واسقاط': u'وَاسِقَاطَ', #1
u'واسقاط': u'وَاسِقَاطُ', #1
u'واسقاط': u'وَاسِقَاطِ', #1
u'وإسقائهم': u'وَإِسْقَائِهِمْ', #1
u'وأسقبت': u'وَأَسْقَبَتْ', #1
u'وأسقبت': u'وَأَسْقَبْت', #1
u'وأسقفته': u'وَأَسْقَفْتُهُ', #1
u'وأسقمتني': u'وَأَسْقَمَتْنِي', #1
u'وأسقمهم': u'وَأَسْقَمَهُمْ', #1
u'وأسقيات': u'وَأَسْقِيَاتٌ', #1
u'وإسكتي': u'وَإِسْكَتَيْ', #2
u'وإسكتيها': u'وَإِسْكَتَيْهَا', #2
u'واسلام': u'وَاسِلَامُ', #1
u'وأسلع': u'وَأَسْلَع', #1
u'وأسلمSمعنى': u'وَأَسْلَمُSمَعْنَى', #1
u'وإسماعيلي': u'وَإِسْمَاعِيلِيُّ', #1
u'وإسماعيلي': u'وَإِسْمَاعِيلِيٍّ', #4
u'وأسمانجوني': u'وأسمانجوني', #1
u'وأسمانها': u'وَأَسْمَانُهَا', #1
u'وأسمحهم': u'وَأَسْمَحِهِمْ', #2
u'وأسمعة': u'وَأَسْمِعَةِ', #1
u'وأسمعونى': u'وَأَسْمِعُونِى', #1
u'وإسمعيل': u'وَإِسْمَعِيل', #1
u'وإسمعيل': u'وَإِسْمَعِيلَ', #1
u'وأسمية': u'وَأَسْمِيَةٌ', #1
u'وأسناخ': u'وَأَسْنَاخُ', #1
u'وأسنع': u'وأسنع', #1
u'واسهكوني': u'وَاسْهَكُونِي', #1
u'واسوء': u'وَاسُوءَ', #1
u'واسوأتاه': u'وَاسَوْأَتَاه', #1
u'واسوأتاه': u'وَاسَوْأَتَاهْ', #1
u'واسوأتاه': u'وَاسَوْأَتَاهُ', #5
u'وإسواره': u'وَإِسْوَارُهُ', #1
u'وأسوان': u'وَأَسْوَانِ', #1
u'وأسوت': u'وَأَسَوْت', #1
u'وأسوكة': u'وَأَسْوِكَةُ', #1
u'واسئلهم': u'وَاسْئَلْهُمْ', #2
u'وأسيد': u'وَأُسِيدُ', #1
u'وأسيد': u'وَأَسَيْدُ', #1
u'وأسيد': u'وَأُسَيْد', #1
u'وأسيد': u'وَأُسَيْدٍ', #1
u'وأسيد،': u'وَأُسَيْدٌ،', #1
u'وأسيد': u'وَأَسِيد', #2
u'وأسيد': u'وَأَسِيدٌ', #2
u'وأسيد': u'وَأَسِيدٍ', #2
u'وأسيد': u'وَأَسِيدِ', #2
u'وأسيد': u'وَأُسَيْدٌ', #2
u'وأسيد': u'وَأَسِيدُ', #3
u'وأسيد': u'وأسيد', #4
u'وأسيد': u'وَأُسَيْدُ', #44
u'وأسيد': u'وأُسَيْدُ', #7
u'وأسيد': u'وَأُسَيْدَ', #8
u'وأسيد': u'وَأُسَيْدِ', #9
u'وأسيدا': u'وَأُسَيْدًا', #1
u'واسيداه': u'وَاسَيِّدَاهُ', #1
u'وأسيفع': u'وَأُسَيْفِعُ', #1
u'وأسيوط': u'وَأَسْيُوطَ', #1
u'وإشاح': u'وَإِشَاحٍ', #1
u'وإشالة': u'وَإِشَالَةُ', #3
u'وإشالته': u'وَإِشَالَتُهُ', #1
u'وإشالته': u'وَإِشَالَتِهِ', #1
u'وأشاهدا': u'وأشاهدا', #1
u'وإشباط': u'وَإِشْبَاطِ', #1
u'وأشببته': u'وَأَشْبَبْتُه', #1
u'وأشبهم': u'وَأَشَبُّهُمْ', #1
u'واشتجر': u'وَاشْتَجَرَ', #1
u'واشتجرا': u'وَاشْتَجَرَا', #1
u'واشتجرت': u'وَاشْتَجَرَتْ', #1
u'واشترطى': u'وَاشْتَرِطِى', #22
u'واشتشقاقهم': u'وَاشْتِشْقَاقِهِمْ', #1
u'واشتط': u'وَاشْتَطَّ', #1
u'واشتفى،': u'وَاشْتَفَى،', #1
u'واشتفى': u'وَاشْتَفَى', #3
u'واشتكاه': u'وَاشْتَكَاهُ', #1
u'واشتواه': u'وَاشْتَوَاهُ', #1
u'واشتوينا': u'وَاشْتَوَيْنَا', #1
u'وإشحانا': u'وَإِشْحَانًا', #1
u'وأشحمت': u'وَأَشْحَمْتُ', #1
u'وإشخاص': u'وَإِشْخَاصِ', #1
u'وأشرا': u'وَأَشَرًا', #1
u'وأشراسا': u'وأشراسا', #1
u'وإشراه': u'وَإِشْرَاهٍ', #1
u'وأشرفية': u'وَأَشْرَفِيَّةٌ', #1
u'وأشرفية': u'وَأَشْرَفِيَّةٍ', #1
u'وآشره': u'وَآشَرَه', #1
u'وآشره': u'وَآشَرِهِ', #1
u'واشعار': u'وَاشِعَارٌ', #1
u'وأشفعا': u'وَأَشْفَعَا', #1
u'وأشقاص': u'وَأَشْقَاصٌ', #1
u'وأشقاصه': u'وَأَشْقَاصَهُ', #1
u'وأشقاصه': u'وَأَشْقَاصُهُ', #1
u'وإشكانيان': u'وإشكانيان', #1
u'وأشكاه': u'وَأَشْكَاهُ', #1
u'واشكرهمو': u'وَاشْكُرْهُمُو', #1
u'وأشلى': u'وَأَشْلَى', #1
u'وأشليته': u'وَأَشْلَيْتُهُ', #1
u'وأشمذين': u'وَأَشْمَذَيْنِ', #1
u'وأشمط': u'وَأَشْمَطُ', #1
u'وأشمليته': u'وَأَشْمَلِيَّتِهِ', #1
u'وأشنان': u'وَأَشْنَانٍ', #1
u'وأشنان': u'وَأُشْنَان', #1
u'وأشنان': u'وَأُشْنَانٌ', #1
u'وأشنان': u'وَأُشْنَانَ', #2
u'وأشنان': u'وَأُشْنَانٍ', #33
u'وأشهريته': u'وَأَشْهَرِيَّتِهِ', #1
u'واشوقاه': u'وَاشَوْقَاه', #1
u'وأشيافاتهم': u'وأشيافاتهم', #1
u'وأشيافهم': u'وَأَشْيَافِهِمْ', #1
u'وأشيم': u'وَأَشْيَمَ', #1
u'وأشيم': u'وَأَشْيَمُ', #1
u'وأصابتنى': u'وَأَصَابَتْنِى', #1
u'وأصابنى': u'وَأَصَابَنِى', #1
u'واصاحباه': u'وَاصَاحِبَاهُ', #1
u'واصاحباه': u'وَاصَاحِبَاهْ', #2
u'وأصاحيب': u'وَأَصَاحِيبُ', #1
u'واصالحا': u'وَاصَّالَحَا', #2
u'واصبا': u'وَاصِبًا', #5
u'واصباح': u'وَاصَبَاحَ', #5
u'واصباحاه،': u'واصَبَاحاه،', #1
u'واصباحاه،': u'واصَبَاحَاهُ،', #1
u'واصباحاه': u'وَاصَبَاحَاهُ', #1
u'واصباحاه': u'وَاصَبَاحَاه', #4
u'واصبرى': u'وَاصْبِرِى', #6
u'وإصبعين': u'وَإِصْبَعَيْنِ', #1
u'وإصبه': u'وَإِصْبَهُ', #1
u'وأصبهان': u'وَأَصْبَهَانَ', #10
u'واصحابه': u'واصحابه', #1
u'وأصحابهوروي': u'وَأَصْحَابِهِوَرُوِيَ', #1
u'وأصحابى': u'وَأَصْحَابِى', #3
u'وأصحمة': u'وَأَصْحَمَةُ', #1
u'وأصحية': u'وَأَصَحِّيَةُ', #1
u'وأصداء': u'وَأَصْدَاءً', #2
u'وأصرفاه': u'وَأَصْرَفَاهُ', #1
u'وأصرفت': u'وَأُصْرِفَتْ', #1
u'واصرفنى': u'وَاصْرِفْنِى', #2
u'واصطباره': u'وَاصْطِبَارِهِ', #1
u'واصطفانى': u'وَاصْطَفَانِى', #4
u'واصطلام': u'وَاصْطِلَامِ', #1
u'واصطلام': u'وَاصْطِلَامُ', #3
u'واصطلامهم': u'وَاصْطِلَامَهُمْ', #1
u'واصطلم': u'وَاصْطَلَمَ', #1
u'واصطلمت': u'وَاصْطَلَمَتْ', #1
u'وآصع': u'وَآصُعَ', #1
u'وآصع': u'وَآصُعٌ', #2
u'وآصع': u'وَآصُعٍ', #4
u'وأصعر': u'وَأَصْعَرُ', #1
u'وآصف': u'وآصف', #1
u'واصفياه': u'واصفياه', #1
u'واصفياه': u'وَاصَفِيَّاهُ', #2
u'وأصلامه': u'وأصلامه', #1
u'وأصلحننى': u'وَأَصْلَحْنَنِى', #3
u'وأصمتوا': u'وَأُصْمِتُوا', #1
u'وأصمع': u'وَأَصْمَعُ', #1
u'واصنعى': u'وَاصْنَعِى', #1
u'وأصيلانا': u'وَأُصَيْلَانًا', #1
u'وأضا': u'وَأَضًا', #1
u'وآضاء': u'وَآضَاء', #1
u'وأضاة': u'وَأَضَاةُ', #2
u'وأضاقه': u'وَأَضَاقَهُ', #1
u'وأضبطية': u'وَأَضْبَطِيَّةُ', #2
u'وأضحاة': u'وَأُضْحَاةٌ', #2
u'وأضحاة': u'وَأَضْحَاةٌ', #8
u'واضحتهيخرجون': u'وَاضِحَتِهِيَخْرُجُونَ', #1
u'وأضحى': u'وَأَضْحًى', #1
u'وأضرا': u'وَأَضْرَا', #1
u'واضرار': u'وَاضِرَارِ', #1
u'وأضراه': u'وَأَضْرَاهُ', #2
u'وأضرت': u'وأضرَّتْ', #1
u'وأضرت': u'وَأَضَرَّتْ', #17
u'وأضز': u'وَأَضَزُّ', #1
u'واضطباع': u'وَاضْطِبَاعٌ', #2
u'واضطباع': u'وَاضْطِبَاعٍ', #3
u'واضطبع': u'وَاضْطَبَعَ', #1
u'واضطبعوا': u'وَاضْطَبَعُوا', #4
u'واضعوا': u'وَاضِعُوا', #1
u'واضفرى': u'وَاضْفِرِى', #1
u'واضم': u'وَاضَمّ', #1
u'وأضهد': u'وَأَضْهَدَ', #1
u'وأضوات': u'وَأَضَوَاتٌ', #1
u'وإضون': u'وَإِضُونَ', #1
u'واضئنات': u'واضئنات', #1
u'وأضيات': u'وَأَضَيَاتٌ', #1
u'واط': u'وَاطٍ', #3
u'وأطأل': u'وَأَطْأَلَ', #1
u'وآطام': u'وَآطَامُ', #1
u'وآطامها': u'وَآطَامِهَا', #2
u'وإطراح': u'وَإِطْرَاحَ', #1
u'وإطراح': u'وَإِطْرَاحُ', #10
u'وإطراح': u'وَإِطْرَاحِ', #2
u'واطراح': u'وَاطِّرَاحِ', #5
u'وإطراحا': u'وَإِطْرَاحًا', #1
u'واطراحا': u'واطراحا', #1
u'واطراحا': u'وَاطِّرَاحًا', #2
u'واطراحك': u'وَاطِّرَاحَك', #1
u'وإطراحه': u'وَإِطْرَاحُهُ', #1
u'واطراحه': u'وَاطّرَاحِهِ', #1
u'وإطراحها': u'وَإِطْرَاحُهَا', #1
u'وإطراحها': u'وَإِطْرَاحِهَا', #1
u'واطراحها': u'وَاطِّرَاحُهَا', #1
u'واطراحهم': u'وَاطِّرَاحَهُمْ', #1
u'وإطراد': u'وَإِطْرَادَ', #1
u'واطرباه': u'وَاطَرَبَاهُ', #1
u'واطربت': u'وَاطَّرَبَتْ', #1
u'واطرحت': u'وَاطَّرَحَتْ', #1
u'واطرحته': u'وَاطَّرَحْته', #1
u'وأطرحنا': u'وَأَطْرَحْنَا', #1
u'وأطردوا': u'وَأَطْرَدُوا', #2
u'وأطرقاء': u'وَأَطْرِقَاءُ', #1
u'وأطرقة': u'وَأَطْرِقَةٌ', #1
u'وإطرية': u'وَإِطْرِيَةٍ', #6
u'وأطعمتوه': u'وَأَطْعَمْتُوهُ', #1
u'وأطعمنى': u'وَأَطْعَمَنِى', #1
u'وأطفاس': u'وَأَطْفَاسُ', #1
u'وأطفلت': u'وَأَطْفَلَتْ', #2
u'وأطفئى': u'وَأَطْفِئِى', #2
u'وإطفيحي': u'وَإِطْفِيحِيٌّ', #4
u'وأطلاح': u'وَأَطْلَاحُ', #1
u'وأطلاع': u'وَأَطْلَاعُ', #2
u'وأطلاق': u'وَأَطْلَاق', #1
u'واطلاق': u'وَاطَلَاقُ', #2
u'وأطلاقها': u'وَأَطْلَاقِهَا', #1
u'وأطلاقهما': u'وَأَطْلَاقُهُمَا', #1
u'وأطليت': u'وَأَطْلَيْت', #1
u'واطليت': u'وَاطَّلَيْت', #2
u'وأطمعوا': u'وأُطمعوا', #1
u'وأطواء': u'وَأَطْوَاءٌ', #1
u'وأطواء': u'وَأَطْوَاءٍ', #1
u'واطوفوا': u'وَاطّوَفّوا', #1
u'واطيا': u'وَاطِيًا', #2
u'وأطيبتها': u'وَأَطْيَبْتُهَا', #1
u'وأطيبهوالوجه': u'وَأَطْيَبُهُوَالْوَجْهُ', #1
u'وأطيبية': u'وَأَطْيَبِيَّةُ', #4
u'وأطيبيته': u'وَأَطْيَبِيَّتِهِ', #1
u'وأطيبيته': u'وَأَطْيَبِيَّتُهُ', #2
u'وأطيط': u'وَأَطِيط', #1
u'وأطيط': u'وَأَطِيطٍ', #1
u'وأطيط': u'وَأَطِيطُ', #1
u'وأطيعون': u'وَأَطِيعُونِ', #23
u'وأظآر': u'وَأَظْآرٌ', #1
u'واظاهر': u'وَاظَّاهَرَ', #2
u'وأظفور': u'وَأُظْفُورٌ', #3
u'وأظننى': u'وَأَظُنُّنِى', #1
u'وأظنني': u'وَأَظُنُّنِي', #4
u'واظهار': u'وَاظِهَارٌ', #1
u'واظهار': u'وَاظِهَارِ', #1
u'وأظهرية': u'وَأَظْهَرِيَّةً', #1
u'وإعابته': u'وَإِعَابَتِهِ', #1
u'واعادة': u'وَاعَادَةُ', #1
u'وأعاننى': u'وَأَعَانَنِى', #1
u'وأعبدا': u'وَأَعْبُدًا', #2
u'وأعتدت': u'وَأَعْتَدَتْ', #16
u'وإعتدنا': u'وَإعْتَدْنَا', #1
u'وأعتدنا': u'وَأَعْتَدْنَا', #22
u'واعترص': u'وَاعْتَرَصَ', #1
u'واعترقه': u'وَاعْتَرَقَهُ', #1
u'وإعتزال': u'وإعتزال', #1
u'واعتزى': u'وَاعْتَزَى', #1
u'واعتضاد': u'وَاعْتِضَادَ', #1
u'واعتضاد': u'وَاعْتِضَادِ', #2
u'واعتضاده': u'وَاعْتِضَادُهُ', #1
u'واعتضاده': u'وَاعْتِضَادِهِ', #3
u'واعتضادها': u'وَاعْتِضَادُهَا', #1
u'واعتضادها': u'وَاعْتِضَادِهَا', #2
u'واعتضد': u'وَاعْتَضَدَ', #14
u'واعتضد': u'وَاعْتُضِدَ', #4
u'واعتضدت': u'وَاعْتَضَدَتْ', #4
u'واعتفتها': u'وَاعْتَفْتُهَا', #1
u'واعتقبوا': u'وَاعْتَقَبُوا', #1
u'واعتقبوها': u'وَاعْتَقَبُوهَا', #1
u'واعتقبوها': u'وَاعْتُقِبُوهَا', #1
u'وأعتقى': u'وَأَعْتِقِى', #4
u'واعتلقوا': u'وَاعْتَلَقُوا', #1
u'واعتمامه': u'وَاعْتِمَامُهُ', #2
u'واعتمره': u'وَاعْتَمِرْهُ', #1
u'واعتمره': u'وَاعْتَمَرَهُ', #10
u'واعتمل': u'وَاعْتَمَلَ', #1
u'واعتنا': u'وَاعْتِنَا', #1
u'واعتورته': u'وَاعْتَوَرَتْهُ', #1
u'واعتيافا': u'وَاعْتِيَافًا', #1
u'واعجبا': u'وَاعَجَبًا', #12
u'واعجباه': u'وَاعَجَبَاهُ', #3
u'وأعجنيه': u'وَأَعْجِنِيهِ', #1
u'واعدتنى': u'وَاعَدْتَنِى', #1
u'وأعدلية': u'وَأَعْدَلِيَّةٌ', #1
u'وأعدلية': u'وَأَعْدَلِيَّةُ', #11
u'وأعذنى': u'وَأَعِذْنِى', #1
u'وأعرابى': u'وَأَعْرَابِىٌّ', #2
u'وأعرص': u'وَأَعْرَصَ', #1
u'وأعرورى': u'وَأَعْرَوْرَى', #1
u'واعرورى': u'وَاعْرَوْرَى', #1
u'واعروساه': u'وَاعَرُوسَاه', #1
u'وأعريت': u'وَأَعْرَيْت', #1
u'وأعريتني': u'وَأَعْرَيْتنِي', #1
u'واعريساه': u'واعريساه', #1
u'واعزاز': u'وَاعَزَازِ', #1
u'وإعزائها': u'وَإِعْزَائِهَا', #2
u'وأعصاهم': u'وَأَعْصَاهُمْ', #2
u'وأعصل': u'وَأَعْصَلَ', #2
u'وإعضاله': u'وَإِعْضَالَهُ', #2
u'واعطاء': u'وَاعَطَاءُ', #1
u'واعطاء': u'وَاعَطَاءِ', #3
u'وأعطان': u'وَأَعْطَان', #1
u'وأعطان': u'وَأَعْطَانَ', #1
u'وأعطان': u'وَأَعْطَانُ', #2
u'وأعطان': u'وَأَعْطَانِ', #6
u'وأعطانى': u'وَأَعْطَانِى', #14
u'وأعطانيه': u'وَأَعْطَانِيهِ', #2
u'وأعطاهموها': u'وَأَعْطَاهُمُوهَا', #2
u'وأعطتنى': u'وَأَعْطَتْنِى', #1
u'وأعطنوا': u'وَأَعْطَنُوا', #1
u'وأعطنى': u'وَأَعْطِنِى', #1
u'وأعطنيه': u'وَأَعْطَنِيهِ', #1
u'وأعطنيها': u'وَأَعْطِنِيهَا', #3
u'وأعطونى': u'وَأَعْطُونِى', #1
u'وأعطيات': u'وَأَعْطِيَاتٌ', #3
u'وأعطياتهم': u'وَأَعْطِيَاتُهُمْ', #2
u'واعطيت': u'واعطيت', #1
u'واعطيتك': u'واعطيتك', #1
u'وأعطيتكها': u'وَأَعْطَيْتُكَهَا', #2
u'وأعطيتنيه': u'وَأَعْطَيْتَنِيهِ', #4
u'وأعظامها': u'وَأَعْظَامِهَا', #1
u'وأعظمية': u'وَأَعْظَمِيَّةُ', #1
u'وأعظميتها': u'وَأَعْظَمِيَّتُهَا', #1
u'وأعقبنى': u'وَأَعْقِبْنِى', #1
u'وإعلاقه': u'وَإِعْلَاقِهِ', #1
u'وأعلفت': u'وَأَعْلَفْت', #1
u'وأعلقته': u'وَأَعْلَقْتهُ', #1
u'وأعلمنيه': u'وَأَعْلَمَنِيهِ', #1
u'واعلمى': u'وَاعْلَمِى', #2
u'وأعمالهمالوجه': u'وَأَعْمَالَهُمْالْوَجْهُ', #1
u'واعماه': u'وَاعَمّاهُ', #2
u'وأعمرتكه': u'وَأَعْمَرْتُكَهُ', #1
u'وأعمى': u'وَأَعْمًى', #1
u'وأعمية': u'وَأَعَمِّيَّةً', #1
u'وأعمية': u'وَأَعَمِّيَّةٌ', #1
u'وأعنتنى': u'وَأَعَنْتَنِى', #1
u'وأعولي': u'وَأَعْوِلِي', #2
u'وأعون': u'وَأَعْوَنَ', #1
u'وأعون': u'وَأَعْوَنُ', #8
u'وأعيت': u'وَأَعْيَتْ', #3
u'وأعيمي': u'وَأُعَيْمِي', #1
u'وأعيمى': u'وأعيمى', #1
u'وأعيى': u'وَأَعْيَى', #1
u'وأغابت': u'وَأَغَابَتْ', #1
u'وأغاة': u'وَأَغَاةِ', #1
u'وأغبط': u'وَأَغْبِطُ', #1
u'وأغبط': u'وَأُغْبَطُ', #1
u'وأغتدي': u'وَأَغْتَدِي', #2
u'واغتدى': u'وَاغْتَدَى', #3
u'واغترز': u'وَاغْتَرَزَ', #1
u'واغترس': u'وَاغْتُرِسَ', #1
u'واغتسلى': u'وَاغْتَسِلِى', #2
u'واغتص': u'وَاغْتَصَّ', #1
u'واغتصت': u'وَاغْتُصَّتْ', #1
u'واغتلال': u'وَاغْتِلَالَ', #1
u'واغتلال': u'وَاغْتِلَالُ', #1
u'واغتلال': u'وَاغْتِلَالِ', #2
u'واغتلم': u'وَاغْتَلَمَ', #1
u'واغتلوها': u'وَاغْتَلُّوهَا', #1
u'واغدودق': u'وَاغْدَوْدَقَ', #1
u'وإغريض': u'وَإِغْرِيضٌ', #1
u'وأغزاه': u'وأغزاه', #1
u'وإغزاؤه': u'وَإِغْزَاؤُهُ', #1
u'واغلاق': u'وَاغِلَاقُ', #1
u'وأغلفا': u'وَأَغْلَفَا', #1
u'واغماه،': u'وَاغَمَّاهُ،', #1
u'وأغمص': u'وَأَغْمَصُ', #1
u'وأغمى': u'وَأُغْمِىَ', #1
u'واغننا': u'وَاغْنَنَا', #1
u'واغنني': u'وَاغْنَنِي', #1
u'واغنني': u'وَاغْنِنِي', #1
u'واغنهم': u'وَاغْنِهِمْ', #1
u'واغوثاه': u'وَاغَوْثَاهُ', #6
u'وأفاتاها': u'وَأَفَاتَاهَا', #1
u'وأفاته': u'وَأَفَاتَهُ', #1
u'وأفاتوا': u'وَأَفَاتُوا', #2
u'وأفادنيه': u'وَأَفَادَنِيهِ', #1
u'وافتاء': u'وَافَتَاءُ', #2
u'وافتاته': u'وَافْتَاتَهُ', #1
u'وإفتان': u'وَإِفْتَانِ', #2
u'وافتراده': u'وَافْتِرَادِهِ', #1
u'وافتراعها': u'وَافْتِرَاعُهَا', #1
u'وافتراعها': u'وَافْتِرَاعِهَا', #1
u'وافترط': u'وَافْتَرَطَ', #1
u'وافترعت': u'وَافْتُرِعَتْ', #1
u'وافتض': u'وَافْتَضَّ', #1
u'وافتضها': u'وَافْتَضَّهَا', #26
u'وافتكاك': u'وَافْتِكَاكُ', #1
u'وأفتنته': u'وَأَفْتَنْتُهُ', #2
u'وافتى': u'وَافَتَى', #3
u'وافتيات': u'وَافْتِيَاتٌ', #1
u'وافتيات': u'وَافْتِيَاتِ', #1
u'وافتياتا': u'وَافْتِيَاتًا', #1
u'وافتياته': u'وَافْتِيَاتِهِ', #3
u'وإفحتها': u'وَإِفْحَتُهَا', #1
u'وأفدة': u'وَأَفِدَةٌ', #1
u'وافدى': u'وَافِدَىِ', #1
u'وإفراء': u'وَإِفْرَاءُ', #1
u'وإفراء': u'وَإِفْرَاءِ', #1
u'وافراد': u'وَافِرَادِ', #1
u'وأفراس': u'وَأَفْرَاسٍ', #1
u'وأفراس': u'وَأَفْرَاسُ', #1
u'وأفراس': u'وَأَفْرَاسٌ', #2
u'وأفراسا': u'وَأَفْرَاسًا', #3
u'وافراط': u'وَافِرَاطُ', #1
u'وأفراه': u'وَأَفْرَاهُ', #1
u'وأفراه،': u'وَأَفْرَاهُ،', #1
u'وأفرحة': u'وَأَفْرِحَةٍ', #1
u'وأفرخة': u'وَأَفْرِخَةٌ', #1
u'وأفرضته': u'وَأَفْرَضْتُهُ', #1
u'وأفرعا': u'وَأَفْرُعًا', #1
u'وأفريقيس': u'وأفريقيس', #1
u'وافساد': u'وَافَسَادَ', #1
u'وافساد': u'وَافَسَادُ', #1
u'وأفسوس': u'وَأُفْسُوسُ', #1
u'وافشاء': u'وَافَشَاءِ', #1
u'وافصله': u'وَافْصِلْهُ', #1
u'وإفضاحه': u'وَإِفْضَاحَهُ', #1
u'وأفضلى': u'وأفضلى', #1
u'وافطلوا': u'وافطلوا', #1
u'وافعال': u'وَافْعَالَّ', #1
u'وأفعلة': u'وَأَفْعِلَةٌ', #1
u'وأفعلة': u'وَأَفْعِلَةُ', #1
u'وأفعلة': u'وَأَفْعِلَةٍ', #2
u'وافعنلل': u'وَافْعَنْلِلْ', #1
u'وافعوعل': u'وَافْعَوْعِلْ', #1
u'وافعول': u'وَافْعَوِّلْ', #1
u'وأفغى': u'وَأَفْغَى', #1
u'وافقا': u'وَافِقًا', #1
u'وافقنى': u'وَافَقَنِى', #2
u'وأفلاء': u'وَأَفْلَاءٍ', #2
u'وأفلاس': u'وَأَفْلَاسٍ', #1
u'وأفلاس': u'وَأَفْلَاسُ', #1
u'وافلاناه': u'وَافُلَانَاه', #1
u'وأفناء': u'وَأَفْنَاءٍ', #1
u'وأفناء': u'وَأَفْنَاءُ', #1
u'وأفنوا': u'وَأَفْنَوْا', #1
u'وأفنيت': u'وَأَفْنَيْتُ', #1
u'وأفنيت': u'وَأَفْنَيْت', #2
u'وأفهقته': u'وَأَفْهَقَتْهُ', #1
u'وأفهمنى': u'وَأَفْهَمَنِى', #1
u'وأفود': u'وَأَفْوَدُ', #1
u'وأفود': u'وَأَفْوَدَ', #3
u'وإقادة': u'وَإِقَادَةُ', #1
u'وأقاريرهم': u'وَأَقَارِيرِهِمْ', #2
u'وأقاصى': u'وَأَقَاصِى', #1
u'وأقالكها': u'وَأَقَالَكَهَا', #1
u'وإقام': u'وَإِقَامَ', #1
u'وإقام': u'وَإِقَامُ', #12
u'وإقام': u'وَإِقَام', #2
u'وإقام': u'وَإِقَامِ', #45
u'واقامة': u'وَاقَامَةُ', #1
u'وأقائل': u'وَأَقَائِلَ', #1
u'وأقائم': u'وَأَقَائِمٌ', #1
u'وإقباض': u'وَإِقْبَاضَ', #1
u'وإقباض': u'وَإِقْبَاضُ', #1
u'وإقباض': u'وَإِقْبَاضٍ', #19
u'وإقباض': u'وَإِقْبَاضٌ', #2
u'وإقباض': u'وَإِقْبَاضِ', #2
u'وإقباضا': u'وَإِقْبَاضًا', #5
u'وإقباضه': u'وَإِقْبَاضُهُ', #2
u'وإقباضه': u'وَإِقْبَاضِهِ', #6
u'وإقباضها': u'وَإِقْبَاضُهَا', #2
u'وإقباضها': u'وَإِقْبَاضَهَا', #5
u'وإقباضها': u'وَإِقْبَاضِهَا', #7
u'وإقباضهما': u'وَإِقْبَاضُهُمَا', #1
u'وإقبالى': u'وَإِقْبَالِى', #2
u'وأقبرا': u'وَأَقْبُرًا', #1
u'وأقبضا': u'وَأَقْبَضَا', #1
u'وأقبضاه': u'وَأَقْبَضَاهُ', #8
u'وأقبضاهما': u'وَأَقْبَضَاهُمَا', #1
u'وأقبضت': u'وَأَقْبَضْت', #1
u'وأقبضتك': u'وَأَقْبَضْتُك', #1
u'وأقبضته': u'وَأَقْبَضَتْهُ', #1
u'وأقبضته': u'وَأَقْبَضْتَهُ', #1
u'وأقبضته': u'وَأَقْبَضْته', #21
u'وأقبضته': u'وَأَقْبَضْتُهُ', #7
u'وأقبضنيه': u'وَأَقْبَضَنِيهِ', #1
u'وأقبضنيها': u'وَأَقْبَضَنِيهَا', #1
u'وأقتاب': u'وَأَقْتَابٍ', #3
u'وأقتابا': u'وَأَقْتَابًا', #1
u'وأقتابها': u'وَأْقَتَابَهَا', #1
u'وأقتابها': u'وَأَقْتَابِهَا', #9
u'واقتاره': u'وَاقْتَارَهُ', #1
u'واقتاسوه': u'وَاقْتَاسُوهُ', #2
u'واقتاف': u'وَاقْتَافَ', #2
u'واقتتبت': u'وَاقْتَتَبَتْ', #1
u'واقترأ': u'واقترأ', #1
u'واقتصه': u'وَاقْتَصَّهُ', #2
u'واقتضاض': u'وَاقْتِضَاضُ', #4
u'واقتوره': u'وَاقْتَوَرَهُ', #1
u'وأقحبت': u'وَأَقْحَبَتْ', #1
u'وأقحطت': u'وَأُقْحِطَتْ', #1
u'وأقحطنا': u'وَأَقْحَطْنَا', #1
u'واقد،': u'وَاقِد،', #1
u'واقد،': u'وَاقِدٌ،', #1
u'واقد': u'وَاقِدٌ', #11
u'واقد،': u'وَاقِدٍ،', #126
u'واقد': u'واقد', #17
u'واقد': u'وَاقِدَ', #2
u'واقد': u'وَاقِدٍ', #368
u'واقد': u'وَاقِدُ', #42
u'واقد': u'وَاقِدِ', #49
u'واقد،': u'واقد،', #7
u'واقد': u'وَاقِد', #8
u'واقدا': u'وَاقِدًا', #4
u'وإقدار': u'وَإِقْدَارٍ', #1
u'وإقدار': u'وَإِقْدَارِ', #3
u'وإقداره': u'وَإِقْدَارُهُ', #3
u'واقدة': u'وَاقِدَةَ', #1
u'واقدة': u'وَاقِدَةُ', #4
u'واقدحى': u'وَاقْدَحِى', #1
u'وأقدرته': u'وَأَقْدَرْته', #1
u'وأقدناك': u'وَأَقَدْنَاك', #1
u'وأقدناك': u'وَأَقَدْنَاكَ', #1
u'وأقذرنا': u'وَأَقْذَرَنَا', #1
u'واقرءوا': u'وَاقْرَءُوا', #15
u'واقرءوه': u'وَاقْرَءُوهُ', #2
u'واقرءوها': u'وَاقْرَءُوهَا', #1
u'واقرءوهم': u'وَاقْرَءُوهُمْ', #1
u'واقرإ': u'وَاقْرَإِ', #1
u'وأقراء': u'وَأَقْرَاءٌ', #1
u'وأقراء': u'وَأَقْرَاءِ', #1
u'وأقراء': u'وَأَقْرَاءٍ', #2
u'وأقراب': u'وَأَقْرَابٌ', #2
u'واقرار': u'وَاقَرَارٌ', #2
u'واقرار': u'وَاقَرَارُ', #3
u'وإقرارته': u'وَإِقْرَارَتُهُ', #1
u'واقران': u'وَاقِرَان', #1
u'واقرأوا': u'واقرأوا', #1
u'واقربت': u'وَاقْرَبَتِ', #1
u'وأقربية': u'وَأَقْرَبِيَّةُ', #2
u'وأقربيتهم': u'وَأَقْرَبِيَّتِهِمْ', #1
u'وأقرحة': u'وَأَقْرِحَةً', #2
u'وأقرحة': u'وَأَقْرِحَةٍ', #3
u'وأقرحة': u'وَأَقْرِحَةٌ', #7
u'وأقرطة': u'وَأَقْرِطَةٌ', #1
u'وأقرؤ': u'وَأَقْرُؤٍ', #3
u'واقرؤا': u'واقرؤا', #1
u'وأقضاؤه': u'وَأَقْضَاؤُهُ', #1
u'واقضى': u'وَاقَضَى', #1
u'وأقطا،': u'وَأَقِطًا،', #1
u'وأقطا': u'وَأَقِطًا', #9
u'وأقطاعهم': u'وَأَقْطَاعِهِمْ', #1
u'وأقفزة': u'وَأَقْفِزَةٍ', #1
u'وأقفزة': u'وَأَقْفِزَةِ', #2
u'واقلة': u'وَاقِلَّةَ', #1
u'وأقلوا': u'وَأَقَلُّوا', #1
u'وأقلوا': u'وَأَقِلُّوا', #1
u'واقم': u'وَاقِمٌ', #1
u'واقم،': u'وَاقِمَ،', #1
u'واقم': u'وَاقِمٍ', #6
u'وأقنان': u'وَأَقْنَانٍ', #1
u'وأقنة': u'وَأَقِنَّةٍ', #6
u'وأقنيت': u'وَأَقْنَيْت', #1
u'وأقنيت': u'وَأَقْنَيْتَ', #3
u'واقول': u'وَاقَوْلُ', #1
u'واقوماه': u'وَاقَوْمَاه', #2
u'واقومي': u'وَاقَوْمِي', #1
u'وأقيال': u'وَأَقْيَالْ', #2
u'وإكارتها': u'وَإِكَارَتُهَا', #1
u'واكاسباه': u'وَاكَاسِبَاهُ', #2
u'وإكاف': u'وَإِكَافٍ', #6
u'وإكافه': u'وَإِكَافُهُ', #1
u'وإكافه': u'وَإِكَافِهِ', #1
u'وإكافها': u'وَإِكَافِهَا', #1
u'وإكاك': u'وَإِكَاكُ', #1
u'وإكام': u'وَإِكَامٍ', #1
u'وإكام': u'وَإِكَامٌ', #2
u'وأكاميم': u'وَأَكَامِيمُ', #4
u'وأكاويبه': u'وَأَكَاوِيبُهُ', #1
u'وأكبار': u'وَأَكْبَارٍ', #1
u'واكتبنى': u'وَاكْتُبْنِى', #1
u'واكتحال': u'وَاكْتِحَالً', #1
u'واكتسع': u'وَاكْتَسَعَ', #2
u'واكتفأه': u'وَاكْتَفَأَهُ', #1
u'واكتن': u'وَاكْتَنّ', #1
u'واكذا': u'وَاكَذَا', #3
u'وأكرار': u'وَأَكْرَارُ', #1
u'واكران': u'واكران', #1
u'واكرمجاهري': u'واكرمجاهري', #1
u'واكرويرا': u'واكرويرا', #1
u'وأكرية': u'وَأَكْرِيَةِ', #1
u'واكريماه': u'وَاكَرِيمَاه', #1
u'واكريماه': u'وَاكَرِيمَاهُ', #1
u'وأكساب': u'وَأَكْسَابَ', #1
u'وأكساب': u'وَأَكْسَابُ', #1
u'وأكساب': u'وَأَكْسَابِ', #1
u'وأكسابه': u'وَأَكْسَابَهُ', #1
u'وأكسابه': u'وَأَكْسَابِهِ', #10
u'وأكسابه': u'وَأَكْسَابُهُ', #6
u'وأكسابها': u'وَأَكْسَابُهَا', #2
u'وأكسابها': u'وَأَكْسَابِهَا', #3
u'وأكسابهم': u'وَأَكْسَابُهُمْ', #1
u'وأكسابهم': u'وَأَكْسَابِهِمْ', #1
u'واكسى': u'وَاكْسِى', #1
u'وآكف': u'وَآكَفَ', #1
u'وأكفاه': u'وَأَكْفَاهُ', #1
u'وأكفاهما': u'وَأَكْفَاهُمَا', #1
u'وأكفت': u'وَأَكْفِتُ', #1
u'وأكفتوا': u'وَأَكْفِتُوا', #1
u'واكففي': u'وَاكْفُفِي', #1
u'وأكفلنيها': u'وَأَكْفِلْنِيهَا', #1
u'واكفئوا': u'وَاكْفِئُوا', #1
u'واكمال': u'وَاكَمَالِ', #1
u'وأكمنت': u'وَأَكْمَنْتُ', #1
u'وأكهب': u'وَأَكْهَبُ', #1
u'واكهفاه': u'وَاكَهْفَاه', #2
u'واكهفاه': u'وَاكَهْفَاهْ', #2
u'واكهفاه': u'وَاكَهْفَاهُ', #3
u'واكوابي': u'واكوابي', #1
u'وأكيدر': u'وَأُكَيْدَرٌ', #1
u'وأكيدر': u'وَأُكَيْدِرٌ', #1
u'وأكيدر': u'وَأُكَيْدِرِ', #1
u'وأكيدر': u'وَأُكَيْدِرَ', #2
u'والاب': u'وَالَابُّ', #2
u'والإبا': u'وَالإِبَا', #1
u'والأباءة': u'وَالْأَبَاءَةُ', #1
u'والإباحه': u'والإباحه', #4
u'والإبار': u'والإبَار', #1
u'والإبار': u'وَالْإِبَارِ', #1
u'والإبار': u'وَالْإِبَّارُ', #1
u'والإبار': u'وَالْإِبَّارِ', #2
u'والإبار': u'وَالْإِبَارُ', #5
u'والأباريز': u'والْأَبَارِيزِ', #1
u'والإباق': u'وَالْإِبَاق', #2
u'والإباق': u'وَالْإِبَاقُ', #41
u'والإباق': u'وَالْإِبَاقِ', #55
u'والإباق': u'وَالْإِبَاقَ', #6
u'والأباهر': u'وَالْأَبَاهِرِ', #1
u'والإباية': u'وَالْإِبَايَةِ', #7
u'والابتدال': u'والابتدال', #1
u'والابتغاوية': u'والابتغاوية', #3
u'والابتهار': u'وَالِابْتِهَارُ', #1
u'والأبخر': u'وَالْأَبْخَرُ', #2
u'والإبداد': u'وَالْإِبْدَادُ', #1
u'والأبدانا': u'وَالْأَبْدَانَا', #1
u'والأبذوي': u'وَالْأَبْذَوِيُّ', #1
u'والآبر': u'وَالْآبِرُ', #1
u'والأبر': u'وَالْأَبَرْ', #1
u'والإبراد': u'وَالْإِبْرَادُ', #10
u'والإبراد': u'وَالْإِبْرَادِ', #5
u'والأبرة': u'وَالْأَبِرَةِ', #1
u'والأبرد': u'وَالأَبْرَدُ', #1
u'والأبرق': u'وَالْأَبْرَقُ', #1
u'والأبرئة': u'وَالْأَبْرِئَةُ', #1
u'والآبرية': u'وَالْآبُرِيَّةِ', #1
u'والإبريسم': u'وَالِإِبْرَيْسَمِ', #1
u'والإبريسم': u'وَالْإِبْرَيْسَمَ', #1
u'والإبريسم': u'وَالْإِبْرَيْسَمْ', #1
u'والإبريسم': u'وَالْإِبْرَيْسَمُ', #12
u'والإبريسم': u'وَالْإِبْرَيْسَمِ', #16
u'والإبريسم': u'وَالْإِبْرَيْسِمِ', #2
u'والأبسطة': u'وَالْأَبْسِطَةِ', #1
u'والإبضاع': u'وَالْإِبْضَاعِ', #11
u'والإبضاع': u'وَالْإِبْضَاعُ', #19
u'والأبضاع': u'وَالْأَبْضَاعِ', #20
u'والإبضاع': u'وَالْإِبْضَاعَ', #7
u'والأبضاع': u'وَالْأَبْضَاعُ', #8
u'والإبعاض': u'وَالْإِبْعَاضِ', #1
u'والأبق': u'وَالْأَبَقُ', #1
u'والآبق': u'وَالْآبِقَ', #4
u'والآبق': u'وَالْآبِقُ', #42
u'والآبق': u'وَالْآبِقِ', #50
u'والأبقا': u'وَالْأَبْقَا', #1
u'والإبقاق': u'وَالْإِبْقَاقِ', #1
u'والآبقة': u'وَالْآبِقَةُ', #1
u'والآبقة': u'وَالْآبِقَةِ', #1
u'والأبقع': u'وَالْأَبْقَعَ', #1
u'والأبقع': u'وَالْأَبْقَعُ', #12
u'والأبقع': u'وَالْأَبْقَعِ', #6
u'والأبقور': u'وَالْأَبْقُورُ', #1
u'والأبلة،': u'والأُبُلَّة،', #1
u'والأبلغية': u'وَالْأَبْلَغِيَّةُ', #5
u'والأبن': u'وَالْأَبْنُ', #1
u'والأبنة': u'وَالْأُبْنَةُ', #2
u'والآبنس': u'وَالْآبُنُسِ', #1
u'والأبنوس': u'وَالْأَبَنُوسَ', #1
u'والأبنوس': u'وَالْأَبَنُوسِ', #11
u'والأبنوس': u'وَالْأَبَنُوسُ', #2
u'والأبواء': u'وَالأَبْوَاءِ', #1
u'والأبواء': u'وَالْأَبْوَاءُ', #2
u'والأبواء': u'وَالْأَبْوَاءِ', #2
u'والأبوار': u'والأبوار', #2
u'والأبود': u'وَالْأُبُودِ', #1
u'والأبياري': u'وَالْأَبْيَارِيُّ', #1
u'والأبياري': u'وَالْأَبْيَارِيِّ', #1
u'والإبياري': u'وَالْإِبْيَارِيُّ', #6
u'والأبياني': u'وَالْأَبْيَانِيّ', #1
u'والأبياني': u'وَالْأَبْيَانِيُّ', #1
u'والأبيل': u'وَالْأَبِيلِ', #1
u'والإبيل': u'وَالْإِبِيلِ', #1
u'والأتانة': u'وَالْأَتَانَةُ', #3
u'والأتاوي': u'وَالْأَتَاوِيُّ', #1
u'والأتبار': u'وَالْأَتْبَارِ', #1
u'والإتبار': u'وَالْإِتْبَارُ', #2
u'والأتجر': u'وَالْأَتْجُرُ', #1
u'والأتحمية': u'وَالْأَتْحَمِيّةُ', #1
u'والأترنج': u'وَالْأُتْرُنْجِ', #2
u'والأتريبي': u'وَالْأَتْرِيبِيُّ', #1
u'والأتريبي': u'وَالْأَتْرِيبِيِّ', #1
u'والإتساع': u'وَالْإِتْسَاعِ', #1
u'والأتقاني': u'وَالْأَتْقَانِيِّ', #2
u'والأتقاني': u'وَالْأَتْقَانِيُّ', #7
u'والأتك': u'وَالْأَتَكُ', #1
u'والأتلد': u'وَالْأَتْلَدُ', #1
u'والاتهاب': u'وَالِاتِّهَابُ', #17
u'والاتهاب': u'وَالِاتِّهَابِ', #34
u'والآتيه': u'وَالْآتِيَهْ', #1
u'والإثاث': u'وَالْإِثَاثِ', #1
u'والأثانين': u'وَالْأَثَانِينَ', #1
u'والأثبت': u'وَالأَثْبَتُ', #1
u'والأثبت': u'وَالْأَثْبَتِ', #1
u'والأثبت': u'وَالْأَثْبَتُ', #3
u'والاثخان': u'والاثخان', #1
u'والأثرم': u'وَالْأَثْرَمِ', #25
u'والأثرم': u'وَالْأَثْرَمُ', #88
u'والأثفال': u'وَالْأَثْفَالُ', #2
u'والأثم': u'وَالْأَثِم', #1
u'والأثم': u'وَالْأَثِمُ', #2
u'والإثمد': u'وَالْإِثْمِد', #1
u'والإثمد': u'وَالْإِثْمِدُ', #1
u'والإثمد': u'وَالْإِثْمِدِ', #2
u'والاثنا': u'وَالِاثْنَا', #33
u'والاثنتي': u'وَالْاثْنَتَيْ', #1
u'والاثني': u'وَالِاثْنَيْ', #16
u'والأثنين': u'والأثنين', #1
u'والإجابه': u'وَالْإِجَابَهْ', #1
u'والإجاح': u'وَالْإِجَاحِ', #1
u'والإجاحة': u'وَالْإِجَاحَةِ', #1
u'والإجاز': u'وَالْإِجَاز', #1
u'والإجانات': u'وَالْإِجَّانَاتِ', #4
u'والإجانات': u'وَالْإِجَّانَاتُ', #5
u'والأجانة': u'وَالْأَجَانَةِ', #1
u'والأجانة': u'وَالْأَجَّانَةِ', #1
u'والإجباء': u'وَالإِجْبَاءُ', #1
u'والاجتزاء': u'وَالِاجْتِزَاءِ', #1
u'والإجتماع': u'والإجتماع', #1
u'والاجتنان': u'وَالِاجْتِنَانُ', #4
u'والأجدح': u'وَالْأَجْدَحِ', #1
u'والإجذاع': u'وَالْإِجْذَاعُ', #1
u'والإجذاع': u'وَالْإِجْذَاعِ', #2
u'والإجرياء': u'وَالْإِجْرِيّاءُ', #1
u'والأجزئية': u'وَالْأَجْزَئِيَّةُ', #1
u'والأجزية': u'وَالْأَجْزِيَةِ', #2
u'والأجزية': u'وَالْأَجْزِيَةُ', #3
u'والأجلاب': u'وَالْأَجْلَابُ', #1
u'والأجلح': u'وَالأَجْلَحُ', #1
u'والأجلح،': u'وَالأَجْلَحِ،', #1
u'والأجلح': u'وَالْأَجْلَحُ', #1
u'والإجمار': u'وَالْإِجْمَارِ', #3
u'والإجمار': u'وَالْإِجْمَارُ', #6
u'والأجملية': u'وَالْأَجْمَلِيَّةُ', #1
u'والأجنات': u'وَالْأَجِنَاتُ', #1
u'والأجنب': u'وَالْأَجْنَبُ', #1
u'والأجهر': u'وَالْأَجْهَرُ', #4
u'والأجهوري': u'وَالْأُجْهُورِيَّ', #2
u'والأجهوري': u'وَالْأُجْهُورِيُّ', #6
u'والأجهوري': u'وَالْأُجْهُورِيِّ', #7
u'والأحاوم': u'وَالْأَحَاوِمُ', #1
u'والأحائم': u'وَالْأَحَائِمِ', #3
u'والإحباء': u'وَالْإِحْبَاءِ', #2
u'والأحبل': u'وَالْأَحْبُلِ', #3
u'والاحتباك': u'وَالِاحْتِبَاكُ', #1
u'والاحتجام': u'وَالِاحْتِجَامِ', #2
u'والاحتزام': u'وَالِاحْتِزَامِ', #2
u'والاحتشاء': u'وَالِاحْتِشَاءُ', #1
u'والاحتشاش': u'وَالِاحْتِشَاشُ', #13
u'والاحتشاش': u'وَالِاحْتِشَاشَ', #3
u'والاحتشاش': u'وَالِاحْتِشَاشِ', #43
u'والاحتظار': u'وَالِاحْتِظَار', #1
u'والأحتم': u'وَالْأَحْتَمُ', #1
u'والاحتواش': u'وَالِاحْتِوَاشُ', #2
u'والاحتياز': u'وَالِاحْتِيَازِ', #1
u'والإحجاج': u'وَالْإِحْجَاجِ', #1
u'والإحجاج': u'وَالْإِحْجَاجُ', #2
u'والأحداثا': u'وَالْأَحْدَاثَا', #2
u'والأحداد': u'وَالْأَحْدَادِ', #1
u'والإحداد': u'وَالْإِحْدَادَ', #1
u'والإحداد': u'وَالْإِحْدَادِ', #14
u'والإحداد': u'وَالْإِحْدَاد', #2
u'والإحداد': u'وَالْإِحْدَادُ', #22
u'والإحدار': u'وَالْإِحْدَارُ', #1
u'والإحدى': u'وَالْإِحْدَى', #8
u'والأحراس،': u'والأحراس،', #1
u'والأحرد': u'وَالْأَحْرَدُ', #1
u'والأحروية': u'وَالْأَحْرَوِيَّةُ', #1
u'والأحسنية': u'وَالْأَحْسَنِيَّةُ', #2
u'والأحشاف': u'وَالْأَحْشَافُ', #1
u'والإحصار': u'وَالْإِحْصَارُ', #18
u'والإحصار': u'وَالْإِحْصَارِ', #46
u'والأحصال': u'وَالْأَحْصَالِ', #1
u'والأحضار': u'وَالْأَحْضَارِ', #1
u'والإحضان': u'وَالْإِحْضَانُ', #1
u'والأحظ': u'وَالْأَحَظَّ', #1
u'والأحظ': u'وَالْأَحَظُّ', #2
u'والإحفاء': u'وَالْإِحْفَاءَ', #2
u'والإحفاء': u'وَالْإِحْفَاء', #4
u'والإحفاء': u'وَالْإِحْفَاءُ', #4
u'والأحفظ': u'وَالْأَحْفَظَ', #1
u'والأحفظ': u'وَالْأَحْفَظُ', #3
u'والأحقاف': u'وَالأَحْقَافُ', #5
u'والأحقم': u'وَالْأَحْقَمُ', #1
u'والأحكاميون': u'والأحْكامِيُّونَ', #1
u'والأحل': u'وَالْأَحَلُّ', #1
u'والأحم': u'وَالْأَحَمُّ', #1
u'والأحمسي،': u'والأَحْمَسِيُّ،', #1
u'والأحمسي': u'وَالأَحْمَسِيِّ', #1
u'والأحمسي،': u'وَالأَحْمَسِيِّ،', #1
u'والأحمسي،': u'وَالأَحْمَسِيُّ،', #2
u'والأحموقة': u'وَالْأُحْمُوقَةُ', #1
u'والإحواء': u'وَالْإِحْوَاءِ', #1
u'والأحوام': u'وَالْأَحْوَامُ', #1
u'والأحوط': u'وَالْأَحْوَطَ', #1
u'والأحوط': u'وَالْأَحْوَطُ', #204
u'والأحوط': u'وَالْأَحْوَطِ', #4
u'والأحوى': u'وَالْأَحْوَى', #1
u'والأحياز': u'وَالْأَحْيَازُ', #1
u'والأخاشب': u'وَالْأَخَاشِبُ', #1
u'والأخافيق': u'وَالْأَخَافِيقُ', #1
u'والأخاقيق': u'وَالْأَخَاقِيقُ', #1
u'والإخباز': u'وَالْإِخْبَازُ', #1
u'والأخباز': u'وَالْأَخْبَازُ', #2
u'والأخباز': u'وَالْأَخْبَازِ', #7
u'والاختلاع': u'وَالِاخْتِلَاعُ', #1
u'والاختلاع': u'وَالِاخْتِلَاعِ', #4
u'والاختيارة': u'وَالِاخْتِيَارَةَ', #1
u'والاختيارة': u'وَالِاخْتِيَارَةُ', #1
u'والاختيارة': u'وَالِاخْتِيَارَةِ', #1
u'والإخدام': u'وَالْإِخْدَامِ', #16
u'والإخدام': u'وَالْإِخْدَامُ', #17
u'والإخدام': u'وَالْإِخْدَامَ', #6
u'والأخدع': u'وَالْأَخْدَعُ', #1
u'والإخراق': u'وَالْإِخْرَاقُ', #1
u'والآخرية': u'وَالْآخِرِيَّةَ', #2
u'والآخرية': u'وَالْآخِرِيَّةُ', #5
u'والآخرية': u'وَالْآخِرِيَّةِ', #6
u'والإخساس': u'وَالْإِخْسَاسِ', #1
u'والأخسمة': u'والأخسمة', #1
u'والأخشم': u'وَالْأَخْشَمُ', #1
u'والإخصاء': u'وَالإِخْصَاءُ', #1
u'والإخصاء': u'وَالإِخْصَاءِ', #1
u'والإخصاء': u'وَالْإِخْصَاءِ', #1
u'والإخصاء': u'وَالْإِخْصَاءُ', #3
u'والأخصر': u'وَالْأَخْصَرُ', #31
u'والأخصر': u'وَالْأَخْصَرِ', #6
u'والأخصرية': u'وَالْأَخْصَرِيَّةُ', #1
u'والأخصية': u'وَالْأَخَصِّيَّةِ', #1
u'والأخصية': u'وَالْأَخَصِّيَّةَ', #4
u'والأخصية': u'وَالْأَخَصِّيَّةُ', #9
u'والإخفات': u'وَالإِخفاتِ', #1
u'والإخفات': u'وَالْإِخْفَاتَ', #2
u'والإخفات': u'وَالْإِخْفَاتِ', #5
u'والإخفات': u'وَالْإِخْفَاتُ', #7
u'والإخفار': u'وَالْإِخْفَارُ', #1
u'والأخفافي': u'وَالْأَخْفَافِيِّ', #1
u'والإخلاصقوله': u'وَالإِخْلاصِقَولُهُ', #1
u'والإخلاط': u'وَالْإِخْلَاطِ', #1
u'والإخلاق': u'وَالْإِخْلَاقُ', #1
u'والإخلاق': u'وَالْإِخْلَاقِ', #1
u'والأخلص': u'وَالْأَخْلَصُ', #4
u'والإخوه': u'وَالْإِخْوَهْ', #1
u'والأخيذة': u'وَالْأَخِيذَةِ', #1
u'والأخيل': u'وَالْأَخْيَلِ', #1
u'والأداف': u'وَالْأُدَافُ', #1
u'والإدبارة': u'وَالْإِدْبَارَةُ', #1
u'والإدبارة': u'وَالْإِدْبَارَةِ', #1
u'والأدحر': u'وَالْأَدْحَرُ', #1
u'والإدخار': u'وَالْإِدْخَارِ', #3
u'والآدر': u'وَالْآدَرُ', #1
u'والأدر': u'وَالْأَدَرِ', #1
u'والأدر': u'وَالْأَدَرُ', #2
u'والأدراع': u'وَالْأَدْرَاعُ', #1
u'والأدراع': u'وَالْأَدْرَاعِ', #1
u'والأدرة': u'وَالْأُدْرَةِ', #1
u'والأدرة': u'وَالْأُدْرَةُ', #4
u'والأدرم': u'وَالْأَدْرَمُ', #2
u'والادعام': u'وَالاِدِّعَامَ', #1
u'والأدعج': u'وَالْأَدْعَجُ', #1
u'والأدعى': u'وَالْأَدْعَى', #1
u'والإدلال': u'وَالْإِدْلَالَ', #2
u'والإدلال': u'وَالْإِدْلَالُ', #2
u'والإدلال': u'وَالْإِدْلَالِ', #3
u'والأدلم': u'وَالْأَدْلَمُ', #1
u'والأدلية': u'وَالْأَدِلِّيَّةُ', #1
u'والآدم': u'وَالْآدَمُ', #3
u'والإدهان': u'والإدهان', #1
u'والإدهان': u'وَالْإِدْهَان', #1
u'والإدهان': u'وَالْإِدْهَانُ', #1
u'والإدهان': u'وَالْإِدْهَانِ', #1
u'والادهان': u'وَالِادِّهَانَ', #1
u'والادهان': u'وَالِادِّهَانُ', #12
u'والادهان': u'وَالِادِّهَانِ', #15
u'والإدوار': u'وَالْإِدْوَارُ', #1
u'والأدوم': u'وَالْأَدْوَمُ', #1
u'والأدون': u'وَالْأَدْوَنَ', #1
u'والأدون': u'وَالْأَدْوَنُ', #4
u'والأدون': u'وَالْأَدْوَنِ', #4
u'والأدين': u'وَالْأَدْيَنُ', #1
u'والأدين': u'وَالْأَدْيَنِ', #1
u'والإذاية': u'وَالْإِذَايَةَ', #2
u'والإذاية': u'وَالْإِذَايَةُ', #4
u'والإذاية': u'وَالْإِذَايَةِ', #7
u'والإذخر': u'وَالْإِذْخِر', #1
u'والإذخر': u'وَالْإِذْخِرُ', #13
u'والإذخر': u'وَالْإِذْخِرَ', #2
u'والإذخر': u'وَالْإِذْخِرِ', #9
u'والإذراع': u'وَالْإِذْرَاعِ', #2
u'والأذرعي': u'وَالْأَذْرَعِيِّ', #1
u'والأذرعي': u'وَالْأَذْرَعِيّ', #1
u'والأذرعي': u'وَالْأَذْرَعِيُّ', #198
u'والأذرعي': u'وَالْأَذْرَعِيِّ', #48
u'والأذرعي': u'وَالْأَذْرَعِيَّ', #6
u'والأذنيييي': u'وَالْأُذُنَيييي', #1
u'والأذواد': u'وَالأَذْوَادِ', #1
u'والأذىSمتى': u'وَالْأَذَىSمَتَى', #1
u'والإراءة': u'وَالْإِرَاءَةِ', #1
u'والإراده': u'وَالإرَادَهْ', #1
u'والإراشي': u'وَالْإِرَاشِيّ', #2
u'والأراضى': u'وَالأَرَاضِى', #1
u'والأربعا': u'وَالْأَرْبَعَا', #1
u'والأربعا': u'وَالْأَرْبِعَا', #1
u'والأربعيات': u'وَالْأَرْبَعِيَّات', #1
u'والأربية': u'وَالْأُرْبِيَّةِ', #1
u'والأرت': u'وَالْأَرَتَّ', #2
u'والأرت': u'وَالْأَرَتُّ', #5
u'والارتثاث': u'وَالِارْتِثَاثُ', #8
u'والارتضاع': u'وَالِارْتِضَاعِ', #3
u'والارتضاع': u'وَالِارْتِضَاعُ', #9
u'والارتفاض': u'وَالِارْتِفَاضُ', #1
u'والارتفاض': u'وَالِارْتِفَاضَ', #2
u'والإرتفاق': u'والإرتفاق', #1
u'والارتفاق': u'وَالِارْتِفَاقَ', #1
u'والارتفاق': u'وَالِارْتِفَاقِ', #18
u'والارتفاق': u'وَالِارْتِفَاقُ', #7
u'والارتيابقيس': u'وَالِارْتِيَابِقَيْسُ', #1
u'والارتياض': u'وَالِارْتِيَاضَ', #1
u'والارتياض': u'وَالِارْتِيَاضُ', #1
u'والارتياض': u'وَالِارْتِيَاضِ', #2
u'والأرث': u'وَالْأَرَثَّ', #1
u'والأرثم': u'وَالْأَرْثَمُ', #1
u'والأرحبية': u'وَالْأَرْحَبِيّة', #1
u'والأرحبية': u'وَالْأَرْحَبِيّةُ', #1
u'والأرحبية': u'وَالْأَرْحَبِيّةِ', #1
u'والأرحبية': u'وَالْأَرْحَبِيَّةِ', #1
u'والأرحبية': u'وَالْأَرْحَبِيَّةُ', #4
u'والأرحي': u'والأرحي', #1
u'والأرحى': u'والأرحى', #1
u'والأرحية': u'وَالْأَرْحِيَةَ', #1
u'والأرد،': u'وَالْأَرْدُ،', #1
u'والإرداع': u'وَالْإِرْدَاعُ', #1
u'والإردب': u'وَالْإِرْدَبَّ', #1
u'والإردب': u'وَالْإِرْدَبِّ', #3
u'والإردب': u'وَالْإِرْدَبُّ', #6
u'والأردبيلي': u'والأردبيلي', #1
u'والإردبين': u'وَالْإِرْدَبَّيْنِ', #1
u'والأردئية': u'وَالْأَرْدَئِيَّةِ', #2
u'والارسان': u'وَالْارسان', #1
u'والأرش': u'وَالأَرْشَ', #1
u'والأرش،': u'وَالأَرْشُ،', #1
u'والأرش': u'وَالْأَرْشُ', #153
u'والأرش': u'وَالْأَرْشِ', #167
u'والأرش': u'وَالْأَرْشَ', #34
u'والأرشدية': u'وَالْأَرْشَدِيَّةُ', #1
u'والأرشين': u'وَالْأَرْشَيْنِ', #7
u'والآرض؟': u'والآرض؟', #1
u'والارض': u'والارض', #1
u'والإرغاب': u'وَالْإِرْغَابِ', #2
u'والأرغياني': u'والأرغياني', #3
u'والأرف': u'وَالأُرَفُ', #1
u'والأرفاض': u'وَالْأَرْفَاضِ', #1
u'والأرفاق': u'وَالْأَرْفَاقِ', #3
u'والأرفق': u'وَالْأَرْفَقِ', #3
u'والأرفق': u'وَالْأَرْفَقُ', #9
u'والإرقاب': u'وَالْإِرْقَابُ', #1
u'والإرقاق': u'وَالْإِرْقَاقَ', #1
u'والإرقاق': u'وَالْإِرْقَاقُ', #4
u'والإرقاق': u'وَالْإِرْقَاقِ', #5
u'والأرماك': u'وَالْأَرْمَاكُ', #1
u'والإرمام': u'وَالْإِرْمَامُ', #1
u'والأروح': u'والأروح', #1
u'والأروش': u'وَالْأُرُوشُ', #4
u'والأروض': u'وَالْأُرُوضَ', #1
u'والأريسح': u'وَالْأُرَيْسِحُ', #1
u'والأريسيون': u'وَالْأَرِيسِيُّونَ', #1
u'والأريسيين': u'وَالْأَرِيسِيِّينَ', #1
u'والأريصح': u'وَالْأُرَيْصِحُ', #1
u'والأزارقة': u'وَالْأَزَارِقَةُ', #1
u'والأزب': u'وَالْأَزَبّ', #1
u'والأزب': u'وَالْأَزَبُّ', #1
u'والأزج': u'وَالْأَزَجِ', #1
u'والأزجي': u'وَالْأَزَجِيُّ', #19
u'والأزجي': u'وَالْأَزَجِيِّ', #2
u'والأزد': u'وَالأَزْدُ', #2
u'والأزد': u'وَالْأَزْدُ', #3
u'والازدراع': u'وَالِازْدِرَاعُ', #10
u'والازدراع': u'وَالِازْدِرَاعِ', #28
u'والازدلاف': u'وَالِازْدِلَافُ', #6
u'والأزدي،': u'وَالأَزْدِيُّ،', #1
u'والأزدي': u'وَالْأُزْدِيّ', #1
u'والأزدي': u'وَالْأَزْدِيُّ', #8
u'والأزرة': u'وَالْأُزْرَةِ', #1
u'والإزرة': u'وَالْإِزْرَةُ', #1
u'والأزرة': u'وَالْأُزْرَةُ', #4
u'والأزرقي': u'وَالْأَزْرَقِيُّ', #1
u'والأزرقي': u'وَالْأَزْرَقِيِّ', #1
u'والأزلف': u'وَالْأَزْلَفُ', #1
u'والأزمل': u'وَالْأَزْمَلُ', #1
u'والأزيب': u'وَالْأَزْيَبُ', #3
u'والأسا': u'وَالْأَسَا', #1
u'والإسآد': u'وَالْإِسْآدُ', #1
u'والإسادة': u'وَالْإِسَادَةِ', #1
u'والأسارى': u'وَالأَسَارَى', #1
u'والأسارى': u'وَالأُسَارَى', #1
u'والأسارى': u'وَالْأُسَارَى', #8
u'والأسامات': u'وَالْأُسَامَاتِ', #1
u'والإسامة': u'وَالْإِسَامَةُ', #4
u'والإسامة': u'وَالْإِسَامَةِ', #7
u'والأسبطة': u'وَالْأَسْبِطَةِ', #1
u'والأسبك': u'وَالْأَسْبَكِ', #1
u'والأسبك': u'وَالْأَسْبَكُ', #2
u'والأسبلة': u'وَالْأَسْبِلَةِ', #1
u'والإسبهدية': u'والإسبهدية', #1
u'والإسبيجابي': u'وَالْإِسْبِيجَابِيّ', #2
u'والإسبيجابي': u'والإسبيجابي', #40
u'والإست': u'وَالْإِسْتُ', #1
u'والاست': u'وَالِاسْت', #1
u'والاست': u'وَالِاسْتُ', #1
u'والاست': u'وَالِاسْتِ', #4
u'والأستاء': u'وَالْأَسْتَاءُ', #1
u'والإستار': u'وَالْإِسْتَارُ', #4
u'والاستبضاع': u'وَالِاسْتِبْضَاعُ', #2
u'والاستتابة': u'وَالِاسْتِتَابَةِ', #2
u'والاستتابة': u'وَالِاسْتِتَابَةُ', #4
u'والاستثبات': u'وَالِاسْتِثْبَاتُ', #1
u'والاستثبات': u'وَالِاسْتِثْبَاتِ', #1
u'والاستثفار': u'وَالِاسْتِثْفَارِ', #1
u'والاستثفار': u'وَالِاسْتِثْفَار', #2
u'والاستثفار': u'وَالِاسْتِثْفَارُ', #2
u'والاستثنا': u'وَالِاسْتِثْنَا', #1
u'والاستجرار': u'وَالِاسْتِجْرَارُ', #1
u'والاستجرار': u'وَالِاسْتِجْرَارَ', #2
u'والاستجمار': u'وَالاِسْتِجْمَارِ', #1
u'والاستجمار': u'وَالِاسْتِجْمَارُ', #21
u'والاستجمار': u'وَالِاسْتِجْمَارِ', #9
u'والاستحاضة': u'وَالاسْتِحَاضَةِ', #1
u'والاستحاضة': u'وَالِاسْتِحَاضَة', #1
u'والاستحاضة': u'وَالِاسْتِحَاضَةَ', #3
u'والاستحاضة': u'وَالِاسْتِحَاضَةُ', #49
u'والاستحاضة': u'وَالِاسْتِحَاضَةِ', #61
u'والإستحداد،': u'وَالإِسْتِحْدَادُ،', #1
u'والاستحداد،': u'وَالاسْتِحْدَادُ،', #2
u'والاستحداد': u'وَالِاسْتِحْدَاد', #3
u'والاستحداد': u'وَالِاسْتِحْدَادُ', #30
u'والاستحداد': u'وَالاِسْتِحْدَادُ', #5
u'والاستحداد': u'وَالِاسْتِحْدَادِ', #9
u'والاستحشاف': u'وَالِاسْتِحْشَافُ', #2
u'والإستحضار،': u'وَالإِسْتِحْضَارِ،', #1
u'والاستحكار': u'وَالِاسْتِحْكَارُ', #1
u'والاستخباث': u'وَالِاسْتِخْبَاثِ', #3
u'والاستخذاء': u'وَالاسْتِخْذَاءُ', #1
u'والاستدخال': u'وَالِاسْتِدْخَالِ', #16
u'والاستدخال': u'وَالِاسْتِدْخَالُ', #4
u'والاستذلال': u'وَالِاسْتِذْلَالُ', #2
u'والاسترباء': u'وَالِاسْتِرْبَاءُ', #1
u'والاسترباح': u'وَالِاسْتِرْبَاحَ', #1
u'والاسترباح': u'وَالِاسْتِرْبَاحِ', #10
u'والاسترباح': u'وَالِاسْتِرْبَاحُ', #11
u'والاسترذال': u'وَالِاسْتِرْذَالِ', #1
u'والاسترقاء': u'وَالِاسْتِرْقَاء', #1
u'والاسترقاء': u'وَالِاسْتِرْقَاءُ', #1
u'والاسترقاء': u'وَالِاسْتِرْقَاءِ', #1
u'والاسترقاء': u'وَالاِسْتِرْقَاءِ', #1
u'والاسترقاق': u'وَالِاسْتِرْقَاقَ', #1
u'والاسترقاق': u'وَالِاسْتِرْقَاقُ', #21
u'والاسترقاق': u'وَالِاسْتِرْقَاقِ', #48
u'والإستروشني': u'والإستروشني', #1
u'والاستزكاء': u'وَالِاسْتِزْكَاءِ', #3
u'والاستسعاء': u'وَالِاسْتِسْعَاء', #1
u'والاستسعاء': u'وَالِاسْتِسْعَاءُ', #21
u'والاستسعاء': u'وَالِاسْتِسْعَاءِ', #50
u'والاستسعاء': u'وَالِاسْتِسْعَاءَ', #7
u'والاستسعاط': u'وَالِاسْتِسْعَاطِ', #2
u'والاستسماح': u'وَالِاسْتِسْمَاحِ', #1
u'والإستشراف': u'والإستشراف', #1
u'والاستصناع': u'وَالِاسْتِصْنَاعَ', #1
u'والاستصناع': u'وَالِاسْتِصْنَاعُ', #12
u'والاستصناع': u'وَالِاسْتِصْنَاعِ', #5
u'والاستضحاء': u'وَالِاسْتِضْحَاءِ', #1
u'والاستضرار': u'وَالِاسْتِضْرَارَ', #1
u'والاستطراق': u'وَالِاسْتِطْرَاقَ', #1
u'والاستطراق': u'وَالِاسْتِطْرَاقُ', #4
u'والاستطراق': u'وَالِاسْتِطْرَاقِ', #5
u'والاستطهار': u'وَالِاسْتِطْهَارُ', #1
u'والاستعاط': u'وَالِاسْتِعَاطَ', #1
u'والاستعاط': u'وَالِاسْتِعَاطُ', #1
u'والاستعذار': u'وَالِاسْتِعْذَارِ', #1
u'والاستغزار': u'وَالِاسْتِغْزَار', #1
u'والاستغزار': u'وَالِاسْتِغْزَارِ', #1
u'والاستغزال': u'وَالِاسْتِغْزَالِ', #1
u'والاستغنام': u'وَالِاسْتِغْنَام', #1
u'والاستغنام': u'وَالِاسْتِغْنَامِ', #6
u'والاستفراخ': u'وَالِاسْتِفْرَاخِ', #1
u'والاستفراش': u'وَالِاسْتِفْرَاشِ', #4
u'والاستفصال': u'وَالِاسْتِفْصَالَ', #1
u'والاستفصال': u'وَالِاسْتِفْصَالُ', #2
u'والاستفعال': u'وَالِاسْتِفْعَالُ', #2
u'والاستفهاميتي': u'وَالِاسْتِفْهَامِيَّتَيْ', #2
u'والاستقاءة': u'وَالِاسْتِقَاءَةِ', #13
u'والاستقاءة': u'وَالِاسْتِقَاءَةُ', #2
u'والاستكراء': u'وَالِاسْتِكْرَاءُ', #1
u'والاستكساب': u'وَالِاسْتِكْسَابِ', #2
u'والاستكنان': u'وَالِاسْتِكْنَانِ', #1
u'والاستمانة': u'وَالِاسْتِمَانَةُ', #1
u'والاستمانة': u'وَالِاسْتِمَانَةِ', #1
u'والاستمطار': u'وَالِاسْتِمْطَارِ', #1
u'والاستمكان': u'وَالِاسْتِمْكَانُ', #1
u'والاستناء': u'وَالِاسْتِنَاءُ', #1
u'والاستنامة': u'وَالِاسْتِنَامَةُ', #1
u'والاستنامة': u'وَالِاسْتِنَامَةِ', #2
u'والاستنان': u'وَالِاسْتِنَانِ', #1
u'والاستنان': u'وَالِاسْتِنَانَ', #2
u'والاستنان': u'وَالِاسْتِنَانُ', #3
u'والاستنثار': u'والاستنثار', #1
u'والاستنثار': u'وَالاسْتِنْثَارُ', #1
u'والاستنثار': u'وَالِاسْتِنْثَارَ', #1
u'والاستنثار': u'وَالِاسْتِنْثَارِ', #12
u'والاستنثار': u'وَالِاسْتِنْثَارُ', #17
u'والاستنثار': u'وَالِاسْتِنْثَار', #2
u'والاستنجاء': u'وَالاسْتِنْجَاءِ', #1
u'والاستنجاء': u'وَالِاسْتِنْجَاء', #1
u'والاستنجاء': u'والاستنجاء', #2
u'والاستنجاء': u'وَالِاسْتِنْجَاءَ', #2
u'والاستنجاء': u'وَالِاسْتِنْجَاءِ', #39
u'والاستنجاء': u'وَالِاسْتِنْجَاءُ', #48
u'والاستنزاه': u'وَالِاسْتِنْزَاهُ', #3
u'والإستنشاق': u'وَالإِسْتِنْشَاقَ', #1
u'والاستنصاح': u'وَالِاسْتِنْصَاحِ', #1
u'والاستنقاء': u'وَالِاسْتِنْقَاءِ', #1
u'والاستنقاع': u'وَالِاسْتِنْقَاعُ', #3
u'والاستنكاح': u'وَالِاسْتِنْكَاحِ', #1
u'والاستنكاح': u'وَالِاسْتِنْكَاحُ', #2
u'والاستنكاه': u'وَالِاسْتِنْكَاهُ', #1
u'والاستنكاه': u'وَالِاسْتِنْكَاهِ', #2
u'والاستنماء': u'وَالِاسْتِنْمَاءُ', #1
u'والاستنماء': u'وَالِاسْتِنْمَاء', #2
u'والاستنماء': u'وَالِاسْتِنْمَاءِ', #3
u'والاستنهاء': u'وَالِاسْتِنْهَاءِ', #1
u'والاستهام': u'وَالِاسْتِهَام', #1
u'والاستهام': u'وَالِاسْتِهَامِ', #1
u'والاستوا': u'وَالِاسْتِوَا', #1
u'والإستئذان': u'وَالإِسْتِئْذَان', #1
u'والإستئذان': u'وَالإِسْتِئْذَانِ', #1
u'والاستياك': u'وَالِاسْتِيَاكَ', #1
u'والاستياك': u'وَالِاسْتِيَاكُ', #8
u'والاستيام': u'وَالاِسْتِيَامِ', #2
u'والاستيام': u'وَالِاسْتِيَامُ', #4
u'والاستيام': u'وَالِاسْتِيَامِ', #4
u'والاستيصال': u'وَالِاسْتِيصَالُ', #2
u'والاستيمان': u'وَالِاسْتِيمَانُ', #5
u'والاستيمان': u'وَالِاسْتِيمَانِ', #7
u'والاستيناء': u'والاستيناء', #1
u'والاستيناء': u'وَالِاسْتِينَاءُ', #4
u'والاستيناء': u'وَالِاسْتِينَاءِ', #4
u'والاستيناس': u'وَالِاسْتِينَاسُ', #1
u'والاستيناف': u'وَالِاسْتِينَافُ', #1
u'والاستيهاب': u'وَالِاسْتِيهَابَ', #1
u'والاستيهاب': u'وَالِاسْتِيهَابُ', #13
u'والاستيهاب': u'وَالِاسْتِيهَابِ', #7
u'والإسجال': u'وَالْإِسْجَالِ', #1
u'والإسحات': u'وَالْإِسْحَاتُ', #1
u'والإسرا': u'وَالْإِسْرَا', #1
u'والأسراء': u'وَالْأُسَرَاءِ', #1
u'والأسراء': u'وَالْأُسَرَاءُ', #3
u'والأسراج': u'وَالْأَسْرَاجِ', #1
u'والإسرار': u'وَالإِسْرَارِ', #1
u'والإسرار': u'وَالْإِسْرَارُ', #25
u'والإسرار': u'وَالْإِسْرَارَ', #4
u'والإسرار': u'وَالْإِسْرَارِ', #42
u'والأسرب': u'وَالْأُسْرُبُّ', #2
u'والأسرف': u'وَالْأُسْرُفُّ', #1
u'والأسروشني': u'والْأُسْرُوشَنِيّ', #1
u'والأسروشني': u'والأسروشني', #3
u'والأسروشنية': u'وَالْأُسْرُوشَنِيَّةِ', #2
u'والأسروشنية': u'وَالْأُسْرُوشَنِيَّة', #8
u'والأسطام': u'وَالْأَسْطَامُ', #1
u'والأسطحة': u'وَالْأَسْطِحَةِ', #2
u'والأسطوان': u'وَالْأُسْطُوَانُ', #2
u'والإسعاط': u'وَالْإِسْعَاطُ', #2
u'والإسعاط': u'وَالْإِسْعَاطِ', #2
u'والإسفاناخ': u'وَالْإِسْفَانَاخُ', #1
u'والإسفاناخ': u'وَالْإِسْفَانَاخِ', #1
u'والأسفت': u'والأسفت', #1
u'والإسفراييني': u'وَالْإسْفَرايِينِيّ', #3
u'والأسفوني': u'وَالْأَسْفُونِيِّ', #1
u'والإسفيداج': u'والإسفيداج', #1
u'والإسكتان': u'والإسكتان', #1
u'والإسكندر': u'وَالْإِسْكَنْدَرُ', #1
u'والإسكندر': u'وَالْإِسْكَنْدَرِ', #2
u'والإسكندراني': u'والإسْكَنْدَرانِيِّ', #1
u'والإسكندرانية': u'والْإسْكَنْدَرانيَّة', #1
u'والإسلال': u'وَالْإِسْلَالِ', #1
u'والإسلال': u'وَالْإِسْلَالَ', #2
u'والإسلال': u'وَالْإِسْلَالُ', #2
u'والأسلت': u'وَالْأَسْلَتُ', #1
u'والأسلمي': u'وَالْأَسْلَمِيَّ', #1
u'والأسلمي': u'وَالْأَسْلَمِيُّ', #1
u'والأسمان': u'وَالْأَسْمَانُ', #2
u'والأسمح': u'وَالْأَسْمَحِ', #1
u'والإسنوي': u'وَالْإِسْنَوِيُّ', #114
u'والإسنوي': u'وَالْإِسْنَوِيَّ', #2
u'والإسنوي': u'وَالْإِسْنَوِيِّ', #32
u'والأسنى': u'وَالْأَسْنَى', #303
u'والأسو': u'وَالْأَسْوُ', #1
u'والأسواني،': u'وَالأَسْوَانِيُّ،', #1
u'والأسواني': u'وَالْأُسْوَانِيُّ', #1
u'والأسودة': u'وَالأَسْوِدَةُ', #2
u'والأسودة': u'وَالْأَسْوِدَةُ', #3
u'والأسوق': u'وَالْأَسْوُقِ', #1
u'والأسوقة': u'وَالْأَسْوِقَةُ', #1
u'والأسيلم': u'وَالْأُسَيْلِمُ', #2
u'والأشافي': u'وَالْأَشَافِيِّ', #1
u'والأشافي': u'وَالْأَشَافِي', #2
u'والأشتر،': u'وَالْأَشْتَرُ،', #1
u'والأشتر': u'والأشتر', #2
u'والأشتر': u'وَالأَشْتَرُ', #2
u'والأشتر': u'وَالْأَشْتَرُ', #7
u'والاشتشفاق': u'وَالِاشْتِشْفَاقِ', #1
u'والأشج': u'وَالأَشَجُّ', #1
u'والأشج': u'وَالأَشَجِّ', #1
u'والأشج،': u'وَالأَشَجُّ،', #1
u'والأشج،': u'وَالأَشَجِّ،', #1
u'والأشج': u'وَالْأَشَجُّ', #1
u'والإشخاص': u'وَالْإِشْخَاصِ', #1
u'والإشخاص': u'وَالْإِشْخَاصُ', #2
u'والأشر': u'وَالْأَشَرُ', #1
u'والأشر': u'وَالْأَشَرَّ', #1
u'والأشر': u'وَالْأَشَرُّ', #1
u'والأشر': u'وَالْأَشَرِّ', #1
u'والأشر': u'وَالْأَشِرُ', #1
u'والأشر': u'وَالْأَشَرِ', #5
u'والأشرب': u'وَالْأَشْرُبِّ', #1
u'والأشرة': u'وَالْأَشَرَةُ', #1
u'والأشرفي': u'وَالْأَشْرَفِي', #1
u'والأشرفي': u'وَالْأَشْرَفِيِّ', #2
u'والأشرفية': u'وَالْأَشْرَفِيَّةِ', #2
u'والأشطاط': u'وَالْأَشْطَاطُ', #1
u'والأشعرون': u'وَالْأَشْعَرُونَ', #4
u'والإشفاع': u'وَالْإِشْفَاعِ', #2
u'والأشفق': u'وَالْأَشْفَقِ', #1
u'والأشفق': u'وَالْأَشْفَقُ', #3
u'والإشفن': u'والإشفن', #1
u'والأشفى': u'وَالْأَشْفَى', #1
u'والإشفى': u'وَالْإِشْفَى', #1
u'والإشقاح': u'وَالإِشْقَاحُ', #1
u'والأشقاص': u'وَالْأَشْقَاصُ', #1
u'والإشقاه': u'وَالإِشْقَاهُ', #2
u'والأشكل': u'وَالْأَشْكَلِ', #1
u'والإشلاء': u'وَالْإِشْلَاءُ', #2
u'والإشمام': u'وَالْإِشْمَامَ', #1
u'والإشمام': u'وَالْإِشْمَامِ', #1
u'والأشموني': u'وَالْأُشْمُونِيُّ', #3
u'والأشنان': u'وَالأَشْنَانُ', #1
u'والأشنان': u'وَالأُشْنَانِ', #2
u'والأشنان': u'وَالْأُشْنَانُ', #21
u'والأشنان': u'وَالْأُشْنَانِ', #33
u'والأشنان': u'وَالْأُشْنَانَ', #4
u'والأشيبون': u'وَالْأَشْيَبُونَ', #1
u'والأشيمط': u'وَالْأُشَيْمِطُ', #2
u'والإصابه': u'وَالْإِصَابَهْ', #1
u'والأصاريف': u'وَالْأَصَارِيفِ', #1
u'والأصب': u'وَالْأَصَبُّ', #2
u'والأصبحي': u'وَالْأَصْبَحِيِّ', #1
u'والأصبحي': u'وَالْأَصْبَحِيّ', #2
u'والإصبعين': u'وَالْإِصْبَعَيْنِ', #4
u'والأصبهاني': u'وَالْأَصْبَهَانِيُّ', #1
u'والأصبهاني': u'وَالْأَصْبَهَانِيّ', #34
u'والأصدقا': u'وَالْأَصْدِقَا', #1
u'والإصراع': u'وَالْإِصْرَاعُ', #6
u'والإصرافات': u'وَالْإِصْرَافَاتِ', #1
u'والأصطال': u'وَالْأَصْطَالُ', #1
u'والأصطال': u'وَالْأَصْطَالِ', #1
u'والاصطباح': u'وَالِاصْطِبَاحُ', #1
u'والإصطخري': u'وَالْإِصْطَخْرِيُّ', #5
u'والإصطخري': u'وَالْإِصْطَخْرِيِّ', #5
u'والاصطلام': u'وَالِاصْطِلَامُ', #1
u'والأصفوني': u'وَالْأَصْفُونِيِّ', #3
u'والأصفوني': u'وَالْأَصْفُونِيُّ', #4
u'والأصقع': u'وَالْأَصْقَعُ', #1
u'والأصك': u'وَالْأَصَكُّ', #1
u'والأصلحية': u'وَالْأَصْلَحِيَّةُ', #1
u'والإصماء': u'وَالْإِصْمَاءُ', #7
u'والأصمعي': u'وَالْأَصْمَعِيَّ', #1
u'والأصمعى': u'وَالأَصْمَعِىُّ', #1
u'والأصمعي': u'وَالْأَصْمَعِيُّ', #14
u'والأصمعي': u'وَالْأَصْمَعِيِّ', #9
u'والأصوع': u'وَالْأَصْوُعُ', #1
u'والأصولين': u'وَالْأُصُولَيْنِ', #1
u'والأصيد': u'وَالْأَصْيَدُ', #2
u'والأضاة': u'وَالْأَضَاةُ', #2
u'والأضاعف': u'وَالأَضَاعِفِ', #1
u'والإضاقة': u'وَالْإِضَاقَةِ', #4
u'والأضالع': u'وَالْأَضَالِعِ', #1
u'والأضحيه': u'وَالْأُضْحِيَّهْ', #4
u'والأضر': u'وَالْأَضَرَّ', #1
u'والأضر': u'وَالْأَضَرِّ', #1
u'والأضر': u'وَالْأَضَرُّ', #2
u'والأضرب': u'وَالْأَضْرُبُ', #1
u'والاضطباع': u'وَالِاضْطِبَاعِ', #22
u'والاضطباع': u'وَالِاضْطِبَاعُ', #23
u'والاضطباع': u'وَالِاضْطِبَاعَ', #6
u'والأضعف': u'وَالْأَضْعَفِ', #5
u'والأضعف': u'وَالْأَضْعَفُ', #9
u'والأضعفية': u'وَالْأَضْعَفِيَّةَ', #1
u'والأضمن': u'وَالْأَضْمَنُ', #3
u'والإطابة': u'وَالْإِطَابَة', #1
u'والأطالس': u'وَالْأَطَالِسَ', #1
u'والأطالس': u'وَالْأَطَالِسِ', #1
u'والأطاليس': u'وَالْأَطَالِيسِ', #1
u'والآطام': u'وَالْآطَامُ', #3
u'والآطام': u'وَالْآطَامِ', #4
u'والأطباعي': u'وَالْأَطْبَاعِيِّ', #1
u'والأطحلة': u'وَالْأَطْحِلَةُ', #2
u'والأطرة': u'وَالْأُطْرَةُ', #1
u'والإطرة': u'وَالْإِطْرَةُ', #1
u'والأطروش': u'وَالْأُطْرُوشُ', #1
u'والإطرية': u'وَالْإِطْرِيَّةِ', #1
u'والأطريفل': u'والأطريفل', #2
u'والاطعام': u'وَالِاطِّعَامِ', #1
u'والاطعام': u'وَالِاطِّعَامُ', #2
u'والإطفيحي': u'وَالْإِطْفِيحِيِّ', #3
u'والإطلاء': u'وَالْإِطْلَاءِ', #1
u'والاطلاء': u'وَالِاطِّلَاءِ', #3
u'والأطمات': u'وَالْأَطَمَاتُ', #1
u'والأطنيه': u'والأطنيه', #1
u'والإطهار': u'وَالْإِطْهَارُ', #1
u'والأطوفة': u'وَالْأَطْوِفَةِ', #1
u'والأطولة': u'وَالْأَطْوِلَةِ', #1
u'والاظفار،': u'والاظفار،', #1
u'والأظلة': u'وَالأَظِلَّةَ', #2
u'والأظلة': u'وَالْأَظِلَّةَ', #3
u'والإعاره': u'وَالْإِعَارَهْ', #1
u'والأعبل': u'وَالْأَعْبَلُ', #1
u'والأعتاد': u'وَالْأَعْتَادُ', #1
u'والاعتجار': u'وَالِاعْتِجَارُ', #5
u'والأعتق': u'وَالْأَعْتَقُ', #1
u'والاعتلاج': u'وَالِاعْتِلَاجُ', #1
u'والاعتلاف': u'وَالِاعْتِلَافَ', #1
u'والاعتلاف': u'وَالِاعْتِلَافِ', #1
u'والاعتلاف': u'وَالِاعْتِلَافُ', #4
u'والاعتمال': u'وَالِاعْتِمَالُ', #3
u'والأعجام': u'وَالْأَعْجَامِ', #1
u'والأعدلية': u'وَالْأَعْدَلِيَّةِ', #1
u'والأعدلية': u'وَالْأَعْدَلِيَّةُ', #2
u'والإعراء': u'وَالْإِعْرَاءُ', #2
u'والأعرابى': u'وَالأَعْرَابِىِّ', #1
u'والأعزية': u'وَالْأَعْزِيَةِ', #2
u'والأعسم': u'وَالْأَعْسَمُ', #1
u'والإعضال': u'وَالْإِعْضَالِ', #1
u'والأعطان': u'وَالْأَعْطَان', #1
u'والأعطان': u'وَالْأَعْطَانُ', #1
u'والأعطيات': u'وَالْأَعْطِيَاتُ', #2
u'والأعظمية': u'وَالْأَعْظَمِيَّةُ', #1
u'والإعلاف': u'وَالْإِعْلَافِ', #1
u'والإعلاق': u'وَالْإِعْلَاقِ', #1
u'والإعلاق': u'وَالْإِعْلَاقُ', #3
u'والأعلمية': u'وَالْأَعْلَمِيَّة', #1
u'والأعلمية': u'وَالْأَعْلَمِيَّةُ', #2
u'والأعلمية': u'وَالْأَعْلَمِيَّةِ', #2
u'والأعمس': u'وَالْأَعْمَسُ', #1
u'والأعمشأنها': u'وَالأَعْمَشِأَنَّهَا', #1
u'والأعمية': u'وَالْأَعَمِّيَّةُ', #2
u'والأعمية': u'وَالْأَعَمِّيَّةِ', #4
u'والأعواف': u'وَالْأَعْوَافُ', #2
u'والأعونة': u'وَالْأَعْوِنَةِ', #1
u'والأعونة': u'وَالْأَعْوِنَةُ', #4
u'والأغبط': u'وَالْأَغْبَطُ', #4
u'والأغبيا': u'وَالْأَغْبِيَا', #1
u'والاغتباق': u'وَالِاغْتِبَاقِ', #1
u'والاغتلال': u'وَالِاغْتِلَالِ', #2
u'والإغريض': u'وَالْإِغْرِيضُ', #2
u'والإغريض': u'وَالْإِغْرِيضِ', #3
u'والأغلف': u'وَالْأَغْلَفِ', #3
u'والأغلف': u'وَالْأَغْلَفُ', #4
u'والأغلوطات': u'وَالْأُغْلُوطَاتِ', #1
u'والإغما': u'وَالْإِغْمَا', #1
u'والأغياء': u'والْأَغْيَاءُ', #1
u'والافتكاك': u'وَالِافْتِكَاكَ', #1
u'والافتكاك': u'وَالِافْتِكَاكِ', #1
u'والافتكاك': u'وَالِافْتِكَاكُ', #2
u'والافتيات': u'وَالِافْتِيَاتِ', #4
u'والافتيات': u'وَالِافْتِيَاتُ', #7
u'والأفتيمون': u'والأفتيمون', #1
u'والأفحاث': u'وَالْأَفْحَاثَ', #1
u'والأفحج': u'وَالْأَفْحَجُ', #1
u'والأفدق': u'والأفدق', #1
u'والإفراء': u'وَالْإِفْرَاءَ', #1
u'والإفراء': u'وَالْإِفْرَاءِ', #1
u'والإفراء': u'وَالْإِفْرَاءُ', #5
u'والأفراس': u'وَالْأَفْرَاسِ', #3
u'والإفراطا': u'وَالْإِفْرَاطَا', #1
u'والأفراق': u'وَالْأَفْرَاقُ', #1
u'والأفرنة': u'وَالْأَفْرِنَةِ', #1
u'والأفرنثى': u'والأفرنثى', #1
u'والافرنقاع': u'وَالِافْرِنْقَاعُ', #1
u'والأفرية': u'وَالْأَفْرِيَةُ', #1
u'والأفزاع': u'وَالْأَفْزَاعُ', #1
u'والأفزاع': u'وَالْأَفْزَاعِ', #4
u'والإفعال': u'وَالْإِفْعَالِ', #1
u'والأفعل': u'وَالْأَفْعَلُ', #1
u'والأفقر': u'وَالْأَفْقَرُ', #1
u'والأفقه': u'وَالْأَفْقَهُ', #14
u'والأفقه': u'وَالْأَفْقَهِ', #7
u'والأفلاء': u'وَالْأَفْلَاءِ', #2
u'والأفلاج': u'وَالْأَفْلَاجُ', #1
u'والأفلاكية': u'والأفلاكية', #1
u'والأفلس': u'وَالْأَفْلَسَ', #1
u'والأفن': u'وَالْأَفْنُ', #1
u'والأفيالا': u'وَالْأَفْيَالا', #1
u'والأفيق': u'وَالْأَفِيقُ', #1
u'والأفين': u'وَالْأَفِينُ', #1
u'والأقارير': u'وَالْأَقَارِيرَ', #3
u'والأقارير': u'وَالْأَقَارِيرِ', #33
u'والأقارير': u'وَالْأَقَارِيرُ', #4
u'والإقاله': u'وَالْإِقَالَهْ', #1
u'والإقباض': u'وَالْإِقْبَاضُ', #19
u'والإقباض': u'وَالْإِقْبَاضِ', #27
u'والإقباض': u'وَالْإِقْبَاضَ', #3
u'والأقباع': u'وَالْأَقْبَاعِ', #1
u'والأقباع': u'وَالْأَقْبَاعَ', #3
u'والإقبالة': u'وَالْإِقْبَالَة', #1
u'والأقتاب': u'وَالْأَقْتَاب', #1
u'والأقتاب': u'وَالْأَقْتَابُ', #2
u'والأقتاب': u'وَالْأَقْتَابِ', #2
u'والاقتدا': u'وَالِاقْتِدَا', #1
u'والاقتراني': u'وَالِاقْتِرَانِيِّ', #2
u'والاقتضاض': u'وَالِاقْتِضَاضُ', #1
u'والاقتعاط': u'وَالِاقْتِعَاطُ', #1
u'والإقدار': u'وَالْإِقْدَارَ', #1
u'والإقدار': u'وَالْإِقْدَارُ', #10
u'والإقدار': u'وَالْإِقْدَارِ', #3
u'والإقداما': u'وَالْإِقْدَامَا', #1
u'والأقذر': u'وَالْأَقْذَرِ', #2
u'والأقراء': u'وَالْأَقْرَاءِ', #14
u'والأقراء': u'وَالْأَقْرَاءُ', #26
u'والأقراباذينات': u'والأقراباذينات', #1
u'والأقربية': u'وَالْأَقْرَبِيَّةِ', #2
u'والأقربية': u'وَالْأَقْرَبِيَّةُ', #4
u'والأقرحة': u'وَالْأَقْرِحَةَ', #1
u'والأقرحة': u'وَالْأَقْرِحَةُ', #12
u'والأقرحة': u'وَالْأَقْرِحَةِ', #8
u'والأقرطة': u'وَالأَقْرِطَةُ', #1
u'والإقساطا': u'وَالْإِقْسَاطَا', #1
u'والأقط،': u'والأقط،', #1
u'والأقط': u'وَالأَقْطُ', #1
u'والأقط': u'وَالْأَقْطُ', #1
u'والأقط': u'وَالْأَقْطِ', #1
u'والأقط': u'وَالْأَقِطَ', #12
u'والأقط': u'وَالْأَقِط', #2
u'والأقط': u'وَالأَقِطَ', #3
u'والأقط': u'وَالأَقِطُ', #3
u'والأقط': u'وَالْأَقِطُ', #31
u'والأقط': u'وَالْأَقِطِ', #46
u'والأقط': u'وَالأَقِطِ', #6
u'والأقط': u'والأقط', #8
u'والأقطيطاء': u'وَالْأَقْطِيطَاءُ', #1
u'والأقفزة': u'وَالْأَقْفِزَةُ', #2
u'والأقفزة': u'وَالْأَقْفِزَةِ', #3
u'والأقفهسي': u'وَالْأَقْفَهْسِيَّ', #1
u'والأقفهسي': u'وَالْأَقْفَهْسِيِّ', #11
u'والأقفهسي': u'وَالْأَقْفَهْسِيُّ', #3
u'والأقلح': u'وَالْأَقْلَحُ', #2
u'والأقلف': u'وَالْأَقْلَفُ', #11
u'والأقلف': u'وَالْأَقْلَفَ', #2
u'والأقلف': u'وَالْأَقْلَفِ', #3
u'والأقنأ': u'وَالْأَقْنَأُ', #1
u'والأقنف': u'وَالْأَقْنَفُ', #1
u'والأقيس': u'وَالْأَقْيَسُ', #36
u'والاكا': u'وَالَاكَا', #1
u'والإكارة': u'وَالْإِكَارَةُ', #1
u'والإكارة': u'وَالْإِكَارَةِ', #4
u'والأكاف': u'وَالْأَكَّافُ', #1
u'والإكاف': u'وَالْإِكَافِ', #19
u'والإكاف': u'وَالْإِكَافُ', #25
u'والإكاف': u'وَالْإِكَافَ', #6
u'والأكبار': u'وَالْأَكْبَارَ', #1
u'والأكبار': u'وَالْأَكْبَارُ', #1
u'والاكتفا': u'وَالِاكْتِفَا', #1
u'والآكد': u'وَالْآكَدُ', #3
u'والأكدار': u'وَالْأَكْدَارِ', #3
u'والأكدرية': u'وَالْأَكْدَرِيَّةُ', #1
u'والأكدرية': u'وَالْأَكْدَرِيَّةِ', #1
u'والآكدية': u'وَالْآكَدِيَّةُ', #2
u'والأكرية': u'وَالْأَكْرِيَةَ', #1
u'والأكرية': u'وَالْأَكْرِيَةِ', #5
u'والأكساب': u'وَالْأَكْسَابِ', #12
u'والأكساب': u'وَالْأَكْسَابُ', #18
u'والأكساب': u'وَالْأَكْسَابَ', #5
u'والأكعب': u'وَالْأَكْعُبِ', #3
u'والأكهب': u'وَالْأَكْهَبُ', #1
u'والأكيسة': u'وَالْأَكْيِسَةُ', #1
u'والأكيسة': u'وَالْأَكْيِسَةِ', #2
u'والإل': u'وَالْإِلّ', #2
u'وألالا': u'وَأَلَالًا', #1
u'والإلاطة': u'وَالْإِلَاطَةُ', #1
u'والالتفاع': u'وَالِالْتِفَاعُ', #2
u'والألحفة': u'والْأَلْحِفَةِ', #1
u'والألحفة': u'وَالْأَلْحِفَةِ', #1
u'والإلزاما': u'وَالْإِلْزَامَا', #5
u'والألزم': u'وَالْأَلْزَمُ', #2
u'والألسة': u'وَالْأَلْسَةِ', #1
u'والإلفات': u'وَالْإِلْفَاتُ', #1
u'والآلهية': u'وَالْآلِهِيَّةِ', #1
u'والألوة': u'وَالْأَلُوَّةُ', #2
u'والألوة': u'وَالْأُلُوّةُ', #2
u'والأماء': u'وَالْأُمَاء', #1
u'والأمات': u'وَالْأُمَّاتُ', #12
u'والإماما': u'وَالإِمَامَا', #1
u'والإمامه': u'وَالْإِمَامَهْ', #2
u'والأمانى': u'وَالأَمَانِىَّ', #1
u'والإمة': u'وَالْإِمّةِ', #1
u'والامة': u'وَالَامَةُ', #1
u'والأمت': u'والأمت', #1
u'والأمتعات': u'وَالْأَمْتِعَاتِ', #2
u'والامتلاخ': u'وَالِامْتِلَاخُ', #1
u'والأمدار': u'وَالْأَمْدَارِ', #1
u'والآمدي': u'وَالْآمِدَيُّ', #1
u'والآمدي': u'وَالْآمِدِيُّ', #103
u'والآمدي': u'وَالْآمِدِيّ', #2
u'والآمدي': u'وَالْآمِدِيِّ', #39
u'والآمدي': u'وَالْآمِدِيَّ', #48
u'والامرأة': u'وَالِامْرَأَةُ', #1
u'والامرأتين': u'وَالِامْرَأَتَيْنِ', #1
u'والأمراق': u'وَالْأَمْرَاقِ', #2
u'والأمعوز': u'وَالْأُمْعُوزُ', #5
u'والإملاج': u'وَالْإِمْلَاجُ', #2
u'والإملاجة': u'وَالْإِمْلَاجَةُ', #6
u'والإملاجتان': u'والإملاجتان', #1
u'والإملاجتان': u'وَالْإِمْلَاجَتَانِ', #4
u'والإملاجتان': u'وَالإِمْلاَجَتَانِ', #5
u'والإملاجتان': u'وَالإِمْلاجَتَانِ', #7
u'والأملوك': u'وَالْأُمْلُوكُ', #1
u'والأمليس': u'وَالْأَمْلِيسُ', #1
u'والإمناء': u'وَالْإِمْنَاءُ', #2
u'والإمناء': u'وَالْإِمْنَاءِ', #2
u'والأموالا': u'وَالْأَمْوَالَا', #1
u'والان': u'وَالانُ', #1
u'والان': u'وَالَانَ', #3
u'والان': u'وَالانَ', #4
u'والإنا': u'وَالْإِنَا', #2
u'والأنادر': u'وَالْأَنَادِرُ', #2
u'والأنبابي': u'وَالْأُنْبَابِيِّ', #1
u'والأنبابي': u'وَالْأُنْبَابِيُّ', #2
u'والأنبابي': u'والأنبابي', #3
u'والأنباري': u'وَالْأَنْبَارِيُّ', #1
u'والأنباري': u'وَالْأَنْبَارِيِّ', #1
u'والأنبجاني': u'والأنبجاني', #1
u'والأنبجانيات': u'والْأنْبَجانِيَّات', #1
u'والأنبجانيات': u'وَالْأَنْبِجَانِيَّات', #1
u'والأنبجانيات': u'وَالْأَنْبِجَانِيَّاتِ', #1
u'والإنبجانية': u'والْإِنْبِجانِيَّة', #1
u'والإنبجانية': u'وَالْإِنْبِجَانِيَّةُ', #1
u'والأنبجانية': u'وَالْأَنْبِجَانِيَّة', #4
u'والأنبولة': u'وَالْأُنْبُولَةِ', #2
u'والانتثار': u'وَالِانْتِثَارِ', #1
u'والانتثار': u'وَالِانْتِثَارُ', #3
u'والانتذار': u'والانتذار', #1
u'والإنتضاح': u'وَالإِنْتِضَاحُ', #1
u'والانتقار': u'وَالِانْتِقَارُ', #1
u'والانتقاع': u'وَالِانْتِقَاعُ', #3
u'والأنثىقوله': u'وَالْأُنْثَىقَوْلُهُ', #1
u'والإنجانة': u'وَالْإِنْجَانَةُ', #1
u'والانجدال': u'وَالِانْجِدَالُ', #1
u'والأنجيل': u'والأنجيل', #1
u'والأنجيل': u'وَالْأَنْجِيلِ', #1
u'والإنجيلوالوجه': u'وَالإِنْجِيلِوَالْوَجْهُ', #1
u'والانحجار': u'وَالِانْحِجَارَ', #1
u'والانحجاز': u'وَالِانْحِجَاز', #2
u'والأندراني': u'والأندراني', #1
u'والأندلسيي': u'والأندلسيي', #2
u'والأندوج': u'وَالْأُنْدُوجُ', #1
u'والإنزاء': u'وَالْإِنْزَاءِ', #1
u'والإنزاء': u'وَالْإِنْزَاءُ', #3
u'والأنزع': u'وَالْأَنْزَعَ', #1
u'والأنزع': u'وَالْأَنْزَعِ', #2
u'والأنزع': u'وَالْأَنْزَعُ', #4
u'والأنسبية': u'وَالْأَنْسَبِيَّةَ', #1
u'والإنسوروي': u'وَالإِنْسُوَرُوِيَ', #2
u'والأنسون': u'وَالْأَنِسُونِ', #1
u'والانشتار': u'وَالِانْشِتَارُ', #2
u'والأنص': u'وَالْأَنَصُّ', #2
u'والأنصارSحول': u'وَالْأَنْصَارَSحَوْلَ', #1
u'والأنصارى': u'وَالأَنْصَارِىُّ', #1
u'والأنصال': u'وَالْأَنْصَالِ', #2
u'والانصباغ': u'وَالِانْصِبَاغِ', #1
u'والأنطح': u'وَالْأَنْطَحُ', #1
u'والإنعاظ': u'وَالْإِنْعَاظُ', #1
u'والإنعاظ': u'وَالْإِنْعَاظِ', #1
u'والأنعامقوله': u'وَالْأَنْعَامِقَوْلُهُ', #1
u'والأنفا': u'وَالْأَنْفَا', #1
u'والإنفاع': u'وَالْإِنْفَاعِ', #1
u'والإنفحة': u'وَالْإِنْفَحَةَ', #1
u'والإنفحة': u'وَالْإِنْفَحَةُ', #12
u'والإنفحة': u'وَالْإِنْفَحَّةُ', #2
u'والإنفحة': u'وَالْإِنْفَحَةِ', #9
u'والأنفذ': u'وَالْأَنْفَذِ', #1
u'والأنقروي': u'وَالْأَنْقِرْوِيِّ', #13
u'والأنقروي': u'وَالْأَنْقِرْوِيّ', #32
u'والأنقروي': u'وَالْأَنْقِرْوِيُّ', #87
u'والأنقروية': u'وَالْأَنْقِرْوِيَّةِ', #1
u'والأنقص': u'وَالْأَنْقَصُ', #1
u'والانقضا': u'وَالِانْقِضَا', #1
u'والانقطاعا': u'وَالِانْقِطَاعَا', #1
u'والآنك': u'وَالآنُكَ', #1
u'والآنك': u'وَالْآنُكُ', #4
u'والآنك': u'وَالْآنُكِ', #6
u'والإنكاء': u'وَالْإِنْكَاءُ', #1
u'والأنكحة': u'وَالْأَنْكِحَةِ', #20
u'والأنكحة': u'وَالْأَنْكِحَةَ', #4
u'والأنكحة': u'وَالْأَنْكِحَةُ', #4
u'والإنهاش': u'وَالْإِنْهَاشِ', #1
u'والأنوفا': u'وَالْأَنُوفَا', #1
u'والأنوفا': u'وَالْأُنُوفَا', #2
u'والإنى': u'وَالْإِنَى', #1
u'والآنيسون': u'وَالْآنِيسُونُ', #1
u'والأنيم': u'وَالْأَنِيمُ', #2
u'والأهان': u'وَالْأَهَانُ', #1
u'والأهاويل': u'وَالْأَهَاوِيلِ', #1
u'والإهدام': u'وَالْإِهْدَامِ', #1
u'والأهذلي': u'وَالْأَهْذَلِيِّ', #1
u'والإهليلج': u'وَالْإِهْلِيلَجِ', #1
u'والإهليلج': u'وَالْإِهْلِيلِجِ', #1
u'والأهوية': u'وَالْأَهْوِيَةِ', #2
u'والأهيب': u'وَالْأَهْيَبُ', #2
u'والأهيل': u'وَالْأَهْيَل', #1
u'والأوارك': u'وَالْأَوَارِكُ', #1
u'والأودني': u'وَالْأَوْدَنِيِّ', #1
u'والأورع': u'وَالْأَوْرَعِ', #16
u'والأورع': u'وَالْأَوْرَعُ', #23
u'والأورع': u'وَالْأَوْرَعَ', #4
u'والأوز': u'وَالْأَوُزُّ', #2
u'والأوزاعي،': u'والأَوْزَاعِيُّ،', #1
u'والأوزاعي': u'وَالأَوْزَاعِيِّ', #1
u'والأوزاعي': u'وَالْأَوْزَاعِيُّ', #138
u'والأوزاعي': u'وَالْأَوْزَاعِيّ', #2
u'والأوزاعي،': u'وَالأَوْزَاعِيِّ،', #3
u'والأوزاعي': u'وَالْأَوْزَاعِيَّ', #3
u'والأوزاعى': u'وَالأَوْزَاعِىُّ', #3
u'والأوزاعي': u'وَالأَوْزَاعِيُّ', #4
u'والأوزاعي،': u'وَالأَوْزَاعِيُّ،', #4
u'والأوزاعى': u'وَالأَوْزَاعِىِّ', #5
u'والأوزاعي': u'وَالْأَوْزَاعِيِّ', #77
u'والأوزجندي': u'والأوزجندي', #5
u'والأوزجندية': u'والأوزجندية', #1
u'والأوزجندية': u'وَالْأُوزَجَنْدِيَّةُ', #1
u'والأوسق': u'وَالْأَوْسُقِ', #2
u'والأوسق': u'وَالْأَوْسُقُ', #3
u'والأوضع': u'والأوضع', #1
u'والأوضية': u'وَالْأَوْضِيَةِ', #1
u'والأوطئة': u'وَالْأَوْطِئَةِ', #1
u'والأوطية': u'وَالْأَوْطِيَةِ', #2
u'والأوعار': u'وَالْأَوْعَارِ', #1
u'والأوفاض': u'وَالْأَوْفَاضِ', #2
u'والأوفاق': u'والأوفاق', #1
u'والأوفاق': u'وَالْأَوْفَاقُ', #2
u'والأوفاق': u'وَالْأَوْفَاقِ', #4
u'والأوقاص': u'وَالأَوْقَاصُ', #1
u'والأوقاص': u'وَالْأَوْقَاصِ', #3
u'والأوقاص': u'وَالْأَوْقَاصُ', #5
u'والأوقه': u'والأوقه', #1
u'والأوكد': u'وَالْأَوْكَدُ', #4
u'والأولة': u'وَالْأُولَةَ', #1
u'والأولة': u'وَالْأَوَّلَةُ', #1
u'والأولة': u'وَالْأَوِّلَةُ', #1
u'والأولتان': u'وَالْأُولَتَانِ', #1
u'والأولتين': u'وَالْأُولَتَيْنِ', #1
u'والأوهات': u'وَالْأَوْهَاتُ', #1
u'والأوهاط': u'والأوهاط', #1
u'والائتساء': u'وَالِائْتِسَاءُ', #1
u'والائتمام': u'وَالِائْتِمَامُ', #14
u'والائتمام': u'وَالِائْتِمَامِ', #16
u'والأيا': u'وَالْأَيَا', #1
u'والإياد': u'وَالْإِيَادُ', #1
u'والأيارجات': u'والأيارجات', #1
u'والإيارجات': u'والإيارجات', #1
u'والإياس': u'وَالإِيَاسُ', #1
u'والإياس': u'وَالْإِيَاسَ', #1
u'والإياس': u'وَالْإِيَاسِ', #5
u'والإياس': u'وَالْإِيَاسُ', #7
u'والأياييل': u'والأياييل', #1
u'والإيتان': u'وَالْإِيتَانُ', #1
u'والايتناف': u'وَالِايتِنَافُ', #1
u'والإيجارة': u'وَالْإِيجَارَةِ', #1
u'والإيدام': u'وَالْإِيدَامُ', #1
u'والأيدر': u'وَالْأَيْدَرُ', #1
u'والآيس': u'وَالْآيِسُ', #3
u'والأيسة': u'وَالْأَيِسَةَ', #1
u'والأيسة': u'وَالْأَيِسَةِ', #2
u'والآيسة': u'وَالْآيِسَةُ', #26
u'والآيسة': u'وَالْآيِسَةَ', #4
u'والآيسة': u'وَالْآيِسَةِ', #53
u'والإيكاء': u'وَالْإِيكَاءِ', #1
u'والإيكاف': u'وَالْإِيكَافِ', #3
u'والإيل': u'وَالْإِيَّلِ', #1
u'والآيل': u'وَالْآيِلِ', #2
u'والآيل': u'وَالْآيِلُ', #6
u'والإيلاقي': u'والإيلاقي', #1
u'والإيناث': u'وَالْإِينَاثِ', #2
u'والبابكية': u'وَالْبَابَكِيَّةُ', #1
u'والبابلتي،': u'وَالْبَابْلُتِّيُّ،', #1
u'والبابلتى': u'وَالْبَابْلُتِّىُّ', #1
u'والباجرمي': u'وَالْبَاجَرِمِيُّ', #1
u'والباجوري': u'وَالْبَاجُورِيّ', #1
u'والباجوري': u'وَالْبَاجُورِيُّ', #3
u'والباد': u'وَالَبَّادِ', #1
u'وإلباد': u'وَإِلْبَادُ', #2
u'والباد': u'وَالْبَادِ', #21
u'والبادى': u'وَالْبَادِى', #1
u'والبادى': u'وَالْبَادِىَ', #1
u'والباذق': u'وَالْبَاذِقِ', #7
u'والباذق': u'وَالْبَاذِقُ', #9
u'والبارزي': u'وَالْبَارِزُيُّ', #1
u'والبارزي': u'وَالْبَارِزِيَّ', #2
u'والبارزي': u'وَالْبَارِزِيُّ', #31
u'والبارزي': u'وَالْبَارِزِيِّ', #7
u'والبارض': u'وَالْبَارِضُ', #1
u'والبارقي': u'وَالْبَارِقِي', #1
u'والبازري': u'وَالْبَازِرِيُّ', #1
u'والبازري': u'وَالْبَازِرِيِّ', #1
u'والبازى': u'وَالْبَازِى', #2
u'والباس': u'وَالِبَاسِ', #1
u'والباس': u'وَالْبَاسِ', #2
u'والباسة': u'وَالْبَاسَّةَ', #2
u'والباعوث': u'وَالْبَاعُوثُ', #2
u'والباغ': u'وَالْبَاغِّ', #1
u'والباغ': u'وَالْبَاغُ', #2
u'والباقاني': u'وَالْبَاقَانِيِّ', #4
u'والباقاني': u'وَالْبَاقَانِيُّ', #6
u'والباقلا': u'وَالْبَاقِلَا', #12
u'والباقلا': u'وَالْبَاقِلَّا', #28
u'والباقلاني': u'وَالْبَاقِلَّانِيّ', #13
u'والباقلاني': u'وَالْبَاقِلَّانِيُّ', #2
u'والباقلائي': u'والْباقِلَّائِيُّ', #1
u'والباقور': u'وَالْبَاقُورُ', #2
u'والباقى': u'والْبَاقِى', #1
u'والباقى': u'وَالْبَاقِى', #63
u'والبامية': u'وَالْبَامِيَةَ', #1
u'والبامية': u'وَالْبَامِيَةِ', #3
u'والبانوا': u'والبانوا', #1
u'والباه': u'وَالْبَاهَ', #2
u'والباه': u'وَالْبَاهِ', #2
u'والباهلي': u'وَالْبَاهِلِيُّ', #1
u'والباوردي': u'وَالْبَاوَرْدِيُّ', #1
u'وألبتة': u'وَأَلْبَتَّةَ', #4
u'والبتع': u'وَالْبِتْعَ', #1
u'والبتع': u'وَالْبِتْعِ', #1
u'والبتع': u'وَالْبِتْعُ', #5
u'والبتك': u'وَالْبَتْكُ', #1
u'والبتلة': u'وَالْبَتْلَةِ', #1
u'والبتلة': u'وَالْبَتْلَةَ', #3
u'والبتي': u'وَالْبَتِّيِّ', #1
u'والبتي': u'وَالْبَتِّيُّ', #3
u'والبتيراء': u'وَالْبُتَيْرَاءُ', #3
u'والبتيرية': u'وَالْبُتَيْرِيَّةُ', #1
u'والبثرات': u'وَالْبَثَرَاتِ', #3
u'والبثرة': u'وَالْبَثْرَةُ', #2
u'والبجات': u'وَالْبَجَّاتِ', #1
u'والبجاد': u'وَالْبِجَادُ', #4
u'والبجاري': u'والبجاري', #1
u'والبجاري': u'وَالْبَجَارِي', #1
u'والبجالة': u'وَالْبُجَالَةُ', #1
u'والبجالة': u'وَالْبَجَالَةُ', #2
u'والبجة': u'وَالْبَجَّةِ', #1
u'والبجيرمي': u'وَالْبُجَيْرَمِيُّ', #1
u'والبجيرمي': u'والبجيرمي', #2
u'والبجيرمي': u'وَالْبُجَيْرَمِيِّ', #2
u'والبجيرمي': u'وَالْبُجَيْرِمِيِّ', #22
u'والبجيرمي': u'وَالْبُجَيْرِمِيُّ', #25
u'والبحائر': u'والْبَحَائِرِ', #1
u'والبحرات': u'وَالْبَحْرَاتِ', #1
u'والبحرات': u'وَالْبَحَرَاتِ', #2
u'والبحرة': u'وَالْبَحْرَةُ', #1
u'والبحل': u'والبحل', #1
u'والبحوحة': u'وَالْبُحُوحَةِ', #1
u'والبخاتي': u'وَالْبَخَاتِيَّ', #1
u'والبخاتى': u'وَالْبَخَاتَى', #1
u'والبخاتي': u'وَالْبَخَاتِيِّ', #4
u'والبخاتي': u'وَالْبَخَاتِيُّ', #5
u'والبخارى': u'والبخارى', #1
u'والبخارى': u'وَالْبُخَارِىِّ', #1
u'والبخارى': u'وَالْبُخَارِىُّ', #12
u'والبخاريون': u'وَالْبُخَارِيُّونَ', #2
u'والبختج': u'والبختج', #1
u'والبختج': u'وَالْبُخْتُجُ', #2
u'والبخترى': u'وَالْبَخْتَرِىِّ', #1
u'والبخراء': u'وَالْبَخْرَاءِ', #1
u'والبخقاء': u'وَالْبَخْقَاءُ', #2
u'والبخقاء': u'وَالْبَخْقَاءِ', #2
u'والبخنداة': u'وَالْبَخَنْدَاةُ', #1
u'والبدءة': u'وَالْبَدْءَةُ', #1
u'والبداء': u'وَالْبَدَاءِ', #2
u'والبداء': u'وَالْبَدَاءُ', #4
u'والبدار': u'وَالْبِدَارَ', #1
u'والبدار': u'وَالْبِدَارِ', #1
u'والبدار': u'وَالْبِدَارُ', #3
u'والبدرة': u'وَالْبَدْرَةُ', #2
u'والبديء': u'وَالْبَدِيءُ', #2
u'والبديعية': u'وَالْبَدِيعِيَّةِ', #1
u'والبذا': u'وَالْبِذَا', #1
u'والبذاذة': u'وَالْبَذَاذَةِ', #2
u'والبذرقة': u'وَالْبَذْرَقَةِ', #1
u'والبذرقة': u'وَالْبَذْرَقَةُ', #3
u'والبذوذة': u'وَالْبُذُوذَةِ', #1
u'والبذي': u'وَالْبَذِيَّ', #1
u'والبذي': u'وَالْبَذِيُّ', #1
u'والبذي': u'وَالْبَذِيِّ', #2
u'والبرآء': u'وَالْبُرَآءُ', #1
u'والبرابط': u'وَالْبَرَابِطَ', #1
u'والبرابي': u'وَالْبَرَابِي', #1
u'والبراثي': u'والبراثي', #1
u'والبراجم': u'وَالْبَرَاجِمُ', #1
u'والبرادعي': u'وَالْبَرَادِعِيُّ', #5
u'والبراذع': u'وَالْبَرَاذِعِ', #1
u'والبراذع': u'وَالْبَرَاذِعَ', #2
u'والبراذعي': u'وَالْبَرَاذْعِيُّ', #1
u'والبراوات': u'وَالْبَرَاوَاتُ', #1
u'والبربط': u'وَالْبَرْبَطُ', #1
u'والبربط': u'وَالْبَرْبَطِ', #4
u'والبرتي': u'وَالْبِرْتِيُّ', #1
u'والبرجندي': u'وَالْبُرْجَنْدِيِّ', #1
u'والبرجندي': u'وَالْبُرْجُنْدِيِّ', #10
u'والبرجندي': u'وَالْبُرْجُنْدِيُّ', #4
u'والبرز': u'وَالْبَرْزِ', #1
u'والبرزاطي': u'وَالْبُرْزَاطِيُّ', #1
u'والبرزلي': u'وَالْبَرْزَلِيُّ', #10
u'والبرزلي': u'وَالْبَرْزَلِيِّ', #4
u'والبرسام': u'وَالْبِرْسَام', #1
u'والبرسام': u'وَالْبِرْسَامَ', #1
u'والبرسام': u'وَالْبِرْسَامِ', #2
u'والبرسام': u'وَالْبِرْسَامُ', #4
u'والبرساني': u'وَالبُرْسَانِيُّ', #1
u'والبرشنوني': u'والبرشنوني', #1
u'والبرعي': u'وَالْبُرَعِيُّ', #1
u'والبرقاء': u'وَالْبَرْقَاءُ', #1
u'والبرقاء': u'وَالْبَرْقَاءِ', #1
u'والبرقاني': u'وَالْبَرْقَانِيِّ', #1
u'والبرقاني': u'وَالْبَرْقَانِيُّ', #2
u'والبرقة': u'وَالْبُرْقَةُ', #1
u'والبركوية': u'وَالْبِرْكَوِيَّةِ', #1
u'والبرلسي': u'والبرلسي', #1
u'والبرلسي': u'وَالْبُرُلُّسِيُّ', #2
u'والبرلسي': u'وَالْبُرُلُّسِيِّ', #3
u'والبرمان': u'وَالْبُرْمَانِ', #1
u'والبرماوي': u'وَالْبِرْمَاوِيُّ', #10
u'والبرماوي': u'وَالْبِرْمَاوِيِّ', #11
u'والبرمكي': u'وَالْبَرْمَكِيِّ', #1
u'والبرموني': u'وَالْبَرْمُونِيُّ', #1
u'والبروي': u'وَالْبَرَوِيُّ', #1
u'والبريدات': u'وَالْبَرِيدَاتِ', #1
u'والبرير': u'وَالْبَرِيرُ', #1
u'والبريرة': u'وَالْبَرِيرَةُ', #1
u'والبز': u'وَالْبَزّ', #1
u'والبز': u'وَالْبَزِّ', #10
u'والبز': u'وَالْبَزُّ', #11
u'والبزا': u'وَالْبَزَا', #2
u'والبزابز': u'وَالْبُزَابِزُ', #1
u'والبزاغ': u'والبزاغ', #1
u'والبزاغ': u'وَالْبَزَّاغَ', #2
u'والبزاغ': u'وَالْبَزَّاغُ', #8
u'والبزاغ': u'وَالْبَزَّاغِ', #8
u'والبزدوي': u'وَالْبَزْدَوِيُّ', #10
u'والبزدوي': u'وَالْبَزْدَوِيِّ', #6
u'والبزدويان': u'والبزدويان', #1
u'والبزوز': u'وَالْبُزُوزِ', #1
u'والبزيعي،': u'وَالْبَزِيعِيُّ،', #1
u'والبزيون': u'وَالْبَزْيُونُ', #1
u'والبساخي': u'والبساخي', #2
u'والبساخي': u'وَالْبَسَاخِيِّ', #4
u'والبساق': u'وَالْبُسَاقُ', #1
u'والبسائط': u'وَالْبَسَائِطِ', #1
u'والبسائط': u'وَالْبَسَائِطُ', #2
u'والبستي': u'وَالْبُسْتِيّ', #1
u'والبستي': u'وَالْبُسْتِيُّ', #1
u'والبسرى': u'وَالْبُسَرِىُّ', #1
u'والبسطامي': u'وَالْبِسْطَامِيُّ', #1
u'والبسل': u'وَالْبَسْلُ', #5
u'والبسلاء': u'وَالْبَسْلَاءِ', #1
u'والبسلاء': u'وَالْبُسَلَاءُ', #1
u'والبسندود': u'وَالْبُسْنَدُودِ', #1
u'والبسورة': u'وَالْبُسُورَةِ', #1
u'والبسيس': u'وَالْبَسِيسُ', #1
u'والبسيس': u'وَالْبَسِيسِ', #1
u'والبسيلة': u'وَالْبَسِيلَةَ', #1
u'والبسيلة': u'وَالْبَسِيلَةُ', #13
u'والبسيلة': u'وَالْبَسِيلَةِ', #4
u'والبشخانات': u'وَالْبَشْخَانَاتِ', #2
u'والبشخانة': u'والبشخانة', #1
u'والبشكى': u'وَالْبَشَكَى', #1
u'والبشم': u'وَالْبَشَمُ', #2
u'والبشمى': u'وَالْبَشْمَى', #1
u'والبصاقفي': u'وَالْبُصَاقُفِي', #1
u'والبصرا': u'وَالْبَصَرَا', #2
u'والبصريون': u'والبصريّون', #1
u'والبصريون': u'وَالْبَصْرِيُّونَ', #12
u'والبضاع': u'وَالْبِضَاعُ', #2
u'والبطاء': u'وَالْبِطَاءِ', #1
u'والبطارخ': u'وَالْبَطَارِخُ', #1
u'والبطارخ': u'وَالْبَطَارِخِ', #1
u'والبطاطيخ': u'والبطاطيخ', #1
u'والبطاطيخ': u'وَالْبَطَاطِيخِ', #3
u'والبطراوي': u'وَالْبَطْرَاوِيُّ', #1
u'والبططيين': u'والبططيين', #1
u'والبطول': u'وَالْبُطُولُ', #1
u'والبطوي': u'وَالْبُطْوِي', #1
u'والبعال': u'وَالْبِعَالُ', #2
u'والبعج': u'وَالْبَعْجُ', #1
u'والبعزجة': u'وَالْبَعْزَجَةُ', #1
u'والبعلة': u'وَالْبَعْلَةُ', #1
u'والبعيثران': u'وَالْبُعَيْثَرَانِ', #1
u'والبغاث': u'وَالْبُغَاثِ', #4
u'والبغاث': u'وَالْبُغَاثُ', #7
u'والبغاثة': u'وَالْبُغَاثَةُ', #2
u'والبغاثة': u'وَالْبُغَاثَةِ', #2
u'والبغالون': u'وَالْبَغَّالُونَ', #2
u'والبغالين': u'وَالْبَغَّالِينَ', #2
u'والبغر': u'وَالْبَغَرُ', #1
u'والبغش': u'وَالْبَغْشِ', #1
u'والبغضة': u'وَالْبُغْضَةُ', #1
u'والبغضة': u'وَالْبِغْضَةَ', #2
u'والبغضة': u'وَالْبِغْضَةِ', #4
u'والبغضة': u'وَالْبِغْضَةُ', #6
u'والبغوي': u'وَالْبَغَوِيِّ', #171
u'والبغوي': u'وَالْبَغَوِيّ', #2
u'والبغوي': u'وَالْبَغَوِيَّ', #2
u'والبغوي': u'وَالْبَغَوِيُّ', #220
u'والبقار': u'وَالْبَقَّارُ', #4
u'والبقار': u'وَالْبَقَّارِ', #4
u'والبقج': u'والبقج', #1
u'والبقجة': u'وَالْبُقْجَةِ', #2
u'والبقلة': u'وَالْبَقْلَةُ', #1
u'والبقلة': u'وَالْبَقْلَةِ', #3
u'والبقم': u'وَالْبَقَّمِ', #2
u'والبقولات': u'وَالْبُقُولَاتِ', #2
u'والبقيار': u'وَالْبَقْيَارُ', #1
u'والبقير': u'وَالْبَقِيرِ', #2
u'والبلا': u'وَالْبَلَا', #1
u'والبلا': u'وَالْبِلَا', #1
u'والبلاذري': u'وَالْبَلَاذُرِيُّ', #1
u'والبلان': u'وَالْبَلَّانُ', #1
u'والبلبيسي': u'وَالْبِلْبِيسِيِّ', #1
u'والبلتعة': u'وَالْبَلْتَعَةُ', #1
u'والبلتعة': u'وَالْبُلْتُعَةُ', #1
u'والبلخش': u'وَالْبَلْخَش', #1
u'والبلخش': u'والبلخش', #2
u'والبلخش': u'وَالْبَلْخَشُ', #2
u'والبلخش': u'وَالْبَلْخَشِ', #6
u'والبلخي': u'وَالْبَلْخِيَّ', #1
u'والبلخي': u'وَالْبَلْخِيِّ', #1
u'والبلخيون': u'وَالْبَلْخِيُّونَ', #4
u'والبلخيين': u'وَالْبَلْخِيِّينَ', #2
u'والبلغم': u'وَالْبَلْغَمَ', #2
u'والبلغم': u'وَالْبَلْغَمُ', #26
u'والبلغم': u'وَالْبَلْغَمِ', #31
u'والبلغمية': u'وَالْبَلْغَمِيَّةِ', #1
u'والبلقيني': u'وَالْبُلْقِينِيُّ', #115
u'والبلقيني': u'وَالْبُلْقِينِيَّ', #2
u'والبلقيني': u'وَالْبُلْقِينِيِّ', #52
u'والبلى': u'وَالْبِلَى', #23
u'والبليلة': u'وَالْبَلِيلَةُ', #1
u'والبنادقة': u'وَالْبَنَادِقَةُ', #2
u'والبنادقة': u'وَالْبَنَادِقَةِ', #3
u'والبنانة': u'وَالْبُنَانَةُ', #1
u'والبندنيجي': u'وَالْبَنْدَنِيجِيُّ', #15
u'والبندنيجي': u'وَالْبَنْدَنِيجِيِّ', #3
u'والبندنيجي': u'وَالْبَنْدَنِيجِيّ', #99
u'والبنغش': u'وَالْبَنْغَشِ', #1
u'والبنفحة': u'وَالْبِنْفَحَةُ', #1
u'والبنفش': u'والبنفش', #1
u'والبهارات': u'وَالْبَهَارَاتِ', #2
u'والبهاق': u'وَالْبُهَاقِ', #1
u'والبهشمية': u'وَالْبَهْشَمِيَّةُ', #1
u'والبهق': u'وَالْبَهَقَ', #4
u'والبهق': u'وَالْبَهَقُ', #4
u'والبهق': u'وَالْبَهَقِ', #5
u'والبهكنة': u'وَالْبَهْكَنَةُ', #1
u'والبهلة': u'وَالْبَهْلَةُ', #2
u'والبهنسي': u'وَالْبَهْنَسِيِّ', #1
u'والبهى': u'وَالْبَهِىِّ', #1
u'والبهيتة': u'وَالْبَهِيتَةُ', #1
u'والبوارديين': u'والبوارديين', #1
u'والبواقين': u'وَالْبَوَّاقِينَ', #1
u'والبوائق': u'وَالْبَوَائِقِ', #1
u'والبوذري': u'والبوذري', #1
u'والبوذري': u'وَالْبُوذَرِيُّ', #1
u'والبوريا': u'وَالْبُورِيَا', #1
u'والبوريا': u'وَالْبُورِيَّا', #5
u'والبوشنجي': u'وَالْبُوشَنْجِيُّ', #1
u'والبوصيري': u'وَالْبُوصَيْرِيُّ', #1
u'والبوك': u'وَالْبَوْكُ', #1
u'والبويطي': u'وَالْبُوَيْطِيِّ', #27
u'والبويطي': u'وَالْبُوَيْطِيُّ', #7
u'والبئرة': u'وَالْبِئْرَةَ', #1
u'والبيانيون': u'وَالْبَيَانِيُّونَ', #2
u'والبيبرسية': u'والبيبرسية', #1
u'والبيبرسية': u'وَالْبِيبَرْسِيَّة', #1
u'والبيتوتة': u'وَالْبَيْتُوتَة', #1
u'والبيتوتة': u'وَالْبَيْتُوتَةُ', #18
u'والبيتوتة': u'وَالْبَيْتُوتَةَ', #3
u'والبيتوتة': u'وَالْبَيْتُوتَةِ', #8
u'والبيرة': u'وَالْبِيرَةِ', #1
u'والبيري': u'وَالْبِيرِيِّ', #2
u'والبيري': u'وَالْبِيرِيُّ', #3
u'والبيسار': u'وَالْبَيْسَارِ', #1
u'والبيغوري': u'وَالْبَيْغُورِيُّ', #1
u'والبيقور': u'وَالْبَيْقُورُ', #3
u'والبينه': u'وَالْبَيِّنَهْ', #1
u'والبيهسية': u'وَالْبَيْهَسِيَّةُ', #1
u'والبيهقي': u'وَالْبَيْهَقِيِّ', #111
u'والبيهقي': u'وَالْبَيْهَقِيُّ', #1271
u'والبيهقي': u'وَالْبَيْهَقِيَّ', #3
u'والبيوعات': u'وَالْبُيُوعَاتِ', #1
u'والبيوعات': u'وَالْبُيُوعَاتُ', #2
u'والبيونة': u'وَالْبَيُونَةِ', #1
u'والتابوه': u'وَالتَّابُوهِ', #2
u'والتأبي': u'وَالتَّأَبِّي', #1
u'والتآجر': u'وَالتَّآجُرِ', #2
u'والتأخذ': u'وَالتَّأَخُّذِ', #2
u'والتأخيرقوله': u'وَالتَّأْخِيرِقَوْلُهُ', #1
u'والتادلي': u'وَالتَّادَلِيِّ', #1
u'والتادلي': u'وَالتَّادَلِيُّ', #3
u'والتأدم': u'وَالتَّأَدُّمِ', #4
u'والتأدم': u'وَالتَّأَدُّمُ', #7
u'والتأدي': u'وَالتَّأَدِّي', #2
u'والتأذى': u'وَالتَّأَذِىَ', #1
u'والتأذى': u'وَالتَّأَذِّىَ', #1
u'والتأذي': u'وَالتَّأَذِّي', #23
u'والتأريب': u'وَالتَّأْرِيبُ', #4
u'والتأريب': u'وَالتَّأْرِيبِ', #4
u'والتأزيرات': u'وَالتَّأْزِيرَاتِ', #1
u'والتاسومة': u'وَالتَّاسُومَةُ', #1
u'والتاسومة': u'وَالتَّاسُومَةِ', #3
u'والتآسيا': u'والتّآسِيا', #1
u'والتآسيا': u'وَالتّآسِيَا', #1
u'والتآسيا': u'وَالتَّآسِيَا', #1
u'والتأسية': u'وَالتَّأْسِيَةُ', #1
u'والتاطه': u'وَالْتَاطَهُ', #2
u'والتأقيت': u'وَالتَّأْقِيتَ', #1
u'والتأقيت': u'وَالتَّأْقِيتُ', #14
u'والتأقيت': u'وَالتَّأْقِيتِ', #15
u'والتالة': u'وَالتَّالَّةَ', #1
u'والتالة': u'وَالتَّالَّةُ', #1
u'والتالف': u'وَالتَّالِفَ', #1
u'والتالف': u'وَالتَّالِفِ', #2
u'والتالف': u'وَالتَّالِفُ', #38
u'والتالفين': u'وَالتَّالِفَيْنِ', #1
u'والتالى': u'وَالتَّالِىَ', #1
u'والتأنف': u'وَالتَّأَنُّفُ', #1
u'والتاودي': u'وَالتَّاوُدِيُّ', #1
u'والتباب': u'وَالتّبَابُ', #3
u'والتبابعة': u'وَالتّبَابِعَةُ', #1
u'والتبابعة': u'وَالتَّبَابِعَةُ', #1
u'والتباعة': u'وَالْتَبَاعَةِ', #1
u'والتباعة': u'وَالتّبَاعَةِ', #2
u'والتباعة': u'وَالتَّبَاعَةُ', #2
u'والتباعة': u'وَالتِّبَاعَةُ', #6
u'والتباله': u'وَالتّبَالُهِ', #1
u'والتباهل': u'وَالتَّبَاهُلُ', #3
u'والتباؤس': u'وَالتَّبَاؤُسُ', #1
u'والتباؤس': u'وَالتَّبَاؤُسِ', #2
u'والتبب': u'وَالتّبَبُ', #1
u'والتبب': u'وَالتّبَبِ', #2
u'والتبتيل': u'وَالتَّبْتِيلِ', #1
u'والتبدت': u'وَالْتَبَدَتْ', #1
u'والتبدع': u'وَالتَّبَدُّعَ', #1
u'والتبديع': u'وَالتَّبْدِيعُ', #1
u'والتبديع': u'وَالتَّبْدِيعِ', #1
u'والتبرين': u'وَالتِّبْرَيْنِ', #1
u'والتبصرة': u'وَالتَّبْصِرَةُ', #3
u'والتبصرة': u'وَالتَّبْصِرَةِ', #93
u'والتبطن': u'وَالتَّبَطُّنُ', #1
u'والتبعد': u'وَالتَّبَعُّدُ', #1
u'والتبغيل': u'وَالتّبْغِيلُ', #1
u'والتبكر': u'وَالتَّبَكُّرِ', #1
u'والتبوء': u'وَالتَّبَوُّءُ', #1
u'والتبوئة': u'وَالتَّبْوِئَةِ', #1
u'والتبوئة': u'وَالتَّبْوِئَةُ', #19
u'والتبيانا': u'والتِّبْيَانَاً', #1
u'والتبيع': u'وَالتَّبِيعُ', #12
u'والتبيع': u'وَالتَّبِيعَ', #3
u'والتبيع': u'وَالتَّبِيعِ', #6
u'والتبيعة': u'وَالتَّبِيعَةُ', #1
u'والتبيعة': u'وَالتَّبِيعَةِ', #6
u'والتتارخانية': u'وَالتَّتَارْخَانِيَّة', #13
u'والتتارخانية': u'والتتارخانية', #56
u'والتتارخانية': u'وَالتَّتَارْخَانِيَّةِ', #9
u'والتتائي': u'والتتائي', #1
u'والتتائي': u'وَالتَّتَّائِيِّ', #14
u'والتتائي': u'وَالتَّتَّائِيُّ', #8
u'والتتريب': u'وَالتَّتْرِيبَ', #1
u'والتتريب': u'وَالتَّتْرِيبُ', #1
u'والتتريب': u'وَالتَّتْرِيبِ', #6
u'والتتيم': u'وَالتَّتَيُّمُ', #1
u'والتثلج': u'وَالتَّثَلُّجُ', #1
u'والتجاحد': u'وَالتَّجَاحُدُ', #2
u'والتجاره': u'وَالتِّجَارَهْ', #1
u'والتجاعل': u'وَالتَّجَاعُلُ', #1
u'والتجري': u'وَالتَّجَرِّي', #1
u'والتجزي': u'وَالتَّجَزِّي', #1
u'والتجزي': u'وَالَّتَجَزِّيَ', #1
u'والتجسيس': u'وَالتَّجْسِيسُ', #2
u'والتجمر': u'وَالتَّجَمُّرِ', #1
u'والتجمر': u'وَالتَّجَمُّرُ', #2
u'والتجمي': u'وَالْتَجِمِي', #1
u'والتجنح': u'وَالتَّجَنُّحُ', #1
u'والتجى': u'وَالْتَجَى', #1
u'والتجيب': u'والتجيب', #1
u'والتحابب': u'وَالتَّحَابُبُ', #2
u'والتحابب': u'وَالتَّحَابُبِ', #2
u'والتحاتح': u'وَالتَّحَاتِحِ', #1
u'والتحتيم': u'وَالتَّحْتِيمِ', #1
u'والتحذيف': u'وَالتَّحْذِيفَ', #1
u'والتحذيف': u'وَالتَّحْذِيفُ', #5
u'والتحذيف': u'وَالتَّحْذِيفِ', #7
u'والتحرم': u'وَالتَّحَرُّمَ', #3
u'والتحرم': u'وَالتَّحَرُّمِ', #9
u'والتحزن': u'وَالتَّحَزُّنِ', #4
u'والتحطب': u'وَالتَّحَطُّبِ', #2
u'والتحفش': u'وَالتَّحَفُّشُ', #1
u'والتحفل': u'وَالتَّحَفُّلِ', #1
u'والتحلم': u'وَالتَّحَلُّمُ', #2
u'والتحلى': u'وَالتَّحَلِّى', #1
u'والتحميدة': u'وَالتَّحْمِيدَةِ', #5
u'والتحنف': u'وَالتّحَنّفُ', #2
u'والتحنك': u'وَالتَّحَنُّكُ', #2
u'والتحنن': u'وَالتَّحَنُّنِ', #1
u'والتحوال': u'وَالتَّحْوَالِ', #2
u'والتحيف': u'وَالتَّحَيُّفِ', #2
u'والتحيل': u'وَالتَّحَيُّلِ', #13
u'والتحيل': u'وَالتَّحَيُّلُ', #4
u'والتخارج': u'وَالتَّخَارُجِ', #2
u'والتخالج': u'وَالتَّخَالُجِ', #1
u'والتخاير': u'وَالتَّخَايُرِ', #3
u'والتخاير': u'وَالتَّخَايُرُ', #8
u'والتختم': u'والتختم', #1
u'والتختم': u'وَالتَّخَتُّمَ', #1
u'والتختم': u'وَالتَّخَتُّمُ', #21
u'والتختم': u'وَالتَّخَتُّمِ', #8
u'والتخرص': u'وَالتَّخَرُّصِ', #1
u'والتخريص': u'وَالتَّخْرِيصُ', #1
u'والتخريص': u'وَالتَّخْرِيصِ', #2
u'والتخصر': u'وَالتَّخَصُّرَ', #1
u'والتخصر': u'وَالتَّخَصُّرِ', #2
u'والتخصر': u'وَالتَّخَصُّرُ', #5
u'والتخلج': u'وَالتَّخَلُّجُ', #1
u'والتخن': u'وَالتُّخْنِ', #1
u'والتخويه': u'وَالتَّخْوِيَهْ', #1
u'والتد': u'وَالْتَدَّ', #1
u'والتدثيث': u'وَالتَّدْثِيثُ', #1
u'والتدعي': u'وَالتَّدَعِّي', #1
u'وألتدم': u'وَأَلْتَدِمُ', #1
u'والتذه': u'وَالْتَذَّهُ', #1
u'والترابة': u'وَالتُّرَابَةِ', #1
u'والتراجيح': u'وَالتَّرَاجِيحَ', #1
u'والتراجيح': u'وَالتَّرَاجِيحُ', #3
u'والتراجيح': u'وَالتَّرَاجِيحِ', #5
u'والتراد': u'وَالتَّرَادِّ', #1
u'والتراد': u'وَالتَّرَادَّ', #3
u'والتراد': u'وَالتَّرَادُّ', #6
u'والتراسين': u'وَالتَّرَّاسَيْنِ', #1
u'والتراكمة': u'وَالتَّرَاكِمَةُ', #1
u'والتراكمة': u'وَالتَّرَاكِمَةِ', #2
u'والتراكن': u'وَالتَّرَاكُنُ', #2
u'والترامات': u'والتِّرَامَاتِ', #1
u'والتربيعة': u'وَالتَّرْبِيعَةِ', #2
u'والترة': u'وَالتّرَةُ', #1
u'والترة': u'وَالتِّرَةُ', #1
u'والترترة': u'وَالتَّرْتَرَةُ', #5
u'والترخص': u'وَالتَّرَخُّصَ', #1
u'والترخص': u'وَالتَّرَخُّصُ', #10
u'والترخص': u'وَالتَّرَخُّصِ', #4
u'والترزيق': u'وَالتَّرْزِيقُ', #2
u'والترشد': u'وَالتَّرَشُّدِ', #2
u'والترشيش': u'وَالتَّرْشِيشِ', #1
u'والترفيخ': u'وَالتَّرْفِيخِ', #2
u'والتركاش': u'وَالتِّرْكَاشِ', #1
u'والتركاش': u'والتركاش', #2
u'والتركه': u'وَالتَّرِكَهْ', #1
u'والترنجبيل': u'وَالتَّرْنَجَبِيلِ', #1
u'والترنجبين': u'والترنجبين', #4
u'والترنجيل': u'وَالتَّرَنْجِيلِ', #1
u'والتروك': u'وَالتُّرُوكَ', #1
u'والتروك': u'وَالتُّرُوكُ', #1
u'والتروك': u'وَالتُّرُوكِ', #9
u'والترويغ': u'وَالتَّرْوِيغِ', #1
u'والترية': u'وَالتَّرِيَّةُ', #1
u'والترية': u'وَالتِّرْيَةُ', #1
u'والترية': u'وَالتَّرِيَةُ', #2
u'والتزرر': u'وَالتَّزَرُّرُ', #2
u'والتزريق': u'وَالتَّزْرِيقِ', #1
u'والتزكيه': u'وَالتَّزْكِيَهْ', #1
u'والتزليع': u'وَالتَّزْلِيعِ', #1
u'والتزيد': u'وَالتَّزَيُّدُ', #1
u'والتزيد': u'وَالتَّزَيُّدِ', #3
u'والتساخين': u'وَالتَّسَاخِينَ', #1
u'والتساخين': u'وَالتَّسَاخِينُ', #2
u'والتساخين': u'وَالتَّسَاخِينِ', #5
u'والتسبيت': u'وَالتَّسْبِيتُ', #3
u'والتسبيد': u'وَالتّسْبِيدُ', #1
u'والتسحب': u'وَالتَّسَحُّبُ', #1
u'والتسحر': u'وَالتَّسَحُّرِ', #1
u'والتسحر': u'وَالتَّسَحُّرُ', #4
u'والتسخط': u'وَالتَّسَخُّطِ', #2
u'والتسخيم': u'وَالتَّسْخِيمَ', #5
u'والتسخيم': u'وَالتَّسْخِيمِ', #7
u'والتسري': u'وَالتَّسَرِّي', #36
u'والتسعان': u'وَالتُّسْعَانِ', #2
u'والتسليمة': u'وَالتَّسْلِيمَةُ', #14
u'والتسليمة': u'وَالتَّسْلِيمَةَ', #3
u'والتسليمة': u'وَالتَّسْلِيمَةِ', #7
u'والتسليمتان': u'والتَّسْلِيمَتَانِ', #1
u'والتسمح': u'وَالتَّسَمُّحُ', #3
u'والتسميعة': u'وَالتَّسْمِيعَةِ', #1
u'والتسميه': u'وَالتَّسْمِيَهْ', #1
u'والتسويه': u'وَالتَّسْوِيَهْ', #1
u'والتشاق': u'وَالتَّشَاقُّ', #1
u'والتشريج': u'وَالتَّشْرِيجِ', #1
u'والتشريج': u'وَالتَّشْرِيجُ', #8
u'والتشطر': u'وَالتَّشَطُّرُ', #1
u'والتشطط': u'وَالتَّشَطُّطِ', #1
u'والتشقيص': u'وَالتَّشْقِيصِ', #1
u'والتشقيص': u'وَالتَّشْقِيصُ', #7
u'والتشهر': u'وَالتَّشَهُّرِ', #1
u'والتصاون': u'وَالتَّصَاوُنَ', #1
u'والتصاون': u'وَالتَّصَاوُنُ', #1
u'والتصاون': u'وَالتَّصَاوُنِ', #4
u'والتصرية': u'وَالتَّصْرِيَة', #1
u'والتصرية،': u'وَالتَّصْرِيَةِ،', #2
u'والتصرية': u'وَالتَّصْرِيَةِ', #3
u'والتصرية': u'وَالتَّصْرِيَةُ', #9
u'والتصفيقة': u'وَالتَّصْفِيقَةُ', #1
u'والتضبيب': u'وَالتَّضْبِيبِ', #2
u'والتضحي': u'وَالتَّضَحِّي', #2
u'والتضمير': u'وَالتَّضْمِيرِ', #1
u'والتطاريف': u'وَالتَّطَارِيفُ', #1
u'والتطاريف': u'وَالتَّطَارِيفِ', #1
u'والتطالب': u'وَالتَّطَالُبِ', #1
u'والتطرية': u'وَالتَّطْرِيَةِ', #1
u'والتطفيل': u'وَالتَّطْفِيلُ', #1
u'والتطليقة': u'وَالتَّطْلِيقَةِ', #2
u'والتطليقة': u'وَالتَّطْلِيقَةُ', #5
u'والتطليقتان': u'وَالتَّطْلِيقَتَانِ', #1
u'والتطليقتين': u'وَالتَّطْلِيقَتَيْنِ', #8
u'والتطمث': u'وَالتَّطَمُّثِ', #1
u'والتطوية': u'والتطوية', #1
u'والتطين': u'وَالتَّطَيُّنِ', #1
u'والتعاذير': u'وَالتَّعَاذِيرِ', #1
u'والتعازير': u'وَالتَّعَازِيرُ', #2
u'والتعازير': u'وَالتَّعَازِيرِ', #33
u'والتعاسيف': u'وَالتَّعَاسِيفُ', #1
u'والتعاشير': u'وَالتَّعَاشِيرِ', #1
u'والتعاطر': u'وَالتَّعَاطُرِ', #1
u'والتعاقه': u'وَالْتِعَاقِهِ', #3
u'والتعانه': u'وَالْتِعَانِهِ', #1
u'والتعته': u'وَالتَّعَتُّهُ', #1
u'والتعريك': u'وَالتَّعْرِيكِ', #2
u'والتعزيل': u'وَالتَّعْزِيلِ', #1
u'والتعضية': u'وَالتَّعْضِيَةُ', #2
u'والتعقاد': u'وَالتِّعْقَادُ', #2
u'والتعيب': u'وَالتَّعَيُّبَ', #2
u'والتعيب': u'وَالتَّعَيُّبُ', #8
u'والتعيب': u'وَالتَّعَيُّبِ', #9
u'والتغاشي': u'وَالتَّغَاشِي', #1
u'والتغاطي': u'والتَّغَاطِي', #1
u'والتغالي': u'وَالتَّغَالِي', #7
u'والتغبير': u'وَالتَّغْبِيرُ', #1
u'والتغبير': u'وَالتَّغْبِيرِ', #1
u'والتغبيط': u'وَالتَّغْبِيطِ', #1
u'والتغميز': u'وَالتَّغْمِيزُ', #1
u'والتفاريع': u'وَالتَّفَارِيعَ', #1
u'والتفاريع': u'وَالتَّفَارِيعُ', #3
u'والتفتازاني': u'وَالتَّفْتَازَانِي', #7
u'والتفث': u'وَالتَّفَثِ', #2
u'والتفث': u'وَالتَّفَثَ', #3
u'والتفث': u'وَالتَّفَثُ', #6
u'والتفعل': u'وَالتَّفَعُّلُ', #2
u'والتفلة': u'وَالتَّفِلَةِ', #1
u'والتفهني': u'وَالتَّفَهْنِيُّ', #1
u'والتفهني': u'وَالتَّفِهْنِيُّ', #1
u'والتفهني': u'وَالتَّفْهَنِيُّ', #1
u'والتقادير': u'وَالتَّقَادِيرُ', #1
u'والتقادير': u'وَالتَّقَادِيرِ', #5
u'والتقار': u'وَالتَّقَارِّ', #1
u'والتقاص': u'وَالتَّقَاصُّ', #3
u'والتقاص': u'وَالتَّقَاصِّ', #3
u'والتقالي': u'وَالتَّقَالِي', #1
u'والتقاوة': u'وَالتَّقَاوَةُ', #1
u'والتقرش': u'وَالتَّقَرُّشُ', #1
u'والتقرش': u'وَالتّقَرّشُ', #2
u'والتقري': u'وَالتَّقَرِّي', #1
u'والتقسيما': u'وَالتَّقْسِيمَا', #1
u'والتقلل': u'وَالتَّقَلُّلَ', #1
u'والتقلل': u'وَالتَّقَلُّلُ', #2
u'والتقلل': u'وَالتَّقَلُّلِ', #8
u'والتقليس': u'وَالتَّقْلِيس', #1
u'والتقليس': u'وَالتَّقْلِيسُ', #1
u'والتقور': u'وَالتَّقَوُّرُ', #2
u'والتكا': u'وَالتّكَا', #1
u'والتكاري': u'وَالتَّكَارِي', #1
u'والتكأكؤ': u'وَالتَّكَأْكُؤُ', #1
u'والتكدي': u'وَالتَّكَدِّي', #5
u'والتكرور': u'وَالتَّكْرُورُ', #1
u'والتكرور': u'وَالتَّكْرُورِ', #3
u'والتكروري': u'وَالتَّكْرُورِيُّ', #1
u'والتكروري': u'وَالتَّكْرُورِيَّ', #2
u'والتكريب': u'وَالتَّكْرِيبُ', #1
u'والتكفؤ': u'وَالتَّكَفُّؤُ', #1
u'والتكفؤ': u'وَالتَّكَفُّؤِ', #1
u'والتكفيت': u'وَالتَّكْفِيتُ', #1
u'والتكلان': u'وَالتُّكْلَانُ', #1
u'والتكلان': u'وَالتُّكْلَانِ', #1
u'والتكلثم': u'وَالتَّكَلْثُمِ', #1
u'والتكلما': u'وَالتَّكَلُّمَا', #1
u'والتكهل': u'وَالتَّكَهُّلُ', #1
u'والتلابيس': u'وَالتَّلَابِيسِ', #1
u'والتلاد': u'وَالتِّلاَدُ', #1
u'والتلاد': u'وَالتِّلَادُ', #2
u'والتلاق': u'وَالتَّلَاقُ', #2
u'والتلبينة': u'وَالتَّلْبِينَةُ', #1
u'والتلتلة': u'وَالتَّلْتَلَةُ', #3
u'والتلجم': u'وَالتَّلَجُّمُ', #1
u'والتلجم': u'وَالتَّلَجُّمِ', #5
u'والتلحي': u'وَالتَّلَحِّي', #1
u'والتلعاب': u'وَالتِّلْعَابِ', #1
u'والتلفع': u'وَالتَّلَفُّع', #1
u'والتلمساني': u'والتِّلِمْسَانِيِّ', #1
u'والتلمساني': u'والتِّلِمْسَانِيُّ', #3
u'والتلمساني': u'وَالتِّلْمِسَانِيّ', #3
u'والتلمساني': u'وَالتِّلْمِسَانِيُّ', #4
u'والتلمظ': u'وَالتَّلَمُّظُ', #1
u'والتمالؤ': u'وَالتَّمَالُؤُ', #1
u'والتماما': u'وَالتَّمَامَا', #1
u'والتمانع': u'وَالتَّمَانُعُ', #11
u'والتماهن': u'وَالتَّمَاهُنِ', #1
u'والتمتان': u'وَالتِّمْتَانُ', #1
u'والتمجس': u'وَالتَّمَجُّسِ', #3
u'والتمحل': u'وَالتَّمَحُّلُ', #1
u'والتمحل': u'وَالتَّمَحُّلِ', #1
u'والتمخي': u'وَالتَّمَخِّي', #1
u'والتمدح': u'وَالتَّمَدُّحِ', #2
u'والتمدح': u'وَالتَّمَدُّحُ', #4
u'والتمرتاش': u'وَالتُّمُرْتَاشِ', #1
u'والتمرتاشي': u'وَالتُّمُرْتَاشِيُّ', #1
u'والتمرتاشي': u'وَالتُّمُرْتَاشِيّ', #3
u'والتمرتاشي': u'والتمرتاشي', #30
u'والتمرتاشي': u'وَالتُّمُرْتَاشِيِّ', #7
u'والتمرتاشية': u'والتمرتاشية', #1
u'والتمريخ': u'وَالتَّمْرِيخِ', #1
u'والتمريييي': u'وَالتَّمْرِيييي', #1
u'والتمسخر': u'وَالتَّمَسْخُرُ', #1
u'والتمشط': u'وَالتَّمَشُّطَ', #1
u'والتمشط': u'وَالتَّمَشُّطُ', #1
u'والتمعش': u'وَالتَّمَعُّشِ', #2
u'والتمعك': u'وَالتَّمَعُّكِ', #1
u'والتمودرات': u'وَالتُّمُودَرَاتِ', #1
u'والتميميون': u'وَالتَّمِيمِيُّونَ', #2
u'والتنابيل': u'وَالتّنَابِيلُ', #2
u'والتناجز': u'وَالتَّنَاجُزَ', #1
u'والتناجز': u'وَالتَّنَاجُزِ', #11
u'والتناجز': u'وَالتَّنَاجُزُ', #4
u'والتناجش': u'وَالتَّنَاجُشِ', #1
u'والتناضب': u'والتناضب', #1
u'والتناضب': u'وَالتَّنَاضِبُ', #1
u'والتنافذ': u'وَالتَّنَافُذَ', #2
u'والتنافيس': u'وَالتَّنَافِيسَ', #1
u'والتنافيس': u'وَالتَّنَافِيسُ', #2
u'والتنخع': u'وَالتَّنَخُّعُ', #1
u'والتنخم': u'وَالتَّنَخُّمَ', #1
u'والتنخم': u'وَالتَّنَخُّمُ', #6
u'والتندير': u'وَالتَّنْدِيرِ', #1
u'والتنزية': u'وَالتَّنْزِيَةِ', #1
u'والتنضباوي': u'وَالتَّنْضَبَاوِيّ', #1
u'والتنضيض': u'وَالتَّنْضِيضُ', #4
u'والتنضيض': u'وَالتَّنْضِيضِ', #5
u'والتنطس': u'وَالتّنَطّسُ', #1
u'والتنفر': u'وَالتَّنَفُّرُ', #3
u'والتنميص': u'وَالتَّنْمِيصُ', #4
u'والتنميه': u'وَالتَّنْمِيَهْ', #1
u'والتنوط': u'وَالتُّنْوِطِ', #1
u'والتهارج': u'وَالتَّهَارُجِ', #2
u'والتهاليل': u'وَالتَّهَالِيلِ', #10
u'والتهانيء': u'وَالتَّهَانِيءُ', #1
u'والتهايؤ': u'وَالتَّهَايُؤِ', #2
u'والتهايؤ': u'وَالتَّهَايُؤُ', #41
u'والتهزي': u'وَالتَّهَزِّي', #1
u'والتهمز': u'وَالتَّهَمُّزُ', #1
u'والتهمم': u'وَالتَّهَمُّمُ', #4
u'والتهنئه': u'وَالتَّهْنِئَهْ', #1
u'والتهيئ': u'وَالتَّهَيُّئ', #1
u'والتوادد': u'وَالتَّوَادُدِ', #1
u'والتوبان': u'وَالتَّوْبَانُ', #1
u'والتوحية': u'وَالتَّوْحِيَةُ', #4
u'والتور': u'وَالتَّوْرُ', #3
u'والتور': u'وَالتَّوْرِ', #3
u'والتوربشتي': u'وَالتُّورْبَشْتِيّ', #1
u'والتورة': u'وَالتَّوْرَةِ', #1
u'والتوسلا': u'وَالتَّوَسّلاَ', #1
u'والتوعيد': u'وَالتَّوْعِيدَ', #1
u'والتوقان': u'وَالتَّوَقَانَ', #1
u'والتوقان': u'وَالتَّوَقَانُ', #1
u'والتوقان': u'وَالتَّوَقَانِ', #1
u'والتوكاف': u'والتوكاف', #1
u'والتولاء': u'وَالتَّوْلَاءُ', #2
u'والتولاء': u'وَالتَّوْلَاءِ', #2
u'والتولة': u'والتولة', #1
u'والتولة': u'وَالتَّوَلَةَ', #1
u'والتولة': u'وَالتَّوَلَةُ', #1
u'والتولة': u'وَالتُّوَلَةِ', #1
u'والتولة': u'وَالتِّوَلَة', #1
u'والتولة': u'وَالتِّوَلَةَ', #3
u'والتولة': u'وَالتُّوَلَةُ', #5
u'والتولة': u'وَالتُّوَلَةَ', #7
u'والتولى': u'وَالتَّوَلِّى', #4
u'والتومة': u'وَالتّومَةُ', #1
u'والتومنية': u'وَالتُّومَنِيَّةُ', #1
u'والتويتات': u'وَالتّوَيْتَاتِ', #1
u'والتى': u'والتى', #1
u'والتى': u'وَالَّتِى', #17
u'وألتى': u'وَأَلْتَى', #2
u'والتيابين': u'وَالتَّيَّابِينَ', #1
u'والتيامنة': u'وَالتَّيَامِنَةَ', #1
u'والتيامنة': u'والتيامنة', #2
u'والتيامنة': u'وَالتَّيَامِنَةُ', #3
u'والتيامنة': u'وَالتَّيَامِنَةِ', #3
u'والتيتل': u'وَالتَّيْتَلُ', #1
u'والتيتل': u'وَالتَّيْتَلِ', #5
u'والتيغار': u'والتِّيغَارُ', #1
u'والتيك': u'وَالتَّيْكَ', #1
u'والتيمار': u'والتيمار', #1
u'والتيمار': u'وَالتَّيْمَارِ', #2
u'والتيماري': u'وَالتَّيْمَارِيِّ', #6
u'والثاتي': u'وَالِثَاتِي', #1
u'والثارة': u'وَالثَّارَّةِ', #1
u'والثأط': u'وَالثّأَطُ', #1
u'والثأط': u'وَالثَّأْطُ', #1
u'والثان': u'وَالِثَانِ', #1
u'والثان': u'وَالثَّانِ', #11
u'والثانى': u'وَالثَّانِى', #12
u'والثبر': u'والثبر', #1
u'والثبطة': u'وَالثَّبِطَةُ', #2
u'والثبنة': u'وَالثُّبْنَةُ', #1
u'والثجلة': u'وَالثَّجْلَةُ', #1
u'والثجير': u'وَالثَّجِيرُ', #1
u'والثجير': u'وَالثَّجِيرِ', #6
u'والثجيرة': u'وَالثَّجِيرَةُ', #1
u'والثخانة': u'وَالثَّخَانَةُ', #1
u'والثخانة': u'وَالثَّخَانَةَ', #2
u'والثخانة': u'وَالثَّخَانَةِ', #6
u'والثخن': u'وَالثِّخَنَ', #1
u'والثخن': u'وَالثِّخَنُ', #3
u'والثخن': u'وَالثِّخَنِ', #3
u'والثدن': u'وَالثّدَنُ', #1
u'والثرماء': u'وَالثَّرْمَاءُ', #1
u'والثروب،': u'وَالثُّرُوبُ،', #1
u'والثعارير': u'وَالثَّعَارِيرُ', #1
u'والثعالبي': u'وَالثَّعَالِبِيُّ', #1
u'والثعول': u'وَالثَّعُولُ', #1
u'والثغام': u'وَالثّغَامُ', #1
u'والثغامة': u'وَالثَّغَامَةَ', #1
u'والثغية': u'وَالثَّغْيَةُ', #1
u'والثفا': u'وَالثُّفَّا', #1
u'والثفاء': u'وَالثُّفَّاءُ', #1
u'والثفر': u'وَالثَّفْرُ', #1
u'والثفر': u'وَالثُّفْرُ', #2
u'والثفر': u'وَالثَّفْرِ', #5
u'والثفر': u'وَالثُّفْرِ', #6
u'والثقفي': u'وَالثَّقَفِيّ', #1
u'والثقفي،': u'وَالثَّقَفِيُّ،', #1
u'والثقفي': u'وَالثَّقَفِيُّ', #2
u'والثقفي،': u'وَالثَّقَفِيِّ،', #2
u'والثقفى': u'وَالثَّقَفِىِّ', #2
u'والثقفى': u'وَالثَّقَفِىُّ', #5
u'والثلاة': u'والثلاة', #1
u'والثلثمائة': u'وَالثَّلَثَمِائَةِ', #1
u'والثلثمائة': u'وَالثَّلَثُمِائَةِ', #2
u'والثلثمائة': u'وَالثَّلَثِمِائَةِ', #2
u'والثلجم': u'والثَّلْجَمِ', #1
u'والثلوم': u'وَالثُّلُومَ', #1
u'والثلوم': u'وَالثُّلُومِ', #1
u'والثمارالوجه': u'وَالثِّمَارِالْوَجْهُ', #1
u'والثمام': u'وَالثّمَامُ', #1
u'والثمام': u'وَالثُّمَامُ', #1
u'والثمامية': u'وَالثُّمَامِيَّةُ', #1
u'والثمود': u'وَالثَّمُودَ', #1
u'والثندوة': u'وَالثَّنْدُوَةَ', #1
u'والثندوة': u'وَالثَّنْدُوَةُ', #5
u'والثنى': u'وَالثَّنِىَّ', #1
u'والثنى': u'وَالثِّنَى', #1
u'والثنيا': u'وَالثَّنِيَّا', #1
u'والثنيا': u'وَالثُّنْيَا', #11
u'والثؤاج': u'وَالثُّؤَاجُ', #1
u'والثواقيل': u'وَالثَّوَاقِيلِ', #1
u'والثوبانية': u'وَالثَّوْبَانِيَّةُ', #1
u'والثؤثور': u'وَالثّؤْثُورُ', #1
u'والثورى': u'وَالثَّوْرِىُّ', #12
u'والثورى': u'وَالثَّوْرِىِّ', #7
u'والثول': u'وَالثّوْلُ', #1
u'والثولاء': u'وَالثَّوْلَاءُ', #5
u'والثولاء': u'وَالثَّوْلَاءِ', #7
u'والثيابة': u'وَالثِّيَابَةِ', #6
u'والثيابة': u'وَالثِّيَابَةُ', #8
u'والثيابي': u'وَالثِّيَابِيُّ', #1
u'والثيابي': u'وَالثِّيَابِيِّ', #5
u'والثيبة': u'وَالثَّيِّبَةَ', #3
u'والثيوبة': u'وَالثُّيُوبَةَ', #1
u'والثيوبة': u'وَالثُّيُوبَةُ', #11
u'والثيوبة': u'وَالثُّيُوبَةِ', #36
u'والجاجرمي': u'وَالْجَاجَرَمِيُّ', #1
u'والجاربردي': u'والجارْبُرْدِيُّ', #2
u'والجارود': u'وَالْجَارُودُ', #4
u'والجارودي': u'وَالْجَارُودِيُّ', #1
u'والجاروس': u'وَالْجَارُوسُ', #1
u'والجاريه': u'وَالْجَارِيَهْ', #1
u'والجاسمين': u'وَالْجَاسِمَيْنِ', #1
u'والجاشم': u'وَالْجَاشِمُ', #1
u'والجامزون': u'وَالْجَامِزُونَ', #1
u'والجامكيات': u'والجَامِكِيَّاتِ', #1
u'والجامكية': u'وَالْجَامْكِيَّةُ', #1
u'والجامكية': u'وَالْجَامَكِيَّةُ', #3
u'والجامكية': u'وَالْجَامِكِيَّةُ', #3
u'والجامكية': u'وَالْجَامِكِيَّةِ', #3
u'والجاورس': u'وَالْجَاوَرْسَ', #1
u'والجاورس': u'وَالْجَاوَرْسِ', #1
u'والجاورس': u'وَالْجَاوَرْسُ', #2
u'والجاويشية': u'وَالْجَاوِيشِيَّةُ', #1
u'والجباجب': u'وَالْجَبَاجِبُ', #2
u'والجباجب': u'وَالْجُبَاجِبُ', #2
u'والجبت': u'وَالْجِبْتُ', #4
u'والجبران': u'وَالْجُبْرَانُ', #15
u'والجبران': u'وَالْجُبْرَانِ', #3
u'والجبرانات': u'وَالْجُبْرَانَاتُ', #1
u'والجبرانات': u'وَالْجُبْرَانَاتِ', #1
u'والجبرانين': u'وَالْجُبْرَانَيْنِ', #2
u'والجبروة': u'وَالْجَبَرُوَّةِ', #1
u'والجبصين': u'والجبصين', #1
u'والجبلا': u'وَالْجَبَلَا', #2
u'والجبنة': u'وَالْجُبْنَةُ', #1
u'والجبنة': u'وَالْجُبْنَةِ', #1
u'والجبوب': u'وَالْجَبُوبِ', #1
u'والجبورة': u'وَالْجَبُّورَةِ', #1
u'والجبيرة': u'وَالْجَبِيرَةَ', #1
u'والجبيرة': u'وَالْجَبِيرَةُ', #15
u'والجبيرة': u'وَالْجَبِيرَةِ', #15
u'والجبيل': u'وَالْجُبَيْلُ', #2
u'والجثوم': u'وَالْجُثُومِ', #1
u'والجحفة': u'وَالْجَحْفَةُ', #1
u'والجحفة': u'وَالْجُحْفَة', #1
u'والجحفة': u'وَالْجُحْفَةَ', #1
u'والجحفة': u'وَالْجُحْفَةُ', #12
u'والجحفة': u'وَالْجُحْفَةِ', #6
u'والجحل': u'وَالْجَحْلُ', #3
u'والجدامة': u'وَالْجُدَامَةُ', #1
u'والجدان': u'وَالْجَدَّانِ', #1
u'والجداية': u'وَالْجَدَايَةُ', #2
u'والجدك': u'وَالْجَدَكُ', #1
u'والجدك': u'وَالْجَدَكِ', #1
u'والجدن': u'وَالْجَدَنُ', #1
u'والجده': u'وَالْجِدَّهْ', #1
u'والجدوب': u'وَالْجُدُوبُ', #1
u'والجدودة': u'وَالْجُدُودَةَ', #1
u'والجدودة': u'وَالْجُدُودَةُ', #11
u'والجدودة': u'وَالْجُدُودَةِ', #5
u'والجدودية': u'وَالْجُدُودِيَّةُ', #1
u'والجدين': u'وَالْجَدَّيْنِ', #3
u'والجذة': u'وَالْجُذَّةِ', #1
u'والجذعات': u'وَالْجَذَعَاتِ', #3
u'والجذعة': u'وَالْجَذَعَةِ', #17
u'والجذعة': u'وَالْجَذَعَةُ', #22
u'والجذلة': u'وَالْجِذْلَةُ', #1
u'والجراسيا': u'والجراسيا', #1
u'والجرائحي': u'وَالْجَرَائِحِيُّ', #1
u'والجرائحي': u'وَالْجَرَائِحِيَّ', #3
u'والجرائحيين': u'والجرائحيين', #3
u'والجرايات': u'وَالْجِرَايَاتِ', #1
u'والجراية': u'وَالْجِرَايَةِ', #2
u'والجرايحي': u'وَالْجَرَايِحِيُّ', #1
u'والجربا': u'وَالْجَرْبَا', #1
u'والجرجار': u'وَالْجَرْجَارِ', #1
u'والجرجاني،': u'والجرجاني،', #1
u'والجرجانى': u'وَالْجُرْجَانِىُّ', #1
u'والجرجاني': u'وَالْجُرْجَانِيِّ', #12
u'والجرجاني،': u'وَالْجُرْجَانِيُّ،', #2
u'والجرجاني': u'وَالْجُرْجَانِيُّ', #81
u'والجرجانيات': u'والجرجانيات', #3
u'والجرجانية': u'وَالْجُرْجَانِيَّة', #1
u'والجرجانية': u'والجرجانية', #2
u'والجرجير': u'وَالْجِرْجِير', #1
u'والجرجير': u'وَالْجِرْجِيرُ', #1
u'والجرصن': u'وَالْجُرْصُنَ', #2
u'والجرصن': u'وَالْجُرْصُنُ', #2
u'والجرصن': u'والجرصن', #3
u'والجرصن': u'وَالْجُرْصُنِ', #4
u'والجرموق': u'وَالْجُرْمُوقُ', #12
u'والجرموق': u'وَالْجُرْمُوقِ', #5
u'والجرموقين': u'وَالْجُرْمُوقَيْنِ', #3
u'والجرن': u'وَالْجُرْنُ', #2
u'والجرهمية': u'وَالْجُرْهُمِيَّةُ', #1
u'والجريب': u'وَالْجَرِيبِ', #1
u'والجريب': u'وَالْجَرِيبُ', #18
u'والجريث': u'وَالْجِرِّيثُ', #3
u'والجريش': u'وَالْجَرِيشِ', #1
u'والجرين': u'وَالْجَرِينَ', #1
u'والجرين': u'وَالْجَرِينُ', #10
u'والجرين': u'وَالْجَرِينِ', #21
u'والجزا': u'وَالْجَزَا', #2
u'والجزافة': u'وَالْجِزَافَةُ', #1
u'والجزافين': u'وَالْجُزَافَيْنِ', #1
u'والجزرة': u'وَالْجَزَرَةُ', #1
u'والجزعا': u'وَالْجَزَعَا', #1
u'والجزولي': u'وَالْجُزُولِيَّ', #1
u'والجزولي': u'وَالْجُزُولِيُّ', #3
u'والجزولي': u'وَالْجُزُولِيِّ', #5
u'والجزيري': u'وَالْجَزِيرِيِّ', #3
u'والجزيري': u'وَالْجَزِيرِيُّ', #5
u'والجسة': u'وَالْجَسّةِ', #1
u'والجسة': u'وَالْجَسَّةُ', #1
u'والجسة': u'وَالْجِسَةُ', #1
u'والجشأ': u'وَالْجُشَأُ', #1
u'والجشا': u'وَالْجَشَّا', #1
u'والجشب': u'وَالْجَشْبَ', #1
u'والجعادر': u'وَالْجَعَادِرُ', #1
u'والجعالات': u'وَالْجِعَالَاتِ', #1
u'والجعالات': u'وَالْجَعَالَاتِ', #3
u'والجعالة': u'وَالْجِعَالَةُ', #14
u'والجعالة': u'وَالْجِعَالَةِ', #14
u'والجعالة': u'وَالْجَعَالَة', #2
u'والجعالة': u'وَالْجَعَالَةُ', #48
u'والجعالة': u'وَالْجَعَالَةِ', #59
u'والجعالة': u'وَالْجَعَالَةَ', #7
u'والجعالة': u'وَالْجِعَالَةَ', #7
u'والجعائل': u'وَالْجَعَائِلُ', #2
u'والجعبري': u'وَالْجَعْبَرِيِّ', #1
u'والجعدبة': u'وَالْجُعْدُبَةُ', #1
u'والجعرانة': u'وَالْجِعِرَّانَةِ', #1
u'والجعرانة': u'وَالْجِعْرَانَةَ', #1
u'والجعرانة': u'وَالْجِعْرَانَةِ', #11
u'والجعرانة': u'وَالْجِعْرَانَةُ', #14
u'والجعرور': u'وَالجَعْرُورِ', #1
u'والجعرور': u'وَالْجُعْرُورُ', #3
u'والجعروري': u'وَالْجُعْرُورِيِّ', #1
u'والجعظري،': u'وَالْجَعْظَرِيُّ،', #1
u'والجعظري': u'وَالْجَعْظَرِيُّ', #2
u'والجعفلة': u'وَالْجَعْفَلَةُ', #1
u'والجعلفة': u'وَالْجَعْلَفَةُ', #1
u'والجعيلة': u'وَالْجَعِيلَة', #1
u'والجعيلة': u'وَالْجَعِيلَةِ', #1
u'والجعيلة': u'وَالْجَعِيلَةُ', #7
u'والجفا': u'وَالْجَفَا', #1
u'والجفلى': u'وَالْجَفَلَى', #1
u'والجفير': u'وَالْجَفِيرِ', #4
u'والجقمقية': u'وَالْجَقْمَقِيَةَ', #1
u'والجلاب': u'وَالْجَلَّابُ', #12
u'والجلاب': u'وَالْجَلَّابَ', #2
u'والجلاب': u'وَالْجُلَّابِ', #2
u'والجلاب': u'وَالْجَلَّابِ', #30
u'والجلابي': u'وَالْجَلَّابِيُّ', #1
u'والجلاجل': u'وَالْجَلَاجِلُ', #1
u'والجلاح': u'وَالْجُلاحُ', #1
u'والجلافة': u'وَالْجَلَافَةِ', #1
u'والجلالا': u'وَالْجِلَالَا', #2
u'والجلاهق،': u'وَالْجَلاهِقُ،', #1
u'والجلاوات': u'والجلاوات', #1
u'والجلجلوتية': u'والجلجلوتية', #1
u'والجلحاء': u'وَالْجَلْحَاءُ', #1
u'والجلدا': u'وَالْجِلْدَا', #1
u'والجلدات': u'وَالْجَلَدَاتُ', #1
u'والجلس': u'وَالْجِلْسُ', #1
u'والجلم': u'وَالْجَلَمَ', #1
u'والجلمان': u'وَالْجَلَمَان', #1
u'والجلواز': u'وَالْجِلْوَازُ', #1
u'والجلواز': u'وَالْجِلْوَازَ', #3
u'والجلوز': u'وَالْجِلَّوْزِ', #4
u'والجليح': u'وَالْجُلَيْحُ', #1
u'والجماء': u'وَالْجَمَّاءُ', #2
u'والجمالا': u'وَالْجَمَالَا', #2
u'والجمجم': u'وَالْجُمْجُمِ', #5
u'والجمعه': u'وَالْجُمُعَهْ', #1
u'والجمكيات': u'وَالْجَمَكِيَّاتِ', #1
u'والجملون': u'وَالْجَمَلُونِ', #1
u'والجناء': u'وَالْجَنَاءُ', #1
u'والجنادرة': u'وَالْجَنَادِرَةُ', #1
u'والجنادرة': u'وَالْجَنَادِرَةِ', #1
u'والجنزير': u'وَالْجَنْزِيرَ', #1
u'والجنف': u'وَالْجَنَفُ', #1
u'والجنك': u'وَالْجُنْكِ', #1
u'والجنك': u'وَالْجُنْكُ', #2
u'والجنيب': u'وَالْجَنِيبُ', #2
u'والجنيبة': u'وَالْجَنِيبَةُ', #2
u'والجنيد': u'وَالْجُنَيْدُ', #1
u'والجنيد': u'وَالْجُنَيْدِ', #2
u'والجهاض': u'وَالْجِهَاضُ', #1
u'والجهني': u'وَالْجُهَنِيِّ', #1
u'والجهنية': u'وَالْجُهَنِيَّةِ', #3
u'والجهودوري': u'والجهودوري', #1
u'والجهوذوري': u'وَالْجَهْوَذُورِيّ', #1
u'والجهوذوري': u'والجهوذوري', #3
u'والجوارشنات': u'والجوارشنات', #1
u'والجوارشيات': u'والجوارشيات', #1
u'والجوازل': u'وَالْجَوَازِلُ', #1
u'والجوازل': u'وَالْجَوَازِلِ', #1
u'والجواشن': u'وَالْجَوَاشِنِ', #1
u'والجواظ': u'وَالْجَوَّاظُ', #3
u'والجوالقات': u'وَالْجُوَالِقَاتُ', #2
u'والجوامك': u'وَالْجَوَامِكِ', #1
u'والجوانية': u'والْجَوَّانِيَّةِ', #1
u'والجوانية': u'وَالْجَوَّانِيَّة', #3
u'والجوانية': u'وَالْجَوَّانِيَّةِ', #8
u'والجوبة': u'وَالْجَوْبَةِ', #1
u'والجوجان': u'وَالْجُوجَانُ', #1
u'والجوجري': u'وَالْجَوْجَرِيَّ', #1
u'والجوجري': u'وَالْجَوْجَرِيِّ', #1
u'والجوجري': u'وَالْجَوْجَرِيُّ', #4
u'والجوخار': u'وَالْجُوخَارُ', #1
u'والجودا': u'وَالْجُودَا', #2
u'والجوزجاني': u'وَالْجَوْزَجَانِيّ', #1
u'والجوزجاني': u'وَالْجُوزَجَانِيُّ', #7
u'والجوزنيج': u'وَالْجَوْزَنِيجِ', #1
u'والجوزينج': u'وَالْجَوْزَيْنَجِ', #2
u'والجوشن': u'وَالْجَوْشَنُ', #1
u'والجوشن': u'وَالْجَوْشَنِ', #2
u'والجولق': u'وَالْجَوْلَقُ', #1
u'والجولق': u'وَالْجَوْلَقِ', #1
u'والجويني': u'وَالْجُوَيْنِيَّ', #1
u'والجويني': u'وَالْجُوَيْنِيِّ', #7
u'والجويني': u'وَالْجُوَيْنِيُّ', #9
u'والجيء': u'وَالْجَيْء', #1
u'والجيال': u'وَالْجِيَالِ', #1
u'والجيت': u'والجيت', #2
u'والجيحون': u'وَالْجَيْحُونِ', #3
u'والجيزي': u'وَالْجِيزِيِّ', #1
u'والجيزي': u'وَالْجِيزِيُّ', #3
u'والحاتم': u'وَالْحَاتِمُ', #1
u'والحاحزة': u'وَالْحَاحِزَةُ', #1
u'والحادثون': u'وَالْحَادِثُونَ', #4
u'والحارثية': u'وَالْحَارِثِيَّةُ', #1
u'والحارصة': u'وَالْحَارِصَةُ', #2
u'والحارصة': u'وَالْحَارِصَةِ', #2
u'والحازمي': u'وَالْحَازِمِيّ', #1
u'والحازمي': u'وَالْحَازِمِيُّ', #2
u'والحازمية': u'وَالْحَازِمِيَّةُ', #1
u'والحاضري': u'وَالْحَاضِرِي', #1
u'والحاظر': u'وَالْحَاظِرَ', #2
u'والحاظر': u'وَالْحَاظِرُ', #7
u'والحافظية': u'وَالْحَافِظِيَّةِ', #2
u'وإلحاقة': u'وَإِلْحَاقَةُ', #1
u'والحاكورة': u'وَالْحَاكُورَةِ', #1
u'والحالوم': u'وَالْحَالُومِ', #4
u'والحامدي': u'وَالْحَامِدِيُّ', #2
u'والحامدية': u'وَالْحَامِدِيَّةِ', #8
u'والحامزون': u'وَالْحَامِزُونَ', #1
u'والحان': u'وَالْحَانُّ', #1
u'والحايل': u'وَالْحَايِلُ', #1
u'والحباك': u'وَالْحَبَّاكِ', #2
u'والحبالات': u'وَالْحِبَالَاتُ', #1
u'والحبالات': u'وَالْحِبَالَاتِ', #1
u'والحبحاب': u'وَالْحَبْحَابُ', #3
u'والحبقوله': u'وَالْحَبَّقَوْلُهُ', #1
u'والحبلق': u'وَالْحَبَلّقُ', #1
u'والحبوبات': u'وَالْحُبُوبَاتُ', #1
u'والحبوبات': u'وَالْحُبُوبَاتِ', #1
u'والحثر': u'وَالْحَثَرُ', #1
u'والحجاوي': u'وَالْحَجَّاوِيُّ', #2
u'والحجبي': u'وَالْحَجَبِيُّ', #2
u'والحجبى': u'وَالْحَجَبِىُّ', #4
u'والحجرا': u'وَالْحَجَرَا', #1
u'والحجف': u'وَالْحُجُفَ', #1
u'والحجف': u'وَالْحُجُفِ', #1
u'والحجف،': u'وَالْحَجَفِ،', #1
u'والحجف': u'وَالْحَجَفِ', #3
u'والحجفة': u'وَالْحُجْفَةِ', #2
u'والحجن': u'وَالْحَجَنُ', #1
u'والحجنة': u'وَالْحَجْنَةُ', #1
u'والحجون': u'وَالْحَجُونُ', #1
u'والحجون': u'وَالْحَجُونِ', #2
u'والحجى': u'وَالْحِجَى', #1
u'والحداقة': u'وَالْحَدَّاقَةِ', #1
u'والحداقة': u'وَالْحَدَّاقَةُ', #2
u'والحدال': u'وَالْحُدَالَ', #1
u'والحديا': u'والحديا', #1
u'والحديا': u'وَالْحِدَيَا', #1
u'والحديا': u'وَالْحُدَيَّا', #17
u'والحرابه': u'وَالْحِرَابَهْ', #1
u'والحراثون': u'وَالْحَرَّاثُونَ', #1
u'والحراثين': u'وَالْحَرَّاثِينَ', #2
u'والحرادي': u'وَالْحَرَادِيُّ', #1
u'والحراموالوجه': u'وَالْحَرَامُوَالْوَجْهُ', #1
u'والحراني،': u'وَالْحَرَّانِيِّ،', #1
u'والحرصة': u'وَالْحَرْصَةَ', #1
u'والحرمد': u'وَالْحَرْمَدُ', #1
u'والحرمه': u'وَالْحُرُمَهْ', #1
u'والحرمه': u'وَالْحُرْمَهْ', #2
u'والحروز': u'وَالْحُرُوزُ', #1
u'والحروز': u'وَالْحُرُوزِ', #1
u'والحرى': u'وَالْحَرَى', #1
u'والحريسة': u'وَالْحَرِيسَة', #1
u'والحريسة': u'وَالْحَرِيسَةُ', #1
u'والحريسة': u'وَالْحَرِيسَةِ', #2
u'والحريش': u'وَالْحُرَيْشُ', #2
u'والحريش': u'وَالْحَرِيشُ', #3
u'والحريه': u'وَالْحُرِّيَّهْ', #4
u'والحزاة': u'والحُزاة', #2
u'والحزان': u'وَالْحِزّانُ', #1
u'والحزة': u'وَالْحَزَّةُ', #1
u'والحزة': u'وَالْحُزَّةُ', #1
u'والحزرات': u'وَالْحَزَرَاتُ', #1
u'والحزورة': u'وَالْحَزْوَرَةُ', #1
u'والحزومة': u'وَالْحُزُومَةِ', #2
u'والحزونة': u'وَالْحُزُونَةَ', #1
u'والحزونة': u'وَالْحُزُونَةِ', #2
u'والحسنيون': u'وَالْحَسَنِيُّونَ', #1
u'والحشاء': u'وَالْحِشَاءِ', #1
u'والحشوش': u'وَالْحُشُوشِ', #3
u'والحشى': u'وَالْحَشَى', #2
u'والحصا': u'وَالْحَصَا', #9
u'والحصاف': u'وَالْحَصَّافُ', #1
u'والحضيضى': u'وَالْحِضِّيضَى', #1
u'والحطيط': u'وَالْحَطِيطِ', #1
u'والحطيم': u'وَالْحَطِيمِ', #5
u'والحطيم': u'وَالْحَطِيمُ', #6
u'والحظل': u'وَالْحَظْلُ', #2
u'والحظير': u'وَالْحَظِيرِ', #1
u'والحفش': u'وَالْحِفْشُ', #2
u'والحفناوي': u'وَالْحَفْنَاوِيُّ', #3
u'والحقرة': u'وَالْحُقْرَةُ', #3
u'وألحقنى': u'وَأَلْحَقَنِى', #1
u'وألحقنى': u'وَأَلْحِقْنِى', #1
u'والحكال': u'وَالْحُكَّالُ', #1
u'والحكرة': u'وَالْحُكْرَةُ', #1
u'والحكورة': u'وَالْحُكُورَةَ', #1
u'والحكورة': u'وَالْحُكُورَةُ', #2
u'والحلالالوجه': u'وَالْحَلالُالْوَجْهُ', #1
u'والحلزوم': u'والحلزوم', #1
u'والحللا': u'وَالْحُلَلَا', #2
u'والحلوانى': u'وَالْحُلْوَانِىُّ', #4
u'والحليفا': u'وَالْحَلِيفَا', #3
u'والحمائلي': u'وَالْحَمَائِلِيِّ', #1
u'والحمزية': u'وَالْحَمْزِيَّةُ', #1
u'والحمنانة': u'وَالْحَمْنَانَةُ', #1
u'والحمنانة': u'وَالْحَمْنَانَةِ', #1
u'والحموشة': u'وَالْحُمُوشَة', #1
u'والحمئة': u'وَالْحَمِئَةُ', #1
u'والحميدي': u'وَالْحُمَيْدِيُّ', #15
u'والحميدى': u'وَالْحُمَيْدِىَّ', #2
u'والحميدي': u'وَالْحُمَيْدِيَّ', #3
u'والحميدي': u'وَالْحُمَيْدِيِّ', #3
u'والحميدى': u'وَالْحُمَيْدِىُّ', #5
u'والحميري': u'وَالْحِمْيَرِيُّ', #1
u'والحميري،': u'وَالْحِمْيَرِيُّ،', #1
u'والحناتم': u'وَالْحَنَاتِمِ', #1
u'والحناكية': u'وَالْحِنَاكِيَّةِ', #1
u'والحناكية': u'وَالْحِنَاكِيَّةُ', #3
u'والحنتم': u'والحنتم', #1
u'والحنتم': u'وَالْحَنَتْمِ', #1
u'والحنتم': u'وَالْحَنْتَم', #1
u'والحنتم': u'وَالْحَنْتَمََََِ', #1
u'والحنتم؟': u'وَالْحَنْتَمِ؟', #1
u'والحنتم': u'وَالْحَنْتَمُ', #10
u'والحنتم،': u'وَالْحَنْتَمِ،', #22
u'والحنتم': u'وَالْحَنْتَمَ', #4
u'والحنتم': u'وَالْحَنْتَمِ', #92
u'والحنتمة': u'وَالْحَنْتَمَة', #1
u'والحندج': u'وَالْحُنْدُجُ', #1
u'والحنفيه،': u'والحنفيه،', #1
u'والحنفيون': u'وَالْحَنَفِيُّونَ', #1
u'والحنيذ': u'وَالْحَنِيذُ', #2
u'والحواء': u'وَالْحِوَاءُ', #3
u'والحوابي': u'وَالْحَوَابِيَ', #1
u'والحوابي': u'وَالْحَوَابِي', #6
u'والحواميم': u'وَالْحَوَامِيمَ', #1
u'والحوايا،': u'وَالْحَوَايَا،', #1
u'والحوايا': u'وَالْحَوَايَا', #3
u'والحوب': u'وَالُحُوبُ', #2
u'والحوب': u'وَالْحُوبُ', #4
u'والحوص': u'وَالْحَوَصِ', #1
u'والحوص': u'وَالْحَوَصُ', #5
u'والحوضى': u'وَالْحَوْضِىُّ', #3
u'والحولة': u'وَالْحَوْلَةُ', #1
u'والحولقة': u'وَالْحَوْلَقَة', #1
u'والحولل': u'وَالْحُولَلِ', #1
u'والحويرث': u'وَالْحُوَيْرِث', #1
u'والحويرث': u'وَالْحُوَيْرِثِ', #1
u'والحويرث': u'وَالْحُوَيْرِثُ', #6
u'والحويل': u'وَالْحَوِيلُ', #2
u'والحى': u'وَالْحَىُّ', #1
u'والحئول': u'وَالْحُئُولِ', #1
u'والحياطة': u'وَالْحِيَاطَةِ', #5
u'والحياكون': u'وَالْحَيَّاكُونَ', #1
u'والحيالى': u'وَالْحَيَالَى', #3
u'والحيدى': u'وَالْحَيَدَى', #2
u'والحيس': u'وَالْحَيْسُ', #2
u'والحيسة': u'وَالْحَيْسَةُ', #1
u'والحيشان': u'وَالْحِيْشَانِ', #1
u'والحيشان': u'وَالْحَيْشَانِ', #2
u'والحيضان': u'وَالْحِيضَانِ', #1
u'والحيضةوالوجه': u'وَالْحَيْضَةَوَالْوَجْهُ', #1
u'والحيوت': u'وَالْحَيَّوْتُ', #1
u'وإلخ': u'وَإِلَخْ', #17
u'والخاتمية': u'وَالْخَاتِمِيَّةِ', #1
u'والخاربة': u'وَالْخَارِبَةَ', #1
u'والخاربة': u'وَالْخَارِبَةِ', #1
u'والخارص': u'وَالْخَارِصِ', #1
u'والخارص': u'وَالْخَارِصُ', #2
u'والخازق': u'وَالْخَازِقُ', #1
u'والخاقان': u'وَالْخَاقَانِ', #1
u'والخاقان': u'وَالْخَاقَانُ', #4
u'والخالدية': u'وَالْخَالِدِيَّةُ', #1
u'والخاناتي': u'وَالْخَانَاتِيِّ', #1
u'والخانقاة': u'وَالْخَانْقَاةُ', #1
u'والخانقاه': u'وَالْخَانِقَاهْ', #1
u'والخانقاه': u'وَالْخَانِقَاهُ', #2
u'والخانقاه': u'وَالْخَانْقَاهْ', #4
u'والخانقاهات': u'والخانقاهات', #1
u'والخانكات': u'وَالْخَانِكَاتِ', #1
u'والخانكات': u'وَالْخَانَكَاتُ', #2
u'والخانكاه': u'وَالْخَانِكَاهِ', #1
u'والخانكاه': u'وَالْخَانِكَاهْ', #1
u'والخانه': u'وَالْخَانَهْ', #1
u'والخباث': u'وَالْخِبَاثِ', #1
u'والخباثة': u'وَالْخَبَاثَةِ', #2
u'والخبت': u'وَالْخَبْتُ', #1
u'والخبجبة': u'وَالْخَبْجَبَةُ', #1
u'والخبق': u'وَالْخِبَقّ', #1
u'والخبنة': u'وَالْخُبْنَة', #1
u'والخبنة': u'وَالْخُبْنَةُ', #3
u'والخبيز': u'وَالْخَبِيزِ', #2
u'والختومة': u'وَالْخُتُومَةِ', #1
u'والخثعمية': u'وَالْخَثْعَمِيَّةِ', #1
u'والخثى': u'وَالْخُثَى', #1
u'والخثى': u'وَالْخِثَى', #5
u'والخثى': u'وَالْخَثَى', #6
u'والخجندي': u'وَالْخُجَنْدِيُّ', #1
u'والخجندي': u'وَالْخُجَنْدِيِّ', #2
u'والخداج': u'وَالْخِدَاج', #1
u'والخداج': u'وَالْخِدَاجُ', #1
u'والخدشة': u'وَالْخَدْشَةَ', #2
u'والخذف': u'وَالْخَذْفَ', #1
u'والخذف': u'وَالْخَذْفُ', #3
u'والخرء': u'وَالْخَرْءُ', #1
u'والخرء': u'وَالْخُرْءَ', #1
u'والخرء': u'وَالْخُرْءِ', #1
u'والخرء': u'وَالْخُرْءُ', #2
u'والخراتان': u'والخراتان', #1
u'والخراجات': u'وَالْخَرَاجَاتُ', #1
u'والخراجات': u'وَالْخَرَاجَاتِ', #1
u'والخراجات': u'وَالْخُرَّاجَاتِ', #1
u'والخراديل': u'وَالْخَرَادِيلُ', #1
u'والخرار': u'وَالْخَرّارُ', #1
u'والخراسانيي': u'والخراسانيي', #1
u'والخراسانيي': u'وَالْخُرَاسَانِيِّي', #1
u'والخراش': u'وَالْخِرَاشُ', #2
u'والخراكي': u'وَالْخَرَاكِي', #2
u'والخربز': u'وَالْخِرْبِزَ', #1
u'والخربز': u'وَالْخِرْبِزُ', #1
u'والخربز': u'وَالْخِرْبِزِ', #13
u'والخرثي': u'وَالْخُرْثِيَّ', #1
u'والخرثي': u'وَالْخُرْثِيِّ', #1
u'والخرفع': u'وَالْخِرْفِعُ', #1
u'والخركاه': u'وَالْخَرْكَاهَ', #1
u'والخركاوات': u'وَالْخَرْكَاوَات', #1
u'والخركاوات': u'وَالْخَرْكَاوَاتِ', #1
u'والخرمة': u'وَالْخَرْمَةَ', #1
u'والخرمية': u'وَالْخُرَّمِيَّةُ', #1
u'والخرنوبة': u'وَالْخَرْنُوبَةُ', #1
u'والخرنوبة': u'وَالْخُرْنُوبَةُ', #3
u'والخروبة': u'وَالْخَرُّوبَةِ', #1
u'والخريت': u'وَالْخِرِّيتَ', #1
u'والخريت': u'وَالْخِرّيتُ', #2
u'والخريت': u'وَالْخِرِّيتُ', #4
u'والخزام': u'وَالْخُزَامُ', #1
u'والخزز': u'وَالْخُزَزُ', #1
u'والخسق': u'وَالْخَسْقَ', #2
u'والخسق': u'وَالْخَسْقُ', #2
u'والخسق': u'وَالْخَسْقِ', #2
u'والخشاف': u'وَالْخُشَّافُ', #1
u'والخشام': u'وَالْخُشَامُ', #2
u'والخشخاشة': u'وَالْخَشْخَاشَةُ', #1
u'والخششا': u'وَالْخُشَشَا', #1
u'والخشكتان': u'وَالْخَشْكِتَانِ', #1
u'والخشكتانك': u'وَالخشكتانك', #1
u'والخشكنان': u'والخشكنان', #3
u'والخشكنان': u'وَالْخُشْكَنَانُ', #5
u'والخشكنان': u'وَالْخُشْكَنَانِ', #5
u'والخشكنانج': u'وَالْخَشْكَنَانْجَ', #1
u'والخشكنانج': u'وَالْخُشْكَنَانَجِ', #1
u'والخشل': u'وَالْخَشْلُ', #2
u'والخشل': u'وَالْخَشْلِ', #2
u'والخضخاض': u'وَالْخِضْخَاضُ', #1
u'والخضخضة': u'وَالْخَضْخَضَةِ', #1
u'والخضمات': u'وَالْخَضَمَاتُ', #1
u'والخضمات': u'وَالْخَضِمَاتُ', #1
u'والخضورية': u'وَالْخُضُورِيَّةِ', #1
u'والخطا': u'وَالْخُطَا', #2
u'والخطمى': u'وَالْخَطْمِىِّ', #1
u'والخطيم': u'وَالْخَطِيمُ', #1
u'والخفرة': u'وَالْخَفَرَةُ', #1
u'والخفرة': u'وَالْخَفِرَةُ', #1
u'والخفرة': u'وَالْخَفْرَةُ', #1
u'والخفرة': u'وَالْخُفْرَةُ', #1
u'والخفيدد': u'وَالْخَفَيْدَدُ', #1
u'والخلا': u'وَالْخَلَا', #15
u'والخلوتية': u'وَالْخَلْوَتِيَّةُ', #1
u'والخلول': u'وَالْخُلُولِ', #4
u'والخلول': u'وَالْخُلُولُ', #7
u'والخلى': u'وَالْخَلَى', #7
u'والخليسة': u'وَالْخَلِيسَةَ', #2
u'والخليطان': u'وَالْخَلِيطَانِ', #14
u'والخليطين': u'وَالْخَلِيطَيْنِ', #2
u'والخليفا': u'وَالْخِلِّيفَا', #1
u'والخليفتي': u'وَالْخَلِيفَتِيِّ', #1
u'والخليفتي': u'وَالْخَلِيفَتِيُّ', #2
u'والخليقه': u'وَالْخَلِيقَهْ', #1
u'والخليلي': u'وَالْخَلِيلِيُّ', #1
u'والخليلي': u'وَالْخَلِيلِيِّ', #1
u'والخمساوية': u'وَالْخَمْسَاوِيَّة', #1
u'والخمستان': u'وَالْخَمْسَتَانِ', #1
u'والخمسينا': u'وَالْخَمْسِينَا', #2
u'والخموس': u'وَالْخَمُوسُ', #1
u'والخمولة': u'وَالْخُمُولَةِ', #1
u'والخميصة': u'وَالْخَمِيصَةَ', #1
u'والخميصة': u'وَالْخَمِيصَةُ', #3
u'والخميصة': u'وَالْخَمِيصَةِ', #5
u'والخنابة': u'وَالْخِنّابَةُ', #1
u'والخناثي': u'وَالْخَنَاثِي', #2
u'والخنادم': u'وَالْخَنَادِمُ', #1
u'والخناقون': u'وَالْخَنَّاقُونَ', #5
u'والخنبق': u'وَالْخنْبَقُ', #1
u'والخندفة': u'وَالْخَنْدِفَةُ', #1
u'والخندمة': u'وَالْخَنْدَمَةُ', #2
u'والخنفقيق': u'وَالْخَنْفَقِيقِ', #1
u'والخنوثه': u'وَالْخُنُوثَهْ', #1
u'والخوانق': u'وَالْخَوَانِقُ', #1
u'والخوانق': u'وَالْخَوَانِقِ', #8
u'والخوانك': u'وَالْخَوَانِكِ', #3
u'والخورنق': u'وَالْخَوَرْنَقَ', #1
u'والخورنق': u'وَالْخَوَرْنَقُ', #1
u'والخورنق': u'وَالْخَوَرْنَقِ', #1
u'والخوط': u'وَالْخُوطَ', #2
u'والخويصة': u'وَالْخُوَيْصَةُ', #1
u'والخئولة': u'والخئولة', #1
u'والخئولة': u'وَالْخُئُولَةُ', #1
u'والخيشة': u'وَالْخَيْشَةُ', #1
u'والخيطفة': u'وَالْخَيْطَفَةُ', #1
u'والخيلا': u'وَالْخُيَلَا', #1
u'والدءوب': u'وَالدَّءُوبُ', #1
u'والدءوب': u'وَالدَّءُوبِ', #1
u'والدابوغة': u'وَالدَّابُوغَةُ', #1
u'والدابوقة': u'وَالدَّابُوقَةُ', #1
u'والداتورة': u'وَالدَّاتُورَةُ', #1
u'والداتورة': u'وَالدَّاتُورَةِ', #2
u'والداراني': u'وَالدَّارَانِيِّ', #1
u'والدارصيني': u'والدارصيني', #1
u'والدارصيني': u'وَالدَّارَصِينِيّ', #3
u'والدارصيني': u'وَالدَّارَصِينِيُّ', #3
u'والدارصيني': u'وَالدَّارَصِينِيِّ', #4
u'والدارقطن': u'وَالَّداَرُقْطِنُّ', #4
u'والدارقطني': u'والدّارَقُطْنِيّ', #1
u'والدارقطني': u'وَالدّارَقُطْنِيّ', #1
u'والدارقطني': u'وَالدّارَقُطْنِيُّ', #1
u'والدارقطنى': u'وَالدَّارَقُطْنِىُّ', #1
u'والدارقطني': u'وَالدَّارَقُطْنِيِّ', #18
u'والدارقطني': u'والدارقطني', #3
u'والدارقطني': u'وَالدَّارَقُطْنِيُّ', #30
u'والدارقطني': u'وَالدَّارَقُطْنِيّ', #584
u'والداركي': u'وَالدَّارَكِيِّ', #2
u'والداروم': u'والداروم', #1
u'والداروم': u'وَالدَّارُومُ', #1
u'والداروم': u'وَالدَّارُومِ', #1
u'والداروم': u'وَالدّارُومِ', #3
u'والدافة': u'وَالدَّافَةُ', #1
u'والدافة': u'وَالدَّافَّة', #1
u'والدافة': u'وَالدَّافَّةُ', #5
u'والداقنة': u'وَالدّاقِنَةُ', #1
u'والدالولاء': u'وَالدَّالُولَاءُ', #1
u'والدامغاني': u'وَالدَّامَغَانِيُّ', #1
u'والدانق': u'وَالدَّانَقَ', #1
u'والدانق': u'وَالدَّانَقِ', #1
u'والدانق': u'وَالدَّانَقُ', #10
u'والدانق': u'وَالدَّانِقُ', #12
u'والدانقان': u'وَالدَّانَقَانِ', #1
u'والدانقين': u'وَالدَّانِقَيْنِ', #1
u'والدانقين': u'وَالدَّانَقَيْنِ', #3
u'والداودي': u'والداودي', #1
u'والداودي': u'وَالدَّاوُدِيِّ', #1
u'والداودية': u'وَالدَّاوُدِيَّةُ', #1
u'والداين': u'والداين', #1
u'والدبا': u'وَالدَّبَا', #1
u'والدباء': u'وَالدُّبَّاء', #1
u'والدباء،': u'وَالدُّبَّاءِ،', #15
u'والدباء': u'وَالدُّبَّاءُ', #3
u'والدباء؟': u'وَالدُّبَّاءِ؟', #3
u'والدباء': u'وَالدُّبَّاءِ', #54
u'والدبسى': u'وَالدُّبْسِىِّ', #1
u'والدبلوج': u'وَالدُّبْلُوجُ', #1
u'والدبى': u'وَالدَّبَى', #1
u'والدبير': u'وَالدَّبِيرُ', #2
u'والدجلة': u'وَالدَّجْلَةَ', #1
u'والدجلة': u'وَالدِّجْلَةِ', #5
u'والدحداح': u'وَالدَّحْدَاحُ', #2
u'والدحرضان': u'وَالدَّحْرَضَانُ', #1
u'والدحية': u'وَالدّحْيَةُ', #1
u'والدخاريص': u'وَالدَّخَارِيصُ', #1
u'والدخاريص': u'وَالدَّخَارِيصِ', #1
u'والدخرص': u'وَالدِّخْرِصُ', #1
u'والدخروصة': u'وَالدُّخْرُوصَةُ', #1
u'والدخريص': u'وَالدِّخْرِيصِ', #11
u'والدخريص': u'وَالدِّخْرِيصُ', #2
u'والدخيس': u'وَالدّخِيسُ', #1
u'والدرابزين': u'وَالدَّرَابْزِينِ', #2
u'والدراوردي': u'والدَّرَاوَرْدِيُّ', #1
u'والدراوردي': u'وَالدَّرَاوَرْدِيُّ', #1
u'والدراوردي،': u'وَالدَّرَاوَرْدِيُّ،', #1
u'والدراوردى': u'وَالدَّرَاوَرْدِىَّ', #1
u'والدراوردى': u'وَالدَّرَاوَرْدِىُّ', #1
u'والدراوردي': u'والدراوردي', #3
u'والدرد': u'وَالدَّرَدُ', #1
u'والدرد': u'وَالدُّرَدِ', #1
u'والدردير': u'وَالدَّرْدِيرُ', #1
u'والدرفس': u'والدرفس', #1
u'والدرياب': u'وَالدِّرْيَابُ', #1
u'والدرياق': u'وَالدِّرْيَاقُ', #1
u'والدريانية': u'والدريانية', #1
u'والدريد': u'وَالدّرَيْدُ', #1
u'والدريرة': u'وَالدَّرِيرَةِ', #1
u'والدريس': u'وَالدّرِيسُ', #1
u'والدريس': u'وَالدَّرِيسِ', #1
u'والدزماري': u'وَالدِّزمَارِيُّ', #1
u'والدستوائي': u'وَالدَّسْتُوَائِيِّ', #1
u'والدسعة': u'وَالدَّسْعَةُ', #1
u'والدسكرة': u'وَالدَّسْكَرَةِ', #1
u'والدسومات': u'وَالدُّسُومَاتِ', #1
u'والدسومة': u'وَالدُّسُومَةَ', #4
u'والدشت': u'وَالدَّشْتِ', #1
u'والدشت': u'وَالدَّشْتَ', #2
u'والدشت': u'وَالدَّشْتُ', #2
u'والدعج': u'وَالدَّعَجَ', #1
u'والدعج': u'وَالدَّعَجِ', #5
u'والدعج': u'وَالدَّعَجُ', #7
u'والدعجاء': u'وَالدَّعْجَاءُ', #2
u'والدعموص': u'وَالدُّعْمُوصُ', #4
u'والدغنة': u'وَالدّغُنّةُ', #1
u'والدفاف': u'وَالدّفَافِ', #2
u'والدفاف': u'وَالدِّفَافُ', #2
u'والدفر': u'وَالدّفْرُ', #1
u'والدفر': u'وَالدَّفْرُ', #11
u'والدفر': u'وَالدَّفْرِ', #2
u'والدفر': u'وَالدَّفَرُ', #6
u'والدفر': u'وَالدَّفَرِ', #6
u'والدفري': u'وَالدَّفَرِيُّ', #2
u'والدفعه': u'وَالدّفَعَهْ', #4
u'والدقاقين': u'وَالدَّقَّاقِينَ', #1
u'والدقل': u'وَالدَّقَلِ', #1
u'والدقل': u'وَالدَّقْلُ', #1
u'والدقل': u'وَالدَّقَلُ', #3
u'والدكانة': u'وَالدُّكَّانَةُ', #1
u'والدكروري': u'وَالدَّكْرُورِيُّ', #1
u'والدكروري': u'وَالدَّكْرُورِيِّ', #1
u'والدكك': u'وَالدِّكَكِ', #1
u'والدكك': u'وَالدِّكَكُ', #2
u'والدلجة': u'وَالدَّلْجَة', #1
u'والدلجة': u'وَالدُّلْجَةُ', #1
u'والدلجة': u'وَالدُّلْجَة', #2
u'والدلجي': u'وَالدُّلَجِيِّ', #1
u'والدلجية': u'وَالدُّلَجِيَّةُ', #1
u'والدلجية': u'وَالدُّلَجِيَّةِ', #1
u'والدلدل': u'وَالدّلْدُلُ', #1
u'والدلدل': u'وَالدُّلْدُلِ', #2
u'والدلدل': u'وَالدُّلْدُلُ', #4
u'والدلسة': u'وَالدُّلْسَةُ', #3
u'والدلوقوله': u'وَالدَّلْوُقَوْلُهُ', #1
u'والدليلا': u'وَالدَّلِيلَا', #1
u'والدما': u'وَالدِّمَا', #2
u'والدماميني': u'وَالدَّمَامِينِيُّ', #1
u'والدماميني': u'وَالدَّمَامِينِيِّ', #1
u'وألدمت': u'وَأَلْدَمَتْ', #1
u'والدمشق': u'وَالدّمَشْقُ', #1
u'والدمص': u'وَالدَّمْصُ', #1
u'والدمعزة': u'وَالدَّمْعَزَةُ', #2
u'والدميري': u'وَالدَّمِيرِيِّ', #16
u'والدميري': u'وَالدَّمِيرِيُّ', #31
u'والدنداني': u'وَالدَّنْدَانِيُّ', #1
u'والدنداني،': u'وَالْدَنْدَانِيُّ،', #1
u'والدنداني،': u'والدَّنْدَانِيُّ،', #3
u'والدنداني،': u'وَالدَّنْدَانِيُّ،', #3
u'والدنداني،': u'وَالدَّنْدَانِيِّ،', #4
u'والدندبان': u'وَالدَّنْدَبَانِ', #1
u'والدنيلس': u'والدنيلس', #1
u'والدهنا': u'وَالدُّهُنَّا', #1
u'والدوا': u'وَالدَّوَا', #1
u'والدواريق': u'وَالدَّوَارِيقُ', #1
u'والدوانق': u'وَالدَّوَانِقُ', #1
u'والدوانيق': u'وَالدَّوَانِيقِ', #2
u'والدودم': u'وَالدّوَدِمُ', #1
u'والدوساء': u'وَالدَّوْسَاءُ', #1
u'والدوسيين': u'وَالدَّوْسِيِّينَ', #1
u'والدوكس': u'وَالدَّوْكَسُ', #1
u'والدونمات': u'وَالدُّونَمَاتُ', #1
u'والدونيس': u'والدونيس', #1
u'والدونيس': u'وَالدُّونِيسُ', #1
u'والدويرات': u'والدويرات', #1
u'والدويرات': u'وَالدُّوَيْرَاتِ', #3
u'والدى': u'وَالِدِى', #13
u'والدياس': u'وَالدِّيَاسُ', #16
u'والدياس': u'وَالدِّيَاسَ', #4
u'والدياس': u'وَالدِّيَاسِ', #94
u'والدياسة': u'وَالدِّيَاسَةُ', #3
u'والدياسة': u'وَالدِّيَاسَةِ', #5
u'والدياسي': u'وَالدَّيَاسِي', #1
u'والديانه': u'وَالدِّيَانَهْ', #1
u'والديبة': u'والديبة', #1
u'والديش': u'وَالدِّيشُ', #1
u'والديل': u'وَالدّيلُ', #3
u'والديورة': u'وَالدُّيُورَةَ', #1
u'والديورة': u'وَالدُّيُورَةُ', #1
u'والذحول': u'وَالذُّحُولِ', #1
u'والذرافات': u'وَالذَّرَّافَاتِ', #1
u'والذريرة': u'وَالذَّرِيرَةِ', #3
u'والذريرة': u'وَالذَّرِيرَةُ', #4
u'والذعارة': u'وَالذِّعَارَةِ', #1
u'والذفر': u'وَالذَّفْرُ', #1
u'والذفر': u'وَالذَّفَرِ', #2
u'والذفر': u'وَالذَّفَرُ', #8
u'والذكوره': u'وَالذُّكُورَهْ', #1
u'والذلال': u'وَالذّلَالُ', #1
u'والذنابير': u'وَالذَّنَابِيرِ', #1
u'والذنن': u'وَالذّنَنُ', #1
u'والذنين': u'وَالذّنِينُ', #1
u'والذى': u'وَالَذَى', #2
u'والذى': u'وَالَّذِى', #412
u'والذيال،': u'وَالذَّيَّالُ،', #1
u'والر': u'والر', #1
u'والرءوس': u'والرءوس', #1
u'والرءوس': u'وَالرُّءُوسُ', #19
u'والرءوس': u'وَالرُّءُوسَ', #2
u'والرءوس': u'وَالرُّءُوس', #4
u'والرءوس': u'وَالرُّءُوسِ', #53
u'والرءوف': u'وَالرَّءُوفُ', #1
u'والرابعه': u'والرابعه', #1
u'والراتج': u'وَالرَّاتِجِ', #1
u'والراحله': u'وَالرَّاحِلَهِ', #1
u'والرأد': u'وَالرَّأْدُ', #1
u'والرازي': u'وَالرَّازِيَّ', #18
u'والرازي': u'وَالرَّازِي', #2
u'والرازي': u'وَالرَّازِيِّ', #21
u'والرازي': u'وَالرَّازِيُّ', #22
u'والراس': u'وَالرَّاسِ', #1
u'والراعى': u'وَالرَّاعِى', #2
u'والرامخ': u'وَالرَّامِخِ', #3
u'والرامهرمزي': u'والرامهرمزي', #2
u'والرامى': u'وَالرَّامِىَ', #3
u'والرانج': u'وَالرَّانِجُ', #1
u'والرانج': u'وَالرَّانِجِ', #1
u'والراوند': u'وَالرَّاوَنْدِ', #1
u'والراوند': u'والراوند', #2
u'والرائض': u'وَالرَّائِضُ', #2
u'والرائض': u'وَالرَّائِضِ', #8
u'والرايش': u'وَالرَّايِشُ', #2
u'والرباريب': u'وَالرَّبَارِيبِ', #1
u'والربوبات': u'وَالرُّبُوبَاتِ', #1
u'والربيثا': u'وَالرِّبِّيثَا', #1
u'والربيثة': u'وَالرِّبِّيثَةُ', #1
u'والرتائم': u'وَالرَّتَائِمُ', #1
u'والرتقاء': u'وَالرَّتْقَاءُ', #14
u'والرتقاء': u'وَالرَّتْقَاءِ', #27
u'والرتقاء': u'وَالرَّتْقَاءَ', #4
u'والرتم': u'وَالرَّتْمُ', #1
u'والرتم': u'وَالرَّتْمِ', #1
u'والرتم': u'وَالرَّتَمُ', #5
u'والرتيمة': u'وَالرَّتِيمَةُ', #4
u'والرجراجي': u'وَالرَّجْرَاجِيِّ', #7
u'والرجراجي': u'وَالرَّجْرَاجِيُّ', #8
u'والرجيح': u'وَالرَّجِيحُ', #1
u'والرحا': u'وَالرَّحَا', #20
u'والرحس': u'والرحس', #1
u'والرحمتي': u'وَالرَّحْمَتِيُّ', #6
u'والرحمن،': u'وَالرَّحْمَنُ،', #1
u'والرحمن': u'وَالرّحْمَنُ', #2
u'والرحمن': u'وَالرَّحْمَنُ', #30
u'والرحمن': u'وَالرَّحْمَنِ', #77
u'والرحيض': u'وَالرّحِيضُ', #1
u'والرحيض': u'وَالرّحِيضَ', #2
u'والرحيمية': u'وَالرَّحِيمِيَّةَ', #1
u'والرحيمية': u'وَالرَّحِيمِيَّةِ', #1
u'والرخج': u'وَالرُّخَّجُ', #1
u'والرخجيات': u'وَالرُّخَّجِيَّاتُ', #1
u'والرخجيون': u'وَالرُّخَّجِيُّونَ', #1
u'والردء': u'وَالرَّدْءَ', #1
u'والردء': u'وَالرَّدْءِ', #1
u'والردء': u'وَالرِّدْء', #1
u'والردء': u'وَالرِّدْءُ', #17
u'والردء': u'وَالرِّدْءَ', #3
u'والردغ': u'وَالرَّدَغُ', #2
u'والردغة': u'وَالرَّدَغَةُ', #1
u'والردغة': u'وَالرَّدْغَةُ', #1
u'والردغة': u'وَالرَّدْغَةِ', #8
u'والرديدى': u'وَالرِّدِّيدِى', #1
u'والرزامية': u'وَالرِّزَامِيَّةُ', #1
u'والرزغ': u'وَالرَّزَغُ', #1
u'والرزغة': u'وَالرَّزْغَةَ', #1
u'والرزقة': u'وَالرَّزْقَةُ', #1
u'والرساتيق': u'وَالرَّسَاتِيقَ', #1
u'والرساتيق': u'وَالرَّسَاتِيقِ', #1
u'والرستاق': u'وَالرُّسْتَاقِ', #1
u'والرستاق': u'وَالرُّسْتَاقُ', #2
u'والرسراس': u'وَالرَّسْرَاسِ', #1
u'والرشداء': u'وَالرُّشَدَاءُ', #1
u'والرشدى': u'وَالرَّشَدَى', #1
u'والرشيدي': u'وَالرَّشِيدِيَّ', #1
u'والرشيدي': u'وَالرَّشِيدِيِّ', #33
u'والرشيدي': u'وَالرَّشِيدِيُّ', #54
u'والرصاع': u'وَالرَّصَّاعِ', #1
u'والرصاع': u'وَالرَّصَّاعُ', #3
u'والرصوف': u'وَالرُّصُوفُ', #1
u'والرضعات': u'وَالرَّضَعَاتُ', #1
u'والرضعتان': u'والرضعتان', #1
u'والرضعتان،': u'وَالرَّضْعَتَانِ،', #1
u'والرضعتان': u'وَالرَّضْعَتَانِ', #5
u'والرضعتين': u'وَالرَّضْعَتَيْنِ', #5
u'والرعة': u'وَالرِّعَةُ', #1
u'والرعة': u'وَالرِّعَةِ', #2
u'والرغبا': u'وَالرُّغُبَا', #1
u'والرغبا': u'وَالرُّغْبَا', #2
u'والرغباء': u'والرغباء', #1
u'والرغباء': u'وَالرَْغْبَاءُ', #1
u'والرغباء': u'وَالرَّغْبَاءُ', #44
u'والرغل': u'وَالرّغْلُ', #1
u'والرفاف': u'وَالرِّفَافُ', #1
u'والرفائين': u'وَالرَّفَّائِينَ', #1
u'والرفغ': u'وَالرُّفْغِ', #1
u'والرفغين': u'وَالرُّفْغَيْنِ', #2
u'والرقاشي،': u'وَالرَّقَاشِيِّ،', #1
u'والرقاطي': u'وَالرَّقَاطِي', #1
u'والرقاعة': u'وَالرَّقَاعَةِ', #1
u'والرقبى': u'والرقبى', #1
u'والرقبى': u'وَالرُقْبَى', #1
u'والرقبى': u'وَالرُّقْبَى', #69
u'والرقمة': u'وَالرّقْمَةُ', #1
u'والرقوم': u'والرقوم', #1
u'والرقوم': u'وَالرُّقُومَ', #2
u'والرقوم': u'وَالرُّقُومِ', #2
u'والرقوم': u'وَالرُّقُومُ', #3
u'والرقيا': u'وَالرُّقْيَا', #1
u'والركابات': u'وَالرِّكَابَات', #1
u'والركاز': u'وَالرِّكَازَ', #3
u'والركاز': u'وَالرِّكَازُ', #39
u'والركاز': u'وَالرِّكَازِ', #86
u'والركزة': u'وَالرِّكْزَةُ', #1
u'والركس': u'وَالرِّكْسُ', #5
u'والركية': u'وَالرَّكِيَّةُ', #1
u'والرما': u'وَالرِّمَا', #1
u'والرمادى': u'وَالرَّمَادِىُّ', #1
u'والرماصي': u'وَالرَّمَاصِيِّ', #3
u'والرماصي': u'وَالرَّمَاصِيُّ', #5
u'والرماك': u'وَالرِّمَاكُ', #2
u'والرماك': u'وَالرِّمَاكِ', #3
u'والرمانا': u'وَالرُّمَّانَا', #1
u'والرمث': u'وَالرَّمْثُ', #1
u'والرمضان': u'وَالرَّمَضَانُ', #1
u'والرمضانان': u'وَالرَّمَضَانَانِ', #1
u'والرمضة': u'وَالرَّمْضَةُ', #1
u'والرمك': u'وَالرَّمَكُ', #1
u'والرمك': u'وَالرَّمَكِ', #5
u'والرمكة': u'وَالرَّمَكَةِ', #1
u'والرمكة': u'وَالرَّمَكَةُ', #3
u'والرمى': u'والرمى', #1
u'والرمى': u'وَالرَّمْىَ', #1
u'والرمى': u'وَالرَّمْىِ', #4
u'والرميصاء': u'وَالرّمَيْصَاءِ', #1
u'والرهاوي': u'والرّهاوي', #1
u'والرهبوت': u'وَالرَّهَبُوت', #1
u'والرهرهة': u'وَالرّهْرَهَةُ', #1
u'والرهوني': u'وَالرَّهُونِيُّ', #4
u'والروازن': u'وَالرَّوَازِنِ', #1
u'والرواشن': u'وَالرَّوَاشِنُ', #4
u'والرواشين': u'وَالرَّوَاشِينَ', #1
u'والرواع': u'وَالرّوَاعَ', #1
u'والروثة': u'وَالرَّوْثَةِ', #3
u'والروحاء': u'وَالرَّوْحَاءُ', #1
u'والروذبارى': u'وَالرُّوذْبَارِىِّ', #1
u'والروزنة': u'وَالرَّوْزَنَةُ', #1
u'والروشن': u'وَالرَّوْشَن', #1
u'والروشن': u'وَالرَّوْشَنِ', #1
u'والروشن': u'وَالرَّوْشَنَ', #5
u'والروشن': u'وَالرَّوْشَنُ', #7
u'والروضوانيون': u'والرَّوْضَوانِيّون', #1
u'والروعات': u'وَالرَّوْعَات', #1
u'والروياني': u'وَالرُّويَانِيّ', #1
u'والروياني': u'وَالرُّويَانِيَّ', #11
u'والروياني': u'وَالرُّويَانِيِّ', #152
u'والروياني': u'وَالرُّويَانِيُّ', #687
u'والرويثة': u'وَالرُّوَيْثَةِ', #1
u'والرئاء': u'والرئاء', #1
u'والرئاء': u'وَالرِّئَاءُ', #1
u'والرئبال': u'وَالرِّئْبَالُ', #1
u'والريا': u'وَالرِّيَا', #2
u'والرياسات': u'وَالرِّيَاسَاتِ', #1
u'والرية': u'وَالرّيّةُ', #1
u'والريس': u'وَالرَّيِّسِ', #1
u'والريضة': u'وَالرِّيضَةُ', #3
u'والريطة': u'وَالرَّيْطَةُ', #1
u'والريطة': u'وَالرَّيْطَة', #3
u'والريناس': u'والريناس', #1
u'والزاء': u'وَالزَّاءِ', #1
u'والزاب': u'وَالزَّابُ', #1
u'والزاح': u'وَالزَّاحُ', #1
u'والزاز': u'وَالزَّازِ', #1
u'والزاغوني': u'وَالزَّاغُونِيِّ', #1
u'والزالون': u'وَالزَّالُّونَ', #2
u'والزانات': u'وَالزَّانَاتُ', #1
u'والزانة': u'وَالزَّانَةَ', #1
u'والزانى': u'وَالزَّانِى', #7
u'والزاهدي': u'وَالزَّاهِدِي', #2
u'والزاهدي': u'وَالزَّاهِدِيُّ', #2
u'والزاهدي': u'وَالزَّاهِدِيِّ', #7
u'والزبانان': u'وَالزِّبَانَانِ', #1
u'والزبرة': u'وَالزَّبْرَةِ', #1
u'والزبرة': u'وَالزُّبْرَةِ', #2
u'والزبرقان': u'والزِّبْرِقَان', #1
u'والزبرقان': u'وَالزِّبْرَقَانَ', #1
u'والزبرقان': u'وَالزِّبْرِقَانِ', #1
u'والزبرقان': u'وَالزّبْرِقَانُ', #7
u'والزبرقان': u'وَالزِّبْرِقَانَ', #7
u'والزبرقان': u'وَالزِّبْرِقَانُ', #7
u'والزبعرى': u'وَالزّبَعْرَى', #1
u'والزبعرى': u'وَالّزِبَعْرَى', #1
u'والزبلة': u'وَالزَّبْلَةِ', #1
u'والزبول': u'وَالزُّبُولُ', #1
u'والزبول': u'وَالزُّبُولِ', #1
u'والزبيدي': u'وَالزَّبِيدِيِّ', #1
u'والزبيدي': u'وَالزّبَيْدِيّ', #1
u'والزبيدي،': u'وَالزُّبَيْدِيُّ،', #1
u'والزبيدى': u'وَالزُّبَيْدِىِّ', #1
u'والزبيدي': u'وَالزُّبَيْدِيِّ', #2
u'والزبيدى': u'وَالزُّبَيْدِىُّ', #6
u'والزبيدي': u'وَالزُّبَيْدِيُّ', #8
u'والزبيروجابر': u'وَالزُّبَيْرِوَجَابِرٍ', #1
u'والزبيرى': u'وَالزُّبَيْرِىُّ', #1
u'والزخزب': u'وَالزُّخْزُبُّ', #1
u'والزخيرة': u'وَالزَّخِيرَةِ', #1
u'والزرابط': u'والزرابط', #1
u'والزراجين': u'وَالزَّرَاجِين', #12
u'والزراريع': u'وَالزَّرَارِيعُ', #2
u'والزراريع': u'وَالزَّرَارِيعِ', #2
u'والزرانيق': u'وَالزَّرَانِيقُ', #1
u'والزراية': u'وَالزِّرَايَةُ', #1
u'والزربول': u'والزربول', #1
u'والزربول': u'وَالزُّرْبُولُ', #1
u'والزربول': u'وَالزُّرْبُولِ', #3
u'والزرجون': u'والزرجون', #1
u'والزرقالية': u'والزرقالية', #2
u'والزرقاني': u'وَالزَّرْقَانِيُّ', #2
u'والزرقاني': u'وَالزَّرْقَانِيِّ', #7
u'والزرموزة': u'وَالزَّرْمُوزَةُ', #1
u'والزريراني': u'وَالزَّرِيرَانِيُّ', #1
u'والزريراني': u'وَالزَّرِيرَانِيِّ', #1
u'والزريفية': u'والزريفية', #1
u'والزط': u'وَالزُّطُّ', #4
u'والزطي': u'وَالزُّطِّيَّ', #1
u'والزطي': u'وَالزُّطِّيُّ', #1
u'والزعارة': u'وَالزَّعَارَةُ', #1
u'والزعبل': u'وَالزَّعْبَلِ', #2
u'والزعبلة': u'وَالزَّعْبَلَةِ', #1
u'والزفن': u'وَالزَّفَنَ', #1
u'والزفن': u'وَالزَّفْنَ', #1
u'والزفن': u'وَالزَّفْنُ', #3
u'والزفنان': u'وَالزّفَنَانِ', #1
u'والزفيزف': u'والزفيزف', #1
u'والزقلبع': u'والزقلبع', #1
u'والزقوق': u'والزقوق', #1
u'والزلاء': u'وَالزَّلَّاءُ', #1
u'والزلاطة': u'والزلاطة', #1
u'والزلط': u'وَالزَّلَطُ', #1
u'والزلط': u'وَالزَّلَطِ', #1
u'والزلنبغي': u'والزلنبغي', #1
u'والزمامجة': u'وَالزَّمَامِجَةَ', #1
u'وألزمتكه': u'وَأَلْزَمْتُكَهُ', #1
u'والزمخشري': u'وَالزَّمَخْشَرِيُّ', #14
u'والزمخشري': u'وَالزَّمَخْشَرِيِّ', #3
u'والزمرذ': u'وَالزُّمُرُّذِ', #1
u'والزملكاني': u'وَالزَّمْلَكانِيِّ', #1
u'والزمنة': u'وَالزَّمِنَةُ', #1
u'والزمنى،': u'وَالزَّمْنَى،', #1
u'والزمنى': u'وَالزَّمْنَى', #23
u'والزناتي': u'وَالزَّنَاتِيِّ', #1
u'والزندبيجي': u'والزندبيجي', #1
u'والزندة': u'وَالزَّنْدَةُ', #1
u'والزندنيجي': u'والزندنيجي', #5
u'والزنديجي': u'وَالزَّنْدِيجِيِّ', #1
u'والزنديجي': u'وَالزَّنْدِيجِيُّ', #3
u'والزنديقة': u'وَالزِّنْدِيقَةِ', #1
u'والزنط': u'وَالزُّنْطَ', #2
u'والزنكلوني': u'والزنكلوني', #1
u'والزنية': u'وَالزَّنْيَةُ', #1
u'والزنيرة': u'وَالزّنّيرَةُ', #1
u'والزنيم': u'وَالزَّنِيمُ', #1
u'والزنيم': u'وَالزّنِيمُ', #2
u'والزهرى': u'وَالزُّهْرِىَّ', #1
u'والزهرى': u'وَالزُّهْرِىِّ', #27
u'والزهرى': u'وَالزُّهْرِىُّ', #9
u'والزهومة': u'وَالزُّهُومَةِ', #1
u'والزهومة': u'وَالزُّهُومَةُ', #2
u'والزواريق': u'وَالزَّوَارِيقِ', #1
u'والزوان': u'وَالزُّوَانُ', #1
u'والزوراء': u'وَالزَّوْرَاء', #1
u'والزوراء': u'وَالزَّوْرَاءُ', #4
u'والزوزني': u'وَالزَّوْزَنِيِّ', #1
u'والزياد': u'وَالزِّيَادُ', #1
u'والزياده': u'وَالزِّيَادَهْ', #1
u'والزياره': u'وَالزِّيَارَهْ', #1
u'والزيافة': u'وَالزِّيَافَةَ', #1
u'والزيافة': u'وَالزِّيَافَةُ', #13
u'والزيدان': u'وَالزَّيْدَانِ', #1
u'والزيدون': u'وَالزَّيْدُونَ', #1
u'والزيدين': u'وَالزَّيْدِينَ', #1
u'والزيقة': u'وَالزِّيقَةِ', #1
u'والزيقة': u'وَالزِّيَقَةُ', #1
u'والزيلعي': u'وَالزَّيْلَعِيِّ', #101
u'والزيلعي': u'وَالزَّيْلَعِيَّ', #2
u'والزيلعي': u'وَالزَّيْلَعِيُّ', #36
u'والزيلعي': u'وَالزَّيْلَعِيّ', #93
u'والزيود': u'وَالزُّيُودِ', #1
u'والساباط': u'وَالسَّابَاطَ', #1
u'والساباط': u'وَالسَّابَاطِ', #24
u'والساباط': u'وَالسَّابَاطُ', #7
u'والساباطات': u'وَالسَّابَاطَاتِ', #1
u'والسابري': u'وَالسَّابِرِيَّ', #1
u'والسابري': u'وَالسَّابِرِيُّ', #2
u'والسابعه': u'والسابعه', #1
u'والساج': u'وَالسَّاجِ', #13
u'والساج': u'وَالسَّاجُ', #5
u'والساجة': u'وَالسَّاجَةِ', #2
u'والساجة': u'وَالسَّاجَةُ', #5
u'والساخوزة': u'وَالسَّاخُوزَةُ', #1
u'والساروراء': u'وَالسَّارُورَاءُ', #1
u'والساس': u'وَالسَّاسُ', #6
u'والساعه،': u'والساعه،', #1
u'والساقب': u'وَالسَّاقِبُ', #1
u'والساكنيه': u'وَالسَّاكِنِيهِ', #1
u'والسالحين': u'وَالسَّالِحِينَ', #1
u'والسائحاني': u'وَالسَّائِحَانِيُّ', #4
u'والسائف': u'وَالسَّائِفِ', #2
u'والسآئلين': u'وَالسَّآئِلِينَ', #1
u'والسائم': u'وَالسَّائِمُ', #1
u'والسائم': u'وَالسَّائِمِ', #1
u'والسائمون': u'وَالسَّائِمُونَ', #1
u'والسايس': u'وَالسَّايِسِ', #1
u'والسباء': u'وَالسّبَاءِ', #1
u'والسباء': u'وَالسِّبَاءُ', #1
u'والسباء': u'وَالسِّبَاءِ', #1
u'والسباخي': u'وَالسِّبَاخِيِّ', #2
u'والسبالان': u'وَالسِّبَالَانِ', #1
u'والسبتي': u'وَالسَّبْتِيُّ', #1
u'والسبتي': u'وَالسَّبْتِيِّ', #1
u'والسبج': u'وَالسَّبْجِ', #1
u'والسبج': u'وَالسَّبَجِ', #3
u'والسبد': u'وَالسَّبَدُ', #1
u'والسبه': u'وَالسَّبَهُ', #1
u'والسبور': u'وَالسَّبُورُ', #1
u'والسبوطة': u'وَالسُّبُوطَةُ', #1
u'والسبوطة': u'وَالسُّبُوطَةِ', #4
u'والسبى': u'وَالسَّبْىِ', #2
u'والسبيعي': u'وَالسَّبِيعِيِّ', #1
u'والستره': u'وَالسُّتْرَهْ', #1
u'والستوق': u'وَالسَّتُّوقَ', #1
u'والستوق': u'وَالسَّتُّوقِ', #2
u'والستوق': u'وَالسَّتُّوقُ', #4
u'والستوقة': u'وَالسَّتُّوقَةُ', #34
u'والستوقة': u'وَالسَّتُّوقَةِ', #6
u'والستوقة': u'وَالسَّتُّوقَةَ', #9
u'والسجة': u'وَالسَّجَّةِ', #1
u'والسجزي': u'وَالسِّجْزِيُّ', #6
u'والسجستاني': u'والسجستاني', #1
u'والسجوح': u'وَالسُّجُوحِ', #1
u'والسجير': u'وَالسَّجِيرُ', #1
u'والسحالة': u'وَالسُّحَالَةُ', #1
u'والسحالي': u'وَالسَّحَالِي', #4
u'والسحامي': u'وَالسُّحَامِيُّ', #1
u'والسحراء': u'وَالسَّحْرَاءُ', #1
u'والسحل': u'وَالسّحْلُ', #1
u'والسحل': u'وَالسّحْلِ', #1
u'والسحل': u'وَالسَّحْلُ', #1
u'والسحلفاة': u'وَالسُّحُلْفَاةُ', #2
u'والسحلية': u'وَالسِّحْلِيَّةِ', #1
u'والسحلية': u'وَالسِّحْلِيَّةُ', #2
u'والسحولية': u'وَالسَّحُولِيَّةُ', #3
u'والسخاب': u'وَالسِّخَابُ', #2
u'والسخاطة': u'وَالسَّخَاطَةِ', #1
u'والسخال': u'وَالسِّخَالُ', #1
u'والسخال': u'وَالسِّخَالِ', #8
u'والسخاوي': u'وَالسَّخَاوِيِّ', #1
u'والسخب': u'وَالسَّخَبَ', #1
u'والسخب': u'وَالسُّخُبَ', #1
u'والسخرى': u'وَالسّخْرَى', #1
u'والسخل': u'وَالسَّخْلَ', #1
u'والسخل': u'وَالسَّخْلُ', #3
u'والسخلة': u'وَالسَّخْلَةَ', #1
u'والسخلة': u'وَالسَّخْلَةُ', #15
u'والسخلة': u'وَالسَّخْلَةِ', #2
u'والسدا': u'وَالسَّدَا', #1
u'والسداء': u'وَالسِّدَاءُ', #1
u'والسداب': u'وَالسِّدَابَ', #1
u'والسدقة': u'وَالسّدْقَةُ', #1
u'والسرابات': u'وَالسَّرَابَاتِ', #1
u'والسراغج': u'والسراغج', #1
u'والسراوين': u'وَالسَّرَاوِينُ', #1
u'والسرايجه': u'والسرايجه', #1
u'والسرحان': u'وَالسِّرْحَانِ', #1
u'والسرحان': u'وَالسِّرْحَانُ', #5
u'والسرخكتي': u'وَالسُّرْخَكَتِيِّ', #2
u'والسرف': u'وَالسَّرَفِ', #22
u'والسرف': u'وَالسَّرَفُ', #29
u'والسرف': u'وَالسَّرَفَ', #5
u'والسرقنة': u'وَالسَّرْقَنَةِ', #2
u'والسرقند': u'والسرقند', #1
u'والسرقه': u'وَالسَّرِقَهْ', #1
u'والسرقين': u'وَالسِّرْقِينَ', #11
u'والسرقين': u'وَالسِّرْقِينِ', #17
u'والسرقين': u'وَالسِّرْقِينُ', #9
u'والسرموزة': u'وَالسُّرْمُوزَةِ', #1
u'والسروجي': u'وَالسَّرُوجِيِّ', #2
u'والسروجي': u'وَالسَّرُوجِيُّ', #4
u'والسريجي': u'وَالسُّرَيْجيُّ', #1
u'والسريجي': u'وَالسُّرَيْجِيُّ', #1
u'والسريجية': u'وَالسَّرِيجِيَّةَ', #1
u'والسطي': u'وَالسَّطِّيِّ', #3
u'والسعاده': u'وَالسَّعَادَهْ', #1
u'والسعانين': u'وَالسَّعَانِينُ', #3
u'والسعدانة': u'وَالسّعْدَانَةُ', #1
u'والسعلاة': u'وَالسّعْلَاةُ', #1
u'والسعوط': u'وَالسُّعُوطِ', #1
u'والسعوط': u'وَالسَّعُوطِ', #17
u'والسعوط': u'وَالسُّعُوطُ', #2
u'والسعوط': u'وَالسَّعُوطُ', #24
u'والسعوط': u'وَالسَّعُوطَ', #7
u'والسعى': u'والسَّعْىَ', #1
u'والسعى': u'وَالسَّعْىِ', #2
u'والسعى': u'وَالسَّعْىُ', #5
u'والسعيدي': u'وَالسَّعِيدِيِّ', #1
u'والسغد': u'وَالسُّغْدُ', #1
u'والسغناقي': u'وَالسِّغْنَاقِيُّ', #1
u'والسغناقي': u'وَالسِّغْنَاقِيِّ', #3
u'والسفاة': u'وَالسَّفَاةَ', #1
u'والسفاتج': u'وَالسَّفَاتِجِ', #1
u'والسفاتج': u'وَالسَّفَاتِجُ', #2
u'والسفاقسي': u'وَالسَّفَاقِسِيُّ', #1
u'والسفوفات': u'وَالسُّفُوفَاتِ', #1
u'والسفيانان': u'وَالسُّفْيَانَانِ', #21
u'والسفيانين': u'وَالسُّفْيَانَيْنِ', #4
u'والسفيق': u'وَالسَّفِيقُ', #2
u'والسقايين': u'وَالسَّقَّايِينَ', #1
u'والسقب': u'وَالسَّقَبُ', #2
u'والسقبا': u'وَالسَّقْبَا', #1
u'والسقمونيا': u'والسقمونيا', #1
u'والسقمونيا': u'وَالسَّقَمُونْيَا', #10
u'والسقيتان': u'وَالسَّقْيَتَانِ', #1
u'والسكاء': u'وَالسَّكَّاءِ', #1
u'والسكاء': u'وَالسَّكَّاءُ', #5
u'والسكاسك': u'وَالسَّكَاسِكَِِِِ', #1
u'والسكاسك': u'وَالسَّكَاسِكِ', #2
u'والسكاكي': u'وَالسَّكَّاكِيِّ', #1
u'والسكاكي': u'وَالسَّكَّاكِيُّ', #3
u'والسكرجة': u'وَالسُّكُرُّجَةُ', #1
u'والسكركة': u'والسكركة', #1
u'والسكركة': u'وَالسُّكْرُكَةُ', #1
u'والسكركة': u'وَالسُّكْرُكَةِ', #2
u'والسكنجبين': u'والسكنجبين', #2
u'والسكنجبين': u'وَالسَّكَنْجَبِينُ', #2
u'والسكنجبين': u'وَالسَّكَنْجَبِينِ', #2
u'والسكندري': u'وَالسَّكَنْدَرِيِّ', #1
u'والسكندرية': u'والسكندرية', #1
u'والسلابين': u'وَالسَّلَّابِينَ', #2
u'والسلاق': u'وَالسُّلَاقِ', #1
u'والسلاليم': u'وَالسَّلَالِيمِ', #1
u'والسلاليم': u'وَالسَّلَالِيمُ', #3
u'والسلامlements': u'والسلامlements', #20
u'والسلامlement': u'والسلامlement', #10
u'والسلامTLIرضي': u'والسلامTLIرضي', #9
u'والسلامXT-عز': u'والسلامXT-عز', #10
u'والسلامرحمه': u'والسلامرحمه', #10
u'والسلامقوله': u'وَالسَّلامُقَوْلُهُ', #1
u'والسلامه': u'وَالسّلَامَهْ', #1
u'والسلجم': u'وَالسَّلْجَمِ', #12
u'والسلجم': u'وَالسَّلْجَمُ', #2
u'والسلحفاء': u'وَالسُّلَحْفَاءُ', #1
u'والسلعا': u'وَالسّلَعَا', #1
u'والسلعنة': u'وَالسَّلْعَنَةُ', #1
u'والسلمى': u'وَالسُّلَمِىُّ', #1
u'والسلول': u'وَالسَّلُول', #1
u'والسلولية': u'وَالسّلُولِيّةُ', #1
u'والسليمي': u'وَالسُّلَيْمِيِّ', #1
u'والسمآء': u'وَالسَّمَآء', #1
u'والسماحه': u'وَالسَّمَاحَهْ', #1
u'والسماسم': u'وَالسَّمَاسِمُ', #1
u'والسمامة': u'وَالسّمَامَةُ', #1
u'والسماوة': u'والسماوَةُ', #1
u'والسماوة': u'وَالسّمَاوَةِ', #1
u'والسمحاق': u'وَالسِّمْحَاقَ', #1
u'والسمحاق': u'وَالسِّمْحَاقِ', #10
u'والسمحاق': u'وَالسِّمْحَاقُ', #19
u'والسمعاني': u'وَالسَّمْعَانِيُّ', #2
u'والسمندل': u'وَالسَّمَنْدَلُ', #1
u'والسمهري': u'والسّمْهَرِيّ', #1
u'والسمهري': u'وَالسّمْهَرِيّ', #1
u'والسمهودي': u'وَالسَّمْهُودِيِّ', #1
u'والسمهودي': u'وَالسَّمْهُودِيُّ', #2
u'والسميدع': u'وَالسّمَيْدَعُ', #1
u'والسميدع': u'وَالسّمَيْدَعِ', #2
u'والسميذ': u'وَالسَّمِيذِ', #1
u'والسميراء': u'وَالسّمَيْرَاءُ', #1
u'والسناوير': u'وَالسَّنَاوِيرَ', #1
u'والسناوير': u'وَالسَّنَاوِيرِ', #1
u'والسنباطي': u'وَالسَّنْبَاطِيِّ', #1
u'والسنباطي': u'وَالسَّنْبَاطِيُّ', #2
u'والسنجاري': u'والسنجاري', #1
u'والسندروس': u'والسندروس', #2
u'والسنذر': u'وَالسّنْذِرِ', #1
u'والسنكلوي': u'والسنكلوي', #1
u'والسنمار': u'وَالسّنِمّارُ', #1
u'والسنهاء': u'وَالسَّنْهَاءُ', #1
u'والسنهوري': u'وَالسَّنْهُورِيُّ', #5
u'والسنوت': u'وَالسَّنُّوت', #1
u'والسنوت': u'وَالسَّنُّوتُ', #1
u'والسنوت': u'وَالسَّنُّوتِ', #2
u'والسنوسي': u'وَالسَّنُوسِيِّ', #1
u'والسنونوروي': u'وَالسِّنُونَوَرُوِيَ', #1
u'والسنى': u'وَالسَّنَى', #4
u'والسنيد': u'وَالسّنِيدُ', #1
u'والسه': u'وَالَسَهُ', #1
u'والسه': u'وَالسَّهُ', #5
u'والسهروردي': u'وَالسُّهْرَوَرْدِي', #2
u'والسهك': u'وَالسَّهَكُ', #1
u'والسهوكة': u'وَالسَّهُوكَةِ', #1
u'والسوبيا': u'وَالسُّوبْيَا', #3
u'والسودد': u'والسّودَد', #1
u'والسودد': u'وَالسّودَدُ', #1
u'والسودد': u'وَالسّودَدِ', #1
u'والسودد': u'وَالسُّوْدُدُ', #1
u'والسودد': u'وَالسّوْدُدِ', #2
u'والسوذانق': u'وَالسَّوْذَانِقُ', #1
u'والسوذق': u'وَالسَّوْذَقُ', #1
u'والسوذنيق': u'وَالسَّوْذَنِيقُ', #1
u'والسوطل': u'وَالسَّوْطَلِ', #1
u'والسوقة': u'وَالسُّوقَةِ', #3
u'والسويق': u'وَالسّوِيقَ', #1
u'والسويق': u'وَالسَّوِيق', #3
u'والسويق': u'وَالسَّوِيقُ', #30
u'والسويق': u'وَالسّوِيقِ', #4
u'والسويق': u'وَالسَّوِيقَ', #4
u'والسويق': u'وَالسَّوِيقِ', #64
u'والسويقا': u'وَالسَّوِيقَا', #1
u'والسياده': u'وَالسِّيَادَهْ', #1
u'والسيب': u'وَالسُّيَّبِ', #1
u'والسيب': u'وَالسِّيَبُ', #1
u'والسيب': u'وَالسّيّبُ', #2
u'والسيج': u'وَالسِّيجِ', #1
u'والسيجة': u'وَالسِّيجَةُ', #1
u'والسيجة': u'وَالسِّيجَةِ', #3
u'والسيحون': u'وَالسَّيْحُونِ', #1
u'والسيدية': u'وَالسَّيِّدِيَّةُ', #1
u'والسيدية': u'وَالسَّيِّدِيَّةِ', #1
u'والسيرا': u'وَالسِّيرَا', #1
u'والسيراء': u'وَالسِّيَرَاءُ', #4
u'والسيرافي': u'وَالسِّيرَافِيِّ', #2
u'والسيرافي': u'وَالسِّيرَافِيُّ', #5
u'والسيكران': u'وَالسَّيْكَرَانِ', #6
u'والسيميا': u'وَالسِّيمَيَا', #1
u'والسيميا': u'وَالسِّيمْيَا', #2
u'والسينوسج': u'والسينوسج', #1
u'والسيوب': u'وَالسُّيُوبُ', #4
u'والسيوري': u'وَالسُّيُورِيُّ', #12
u'والسيوري': u'وَالسُّيُورِيِّ', #3
u'والسيوغ': u'وَالسُّيُوغِ', #1
u'والسيوم': u'وَالسُّيُومُ', #3
u'والشاء': u'والشَّاء', #1
u'والشاء،': u'والشَّاء،', #1
u'والشاء': u'وَالشَّاءَ', #1
u'والشاء': u'وَالشّاءِ', #12
u'والشاء': u'وَالشَّاءِ', #4
u'والشاء': u'وَالشّاءُ', #5
u'والشاء': u'وَالشَّاءُ', #5
u'والشاء': u'وَالشّاءَ', #8
u'والشاتينالوجه': u'وَالشَّاتَيْنِالْوَجْهُ', #1
u'والشادوران': u'والشادوران', #2
u'والشادوف': u'وَالشَّادُوفِ', #1
u'والشادوف': u'وَالشَّادُوفُ', #2
u'والشادياخي': u'وَالشَّادْيَاخِيُّ', #2
u'والشاذروان': u'وَالشَّاذَرْوَانُ', #10
u'والشاذروان': u'وَالشَّاذَرْوَانِ', #3
u'والشاذروانات': u'والشاذروانات', #1
u'والشاذكوني': u'وَالشَّاذَكُونِيُّ', #2
u'والشاغور': u'وَالشَّاغُورُ', #1
u'والشاغور': u'وَالشَّاغُورِ', #1
u'والشاغية': u'وَالشَّاغِيَةُ', #1
u'والشافعى': u'والشَّافِعِىِّ', #2
u'والشافعى': u'وَالشَّافِعِىُّ', #2
u'والشافعى': u'والشَّافِعِىُّ', #5
u'والشافعيفي': u'وَالشَّافِعِيُّفِي', #1
u'والشاكرية': u'وَالشَّاكِرِيَّةِ', #1
u'والشالقة': u'وَالشَّالِقَةِ', #1
u'والشالنجي': u'والشالنجي', #1
u'والشالنجي': u'وَالشَّالَنْجِيُّ', #6
u'والشآم': u'وَالشّآمِ', #1
u'والشاهسبرم': u'وَالشَّاهِسْبَرَمِ', #1
u'والشاوي': u'وَالشَّاوِي', #2
u'والشبابة': u'وَالشَّبَّابَةِ', #14
u'والشبابة': u'وَالشَّبَّابَةَ', #2
u'والشبابة': u'وَالشَّبَّابَةُ', #6
u'والشبة': u'وَالشَّبَّةُ', #1
u'والشبة': u'وَالشَّبَّةِ', #3
u'والشبت': u'وَالشِّبِتِّ', #1
u'والشبراملسي': u'والشَّبْرَامَلِّسِيّ', #2
u'والشبراملسي': u'والشبراملسي', #3
u'والشبرخيتي': u'والشبرخيتي', #2
u'والشبرم': u'وَالشُّبْرُمُ', #1
u'والشبشيري': u'وَالشَّبْشِيرِيُّ', #1
u'والشبوبة': u'وَالشَّبُوبَةِ', #2
u'والشبور': u'وَالشَّبُّورُ', #1
u'والشتر': u'وَالشَّتَرِ', #1
u'والشتر': u'وَالشَّتَرُ', #5
u'والشتيم': u'وَالشَّتِيمِ', #1
u'والشث': u'وَالشَّثُّ', #1
u'والشث': u'وَالشَّثِّ', #3
u'والشحر': u'وَالشّحْرَ', #1
u'والشحر': u'وَالشِّحْرُ', #2
u'والشداخ': u'وَالشّدّاخُ', #2
u'والشداقة': u'وَالشَّدَّاقَةِ', #1
u'والشداقة': u'وَالشَّدَّاقَةُ', #3
u'والشدخ': u'وَالشَّدْخُ', #2
u'والشذانقات': u'وَالشُّذَانِقَاتِ', #1
u'والشذانيق': u'والشذانيق', #1
u'والشرا': u'وَالشِّرَا', #4
u'والشرابة': u'وَالشَّرَابَةِ', #1
u'والشرابة': u'وَالشِّرَابَةُ', #1
u'والشراج': u'وَالشّرَاجُ', #1
u'والشراريب': u'وَالشَّرَارِيبِ', #1
u'والشراريب': u'وَالشَّرَارِيبُ', #6
u'والشراريف': u'وَالشَّرَارِيفِ', #1
u'والشراسيف': u'وَالشَّرَاسِيفُ', #2
u'والشراسيف': u'وَالشَّرَاسِيفِ', #3
u'والشراط': u'وَالشِّرَاطُ', #1
u'والشراميز': u'وَالشَّرَامِيزِ', #1
u'والشربيني': u'وَالشِّرْبِينِيُّ', #1
u'والشربيني': u'وَالشِّرْبِينِيِّ', #4
u'والشرثاء': u'وَالشَّرْثَاءِ', #1
u'والشرجب': u'وَالشّرْجَبُ', #1
u'والشرشير': u'وَالشَّرْشِيرُ', #1
u'والشرقاء': u'وَالشَّرْقَاءِ', #1
u'والشرقاء': u'وَالشَّرْقَاء', #2
u'والشرقاء': u'وَالشَّرْقَاءُ', #9
u'والشرقاوي': u'وَالشَّرْقَاوِيُّ', #3
u'والشرقاوي': u'وَالشَّرْقَاوِيِّ', #3
u'والشركا': u'وَالشُّرَكَا', #1
u'والشرنبلالي': u'وَالشُّرُنْبَلاليّ', #1
u'والشرنبلالي': u'وَالشُّرُنْبُلاليُّ', #1
u'والشرنبلالي': u'والشرنبلالي', #17
u'والشرنبلالي': u'والشُّرُنْبُلاليُّ', #17
u'والشرنبلالي': u'وَالشُّرُنْبُلالي', #17
u'والشرنبلالي': u'والشُّرُنْبُلاليِّ', #2
u'والشرنبلالي': u'وَالشُّرُنْبُلاليّ', #2
u'والشرنبلالي': u'وَالشُّرْنُبَلاليّ', #2
u'والشرنبلالي': u'والشُّرُنْبُلاليّ', #3
u'والشرنبلالية': u'وَالشُّرُنبُلالِيَّة', #1
u'والشرنبلالية': u'وَالشُّرُنْبُلالِيَّةِ', #1
u'والشرنبلالية': u'والشُّرُنبُلالِيَّةِ', #2
u'والشرنبلالية': u'والشُّرُنبُلالِيَّة', #26
u'والشرنبلالية': u'والشرنبلالية', #7
u'والشروال': u'وَالشِّرْوَالُ', #1
u'والشريب': u'وَالشَّرِيبُ', #1
u'والشريبين': u'وَالشِّرِّيبِينَ', #1
u'والشريحية': u'وَالشَّرِيحِيَّةَ', #1
u'والشريحية': u'وَالشُّرَيْحِيَّةِ', #1
u'والشريحية': u'وَالشُّرَيْحِيَّةَ', #2
u'والشسع': u'وَالشِّسْعَ', #1
u'والشسع': u'وَالشِّسْعُ', #1
u'والشسع': u'وَالشِّسْعِ', #2
u'والششتري': u'وَالشَّشْتَرِيِّ', #1
u'والششم': u'وَالشِّشْمِ', #1
u'والشطاة': u'وَالشَّطَاةُ', #1
u'والشطح': u'وَالشَّطْحِ', #1
u'والشطوي': u'وَالشَّطَوِيُّ', #1
u'والشطوي': u'وَالشَّطَوِيِّ', #3
u'والشطير': u'وَالشَّطِيرُ', #1
u'والشظاظ': u'والشظاظ', #1
u'والشعارى': u'والشعارى', #2
u'والشعبثة': u'وَالشَّعْبَثَةِ', #1
u'والشعبذة': u'وَالشَّعْبَذَةِ', #16
u'والشعبذة': u'وَالشَّعْبَذَةُ', #7
u'والشعبى': u'وَالشَّعْبِىُّ', #12
u'والشعبى': u'وَالشَّعْبِىِّ', #38
u'والشعثا': u'وَالشَّعِثَا', #1
u'والشعرعلى': u'والشعرعلى', #1
u'والشعشعاني': u'وَالشّعْشَعَانِيّ', #1
u'والشعيب': u'وَالشُّعَيْبُ', #1
u'والشعيبة': u'وَالشّعَيْبَةُ', #1
u'والشعيبى': u'وَالشُّعَيْبِىِّ', #1
u'والشعيبية': u'وَالشُّعَيْبِيَّةُ', #1
u'والشغانين': u'وَالشَّغَانِينُ', #1
u'والشغوش': u'وَالشّغُوشُ', #2
u'والشفعا': u'وَالشُّفَعَا', #1
u'والشفقان': u'وَالشَّفَقَانِ', #2
u'والشفوع': u'وَالشَّفُوعَ', #1
u'والشفوع': u'وَالشَّفُوعِ', #1
u'والشقدف': u'وَالشُّقْدُفِ', #1
u'والشقران': u'وَالشَّقْرَانِ', #1
u'والشقص': u'وَالشِّقْصُ', #30
u'والشقص': u'وَالشِّقْصِ', #8
u'والشقم': u'وَالشَّقَمِ', #1
u'والشكارية': u'وَالشَّكَّارِيَّةِ', #2
u'والشكاز': u'وَالشَّكَّازُ', #1
u'والشكاز': u'وَالشَّكَّازِ', #1
u'والشكرين': u'وَالشُّكْرَيْنِ', #1
u'والشلا': u'وَالشَّلَا', #1
u'والشلبي': u'وَالشَّلَبِيُّ', #1
u'والشلبي': u'وَالشَّلَبِيِّ', #1
u'والشلبي': u'وَالشَّلَبِيّ', #8
u'والشلجم': u'وَالشَّلْجَمِ', #2
u'والشلوبين': u'وَالشَّلُوبِينَ', #1
u'والشلوبين': u'وَالشَّلَوْبِينُ', #1
u'والشليل': u'وَالشّلِيلُ', #1
u'والشماريخ': u'وَالشَّمَارِيخُ', #1
u'والشماريخ': u'وَالشَّمَارِيخِ', #3
u'والشمامسة': u'وَالشَّمَامِسَةُ', #1
u'والشمرخة': u'وَالشَّمْرَخَةُ', #1
u'والشمط': u'وَالشَّمَطِ', #1
u'والشمط': u'وَالشَّمَطُ', #3
u'والشمليل': u'وَالشّمْلِيلُ', #1
u'والشمني': u'وَالشُّمُنِّيُّ', #2
u'والشمني': u'وَالشُّمُنِّيِّ', #9
u'والشنار': u'وَالشَّنَارَ', #1
u'والشنار': u'وَالشَّنَارُ', #2
u'والشنار': u'وَالشَّنَارِ', #4
u'والشنة': u'وَالشّنّةُ', #1
u'والشندخي': u'والشندخي', #1
u'والشندخي': u'وَالشَّنْدَخِيُّ', #1
u'والشنظير': u'وَالشِّنْظِيرَ', #1
u'والشنظير': u'وَالشِّنْظِيرُ', #3
u'والشنوفا': u'وَالشُّنُوفَا', #1
u'والشنوفا': u'وَالشّنُوفَا', #4
u'والشهاده': u'وَالشَّهَادَهْ', #1
u'والشهدانج': u'وَالشَّهْدَانِجُ', #1
u'والشهرق': u'وَالشّهْرَقُ', #1
u'والشواب': u'وَالشَّوَابَّ', #1
u'والشواب': u'وَالشَّوَابُّ', #1
u'والشواب': u'وَالشَّوَابِّ', #2
u'والشوبان': u'وَالشَّوْبَانُ', #1
u'والشوبري': u'وَالشَّوْبَرِيُّ', #18
u'والشوبري': u'وَالشَّوْبَرِيِّ', #9
u'والشوذب': u'وَالشّوْذَبُ', #1
u'والشورة': u'وَالشُّورَةِ', #4
u'والشوصة': u'وَالشَّوْصَةِ', #1
u'والشوقب': u'وَالشّوْقَبُ', #1
u'والشوكس': u'وَالشَّوْكَسِ', #1
u'والشوم': u'وَالشُّومُ', #1
u'والشون': u'وَالْشُّوَنِ', #1
u'والشونيز': u'وَالشُّونِيز', #1
u'والشونيز': u'وَالشُّونِيزَ', #2
u'والشونيز': u'وَالشُّونِيزُ', #2
u'والشونيز': u'وَالشُّونِيزِ', #6
u'والشؤونا': u'وَالشّؤُونَا', #1
u'والشىء': u'وَالشَّىْءِ', #1
u'والشىء': u'وَالشَّىْءَ', #5
u'والشئونا': u'وَالشّئُونَا', #1
u'والشياد': u'وَالشِّيَادُ', #1
u'والشيادة': u'وَالشِّيَادَةُ', #1
u'والشياع': u'وَالشِّيَاع', #1
u'والشياع': u'وَالشِّيَاعُ', #8
u'والشيخون': u'وَالشَّيْخُونُ', #1
u'والشير': u'وَالشَّيِّرُ', #1
u'والشيراز': u'وَالشِّيرَازِ', #1
u'والشيراز': u'وَالشِّيرَازُ', #3
u'والشيرازي': u'وَالشِّيرَازِيُّ', #173
u'والشيرازي': u'وَالشِّيرَازِيَّ', #2
u'والشيرازي': u'وَالشِّيرَازِيِّ', #60
u'والشيرخشك': u'وَالشَّيْرَخَشْكِ', #1
u'والشيرخشك': u'وَالشَّيْرَخُشْكِ', #1
u'والشيرخشك': u'والشيرخشك', #4
u'والشيرق': u'والشيرق', #1
u'والشيرق': u'وَالشَّيْرَقُ', #1
u'والشيرق': u'وَالشِّيرِقِ', #2
u'والشيرق': u'وَالشَّيْرَقِ', #2
u'والشيص،': u'وَالشَّيصِ،', #1
u'والشيطانة': u'وَالشَّيْطَانَةِ', #1
u'والشيطرج': u'والشيطرج', #2
u'والشيكران': u'وَالشَّيْكَرَانُ', #1
u'والشيكران': u'وَالشَّيْكَرَانِ', #4
u'والشيلان': u'وَالشِّيلَانِ', #2
u'والشيماء': u'وَالشّيْمَاءِ', #1
u'والشيهم': u'وَالشّيْهَمُ', #1
u'والشيوخة': u'وَالشُّيُوخَةِ', #3
u'والشيوم': u'وَالشّيُومُ', #2
u'والصابؤون': u'وَالصَّابِؤُونَ', #1
u'والصابئي': u'وَالصَّابِئِيُّ', #1
u'والصابئية': u'وَالصَّابِئِيَّةَ', #1
u'والصابئية': u'وَالصَّابِئِيَّةُ', #2
u'والصابيون': u'وَالصَّابِيُونَ', #1
u'والصاحبية': u'وَالصَّاحِبِيَّةُ', #1
u'والصادرا': u'وَالصَّادِرَا', #1
u'والصاروج': u'وَالصَّارُوج', #2
u'والصاغاني،': u'والصاغاني،', #1
u'والصاغاني،': u'وَالصَّاغَانِيُّ،', #18
u'والصاغاني': u'وَالصَّاغَانِيِّ', #2
u'والصاغاني': u'وَالصَّاغَانِيُّ', #3
u'والصالحية': u'وَالصَّالِحِيَّةُ', #3
u'والصالحية': u'وَالصَّالِحِيَّةِ', #4
u'والصالقة': u'وَالصّالِقَةُ', #1
u'والصالقة': u'وَالصَّالِقَةَ', #4
u'والصالقة': u'وَالصَّالِقَةُ', #6
u'والصايغ،': u'وَالصَّايِغِ،', #1
u'والصبأة': u'وَالصَّبَأَةِ', #1
u'والصبب': u'وَالصَّبَبُ', #2
u'والصبحا': u'وَالصُّبْحَا', #2
u'والصبوب': u'وَالصَّبُوبُ', #1
u'والصبى': u'وَالصَّبِىُّ', #1
u'والصبى': u'وَالصَّبَى', #2
u'والصبى': u'وَالصَّبِىِّ', #3
u'والصبيحي،': u'والصَّبِيحِيُّ،', #1
u'والصبيحي،': u'وَالصُّبَيْحِيِّ،', #1
u'والصحاصح': u'وَالصّحَاصِحُ', #1
u'والصحل': u'وَالصَّحْلُ', #1
u'والصداء': u'والصداء', #1
u'والصداغ': u'وَالصّدَاغُ', #1
u'والصدائي': u'وَالصُّدَائِيُّ', #1
u'والصدفى': u'وَالصَّدَفِىُّ', #1
u'والصدقه': u'وَالصَّدَقَهْ', #1
u'والصراة': u'وَالصَّرَاةُ', #1
u'والصراة': u'وَالصَّرَاةِ', #2
u'والصرائح': u'وَالصَّرَائِحُ', #1
u'والصرصار': u'وَالصِّرْصَارِ', #1
u'والصرصار': u'وَالصِّرْصَارُ', #2
u'والصرعتمشية': u'والصرعتمشية', #1
u'والصرغتمشية': u'والصرغتمشية', #2
u'والصرورة': u'وَالصَّرُورَةِ', #1
u'والصرورة': u'وَالصَّرُورَةَ', #2
u'والصرورة': u'وَالصَّرُورَةُ', #5
u'والصعايدة': u'وَالصَّعَايِدَةُ', #1
u'والصعثر': u'وَالصَّعْثَرِ', #1
u'والصعقب': u'وَالصّعْقَبُ', #1
u'والصعقى': u'وَالصَّعْقَى', #1
u'والصعلة': u'وَالصَّعْلَةُ', #1
u'والصعوة': u'وَالصَّعْوَةِ', #1
u'والصعوة': u'وَالصَّعْوَةُ', #2
u'والصغاني،': u'وَالصَّغَانِيُ،', #1
u'والصغاني،': u'وْالصَّغَانِيُّ،', #1
u'والصغانى': u'والصَّغَانِىِّ', #1
u'والصغانى': u'وَالصَّغَانِىِّ', #1
u'والصغاني،': u'وَالصَّغَانِيُّ،', #126
u'والصغاني،': u'والصغاني،', #14
u'والصغاني': u'والصغاني', #2
u'والصغاني،': u'والصَّغَانِيُّ،', #26
u'والصغاني': u'وَالصَّغَانِيُّ', #31
u'والصغاني،': u'وَالصَّغَانِيِّ،', #51
u'والصغاني': u'وَالصَّغَانِيِّ', #9
u'والصفاة': u'وَالصَّفَاةُ', #1
u'والصفاقه': u'وَالصَّفَاقَهْ', #1
u'والصفه': u'وَالصِّفَهْ', #2
u'والصفى': u'وَالصَّفِىُّ', #1
u'والصفى': u'وَالصَّفِىِّ', #1
u'والصفى': u'وَالصَّفِىَّ', #3
u'والصقالبة،': u'وَالصَّقَالِبَةُ،', #1
u'والصقالبة': u'وَالصَّقَالِبَةِ', #3
u'والصقب': u'وَالصَّقَبُ', #2
u'والصقراط': u'والصقراط', #1
u'والصقعب': u'وَالصَّقْعَبُ', #1
u'والصقلبي': u'وَالصَّقْلَبِيَّ', #1
u'والصقلبي': u'وَالصَّقْلَبِيُّ', #1
u'والصقليون': u'وَالصَّقَلِّيُّونَ', #1
u'والصكاك': u'وَالصَّكَّاكِ', #3
u'والصكاكين': u'وَالصَّكَّاكِينَ', #1
u'والصكك': u'وَالصَّكَكِ', #3
u'والصكك': u'وَالصَّكَكُ', #4
u'والصلا': u'وَالصّلَا', #1
u'والصلا': u'وَالصَّلَا', #1
u'والصلاء': u'وَالصِّلَاءُ', #1
u'والصلاتية': u'وَالصَّلَاتِيَّةَ', #1
u'والصلاتية': u'وَالصَّلَاتِيَّةِ', #2
u'والصلاتية': u'وَالصَّلَاتِيَّةُ', #7
u'والصلاصل': u'وَالصّلَاصِلُ', #2
u'والصلاية': u'وَالصَّلَايَةُ', #1
u'والصلصل': u'وَالصَّلْصَلُ', #1
u'والصلصل': u'وَالصُّلْصُلِ', #1
u'والصلق': u'وَالصَّلْقُ', #7
u'والصلوان': u'وَالصَّلَوَانِ', #4
u'والصلوة': u'وَالصَّلَوةِ', #1
u'والصلوة': u'وَالصِّلْوَةُ', #1
u'والصماب': u'والصماب', #1
u'والصماح': u'وَالصّمَاحُ', #1
u'والصمحمح': u'وَالصّمَحْمَحُ', #1
u'والصمداني': u'وَالصَّمَدَانِيُّ', #1
u'والصمصامة': u'وَالصّمْصَامَةُ', #1
u'والصمعاء': u'وَالصَّمْعَاءُ', #1
u'والصميري': u'وَالصَّمْيَرِيِّ', #1
u'والصنابحي': u'وَالصُّنَابِحِيِّ', #1
u'والصنابحى': u'وَالصُّنَابِحِىُّ', #2
u'والصنابحي': u'وَالصُّنَابِحِيُّ', #4
u'والصنادلة': u'وَالصَّنَادِلَةِ', #1
u'والصنجات': u'وَالصَّنْجَاتُ', #1
u'والصنجات': u'وَالصَّنْجَاتِ', #1
u'والصنجات': u'وَالصَّنَجَاتُ', #2
u'والصنجات': u'وَالصَّنَجَاتِ', #3
u'والصنجة': u'وَالصَّنْجَةِ', #3
u'والصنجة': u'وَالصَّنْجَةُ', #5
u'والصندروس': u'والصندروس', #1
u'والصنعاني،': u'وَالصَّنْعَانِيِّ،', #1
u'والصنعاني': u'والصنعاني', #2
u'والصنقة': u'والصِّنْقَةِ', #1
u'والصهرة': u'وَالصِّهْرَةِ', #1
u'والصهرة': u'وَالصِّهْرَةَ', #2
u'والصهرة': u'وَالصِّهْرَةُ', #2
u'والصهريه': u'وَالصِّهْرِيَّهْ', #1
u'والصهوبة': u'وَالصُّهُوبَةِ', #2
u'والصهوبة': u'وَالصُّهُوبَةُ', #4
u'والصوارف': u'وَالصَّوَارِفِ', #2
u'والصواع': u'وَالصُّوَاعُ', #1
u'والصواغون': u'وَالصَّوَّاغُونَ', #7
u'والصواغين': u'وَالصَّوَّاغِينَ', #15
u'والصول': u'وَالصَّوْلُ', #1
u'والصول': u'وَالصَّوْلِ', #1
u'والصئبان': u'وَالصِّئْبَان', #1
u'والصئبان': u'وَالصِّئْبَانَ', #1
u'والصيال': u'وَالصِّيَالِ', #2
u'والصيال': u'وَالصِّيَالُ', #5
u'والصيانه': u'وَالصِّيَانَهْ', #1
u'والصيحاني': u'وَالصَّيْحَانِيِّ', #5
u'والصيحاني': u'وَالصَّيْحَانِيُّ', #9
u'والصيرفى': u'والصَّيْرَفِىُّ', #1
u'والصيقل': u'وَالصَّيْقَلُ', #1
u'والصيقل': u'وَالصَّيْقَلِ', #1
u'والصيقل': u'وَالصّيْقَلُ', #1
u'والصيمري': u'وَالصَّيْمَرِيُّ', #18
u'والصيمري': u'وَالصَّيْمَرِيِّ', #2
u'والصيود': u'وَالصَّيُودِ', #1
u'والصيود': u'وَالصُّيُودِ', #7
u'والضاروراء': u'وَالضَّارُورَاءُ', #1
u'والضائر': u'وَالضَّائِرُ', #1
u'والضائر': u'وَالضَّائِرِ', #3
u'والضبات': u'وَالضَّبَّاتُ', #1
u'والضبوب': u'وَالضَّبُوبُ', #1
u'والضبوع': u'وَالضُّبُوعُ', #1
u'والضبينا': u'وَالضّبِينَا', #1
u'والضجاج': u'وَالضّجَاجُ', #1
u'والضح': u'وَالضّحّ', #1
u'والضرا': u'وَالضَّرَّا', #1
u'والضرابيب': u'وَالضَّرَابِيبُ', #2
u'والضرات': u'وَالضَّرَّاتُ', #2
u'والضربوب': u'وَالضَّرْبُوبُ', #2
u'والضرورةليعلم': u'وَالضَّرُورَةِلِيَعْلَمَ', #1
u'والضغابيس': u'وَالضَّغَابِيسُ', #2
u'والضغانة': u'وَالضَّغَانَةُ', #1
u'والضغانيث': u'وَالضَّغَانِيثُ', #1
u'والضغبوس': u'وَالضّغْبُوسُ', #1
u'والضناك': u'وَالضُّنَاكُ', #1
u'والضنة': u'وَالضِّنَةِ', #2
u'والضنة': u'وَالضِّنَّةُ', #3
u'والضنة': u'وَالضِّنَةُ', #7
u'والضهل': u'وَالضّهْلُ', #1
u'والضهيأ': u'وَالضّهْيَأُ', #1
u'والضوج': u'وَالضّوْجُ', #1
u'والضئضئ': u'والضئضئ', #1
u'والضئي': u'وَالضّئْيُ', #2
u'والضئين': u'وَالضّئِينِ', #1
u'والضيزن': u'وَالضّيْزَنُ', #1
u'والطاب': u'وَالطَّابُ', #1
u'والطاب': u'وَالطَّابِ', #8
u'والطابو': u'وَالطَّابُو', #1
u'والطارمة': u'وَالطَّارِمَةِ', #1
u'والطالبية': u'وَالطَّالِبِيَّةِ', #1
u'والطالقاني': u'وَالطَّالَقَانِيُّ', #5
u'والطاهرية': u'وَالطَّاهِرِيَّةُ', #1
u'والطاهرية': u'وَالطَّاهِرِيَّةِ', #1
u'والطاهرية': u'وَالطَّاهِرِيَّةَ', #3
u'والطاوس': u'وَالطَّاوُسِ', #2
u'والطباب': u'وَالطّبَابُ', #1
u'والطباهجة': u'وَالطَّبَاهِجَةِ', #1
u'والطبر': u'وَالطَّبَرِ', #1
u'والطبراني،': u'وَالطَّبَرَانِيُّ،', #2
u'والطبراني': u'وَالطَّبَرَانِيِّ', #52
u'والطبراني': u'وَالطَّبَرَانِيُّ', #854
u'والطبرزذا': u'وَالطَّبَرْزَذَا', #1
u'والطبرسية': u'وَالطَّبَرَسِيَّةِ', #1
u'والطبري': u'وَالطَّبَرِيّ', #1
u'والطبري': u'وَالطَّبَرِيِّ', #18
u'والطبري': u'وَالطَّبَرِيُّ', #27
u'والطبري': u'وَالطّبَرِيّ', #3
u'والطبرية': u'وَالطَّبَرِيَّةَ', #1
u'والطبرية': u'وَالطَّبَرِيَّةِ', #2
u'والطبرية': u'وَالطَّبَرِيَّةُ', #6
u'والطبلاوي': u'وَالطَّبَلَاوِيُّ', #10
u'والطبلاوي': u'وَالطَّبَلَاوِيِّ', #10
u'والطبلقة': u'وَالطَّبْلَقَةُ', #1
u'والطبوع': u'وَالطُّبُوعِ', #2
u'وألطت': u'وَأَلَطّتْ', #1
u'والطحاوي': u'وَالطَّحَاوِيّ', #1
u'والطحاوي': u'وَالطَّحَاوِيُّ', #105
u'والطحاوي': u'وَالطَّحَاوِيِّ', #34
u'والطحطاوي': u'وَالطَّحْطَاوِيّ', #1
u'والطحطاوي': u'وَالطَّحْطَاوِيِّ', #2
u'والطحطاوي': u'وَالطَّحْطَاوِيُّ', #67
u'والطحينة': u'وَالطَّحِينَةَ', #1
u'والطحينة': u'وَالطَّحِينَةِ', #5
u'والطخاء': u'وَالطَّخَاءُ', #1
u'والطخاء': u'وَالطَّخَاءِ', #1
u'والطخبير': u'وَالطَّخَبِيرُ', #1
u'والطخياء': u'وَالطَّخْيَاءِ', #1
u'والطخيخي': u'وَالطِّخِّيخِيِّ', #3
u'والطخيخي': u'وَالطِّخِّيخِيُّ', #6
u'والطراحة': u'وَالطَّرَّاحَةِ', #1
u'والطراخم': u'وَالطّرَاخِمُ', #1
u'والطرار': u'وَالطَّرَّارَ', #1
u'والطرار': u'وَالطَّرَّارُ', #1
u'والطرار': u'وَالطَّرَّارِ', #2
u'والطراريح': u'وَالطَّرَارِيحِ', #1
u'والطرازدان': u'وَالطِّرَازْدَانَ', #1
u'والطراطير': u'وَالطَّرَاطِيرُ', #1
u'والطرانة': u'وَالطَّرَانَةُ', #1
u'والطربسية': u'وَالطَّرْبَسِيَّةِ', #1
u'والطرثوث': u'وَالطَّرْثُوثِ', #1
u'والطرثوث': u'وَالطُّرْثُوثُ', #1
u'والطرثوث': u'وَالطُّرْثُوثِ', #3
u'والطرخون': u'وَالطَّرْخُونُ', #1
u'والطرخون': u'وَالطَّرْخُونِ', #1
u'والطرسوسي': u'وَالطَّرَسُوسِيِّ', #1
u'والطرطوشي': u'وَالطُّرْطُوشِيِّ', #4
u'والطرطوشي': u'وَالطُّرْطُوشِيُّ', #8
u'والطرماح': u'وَالطّرِمّاحُ', #2
u'والطروقة': u'وَالطَّرُوقَة', #1
u'والطروقة': u'وَالطَّرُوقَةُ', #1
u'والطريا': u'وَالطَّرِيَّا', #5
u'والطساس': u'وَالطِّسَاسِ', #1
u'والطسوج': u'وَالطَّسُّوجُ', #4
u'والطش': u'وَالطّشّ', #1
u'والطشت': u'وَالطَّشْتُ', #1
u'والطشت': u'وَالطَّشْتِ', #5
u'والططماج': u'وَالطَّطْمَاجِ', #4
u'والطعين': u'وَالطَّعِينُ', #1
u'والطغام': u'وَالطَّغَامِ', #2
u'والطفى': u'وَالطُّفَى', #2
u'والطفية': u'وَالطُّفْيَةُ', #3
u'والطفيتان': u'وَالطُّفْيَتَانِ', #1
u'والطفيتين': u'وَالطُّفْيَتَيْنِ', #1
u'والطفيل،': u'والطُّفيل،', #1
u'والطفيل': u'والطُّفَيْل', #1
u'والطفيل': u'وَالطّفَيْلُ', #12
u'والطفيل': u'والطفيل', #2
u'والطفيل': u'وَالطّفَيْلَ', #2
u'والطفيل': u'وَالطُّفَيْلُ', #7
u'والطلا': u'وَالطَّلَا', #2
u'والطلاطلة': u'وَالطّلَاطِلَةُ', #2
u'والطلبقة': u'وَالطَّلْبَقَةُ', #1
u'والطلبقة': u'وَالطَّلْبَقَةِ', #1
u'والطليع': u'وَالطَّلِيعُ', #1
u'والطمرس': u'وَالطِّمْرِسَ', #1
u'والطمرس': u'وَالطِّمْرِسُ', #1
u'والطمطام': u'وَالطَّمْطَامَ', #1
u'والطمطام': u'وَالطِّمْطَامَ', #1
u'والطمل': u'وَالطّمْلُ', #2
u'والطملال': u'وَالطّمْلَالُ', #1
u'والطنابر': u'وَالطَّنَابِرُ', #1
u'والطنبار': u'وَالطِّنْبَارُ', #2
u'والطندتائي': u'والطندتائي', #1
u'والطنيزي': u'وَالطُّنَيْزِيِّ', #1
u'والطهران': u'وَالطُّهْرَانِ', #3
u'والطهيان': u'وَالطَّهَيَانُ', #1
u'والطواشي': u'وَالطَّوَاشِيُّ', #1
u'والطواشية': u'وَالطَّوَاشِيَّةِ', #1
u'والطوطي': u'وَالطُّوطِيُّ', #1
u'والطونجة': u'والطونجة', #1
u'والطياب': u'وَالطِّيَابُ', #1
u'والطياب': u'وَالطِّيَابِ', #1
u'والطيابادي': u'وَالطَّيَابَادِيِّ', #1
u'والطيالسي': u'وَالطَّيَالِسِيِّ', #1
u'والطيالسي،': u'وَالطَّيَالِسِيُّ،', #1
u'والطيالسي': u'وَالطَّيَالِسِيُّ', #12
u'والطيل': u'وَالطِّيَلُ', #1
u'والطيئ': u'والطيئ', #1
u'والظبا': u'وَالظُّبَا', #1
u'والظبينا': u'وَالظّبِينَا', #1
u'والظبينا': u'وَالظّبَيْنَا', #1
u'وألظت': u'وَأَلَظّتْ', #2
u'والظريب': u'وَالظّرَيْبُ', #1
u'والظما': u'وَالظَّمَا', #1
u'والظئر': u'وَالظِّئْرَ', #1
u'والظئر': u'وَالظِّئْرِ', #12
u'والظئر': u'وَالظِّئْرُ', #4
u'والظئورة': u'وَالظُّئُورَةِ', #1
u'والعاب': u'وَالُعَابُ', #1
u'والعاب': u'وَالْعَابُ', #1
u'والعابدية': u'وَالْعَابِدِيَّةِ', #1
u'والعادلي': u'وَالْعَادِلِيُّ', #1
u'والعادلية': u'وَالْعَادِلِيَّةِ', #1
u'والعارضية': u'وَالْعَارِضِيَّةِ', #1
u'والعاص،': u'وَالْعَاصُ،', #1
u'والعاص': u'وَالْعَاصِ', #10
u'والعاص': u'وَالْعَاصُ', #21
u'والعاصدية': u'والعاصدية', #1
u'والعاضه': u'وَالْعَاضِهُ', #1
u'والعاطب': u'وَالْعَاطِبِ', #1
u'والعاطش': u'وَالْعَاطِشِ', #1
u'والعانى': u'وَالْعَانِى', #2
u'والعائذي': u'وَالْعَائِذِيّ', #1
u'والعائف': u'وَالْعَائِفُ', #1
u'والعائن': u'وَالْعَائِنُ', #2
u'والعبادلة': u'وَالْعَبَادِلَةَ', #1
u'والعبادلة': u'وَالْعَبَادِلَةِ', #15
u'والعبادلة': u'وَالْعَبَادِلَةُ', #4
u'والعبالة': u'وَالْعَبَالَةُ', #1
u'والعبدانية': u'وَالْعَبْدَانِيَّةُ', #1
u'والعبدانية': u'وَالْعَبْدَانِيَّةِ', #2
u'والعبدري': u'وَالْعَبْدَرِيُّ', #2
u'والعبدوسي': u'وَالْعَبْدُوسِيُّ', #1
u'والعبشميون': u'والعبشميون', #1
u'والعبلة': u'وَالْعَبْلَةُ', #2
u'والعبهر': u'وَالْعَبْهَرُ', #1
u'والعبيتران': u'وَالْعُبَيْتِرَانِ', #1
u'والعتاقه': u'وَالْعَتَاقَهْ', #2
u'والعتائر': u'وَالْعَتَائِرُ', #2
u'والعتر': u'وَالْعَتْرُ', #1
u'والعتر': u'وَالْعِتَرُ', #1
u'والعتر': u'وَالْعِتْرِ', #1
u'والعتر': u'وَالْعِتَرِ', #2
u'والعتقاء': u'وَالْعَتْقَاءُ', #1
u'والعتقاء': u'وَالْعُتَقَاءَ', #1
u'والعتقاء': u'وَالْعُتَقَاءِ', #4
u'والعتقاء': u'وَالْعُتَقَاءُ', #7
u'والعتود،': u'والعتود،', #1
u'والعتود': u'وَالْعَتُودُ', #1
u'والعتودة': u'وَالْعَتْوَدَةُ', #1
u'والعتيبة': u'وَالْعُتَيْبَة', #1
u'والعتيرة': u'والعتيرة', #1
u'والعتيرة': u'وَالْعَتِيرَةِ', #16
u'والعتيرة': u'وَالْعَتِيرَة', #2
u'والعتيرة': u'وَالْعَتِيرَةَ', #2
u'والعتيرة،': u'وَالْعَتِيرَةِ،', #2
u'والعتيرة': u'وَالْعَتِيرَةُ', #27
u'والعثاكل': u'وَالْعَثَاكِلُ', #1
u'والعثانين': u'وَالْعَثَانِينُ', #1
u'والعثرى': u'وَالْعَثَرِىُّ', #1
u'والعثكال': u'وَالْعُثْكَالِ', #2
u'والعثكال': u'وَالْعِثْكَالُ', #4
u'والعثل': u'وَالْعَثَلُ', #1
u'والعثواء': u'وَالْعَثْوَاءُ', #1
u'والعجاجيل': u'وَالْعَجَاجِيلُ', #10
u'والعجاجيل': u'وَالْعَجَاجِيلِ', #13
u'والعجاجيل': u'وَالْعَجَاجِيلَ', #2
u'والعجاية': u'وَالْعُجَايَةُ', #1
u'والعجلاني': u'وَالْعَجْلَانِيُّ', #4
u'والعجلوني': u'وَالْعَجْلُونِيُّ', #1
u'والعجور': u'وَالْعَجُّورَ', #1
u'والعجور': u'وَالْعَجُّورُ', #2
u'والعجور': u'وَالْعَجُّورِ', #2
u'والعجيف': u'وَالْعَجِيفُ', #1
u'والعدات': u'وَالْعِدَّاتُ', #1
u'والعدالى': u'وَالْعَدَالَى', #1
u'والعدامل': u'وَالْعُدَامِلُ', #1
u'والعداملي': u'وَالْعُدَامِلِيّ', #1
u'والعدناني': u'وَالْعَدْنَانِيُّ', #1
u'والعدواة': u'وَالْعَدَوَاةِ', #1
u'والعذرتاق': u'والعذرتاق', #1
u'والعذوب': u'وَالْعَذُوبُ', #1
u'والعذى': u'وَالْعِذْىُّ', #2
u'والعذيب': u'وَالْعُذَيْبُ', #1
u'والعذيب،': u'وَالْعُذَيْبِ،', #1
u'والعذير': u'وَالْعَذِيرُ', #1
u'والعذيطة': u'والعذيطة', #1
u'والعذيطة': u'وَالْعَذْيْطَةُ', #1
u'والعذيطة': u'وَالْعَذْيَطَةُ', #2
u'والعرابي': u'وَالْعِرَابِيُّ', #1
u'والعرادات': u'وَالْعَرّادَاتِ', #1
u'والعراصة': u'وَالْعَرّاصَةُ', #1
u'والعراقب': u'وَالْعَرَاقِبَ', #1
u'والعرباض': u'وَالْعِرْبَاضَ', #1
u'والعرباض،': u'وَالْعِرْبَاضِ،', #1
u'والعرباض': u'وَالْعِرْبَاضُ', #2
u'والعرباض': u'وَالْعِرْبَاضِ', #2
u'والعربد': u'وَالْعِرْبَدُّ', #1
u'والعربى': u'وَالْعَرَبِىُّ', #1
u'والعربى': u'وَالْعَرَبِىِّ', #1
u'والعرزمى': u'وَالْعَرْزَمِىُّ', #1
u'والعرزمي': u'وَالْعَرْزَمِيُّ', #4
u'والعرفا': u'وَالْعُرْفَا', #1
u'والعرقبة': u'وَالْعَرْقَبَةِ', #1
u'والعرقبة': u'وَالْعَرْقَبَةَ', #3
u'والعرقبة': u'وَالْعَرْقَبَةُ', #3
u'والعرقسوس': u'وَالْعِرْقِسُوسِ', #2
u'والعرقوة': u'وَالْعَرْقُوَةِ', #1
u'والعركي': u'وَالْعَرَكِيُّ', #1
u'والعرمس': u'وَالْعِرْمِسُ', #1
u'والعرنجج': u'وَالْعَرَنْجَجُ', #1
u'والعرنجج': u'والعَرَنْجَج', #2
u'والعرنيين': u'وَالْعُرَنِيِّينَ', #1
u'والعرواء': u'وَالْعُرَوَاءُ', #1
u'والعروف': u'وَالْعَرُوفِ', #1
u'والعزةSشعر': u'وَالْعِزّةِSشِعْرُ', #1
u'والعزقة': u'وَالْعَزْقَةُ', #1
u'والعزوز': u'وَالْعَزُوزُ', #1
u'والعزومة': u'وَالْعُزُومَةُ', #1
u'والعزير': u'وَالْعُزَيْر', #1
u'والعزير': u'وَالْعُزَيْرِ', #4
u'والعزيزي': u'وَالْعَزِيزِيِّ', #1
u'والعزيزي': u'وَالْعَزِيزِيُّ', #4
u'وألعس': u'وَأَلْعَسُ', #1
u'والعسار': u'وَالْعِسَارِ', #4
u'والعسب': u'وَالْعُسُبُ', #2
u'والعسب': u'وَالْعَسْبُ', #4
u'والعسب': u'وَالْعُسُبِ', #5
u'والعسبار': u'وَالْعِسْبَارِ', #3
u'والعسفاء': u'وَالْعُسَفَاءُ', #1
u'والعسفاء': u'وَالْعُسَفَاءِ', #1
u'والعسقلاني،': u'وَالْعَسْقَلانِيُّ،', #1
u'والعسقلاني': u'وَالْعَسْقَلَانِيُّ', #1
u'والعسقلاني': u'وَالْعَسْقَلَانِيِّ', #1
u'والعسم': u'وَالْعَسَمُ', #10
u'والعسيب': u'وَالْعَسِيبِ', #4
u'والعسيراء': u'وَالْعُسَيْرَاءُ', #1
u'والعسيراء': u'وَالْعُسَيْرَاءِ', #1
u'والعسيف': u'وَالْعَسِيفُ', #8
u'والعسيلة': u'وَالْعُسَيْلَةِ', #1
u'والعشماوي': u'وَالْعَشْمَاوِيُّ', #5
u'والعشى': u'وَالْعَشَى', #4
u'والعشى': u'وَالْعَشِىِّ', #4
u'والعشيراء': u'وَالْعُشَيْرَاءُ', #1
u'والعشيرالزوج': u'وَالْعَشِيرُالزَّوْجُ', #1
u'والعصا': u'وَالْعَصًا', #1
u'والعصامير': u'وَالْعَصَامِيرُ', #1
u'والعصايد': u'وَالْعَصَايِدِ', #1
u'والعصروروي': u'وَالْعَصْرُوَرُوِيَ', #1
u'والعصفر': u'وَالْعُصْفُرُ', #17
u'والعصفر': u'وَالْعُصْفُرِ', #38
u'والعصفر': u'وَالْعُصْفُرَ', #6
u'والعصوبة': u'وَالْعُصُوبَةُ', #12
u'والعصوبة': u'وَالْعُصُوبَةَ', #2
u'والعصوبة': u'وَالْعُصُوبَةِ', #30
u'والعصى': u'وَالْعُصِىَّ', #1
u'والعصى،': u'وَالْعَصَى،', #1
u'والعصى': u'وَالْعَصَى', #2
u'والعصى': u'وَالْعِصِىِّ', #2
u'والعضابة': u'وَالْعَضَّابَة', #1
u'والعضابة': u'وَالْعَضَّابَةِ', #1
u'والعضاه': u'وَالْعِضَاهِ', #1
u'والعضاه': u'وَالْعِضَاهُ', #2
u'والعضائد': u'وَالْعَضَائِدِ', #2
u'والعضايد': u'وَالْعَضَايِدِ', #1
u'والعضب': u'وَالْعَضْبِ', #4
u'والعضباء': u'وَالْعَضْبَاءَ', #1
u'والعضباء': u'وَالْعَضْبَاءُ', #4
u'والعضه': u'وَالْعَضْهُ', #3
u'والعضيوط': u'وَالْعِضْيَوْطُ', #1
u'والعطارون': u'وَالْعَطَّارُونَ', #2
u'والعطارين': u'وَالْعَطَّارِينَ', #5
u'والعطافة': u'وَالْعَطَّافَةِ', #1
u'والعطن': u'وَالْعَطَنُ', #8
u'والعطيات': u'وَالْعَطِيّاتُ', #2
u'والعظاية': u'وَالْعَظَايَةُ', #1
u'والعظاية': u'وَالْعَظَايَةِ', #1
u'والعفاص': u'وَالْعِفَاصَ', #1
u'والعفاص': u'وَالْعِفَاصِ', #3
u'والعفاص': u'وَالْعِفَاصُ', #6
u'والعفص': u'وَالْعَفَصُ', #1
u'والعفص': u'وَالْعَفَصِ', #1
u'والعفص': u'وَالْعَفْصُ', #2
u'والعفص': u'وَالْعَفْصِ', #22
u'والعفل': u'وَالْعَفْلِ', #1
u'والعفل': u'وَالْعَفَلِ', #11
u'والعفل': u'وَالْعَفْلُ', #2
u'والعفل': u'وَالْعَفَلُ', #20
u'والعفل': u'وَالْعَفَلَ', #4
u'والعفلاء': u'وَالْعَفْلَاءِ', #1
u'والعفلاء': u'وَالْعَفْلاَءَ', #1
u'والعفلاء': u'وَالْعَفْلاَءُ', #1
u'والعفلاء': u'وَالْعَفْلَاءُ', #2
u'والعفلة': u'وَالْعَفْلَةُ', #1
u'والعفلة': u'وَالْعَفَلَةُ', #2
u'والعفوصة': u'وَالْعُفُوصَةِ', #4
u'والعفين': u'وَالْعَفِينِ', #1
u'والعقاص': u'وَالْعِقَاصُ', #3
u'والعقائص': u'وَالْعَقَائِصُ', #1
u'والعقباني': u'وَالْعَقَبَانِيُّ', #1
u'والعقباني': u'وَالْعُقْبَانِيُّ', #1
u'والعقدى': u'وَالْعَقَدِىِّ', #1
u'والعقصة': u'وَالْعِقْصَةُ', #1
u'والعقنقل': u'وَالْعَقَنْقَلُ', #1
u'والعقودا': u'وَالْعُقُودَا', #1
u'والعقيبة': u'وَالْعُقَيْبَةُ', #1
u'والعقيل': u'وَالْعُقَيْل', #1
u'والعكاش': u'وَالْعُكّاشُ', #1
u'والعكبري': u'وَالْعُكْبَرِيُّ', #4
u'والعكلي': u'وَالْعُكْلِيِّ', #1
u'والعكنة': u'وَالْعُكْنَة', #1
u'والعكوس': u'وَالْعُكُوسُ', #2
u'والعكوم': u'وَالْعُكُومُ', #1
u'والعلاثة': u'وَالْعُلَاثَةُ', #1
u'والعلاق': u'وَالْعَلَاق', #1
u'والعلاق': u'وَالْعَلَاقُ', #3
u'والعلامية': u'وَالْعَلَّامِيَّةِ', #1
u'والعلانيةالوجه': u'وَالْعَلانِيَةِالْوَجْهُ', #1
u'والعلث': u'وَالْعَلْثِ', #1
u'والعلث': u'وَالْعَلْثُ', #3
u'والعلجة': u'وَالْعِلْجَةَ', #1
u'والعلجة': u'وَالْعِلْجَةِ', #1
u'والعلس': u'وَالْعَلَسْ', #1
u'والعلس': u'وَالْعَلَسِ', #27
u'والعلس': u'وَالْعَلْسِ', #3
u'والعلس': u'وَالْعَلَسَ', #6
u'والعلس': u'وَالْعَلَسُ', #8
u'والعلس': u'وَالْعَلْسُ', #8
u'والعلطتان': u'وَالْعَلْطَتَانِ', #1
u'والعلقمة': u'وَالْعَلْقَمَةِ', #1
u'والعلما': u'وَالْعُلَمَا', #1
u'والعلهز': u'وَالْعِلْهِزِ', #1
u'والعلوتين': u'وَالْعُلْوَتَيْنِ', #1
u'والعلوز': u'وَالْعِلَّوْزِ', #1
u'والعلوص': u'وَالْعِلَّوْصَ', #1
u'والعلوص': u'وَالْعِلَّوْصِ', #10
u'والعلوص': u'وَالْعِلَّوْصُ', #3
u'والعلوفات': u'وَالْعُلُوفَاتِ', #1
u'والعلوفة': u'وَالْعَلُوفَةَ', #1
u'والعلوفة': u'وَالْعَلُوفَةِ', #12
u'والعلوفة': u'وَالْعُلُوفَةُ', #3
u'والعلوفة': u'وَالْعُلُوفَةِ', #4
u'والعلوفة': u'وَالْعَلُوفَةُ', #5
u'والعماس': u'وَالْعِمَاسُ', #1
u'والعمالين': u'وَالْعَمَّالِينَ', #1
u'والعمرو': u'وَالْعَمْرُو', #1
u'والعمرى': u'والعُمْرَى', #1
u'والعمرى': u'وَالْعُمْرَى', #74
u'والعمشان': u'وَالْعُمْشَانِ', #1
u'والعنابل': u'وَالْعُنَابِلُ', #1
u'والعنبس': u'وَالْعَنْبَسُ', #1
u'والعنة': u'وَالْعُنَّة', #1
u'والعنة': u'وَالْعُنَّةِ', #138
u'والعنة': u'وَالْعُنَّةُ', #37
u'والعنة': u'وَالْعُنَّةَ', #5
u'والعنجدة': u'وَالْعُنْجُدَةُ', #1
u'والعندية': u'وَالْعِنْدِيَّةُ', #1
u'والعنسي': u'وَالْعَنْسِيّ', #1
u'والعنسى': u'وَالْعَنْسِىِّ', #1
u'والعنفوة': u'وَالْعُنْفُوَةُ', #2
u'والعنوي': u'وَالْعَنَوِيُّ', #10
u'والعنوية': u'وَالْعَنْوِيَّةُ', #1
u'والعنين': u'وَالْعِنِّينَ', #3
u'والعنين': u'وَالْعِنِّينُ', #53
u'والعنين': u'وَالْعِنِّينِ', #72
u'والعنينة': u'وَالْعِنِينَةِ', #1
u'والعنينة': u'وَالْعِنِّينَةُ', #1
u'والعواتك': u'وَالْعَوَاتِكُ', #1
u'والعوار،': u'وَالْعَوَارِ،', #1
u'والعوار': u'وَالْعَوَارُ', #4
u'والعواطي': u'وَالْعَوَاطِي', #1
u'والعوالى': u'وَالْعَوَالِى', #1
u'والعوانة': u'وَالْعَوَانَةَ', #1
u'والعواني': u'وَالْعَوَانِيِّ', #1
u'والعوة': u'وَالْعَوّةُ', #1
u'والعوذى': u'وَالْعَوْذِىُّ', #1
u'والعورجي': u'وَالْعَوْرَجِيُّ', #1
u'والعوفي': u'وَالْعُوفِيِّ', #1
u'والعوفي': u'وَالْعُوفِيُّ', #3
u'والعى': u'وَالْعَىَّ', #1
u'والعياثة': u'وَالْعِيَاثَةِ', #1
u'والعيارة': u'وَالْعِيَارَةُ', #1
u'والعيارون': u'وَالْعَيَّارُونَ', #1
u'والعيافة': u'وَالْعِيَافَةَ', #1
u'والعيافة': u'وَالْعِيَافَةِ', #1
u'والعيافة': u'وَالْعِيَافَةُ', #4
u'والعيالات،': u'وَالْعِيَالاتِ،', #1
u'والعيبة': u'وَالْعَيْبَةُ', #2
u'والعيبة': u'وَالْعَيْبَةِ', #2
u'والعيدا': u'وَالْعِيدَا', #1
u'والعيزار': u'والعَيْزَار', #1
u'والعيزار': u'والعيزار', #2
u'والعيزار': u'وَالْعَيْزَارُ', #2
u'والعيس': u'وَالْعِيسُ', #2
u'والعيسوي': u'وَالْعِيسَوِيُّ', #1
u'والعيسوية': u'وَالْعِيسَوِيَّةُ', #3
u'والعيص': u'وَالْعِيصُ', #1
u'والعيص': u'وَالْعَيْصُ', #2
u'والعيهب': u'وَالْعَيْهَبُ', #3
u'والعيوق': u'وَالْعَيُّوقِ', #1
u'والعيونا': u'وَالْعُيُونَا', #1
u'والعيونا': u'وَالْعَيُونَا', #2
u'والغابن': u'وَالْغَابِنُ', #2
u'والغاريقون': u'وَالْغَارِيقُونَ', #1
u'والغالط': u'وَالْغَالِطَ', #1
u'والغالط': u'وَالْغَالِطِ', #1
u'والغالط': u'وَالْغَالِطُ', #3
u'والغامدية': u'وَالْغَامِدِيَّةَ', #21
u'والغامدية': u'وَالْغَامِدِيَّةِ', #22
u'والغامدية': u'وَالْغَامِدِيَّةُ', #9
u'والغامي': u'وَالْغَامِي', #1
u'والغبريني': u'وَالْغُبْرِينِيُّ', #4
u'والغبط': u'وَالْغُبُطُ', #1
u'والغبغب': u'وَالْغَبْغَبُ', #2
u'والغبوق': u'والغبوق', #1
u'والغبوق': u'وَالْغَبُوقُ', #1
u'والغبوق': u'وَالْغُبُوقُ', #1
u'والغبيراء': u'وَالْغُبَيْرَاءُ', #3
u'والغبيراء': u'وَالْغُبَيْرَاءِ', #4
u'والغبيراء': u'وَالْغُبَيْرَاءَ', #7
u'والغداف': u'وَالْغُدَافِ', #2
u'والغداف': u'وَالْغُدَافُ', #7
u'والغربا': u'وَالْغُرَبَا', #2
u'والغرث': u'وَالْغَرَثُ', #1
u'والغرقا': u'والغرقا', #1
u'والغرلة': u'وَالْغُرْلَةُ', #1
u'والغروان': u'وَالْغَرَوَانِ', #1
u'والغريف': u'وَالْغَرِيفُ', #1
u'والغزر': u'وَالْغَزْرُ', #1
u'والغزى': u'وَالْغُزَّى', #1
u'والغزى': u'وَالْغَزِّىُّ', #2
u'والغسيسة': u'وَالْغَسِيسَةُ', #1
u'والغشواء': u'وَالْغَشْوَاءُ', #1
u'والغصوب': u'وَالْغُصُوبَ', #1
u'والغصوب': u'وَالْغُصُوبِ', #38
u'والغصوب': u'وَالْغُصُوبُ', #5
u'والغصوبات': u'وَالْغُصُوبَاتِ', #1
u'والغصوص': u'وَالْغُصُوصِ', #1
u'والغضارين': u'وَالغَضّارِينَ', #1
u'والغضنفر': u'وَالْغَضَنْفَرُ', #2
u'والغطريفي': u'وَالْغِطْرِيفِيُّ', #2
u'والغطفاني': u'وَالْغَطَفَانِيّ', #1
u'وألغطوا': u'وَأَلْغَطُوا', #2
u'والغفالغة': u'وَالْغَفَالِغَةُ', #1
u'والغلابي،': u'وَالْغُلَابِيُّ،', #1
u'والغلاق': u'وَالْغِلَاقِ', #1
u'والغلت': u'وَالْغَلَتِ', #1
u'والغلت': u'وَالْغَلْتِ', #1
u'والغلث': u'وَالْغَلَثَ', #2
u'والغلث': u'وَالْغَلَثُ', #2
u'والغلث': u'وَالْغَلْثُ', #2
u'والغلث': u'وَالْغَلَثِ', #3
u'والغلث': u'وَالْغَلْثِ', #3
u'والغلصات': u'وَالْغَلَصَاتِ', #1
u'والغلصمة': u'وَالْغَلْصَمَةُ', #1
u'والغلوة': u'وَالْغَلْوَةُ', #8
u'والغماد': u'وَالْغِمَادُ', #1
u'والغمرا': u'وَالْغَمْرَا', #2
u'والغمغام': u'وَالْغِمْغَامَ', #1
u'والغموس': u'وَالْغَمُوسَ', #1
u'والغموس': u'وَالْغُمُوسِ', #1
u'والغموس': u'وَالْغَمُوسُ', #13
u'والغموس': u'وَالْغَمُوسِ', #9
u'والغميصاء': u'وَالْغُمَيْصَاء', #1
u'والغميم': u'وَالْغَمِيم', #2
u'والغنط': u'وَالْغَنَطُ', #1
u'والغنمة': u'وَالْغَنَمَة', #1
u'والغنن': u'وَالْغَنَنِ', #1
u'والغنيم': u'وَالْغَنِيمُ', #1
u'والغنيمات': u'وَالْغُنَيْمَاتِ', #1
u'والغوج': u'وَالْغَوْجُ', #1
u'والغوراء': u'وَالْغَوْرَاءُ', #1
u'والغورى': u'وَالْغَوْرَى', #3
u'والغوفل': u'والغوفل', #1
u'والغوير': u'وَالْغُوَيْرُ', #1
u'والغياص': u'وَالْغِيَاصُ', #1
u'والغياصة': u'وَالْغِيَاصَةَ', #1
u'والغياطل': u'وَالْغَيَاطِل', #1
u'والغياطل': u'وَالْغَيَاطِلُ', #2
u'والغياطل': u'وَالْغَيَاطِلِ', #5
u'والغيداق': u'وَالْغَيْدَاقُ', #2
u'والغيدق': u'وَالْغَيْدَقُ', #1
u'والغيطلة': u'وَالْغَيْطَلَةُ', #5
u'والغيل': u'والْغَيْلُ', #1
u'والغيل': u'وَالْغَيْلِ', #1
u'وإلفاته': u'وَإِلْفَاتِهِ', #1
u'والفاثور': u'وَالْفَاثُورُ', #1
u'والفاجة': u'وَالْفَاجَّةُ', #1
u'والفاحشية': u'وَالْفَاحِشِيَّةِ', #1
u'والفاخت': u'وَالْفَاخِتِ', #1
u'والفاخت': u'وَالْفَاخِتُ', #2
u'والفاختة': u'وَالْفَاخِتَةُ', #3
u'والفاختة': u'وَالْفَاخِتَةِ', #5
u'والفارابي': u'وَالْفَارَابِيَّ', #1
u'والفارابي': u'وَالْفَارَابِيِّ', #1
u'والفارابي': u'وَالْفَارَابِيُّ', #2
u'والفارقي': u'وَالْفَارِقِيِّ', #1
u'والفارقي': u'وَالْفَارِقِيُّ', #10
u'والفارياب،': u'والفارياب،', #1
u'والفاس': u'وَالْفَاسُ', #1
u'والفاطمه': u'وَالْفَاطِمَهْ', #1
u'والفاغية': u'وَالْفَاغِيَةُ', #1
u'والفاغية': u'وَالْفَاغِيَةِ', #1
u'والفأفاء': u'وَالْفَأْفَاءِ', #7
u'والفأفاء': u'وَالْفَأْفَاءُ', #8
u'والفأفأة': u'وَالْفَأْفَأَةِ', #2
u'والفأفأة': u'وَالْفَأْفَأَةُ', #3
u'والفاقوم': u'وَالْفَاقُومِ', #1
u'والفاقئ': u'وَالْفَاقِئُ', #4
u'والفاكهى': u'وَالْفَاكِهِىِّ', #1
u'والفالوذق': u'وَالْفَالُوذَقُ', #1
u'والفامي': u'وَالْفَامِيِّ', #2
u'والفانيد': u'وَالْفَانِيدِ', #20
u'والفانيد': u'وَالْفَانِيدُ', #8
u'والفانيذ': u'والفانيذ', #1
u'والفانيذ': u'وَالْفَانِيذُ', #1
u'والفانيذ': u'وَالْفَانِيذَ', #3
u'والفانيذ': u'وَالْفَانِيذِ', #8
u'والفتال': u'وَالْفَتَّالُ', #1
u'والفتال': u'وَالْفَتَّالِ', #3
u'والفتايا': u'وَالْفَتَايَا', #1
u'والفتخات': u'وَالْفَتَخَاتُ', #2
u'والفتخة': u'وَالْفَتَخَةُ', #1
u'والفتخة': u'وَالْفَتْخَةُ', #3
u'والفتيا،': u'وَالْفُتْيَا،', #1
u'والفتيا': u'وَالْفُتْيَا', #65
u'وألفج': u'وَأَلْفَجُ', #1
u'وألفج': u'وَأَلْفَجَ', #3
u'والفجيعه': u'وَالْفَجِيعَهْ', #1
u'والفحج': u'وَالْفَحَجِ', #1
u'والفحج': u'وَالْفَحَجُ', #6
u'والفحيل': u'وَالْفَحِيل', #1
u'والفحيل': u'وَالْفَحِيلُ', #1
u'والفحيل': u'وَالْفُحَيْلِ', #1
u'والفدر': u'وَالْفُدُرُ', #1
u'والفدور': u'وَالْفَدُورُ', #1
u'والفرأ': u'وَالْفَرَأُ', #1
u'والفرا': u'وَالْفِرَا', #3
u'والفرآء': u'والفرآء', #1
u'والفرازية': u'والفرازية', #1
u'والفرافصة': u'وَالْفُرَافِصَةُ', #1
u'والفراك': u'وَالْفِرَاكُ', #2
u'والفرانين': u'وَالْفَرَّانِينَ', #1
u'والفرائع': u'وَالْفَرَائِعُ', #1
u'والفراية': u'وَالْفِرَايَةِ', #1
u'والفرتاج': u'وَالْفِرْتَاجُ', #1
u'والفرسطون': u'وَالْفرسطون', #1
u'والفرسك': u'وَالْفِرْسِكُ', #1
u'والفرسك': u'وَالْفِرْسِكِ', #7
u'والفرسن': u'وَالْفِرْسِنُ', #1
u'والفرصاد': u'وَالْفِرْصَادُ', #2
u'والفرصاد': u'وَالْفِرْصَادَ', #3
u'والفرصاد': u'وَالْفِرْصَادِ', #3
u'والفرغانية': u'والفرغانية', #1
u'والفرقبي': u'والفرقبي', #1
u'والفرنساوي': u'والْفَرَنْسَاوِيِّ', #1
u'والفرنساوية': u'والفَرَنْساوِيَّةُ', #1
u'والفرنسيس': u'وَالْفِرِنْسِيسِ', #1
u'والفروعات': u'وَالْفُرُوعَاتِ', #1
u'والفروعية': u'وَالْفُرُوعِيَّةِ', #4
u'والفروى': u'وَالْفَرَوِىُّ', #1
u'والفروى': u'وَالْفَرْوِىُّ', #1
u'والفريابي،': u'والفريابي،', #1
u'والفريابي،': u'وَالْفِرْيَابِيِّ،', #1
u'والفريابي': u'وَالْفِرْيَابِيُّ', #2
u'والفريابى': u'وَالْفِرْيَابِىُّ', #2
u'والفريابي،': u'وَالْفِرْيَابِيُّ،', #4
u'والفريقة': u'وَالْفَرِيقَةُ', #1
u'والفزاري': u'وَالْفَزَارِيُّ', #1
u'والفزارى': u'وَالْفَزَارِىُّ', #1
u'والفزاري': u'وَالْفَزَارِيِّ', #2
u'والفسطاس': u'وَالْفُسْطَاسُ', #1
u'والفسكل': u'وَالْفِسْكِلُ', #2
u'والفسوخ': u'وَالْفُسُوخِ', #103
u'والفسوخ': u'وَالْفُسُوخَ', #3
u'والفسوخ': u'وَالْفُسُوخُ', #5
u'والفسوي،': u'والفسوي،', #1
u'والفسوي': u'وَالْفَسَويُّ', #1
u'والفسية': u'وَالْفُسَيَّةَ', #1
u'والفسيل': u'وَالْفَسِيلُ', #2
u'والفشار': u'وَالْفَشَارِ', #1
u'والفصادة': u'وَالْفَصَادَةَ', #1
u'والفصادة': u'وَالْفَصَادَةُ', #1
u'والفصادة': u'وَالْفَصَادَةِ', #2
u'والفصادة': u'وَالْفِصَادَةُ', #2
u'والفصولين': u'وَالْفُصُولَيْنِ', #54
u'والفصيله': u'وَالْفَصِيلَهْ', #1
u'والفضتان': u'وَالْفِضَّتَانِ', #1
u'والفضتين': u'وَالْفِضَّتَيْنِ', #1
u'والفضخ': u'وَالْفَضْخُ', #2
u'والفضيخ': u'وَالْفَضِيخَ', #1
u'والفضيخ': u'وَالْفَضِيخُ', #10
u'والفضيلية': u'وَالْفُضَيْلِيَّةُ', #1
u'والفطره': u'وَالْفِطْرَهْ', #1
u'والفطيس': u'وَالْفِطِّيسُ', #1
u'والفطيون': u'وَالْفِطْيَوْنُ', #1
u'والفعلى': u'وَالْفَعَلَى', #1
u'والفعيل': u'وَالْفَعِيلُ', #1
u'والفغو': u'وَالْفَغْوُ', #1
u'والفقء': u'وَالْفَقْءَ', #1
u'والفقء': u'وَالْفَقْءُ', #1
u'والفقء': u'وَالْفَقْءِ', #2
u'والفقاط': u'وَالْفَقَّاطُ', #1
u'والفقة': u'والفقة', #1
u'والفقرا': u'وَالْفُقَرَا', #1
u'والفقمان': u'وَالْفَقْمَانِ', #1
u'والفقوسة': u'وَالْفَقُّوسَةُ', #1
u'والفقوص': u'وَالْفَقُّوصُ', #1
u'والفقيرا': u'وَالْفَقِيرَا', #2
u'والفقيمية': u'وَالْفَقِيمِيّةُ', #1
u'والفقيمية': u'وَالْفُقَيْمِيّةُ', #1
u'والفكرى': u'وَالْفِكْرَى', #2
u'والفلاء': u'وَالْفِلَاءُ', #2
u'والفلاس': u'والفلّاس', #1
u'والفلاس': u'والفلَّاس', #1
u'والفلاس': u'وَالْفَلَّاسِ', #1
u'والفلاس': u'والفلاس', #2
u'والفلاس،': u'وَالْفَلَّاسُ،', #5
u'والفلاس': u'وَالْفَلَّاسُ', #8
u'والفلو': u'وَالْفَلُوّ', #1
u'والفلو': u'وَالْفَلُوُّ', #1
u'والفلو': u'وَالْفُلُوُّ', #1
u'والفليل': u'وَالْفَلِيلُ', #1
u'والفنادقة': u'وَالْفَنَادِقَةِ', #1
u'والفنجات': u'وَالْفَنَجَاتُ', #1
u'والفنجانات': u'والفنجانات', #1
u'والفندقلي': u'وَالْفُنْدُقْلِيَّ', #1
u'والفندقلي': u'وَالْفُنْدُقْلِيُّ', #1
u'والفندقلي': u'وَالْفُنْدُقْلِيِّ', #2
u'والفنطسة': u'وَالْفِنْطِسَةُ', #1
u'والفنع': u'وَالْفَنَعُ', #1
u'والفهر': u'وَالْفِهْرُ', #1
u'والفهري': u'وَالْفِهْرَيْ', #1
u'والفهري': u'وَالْفِهْرِيُّ', #1
u'والفهري': u'وَالْفِهْرِيّ', #3
u'والفهوم': u'وَالْفُهُومُ', #1
u'والفهوم': u'وَالْفُهُومِ', #5
u'والفواخت': u'وَالْفَوَاخِتِ', #1
u'والفواخت': u'وَالْفَوَاخِتُ', #3
u'والفواخيت': u'وَالْفَوَاخِيتُ', #1
u'والفواشي': u'وَالْفَوَاشِي', #1
u'والفوائت': u'وَالْفَوَائِتِ', #13
u'والفوائت': u'وَالْفَوَائِتُ', #7
u'والفوس': u'وَالْفُوسُ', #1
u'والفوقيه': u'والفَوْقِيَّهْ', #1
u'والفوقيه': u'وَالْفَوْقِيهْ', #1
u'والفولة': u'والْفُولَةِ', #1
u'والفولة': u'وَالْفُولَةِ', #2
u'والفويسقة': u'وَالْفُوَيْسِقَة', #1
u'والفويسقة': u'وَالْفُوَيْسِقَةُ', #2
u'والفويسقة': u'وَالْفُوَيْسِقَةَ', #8
u'والفئ': u'وَالْفَئُ', #1
u'والفىء': u'وَالْفَىْءِ', #3
u'والفىء': u'وَالْفَىْءُ', #4
u'والفيال': u'وَالْفِيَالُ', #1
u'والفيج': u'وَالْفَيْجِ', #1
u'والفيج': u'وَالْفَيْجُ', #2
u'والفيروزج': u'وَالْفَيْرُوزَجِ', #28
u'والفيروزج': u'وَالْفَيْرُوزَجُ', #8
u'والفيشلة': u'وَالْفَيْشَلَةَ', #1
u'والفيف': u'وَالْفَيْفُ', #1
u'والفيلج': u'وَالْفَيْلَجُ', #2
u'والفيوم': u'والفيوم', #1
u'والفيوم': u'وَالْفَيُّومِ', #2
u'وألقاء': u'وَأَلْقَاءُ', #1
u'والقاء': u'وَالِقَاءِ', #2
u'والقابسي': u'وَالْقَابِسِيّ', #1
u'والقابسي': u'وَالْقَابِسِيَّ', #1
u'والقابسي': u'وَالْقَابِسِيِّ', #11
u'والقابسي': u'وَالْقَابِسِيُّ', #12
u'والقاحة': u'وَالْقَاحَةُ', #1
u'والقاحة': u'وَالْقَاحَةِ', #4
u'والقاد': u'وَالْقَادُّ', #1
u'والقاد': u'وَالْقَادِّ', #5
u'والقارظ': u'وَالْقَارِظُ', #1
u'والقاره': u'وَالْقَارَهْ', #1
u'والقارورات': u'وَالْقَارُورَاتِ', #1
u'والقازمير': u'وَالْقَازْمِيرِ', #1
u'والقاساني': u'وَالْقَاسَانِيِّ', #3
u'والقاسمية': u'وَالْقَاسِمِيَّةُ', #3
u'والقاشاني': u'وَالْقَاشَانِيُّ', #1
u'والقاشاني': u'وَالْقَاشَانِيِّ', #2
u'والقاشور': u'وَالْقَاشُورُ', #1
u'والقاض': u'وَالْقَاضِ', #1
u'والقاضى': u'وَالْقَاضِى', #7
u'والقافة': u'وَالْقَافَةِ', #1
u'والقافة،': u'وَالْقَافَةَ،', #2
u'والقافة': u'وَالْقَافَةَ', #3
u'والقافة': u'وَالْقَافَةُ', #8
u'والقالة': u'وَالْقَالَةُ', #1
u'والقامشلي': u'والقامشلي', #1
u'والقامصة': u'وَالْقَامِصَةِ', #6
u'والقائف': u'وَالْقَائِفِ', #4
u'والقائف': u'وَالْقَائِفُ', #7
u'والقائلون': u'وَالْقَائِلُونً', #1
u'والقائمية': u'وَالْقَائِمِيَّةِ', #1
u'والقاياتي': u'وَالْقَايَاتِيُّ', #1
u'والقايتبايي': u'وَالْقَايِتْبايِي', #1
u'والقبا': u'وَالْقَبَا', #1
u'والقباطي': u'وَالْقَبَاطِيِّ', #1
u'والقباطي': u'وَالْقَبَاطِيُّ', #3
u'والقباطي': u'وَالْقَبَاطِيَّ', #4
u'والقبج': u'والقبج', #1
u'والقبج': u'وَالْقَبْجُ', #1
u'والقبج': u'وَالْقَبْجِ', #1
u'والقبص': u'والقبص', #1
u'والقبصة': u'والقبصة', #1
u'والقبصة': u'وَالْقَبْصَةُ', #1
u'والقبقب': u'وَالْقَبْقَبُ', #1
u'والقبلاء': u'وَالْقُبَلَاءُ', #1
u'والقبولا': u'وَالْقَبُولَا', #1
u'والقبيطاء': u'وَالْقُبَيْطَاءَ', #1
u'والقتب': u'وَالْقَتَبَ', #2
u'والقتب': u'وَالْقَتَبِ', #4
u'والقتب': u'وَالْقَتَبُ', #5
u'والقتبي': u'وَالْقَتِبِي', #1
u'والقتبي': u'وَالْقُتَبِيُّ', #2
u'والقتبي': u'وَالْقُتَبِيّ', #3
u'والقتبي': u'وَالْقُتَبِيِّ', #3
u'والقتد': u'وَالْقَتَدَ', #1
u'والقتلات': u'وَالْقِتْلَاتِ', #1
u'والقتوبة': u'وَالْقَتُوبَةُ', #1
u'والقتيبي': u'وَالْقُتَيْبِيِّ', #1
u'والقتيبي': u'وَالْقُتَيْبِيُّ', #3
u'والقتيتي': u'وَالْقُتَيْتِيِّ', #1
u'والقتير': u'وَالْقَتِيرُ', #2
u'والقثد': u'وَالْقَثَدُ', #1
u'والقثد': u'وَالْقَثَدِ', #1
u'والقج': u'وَالْقَجِّ', #1
u'والقحمة': u'وَالْقُحْمَةُ', #2
u'والقدع': u'وَالْقَدَعُ', #1
u'والقدوري': u'وَالْقُدُورِيَّ', #1
u'والقدوري': u'وَالْقُدُورِيِّ', #27
u'والقدوري': u'وَالْقُدُورِيُّ', #33
u'والقديدين': u'وَالْقَدِيدَيْنِ', #1
u'والقديمه': u'وَالْقَدِيمَهْ', #1
u'والقذم': u'وَالْقَذْمِ', #1
u'والقرءان': u'وَالْقُرْءَانَ', #1
u'والقرءان': u'وَالْقُرْءَانِ', #5
u'والقراسيا': u'والقراسيا', #1
u'والقراسيا': u'وَالْقَرَاسْيَا', #1
u'والقرافة': u'وَالْقَرَافَةِ', #2
u'والقرافي': u'وَالْقَرَافِيَّ', #2
u'والقرافي': u'وَالْقَرَافِيِّ', #44
u'والقرافي': u'وَالْقَرَافِيُّ', #53
u'والقرام': u'وَالْقِرَامُ', #2
u'والقرامل': u'وَالْقَرَامِلَ', #1
u'والقرآنا': u'وَالْقُرْآنَا', #1
u'والقرآنوالوجه': u'وَالْقُرْآنُوَالْوَجْهُ', #1
u'والقرآنوروي': u'وَالْقُرْآنِوَرُوِيَ', #1
u'والقرأين': u'وَالْقُرْأَيْنِ', #2
u'والقرطالة': u'وَالْقِرْطَالَةُ', #2
u'والقرطبان': u'وَالْقَرْطَبَانَ', #1
u'والقرطبان': u'وَالْقَرْطَبَانِ', #1
u'والقرطبان': u'وَالْقَرْطَبَانُ', #7
u'والقرطبة': u'وَالْقُرْطُبَةِ', #2
u'والقرطم': u'وَالْقِرْطِم', #1
u'والقرطم': u'وَالْقِرْطِمِ', #1
u'والقرطم': u'وَالْقُرْطُمِ', #15
u'والقرطم': u'وَالْقُرْطُمُ', #16
u'والقرطم': u'وَالْقُرْطُمَ', #5
u'والقرظ': u'وَالْقَرْظِ', #1
u'والقرظ؟': u'وَالْقَرَظِ؟', #1
u'والقرظ': u'وَالْقَرَظُ', #15
u'والقرظ': u'وَالْقَرَظ', #2
u'والقرظ': u'وَالْقَرْظُ', #2
u'والقرظ': u'وَالْقَرَظِ', #23
u'والقرظي': u'وَالْقُرَظِيُّ', #1
u'والقرظي،': u'وَالْقُرَظِيُّ،', #1
u'والقرفا': u'وَالْقِرْفَا', #1
u'والقرقبي': u'وَالْقُرْقُبِيِّ', #2
u'والقرقر': u'وَالْقَرْقَرُ', #1
u'والقرقس': u'وَالْقِرْقِسِ', #1
u'والقرم': u'وَالْقَرْمُ', #1
u'والقرمة': u'وَالْقَرْمَةُ', #1
u'والقرمة': u'وَالْقُرْمَةُ', #1
u'والقرمز': u'وَالْقِرْمِز', #1
u'والقرمز': u'وَالْقِرْمِزِ', #1
u'والقرموط': u'وَالْقُرْمُوطِ', #2
u'والقرنبا': u'والقرنبا', #1
u'والقرنبا': u'وَالْقَرْنَبَا', #1
u'والقرنباد': u'وَالْقرنباد', #1
u'والقرواح': u'وَالْقِرْوَاحُ', #1
u'والقروان': u'وَالْقِرْوَانِ', #3
u'والقروى': u'وَالْقَرَوِىِّ', #1
u'والقزاز': u'وَالْقَزَّازِ', #2
u'والقزدير': u'وَالْقَزْدِيرَ', #1
u'والقزدير': u'وَالْقَزْدِيرُ', #3
u'والقزع': u'وَالْقَزَعُ', #4
u'والقسب': u'وَالْقَسْبُ', #1
u'والقسطلاني': u'وَالْقَسْطَلَّانِيِّ', #2
u'والقسمه': u'وَالْقِسْمَهْ', #1
u'والقسى،': u'والقسى،', #1
u'والقسى': u'وَالْقَسِّىِّ', #5
u'والقشاشين': u'وَالْقَشَّاشِينَ', #1
u'والقشام': u'وَالْقُشَامٍٍٍٍُ', #1
u'والقشام': u'وَالْقُشَامُ', #5
u'والقشطة': u'وَالْقِشْطَةَ', #1
u'والقشم': u'وَالْقَشْمُ', #1
u'والقشيري': u'وَالْقُشَيْرِيِّ', #3
u'والقشيري': u'وَالْقُشَيْرِيُّ', #4
u'والقصارون': u'وَالْقَصَّارُونَ', #2
u'والقصارين': u'وَالْقَصَّارِينَ', #17
u'والقصباء': u'وَالْقَصْبَاءُ', #2
u'والقصود': u'وَالْقُصُودِ', #2
u'والقصيصة': u'وَالْقَصِيصَةُ', #1
u'والقصيم': u'وَالْقَصِيمُ', #2
u'والقضا': u'وَالْقَضَا', #2
u'والقضيم': u'وَالْقَضِيمُ', #1
u'والقضيمة': u'وَالْقُضَيْمَةِ', #1
u'والقطارميز': u'والقطارميز', #2
u'والقطاط': u'وَالْقِطَاطُ', #2
u'والقطمر': u'وَالْقِطَمْرُ', #1
u'والقطمطة': u'وَالْقَطْمَطَةُ', #1
u'والقطميرة': u'وَالْقِطْمِيرَةُ', #1
u'والقطيعي،': u'وَالْقَطِيعِيِّ،', #1
u'والقطيف': u'وَالْقَطِيفُ', #1
u'والقعاب': u'وَالْقِعَابَ', #1
u'والقعب': u'وَالْقَعْبَ', #1
u'والقعبني': u'وَالْقَعْبَنِيَّ', #1
u'والقعد': u'وَالْقَعَدُ', #1
u'والقعدد': u'وَالْقُعْدُدُ', #2
u'والقعقاع': u'والقعقاع', #1
u'والقعقاع': u'وَالْقَعْقَاعَ', #1
u'والقعقاع': u'وَالْقَعْقَاعِ', #1
u'والقعقاع': u'وَالْقَعْقَاعُ', #3
u'والقعنبي': u'والقعنبي', #1
u'والقعنبي،': u'والْقَعْنَبِيُّ،', #1
u'والقعنبي': u'وَالْقَعْنَبِيَّ', #1
u'والقعنبي': u'وَالْقُعْنُبَيْ', #1
u'والقعنبي،': u'وَالْقَعْنَبِيِّ،', #1
u'والقعنبى': u'وَالْقَعْنَبِىُّ', #1
u'والقعنبي': u'وَالْقَعْنَبِيُّ', #16
u'والقعنبي،': u'وَالْقَعْنَبِيُّ،', #39
u'والقعنبى': u'وَالْقَعْنَبِىِّ', #4
u'والقعنبي': u'وَالْقَعْنَبِيِّ', #5
u'والقفاف': u'وَالْقَفَّافُ', #2
u'والقفاف': u'وَالْقِفَافُ', #2
u'والقفزان': u'وَالْقُفْزَانَ', #1
u'والقفعة': u'وَالْقَفْعَةُ', #1
u'والقفيز': u'وَالْقَفِيزَ', #2
u'والقفيز': u'وَالْقَفِيزُ', #34
u'والقفيز': u'وَالْقَفِيزِ', #5
u'والقلا': u'وَالْقِلَا', #2
u'والقلاش': u'وَالْقَلَّاشُ', #5
u'والقلانسي': u'وَالْقَلَانِسِيُّ', #2
u'والقلانسي': u'وَالْقَلَانِسِيِّ', #2
u'والقلاوونية': u'والقلاوونية', #1
u'والقلت': u'وَالْقَلْتِ', #1
u'والقلت': u'وَالْقَلَتُ', #2
u'والقلت': u'وَالْقَلْتُ', #2
u'والقلتبان': u'وَالْقَلْتَبَانُ', #1
u'والقلح': u'وَالْقَلَحُ', #1
u'والقلح': u'وَالْقَلَحِ', #1
u'والقلحاء': u'وَالْقَلْحَاءُ', #2
u'والقلزم': u'وَالْقُلْزُمَ', #1
u'والقلزم': u'وَالْقُلْزُمُ', #1
u'والقلزم': u'وَالْقُلْزُمِ', #2
u'والقلشاني': u'وَالْقَلْشَانِيَّ', #3
u'والقلشاني': u'وَالْقَلْشَانِيِّ', #6
u'والقلشاني': u'وَالْقَلْشَانِيُّ', #9
u'والقلفطة': u'وَالْقُلْفُطَةِ', #2
u'والقلفونية': u'والْقَلفُونِيّةِ', #1
u'والقلقشندي': u'والقَلْقَشَنْدِيُّ', #1
u'والقلقند': u'والقلقند', #2
u'والقلندرية': u'والقلندرية', #1
u'والقلوصة': u'وَالْقَلْوَصَةِ', #1
u'والقليب': u'وَالْقَلِيبِ', #1
u'والقليب': u'وَالْقَلِيبُ', #4
u'والقليس': u'وَالْقُلِّيسُ', #1
u'والقليشاني': u'والقليشاني', #1
u'والقليشاني': u'وَالْقُلَيْشَانِي', #1
u'والقليعة': u'وَالْقَلِيعَةِ', #1
u'والقليوبي': u'وَالْقَلْيُوبِيُّ', #13
u'والقليوبي': u'وَالْقَلْيُوبِيِّ', #8
u'والقماقمة': u'وَالْقَمَاقِمَةُ', #1
u'والقمرا': u'وَالْقَمَرَا', #5
u'والقمرى': u'وَالْقُمْرِىِّ', #1
u'والقمش': u'وَالْقَمْشُ', #1
u'والقمعه': u'وَالْقَمَعَهْ', #2
u'والقموص': u'وَالْقُمُوصَ', #1
u'والقموص': u'وَالْقُمُوصُ', #1
u'والقمولي': u'وَالْقَمُولِيِّ', #14
u'والقمولي': u'وَالْقَمُولِيُّ', #43
u'والقميم': u'وَالْقَمِيمِ', #1
u'والقناء': u'وَالْقَنَّاءِ', #1
u'والقناء': u'وَالْقِنَاءُ', #1
u'والقنابع': u'وَالْقَنَابِعُ', #1
u'والقنابير': u'وَالْقَنَابِيرَ', #1
u'والقنباز': u'والقنباز', #1
u'والقند': u'وَالْقَنْدِ', #2
u'والقنفوذ': u'وَالْقُنْفُوذُ', #1
u'والقنقل': u'وَالْقَنْقَلُ', #1
u'والقنين': u'وَالْقِنِّينُ', #1
u'والقنين': u'وَالْقِنِّينَ', #7
u'والقهاوي': u'وَالْقَهَاوِي', #2
u'والقهستاني': u'وَالْقُهُسْتَانِيُّ', #19
u'والقهستاني': u'والقهستاني', #3
u'والقهستاني': u'وَالْقُهُسْتَانِيّ', #3
u'والقهستاني': u'وَالْقُهُسْتَانِيِّ', #46
u'والقهقرى': u'وَالْقَهْقَرَى', #4
u'والقوابي': u'وَالْقَوَابِي', #3
u'والقواريري': u'والقواريري', #1
u'والقواريري': u'وَالْقَوَارِيرِيِّ', #1
u'والقواريرى': u'وَالْقَوَارِيرِىُّ', #1
u'والقواريري،': u'وَالْقَوَارِيرِيُّ،', #11
u'والقواريري': u'وَالْقَوَارِيرِيُّ', #5
u'والقوافيا': u'وَالْقَوَافِيَا', #1
u'والقوانس': u'وَالْقَوَانِسُ', #1
u'والقوبا': u'وَالْقُوبَا', #2
u'والقوزي': u'وَالْقُوزِيُّ', #1
u'والقوصرة': u'وَالْقَوْصَرَةِ', #1
u'والقوصرة': u'وَالْقَوْصَرَّةَ', #1
u'والقوصرة': u'وَالْقَوْصَرَّةِ', #1
u'والقوصرة': u'وَالْقَوْصَرَّةُ', #18
u'والقوقلي': u'وَالْقَوْقَلِيّ', #2
u'والقولنج': u'وَالْقُولَنْجَ', #1
u'والقولنج': u'وَالْقُولَنْجُ', #1
u'والقولنج': u'وَالْقُولَنْجِ', #9
u'والقونوي': u'وَالْقُونَوِيُّ', #3
u'والقونوي': u'وَالْقُونَوِيِّ', #4
u'والقوهي': u'وَالقوهي', #1
u'والقىء': u'وَالْقَىْءِ', #2
u'والقياده': u'وَالْقِيَادَهْ', #1
u'والقياسات': u'وَالْقِيَاسَاتِ', #1
u'والقياسر': u'وَالْقَيَاسِرِ', #1
u'والقيالة': u'وَالْقِيَالَةُ', #1
u'والقير': u'وَالْقِيرَ', #1
u'والقير': u'وَالْقَيْر', #1
u'والقير': u'وَالْقِيرُ', #7
u'والقير': u'وَالْقِيرِ', #7
u'والقيسي': u'وَالْقَيْسِيُّ', #1
u'والقيسية': u'وَالْقَيْسِيَّةُ', #1
u'والقيشة': u'وَالْقَيْشَةُ', #1
u'والقيصوم': u'وَالْقَيْصُوم', #1
u'والقيصوم': u'وَالْقَيْصُومِ', #4
u'والقيعة': u'وَالْقِيعَةُ', #1
u'والقيقب': u'وَالْقَيْقَبِ', #1
u'والقيلم': u'وَالْقَيْلَمُ', #1
u'والقيماء': u'وَالْقُيَمَاءِ', #1
u'والقيومية': u'وَالْقَيُّومِيَّةُ', #1
u'والكاذي': u'وَالْكَاذِي', #5
u'والكارع': u'وَالْكَارِعَ', #1
u'والكارع': u'وَالْكَارِعُ', #2
u'والكازروني': u'وَالْكَازَرُونِيُّ', #3
u'والكازنور': u'وَالْكَازَنُورِ', #1
u'والكاشكر': u'والكاشكر', #1
u'والكاكي': u'وَالْكَاكِيُّ', #2
u'والكاكي': u'وَالْكَاكِيِّ', #3
u'والكالئ': u'وَالْكَالِئَ', #1
u'والكالئ': u'وَالْكَالِئِ', #1
u'والكالئ': u'وَالْكَالِئُ', #8
u'والكاملي،': u'وَالْكَامِلِيِّ،', #1
u'والكاني': u'وَالْكَانِي', #1
u'والكباسة': u'وَالْكِبَاسَةُ', #2
u'والكبدا': u'وَالْكَبِدَا', #3
u'والكبنجا': u'وَالْكَبَنْجَا', #1
u'والكبوش': u'وَالْكُبُوشِ', #1
u'والكبيس': u'وَالْكَبِيسِ', #2
u'والكتد': u'وَالْكَتَدُ', #1
u'والكتد': u'وَالْكَتَدِ', #1
u'والكتيلة': u'وَالْكَتِيلَةُ', #1
u'والكثاء': u'وَالْكَثَّاءِ', #1
u'والكثيبة': u'والكثيبة', #2
u'والكثيراء': u'والكثيراء', #1
u'والكحال': u'وَالْكَحَّالُ', #1
u'والكحال': u'وَالْكَحَّالَ', #2
u'والكحال': u'وَالْكَحَّالِ', #2
u'والكحالة': u'وَالْكَحَالَةِ', #2
u'والكحالين': u'وَالْكَحَّالِينَ', #2
u'والكحلة': u'وَالْكُحْلَةَ', #1
u'والكدان': u'وَالْكِدَانَ', #1
u'والكدان': u'وَالْكِدَّانِ', #1
u'والكدك': u'وَالْكَدَكِ', #1
u'والكدوح': u'وَالْكُدُوح', #1
u'والكدورات': u'وَالْكَدُورَاتِ', #1
u'والكدورة': u'وَالْكُدُورَةُ', #1
u'والكديد': u'وَالْكَدِيدِ', #1
u'والكديد': u'وَالْكَدِيدُ', #3
u'والكديمى': u'وَالْكُدَيْمِىُّ', #1
u'والكدين': u'وَالْكَدِينُ', #2
u'والكذان': u'وَالْكَذَّانِ', #1
u'والكذان': u'وَالْكَذَّانُ', #2
u'والكرابيس': u'وَالْكَرَابِيسَ', #1
u'والكرابيس': u'وَالْكَرَابِيسِ', #2
u'والكرابيسي': u'وَالْكَرَابِيسِيِّ', #1
u'والكرابيسي': u'وَالْكَرَابِيسِيُّ', #6
u'والكراديس': u'وَالْكَرَادِيسُ', #1
u'والكرازين': u'وَالْكَرَازِينُ', #1
u'والكراويا': u'وَالْكَرَاوْيَا', #5
u'والكراوية': u'وَالْكَرَاوْيَةَ', #1
u'والكراوية': u'وَالْكَرَاوْيَةُ', #1
u'والكراية': u'وَالْكِرَايَةُ', #2
u'والكربات': u'وَالْكُرُبَاتِ', #1
u'والكرباس': u'وَالْكِرْبَاسِ', #10
u'والكرباس': u'وَالْكِرْبَاسُ', #14
u'والكرخ': u'وَالْكَرْخِ', #2
u'والكرخي': u'وَالْكَرْخِيُّ', #38
u'والكرخي': u'وَالْكَرْخِيِّ', #40
u'والكرد': u'وَالْكُرْدِ', #1
u'والكردار': u'وَالْكِرْدَارُ', #2
u'والكردري': u'وَالْكَرْدَرِيُّ', #1
u'والكردري': u'وَالْكَرْدَرِيِّ', #1
u'والكرسف': u'وَالْكُرْسُفِ', #4
u'والكرسف': u'وَالْكُرْسُفُ', #9
u'والكرسنة': u'وَالْكِرْسِنَّةَ', #1
u'والكرسنة': u'وَالْكِرْسِنَّةِ', #2
u'والكرسنة': u'وَالْكِرْسِنَّةُ', #7
u'والكرسوع': u'وَالْكُرْسُوعُ', #11
u'والكرسوع': u'وَالْكُرْسُوعِ', #4
u'والكركر': u'والكركر', #1
u'والكركر': u'وَالْكُرْكُرُ', #1
u'والكرما': u'وَالْكَرَمَا', #1
u'والكرماني': u'وَالْكَرْمَانِيِّ', #11
u'والكرماني': u'وَالْكَرْمَانِيُّ', #8
u'والكرمسون': u'والكرمسون', #1
u'والكرمسوني': u'والكرمسوني', #1
u'والكرناف': u'وَالْكُرْنَافِ', #1
u'والكرناف': u'وَالْكُرْنَافُ', #3
u'والكرناف': u'وَالْكِرْنَافِ', #3
u'والكرناف': u'وَالْكِرْنَافُ', #4
u'والكرنيج': u'وَالْكَرْنِيجُ', #1
u'والكروبيون': u'وَالْكَرُوبِيُّونَ', #1
u'والكروبيين': u'وَالْكَرُوبِيِّينَ', #1
u'والكرومات': u'وَالْكُرُومَاتِ', #1
u'والكروياء': u'وَالْكَرَوْيَاءِ', #1
u'والكريب': u'وَالْكَرِيبُ', #1
u'والكرين': u'وَالْكُرَّيْنِ', #1
u'والكزبراني،': u'وَالْكُزْبُرَانِيُّ،', #3
u'والكساوى': u'وَالْكَسَاوَى', #1
u'والكسبرة': u'وَالْكُسْبَرَةُ', #1
u'والكستيج': u'وَالْكُسْتِيجُ', #1
u'والكستيج': u'وَالْكِسْتِيجُ', #1
u'والكسراء': u'وَالْكَسْرَاءِ', #1
u'والكسراء': u'وَالْكَسْرَاءُ', #2
u'والكسعة': u'وَالْكُسْعَةِ', #4
u'والكسعة': u'وَالْكُسْعَةُ', #7
u'والكسفرة': u'وَالْكُسْفُرَةِ', #1
u'والكسفرة': u'وَالْكُسْفُرَةُ', #5
u'والكسوب': u'وَالْكَسُوبُ', #6
u'والكشاء': u'وَالْكَشَاءِ', #1
u'والكشخان': u'وَالْكَشْخَانُ', #4
u'والكشكاب': u'وَالْكُشْكَابِ', #1
u'والكشوفات': u'وَالْكُشُوفَاتُ', #1
u'والكشوفات': u'وَالْكُشُوفَاتِ', #1
u'والكشيفة': u'وَالْكَشِيفَةَ', #1
u'والكعام': u'وَالْكِعَامُ', #1
u'والكفاره': u'وَالْكَفَّارَهْ', #1
u'والكفاله': u'وَالْكَفَالَهْ', #2
u'والكفت': u'وَالْكَفْتُ', #7
u'والكفجلار': u'وَالْكَفْجَلَارُ', #1
u'والكفرى': u'وَالْكُفُرَّى', #1
u'والكفرى': u'وَالْكُفَرَّى', #4
u'والكفوء': u'وَالْكُفُوءُ', #1
u'والكفوي': u'وَالْكَفَوِيَّ', #1
u'والكفوي': u'وَالْكَفَوِيِّ', #2
u'والكفوي': u'وَالْكَفَوِيُّ', #5
u'والكفيري': u'وَالْكُفَيْرِيِّ', #1
u'والكلا': u'وَالْكَلاَ', #2
u'والكلا': u'وَالْكَلَا', #3
u'والكلاءة': u'وَالْكَلَاءَةِ', #1
u'والكلاءة': u'وَالْكِلَاءَةِ', #2
u'والكلاباذي': u'وَالْكَلَابَاذِيّ', #1
u'والكلاباذي': u'وَالْكَلَابَاذِيُّ', #1
u'والكلاعي': u'وَالْكَلَاعِيُّ', #2
u'والكلاكل': u'وَالْكَلَاكِلِ', #3
u'والكلامان': u'وَالْكَلَامَانِ', #2
u'والكلائي': u'وَالْكَلَّائِيُّ', #1
u'والكلبى': u'وَالْكَلْبِىُّ', #2
u'والكلح': u'وَالْكَلَحُ', #1
u'والكلحبة': u'وَالْكَلْحَبَةُ', #1
u'وألكلكم': u'وَأَلِكُلِّكُمْ', #1
u'والكلوب': u'وَالْكَلُّوبُ', #1
u'والكلوب': u'وَالْكَلُّوبِ', #1
u'والكمران': u'والكمران', #1
u'والكمران': u'وَالْكِمْرَانِ', #1
u'والكمراناب': u'والكمراناب', #1
u'والكمرة': u'وَالْكَمْرَةُ', #1
u'والكمل': u'وَالْكَمَلِ', #1
u'والكميشة': u'وَالْكَمِيشَةُ', #1
u'والكميع': u'وَالْكَمِيعُ', #3
u'والكناسه': u'وَالْكِنَاسَهْ', #1
u'والكناف': u'وَالْكَنَّافُ', #2
u'والكناف': u'وَالْكَنَّافِ', #2
u'والكنانات': u'وَالْكَنَّانَاتِ', #1
u'والكنائف': u'وَالْكَنَائِفِ', #2
u'والكنتي': u'وَالْكُنْتِيُّ', #1
u'والكندوج': u'وَالْكُنْدُوجُ', #1
u'والكندى': u'وَالْكِنْدِىِّ', #1
u'والكنعد': u'وَالْكَنْعَدُ', #1
u'والكوارة': u'وَالْكِوَارَةُ', #1
u'والكوارة': u'وَالْكُوَّارَةُ', #5
u'والكوارع': u'وَالْكَوَارِعَ', #1
u'والكوارع': u'وَالْكَوَارِعِ', #1
u'والكواشي': u'وَالْكَوَاشِيُّ', #1
u'والكوبة،': u'وَالْكُوبَةَ،', #1
u'والكوبة': u'وَالْكُوبَةَ', #25
u'والكوبة': u'وَالْكُوبَةُ', #4
u'والكوبة': u'وَالْكُوبَةِ', #4
u'والكودن': u'وَالْكَودَنُ', #1
u'والكودن': u'وَالْكَوْدَنُ', #1
u'والكوذين': u'وَالْكُوذِينَ', #2
u'والكوراني': u'وَالْكُورَانِيِّ', #2
u'والكوسج': u'وَالْكَوْسَجَ', #1
u'والكوسج': u'وَالْكَوْسَجِ', #3
u'والكوسج': u'وَالْكَوْسَجُ', #9
u'والكى': u'وَالْكَىِّ', #1
u'والكئود': u'وَالْكَئُودُ', #1
u'وإلكيا': u'وَإِلْكِيَا', #54
u'والكيبة': u'وَالْكَيْبَةَ', #1
u'والكيبة': u'وَالْكَيْبَةِ', #1
u'والكيزان': u'وَالْكِيزَانِ', #10
u'والكيزان': u'وَالْكِيزَانُ', #2
u'والكيساني': u'وَالْكَيْسَانِيَّ', #1
u'والكيساني،': u'وَالْكَيْسَانِيُّ،', #3
u'والكيساني': u'وَالْكَيْسَانِيُّ', #6
u'والكيسانيات': u'والْكَيْسانِيَّاتِ', #1
u'والكيسانيات': u'والكيسانيات', #4
u'والكيفات': u'وَالْكِيفَاتِ', #1
u'والكيفيه': u'وَالْكَيْفِيَّهْ', #1
u'والكيلار': u'والكيلار', #2
u'والكيلجة': u'وَالْكَيْلَجَةِ', #1
u'والكيلجة': u'وَالْكِيلَجَةُ', #2
u'والكيلون': u'وَالْكَيْلُونِ', #1
u'والكيمان': u'وَالْكِيمَانِ', #1
u'والكيميا': u'وَالْكِيمْيَا', #1
u'واللا': u'وَاللَّا', #6
u'واللاتى': u'وَاللاَّتِى', #8
u'واللازمية': u'وَاللَّازِمِيَّةِ', #1
u'واللاطئة': u'وَاللَّاطِئَةَ', #1
u'واللاطية': u'وَاللَّاطِيَةُ', #2
u'واللاقمات': u'واللاقمات', #1
u'واللالكائي': u'وَاللَّالَكَائِيُّ', #3
u'واللأمة': u'وَاللَّأْمَةِ', #1
u'واللأمة': u'وَالْلَأْمَةُ', #1
u'واللأمة': u'وَاللَّأْمَةُ', #2
u'واللامشابهة': u'واللَّامُشَابَهَةُ', #2
u'واللامطابقة': u'واللَّامُطَابَقَة', #1
u'واللامطابقة': u'واللامطابقة', #3
u'واللأواء': u'وَاللَّأْوَاءُ', #2
u'واللأواء': u'وَاللَّأْوَاءِ', #2
u'واللاوقوع': u'وَاللَّاوُقُوعَ', #2
u'واللاوقوع': u'وَاللَّاوُقُوعُ', #4
u'واللاوقوع': u'وَاللَّاوُقُوعِ', #5
u'واللاوقوعها': u'وَاللَّاوُقُوعَهَا', #1
u'واللأي': u'وَاللّأْيُ', #1
u'واللأي': u'وَاللَّأْيُ', #1
u'واللائى': u'وَالَّلائِى', #2
u'واللائى': u'وَاللاَّئِى', #4
u'واللبا': u'وَاللَّبَا', #1
u'واللبأ': u'وَاللِّبَأِ', #11
u'واللبإ': u'وَاللِّبَإِ', #2
u'واللبأ': u'وَاللِّبَأُ', #8
u'واللبا': u'وَاللِّبَا', #8
u'واللبابا': u'وَاللُّبَابَا', #1
u'واللتات': u'وَاللَّتَّاتَ', #1
u'واللتات': u'وَاللُّتَاتُ', #1
u'واللثاة': u'وَاللَّثَاةِ', #1
u'واللثق': u'وَاللّثَقُ', #1
u'واللجأ': u'وَاللَّجَأِ', #1
u'واللجأ': u'وَاللَّجَأُ', #3
u'واللجيم': u'وَاللّجَيْمُ', #1
u'واللحاح': u'وَاللِّحَاحُ', #1
u'واللحكا': u'وَاللُّحَكَا', #2
u'واللحون': u'وَاللُّحُونِ', #2
u'واللحيف': u'وَاللّحِيفُ', #1
u'واللحيف،': u'وَاللَّحِيفَ،', #1
u'واللحيف': u'وَاللُّحَيْفُ', #1
u'واللخاف': u'وَاللَّخَافِ', #1
u'واللخاف': u'وَاللِّخَافُ', #1
u'واللخاف': u'وَاللِّخَافِ', #4
u'واللخص': u'وَاللَّخَصُ', #1
u'واللخم': u'وَاللَّخْمُ', #1
u'واللخمي': u'وَاللَّخْمِيِّ', #123
u'واللخمي': u'وَاللَّخْمِيُّ', #157
u'واللخمي': u'وَاللَّخْمِيَّ', #7
u'واللخن': u'وَاللَّخْنُ', #1
u'واللدم': u'وَاللّدَمُ', #1
u'واللديد': u'وَاللَّدِيدُ', #1
u'واللديغ': u'وَاللَّدِيغَ', #1
u'واللديغ': u'وَاللَّدِيغِ', #1
u'واللديغ': u'وَاللَّدِيغُ', #2
u'واللذغ': u'وَاللَّذَغَ', #1
u'واللطيم': u'وَاللَّطِيمِ', #3
u'واللطيمة': u'وَاللّطِيمَةُ', #2
u'واللعة': u'وَاللّعَةُ', #1
u'واللعس': u'وَاللَّعْسُ', #2
u'واللعس': u'وَاللُّعْسُ', #2
u'واللعساء': u'وَاللَّعْسَاءُ', #1
u'واللعل': u'واللعل', #1
u'واللعل': u'وَاللَّعْلِ', #2
u'واللعلع': u'وَاللّعْلَعُ', #1
u'واللعوقات': u'واللُّعُوقَاتِ', #1
u'واللغاء': u'وَاللِّغَاءُ', #1
u'واللغاب': u'وَاللّغَابُ', #1
u'واللغب': u'وَاللَّغَبِ', #1
u'واللغب': u'وَاللَّغْبَ', #1
u'واللغزة': u'وَاللُّغْزَةُ', #1
u'واللغية': u'وَاللُّغَيَّةُ', #1
u'واللفام': u'وَاللِّفَامِ', #1
u'واللقام': u'وَاللِّقَامُ', #1
u'واللقاني': u'وَاللَّقَانِيَّ', #1
u'واللقاني': u'وَاللَّقَانِيُّ', #10
u'واللقاني': u'وَاللَّقَانِيِّ', #4
u'واللقحة': u'وَاللَّقْحَةَ', #1
u'واللقحة': u'وَاللِّقْحَة', #1
u'واللقحة': u'وَاللِّقْحَةَ', #2
u'واللقحة': u'وَاللِّقْحَةُ', #5
u'واللقس': u'وَاللَّقْسُ', #1
u'واللقس': u'وَاللَّقَسِ', #2
u'واللقلق': u'وَاللَّقْلَقِ', #2
u'واللقلق': u'وَاللَّقْلَقُ', #5
u'واللقوح': u'وَاللَّقُوحَ', #1
u'واللكاع': u'وَاللَّكَاعُ', #1
u'واللكاك': u'وَاللّكَاكُ', #1
u'واللكزة': u'وَاللَّكْزَةِ', #1
u'واللمسين': u'وَاللَّمْسَيْنِ', #1
u'واللمش': u'وَاللَّمْشِ', #2
u'وآلله': u'وَآللَّهِ', #6
u'واللهاء': u'وَاللّهَاءِ', #1
u'واللهام': u'وَاللّهَام', #1
u'واللهبرة': u'وَاللَّهْبَرَةِ', #2
u'واللهز': u'وَاللَّهْز', #1
u'واللهز': u'وَاللَّهْزُ', #4
u'واللو': u'وَاللَّوُّ', #1
u'واللو': u'وَاللَّوَّ', #3
u'واللو': u'وَاللَّوْ', #3
u'واللوب': u'وَاللّوْبُ', #1
u'واللوزنيج': u'واللَّوْزَنِيجُ', #1
u'واللوص': u'وَاللَّوَصِ', #1
u'واللوص': u'وَاللَّوْصَ', #1
u'واللوص': u'وَاللَّوْصُ', #2
u'واللوص': u'وَاللَّوْصِ', #8
u'واللوق': u'وَاللَّوْقِ', #1
u'واللؤلؤة': u'وَاللُّؤْلُؤَةِ', #3
u'واللؤلؤة': u'وَاللُّؤْلُؤَةَ', #4
u'واللؤلؤة': u'وَاللُّؤْلُؤَةُ', #6
u'والليالى': u'وَاللَّيَالِى', #5
u'والليتان': u'وَاللِّيَّتَانِ', #1
u'والليثى': u'وَاللَّيْثِىُّ', #1
u'والليس': u'وَاللُّيَّسِ', #1
u'والليطة': u'وَاللِّيطَةُ', #2
u'والليطة': u'وَاللِّيطَةِ', #3
u'واللينوفر': u'واللينوفر', #1
u'واللينوفر': u'وَاللِّينُوفَرَ', #1
u'واللينوفر': u'وَاللِّينُوفَرُ', #1
u'واللينوفر': u'وَاللِّينُوفَرِ', #4
u'وإلم': u'وَإِلَّمْ', #1
u'والما': u'وَالْمَا', #1
u'والمأبون': u'وَالْمَأْبُونِ', #1
u'والمأبون': u'وَالْمَأْبُونُ', #2
u'والماتريدي': u'وَالْمَاتُرِيدِيُّ', #1
u'والماتريدية': u'وَالْمَاتُرِيدِيَّةُ', #1
u'والماتريدية': u'وَالْمَاتُرِيدِيَّةِ', #4
u'والماتريدية': u'وَالْمَاتُرِيدِيَّة', #5
u'والمأتي': u'وَالْمَأْتِيَّ', #1
u'والمأتي': u'وَالْمَأْتِيُّ', #3
u'والمأتي': u'وَالْمَأْتِيِّ', #3
u'والماجشون': u'وَالْمَاجِشُونَ', #1
u'والماجشون': u'وَالْمَاجِشُونِ', #1
u'والماجشون،': u'وَالْمَاجِشُونُ،', #1
u'والماجشون': u'وَالْمَاجِشُونُ', #2
u'والماجل': u'وَالْمَاجِلُ', #2
u'والماجل': u'وَالْمَاجِلِ', #2
u'والمأدبات': u'وَالْمَأْدُبَاتِ', #1
u'والمأدور': u'وَالْمَأْدُورُ', #1
u'والماذي': u'وَالْمَاذِيّ', #1
u'والماذيانات': u'وَالْمَاذِيَانَاتِ', #1
u'والماذيانات': u'وَالْمَاذِيَانَاتُ', #4
u'والماذية': u'وَالْمَاذِيّةُ', #1
u'والمارما': u'وَالْمَارْمَا', #1
u'والمارماهي': u'وَالْمَارْمَاهِي', #3
u'والمارماهي': u'وَالْمَارْمَاهِيِّ', #8
u'والمارهيج': u'وَالْمَارِهِيجُ', #1
u'والمازري': u'وَالْمَازِرِيُّ', #113
u'والمازري': u'وَالْمَازِرِيَّ', #3
u'والمازري': u'وَالْمَازِرِيِّ', #76
u'والمازني': u'وَالْمَازِنِيِّ', #3
u'والماش': u'وَالْمَاشَ', #1
u'والماش': u'وَالْمَاشّ', #1
u'والماش': u'وَالْمَاشُّ', #11
u'والماش': u'وَالْمَاشِ', #4
u'والماش': u'وَالْمَاشُ', #8
u'والماش': u'وَالْمَاشِّ', #8
u'والماشى': u'وَالْمَاشِى', #10
u'والماصدق': u'وَالْمَاصَدَقَ', #1
u'والماعزة': u'وَالْمَاعِزَةِ', #1
u'والماعزة': u'وَالْمَاعِزَةُ', #3
u'والمأق': u'وَالْمَأَقُ', #1
u'والماق': u'وَالَمَاقَ', #1
u'والماق': u'وَالَمَاقُ', #2
u'والماكس': u'وَالْمَاكِس', #1
u'والمالا': u'وَالْمَالَا', #2
u'والمألوم': u'والمألوم', #1
u'والمألوم': u'وَالْمَأْلُومِ', #1
u'والماليخولي': u'وَالْمَالِيخُولي', #1
u'والمأمومية': u'والْمَأْمُومِيَّةِ', #1
u'والمانعية': u'وَالْمَانِعِيَّةُ', #4
u'والمانعية': u'وَالْمَانِعِيَّةِ', #4
u'والماورد': u'وَالْمَاوَرْدِ', #2
u'والماوردي': u'والماوردي', #1
u'والماوردي': u'وَالْمَاوَرْدِيُّ', #242
u'والماوردي': u'وَالْمَاوَرْدِيّ', #3
u'والماوردي': u'وَالْمَاوَرْدِيِّ', #39
u'والماوردي': u'وَالْمَاوَرْدِيَّ', #5
u'والمائعية': u'والْمَائِعِيَّةُ', #1
u'والمأيوس': u'وَالْمَأْيُوسَ', #1
u'والمأيوس': u'وَالْمَأْيُوسُ', #1
u'والمأيوس': u'وَالْمَأْيُوسِ', #1
u'والمباحية': u'وَالْمُبَاحِيَّةِ', #1
u'والمبارأة': u'وَالْمُبَارَأَةِ', #33
u'والمبارأة': u'وَالْمُبَارَأَةُ', #34
u'والمبارأة': u'وَالْمُبَارَأَةَ', #5
u'والمبارئة': u'وَالْمُبَارِئَةَ', #4
u'والمبارئة': u'وَالْمُبَارِئَةِ', #4
u'والمباضعة': u'وَالْمُبَاضَعَةِ', #3
u'والمباضعة': u'وَالْمُبَاضَعَةُ', #9
u'والمباطخ': u'وَالْمَبَاطِخِ', #2
u'والمباعر': u'وَالْمَبَاعِرُ', #2
u'والمباعلة': u'وَالْمُبَاعَلَةُ', #2
u'والمبان': u'وَالْمُبَانُ', #13
u'والمبان': u'وَالْمُبَانَ', #2
u'والمبانة': u'وَالْمُبَانَةِ', #5
u'والمبانة': u'وَالْمُبَانَةَ', #6
u'والمبانة': u'وَالْمُبَانَةُ', #9
u'والمباهلة': u'وَالْمُبَاهَلَةُ', #7
u'والمباهي': u'وَالْمُبَاهِي', #2
u'والمباين': u'وَالْمُبَايِنُ', #3
u'والمباينة': u'وَالْمُبَايِنَةُ', #1
u'والمباينة': u'وَالْمُبَايِنَةِ', #1
u'والمباينة': u'وَالْمُبَايَنَةُ', #12
u'والمباينة': u'وَالْمُبَايَنَةِ', #25
u'والمبتدي': u'وَالْمُبْتَدِي', #3
u'والمبتوتة': u'وَالْمَبْتُوتَةِ', #13
u'والمبتوتة': u'وَالْمَبْتُوتَةَ', #2
u'والمبتوتة': u'وَالْمَبْتُوتَةُ', #26
u'والمبتول': u'وَالْمَبْتُولُ', #1
u'والمبحار': u'والمبحار', #1
u'والمبرءون': u'وَالْمُبَرَّءُونَ', #1
u'والمبرأ': u'وَالْمُبَرَّأُ', #1
u'والمبرأ': u'وَالْمُبْرَأِ', #1
u'والمبرسم': u'وَالْمُبَرْسَمَ', #1
u'والمبرسم': u'وَالْمُبَرْسَمُ', #12
u'والمبرسم': u'وَالْمُبَرْسَمِ', #20
u'والمبرص': u'وَالْمُبْرَصُ', #2
u'والمبرك': u'وَالْمَبْرَكِ', #1
u'والمبرودين': u'وَالْمَبْرُودِينَ', #1
u'والمبروص': u'وَالْمَبْرُوصَ', #1
u'والمبروص': u'وَالْمَبْرُوصُ', #2
u'والمبعر': u'وَالْمَبْعَرِ', #1
u'والمبعض': u'وَالْمُبَعَّض', #1
u'والمبعض': u'وَالْمُبَعَّضُ', #152
u'والمبعض': u'وَالْمُبَعَّضَ', #16
u'والمبعض': u'وَالْمُبَعِّضُ', #2
u'والمبعض': u'وَالْمُبَعَّضِ', #48
u'والمبعضة': u'وَالْمُبَعِّضَةُ', #2
u'والمبعضة': u'وَالْمُبَعَّضَةُ', #21
u'والمبعضة': u'وَالْمُبَعَّضَةِ', #27
u'والمبعضة': u'وَالْمُبَعَّضَةَ', #4
u'والمبعضين': u'وَالْمُبَعَّضِينَ', #4
u'والمبلس': u'وَالْمُبْلِسُ', #1
u'والمبيعا': u'وَالْمَبِيعَا', #1
u'والمبيعية': u'وَالْمَبِيعِيَّةِ', #1
u'والمبيقر': u'وَالْمُبَيْقِرُ', #1
u'والمتاب': u'وَالْمَتَابَ', #1
u'والمتابة': u'وَالْمَتَابَةِ', #1
u'والمتأتى': u'وَالْمُتَأَتَّى', #2
u'والمتآجران': u'وَالْمُتَآجِرَانِ', #1
u'والمتأدى': u'وَالْمُتَأَدَّى', #1
u'والمتأذى': u'والمتأذى', #1
u'والمتاركة': u'وَالْمُتَارَكَةِ', #3
u'والمتاركة': u'وَالْمُتَارَكَةُ', #7
u'والمتباذلين': u'وَالْمُتَبَاذِلِينَ', #5
u'والمتبن': u'وَالْمَتْبَنِ', #3
u'والمتبوعية': u'وَالْمَتْبُوعِيَّة', #1
u'والمتبوعية': u'وَالْمَتْبُوعِيَّةِ', #1
u'والمتترسون': u'وَالْمُتَتَرَّسُونَ', #1
u'والمتجالات': u'وَالْمُتَجَالَّاتِ', #1
u'والمتجالات': u'وَالْمُتَجَالَّاتُ', #6
u'والمتجالة': u'وَالْمُتَجَالَّةُ', #2
u'والمتجالة': u'وَالْمُتَجَالَّةِ', #3
u'والمتجوز': u'وَالْمُتَجَوَّزُ', #1
u'والمتجوز': u'وَالْمُتَجَوَّزِ', #2
u'والمتحرف': u'وَالْمُتَحَرِّفُ', #4
u'والمتخللون': u'وَالْمُتَخَلَّلُونَ', #1
u'والمتراضعين': u'وَالْمُتَرَاضَعِينَ', #2
u'والمتزر': u'وَالْمُتَّزِرُ', #1
u'والمتساحقتين': u'والمُتساحِقتَيْنِ', #1
u'والمتسحر': u'وَالْمُتَسَحِّرُ', #2
u'والمتسخن': u'وَالْمُتَسَخِّنِ', #1
u'والمتسنن': u'وَالْمُتَسَنِّنُ', #1
u'والمتسننة': u'وَالْمُتَسَنِّنَةِ', #1
u'والمتشرعين': u'والمتشرعين', #1
u'والمتصيد': u'وَالْمُتَصَيِّدُ', #1
u'والمتضايفان': u'وَالْمُتَضَايِفَانِ', #1
u'والمتضمخ': u'وَالْمُتَضَمِّخُ', #2
u'والمتضيف': u'وَالْمُتَضَيِّفُ', #1
u'والمتعاوضان': u'وَالْمُتَعَاوَضَانِ', #1
u'والمتعزر': u'وَالْمُتَعَزِّرِ', #1
u'والمتغالون': u'وَالْمُتَغَالُونَ', #1
u'والمتفقع': u'وَالْمُتَفَقِّعُ', #1
u'والمتفيهق': u'وَالْمُتَفَيْهِقُ', #2
u'والمتفيهقون': u'وَالْمُتَفَيْهِقُونَ', #3
u'والمتكاء': u'وَالْمَتْكَاءُ', #2
u'والمتكاري': u'وَالْمُتَكَارِي', #6
u'والمتلج': u'وَالْمُتّلِجِ', #1
u'والمتلخص': u'وَالْمُتَلَخِّصُ', #2
u'والمتلقط': u'وَالْمُتَلَقِّطِ', #1
u'والمتمالئون': u'وَالْمُتَمَالِئُونَ', #1
u'والمتمالئون': u'وَالْمُتَمَالَئُونَ', #9
u'والمتمرضة': u'وَالْمُتَمَرِّضَةِ', #1
u'والمتمسخر': u'وَالْمُتَمَسْخِرِ', #1
u'والمتمنى': u'وَالْمُتَمَنَّى', #1
u'والمتناضلين': u'وَالْمُتَنَاضَلِينَ', #1
u'والمتنخم': u'وَالْمُتَنَخِّمُ', #1
u'والمتهاجرين': u'وَالْمُتَهَاجِرَيْنِ', #1
u'والمتهب': u'وَالْمُتَّهَبَ', #1
u'والمتهب': u'وَالْمُتَّهِبِ', #15
u'والمتهب': u'وَالْمُتَّهَبِ', #3
u'والمتهب': u'وَالْمُتَّهَبُ', #4
u'والمتهب': u'وَالْمُتَّهِبُ', #4
u'والمتواطد': u'وَالْمُتَوَاطِدُ', #1
u'والمتوسطها': u'والمتوسطها', #1
u'والمتوشمات': u'وَالْمُتَوَشِّمَاتِ', #2
u'والمتوشمة': u'وَالْمُتَوَشِّمَةَ', #3
u'والمتوضاة': u'وَالْمُتَوَضَّاةُ', #1
u'والمتولى': u'وَالْمُتَوَلَّى', #3
u'والمتى': u'وَالْمَتَى', #1
u'والمتيطي': u'وُالْمُتَيْطِيِّ', #1
u'والمتيطي': u'وَالْمُتَيْطِيِّ', #34
u'والمتيطي': u'وَالْمُتَيْطِيُّ', #37
u'والمتيطية': u'وَالْمُتَيْطِيَّةِ', #8
u'والمثبث': u'وَالْمُثْبِثُ', #1
u'والمثدون': u'وَالْمَثْدُون', #1
u'والمثعب': u'وَالْمَثْعَبُ', #1
u'والمثلة': u'وَالْمُثْلَةِ', #11
u'والمثلة': u'والمثلة', #2
u'والمثلة': u'وَالْمَثُلَةُ', #2
u'والمثلة': u'وَالْمُثْلَةُ', #29
u'والمثلة': u'وَالْمُثْلَةَ', #4
u'والمثمون': u'وَالْمَثْمُونَ', #1
u'والمثمون': u'وَالْمَثْمُونِ', #11
u'والمثمون': u'وَالْمَثْمُونُ', #4
u'والمثنويات': u'وَالْمَثْنَوِيَّاتِ', #1
u'والمجاذيف': u'وَالْمَجَاذِيفِ', #2
u'والمجاعل': u'وَالْمُجَاعَلِ', #1
u'والمجاعل': u'وَالْمُجَاعِلُ', #3
u'والمجاعلة': u'وَالْمُجَاعَلَةِ', #2
u'والمجاعلة': u'وَالْمُجَاعَلَةُ', #4
u'والمجالد': u'وَالْمُجَالِدِ', #2
u'والمجالد': u'وَالْمُجَالِدُ', #3
u'والمجاهز': u'وَالْمُجَاهِزُ', #3
u'والمجبوب': u'وَالْمَجْبُوبَ', #15
u'والمجبوب': u'وَالْمَجْبُوبُ', #56
u'والمجبوب': u'وَالْمَجْبُوبِ', #64
u'والمجبوس': u'وَالْمَجْبُوسِ', #1
u'والمجة': u'وَالْمَجَّةُ', #1
u'والمجتعل': u'وَالْمُجْتَعَلِ', #2
u'والمجتعل': u'وَالْمُجْتَعِلِ', #2
u'والمجتن': u'وَالْمُجْتَنُّ', #1
u'والمجتنى': u'وَالْمُجْتَنَى', #2
u'والمجثمة': u'وَالْمُجَثِّمَةَ', #1
u'والمجثمة': u'وَالْمُجَثِّمَةُ', #1
u'والمجثمة': u'وَالْمُجَثَّمَةَ', #3
u'والمجثمة': u'وَالْمُجَثَّمَةُ', #3
u'والمجثمة،': u'وَالْمُجَثَّمَةِ،', #3
u'والمجثمة': u'وَالْمُجَثَّمَةِ', #5
u'والمجح': u'وَالْمُجِحُّ', #1
u'والمجحود': u'وَالْمَجْحُودِ', #10
u'والمجحود': u'وَالْمَجْحُودُ', #3
u'والمجحودات': u'وَالْمَجْحُودَاتِ', #1
u'والمجحور': u'وَالْمَجْحُورُ', #1
u'والمجدود': u'وَالْمَجْدُودُ', #2
u'والمجذم': u'وَالْمُجْذَمُ', #1
u'والمجذم': u'وَالْمُجْذَمِ', #1
u'والمجذوذ': u'وَالْمَجْذُوذُ', #1
u'والمجرن': u'وَالْمِجْرَنُ', #1
u'والمجزم': u'وَالْمُجْزَمِ', #1
u'والمجزوزة': u'وَالْمَجْزُوزَةُ', #2
u'والمجزى': u'وَالْمُجْزَى', #1
u'والمجسمية': u'والمجسمية', #1
u'والمجلوبون': u'وَالْمَجْلُوبُونَ', #2
u'والمجهولتها': u'والمجهولتها', #2
u'والمجهولية': u'والمجهولية', #1
u'والمجهولية': u'وَالْمَجْهُولِيَّةُ', #1
u'والمجوسى': u'وَالْمَجُوسِىُّ', #1
u'والمجىء': u'والْمَجِىءُ', #1
u'والمجيدية': u'وَالْمُجَيْدِيَّةُ', #3
u'والمحابى': u'وَالْمُحَابَى', #2
u'والمحاججة': u'وَالْمُحَاجَجَةُ', #1
u'والمحارس': u'وَالْمَحَارِسُ', #1
u'والمحارسة': u'وَالْمُحَارَسَةُ', #1
u'والمحاصة': u'وَالْمُحَاصَّةَ', #1
u'والمحاصة': u'وَالْمُحَاصَّةِ', #11
u'والمحاصة': u'وَالْمُحَاصَّةُ', #28
u'والمحاصصة': u'وَالْمُحَاصَصَةُ', #1
u'والمحاقلة': u'وَالْمُحَاقَلَة', #1
u'والمحاقلة': u'وَالْمُحَاقَلَةِ', #37
u'والمحاقلة': u'وَالْمُحَاقَلَةَ', #4
u'والمحاقلة': u'وَالْمُحَاقَلَةُ', #44
u'والمحاقلة،': u'وَالْمُحَاقَلَةِ،', #5
u'والمحاملي': u'وَالْمَحَامِلِيِّ', #20
u'والمحاملي': u'وَالْمَحَامِلِيُّ', #63
u'والمحاويج': u'وَالْمَحَاوِيجِ', #1
u'والمحائض': u'وَالْمَحَائِضُ', #2
u'والمحايض': u'وَالْمَحَايِضُ', #1
u'والمحبوبي': u'وَالْمَحْبُوبِيَّ', #1
u'والمحبوبي': u'وَالْمَحْبُوبِيِّ', #13
u'والمحبوبي': u'وَالْمَحْبُوبِيُّ', #19
u'والمحبوبية': u'والمحبوبية', #1
u'والمحتجم': u'وَالْمُحْتَجِمُ', #7
u'والمحجن': u'وَالْمِحْجَنِ', #2
u'والمحجن': u'وَالْمِحْجَنُ', #5
u'والمحجنة': u'وَالْمِحْجَنَةُ', #1
u'والمحجوج': u'وَالْمَحْجُوجُ', #1
u'والمحجوم': u'وَالْمَحْجُوم', #1
u'والمحجوم؟': u'وَالْمَحْجُومُ؟', #1
u'والمحجوم': u'والمحجوم', #2
u'والمحجوم': u'وَالْمَحْجُومٌٌٌٌُ', #2
u'والمحجوم': u'وَالْمَحْجُومِ', #4
u'والمحجوم': u'وَالْمَحْجُومََََُ', #7
u'والمحجوم': u'وَالْمَحْجُومُ', #98
u'والمحد': u'وَالْمُحِدُّ', #1
u'والمحدة': u'وَالْمُحَدَّةِ', #3
u'والمحدة': u'وَالْمُحِدَّةِ', #4
u'والمحدة': u'وَالْمُحِدَّةُ', #5
u'والمحدر': u'وَالْمُحَدِّرِ', #1
u'والمحدودون': u'وَالْمَحْدُودُونَ', #1
u'والمحرما': u'وَالْمُحَرَّمَا', #1
u'والمحروز': u'وَالْمَحْرُوزَ', #1
u'والمحزو': u'وَالْمَحْزُوّ', #1
u'والمحصر': u'وَالْمُحْصِرُ', #1
u'والمحصر': u'وَالْمُحْصَرِ', #2
u'والمحصر': u'وَالْمُحْصَرُ', #25
u'والمحصوب': u'وَالْمَحْصُوبَ', #1
u'والمحصوب': u'وَالْمَحْصُوبِ', #2
u'والمحفود': u'وَالْمَحْفُودُ', #1
u'والمحلبة': u'وَالْمِحْلَبَةُ', #1
u'والمحوج': u'وَالْمُحْوِجُ', #9
u'والمحوى': u'وَالْمُحَوَّى', #1
u'والمحياة': u'وَالْمُحَيَّاةُ', #1
u'والمحيرية': u'والمحيرية', #1
u'والمخارجة': u'وَالْمُخَارَجَةَ', #1
u'والمخاسرة': u'وَالْمُخَاسَرَةِ', #1
u'والمخاسرة': u'وَالْمُخَاسَرَةُ', #4
u'والمخاشاة': u'وَالْمُخَاشَاةُ', #1
u'والمخاضرة': u'وَالْمُخَاضَرَةُ', #1
u'والمخاضرة،': u'وَالْمُخَاضَرَةِ،', #1
u'والمخاضرة': u'وَالْمُخَاضَرَةِ', #3
u'والمخاطة': u'وَالْمُخَاطَةِ', #1
u'والمخاطره': u'وَالْمُخَاطَرَهْ', #1
u'والمخالع': u'وَالْمُخَالَعَ', #2
u'والمخالع': u'وَالْمُخَالِعِ', #2
u'والمخالع': u'وَالْمُخَالَعُ', #4
u'والمخبث': u'وَالْمُخْبِث', #1
u'والمختاره': u'وَالْمُخْتَارَهْ', #1
u'والمختال': u'وَالْمُخْتَالُ', #4
u'والمختالون': u'وَالْمُخْتَالُونَ', #1
u'والمخترجة': u'وَالْمُخْتُرِجَةُ', #1
u'والمختلع': u'وَالْمُخْتَلِعُ', #3
u'والمختلعات': u'وَالْمُخْتَلِعَاتِ', #1
u'والمختلعات': u'وَالْمُخْتَلَعَات', #2
u'والمختلعة': u'وَالْمُخْتَلِعَةِ', #14
u'والمختلعة': u'وَالْمُخْتَلِعَةُ', #20
u'والمختلعة': u'وَالْمُخْتَلِعَةَ', #3
u'والمخثرمة': u'وَالْمُخَثْرَمَةُ', #1
u'والمخد': u'وَالْمِخَدِّ', #1
u'والمخدجي': u'وَالْمُخْدَجِيُّ', #2
u'والمخذل': u'وَالْمُخَذَّلُ', #1
u'والمخذل': u'وَالْمُخْذِلُ', #1
u'والمخذل': u'وَالْمُخَذِّلُ', #9
u'والمخذم': u'وَالْمِخْذَمَ', #2
u'والمخذم': u'وَالْمِخْذَمُ', #2
u'والمخرف': u'وَالْمَخْرَفُ', #1
u'والمخروص': u'وَالْمَخْرُوصُ', #2
u'والمخزوم': u'وَالْمَخْزُومِ', #1
u'والمخزى': u'وَالْمُخْزَى', #1
u'والمخفوض': u'وَالْمَخْفُوضِ', #1
u'والمخفوضات': u'وَالْمَخْفُوضَاتُ', #1
u'والمخلوقية': u'والْمَخْلُوقيَّةِ', #1
u'والمخلى': u'وَالْمُخَلَّى', #1
u'والمخلى': u'وَالْمُخْلَى', #1
u'والمخمصة': u'وَالْمَخْمَصَةِ', #3
u'والمخنق': u'وَالْمُخَنَّقُ', #1
u'والمخيس': u'وَالْمُخَيَّسُ', #2
u'والمدابغي': u'وَالْمَدَابِغِيُّ', #2
u'والمدابغي': u'وَالْمَدَابِغِيِّ', #3
u'والمداسم': u'وَالْمَدَاسِمَ', #1
u'والمداسم': u'وَالْمَدَاسِمُ', #1
u'والمداك': u'وَالْمَدَاكُ', #2
u'والمدالج': u'وَالْمُدَالِجُ', #1
u'والمدائني،': u'والمدائني،', #3
u'والمدائني،': u'وَالْمَدَائِنِيُّ،', #3
u'والمدائني': u'وَالْمَدَائِنِيُّ', #8
u'والمداينون': u'وَالْمُدَايِنُونَ', #1
u'والمدحين': u'وَالْمَدْحَيْنِ', #1
u'والمدفونا': u'وَالْمَدْفُونَا', #1
u'والمدلجي': u'والمدلجي', #1
u'والمدنر': u'وَالْمُدَنَّرُ', #1
u'والمدوك': u'وَالْمِدْوَكَ', #1
u'والمدوك': u'وَالْمِدْوَكُ', #1
u'والمدينةوروي': u'وَالْمَدِينَةِوَرُوِيَ', #1
u'والمذاء': u'وَالْمِذَاءُ', #2
u'والمذاكرين': u'وَالْمُذَاكِرِينَ', #1
u'والمذروع': u'وَالْمَذْرُوعَ', #1
u'والمذروع': u'وَالْمَذْرُوعِ', #23
u'والمذروع': u'وَالْمَذْرُوعُ', #7
u'والمذروعات': u'وَالْمَذْرُوعَاتِ', #14
u'والمذروعات': u'وَالْمَذْرُوعَاتُ', #2
u'والمذكاة': u'وَالْمُذَكَّاةُ', #5
u'والمذكاة': u'وَالْمُذَكَّاةِ', #7
u'والمذكى': u'وَالْمُذَكَّى', #10
u'والمذي': u'وَالْمَذِيُّ', #1
u'والمذي': u'وَالْمَذْي', #1
u'والمذى': u'وَالْمَذْىُ', #3
u'والمذي': u'وَالْمَذْيُ', #35
u'والمذي': u'وَالْمَذْيِ', #43
u'والمذي': u'وَالْمَذْيَ', #9
u'والمرءوس': u'وَالْمَرْءُوسِ', #1
u'والمرادي': u'وَالْمُرَادِيُّ', #1
u'والمرادي': u'وَالْمُرَادِيِّ', #1
u'والمرادية': u'وَالْمُرَادِيَةِ', #1
u'والمراطلة': u'وَالْمُرَاطَلَة', #1
u'والمراطلة': u'وَالْمُرَاطَلَةُ', #13
u'والمراطلة': u'وَالْمُرَاطَلَةَ', #4
u'والمراطلة': u'وَالْمُرَاطَلَةِ', #9
u'والمراعى': u'وَالْمُرَاعَى', #21
u'والمراغ': u'وَالْمَرَاغُ', #1
u'والمراغمة': u'وَالْمُرَاغَمَةِ', #2
u'والمراغمة': u'وَالْمُرَاغَمَةُ', #3
u'والمراوزة': u'وَالْمَرَاوِزَةُ', #2
u'والمراوزة': u'وَالْمَرَاوِزَةِ', #3
u'والمراوضة': u'وَالْمُرَاوَضَةُ', #1
u'والمربات': u'وَالْمَرَبَّاتِ', #1
u'والمربطون': u'وَالْمِرْبِطُونَ', #1
u'والمربوب': u'وَالْمَرْبُوبِ', #4
u'والمرتث': u'وَالْمُرْتَثُّ', #1
u'والمرتجز': u'وَالْمُرْتَجَزِ', #1
u'والمرتجز': u'وَالْمُرْتَجِزُ', #1
u'والمرتجز': u'وَالْمُرْتَجِزِ', #1
u'والمرتدف': u'وَالْمُرْتَدِفُ', #6
u'والمرتشى': u'وَالْمُرْتَشِىَ', #1
u'والمرتضع': u'وَالْمُرْتَضِعَ', #1
u'والمرتضعة': u'وَالْمُرْتَضِعَةُ', #7
u'والمرتضى': u'وَالْمُرْتَضَى', #2
u'والمرتفق': u'وَالْمُرْتَفَقِ', #1
u'والمرتفق': u'وَالْمُرْتَفِقُ', #1
u'والمرتك': u'وَالْمَرْتَكُ', #2
u'والمرتك': u'وَالْمَرْتَكِ', #2
u'والمرثدي،': u'وَالْمَرْثَدِيُّ،', #1
u'والمرثدى': u'وَالْمَرْثَدِىِّ', #1
u'والمرجوحية': u'والمرجوحية', #1
u'والمرجى': u'وَالْمُرَجّى', #2
u'والمرحومي': u'وَالْمَرْحُومِيُّ', #1
u'والمرداسنج': u'وَالْمَرْدَاسِنْجُ', #1
u'والمرداسنج': u'وَالْمَرْدَاسِنْجِ', #1
u'والمردان': u'وَالْمُرْدَانِ', #3
u'والمردكوش': u'وَالْمَرْدَكُوشُ', #1
u'والمرزبانين،': u'وَالْمَرْزُبَانِينَ،', #1
u'والمرزجوش': u'وَالْمَرْزَجُوشِ', #1
u'والمرزنجوش': u'وَالْمَرْزَنْجُوشِ', #3
u'والمرسول': u'وَالْمَرْسُولُ', #3
u'والمرصفي': u'وَالْمَرْصَفِيُّ', #1
u'والمرضخة': u'وَالْمِرْضَخَةُ', #1
u'والمرط': u'وَالْمِرْطُ', #5
u'والمرعز': u'وَالْمَرْعَزِ', #1
u'والمرعز': u'وَالْمِرْعِزِّ', #1
u'والمرعزاء': u'وَالْمِرْعِزَاءِ', #1
u'والمرعزى': u'وَالْمِرْعِزَّى', #14
u'والمرعزي': u'والمرعزي', #3
u'والمرعشي': u'وَالْمَرْعَشِيُّ', #3
u'والمرغناني': u'وَالْمَرْغِنَانِيّ', #1
u'والمرغيناني': u'والْمَرْغِينَانِيُّ', #1
u'والمرغيناني': u'والمرغيناني', #29
u'والمرغينانية': u'وَالْمَرغِينَانيَّةِ', #1
u'والمرفل': u'وَالْمُرَفّلُ', #1
u'والمرفوء': u'وَالْمَرْفُوءُ', #1
u'والمرقوق': u'وَالْمَرْقُوقَ', #1
u'والمرقوقة': u'وَالْمَرْقُوقَةُ', #4
u'والمرقوقية': u'والمرقوقية', #5
u'والمرماة': u'وَالْمِرْمَاة', #1
u'والمرندجين': u'والمرندجين', #1
u'والمرهاء': u'وَالْمَرْهَاءِ', #1
u'والمرهاء': u'وَالْمَرْهَاءَ', #6
u'والمرهونية': u'والمرهونية', #1
u'والمروآت': u'وَالْمُرُوآتِ', #3
u'والمرواح': u'وَالْمِرْوَاحُ', #1
u'والمروانية': u'وَالْمَرْوَانِيَّةُ', #1
u'والمروذي': u'والمروذي', #1
u'والمروذي': u'وَالْمَرُّوذِيَّ', #1
u'والمروذي': u'وَالْمَرُّوذِيِّ', #12
u'والمروذي': u'وَالْمَرُّوذِيُّ', #19
u'والمروراة': u'وَالْمَرَوْرَاةُ', #1
u'والمروروذي': u'وَالْمَرْوَرُوذِيُّ', #1
u'والمروط': u'وَالْمُرُوطُ', #1
u'والمريسيع،': u'والمُرَيْسِيعَ،', #1
u'والمريسيع': u'وَالْمُرَيْسِيعُ', #3
u'والمريسيع': u'وَالْمُرَيْسِيعِ', #3
u'والمريطاء': u'وَالْمُرَيْطَاءُ', #2
u'والمزابلية': u'وَالْمَزَابِلِيّةُ', #1
u'والمزابنة': u'وَالْمُزَابَنَة', #2
u'والمزابنة،': u'وَالْمُزَابَنَةِ،', #8
u'والمزابنة': u'وَالْمُزَابَنَةُ', #80
u'والمزابنة': u'وَالْمُزَابَنَةِ', #80
u'والمزاجر': u'وَالْمَزَاجِرُ', #2
u'والمزاجر': u'وَالْمَزَاجِرِ', #2
u'والمزارعه': u'وَالْمُزَارَعَهْ', #3
u'والمزاريق': u'وَالْمَزَارِيقِ', #3
u'والمزبورة': u'وَالْمَزْبُورَةِ', #1
u'والمزجور': u'وَالْمَزْجُورُ', #1
u'والمزجور': u'وَالْمَزْجُورِ', #1
u'والمزدارية': u'وَالْمُزْدَارِيَّةُ', #1
u'والمزدرعات': u'وَالْمُزْدَرَعَاتِ', #1
u'والمزدلفه': u'وَالْمُزْدَلِفَهْ', #7
u'والمزدلفي': u'وَالْمُزْدَلِفِيُّ', #1
u'والمزدلفي': u'وَالْمُزْدَلِفِيِّ', #4
u'والمزر': u'وَالْمَزْرِ', #1
u'والمزر': u'وَالْمِزْر', #1
u'والمزر': u'وَالْمِزْرُ', #15
u'والمزر': u'وَالْمِزْرِ', #2
u'والمزر': u'وَالْمِزْرَ', #6
u'والمزراق': u'وَالْمِزْرَاقُ', #1
u'والمزراق': u'وَالْمِزْرَاقِ', #1
u'والمزرب': u'وَالْمُزَرِّبِ', #1
u'والمزرور': u'وَالْمَزْرُورَ', #1
u'والمزرور': u'وَالْمَزْرُورُ', #1
u'والمزرورات،': u'وَالْمُزَرْوَرَاتِ،', #1
u'والمزعفر': u'وَالْمُزَعْفَرُ', #10
u'والمزعفر': u'وَالْمُزَعْفَرَ', #3
u'والمزعفر': u'وَالْمُزَعْفَرِ', #36
u'والمزمزة': u'وَالْمَزْمَزَةُ', #3
u'والمزمزة': u'وَالْمَزْمَزَةِ', #4
u'والمزملاتي': u'والمزملاتي', #4
u'والمزنم': u'وَالْمُزَنّمُ', #3
u'والمزنى': u'وَالْمُزَنِىُّ', #1
u'والمزنى': u'وَالْمُزَنِىِّ', #1
u'والمزولات': u'وَالْمُزَوِّلَاتُ', #1
u'والمزولات': u'وَالْمِزْوَلَاتُ', #1
u'والمزيقياء': u'وَالْمُزَيْقِيَاءُ', #2
u'والمساطير': u'وَالْمَسَاطِيرِ', #1
u'والمساف': u'وَالْمَسَافُ', #1
u'والمساقى': u'وَالْمُسَاقَى', #5
u'والمسامت': u'وَالْمُسَامِتَ', #2
u'والمسامتة': u'وَالْمُسَامَتَةُ', #1
u'والمسامتة': u'وَالْمُسَامِتَةُ', #1
u'والمسامتة': u'وَالْمُسَامَتَةِ', #2
u'والمسانهة': u'وَالْمُسَانَهَةِ', #2
u'والمساوقة': u'وَالْمُسَاوَقَةُ', #1
u'والمساوقة': u'وَالْمُسَاوَقَةِ', #3
u'والمسببية': u'وَالْمُسَبَّبِيَّةُ', #1
u'والمسببية': u'وَالْمُسَبَّبِيَّةِ', #1
u'والمسببية': u'وَالْمُسَبَّبِيَّة', #3
u'والمسببية': u'والمسببية', #6
u'والمسبل': u'وَالْمُسَبَّلِ', #1
u'والمسبل': u'وَالْمُسْبَلِ', #1
u'والمسبل': u'وَالْمُسْبِلُ', #11
u'والمسبلة': u'وَالْمُسَبَّلَةِ', #4
u'والمسة': u'وَالْمَسَّةِ', #1
u'والمستأخر': u'وَالْمُسْتَأْخِرُ', #1
u'والمستأخرون': u'والمستأخرون', #2
u'والمستأخرين': u'والمستأخرين', #1
u'والمستأخرين': u'وَالْمُسْتَأْخِرِينَ', #15
u'والمستأدبين': u'والمستأدبين', #1
u'والمستام': u'وَالْمُسْتَامِ', #22
u'والمستام': u'وَالْمُسْتَامُ', #8
u'والمستامة': u'وَالْمُسْتَامَةِ', #1
u'والمستبان': u'وَالْمُسْتَبَّانِ', #1
u'والمستبرأة': u'وَالْمُسْتَبْرَأَةِ', #11
u'والمستبرأة': u'وَالْمُسْتَبْرَأَةُ', #13
u'والمستبرأة': u'وَالْمُسْتَبْرَأَةَ', #2
u'والمستبرأة': u'وَالْمُسْتَبْرَأَة', #5
u'والمستبضع': u'وَالْمُسْتَبْضِعِ', #12
u'والمستبضع': u'وَالْمُسْتَبْضِعُ', #17
u'والمستبضع': u'وَالْمُسْتَبْضَعُ', #3
u'والمستبضع': u'وَالْمُسْتَبْضِعَ', #3
u'والمستبضعان': u'وَالْمُسْتَبْضَعَانِ', #1
u'والمستبضعين': u'والمُسْتَبْضِعِين', #1
u'والمستبضعين': u'والمُسْتَبْضِعِينَ', #1
u'والمستجسد': u'وَالْمُسْتَجْسِدُ', #1
u'والمستجيز': u'وَالْمُسْتَجِيزُ', #1
u'والمستحاضة': u'وَالْمُسْتَحَاضَةُ', #33
u'والمستحاضة': u'وَالْمُسْتَحَاضَةِ', #7
u'والمستحشف': u'وَالْمُسْتَحْشِفِ', #1
u'والمستحيز': u'وَالْمُسْتَحِيزُ', #1
u'والمستخبث': u'وَالْمُسْتَخْبَثُ', #2
u'والمستدخلة': u'والْمُسْتَدْخِلَةِ', #1
u'والمسترعاة': u'وَالْمُسْتَرْعَاةُ', #1
u'والمستزاد': u'وَالْمُسْتَزَادُ', #1
u'والمستزاد': u'وَالْمُسْتَزَادِ', #2
u'والمستسعاة': u'وَالْمُسْتَسْعَاةُ', #23
u'والمستسعاة': u'وَالْمُسْتَسْعَاةِ', #4
u'والمستسعاة': u'وَالْمُسْتَسْعَاةَ', #5
u'والمستسعي': u'وَالْمُسْتَسْعِي', #1
u'والمستسعى': u'وَالْمُسْتَسْعَى', #31
u'والمستشز': u'وَالْمُسْتَشِزّ', #1
u'والمستشكل': u'وَالْمُسْتَشْكِلُ', #2
u'والمستصفي': u'وَالْمُسْتَصْفِي', #1
u'والمستصفى': u'وَالْمُسْتَصْفَى', #6
u'والمستصنع': u'وَالْمُسْتَصْنِعِ', #1
u'والمستصنع': u'وَالْمُسْتَصْنَعُ', #2
u'والمستصنع': u'وَالْمُسْتَصْنِعُ', #9
u'والمستطرف': u'وَالْمُسْتَطْرِفِ', #1
u'والمستظهري': u'وَالْمُسْتَظْهَرَيْ', #2
u'والمستعدى': u'وَالْمُسْتَعْدَى', #1
u'والمستفاض': u'وَالْمُسْتَفَاضُ', #1
u'والمستفتى': u'وَالْمُسْتَفْتَى', #2
u'والمستفرشة': u'والمستفرشة', #3
u'والمستقة': u'وَالْمُسْتَقَةُ', #1
u'والمستقة': u'وَالْمُسْتُقَةُ', #1
u'والمستقذر': u'وَالْمُسْتَقْذَرَ', #1
u'والمستقذر': u'وَالْمُسْتَقْذَرُ', #1
u'والمستقذر': u'وَالْمُسْتَقْذَرِ', #1
u'والمستقذرات': u'وَالْمُسْتَقْذِرَات', #3
u'والمستقرض': u'وَالْمُسْتَقْرَضُ', #1
u'والمستقرض': u'وَالْمُسْتَقْرَضِ', #1
u'والمستقرض': u'وَالْمُسْتَقْرِضُ', #20
u'والمستقرض': u'وَالْمُسْتَقْرِضَ', #3
u'والمستقرض': u'وَالْمُسْتَقْرِضِ', #7
u'والمستقضي': u'وَالْمُسْتَقْضِي', #1
u'والمستقطر': u'وَالْمُسْتَقْطَرُ', #1
u'والمستكري': u'وَالْمُسْتَكْرِي', #6
u'والمستلحق': u'وَالْمُسْتَلْحَقِ', #1
u'والمستلحق': u'وَالْمُسْتَلْحَقُ', #3
u'والمستلحق': u'وَالْمُسْتَلْحِقُ', #3
u'والمستلئم': u'وَالْمُسْتَلْئِمُ', #1
u'والمستملي': u'وَالْمُسْتَمْلِي', #3
u'والمستنبح': u'وَالْمُسْتَنْبَحُ', #1
u'والمستنثر': u'وَالْمُسْتَنْثِرُ', #1
u'والمستنكح': u'وَالْمُسْتَنْكَحِ', #1
u'والمستنكح': u'وَالْمُسْتَنْكِحُ', #1
u'والمستنيب': u'وَالْمُسْتَنِيبُ', #1
u'والمستنيب': u'وَالْمُسْتَنِيبِ', #2
u'والمستهدم': u'وَالْمُسْتَهْدَمِ', #1
u'والمستوشرة': u'وَالْمُسْتَوْشِرَةُ', #1
u'والمستوشرة': u'وَالْمُسْتَوْشِرَة', #4
u'والمستوشرة': u'وَالْمُسْتَوْشِرَةَ', #7
u'والمستوشمات': u'والمستوشمات', #2
u'والمستوشمات': u'وَالْمُسْتَوْشِمَات', #5
u'والمستوشمات': u'وَالْمُسْتَوْشِمَاتِ', #6
u'والمستوشمة': u'والمستوشمة', #1
u'والمستوشمة': u'وَالْمُسْتَوْشِمَةٌٌٌٌَ', #1
u'والمستوشمة،': u'وَالْمُسْتَوْشِمَةَ،', #1
u'والمستوشمة': u'وَاَلْمُسْتَوْشِمَةُ', #1
u'والمستوشمة،': u'والمستوشمة،', #2
u'والمستوشمة': u'وَالْمُسْتَوْشِمَةِ', #2
u'والمستوشمة': u'وَالْمُسْتَوْشِمَةَ', #32
u'والمستوشمة': u'وَالْمُسْتَوْشِمَة', #8
u'والمستوشمة': u'وَالْمُسْتَوْشِمَةُ', #8
u'والمستوصلة،': u'وَالْمُسْتَوْصِلَةَ،', #1
u'والمستوصلة': u'وَالْمُسْتَوْصِلَة', #10
u'والمستوصلة': u'والمستوصلة', #3
u'والمستوصلة': u'وَالْمُسْتَوْصِلَةِ', #3
u'والمستوصلة': u'وَالْمُسْتَوْصِلَةَ', #48
u'والمستوصلة': u'وَالْمُسْتَوْصِلَةُ', #6
u'والمستوغر': u'وَالْمُسْتَوْغِرُ', #1
u'والمستوفز': u'وَالْمُسْتَوْفِزُ', #1
u'والمستوفى': u'وَالْمُسْتَوْفَى', #35
u'والمستوهب': u'وَالْمُسْتَوْهِبُ', #1
u'والمستوهب': u'وَالْمُسْتَوْهِبِ', #1
u'والمسجع': u'وَالْمُسَجَّعُ', #1
u'والمسخوطين': u'وَالْمَسْخُوطِينَ', #1
u'والمسرود': u'وَالْمَسْرُودُ', #2
u'والمسرورية': u'والمسرورية', #1
u'والمسروقى': u'وَالْمَسْرُوقِىُّ', #1
u'والمسعط': u'وَالْمُسْعَطُ', #1
u'والمسعط': u'وَالْمِسْعَطِ', #1
u'والمسعودي': u'وَالْمَسْعُودِيّ', #1
u'والمسعودي': u'وَالْمَسْعُودِيِّ', #2
u'والمسعودى': u'وَالْمَسْعُودِىُّ', #3
u'والمسعودي،': u'وَالْمَسْعُودِيُّ،', #4
u'والمسعودي': u'وَالْمَسْعُودِيُّ', #5
u'والمسعي': u'وَالْمَسْعِيَّ', #1
u'والمسقف': u'وَالْمُسَقَّفِ', #1
u'والمسقف': u'وَالْمُسَقَّفُ', #2
u'والمسقف': u'وَالْمُسْقَفُ', #2
u'والمسقفات': u'وَالْمُسَقَّفَاتِ', #1
u'والمسقفات': u'وَالْمُسْقَفَاتُ', #1
u'والمسقفات': u'وَالْمُسْقَفَاتِ', #2
u'والمسكنا': u'وَالْمَسْكَنَا', #1
u'والمسلاتيين': u'والمسلاتيين', #1
u'والمسلمانية': u'والمسلمانية', #1
u'والمسلمانية': u'وَالْمَسْلَمَانِيَّةِ', #1
u'والمسلمانية': u'وَالْمَسْلِمَانِيَّةِ', #1
u'والمسمط': u'وَالْمُسَمَّطُ', #1
u'والمسمط': u'وَالْمَسْمَطُ', #3
u'والمسموط': u'وَالْمَسْمُوطُ', #1
u'والمسناة': u'وَالْمُسَنَّاة', #1
u'والمسناة': u'وَالْمُسَنَّاةَ', #1
u'والمسناة': u'وَالْمُسْنَاةُ', #1
u'والمسناة': u'وَالْمُسَنَّاةِ', #3
u'والمسناة': u'وَالْمُسَنَّاةُ', #8
u'والمسناوي': u'وَالْمِسْنَاوِيِّ', #1
u'والمسناوي': u'وَالْمِسْنَاوِيُّ', #4
u'والمسنم': u'وَالْمُسَنَّمُ', #1
u'والمسوح': u'وَالْمُسُوحُ', #1
u'والمسوح': u'وَالْمُسُوحِ', #2
u'والمسيحة': u'وَالْمَسِيحَةُ', #2
u'والمسيخ': u'وَالْمَسِيخُ', #1
u'والمشاءون': u'وَالْمَشَّاءُونَ', #5
u'والمشاش': u'وَالْمُشَاشَ', #1
u'والمشاش': u'وَالْمُشَاشُ', #4
u'والمشاقص': u'وَالْمَشَاقِصُ', #2
u'والمشاققة': u'وَالْمُشَاقَقَةِ', #3
u'والمشتر': u'وَالْمُشْتَرِ', #1
u'والمشتراة': u'وَالْمُشْتَرَاةَ', #3
u'والمشتراة': u'وَالْمُشْتَرَاةِ', #5
u'والمشتراة': u'وَالْمُشْتَرَاةُ', #8
u'والمشترى': u'وَالْمُشْتَرِى', #1
u'والمشترى': u'وَالْمُشْتَرَى', #102
u'والمشترى': u'وَالْمُشْتَرِىَ', #3
u'والمشد': u'وَالْمُشِدُّ', #1
u'والمشد': u'وَالْمُشِدِّ', #1
u'والمشد': u'وَالْمِشَدُّ', #1
u'والمشد': u'وَالْمِشَدِّ', #2
u'والمشدخ': u'وَالْمُشَدَّخُ', #2
u'والمشذالي': u'وَالْمَشَذَّالِيُّ', #3
u'والمشروف': u'وَالْمَشْرُوفِ', #1
u'والمشش': u'وَالْمَشَشِ', #1
u'والمشش': u'وَالْمَشَشُ', #7
u'والمشعار': u'وَالْمِشْعَارُ', #1
u'والمشقأ': u'وَالْمَشْقَأُ', #1
u'والمشقر': u'وَالْمُشَقَّرَ', #1
u'والمشقر': u'وَالْمُشَقَّرِ', #1
u'والمشقرا': u'وَالْمُشَقَّرَا', #1
u'والمشقص': u'وَالْمِشْقَصُ', #4
u'والمشلل': u'وَالْمُشَلَّلُ', #1
u'والمشموما': u'وَالْمَشْمُومَا', #1
u'والمشى': u'وَالْمَشِىُّ', #2
u'والمشى': u'وَالْمَشْىُ', #2
u'والمشى': u'وَالْمَشْىِ', #3
u'والمشئوم': u'وَالْمَشْئُومُ', #1
u'والمشيبا': u'وَالْمَشِيبَا', #1
u'والمصابره': u'وَالْمُصَابَرَهْ', #1
u'والمصتكى': u'وَالْمُصْتَكَى', #1
u'والمصدان': u'وَالْمُصْدَانَ', #1
u'والمصدان': u'وَالْمُصْدَانُ', #1
u'والمصراة': u'وَالْمُصْرَاةِ', #1
u'والمصراة': u'وَالْمُصَرَّاةِ', #4
u'والمصراة': u'وَالْمُصَرَّاةُ', #5
u'والمصطرف': u'وَالْمُصْطَرِفُ', #2
u'والمصطكا': u'وَالْمُصْطَكَا', #1
u'والمصطكا': u'وَالْمُصْطَكَّا', #1
u'والمصطلق': u'وَالْمُصْطَلِقُ', #3
u'والمصطلق': u'وَالْمُصْطَلِقِ', #3
u'والمصطنعية': u'والمصطنعية', #1
u'والمصلة': u'وَالْمَصْلَةُ', #1
u'والمصلق': u'وَالْمِصْلَقُ', #1
u'والمصلق': u'وَالْمَصْلَقُ', #2
u'والمصلوق': u'وَالْمَصْلُوقُ', #2
u'والمصلينا': u'وَالْمُصَلِّينَا', #1
u'والمضابح': u'وَالْمَضَابِحُ', #1
u'والمضابي': u'وَالْمَضَابِي', #1
u'والمضاجرة': u'والمضاجرة', #2
u'والمضاحك': u'وَالْمُضَاحَكِ', #1
u'والمضاربه': u'وَالْمُضَارَبَهْ', #2
u'والمضاررة': u'وَالْمُضَارَرَةُ', #1
u'والمضاغ': u'وَالْمَضَاغُ', #1
u'والمضبب': u'وَالْمُضَبَّبَ', #1
u'والمضبب': u'وَالْمُضَبَّبُ', #3
u'والمضبب': u'وَالْمُضَبَّبِ', #8
u'والمضروبية': u'وَالْمَضْرُوبِيّةَ', #1
u'والمضرورين': u'وَالْمَضْرُورِينَ', #2
u'والمضفر': u'وَالْمُضَفِّرُ', #1
u'والمضيرة': u'وَالْمَضِيرَةُ', #1
u'والمطبوب': u'وَالْمَطْبُوبُ', #1
u'والمطبوب': u'وَالْمَطْبُوبِ', #1
u'والمطجن': u'وَالْمُطَجَّنُ', #1
u'والمطحولون': u'وَالْمَطْحُولُونَ', #1
u'والمطرو': u'وَالْمَطْرُوُّ', #1
u'والمطروء': u'وَالْمَطْرُوءُ', #1
u'والمطلقت': u'وَالْمُطَلَّقَتُ', #1
u'والمطلوبية': u'والْمَطْلُوبِيَّةُ', #1
u'والمطلي': u'وَالْمَطْلِيُّ', #1
u'والمطلي': u'وَالْمَطْلِيِّ', #1
u'والمطموم': u'وَالْمَطْمُومُ', #1
u'والمطيطا': u'وَالْمُطَيْطَا', #1
u'والمطيعية': u'وَالْمُطِيعِيَّةُ', #1
u'والمطين': u'وَالْمُطَيِّنِ', #2
u'والمظافر': u'وَالْمُظَافِرِ', #1
u'والمظافرة': u'وَالْمُظَافَرَةُ', #1
u'والمظافرة': u'وَالْمُظَافَرَةِ', #1
u'والمظلمون': u'وَالْمَظْلُمُونَ', #1
u'والمظلومية': u'والمظلومية', #2
u'والمظن': u'وَالْمُظَنُّ', #1
u'والمعابدة': u'وَالْمَعَابِدَةِ', #1
u'والمعاثم': u'وَالْمَعَاثِمِ', #1
u'والمعادده': u'وَالْمُعَادَدَهْ', #1
u'والمعازي': u'وَالْمَعَازِي', #2
u'والمعاصى': u'وَالْمَعَاصِى', #1
u'والمعاطاة': u'وَالْمُعَاطَاةِ', #14
u'والمعاطاة': u'وَالْمُعَاطَاةُ', #6
u'والمعافر': u'وَالْمَعَافِرُ', #1
u'والمعافري': u'وَالْمَعَافِرِيُّ', #1
u'والمعاقد': u'وَالْمَعَاقِدِ', #1
u'والمعاكمة': u'وَالْمُعَاكَمَةِ', #1
u'والمعانى': u'وَالْمُعَانَى', #1
u'والمعائب': u'وَالْمَعَائِبِ', #1
u'والمعايات': u'وَالْمُعَايَاتِ', #1
u'والمعتاط': u'وَالْمُعْتَاطُ', #3
u'والمعتر': u'وَالْمُعَتّرُ', #1
u'والمعتر': u'وَالْمُعَتَّرَ', #1
u'والمعتر': u'وَالْمُعْتَرِّ', #1
u'والمعتر؟': u'وَالْمُعْتَرُّ؟', #1
u'والمعتر': u'وَالْمُعْتَرُّ', #17
u'والمعتر': u'والمعتر', #2
u'والمعتر': u'وَالْمُعْتَرَّ', #43
u'والمعترفا': u'وَالْمُعْتَرِفَا', #1
u'والمعتلف': u'وَالْمُعْتَلَفُ', #1
u'والمعتلف': u'وَالْمُعْتَلَفِ', #1
u'والمعتمل': u'وَالْمُعْتَمِلِ', #1
u'والمعتمل': u'وَالْمُعْتَمِلُ', #8
u'والمعتوق': u'وَالْمَعْتُوقُ', #1
u'والمعتوق': u'وَالْمَعْتُوقِ', #1
u'والمعثور': u'وَالْمَعْثُورِ', #1
u'والمعثور': u'وَالْمَعْثُورُ', #3
u'والمعجر': u'وَالْمِعْجَرُ', #1
u'والمعجوز': u'وَالْمَعْجُوزِ', #1
u'والمعجوز': u'وَالْمَعْجُوزُ', #2
u'والمعدى': u'وَالْمُعْدَى', #1
u'والمعراض': u'وَالْمِعْرَاضِ', #5
u'والمعراض': u'وَالْمِعْرَاضُ', #6
u'والمعرقب': u'وَالْمُعَرْقَبُ', #2
u'والمعرور': u'والمعْرور', #1
u'والمعرور': u'وَالْمَعْرُورِ', #1
u'والمعرور': u'وَالْمَعْرُورُ', #2
u'والمعسور': u'وَالْمَعْسُورِ', #1
u'والمعصفر': u'وَالْمُعْصَفَر', #1
u'والمعصفر': u'وَالْمُعَصْفَرُ', #17
u'والمعصفر': u'وَالْمُعَصْفَرِ', #60
u'والمعصفر،': u'وَالْمُعَصْفَرِ،', #7
u'والمعصفر': u'وَالْمُعَصْفَرَ', #9
u'والمعضوب': u'وَالْمَعْضُوبَ', #1
u'والمعضوب': u'وَالْمَعْضُوبُ', #11
u'والمعضوب': u'وَالْمَعْضُوبِ', #4
u'والمعطن': u'وَالْمَعْطَنُ', #1
u'والمعفوج': u'وَالْمَعْفُوجُ', #1
u'والمعقاب': u'وَالْمِعْقَابُ', #1
u'والمعقص': u'وَالْمُعَقِّصُ', #1
u'والمعقودية': u'والمعقودية', #2
u'والمعقوص': u'وَالْمَعْقُوص', #1
u'والمعقوص': u'وَالْمَعْقُوصَ', #1
u'والمعقوص': u'وَالْمَعْقُوصِ', #3
u'والمعلمينا': u'وَالْمُعْلِمِينَا', #3
u'والمعلهج': u'وَالْمُعَلْهَجُ', #1
u'والمعلوق': u'وَالْمَعْلُوقُ', #1
u'والمعلولية': u'وَالْمَعْلُولِيَّة', #1
u'والمعلومية': u'وَالْمَعْلُومِيَّةُ', #1
u'والمعلومية': u'وَالْمَعْلُومِيَّة', #4
u'والمعمرية': u'وَالْمَعْمَرِيَّةُ', #1
u'والمعنسة': u'وَالْمُعَنَّسَةُ', #1
u'والمعنسة': u'وَالْمُعَنِّسَةَ', #1
u'والمعنسة': u'وَالْمُعَنِّسَةُ', #1
u'والمعهودية': u'والمعهودية', #1
u'والمعيز': u'وَالْمَعِيزِ', #2
u'والمعيز': u'وَالْمَعِيزُ', #5
u'والمعيم': u'وَالْمُعِيمُ', #1
u'والمغابن': u'وَالْمَغَابِنِ', #4
u'والمغابنة': u'وَالمُغَابَنَةُ', #1
u'والمغابنة': u'وَالْمُغَابَنَةُ', #5
u'والمغابنة': u'وَالْمُغَابَنَةِ', #9
u'والمغارسة': u'وَالْمُغَارَسَةِ', #14
u'والمغارسة': u'وَالْمُغَارَسَةَ', #2
u'والمغارسة': u'وَالْمُغَارَسَةُ', #9
u'والمغازى': u'وَالْمَغَازِى', #1
u'والمغازى': u'وَالْمَغْازِى', #1
u'والمغالون': u'وَالْمُغَالُونَ', #1
u'والمغاورة': u'وَالْمُغَاوَرَةِ', #1
u'والمغت': u'وَالْمَغْتُ', #1
u'والمغتلم': u'وَالْمُغْتَلِمُ', #1
u'والمغث': u'وَالْمَغْثُ', #2
u'والمغدق': u'وَالْمُغْدِقُ', #1
u'والمغرة': u'وَالْمُغْرَةِ', #1
u'والمغرة': u'وَالْمَغْرَةِ', #10
u'والمغرة': u'وَالْمَغَرَةُ', #3
u'والمغرة': u'وَالْمَغْرَةَ', #3
u'والمغرة': u'وَالْمَغَرَةِ', #5
u'والمغرة': u'وَالْمَغْرَةُ', #7
u'والمغروم': u'وَالْمَغْرُومُ', #7
u'والمغزول': u'وَالْمَغْزُولِ', #2
u'والمغفر': u'وَالْمِغْفَرِ', #1
u'والمغفر': u'وَالْمِغْفَرَ', #4
u'والمغفر': u'وَالْمِغْفَرُ', #8
u'والمغلصمة': u'وَالْمُغَلْصَمَةِ', #1
u'والمغمس': u'وَالْمُغَمَّسِ', #2
u'والمغموص': u'وَالْمَغْمُوصِ', #1
u'والمغمى': u'وَالْمُغْمًى', #2
u'والمغنومة': u'وَالْمَغْنُومَةُ', #1
u'والمغنيز': u'وَالْمَغْنِيزُ', #1
u'والمغيا': u'وَالْمُغْيَا', #2
u'والمغيا': u'وَالْمُغَيَّا', #3
u'والمغيرية': u'وَالْمُغِيرِيَّةُ', #1
u'والمفاخذة': u'وَالْمُفَاخَذَةُ', #1
u'والمفاخذة': u'وَالْمُفَاخَذَةِ', #2
u'والمفارهة': u'وَالْمُفَارَهَةِ', #1
u'والمفاعلة': u'وَالْمُفَاعَلَةْ', #1
u'والمفاعلة': u'وَالْمُفَاعَلَةُ', #10
u'والمفاعلة': u'وَالْمُفَاعَلَةَ', #2
u'والمفاعلة': u'وَالْمُفَاعَلَةِ', #5
u'والمفاعله': u'وَالْمُفَاعَلَهْ', #1
u'والمفاقم': u'وَالْمُفَاقِمَ', #1
u'والمفاوتة': u'وَالْمُفَاوَتَةُ', #3
u'والمفتسرين': u'والمفتسرين', #1
u'والمفدم': u'وَالْمُفْدَمِ', #1
u'والمفدم،': u'وَالْمُفَّدَّمِ،', #1
u'والمفدم': u'وَالْمُفْدَمُ', #4
u'والمفدمة': u'وَالْمُفَدَّمَة', #1
u'والمفزوع': u'وَالْمَفْزُوعِ', #1
u'والمفسول': u'وَالْمَفْسُولُ', #1
u'والمفضاة': u'وَالْمُفْضَاةُ', #2
u'والمفضولية': u'وَالْمَفْضُولِيَّة', #1
u'والمفضولية': u'وَالْمَفْضُولِيَّةِ', #1
u'والمفطور': u'وَالْمَفْطُورِ', #1
u'والمفظع': u'وَالْمُفْظِع', #1
u'والمفعاة': u'وَالْمُفَعّاةُ', #1
u'والمفقع': u'وَالْمُفَقِّعُ', #1
u'والمفقوء': u'وَالْمَفْقُوءُ', #1
u'والمفقوءة': u'وَالْمَفْقُوءَةُ', #3
u'والمفلسا': u'وَالْمُفْلِسَا', #1
u'والمقاثي': u'وَالْمَقَاثِي', #13
u'والمقاثي': u'وَالْمَقَاثِيَ', #2
u'والمقاثئ': u'وَالْمَقَاثِئِ', #16
u'والمقاثئ': u'والمقاثئ', #2
u'والمقاثئ': u'وَالْمَقَاثِئَ', #2
u'والمقاثئ': u'وَالْمَقَاثِئُ', #8
u'والمقارض': u'وَالْمُقَارَضَ', #2
u'والمقارض': u'وَالْمُقَارَضُ', #3
u'والمقارض': u'وَالْمُقَارَضِ', #7
u'والمقارض': u'وَالْمُقَارِضِ', #7
u'والمقارض': u'وَالْمُقَارِضُ', #9
u'والمقارضه': u'وَالْمُقَارَضَهْ', #1
u'والمقارضين': u'وَالْمُقَارِضِينَ', #1
u'والمقارعين': u'وَالْمُقَارِعِينَ', #1
u'والمقاريف': u'وَالْمَقَارِيفِ', #2
u'والمقاصصة': u'وَالْمُقَاصَصَةُ', #3
u'والمقانع': u'وَالْمَقَانِعِ', #1
u'والمقايس': u'وَالْمُقَايِسِ', #1
u'والمقايلة': u'وَالْمُقَايَلَةُ', #1
u'والمقتب': u'وَالْمُقَتَّبُ', #3
u'والمقتص': u'وَالْمُقْتَصُّ', #3
u'والمقتصين': u'وَالْمُقْتَصِّينَ', #1
u'والمقتعطة': u'وَالْمُقْتَعَطَةُ', #1
u'والمقتنى': u'وَالْمُقْتَنَى', #2
u'والمقثأة': u'وَالْمِقْثَأَةِ', #1
u'والمقثاة': u'وَالْمِقْثَاةِ', #1
u'والمقثأة': u'وَالْمَقْثَأَةِ', #4
u'والمقداد': u'والْمِقْدَادُ', #1
u'والمقداد': u'وَالْمِقْدَادَ', #11
u'والمقداد': u'وَالْمِقْدَادِ', #16
u'والمقداد،': u'وَالْمِقْدَادَ،', #2
u'والمقداد،': u'وَالْمِقْدَادُ،', #3
u'والمقداد': u'وَالْمِقْدَادُ', #36
u'والمقداد': u'والمقداد', #5
u'والمقدمى': u'وَالْمُقَدَّمِىُّ', #2
u'والمقرطس': u'وَالْمُقَرْطِسُ', #1
u'والمقرمات': u'وَالْمُقَرَّمَاتِ', #1
u'والمقروع': u'وَالْمَقْرُوعِ', #1
u'والمقروع': u'وَالْمَقْرُوعُ', #2
u'والمقريزي': u'وَالْمَقْرِيزِيُّ', #1
u'والمقشة': u'وَالْمِقَشَّةِ', #1
u'والمقشقشة': u'وَالْمُقَشْقِشَةُ', #1
u'والمقشور': u'وَالْمَقْشُورُ', #1
u'والمقشورة': u'وَالْمَقْشُورَةَ', #2
u'والمقضى': u'وَالْمَقْضِىِّ', #1
u'والمقضى': u'وَالْمُقْضَى', #5
u'والمقط': u'وَالْمَقَطُّ', #1
u'والمقط': u'وَالْمِقَطُّ', #1
u'والمقعطة': u'وَالْمُقْعَطَةُ', #1
u'والمقفز': u'وَالْمَقْفَزُ', #1
u'والمقلش': u'وَالْمُقَلِّشُ', #1
u'والمقلقلات': u'وَالْمُقَلْقِلَاتِ', #1
u'والمقلوة': u'وَالْمَقْلُوَّةُ', #1
u'والمقلوة': u'وَالْمَقْلُوَّةِ', #1
u'والمقمة': u'وَالْمِقَمَّةُ', #1
u'والمقوقس': u'وَالْمُقَوْقَسِ', #2
u'والمقير': u'وَالْمُقَيَّرَ', #1
u'والمقير،': u'وَالْمُقَيَّرُ،', #1
u'والمقير': u'وَالْمُقَيَّرِ', #18
u'والمقير،': u'وَالْمُقَيَّرِ،', #4
u'والمقير': u'وَالْمُقَيَّرُ', #5
u'والمقيس': u'وَالْمَقِيسُ', #30
u'والمقيس': u'وَالْمَقِيسِ', #49
u'والمقيس': u'وَالْمَقِيسَ', #5
u'والمقيسات': u'وَالْمَقِيسَاتِ', #1
u'والمقيسة': u'وَالْمَقِيسَةِ', #1
u'والمكاتبه': u'وَالْمُكَاتَبَهْ', #2
u'والمكاتل': u'وَالْمَكَاتِلَ', #1
u'والمكاتل': u'وَالْمَكَاتِلُ', #3
u'والمكارى': u'وَالْمُكَارَى', #4
u'والمكاس': u'وَالْمِكَاس', #1
u'والمكاس': u'وَالْمِكَاسَ', #1
u'والمكاس': u'وَالْمُكَّاسُ', #2
u'والمكاس': u'وَالْمُكَّاسِ', #2
u'والمكاس': u'وَالْمِكَاسُ', #2
u'والمكاس': u'وَالْمَكَّاسُ', #3
u'والمكاس': u'وَالْمَكَّاسِ', #5
u'والمكاسين': u'وَالْمَكَّاسِينَ', #3
u'والمكاعب': u'وَالْمَكَاعِبِ', #1
u'والمكاعمة': u'وَالْمُكَاعَمَةُ', #1
u'والمكاعمة': u'وَالْمُكَاعَمَةِ', #1
u'والمكامعة': u'وَالْمُكَامَعَةُ', #1
u'والمكامعة': u'وَالْمُكَامَعَةِ', #5
u'والمكانسية': u'والمكانسية', #1
u'والمكانع': u'والمكانع', #1
u'والمكايسة': u'وَالْمُكَايَسَةَ', #1
u'والمكايسة': u'وَالْمُكَايَسَةِ', #19
u'والمكايسة': u'وَالْمُكَايَسَةُ', #6
u'والمكبوب': u'وَالْمَكْبُوبُ', #1
u'والمكتراة': u'وَالْمُكْتَرَاةِ', #1
u'والمكترى': u'وَالْمُكْتَرَى', #5
u'والمكد': u'وَالْمُكِدُّ', #1
u'والمكربة': u'وَالْمَكْرُبَةِ', #1
u'والمكرى': u'وَالْمُكْرَى', #1
u'والمكسة': u'وَالْمَكَسَةِ', #3
u'والمكفت': u'وَالْمُكَفَّتُ', #1
u'والمكفت': u'وَالْمُكْفِتِ', #1
u'والمكفف': u'وَالْمُكَفَّفِ', #2
u'والمكفى': u'وَالْمُكْفَى', #1
u'والمكلب': u'وَالْمُكَلَّبُ', #1
u'والمكلبين': u'وَالْمُكَلِّبِينَ', #3
u'والمكلة': u'وَالْمَكْلَةُ', #1
u'والمكيس': u'وَالْمُكَيَّسُ', #2
u'والمكيون': u'وَالْمَكِّيُّونَ', #1
u'والملا': u'وَالْمَلَا', #5
u'والملأة': u'وَالْمِلْأَةِ', #1
u'والملاحان': u'وَالْمَلَّاحَانِ', #11
u'والملاذن': u'وَالْمَلَاذِنِ', #1
u'والملاق': u'وَالْمِلَاقُ', #1
u'والملاقى': u'وَالْمُلَاقَى', #2
u'والملاقيح': u'وَالْمَلَاقِيحَ', #1
u'والملاقيح': u'وَالْمَلاَقِيحُ', #2
u'والملاقيح': u'وَالْمَلاَقِيحِ', #2
u'والملاقيح': u'وَالْمَلَاقِيحِ', #27
u'والملاقيح': u'وَالْمَلَاقِيحُ', #32
u'والملالة': u'وَالْمَلَالَةِ', #1
u'والملانة': u'وَالْمُلَانَةَ', #1
u'والملاوذة': u'وَالْمُلَاوَذَةُ', #1
u'والملآئكة': u'وَالْمَلآئِكَةُ', #3
u'والملآئكة': u'وَالْمَلآئِكَةِ', #4
u'والملاية': u'وَالْمَلَايَةِ', #1
u'والملتوت': u'وَالْمَلْتُوتَ', #2
u'والملحب': u'وَالْمُلَحّبُ', #1
u'والملحفةوالوجه': u'وَالْمِلْحَفَةُوَالْوَجْهُ', #1
u'والملذوذات': u'وَالْمَلْذُوذَاتِ', #1
u'والملزز': u'وَالْمُلَزَّزُ', #1
u'والملزوق': u'وَالْمَلْزُوقِ', #1
u'والملزوم': u'وَالْمَلْزُومَ', #2
u'والملزوم': u'وَالْمَلْزُومِ', #3
u'والملزوم': u'وَالْمَلْزُومُ', #8
u'والملزومة': u'وَالْمَلْزُومَةُ', #2
u'والملزومية': u'والملزومية', #2
u'والملزومية': u'وَالْمَلْزُومِيَّة', #2
u'والملطأة': u'وَالْمِلْطَأَةَ', #1
u'والملطاة': u'وَالْمِلْطَاةِ', #1
u'والملطاة': u'وَالْمِلْطَاةُ', #2
u'والملطأة': u'وَالْمِلْطَأَةُ', #3
u'والملطاة': u'وَالْمِلْطَاةَ', #3
u'والملطة': u'وَالْمُلْطَةُ', #1
u'والملقوح': u'وَالْمَلْقُوحَ', #1
u'والملقوح': u'وَالْمَلْقُوحُ', #2
u'والملكانية': u'والملكانية', #1
u'والملكوم': u'وَالْمَلْكُومُ', #1
u'والملوان': u'وَالْمَلَوَانِ', #1
u'والملوط': u'وَالْمُلُوطُ', #2
u'والملوط': u'وَالْمُلُوطِ', #2
u'والملوط': u'وَالْمَلُوطِ', #4
u'والملومية': u'وَالْمَلُومِيَّةِ', #1
u'والمليق': u'وَالْمُلِيقُ', #1
u'والمليلة': u'وَالْمَلِيلَةَ', #1
u'والمماجن': u'وَالْمُمَاجِنُ', #1
u'والممادح': u'وَالْمَمَادِح', #1
u'والممادح': u'وَالْمَمَادِحِ', #1
u'والممايلة': u'وَالْمُمَايَلَةِ', #1
u'والممسح': u'وَالْمُمَسَّحُ', #1
u'والممشاة': u'وَالْمَمْشَاةِ', #1
u'والمملوح': u'وَالْمَمْلُوحُ', #1
u'والمملوح': u'وَالْمَمْلُوحِ', #1
u'والمملوس': u'وَالْمَمْلُوسِ', #1
u'والممنوعية': u'والممنوعية', #1
u'والممهور': u'وَالْمَمْهُورِ', #1
u'والممهورة': u'وَالْمَمْهُورَةُ', #3
u'والمنابزة': u'وَالْمُنَابَزَةِ', #2
u'والمناصلة': u'وَالْمُنَاصَلَةِ', #1
u'والمناطاة': u'وَالْمُنَاطَاةِ', #1
u'والمناكح': u'وَالْمَنَاكِحِ', #6
u'والمناكر': u'وَالْمَنَاكِرِ', #2
u'والمناكرة': u'وَالْمُنَاكَرَةُ', #3
u'والمناكيب': u'وَالْمَنَاكِيبُ', #1
u'والمناهز': u'وَالْمُنَاهِزُ', #4
u'والمنبوش': u'وَالْمَنْبُوشُ', #1
u'والمنبوشة': u'وَالْمَنْبُوشَةِ', #1
u'والمنتثر': u'وَالْمُنْتَثِرِ', #1
u'والمنتفى': u'وَالْمُنْتَفَى', #2
u'والمنتهب': u'وَالْمُنْتَهَبُ', #1
u'والمنتهب': u'وَالْمُنْتَهَبِ', #1
u'والمنتهب': u'وَالْمُنْتَهِبُ', #1
u'والمنتهب': u'وَالْمُنْتَهِبِ', #9
u'والمنتهبة': u'وَالْمُنْتَهِبَةَ', #1
u'والمنتهبة': u'وَالْمُنْتَهِبَةُ', #1
u'والمنتهبون': u'وَالْمُنْتَهَبُونَ', #2
u'والمنتهبين': u'وَالْمُنْتَهَبِينَ', #1
u'والمنتهبين': u'وَالْمُنْتَهِبِينَ', #2
u'والمنتوف': u'وَالْمَنْتُوفُ', #1
u'والمنتوف': u'وَالْمَنْتُوفِ', #1
u'والمنجا': u'وَالْمَنْجَا', #1
u'والمنجنون': u'وَالْمَنْجَنُونِ', #1
u'والمنجنون': u'وَالْمَنْجَنُونُ', #2
u'والمنحمنا': u'وَالْمُنْحَمَنّا', #1
u'والمنخرقة': u'وَالْمُنْخَرِقَةُ', #1
u'والمنخل': u'وَالْمُنْخُلِ', #7
u'والمندبغ': u'وَالْمُنْدَبِغُ', #2
u'والمندورة': u'وَالْمَنْدُورَةَ', #1
u'والمنذري': u'وَالْمُنْذِرِيِّ', #1
u'والمنذري': u'وَالْمُنْذِرِيُّ', #16
u'والمنزوح': u'وَالْمَنْزُوحُ', #3
u'والمنزور': u'وَالْمَنْزُورِ', #1
u'والمنسر': u'وَالْمَنْسَرُ', #1
u'والمنسر': u'وَالْمَنْسِرُ', #2
u'والمنسر': u'وَالْمِنْسَرُ', #2
u'والمنشعب': u'وَالْمُنْشَعِبِ', #2
u'والمنشعبة': u'وَالْمُنْشَعِبَةَ', #1
u'والمنصورية': u'وَالْمَنْصُورِيَّةُ', #1
u'والمنعل': u'وَالْمُنْعَلُ', #1
u'والمنعل': u'وَالْمُنَعَّلِ', #3
u'والمنعل': u'وَالْمُنْعَلِ', #3
u'والمنعل': u'وَالْمُنَعَّلُ', #6
u'والمنعلين': u'وَالْمُنْعَلَيْنِ', #1
u'والمنفح': u'وَالْمِنْفَحُ', #1
u'والمنفحة': u'وَالْمِنْفَحَةُ', #1
u'والمنفصله': u'وَالْمُنْفَصِلَهْ', #1
u'والمنفكان': u'وَالْمُنْفَكَّانِ', #1
u'والمنفوذة': u'وَالْمَنْفُوذَةُ', #1
u'والمنقال': u'وَالْمِنْقَالُ', #1
u'والمنقشة': u'وَالْمُنَقَّشَةِ', #3
u'والمنقود': u'وَالْمَنْقُودِ', #2
u'والمنقودة': u'وَالْمَنْقُودَةُ', #1
u'والمنكسود': u'وَالْمَنْكسُودُ', #1
u'والمنلا': u'وَالْمُنْلَا', #3
u'والمنهبة': u'وَالْمُنْهِبَةُ', #1
u'والمنهوش': u'وَالْمَنْهُوشِ', #1
u'والمنهى': u'وَالْمُنْهَى', #5
u'والمنوب': u'وَالْمَنُوبَ', #1
u'والمنوب': u'وَالْمَنُوبِ', #2
u'والمنوب': u'وَالْمَنُوبُ', #4
u'والمنوفي': u'وَالْمَنُوفِيُّ', #2
u'والمنيح': u'وَالْمَنِيحُ', #1
u'والمنيحة': u'وَالْمَنِيحَةُ', #5
u'والمنيعى': u'وَالْمَنِيعِىُّ', #2
u'والمنيئة': u'وَالْمَنِيئَةُ', #2
u'والمهاجره': u'وَالْمُهَاجِرَه', #1
u'والمهاجره،': u'وَالْمُهَاجِرَهْ،', #2
u'والمهاجره': u'وَالْمُهَاجِرَهْ', #44
u'والمهاجري': u'وَالْمُهَاجِرِيّ', #1
u'والمهاجري': u'وَالْمُهَاجِرِيُّ', #2
u'والمهاجنة': u'وَالْمُهَاجَنَةِ', #1
u'والمهارشة': u'وَالْمُهَارَشَةَ', #1
u'والمهازيل': u'وَالْمَهَازِيلِ', #3
u'والمهامن': u'وَالْمَهَامِنُ', #1
u'والمهامه': u'وَالْمَهَامِهِ', #4
u'والمهايأة': u'وَالْمُهَايَأَةَ', #1
u'والمهايأة': u'وَالْمُهَايَأَةُ', #41
u'والمهايأة': u'وَالْمُهَايَأَةِ', #5
u'والمهايات': u'وَالْمُهَايَاتِ', #1
u'والمهايئات': u'وَالْمُهَايَئَاتُ', #1
u'والمهتدى': u'وَالْمُهْتَدَى', #1
u'والمهتديه': u'وَالْمُهْتَدِيَهْ', #1
u'والمهدول': u'وَالْمَهْدُولُ', #1
u'والمهدوي': u'وَالْمَهْدَوِيِّ', #2
u'والمهروب': u'وَالْمَهْرُوبُ', #1
u'والمهقوع': u'وَالْمَهْقُوعُ', #3
u'والمهلب': u'وَالْمُهَلَّبُ', #4
u'والمهملج': u'وَالْمُهَمْلِجُ', #2
u'والمهملجة': u'وَالْمُهَمْلَجَةُ', #1
u'والمهملجة': u'وَالْمُهَمْلِجَةُ', #1
u'والمهندم': u'وَالْمُهَنْدَمُ', #1
u'والمهير': u'وَالْمَهِيرُ', #3
u'والموءودة': u'وَالْمَوْءُودَةَ', #1
u'والموءودة': u'وَالْمَوْءُودَةُ', #6
u'والمؤاجر': u'وَالْمُؤَاجَرُ', #1
u'والمؤاجر': u'وَالْمُؤَاجَرِ', #1
u'والمؤاجر': u'وَالْمُؤَاجِرُ', #6
u'والمؤاجرة': u'وَالْمُؤَاجَرَةُ', #1
u'والمؤاجرة': u'وَالْمُؤَاجَرَةِ', #1
u'والمواجل': u'وَالْمَوَاجِلِ', #2
u'والمواجل': u'وَالْمَوَاجِلُ', #6
u'والمواجيد': u'وَالْمَوَاجِيدُ', #1
u'والمواجير': u'وَالْمَوَاجِيرِ', #2
u'والمواخاة': u'وَالْمُوَاخَاةُ', #1
u'والموادعين': u'وَالْمُوَادَعِينَ', #1
u'والمؤادمة': u'وَالْمُؤَادَمَةُ', #2
u'والموارثة': u'والموارثة', #2
u'والموارثة': u'وَالْمُوَارَثَةُ', #2
u'والموارثة': u'وَالْمُوَارَثَةِ', #2
u'والموازيني': u'وَالْمَوَازِينِيِّ', #1
u'والمواسى': u'والمواسى', #1
u'والمواشى': u'وَالْمَوَاشِى', #1
u'والمواضح': u'وَالْمَوَاضِحِ', #13
u'والمواضح': u'وَالْمَوَاضِحُ', #2
u'والمواضعة': u'وَالْمُوَاضَعَةُ', #17
u'والمواضعة': u'وَالْمُوَاضَعَةِ', #21
u'والمواضعة': u'وَالْمُوَاضَعَةَ', #3
u'والمواق': u'وَالْمَوَّاقَ', #10
u'والمواق': u'وَالْمَوَّاقُ', #49
u'والمواق': u'وَالْمَوَّاقِ', #73
u'والمواكل': u'وَالْمُوَاكِلُ', #1
u'والموالات': u'وَالْمُوَالَاتِ', #1
u'والموالدات': u'وَالْمُوَالَدَاتِ', #1
u'والمؤبر': u'وَالْمُؤَبَّرُ', #1
u'والمؤبرة': u'وَالْمُؤَبَّرَةُ', #2
u'والموتان': u'وَالْمَوْتَانَ', #1
u'والموتان': u'وَالْمَوَتَانُ', #3
u'والموتان': u'وَالْمَوْتَانُ', #3
u'والمؤتشرة': u'وَالْمُؤْتَشِرَةَ', #1
u'والموتشرة': u'وَالْمُوتَشِرَةَ', #1
u'والمؤتشمة': u'وَالْمُؤْتَشِمَةُ', #1
u'والموتشمة': u'وَالْمُوتَشِمَة', #1
u'والموتشمة': u'وَالْمُوتَشِمَةُ', #1
u'والموتشمة': u'وَالْمُوْتَشِمَة', #1
u'والمؤتشمة': u'وَالْمُؤْتَشِمَةَ', #2
u'والموتشمة': u'وَالْمُوتَشِمَةَ', #4
u'والموتصل': u'وَالْمُوتَصِلُ', #1
u'والموتصلة': u'وَالْمُوتَصِلَةَ', #1
u'والمؤتم': u'وَالْمُؤْتَمُّ', #18
u'والمؤتم': u'وَالْمُؤْتَمَّ', #2
u'والمؤتم': u'وَالْمُؤْتَمِّ', #4
u'والمؤتى': u'وَالْمُؤْتَى', #1
u'والمؤثمة': u'وَالْمُؤَثِّمَةُ', #1
u'والمؤثمة': u'وَالْمُؤَثِّمَةِ', #1
u'والمؤثمة': u'وَالْمُؤْثِمَةِ', #1
u'والموجد': u'وَالْمُوجِدِ', #2
u'والموجد': u'وَالْمُوجِدُ', #3
u'والموجرة': u'وَالْمُوجَرَةِ', #1
u'والموجوء': u'وَالْمَوْجُوءُ', #10
u'والموجوءين': u'وَالْمَوْجُوءَيْنِ', #1
u'والموجئ': u'وَالْمُوجِئِ', #1
u'والمؤخذ': u'وَالْمُؤَخَّذُ', #1
u'والمؤذى': u'والمؤذى', #1
u'والمؤربات': u'وَالْمُؤَرَّبَاتُ', #1
u'والموربات': u'وَالْمُوَرِّبَاتُ', #1
u'والمورس': u'وَالْمُورِسِ', #1
u'والمورس': u'وَالْمُوَرَّسَ', #1
u'والمورس': u'وَالْمُوَرَّسُ', #1
u'والمورس': u'وَالْمُوَرَّسِ', #4
u'والمورقون': u'وَالْمُوَرِّقُونَ', #1
u'والمورود': u'وَالْمَوْرُودُ', #1
u'والمورود': u'وَالْمَوْرُودِ', #1
u'والموسمات': u'وَالْمُوسِمَاتِ', #1
u'والموصف': u'وَالْمُوَصَّفِ', #1
u'والموصوليتين': u'وَالْمَوْصُولِيَّتَيْنِ', #1
u'والموطوء': u'وَالْمَوْطُوءُ', #1
u'والموطوء': u'وَالْمَوْطُوءَ', #2
u'والموطوء': u'وَالْمَوْطُوءِ', #2
u'والموطوءة': u'وَالْمَوْطُوءَةُ', #30
u'والموطوءة': u'وَالْمَوْطُوءَةِ', #57
u'والموطوءة': u'وَالْمَوْطُوءَةَ', #9
u'والموعى': u'وَالْمُوعَى', #1
u'والموقود': u'وَالْمَوْقُودِ', #1
u'والموقوذ': u'وَالْمَوْقُوذ', #1
u'والموقوذة': u'وَالْمَوْقُوذَة', #1
u'والموقوذة': u'وَالْمَوْقُوذَةَ', #3
u'والموقوذة': u'وَالْمَوْقُوذَةُ', #33
u'والموقوذة': u'وَالْمَوْقُوذَةِ', #5
u'والموقوع': u'وَالْمَوْقُوعُ', #1
u'والموقوع': u'وَالْمَوْقُوعِ', #1
u'والمولم': u'وَالْمُولِمِ', #1
u'والمولودية': u'وَالْمَوْلُودِيَّة', #1
u'والمؤلي': u'وَالْمُؤْلِي', #1
u'والمؤلى': u'وَالْمُؤْلَى', #1
u'والمومي': u'وَالْمُومِي', #2
u'والمومئ': u'وَالْمُومِئِ', #10
u'والمومئ': u'وَالْمُومِئُ', #9
u'والموميا': u'وَالْمُومْيَا', #3
u'والمؤنة،': u'والمَؤْنَةَ،', #1
u'والمؤنة': u'وَالْمُؤْنَةَ', #11
u'والمؤنة': u'وَالْمُؤْنَةُ', #57
u'والمؤنة': u'وَالْمُؤْنَةِ', #65
u'والموهب': u'وَالْمُوهِبُ', #1
u'والمؤوف': u'وَالْمَؤُوفُ', #1
u'والمئتي': u'وَالْمِئَتَيْ', #2
u'والمئون': u'وَالْمِئُونَ', #1
u'والمئونة': u'وَالْمَئُونَة', #1
u'والمئونة،': u'وَالْمَئُونَةَ،', #1
u'والمئونة': u'وَالْمَئُونَةِ', #17
u'والمئونة': u'وَالْمَئُونَةَ', #2
u'والمئونة': u'وَالْمَئُونَةُ', #2
u'والمياثر': u'وَالْمَيَاثِر', #1
u'والمياثر': u'وَالْمَيَاثِرُ', #1
u'والمياثر': u'وَالْمَيَاثِرِِِِِِِِِ', #1
u'والمياثر،': u'وَالْمَيَاثِرِ،', #1
u'والمياثر': u'وَالْمَيَاثِرِ', #7
u'والمياخونة': u'والمياخونة', #1
u'والميتاء': u'وَالْمِيتَاءُ', #1
u'والميثرة': u'وَالْمِيثَرَةُُُُِ', #1
u'والميثرة': u'وَالْمِيثَرَةِ', #17
u'والميثرة،': u'وَالْمِيثَرَةِ،', #5
u'والميثرة': u'وَالْمِيثَرَةُ', #6
u'والميثم': u'وَالْمِيثَمِ', #1
u'والمير': u'وَالْمَيْرِ', #2
u'والميرة': u'وَالْمِيرَةِ', #4
u'والميرة': u'وَالْمِيرَةُ', #5
u'والميري': u'وَالْمِيرِيّ', #1
u'والميري': u'وَالْمِيرِيِّ', #2
u'والميش': u'وَالْمَيْشُ', #1
u'والميطار': u'وَالْمِيطَارُ', #1
u'والميف': u'وَالمِيفُ', #1
u'والميفعة': u'وَالْمَيْفَعَةُ', #1
u'والميقاتات': u'والمِيقَاتَاتُ', #1
u'والميقعة': u'وَالْمِيقَعَةُ', #1
u'والميقعة': u'وَالْمِيقَعَةِ', #1
u'والميلق': u'وَالْمَيْلَقُ', #1
u'والميموني،': u'والْمَيْمُونِيُّ،', #1
u'والميموني': u'وَالْمَيْمُونِي', #1
u'والميموني،': u'وَالْمَيْمُونِيِّ،', #1
u'والميموني': u'وَالْمَيْمُونِيُّ', #25
u'والميموني،': u'وَالْمَيْمُونِيُّ،', #3
u'والميموني': u'وَالْمَيْمُونِيِّ', #8
u'والميولات': u'وَالْمُيُولَاتِ', #3
u'والميئوس': u'وَالْمَيْئُوسِ', #1
u'والناجش': u'والناجش', #1
u'والناجش': u'وَالنَّاجِشُ', #2
u'والناد': u'وَالنَّادُّ', #3
u'والناد': u'وَالنَّادِّ', #4
u'والنارنج': u'وَالنَّارِنْجَ', #4
u'والنارنج': u'وَالنَّارِنْجُ', #4
u'والنارنج': u'وَالنَّارِنْجِ', #5
u'والنازلي': u'وَالنَّازِلِيِّ', #1
u'والناستج': u'والناستج', #1
u'والناسوت': u'وَالنَّاسُوتِ', #2
u'والناسور': u'وَالنَّاسُورُ', #1
u'والناسور': u'وَالنَّاسُورِ', #3
u'والناصور': u'وَالنَّاصُورُ', #2
u'والناض': u'وَالنَّاضِّ', #2
u'والناض': u'وَالنَّاضُّ', #9
u'والناطفي': u'وَالنَّاطِفِيُّ', #10
u'والناطقي': u'وَالنَّاطِقِيُّ', #1
u'والناطقية': u'وَالنَّاطِقِيَّةِ', #3
u'والناعور': u'وَالنَّاعُورُ', #1
u'والناعور': u'وَالنَّاعُورِ', #1
u'والنافقاء': u'وَالنَّافِقَاءُ', #1
u'والنافقاء': u'وَالنَّافِقَاءِ', #1
u'والنامصات': u'وَالنَّامِصَاتِ', #2
u'والنامصة': u'وَالنَّامِصَة', #1
u'والنامصة،': u'وَالنَّامِصَةِ،', #1
u'والنامصة': u'وَالنَّامِصَةِ', #3
u'والنامصة': u'وَالنَّامِصَةَ', #9
u'والنامصة': u'وَالنَّامِصَةُ', #9
u'والنانخواه': u'والنانخواه', #1
u'والناوق': u'وَالنَّاوِقُ', #1
u'والناووس': u'وَالنَّاوُوسُ', #1
u'والناووق': u'وَالنَّاوُوقُ', #1
u'والنائرة': u'وَالنَّائِرَةُ', #2
u'والنباذ': u'وَالنِّبَاذِ', #1
u'والنباذ': u'وَالنِّبَاذِِِِِ', #1
u'والنبلSشعر': u'وَالنّبْلِSشِعْرُ', #1
u'والنبهرج': u'وَالنَّبَهْرَجُ', #3
u'والنبهرجة': u'وَالنَّبَهْرَجَةِ', #23
u'والنبهرجة': u'وَالنَّبَهْرَجَةُ', #24
u'والنبهرجة': u'وَالنَّبَهْرَجَةَ', #9
u'والنبى': u'وَالنَّبِىِّ', #1
u'والنبى': u'وَالنَّبِىَّ', #2
u'والنبى': u'وَالنَّبِىُّ', #61
u'والنبيت': u'والنّبِيتِ', #1
u'والنبيت': u'وَالنّبِيتَ', #1
u'والنبيت': u'وَالنَّبِيتِ', #1
u'والنبيت': u'وَالنّبِيتِ', #2
u'والنبيت': u'وَالنّبِيتُ', #3
u'والنبيعة': u'وَالنُّبَيْعَةُ', #1
u'والنتق': u'وَالنَّتْق', #1
u'والنتق': u'وَالنَّتْقُ', #2
u'والنثا': u'وَالنَّثَا', #1
u'والنثاء': u'وَالنَّثَاءُ', #1
u'والنثاء': u'وَالنِّثَاءُ', #1
u'والنج': u'وَالنّجْ', #1
u'والنجاشى': u'وَالنَّجَاشِىُّ', #1
u'والنجاشى': u'وَالنَّجَاشِىِّ', #2
u'والنجام': u'وَالنّجَامِ', #2
u'والنجام': u'وَالنّجّامُ', #2
u'والنجذ': u'وَالنَّجْذُ', #1
u'والنجراني': u'وَالنّجْرَانِيّ', #2
u'والنجش': u'وَالنَّجَشِ', #1
u'والنجش': u'وَالنَّجْش', #1
u'والنجش،': u'وَالنَّجْشِ،', #1
u'والنجش': u'وَالنَّجْشِ', #10
u'والنجش': u'وَالنَّجْشُ', #20
u'والنجش': u'وَالنَّجَشُ', #4
u'والنجيح': u'وَالنَّجِيحِ', #1
u'والنجير': u'وَالنّجَيْرُ', #1
u'والنجير': u'وَالنُّجَيْرُ', #1
u'والنحاز': u'وَالنّحَازُ', #1
u'والنحز': u'وَالنّحْزُ', #1
u'والنحض': u'وَالنّحْضُ', #1
u'والنحمة': u'وَالنّحْمَةُ', #1
u'والنحمة': u'وَالنَّحْمَةُ', #3
u'والنحوسة': u'وَالنُّحُوسَةِ', #1
u'والنخام': u'وَالنِّخَامِ', #1
u'والنخام': u'وَالنُّخَامَ', #2
u'والنخام': u'وَالنُّخَامِ', #2
u'والنخبار': u'وَالنّخْبَارُ', #1
u'والنخة': u'وَالنَّخَّةِ', #1
u'والنخة': u'وَالنُّخَّة', #1
u'والنخة': u'وَالنُّخَّةَ', #1
u'والنخة': u'وَالنَّخَّةُ', #2
u'والنخة': u'وَالنُّخَّةِ', #2
u'والنخة': u'وَالنُّخَّةُ', #6
u'والنخعي': u'وَالنَّخَعِيّ', #1
u'والنخعى': u'وَالنَّخَعِىِّ', #20
u'والنخعي،': u'وَالنَّخَعِيِّ،', #27
u'والنخعي': u'وَالنَّخَعِيَّ', #3
u'والنخعى': u'وَالنَّخَعِىُّ', #3
u'والنخعي،': u'وَالنَّخْعِيِّ،', #4
u'والنخعى': u'وَالنَّخْعِىِّ', #4
u'والنخعي': u'وَالنَّخَعِيُّ', #81
u'والنخعي': u'وَالنَّخَعِيِّ', #83
u'والنخغي': u'وَالنَّخَغِيّ', #1
u'والنخماس': u'وَالنّخْمَاس', #1
u'والنخيلات': u'وَالنُّخَيْلَاتِ', #1
u'والندا': u'وَالنَّدَا', #1
u'والنردشير': u'وَالنَّرْدَشِيرُ', #2
u'والنردشير': u'وَالنَّرْدَشِيرِ', #2
u'والنرسى': u'وَالنَّرْسِىُّ', #1
u'والنسأ': u'وَالنَّسَأِ', #1
u'والنسإ': u'وَالنَّسَإِ', #1
u'والنسأ': u'وَالنَّسَأُ', #2
u'والنسآء': u'وَالنِّسَآء', #1
u'والنساءكالوتر': u'وَالنِّسَاءِكَالْوَتْرِ', #1
u'والنسون': u'وَالنِّسُونُ', #1
u'والنسيء': u'وَالنّسِيءَ', #1
u'والنسيء': u'وَالنَّسِيءُ', #1
u'والنسيء': u'وَالنّسِيءُ', #2
u'والنسيبا': u'وَالنَّسِيبَا', #1
u'والنسيبة': u'وَالنَّسِيبَةُ', #2
u'والنسيك': u'وَالنَّسِيكُ', #1
u'والنسيل': u'وَالنّسِيلَ', #1
u'والنشاءة': u'وَالنَّشَاءَةُ', #1
u'والنشارين': u'وَالنَّشَّارِينَ', #1
u'والنشائي': u'وَالنَّشَائِيِّ', #2
u'والنشائي': u'وَالنَّشَائِيُّ', #22
u'والنشيلي': u'وَالنَّشِيلَيْ', #1
u'والنصاري': u'والنصاري', #1
u'والنصاري': u'وَالنَّصَّارِي', #2
u'والنصرانى': u'وَالنَّصْرانِىِّ', #1
u'والنصرانى': u'وَالنَّصْرَانِىَّ', #1
u'والنصرانى': u'وَالنَّصْرَانِىِّ', #4
u'والنصرانى': u'وَالنَّصْرَانِىُّ', #7
u'والنصرتي': u'وَالنُّصْرُتِيِّ', #3
u'والنصيرية': u'وَالنُّصَيْرِيَّةَ', #1
u'والنصيرية': u'وَالنُّصَيْرِيَّةُ', #5
u'والنصيرية': u'وَالنُّصَيْرِيَّةِ', #6
u'والنضوض': u'وَالنُّضُوضُ', #1
u'والنضوض': u'وَالنَّضُوضِ', #3
u'والنطاة': u'وَالنّطَاةُ', #1
u'والنطاة': u'وَالنَّطَّاةَ', #1
u'والنطاة': u'وَالنّطَاةَ', #2
u'والنطاة': u'وَالنَّطَاةِ', #4
u'والنطاة': u'وَالنّطَاةِ', #5
u'والنطاة': u'وَالنَّطَاةَ', #5
u'والنطاة': u'وَالنَّطَاةُ', #5
u'والنطرون': u'وَالنَّطْرُونِ', #1
u'والنطرون': u'والنطرون', #2
u'والنطرون': u'وَالنَّطْرُونُ', #3
u'والنطقاء': u'وَالنُّطَقَاءُ', #1
u'والنظاره': u'وَالنَّظَّارَهْ', #1
u'والنع': u'وَالنّعِ', #1
u'والنعثل': u'والنَّعْثَل', #1
u'والنعف': u'وَالنَّعْفُ', #1
u'والنعما': u'وَالنّعما', #1
u'والنعما': u'وَالنّعَمَا', #1
u'والنعوس': u'وَالنّعُوسُ', #2
u'والنغض': u'وَالنُّغْضُ', #1
u'والنفاقوالوجه': u'وَالنِّفَاقِوَالْوَجْهُ', #1
u'والنفة': u'وَالنَّفَّةِ', #1
u'والنفقه': u'وَالنَّفَقَهْ', #1
u'والنفى': u'وَالنَّفْىِ', #1
u'والنفيلي': u'وَالنُّفَيْلِيُّ', #1
u'والنفيلي': u'وَالنُّفَيْلِيِّ', #1
u'والنفيلي،': u'وَالنُّفَيْلِيُّ،', #7
u'والنقاخ': u'وَالنُّقَاخُ', #1
u'والنقاية': u'وَالنُّقَايَةُ', #1
u'والنقاية': u'وَالنُّقَايَةِ', #45
u'والنقروي': u'وَالنَّقْرَوِيِّ', #1
u'والنقشواني': u'والنقشواني', #2
u'والنقفا': u'وَالنّقْفَا', #3
u'والنقى': u'وَالنَّقَى', #2
u'والنقيف': u'وَالنّقِيفُ', #1
u'والنقيلة': u'وَالنَّقِيلَةِ', #4
u'والنكولة': u'وَالنُّكُولَةُ', #1
u'والنكي': u'وَالنَّكْي', #1
u'والنما': u'وَالنَّمَا', #2
u'والنمار': u'وَالنِّمَارُ', #1
u'والنماص': u'وَالنِّمَاص', #1
u'والنمرقة': u'وَالنِّمْرُقَةُ', #1
u'والنمرقة': u'وَالنُّمْرُقَةُ', #2
u'والنمريخ': u'والنمريخ', #2
u'والنمص': u'وَالنَّمْصِ', #1
u'والنميري': u'وَالنُّمَيْرِيُّ', #2
u'والنهاروالوجه': u'وَالنَّهَارِوَالْوَجْهُ', #1
u'والنهاروفى': u'وَالنَّهَارِوفِى', #1
u'والنهاس': u'وَالنَّهَّاسُ', #3
u'والنهبرة': u'وَالنَّهْبَرَةِ', #2
u'والنهبى': u'وَالنُّهْبَى', #3
u'والنهرا': u'وَالنَّهَرَا', #1
u'والنهرتيري،': u'وَالنَّهْرَتِيرِيُّ،', #1
u'والنهروان،': u'وَالنَّهْرَوانِ،', #1
u'والنهروان': u'وَالنّهْرَوَان', #1
u'والنهروان': u'وَالنَّهْرَوَانَ', #1
u'والنهروان': u'وَالنَّهْرَوَانِ', #6
u'والنهس': u'وَالنُّهَسُ', #1
u'والنهوب': u'وَالنُّهُوبَ', #1
u'والنهوب': u'وَالنُّهُوبُ', #1
u'والنهوب': u'وَالنُّهُوبِ', #2
u'والنهوش': u'وَالنُّهُوشِ', #1
u'والنهيء': u'وَالنّهِيءُ', #1
u'والنهيية': u'وَالنَّهْيِيَّةِ', #1
u'والنواقض': u'وَالنَّوَاقِضُ', #1
u'والنواكة': u'وَالنَّوَاكَةُ', #1
u'والنورا': u'وَالنُّورَا', #1
u'والنورة': u'والنورة', #1
u'والنورة': u'وَالنُّورَةُ', #16
u'والنورة': u'وَالنَّوْرَةُ', #2
u'والنورة': u'وَالنَّوْرَةِ', #2
u'والنورة': u'وَالنُّورَةَ', #4
u'والنورة': u'وَالنُّورَةِ', #62
u'والنوفر': u'وَالنَّوْفَرِ', #1
u'والنوفلي': u'وَالنَّوْفَلِيِّ', #1
u'والنؤي': u'وَالنّؤْيُ', #2
u'والنؤي': u'وَالنُّؤْيَ', #2
u'والنؤي': u'وَالنُّؤْيُ', #4
u'والنياحة': u'وَالنِّيَاحَةَ', #1
u'والنياحة': u'وَالنّيَاحَةَ', #1
u'والنياحة': u'وَالنِّيَاحَةِ', #16
u'والنياحة': u'وَالنِّيَاحَةُ', #33
u'والنيدة': u'وَالنِّيدَةِ', #1
u'والنيرنجات': u'وَالنِّيرَنْجَاتُ', #2
u'والنيسابوري': u'وَالنَّيْسَابُورِيّ', #4
u'والنيق': u'وَالنّيقُ', #1
u'والنيك': u'وَالنَّيْكِ', #2
u'والنيك': u'وَالنَّيْكُ', #4
u'والنيلة': u'وَالنِّيلَةُ', #2
u'والنيلة': u'وَالنِّيلَةِ', #3
u'والنيمرشت': u'وَالنِّيمَرِشْتُ', #1
u'والهار': u'وَالْهَارُ', #1
u'والهالع': u'وَالْهَالِعُ', #1
u'والهبع': u'وَالْهُبَعُ', #1
u'والهبع': u'وَالْهُبَعِ', #1
u'والهتوع': u'وَالْهُتُوعُ', #1
u'والهجف': u'وَالْهِجَفّ', #1
u'والهجلة': u'وَالْهَجْلَةِ', #1
u'والهجهجة': u'وَالْهَجْهَجَة', #1
u'والهدبد': u'وَالْهُدَبِدُ', #1
u'والهدمى': u'وَالْهَدْمَى', #13
u'والهدو': u'وَالْهُدُوِّ', #1
u'والهديم': u'وَالْهَدِيمُ', #1
u'والهذ': u'وَالْهَذّ', #1
u'والهذ': u'وَالْهَذِّ', #1
u'والهذايانات': u'وَالْهَذَايَانَاتِ', #2
u'والهذيل': u'وَالْهُذَيْلُ', #1
u'والهذيلية': u'وَالْهُذَيْلِيَّةُ', #1
u'والهرادي': u'والهرادي', #1
u'والهرادي': u'وَالْهَرَادِي', #1
u'والهرادي': u'وَالْهَرَادِيِّ', #1
u'والهرادي': u'وَالْهَرَادِيّ', #3
u'والهرادي': u'وَالْهَرَادِيُّ', #7
u'والهراشي': u'وَالْهَرَّاشِيُّ', #1
u'والهراقة': u'وَالْهِرَاقَة', #1
u'والهرائس': u'وَالْهَرَائِسَ', #1
u'والهرائس': u'وَالْهَرَائِسِ', #2
u'والهرايس': u'وَالْهَرَايِسِ', #1
u'والهرطبان': u'وَالْهُرْطُبَانِ', #1
u'والهرطمان': u'وَالْهَرْطَمَانُ', #1
u'والهرطمان': u'وَالْهُرْطُمَانِ', #1
u'والهرطمان': u'وَالْهُرْطُمَانُ', #3
u'والهرماس': u'وَالْهِرْمَاسِ', #1
u'والهرماس': u'وَالْهِرْمَاسُ', #2
u'والهرمزان': u'والهُرْمُزَان', #1
u'والهرمزان،': u'والهُرْمُزَان،', #2
u'والهرمزان': u'وَالْهُرْمُزَانِ', #3
u'والهروى': u'وَالْهَرَوِىِّ', #1
u'والهزهاز': u'وَالْهَزْهَازِ', #1
u'والهزؤ': u'وَالْهُزُؤُ', #1
u'والهزو': u'وَالْهَزْوُ', #1
u'والهزو': u'وَالْهُزُوُ', #1
u'والهزو': u'وَالْهُزُوِ', #1
u'والهقعة': u'وَالْهَقْعَةُ', #4
u'والهقل': u'وَالْهِقْلُ', #3
u'والهلب': u'وَالْهُلْبِ', #1
u'والهلباء': u'وَالْهَلْبَاءُ', #1
u'والهلبة': u'وَالْهُلْبَةُ', #1
u'والهلقام': u'وَالْهِلْقَامُ', #1
u'والهلكه': u'وَالْهَلَكَهْ', #1
u'والهلوف': u'وَالْهِلَّوْفُ', #3
u'والهليلج': u'وَالْهَلِيلَجِ', #2
u'والهليلجة': u'وَالهَلَيْلَجَةِ', #1
u'والهليلجة': u'وَالْهَلِيلَجَة', #1
u'والهليلجة': u'وَالْهَلِيلَجَةِ', #1
u'والهمداني': u'وَالْهَمْدَانِيَّ', #1
u'والهمدانية': u'والهمدانية', #1
u'والهمط': u'وَالْهَمْطُ', #2
u'والهملاج': u'وَالْهِمْلَاجُ', #3
u'والهملجة': u'وَالْهَمْلَجَةِ', #1
u'والهملجة': u'وَالْهِمْلَجَةُ', #1
u'والهملجة': u'وَالْهَمْلَجَةُ', #2
u'والهملع': u'وَالْهَمَلّعُ', #1
u'والهميس': u'وَالْهَمِيسُ', #2
u'والهنب': u'وَالْهَنَبُ', #1
u'والهندات': u'وَالْهِنْدَاتِ', #1
u'والهندباء': u'وَالْهِنْدَبَاءِ', #1
u'والهندباء': u'وَالْهِنْدِبَاءُ', #2
u'والهندرة': u'وَالْهَنْدَرَةِ', #2
u'والهندواني': u'وَالْهِنْدُوَانِي', #10
u'والهندواني': u'وَالْهِنْدُوانِيُّ', #4
u'والهنطية': u'وَالْهِنْطِيَّةِ', #1
u'والهنعة': u'وَالْهَنْعَةُ', #2
u'والهنوك': u'وَالْهُنُوكَ', #1
u'والهنوك': u'وَالْهُنُوكُ', #1
u'والهنوك': u'وَالْهُنُوكِ', #3
u'والهنيد': u'وَالْهُنَيْدِ', #1
u'والهنيدة': u'وَالْهُنَيْدَةِ', #1
u'والهوافي': u'وَالْهَوَافِي', #2
u'والهيبان': u'وَالْهَيَبَانُ', #1
u'والهيبان': u'وَالْهَيّبَانُ', #1
u'والهيبان': u'وَالْهَيْبَانُ', #1
u'والهيذام': u'وَالْهَيْذَامُ', #1
u'والهيضة': u'وَالْهَيْضَةِ', #1
u'والهيطلية': u'والهيطلية', #1
u'والهيعة': u'وَالْهَيْعَةُ', #4
u'والهيلج': u'وَالْهَيْلَجُ', #1
u'والهيميا': u'وَالْهِيمْيَا', #2
u'والهيمياء': u'وَالْهِيمْيَاءُ', #2
u'والهيمياء': u'وَالْهِيمْيَاءِ', #2
u'والهينمة': u'وَالْهَيْنَمَةُ', #1
u'والواجبية': u'وَالْوَاجِبِيَّةِ', #1
u'والواحدي': u'وَالْوَاحِدِيِّ', #3
u'والواحدي': u'وَالْوَاحِدِيُّ', #8
u'والواشرة': u'وَالْوَاشِرَةِ', #1
u'والواشرة': u'وَالْوَاشِرَةَ', #10
u'والواشرة': u'وَالْوَاشِرَةُ', #6
u'والواصب': u'وَالْوَاصِبُ', #1
u'والوافدي،': u'وَالْوَافِدِيُّ،', #1
u'والواقدى': u'وَالْوَاقِدِىِّ', #1
u'والواقدي': u'وَالْوَاقِدِيُّ', #10
u'والواقدي': u'والواقِديّ', #2
u'والواقدي': u'وَالْوَاقِدِيّ', #3
u'والواقدي': u'وَالْوَاقِدِيِّ', #4
u'والواقدي،': u'وَالْوَاقِدِيُّ،', #6
u'والواقصة': u'وَالْوَاقِصَةِ', #7
u'والواقفية': u'وَالْوَاقِفِيَّةُ', #2
u'والواقفية': u'وَالْوَاقِفِيَّةِ', #2
u'والوالجي': u'وَالْوَالِجِيِّ', #1
u'والوالجية': u'وَالْوَالِجِيَّةُ', #4
u'والوالدية': u'وَالْوَالِدِيَّةُ', #1
u'والوالولجية': u'والوالولجية', #1
u'والوالى': u'وَالْوَالِى', #1
u'والوانوغي': u'وَالْوَانُّوغِيُّ', #2
u'والوأواء': u'وَالْوَأْوَاءِ', #2
u'والوبيص': u'وَالْوَبِيصُ', #4
u'وألوة': u'وَأَلُوّةٌ', #1
u'والوترة': u'وَالْوَتْرَةُ', #1
u'والوتير': u'وَالْوَتِيرُ', #1
u'والوجء': u'وَالْوَجْءُ', #4
u'والوجء': u'وَالْوَجْءِ', #4
u'والوجأ': u'وَالْوَجَأُ', #1
u'والوجاء': u'وَالْوِجَاءِ', #2
u'والوجاء': u'وَالْوِجَاءُ', #8
u'والوجاءة': u'وَالْوَجَاءَةِ', #1
u'والوجأة': u'وَالْوَجْأَةِ', #2
u'والوجاح': u'وَالْوِجَاحِ', #1
u'والوجعا': u'وَالْوَجَعَا', #6
u'والوجيف': u'وَالْوَجِيفُ', #4
u'والوحا': u'وَالْوَحَا', #1
u'والوحوح': u'وَالْوَحْوَحُ', #1
u'والوحى': u'وَالْوَحْىَ', #1
u'والوخش': u'وَالْوَخْشُ', #10
u'والوخش': u'وَالْوَخْشِ', #8
u'والوداري': u'وَالْوَدَارِيِّ', #1
u'والودائق': u'وَالْوَدَائِقُ', #1
u'والودائق': u'وَالْوَدَائِقِ', #5
u'والودى': u'وَالْوَدْىِ', #1
u'والودى': u'وَالْوَدْىُ', #2
u'والوذاري': u'وَالْوَذَارِيِّ', #4
u'والوذاري': u'وَالْوَذَارِيُّ', #8
u'والوذيل': u'وَالْوَذِيلُ', #1
u'والوراشين': u'وَالْوَرَاشِينُ', #3
u'والوراقون': u'وَالْوَرَّاقُونَ', #2
u'والوراقين': u'وَالْوَرَّاقِينَ', #1
u'والورخمتى': u'والورخمتى', #1
u'والورخميني': u'والورخميني', #1
u'والورشان': u'وَالْوَرَشَانِ', #1
u'والورشان': u'وَالْوَرَشَانُ', #2
u'والورقا': u'وَالْوَرَقَا', #1
u'والوزانين': u'وَالْوَزَّانِينَ', #1
u'والوزغات': u'وَالْوَزَغَاتِ', #4
u'والوزوع': u'وَالْوَزُوعُ', #1
u'والوزيعة': u'وَالْوَزِيعَةُ', #1
u'والوسطانية': u'والْوَسْطَانِيّةُ', #1
u'والوشى': u'والوشى', #2
u'والوصاة': u'وَالْوَصَاةِ', #1
u'والوصاة': u'وَالْوَصَاةُ', #5
u'والوصاد': u'وَالْوَصَّادُ', #1
u'والوصيه': u'وَالْوَصِيَّهْ', #2
u'والوضر': u'وَالْوَضَرُ', #1
u'والوضم': u'وَالوَضَمِ', #1
u'والوضوءات': u'وَالْوُضُوءَاتِ', #1
u'والوضيمة': u'وَالْوَضِيمَةُ', #2
u'والوضين': u'وَالْوَضِينُ', #4
u'والوطأين': u'وَالْوَطْأَيْنِ', #1
u'والوطبح': u'وَالْوَطْبَحَ', #2
u'والوطف': u'وَالْوَطْفُ', #1
u'والوطفاء': u'وَالْوَطْفَاءُ', #2
u'والوطية': u'وَالْوَطِيَّةَ', #1
u'والوطيح': u'والوطيح', #1
u'والوطيح': u'وَالْوَطِيحُ', #2
u'والوطيح': u'وَالْوَطِيحِ', #2
u'والوطيحة': u'وَالْوَطِيحَةَ', #1
u'والوطيحة': u'وَالْوَطِيحَةُ', #1
u'والوغير': u'وَالْوَغِيرُ', #1
u'والوقاح': u'وَالْوَقَاحُ', #1
u'والوقاص': u'وَالْوَقّاصُ', #1
u'والوقدان': u'وَالْوَقَدَانِ', #1
u'والوقش': u'وَالْوَقْشُ', #2
u'والوقص': u'وَالْوَقَصَ', #1
u'والوقص': u'وَالْوَقَصِ', #1
u'والوقص': u'وَالْوَقْصَ', #1
u'والوقص': u'وَالْوَقْصُ', #12
u'والوقص': u'وَالْوَقْصِ', #2
u'والوقص': u'وَالْوَقَصُ', #8
u'والوقوحة': u'وَالْوُقُوحَةُ', #1
u'والوقية': u'وَالْوَقِيَّةُ', #1
u'والوقية': u'وَالْوُقِيَّةِ', #1
u'والوقية': u'وَالْوُقِيَّةُ', #2
u'والوقيذ': u'وَالْوَقِيذ', #1
u'والوقيذة': u'وَالْوَقِيذَةِ', #1
u'والوكاله': u'وَالْوَكَالَهْ', #1
u'والوكع': u'وَالْوَكَعِ', #1
u'والولا': u'وَالْوَلَا', #1
u'والولا': u'وَالَوْلَا', #2
u'والولا': u'وَالْوِلَا', #3
u'والولاد': u'وَالْوِلَادَ', #1
u'والولاد': u'وَالْوِلَادِ', #11
u'والولاد': u'وَالْوِلَادُ', #9
u'والولايا': u'وَالْوَلَايَا', #1
u'والؤلؤ': u'وَالُؤْلُؤٌ', #1
u'والولوالجي': u'والْوَلْوَالِجِيِّ', #11
u'والولوالجي': u'والْوَلْوَالِجِيّ', #3
u'والولوالجي': u'والْوَلْوَالِجِيُّ', #7
u'والولوالجية': u'وَالْوَلْوالِجِيَّة', #21
u'والولوالجية': u'وَالْوَلْوَالِجِيَّة', #28
u'والولوالجية': u'وَالْوَلْوَالِجِيَّةِ', #5
u'والولوالجية': u'والولوالجية', #77
u'والونيم': u'وَالْوَنِيمُ', #1
u'والوهاط': u'وَالْوِهَاطُ', #1
u'والوهب': u'وَالْوَهْبُ', #1
u'والوهب': u'وَالْوَهْبِ', #1
u'والوهبانية': u'والوهبانية', #4
u'والوهط،': u'وَالْوَهْطُ،', #1
u'والوهيط': u'وَالْوَهِيطِ', #1
u'والويبة': u'وَالْوَيْبَةُ', #3
u'والياس': u'وَالْيَاسُ', #1
u'وإلياسين': u'وَإِلْيَاسِينَ', #1
u'واليانسون': u'وَالْيَانَسُونِ', #1
u'واليانوسة': u'وَالْيَانُوسَةِ', #1
u'واليباس': u'وَالْيَبَاسُ', #1
u'وإليته،': u'وَإِلْيَتِهِ،', #1
u'وإلىد': u'وإلىد', #1
u'واليرناء': u'وَالْيُرَنَّاءُ', #1
u'واليرى': u'وَالْيَرَى', #1
u'واليزنية': u'وَالْيَزَنِيّةُ', #1
u'وأليس': u'وَأُلَّيْسَ', #1
u'وأليس': u'وَأُلَّيْسُ', #1
u'وأليسا': u'وَأُلَّيْسَا', #1
u'واليستعور': u'وَالْيَسْتَعُورُ', #1
u'واليشب': u'وَالْيَشْبِ', #1
u'واليشم': u'وَالْيَشْمِ', #1
u'واليعاليل': u'وَالْيَعَالِيلُ', #1
u'واليعمري': u'وَالْيَعْمُرِيُّ', #1
u'واليعملة': u'وَالْيَعْمُلَةُ', #1
u'واليكسوم': u'وَالْيَكْسُومَ', #1
u'واليكسوم': u'والْيكْسوم', #2
u'وإليكها': u'وَإِلَيْكَهَا', #3
u'واليلب': u'وَالْيَلَبَ', #3
u'واليلملم': u'وَالْيَلَمْلَمُ', #1
u'واليلنجوج': u'وَالْيَلَنْجُوجُ', #1
u'واليمانى': u'وَالْيَمَانِىَ', #1
u'والينبع': u'وَالْيَنْبُعَ', #1
u'والينبع': u'وَالْيَنْبُعُ', #2
u'والينبع': u'وَالْيَنْبُعِ', #7
u'واليهودى': u'وَالْيَهُودِىُّ', #2
u'واليواقيت،': u'واليواقيت،', #1
u'واليواقيت': u'وَالْيَوَاقِيتُ', #2
u'واليواقيت': u'وَالْيَوَاقِيتِ', #23
u'واليونسية': u'وَالْيُونُسِيَّةُ', #2
u'واليونيني': u'وَالْيُونِينِيُّ', #1
u'وام': u'وام', #2
u'واما': u'واما', #2
u'وأماالصبيان': u'وَأَمَّاالصِّبْيَانُ', #1
u'وإماق': u'وَإِمَاقٍ', #1
u'وأمامة': u'وأُمامة', #1
u'وأمامة': u'وَأُمَامَةُ', #12
u'وأمامة': u'وَأُمَامَةَ', #3
u'وأمامكانه': u'وَأَمَّامَكَانُهُ', #1
u'وأمامى': u'وَأَمَامِى', #2
u'وآمت': u'وَآمَتْ', #1
u'وامتار': u'وَامْتَارَ', #1
u'وامتحقت': u'وَامْتَحَقَتْ', #2
u'وامتراء': u'وَامْتِرَاءً', #1
u'وامتشطى': u'وَامْتَشِطِى', #9
u'وأمتعات': u'وَأَمْتِعَاتٍ', #1
u'وامتعظوا': u'وَامْتَعَظُوا', #1
u'وأمتنى': u'وَأَمِتْنِى', #2
u'وأمتى': u'وَأَمَتِى', #1
u'وأمتى': u'وَأُمَّتِى', #1
u'وأمثالهوالوجه': u'وَأَمْثَالِهِوَالْوَجْهُ', #1
u'وأمحلت': u'وَأَمْحَلَتْ', #1
u'وامخيت': u'وَامَّخَيْتُ', #1
u'وإمذاء': u'وَإِمْذَاءٍ', #1
u'وإمذاؤه': u'وَإِمْذَاؤُهُ', #2
u'وإمذائه': u'وَإِمْذَائِهِ', #7
u'وأمذى': u'وَأَمْذَى', #3
u'وأمذيت': u'وَأَمْذَيْتُ', #1
u'وامر': u'وامر', #5
u'وامرأتى': u'وَامْرَأَتِى', #3
u'وأمراق': u'وَأَمْرَاقٌ', #1
u'وأمرأني': u'وَأَمْرَأَنِي', #1
u'وأمرتنى': u'وَأَمَرَتْنِى', #1
u'وأمرنى': u'وَأَمَرَنِى', #20
u'وامرو': u'وامرو', #1
u'وامروز': u'وَامَرُوز', #1
u'وأمروزاين': u'وأمروزاين', #1
u'وأمرى': u'وَأَمْرَى', #1
u'وأمرى': u'وَأَمْرِى', #1
u'وأمسكنى': u'وَأَمْسِكْنِى', #4
u'وأمسكى': u'وَأَمْسِكِى', #3
u'وأمشر': u'وَأَمْشَرَ', #1
u'وامشيوا': u'وَامْشِيُوا', #1
u'وامصيبتاه': u'وَامُصِيبَتَاهْ', #1
u'وامصيبتاه': u'وَامُصِيبَتَاهُ', #2
u'وامعتصماه': u'وَامُعْتَصِمَاه', #1
u'وأمعط': u'وَأَمْعَطُ', #1
u'وامعلماه': u'وَامُعَلِّمَاهُ', #1
u'وامقة': u'وَامِقَةٌ', #1
u'وأملجته': u'وَأَمْلَجَتْهُ', #1
u'وأملجته': u'وَأَمْلَجْتُهُ', #1
u'وإمناء': u'وَإِمْنَاءِ', #1
u'وإمناء': u'وَإِمْنَاءٍ', #3
u'وإمناؤه': u'وَإِمْنَاؤُهُ', #5
u'وإمنائه': u'وَإِمْنَائِهِ', #2
u'وأمهدوا': u'وَأَمْهِدُوا', #1
u'وأمهلى': u'وأمهلى', #1
u'وأموميتها': u'وَأُمُومِيَّتُهَا', #1
u'وامي': u'وامي', #1
u'وامى': u'وامى', #1
u'وأمى؟': u'وَأُمِّى؟', #2
u'وأمى': u'وَأُمِّى', #67
u'وأميم': u'وَأَمِيمُ', #1
u'وأميم': u'وَأَمّيمٌ', #1
u'وأميم': u'وَأُمَيْمَ', #1
u'وأميم': u'وَأُمَيْمٌ', #2
u'وأميم': u'وَأُمَيْمُ', #3
u'وانا': u'وانا', #2
u'وأنأبوا': u'وَأَنْأَبُوا', #1
u'وأنأحتأ': u'وَأَنْأَحْتُأَ', #1
u'واناصراه': u'وَانَاصِرَاه', #1
u'واناصراه': u'وَانَاصِرَاهُ', #1
u'وأنافته': u'وَأَنَافَتِهِ', #1
u'واناها': u'وَانَاهَا', #1
u'وأنبأنى': u'وَأَنْبَأَنِى', #20
u'وأنبأنيه': u'وَأَنْبَأَنِيهِ', #1
u'وأنبضت': u'وَأُنْبِضَتْ', #1
u'وانبلت': u'وَانْبَلّتْ', #1
u'وأنبلته': u'وَأَنْبَلْته', #1
u'وانبهم': u'وَانْبَهَمَ', #4
u'وانبهمت': u'وَانْبَهَمَتْ', #2
u'وانبياه': u'وانبياه', #1
u'وانبياه': u'وَانَبِيَّاهُ', #1
u'وانتباهتها': u'وَانْتِبَاهَتِهَا', #1
u'وانتثار': u'وَانْتِثَارِ', #2
u'وانتثار': u'وَانْتِثَارُ', #3
u'وانتثر': u'وَانْتَثَرَ', #2
u'وانتثرت': u'وَانْتَثَرَتْ', #2
u'وانتثل': u'وَانْتُثِلَ', #1
u'وانتثل': u'وَانْتَثَلَ', #3
u'وانتجاء': u'وَانْتِجَاءً', #1
u'وانتخاء': u'وَانْتِخَاءِ', #3
u'وانتخى': u'وَانْتَخَى', #1
u'وانتشاز': u'وانتشاز', #1
u'وانتشبوا': u'وَانْتَشَبُوا', #1
u'وانتضلوا': u'وَانْتَضِلُوا', #1
u'وانتطق': u'وَانْتَطَقَ', #1
u'وانتطقت': u'وَانْتَطَقَتْ', #2
u'وانتقاب': u'وَانْتِقَابُ', #6
u'وانتقاعه': u'وَانْتِقَاعِهِ', #1
u'وانتقله': u'وَانْتَقَلَهُ', #1
u'وانتها': u'وَانْتِهَا', #1
u'وانتهرنى': u'وَانْتَهَرَنِى', #2
u'وانتهش': u'وَانْتَهَشَ', #2
u'وانتهشت': u'وَانْتَهَشَتْ', #1
u'وأنجا': u'وَأَنْجَا', #1
u'وانجاء': u'وَانَجَاءَ', #1
u'وانجاز': u'وَانِجَازٌ', #1
u'وإنجاشا': u'وَإِنْجَاشًا', #1
u'وإنجانة': u'وَإِنْجَانَةٌ', #1
u'وانجحاره': u'وَانْجِحَارِهِ', #1
u'وانجرح': u'وَانْجَرَحَ', #6
u'وأنجشة': u'وَأَنْجَشَةَ', #1
u'وانجفل': u'وَانْجَفَلَ', #1
u'وانجماده': u'وَانْجِمَادِهِ', #1
u'وأنجيل': u'وَأَنْجِيلٍ', #1
u'وانحاش': u'وَانْحَاشَ', #1
u'وانحتام': u'وَانْحِتَامِ', #3
u'وانحجاره': u'وَانْحِجَارِهِ', #1
u'وانحجاره': u'وَانْحِجَارُهُ', #3
u'وانحجر': u'وَانْحَجَرَ', #2
u'وانحرق': u'وَانْحَرَقَ', #1
u'وانحفاز': u'وانحفاز', #1
u'وانخبز': u'وَانْخَبَزَ', #1
u'وانخزال': u'وَانْخِزَالَ', #1
u'وانخلاق': u'وَانْخِلَاقُ', #1
u'وانخلاق': u'وَانْخِلَاقِ', #1
u'وانخنس': u'وَانْخَنَسَ', #2
u'وأندرائس': u'وَأَنْدَرَائِسُ', #1
u'وأندرائس': u'وَأَنْدِرَائِسُ', #1
u'واندرجست': u'واندرجست', #1
u'واندردست': u'واندردست', #1
u'واندرين': u'واندرين', #1
u'وآنر': u'وآنر', #2
u'وإنزاء': u'وَإِنْزَاءٍ', #2
u'وإنزاء': u'وَإِنْزَاءُ', #8
u'وإنزاء': u'وَإِنْزَاءِ', #9
u'وأنزى': u'وَأَنْزَى', #3
u'وأنزيته': u'وَأَنْزَيْته', #1
u'وأنسأته': u'وَأَنْسَأْتُهُ', #1
u'وانساغ': u'وَانْسَاغَ', #4
u'وأنسبية': u'وَأَنْسَبِيَّةُ', #1
u'وانسر': u'وَانْسَرَّ', #1
u'وأنسئه': u'وَأَنْسَئُهُ', #1
u'وأنسئه': u'وَأُنْسِئُهُ', #5
u'وأنسيون': u'وَأَنْسِيُونٍ', #1
u'وانشاد': u'وَانِشَادِ', #1
u'وانشاز': u'وَانِشَازُ', #1
u'وإنشاز': u'وَإِنْشَازُ', #2
u'وإنشاز': u'وَإِنْشَازَ', #3
u'وإنشاز': u'وَإِنْشَازِ', #8
u'وأنشدنيه': u'وَأَنْشَدَنِيهِ', #3
u'وانشلاء': u'وَانْشِلَاءً', #1
u'وانصان': u'وَانْصَانَ', #1
u'وانصدام': u'وَانْصِدَامِ', #1
u'وانصدم': u'وَانْصَدَمَ', #3
u'وانضحى': u'وَانْضَحِى', #1
u'وانطحنت': u'وَانْطَحَنَتْ', #2
u'وانظاع': u'وَانْظَاع', #1
u'وانظرى': u'وَانْظُرِى', #1
u'وإنعاظ': u'وَإِنْعَاظٍ', #5
u'وانعقاص': u'وَانْعِقَاصٌ', #1
u'وانعكف': u'وَانْعَكَفَ', #5
u'وإنفاء': u'وَإِنْفَاءُ', #1
u'وانفاذ': u'وَانَفَاذِ', #1
u'وانفتالها': u'وَانْفِتَالُهَا', #3
u'وأنفج': u'وَأَنْفَجَ', #1
u'وإنفحة': u'وَإِنفْحَةٍ', #1
u'وإنفحة': u'وَإِنْفَحَةٍ', #2
u'وإنفحة': u'وَإِنْفَحَّةٌ', #2
u'وإنفحة': u'وَإِنْفَحَةُ', #5
u'وإنفحتها': u'وَإِنْفَحَتهَا', #1
u'وإنفحتها': u'وَإِنْفَحَتُهَا', #4
u'وإنفحه': u'وَإِنْفَحَهْ', #1
u'وأنفسهوروي': u'وَأَنْفَسِهِوَرُوِيَ', #1
u'وانفهقت': u'وَانْفَهَقَتْ', #1
u'وأنقال': u'وَأَنْقَالُ', #1
u'وأنقروي': u'وَأَنْقِرْوِيٌّ', #1
u'وأنقروي': u'وأنقروي', #2
u'وانقمع': u'وَانْقَمَعَ', #2
u'وانقمعت': u'وَانْقَمَعْتُ', #1
u'وآنقننى': u'وَآنَقْنَنِى', #1
u'وأنكحة': u'وَأَنْكِحَةُ', #1
u'وأنكحتكها': u'وَأَنْكَحْتُكَهَا', #1
u'وإنكشارية': u'وإنكشارية', #1
u'وإنكشارية': u'وَإنْكِشَارِيَّةٌ', #1
u'وانكشارية': u'وَانْكِشَارِيَّةٌ', #1
u'وانكمأ': u'وَانْكَمَأَ', #1
u'وآنكه': u'وآنكه', #1
u'وانما': u'وانما', #2
u'وانما': u'وَانَمَا', #3
u'وإنماالحجة': u'وَإِنَّمَاالْحِجَّةُ', #1
u'وانملس': u'وانْمَلَسَ', #1
u'وانملق': u'وَانْمَلَقَ', #1
u'وإننى': u'وَإِنَّنِى', #1
u'وانها': u'وَانْهَا', #1
u'وإنهاشه': u'وَإِنْهَاشُهُ', #1
u'وانهدرت': u'وَانْهَدَرَتْ', #1
u'وانهسوا': u'وَانْهَسُوا', #1
u'وانهى': u'وَانْهَى', #1
u'وإنو': u'وَإِنْوٌ', #1
u'وأنواحا': u'وَأَنْوَاحًا', #1
u'وأنوثيته': u'وَأُنُوثِيَّتَهُ', #1
u'وأنوثيته': u'وَأُنُوثِيَّتِهِ', #6
u'وأنى': u'وَأَنًى', #1
u'وإنى': u'وَإِنًى', #1
u'وانى': u'وانى', #1
u'وإنى': u'وَإِنَّى', #2
u'وإنى': u'وَإِنِّى', #281
u'وإنى': u'وَإِنَى', #6
u'وآنيت': u'وَآنَيْت', #4
u'وآنيت': u'وَآنَيْتَ', #6
u'وآنيسون': u'وَآنِيسُونَ', #1
u'وآنيسون': u'وَآنِيسُونٍ', #2
u'وآها': u'وَآهًا', #1
u'واها': u'وَاهًا', #10
u'وأهابه': u'وَأَهَابُهُ', #1
u'وإهالة': u'وَإِهَالَةِ', #1
u'وإهالة': u'وَإِهَالَةٍ', #16
u'وإهالة': u'وَإِهَالَة', #2
u'وإهالة': u'وَإِهَالَةٌ', #2
u'وأهالوا': u'وَأَهَالُوا', #3
u'وآهبة': u'وَآهِبَةٌ', #1
u'واهتضام': u'وَاهْتِضَامِ', #2
u'وأهجاهم': u'وَأَهْجَاهُمْ', #1
u'وأهدنته': u'وَأَهْدَنْتُهُ', #2
u'واهدنى': u'وَاهْدِنِى', #11
u'وإهدى': u'وإهدى', #1
u'واهر': u'واهر', #1
u'وأهراق': u'وَأَهْرَاق', #1
u'وأهراق': u'وَأَهْرَاقَ', #10
u'وأهراقت': u'وَأَهْرَاقَتْ', #1
u'وأهراقه': u'وَأَهْرَاقَهُ', #2
u'وأهراقها': u'وَأَهْرَاقَهَا', #2
u'وأهريق': u'وَأُهْرِيقَ', #11
u'وأهريقت': u'وَأُهَرِيقَتْ', #2
u'وأهريقت': u'وَأُهْرِيقَتْ', #2
u'وأهريقوا': u'وَأَهْرِيقُوا', #8
u'وأهزجوا': u'وَأَهْزَجُوا', #1
u'واهلاكا': u'وَاهَلاكًا', #1
u'واهلكتاه': u'وَاهَلْكَتَاهُ', #1
u'وأهلكنى': u'وأهلكنى', #1
u'وأهلى': u'وَأَهِلِّى', #11
u'وأهلى': u'وَأَهْلِى', #3
u'وأهمانى': u'وَأَهَمَّانِى', #2
u'وأهنؤه': u'وَأَهْنَؤُهُ', #1
u'وإهوان': u'وَإِهْوَانٌ', #1
u'واهى': u'وَاهِى', #2
u'وأهيأه': u'وَأَهْيَأُهُ', #1
u'وأهيلوا': u'وَأَهِيلُوا', #2
u'وأؤاجرك': u'وَأُؤَاجِرُك', #1
u'وأوادم': u'وَأَوَادِمَ', #1
u'وأوبشت': u'وَأَوْبَشَتْ', #1
u'وأوتاق': u'وأوتاق', #1
u'وأوتغه': u'وَأَوْتَغَهُ', #1
u'وأوثار': u'وَأَوْثَارٌ', #1
u'وأوجأ': u'وَأَوْجَأَ', #1
u'وأوجهية': u'وَأَوْجَهِيَّةُ', #1
u'وأودنة': u'وَأَوْدَنَةُ', #1
u'وأوردب': u'وَأُورِدبَ', #1
u'واورسانيده': u'واورسانيده', #1
u'وأوز': u'وَأُوزَ', #1
u'وأوز': u'وَأُوَزٍّ', #1
u'وأوزاع': u'وَأَوْزَاعُ', #1
u'وأوزجند': u'وَأُوزَجَنْدَ', #3
u'وأوساه': u'وَأَوْسَاهُ', #1
u'وأوشكهم': u'وَأَوْشَكُهُمْ', #1
u'وأوضار': u'وَأَوْضَارِ', #1
u'وأوضحيته': u'وَأَوْضَحِيَّتِهِ', #1
u'وأوضية': u'وَأَوْضِيَةٍ', #1
u'وأوضيها': u'وَأُوَضِّيهَا', #1
u'وأوطاس': u'وَأَوْطَاسَ', #3
u'وأوطاس': u'وَأَوْطَاسُ', #3
u'وأوعاد': u'وَأَوْعَادٍ', #1
u'وأوعار': u'وَأَوْعَارٌ', #1
u'وأوعار': u'وَأَوْعَارٍ', #1
u'وأوفاقا': u'وَأَوْفَاقًا', #1
u'وأوفقية': u'وَأَوْفَقِيَّةِ', #1
u'وأوقاص': u'وَأَوْقَاصٍ', #1
u'وأوقص': u'وَأَوْقَصُ', #1
u'وأوكأ': u'وَأَوْكَأَ', #2
u'وأوكأها': u'وَأَوْكَأَهَا', #1
u'وأوكاها': u'وَأَوْكَاهَا', #1
u'وأوكرت': u'وَأَوْكَرَتْ', #1
u'وأوكع': u'وَأَوْكَعُ', #2
u'وأوكه': u'وَأَوْكِهِ', #6
u'وأوكوا': u'وَأَوْكُوا', #29
u'وأوكي': u'وَأَوْكِي', #1
u'وأوكى': u'وَأَوْكَى', #1
u'وأوكئ': u'وَأَوْكِئْ', #1
u'وأوكئوا': u'وَأَوْكِئُوا', #15
u'وأوكيه': u'وَأُوكِيهِ', #3
u'وأولتي': u'وَأُولَتَيْ', #10
u'وأوما': u'وَأَوْمَا', #1
u'وأومى': u'وَأَوْمَى', #3
u'وأوهاطه': u'وَأَوْهَاطِهِ', #1
u'وأوهاطها': u'وَأَوْهَاطَهَا', #1
u'وأويس': u'وَأُوَيْسٍ', #1
u'وأويس': u'وَأُوَيْسٌ', #2
u'وائتدم': u'وَائْتَدِمْ', #1
u'وائتدموا': u'وَائْتَدِمُوا', #1
u'وائتس': u'وَائْتَسِ', #1
u'وائتمام': u'وائْتِمَامِ', #1
u'وائتمام': u'وَائْتِمَامٍ', #1
u'وائتمام': u'وَائْتِمَامُ', #1
u'وائتمام': u'وَائْتِمَامِ', #1
u'وائتمام': u'وَائْتِمَامٌ', #3
u'وائتنافه': u'وَائْتِنَافُهُ', #1
u'وائتنف': u'وَائْتَنَفَ', #1
u'وائتنفت': u'وَائْتَنَفَتْ', #7
u'وائتنى': u'وائْتِنِى', #1
u'وائتونى': u'وَائْتُونِى', #4
u'وائج': u'وَائِجَ', #1
u'وائلا': u'وَائِلًا', #4
u'وائلة': u'وَائِلَةُ', #1
u'وائلة': u'وَائِلَةَ', #9
u'وأيابهم': u'وَأَيَّابِهِمْ', #1
u'وإياد': u'وَإِيَادِ', #1
u'وإياد': u'وَإِيَادَ', #2
u'وإياد': u'وَإِيَادُ', #3
u'وإياد': u'وَإِيَادٍ', #4
u'وإياس': u'وإياس', #1
u'وإياس': u'وَإيَاسُ', #1
u'وإياس': u'وَإِيَاسٍ', #1
u'وإياس': u'وَإِيَاسَ', #1
u'وإياس': u'وَإِيَاسِ', #1
u'وإياس': u'وَإِيَاسُ', #11
u'وإياس': u'وَإِيَاسٌ', #3
u'وإياسه': u'وَإِيَاسَهُ', #1
u'وإياسها،': u'وَإِيَاسَهَا،', #1
u'وإياسها': u'وَإِيَاسُهَا', #3
u'وإياسها': u'وَإِيَاسِهَا', #5
u'وإياسهن': u'وَإِيَاسِهِنَّ', #2
u'وإياسي': u'وَإِيَاسِي', #1
u'وإيامته': u'وَإِيَامَتِهِ', #1
u'وإياى': u'وَإِيَّاىَ', #4
u'وآيبا': u'وَآيِبًا', #9
u'وايتدعوها': u'وَايْتَدِعُوهَا', #1
u'وايجاب': u'وايجاب', #6
u'وإيجابة': u'وإيجابة', #1
u'وإيحاب': u'وإيحاب', #1
u'وايداه': u'وَايَدَاهْ', #2
u'وايداه': u'وَايَدَاهُ', #6
u'وآيسة': u'وَآيِسَةٌ', #12
u'وآيسة': u'وَآيِسَةٍ', #21
u'وآيستنا': u'وَآيَسْتَنَا', #1
u'وآيسهم': u'وَآيَسَهُمْ', #1
u'وأيش': u'وَأَيْشٌ', #1
u'وأيش': u'وَأَيْشٍ', #1
u'وأيش': u'وَأَيْشِ', #1
u'وإيش': u'وإِيشْ', #1
u'وإيش': u'وَإيش', #1
u'وإيش': u'وَإِيشِ', #2
u'وإيكاء': u'وَإِيكَاءً', #1
u'وإيكاء': u'وَإِيكَاءَ', #1
u'وإيكاء': u'وإيكاء', #2
u'وإيكاء': u'وَإِيكَاءُ', #4
u'وإيكاء': u'وَإِيكَاءِ', #5
u'وإيكاف': u'وَإِيكَافُ', #1
u'وإيكافه': u'وَإِيكَافَهُ', #1
u'وإيكافه': u'وَإِيكَافِهِ', #1
u'وآيل': u'وَآيِلٍ', #1
u'وإيل': u'وَإِيلَ', #1
u'وإيل': u'وَإِيلُ', #1
u'وإيل': u'وَإِيَّلُ', #2
u'وإيلا': u'وَإِيلَا', #1
u'وآيلا': u'وَآيِلًا', #3
u'وآيلة': u'وَآيِلَةٌ', #1
u'وأيلة': u'وَأَيَلَةَ', #1
u'وأيلة': u'وَأَيْلَةُ', #2
u'وأيلة،': u'وَأَيْلَةَ،', #2
u'وأيلة': u'وَأَيْلَةَ', #6
u'وأيلولتها': u'وَأَيْلُولَتِهَا', #2
u'وإيليا': u'وَإِيلْيَا', #1
u'وإيلياء': u'وَإِيلِيَاءَ', #3
u'وإيلياء': u'وَإِيلْيَاءَ', #3
u'وآيم': u'وآيم', #1
u'وايم': u'وَايْمُ', #110
u'وإيم': u'وَإِيمُ', #2
u'وايم': u'وايم', #2
u'وايم': u'وَاَيْمُ', #54
u'وإيمانهمقوله': u'وَإِيمَانُهُمْقَولُهُ', #1
u'واين': u'وَايْنَ', #1
u'واين': u'واين', #17
u'وأينعه': u'وَأَيْنَعَهُ', #1
u'وأينقتنى': u'وَأَيْنَقَتْنِى', #1
u'وأينقنني': u'وَأَيْنَقْنَنِي', #1
u'وإيها': u'وَإِيهًا', #1
u'وأيوه': u'وَأَيْوَهْ', #1
u'وآييل': u'وَآيِيلُ', #1
u'وبا': u'وبا', #1
u'وباءوا': u'وَبَاءُوا', #9
u'وبإباقه': u'وَبِإِبَاقِهِ', #2
u'وبابتعت': u'وَبِابْتَعْتُ', #7
u'وبابتغي': u'وَبِابْتَغِي', #2
u'وبإبعاضه': u'وَبِإِبْعَاضِهِ', #1
u'وبأبنت': u'وَبِأَبَنْت', #1
u'وبأبنت': u'وَبِأَبَنْتُ', #3
u'وبأبى': u'وَبِأَبِى', #2
u'وباجة': u'وَبَاجَّةً', #5
u'وبأجزت': u'وَبِأَجَزْتُ', #1
u'وباحتشاشه': u'وَبِاحْتِشَاشِهِ', #1
u'وبأحسب': u'وَبِأَحْسَبُ', #1
u'وباختاري': u'وَبِاخْتَارِي', #1
u'وباخداي': u'وباخداي', #2
u'وبأخسهما': u'وَبِأَخَسِّهِمَا', #1
u'وبأخى': u'وَبِأَخِى', #2
u'وبأدبته': u'وَبِأَدَبَتِهِ', #1
u'وبادرنى': u'وَبَادَرَنِى', #1
u'وبإذا': u'وَبِإِذَا', #4
u'وباذان،': u'وَبَاذَانُ،', #1
u'وبإذائه': u'وَبِإِذَائِهِ', #1
u'وبآذنت': u'وَبِآذَنْت', #1
u'وبأذنت': u'وَبِأَذِنْتُ', #1
u'وباذهبي': u'وَبِاذْهَبِي', #6
u'وبإراءة': u'وَبِإِرَاءَةِ', #1
u'وبارتضاع': u'وَبِارْتِضَاعِ', #1
u'وبإرثائه': u'وَبِإِرْثَائِهِ', #2
u'وبأرش': u'وَبِأَرْشٍ', #1
u'وبأرش': u'وَبِأَرْشِ', #13
u'وبإرغابه': u'وَبِإِرْغَابِهِ', #1
u'وبازات': u'وَبَازَاتٍ', #2
u'وباستحاضة': u'وَبِاسْتِحَاضَةٍ', #1
u'وباستحداد': u'وَبِاسْتِحْدَادٍ', #2
u'وباستدخاله': u'وَبِاسْتِدْخَالِهِ', #1
u'وباسترقاقه': u'وَبِاسْتِرْقَاقِهِ', #2
u'وباستنان': u'وَبِاسْتِنَانِ', #1
u'وبأسكر': u'وَبِأَسْكَرَ', #1
u'وبآسمان': u'وبآسمان', #1
u'وبإشمام': u'وَبِإِشْمَامِ', #1
u'وبإشمامها': u'وَبِإِشْمَامِهَا', #1
u'وبإصبعين': u'وَبِإِصْبَعَيْنِ', #2
u'وبأصبهان': u'وَبِأَصْبَهَانَ', #1
u'وبأصحابى': u'وَبِأَصْحَابِى', #2
u'وباط': u'وَبَاطُّ', #1
u'وبأعجلهم': u'وَبِأَعْجَلِهِمْ', #1
u'وباعشن': u'وَبَاعَشَنٍ', #8
u'وبافضل': u'وَبَافَضْلٌ', #1
u'وبافضل': u'وَبَافَضْلٍ', #11
u'وبإقامها': u'وَبِإِقَامِهَا', #1
u'وبأقراء': u'وَبِأَقْرَاءٍ', #1
u'وبأقربيته': u'وبأقربيته', #1
u'وباقلا': u'وَبَاقِلًا', #1
u'وباقلا': u'وَبَاقِلَّا', #10
u'وباقلاة': u'وَبَاقِلَاةٌ', #1
u'وباقلى': u'وَبَاقِلَّى', #1
u'وباقور': u'وَبَاقُورٌ', #1
u'وباقورة': u'وَبَاقُورَةٌ', #5
u'وباقى': u'وَبَاقِى', #2
u'وبإكاف': u'وَبِإِكَافٍ', #1
u'وباكير': u'وَبَاكِيرٌ', #1
u'وباكير': u'وَبَاكِيرُ', #1
u'وبألا': u'وَبِأَلَّا', #3
u'وبإلا': u'وَبِإِلَّا', #5
u'وبالإباق': u'وَبِالْإِبَاقِ', #5
u'وبالإبراد': u'وَبِالْإِبْرَادِ', #2
u'وبالأبعرة': u'وَبِالأَبْعِرَةِ', #1
u'وبالأبعرة': u'وَبِالْأَبْعِرَةِ', #1
u'وبالآبق': u'وَبِالْآبِقِ', #1
u'وبالاجتنان': u'وَبِالِاجْتِنَانِ', #1
u'وبالاحتشاش': u'وَبِالِاحْتِشَاشِ', #1
u'وبالآخرية': u'وَبِالْآخِرِيَّةِ', #1
u'وبالارتياض': u'وَبِالِارْتِيَاضِ', #1
u'وبالإردب': u'وَبِالْإِرْدَبِّ', #2
u'وبالأرش': u'وَبِالْأَرْشِ', #9
u'وبالإستار': u'وَبِالْإِسْتَارِ', #1
u'وبالاستجمار': u'وَبِالِاسْتِجْمَارِ', #2
u'وبالاسترقاق': u'وَبِالِاسْتِرْقَاقِ', #1
u'وبالأشنان': u'وَبِالْأُشْنَانِ', #1
u'وبالاضطباع': u'وَبِالِاضْطِبَاعِ', #2
u'وبالأعرابى': u'وَبِالأَعْرَابِىِّ', #2
u'وبالأقراء': u'وَبِالْأَقْرَاءِ', #3
u'وبالأقط': u'وَبِالْأَقِطِ', #2
u'وبالأكساب': u'وَبِالْأَكْسَابِ', #2
u'وبالأكنان': u'وَبِالْأَكْنَانِ', #1
u'وبالأمنان': u'وَبِالْأَمْنَانِ', #3
u'وبالأيدى': u'وَبِالأَيْدِى', #2
u'وبالبكا': u'وَبِالْبُكَا', #1
u'وبالبلجاء': u'وَبِالْبَلْجَاءِ', #1
u'وبالبنا': u'وَبِالْبِنَا', #1
u'وبالتأذي': u'وَبِالتَّأَذِّي', #1
u'وبالترخص': u'وَبِالتَّرَخُّصِ', #1
u'وبالتسليمة': u'وَبِالتَّسْلِيمَةِ', #2
u'وبالتشطر': u'وَبِالتَّشَطُّرِ', #1
u'وبالتطليقة': u'وَبِالتَّطْلِيقَةِ', #3
u'وبالتعانها': u'وَبِالْتِعَانِهَا', #1
u'وبالتعيب': u'وَبِالتَّعَيُّبِ', #1
u'وبالتمانع': u'وَبِالتَّمَانُعِ', #1
u'وبالثخانة': u'وَبِالثَّخَانَةِ', #2
u'وبالثمان': u'وَبِالثَّمَانِ', #1
u'وبالثيوبة': u'وَبِالثُّيُوبَةِ', #2
u'وبالجذعة': u'وَبِالْجَذَعَةِ', #1
u'وبالجريب': u'وَبِالْجَرِيبِ', #1
u'وبالجعالة': u'وَبِالْجَعَالَةِ', #1
u'وبالحثي': u'وَبِالْحَثْيِ', #1
u'وبالحولقة': u'وَبِالْحَوْلَقَةِ', #1
u'وبالخفاجية': u'وبالخفاجية', #1
u'وبالدعا': u'وَبِالدُّعَا', #1
u'وبالدوانق': u'وَبِالدَّوَانِقِ', #2
u'وبالذعارة': u'وَبِالذِّعَارَةِ', #1
u'وبالذى': u'وَبِالَّذِى', #4
u'وبالرءوس': u'وَبِالرُّءُوسِ', #1
u'وبالرحمن': u'وَبِالرَّحْمَنِ', #1
u'وبالزراجين': u'وَبِالزَّرَاجِينِ', #1
u'وبالزكاةوروي': u'وَبِالزَّكَاةِوَرُوِيَ', #1
u'وبالستوق': u'وَبِالسَّتُّوقِ', #1
u'وبالسرقنة': u'وَبِالسَّرْقَنَةِ', #1
u'وبالسعوط': u'وَبِالسَّعُوطِ', #1
u'وبالشأس': u'وَبِالشَّأْسِ', #1
u'وبالشبة': u'وبالشبة', #1
u'وبالشلا': u'وَبِالشَّلَّا', #1
u'وبالصنجة': u'وَبِالصَّنْجَةِ', #2
u'وبالصومين': u'وَبِالصَّوْمَيْنِ', #1
u'وبالطبري': u'وَبِالطَّبَرِيِّ', #1
u'وبالطحينة': u'وَبِالطَّحِينَةِ', #1
u'وبالطهرين': u'وَبِالطُّهْرَيْنِ', #4
u'وبالعتقاء': u'وَبِالْعُتَقَاءِ', #2
u'وبالعذيب': u'وَبِالْعَذِيبِ', #1
u'وبالعرضل': u'وَبِالْعَرْضَلِ', #1
u'وبالعصفر': u'وَبِالْعُصْفُرِ', #1
u'وبالعصوبة': u'وَبِالْعُصُوبَةِ', #2
u'وبالعقاص': u'وَبِالْعِقَاصِ', #1
u'وبالعكوس': u'وَبِالْعُكُوسِ', #11
u'وبالعلما': u'وَبِالْعُلَمَا', #2
u'وبالفانيد': u'وَبِالْفَانِيدِ', #1
u'وبالفروجة': u'وَبِالْفَرُّوجَةِ', #1
u'وبالفروجة': u'وَبِالْفُرُوجَةِ', #1
u'وبالفعالى': u'وَبِالْفَعَالَى', #1
u'وبالفوائت': u'وَبِالْفَوَائِتِ', #1
u'وبالقرطبان': u'وَبِالْقَرْطَبَانِ', #1
u'وبالقرظي': u'وَبِالْقُرَظِيِّ', #1
u'وبالقضا': u'وَبِالْقَضَا', #1
u'وبالقلفونية': u'وبالقلفونية', #1
u'وبالقنا': u'وَبِالْقَنَا', #3
u'وبالكبيس': u'وَبِالْكَبِيسِ', #1
u'وبالكنايه': u'وَبِالْكِنَايَهْ', #1
u'وباللقا': u'وَبِاللِّقَا', #1
u'وباللقحة': u'وَبِاللّقْحَةِ', #2
u'وبالماذيانات': u'وبالماذيانات', #1
u'وبالماذيانات': u'وَبالماذِيَانَاتِ', #1
u'وبالمباضعة': u'وَبِالْمُبَاضَعَةِ', #2
u'وبالمباعلة': u'وَبِالْمُبَاعَلَةِ', #2
u'وبالمثلة': u'وَبِالْمُثْلَةِ', #2
u'وبالمذي': u'وَبِالْمَذْيِ', #1
u'وبالمرتصد': u'وَبِالْمُرْتَصِدِ', #1
u'وبالمرداسنج': u'وبالمرداسنج', #1
u'وبالمروانية': u'وَبِالْمَرْوَانِيَّةِ', #1
u'وبالمزعفر': u'وَبِالْمُزَعْفَرِ', #1
u'وبالمستأخرين': u'وبالمستأخرين', #1
u'وبالمشترى': u'وَبِالْمُشْتَرَى', #1
u'وبالمطهرون': u'وبالمطهرون', #1
u'وبالمطهرون': u'وَبِالْمُطَهَّرُون', #1
u'وبالمعاطاة': u'وَبِالْمُعَاطَاةِ', #6
u'وبالمقاثئ': u'وَبِالْمَقَاثِئِ', #1
u'وبالملزوم': u'وَبِالْمَلْزُومِ', #1
u'وبالمناجيق': u'وَبِالْمَنَاجِيقِ', #1
u'وبالمهايأة': u'وَبِالْمُهَايَأَةِ', #2
u'وبالموطوءة': u'وَبِالْمَوْطُوءَةِ', #1
u'وبالمومي': u'وَبِالْمُومِي', #1
u'وبالمومئ': u'وَبِالْمُومِئِ', #1
u'وبالوقية': u'وَبِالْوَقِيَّةِ', #1
u'وبالولاد': u'وَبِالْوِلَادِ', #1
u'وبإلى': u'وَبِإِلَى', #5
u'وبأمكة': u'وَبَأَمَكّةَ', #1
u'وبامياء': u'وَبَامْيَاءَ', #2
u'وبامية': u'وَبَامِيَةٍ', #3
u'وباناس': u'وَبَانَاسَ', #1
u'وبانة': u'وَبَانَةٌ', #1
u'وبأنت': u'وَبِأَنْتِ', #10
u'وبأنتن': u'وَبِأَنْتُنَّ', #1
u'وبإنزائه': u'وَبِإِنْزَائِهِ', #3
u'وبانصدام': u'وَبِانْصِدَامِ', #1
u'وبانصدامه': u'وَبِانْصِدَامِهِ', #2
u'وبانفصل': u'وَبِانْفَصَلَ', #3
u'وبأنقص': u'وَبِأَنْقَصَ', #1
u'وبانقيا': u'وبانقيا', #1
u'وبانقيا': u'وَبَانِقْيَا', #4
u'وبانقياء': u'وَبِانِقْيَاءُ', #1
u'وبإنهاش': u'وَبِإِنْهَاشِ', #1
u'وباهان': u'وَبَاهَانُ', #1
u'وباهلة': u'وَبَاهِلَةَ', #1
u'وباهلة': u'وَبَاهِلَةُ', #8
u'وبأو': u'وَبِأَوْ', #9
u'وبأوا،': u'وَبَأْوًا،', #1
u'وبأولتي': u'وَبِأُولَتَيْ', #1
u'وبآؤوا': u'وَبَآؤُوا', #1
u'وبآؤوا': u'وَبَآؤُوْاْ', #1
u'وباوي': u'وباوي', #2
u'وبأى': u'وَبِأَىِّ', #3
u'وباين': u'وَبَايَنَ', #10
u'وباينت': u'وَبَايَنَتْ', #2
u'وباينها': u'وَبَايَنَهَا', #2
u'وباينهما': u'وَبَايَنَهُمَا', #6
u'وببافم': u'وببافم', #1
u'وببعلبك': u'وَبِبَعْلَبَكَّ', #1
u'وببعني': u'وَبِبِعْنِي', #8
u'وبتأديه': u'وَبِتَأَدِّيهِ', #1
u'وبتح': u'وَبَتَحٍ', #1
u'وبتحرمها': u'وَبِتَحَرُّمِهَا', #1
u'وبتذريهم': u'وَبِتَذْرِيهِمْ', #1
u'وبتزوجتها': u'وَبِتَزَوَّجْتَهَا', #1
u'وبتسحر': u'وَبِتَسَحُّرٍ', #1
u'وبتسليمة': u'وَبِتَسْلِيمَةٍ', #2
u'وبتسليمتين': u'وَبِتَسْلِيمَتَيْنِ', #1
u'وبتعهن': u'وَبِتِعْهِنَ', #1
u'وبتلة': u'وَبَتْلَةً', #1
u'وبثجيره': u'وَبِثَجِيرِهِ', #2
u'وبثرات': u'وَبَثَرَاتٍ', #3
u'وبثرته': u'وَبَثْرَتِهِ', #1
u'وبثق': u'وَبَثَقَ', #1
u'وبثينة': u'وَبُثَيْنَةَ', #1
u'وبثينة': u'وَبُثَيْنَةُ', #1
u'وبجحنى': u'وَبَجَّحَنِى', #1
u'وبجزازوى': u'وبجزازوى', #1
u'وبجه': u'وَبَجّه', #1
u'وبجهام': u'وبجهام', #1
u'وبجهام': u'وَبِجَهَامٍ', #1
u'وبجهام': u'وَبِجَهَامِ', #1
u'وبجيرا': u'وَبُجَيْرًا', #1
u'وبجيرمي': u'وَبُجَيْرِمِيٍّ', #1
u'وبجيرمي': u'وَبُجَيْرِمِيُّ', #1
u'وبجيرمي': u'وَبُجَيْرِمِيٌّ', #77
u'وبجيلة': u'وَبَجِيلَة', #1
u'وبجيلة': u'وَبُجَيْلَةَ', #1
u'وبجيلة': u'وَبُجَيْلَةُ', #1
u'وبجيلة': u'وبجيلة', #2
u'وبجيلة': u'وَبَجِيلَةَ', #3
u'وبجيلة': u'وَبَجِيلَةُ', #6
u'وبجيلتان': u'وَبَجِيلَتَانِ', #1
u'وبحتى': u'وَبِحَتَّى', #1
u'وبحزج': u'وَبَحْزَجٌ', #1
u'وبحزج': u'وَبَحْزَجُ', #2
u'وبحشل': u'وَبَحْشَلٌ', #1
u'وبحولان': u'وَبِحَوَلَانِ', #3
u'وبحيثما': u'وَبِحَيْثُمَا', #1
u'وبحيراء': u'وَبَحِيرَاءُ', #1
u'وبحينة': u'وبحينة', #1
u'وبحينة': u'وَبُحَيْنَةُ', #2
u'وبخارص': u'وَبِخَارِصٍ', #1
u'وبخارى': u'وَبُخَارَى', #11
u'وبختنصر،': u'وبختنصر،', #1
u'وبختنصر': u'وَبُخْتُنَصّرَ', #2
u'وبخراء': u'وَبَخْرَاءُ', #1
u'وبخراء': u'وَبَخْرَاءَ', #6
u'وبخراش': u'وَبِخِرَاشِ', #1
u'وبخزج،': u'وَبُخْزَجُ،', #1
u'وبخعة': u'وَبَخَعَةٌ', #2
u'وبخورد': u'وبخورد', #1
u'وبخيبر': u'وَبِخَيْبَرِ', #1
u'وبخيبر': u'وَبِخَيْبَرَ', #4
u'وبدءوا': u'وَبَدَءُوا', #7
u'وبداء': u'وَبَدَاءً', #1
u'وبداء،': u'وَبِدَاءً،', #1
u'وبداد': u'وَبَدَادُ', #1
u'وبدارا': u'وَبِدَارًا', #13
u'وبدارا': u'وَبِدَاراً', #4
u'وبداعة': u'وَبَدَاعَةَ', #1
u'وبداعة': u'وَبَدَاعَةُ', #1
u'وبدانق': u'وَبِدَانِقٍ', #1
u'وبدرتنى': u'وَبَدَرَتْنِى', #1
u'وبدوعا': u'وَبُدُوعًا', #2
u'وبذاذة': u'وَبَذَاذَةِ', #1
u'وبذت': u'وَبَذَّتْ', #1
u'وبذت': u'وَبَذَتْ', #4
u'وبذوت': u'وَبَذَوْت', #1
u'وبذوذة': u'وَبُذُوذَةً', #1
u'وبذى': u'وَبِذِى', #1
u'وبرءوس': u'وَبِرُءُوسٍ', #1
u'وبرءوس': u'وَبِرُءُوسِ', #2
u'وبرءوسهما': u'وَبِرُءُوسِهِمَا', #1
u'وبراذان': u'وبراذان', #1
u'وبراذان': u'وَبِرَاذَانَ', #1
u'وبراذع': u'وَبَرَاذِعَ', #3
u'وبرجندي': u'وَبُرْجُنْدِيٌّ', #1
u'وبردزبه': u'وَبَرْدِزْبَهْ', #1
u'وبردزيه': u'وَبَرْدَزَيْهْ', #1
u'وبرذع': u'وَبَرْذَع', #1
u'وبرذع': u'وَبَرْذَعُ', #2
u'وبرزمين': u'وبرزمين', #1
u'وبرساما': u'وَبِرْسَامًا', #1
u'وبرسيل': u'وَبِرَسِيلِ', #1
u'وبرصيصا': u'وَبَرْصِيصَا', #1
u'وبركاتهS': u'وَبَرَكَاتُهُS', #1
u'وبركاتهSالخطبة': u'وَبَرَكَاتُهُSالْخُطْبَةُ', #1
u'وبركندن': u'وبركندن', #1
u'وبرماوي': u'وَبِرْمَاوِيُّ', #1
u'وبرماوي': u'وَبِرْمَاوِيٍّ', #2
u'وبرماوي': u'وَبِرْمَاوِيٌّ', #23
u'وبرهمو': u'وَبِرُّهُمُو', #1
u'وبرهوت': u'وَبَرَهُوتُ', #1
u'وبروثة': u'وَبِرَوْثَةٍ', #1
u'وبرؤس': u'وَبِرُؤْسِ', #1
u'وبريدة': u'وَبُرَيْدَةَ', #16
u'وبريدة': u'وَبُرَيْدَةُ', #4
u'وبريرة': u'وَبُرَيْرَةَ', #1
u'وبريرة': u'وَبَرِيرَةُ', #2
u'وبزنا': u'وَبِزِنًا', #4
u'وبزنى': u'وَبِزِنًى', #1
u'وبزنيت': u'وَبِزَنَيْتُ', #1
u'وبزوجني': u'وَبِزَوِّجْنِي', #6
u'وبزيعا': u'وَبَزِيعًا', #1
u'وبسا': u'وَبَسًّا', #1
u'وبسا': u'وَبُسّا', #2
u'وبسبس': u'وبسبس', #1
u'وبسبس': u'وبَسْبَسَ', #1
u'وبسبس': u'وَبَسْبَسٍ', #1
u'وبسبس': u'وَبَسْبَسَ', #1
u'وبسبس': u'وَبَسْبَسٌ', #3
u'وبسبس': u'وَبَسْبَسُ', #5
u'وبسبقيته': u'وَبِسَبْقِيَّتِهِ', #1
u'وبسرف': u'وَبِسَرِفِ', #1
u'وبسلا': u'وَبَسْلًا', #1
u'وبسندود': u'وبسندود', #1
u'وبسويق': u'وَبِسَوِيقِ', #1
u'وبسويق': u'وَبِسَوِيقٍ', #3
u'وبسيلة': u'وَبَسِيلَةٌ', #1
u'وبسيلة': u'وَبِسِيلَةٍ', #2
u'وبشرعا': u'وَبِشَرْعًا', #1
u'وبصبيتى': u'وَبِصِبْيَتِى', #2
u'وبصحح': u'وَبِصُحِّحَ', #1
u'وبصرى': u'وَبَصَرِى', #6
u'وبصرى': u'وَبُصْرَى', #7
u'وبطبرستان': u'وَبِطَبْرِسْتَانَ', #1
u'وبطبعا': u'وَبِطَبْعًا', #1
u'وبطرو': u'وَبِطُرُوِّ', #13
u'وبطريان': u'وَبِطَرَيَانِ', #2
u'وبطريانه': u'وَبِطَرَيَانِهِ', #1
u'وبططهم': u'وَبِطَطَهُمْ', #1
u'وبطنى': u'وَبَطْنِى', #1
u'وبطولا': u'وَبُطُولًا', #2
u'وبطوى': u'وَبِطَوًى', #1
u'وبطوى': u'وَبِطُوًى', #2
u'وبظلما': u'وَبِظُلْمًا', #1
u'وبعاجلا': u'وَبِعَاجِلًا', #2
u'وبعالا': u'وَبِعَالًا', #1
u'وبعالما': u'وَبِعَالِمًا', #1
u'وبعتكه': u'وَبِعْتُكَهُ', #11
u'وبعتنيه': u'وَبِعْتنِيهِ', #3
u'وبعتنيه': u'وَبِعْتِنِيهِ', #3
u'وبعثانى': u'وَبَعَثَانِى', #1
u'وبعثكال': u'وَبِعِثْكَالٍ', #1
u'وبعثنى': u'وَبَعَثَنِى', #3
u'وبعديته': u'وَبَعْدِيَّته', #1
u'وبعديته': u'وَبَعْدِيَّتِهِ', #1
u'وبعديته': u'وَبُعْدِيَّتُهُ', #1
u'وبعديته': u'وَبُعْدِيَّتِهِ', #1
u'وبعديتهما': u'وَبَعْدِيَّتِهِمَا', #2
u'وبعديتهما': u'وَبَعْدِيَّتُهُمَا', #3
u'وبعران': u'وَبُعْرَانٍ', #3
u'وبعسفان': u'وَبِعُسْفَانَ', #1
u'وبعشيا': u'وَبِعَشِيًّا', #6
u'وبعصا': u'وَبِعَصًا', #2
u'وبعضى': u'وبعضى', #1
u'وبعضى': u'وَبَعْضِى', #1
u'وبعمدا': u'وَبِعَمْدًا', #1
u'وبعنة': u'وَبِعُنَّةِ', #1
u'وبعيالاتهم': u'وَبِعِيَالَاتِهِمْ', #1
u'وبعيرى': u'وَبَعِيرِى', #1
u'وبغاثة': u'وَبُغَاثَةٍ', #1
u'وبغاثة': u'وَبُغَاثَةَ', #1
u'وبغاثة': u'وَبُغَاثَةٌ', #7
u'وبغالبا': u'وَبِغَالِبًا', #1
u'وبغثان': u'وَبِغْثَانٌ', #1
u'وبغدان': u'وَبَغْدَانُ', #2
u'وبغدين': u'وَبَغْدَيْنُ', #1
u'وبغدين': u'وَبَغْدَيْنِ', #1
u'وبغصيب': u'وَبِغَصِيبِ', #1
u'وبغضة': u'وَبَغْضَةٌ', #1
u'وبغضة': u'وَبُغْضَةٍ', #1
u'وبغضة': u'وَبِغْضَةً', #1
u'وبغيبغ': u'وَبُغَيْبِغٌ', #1
u'وبفتيا': u'وَبِفُتْيَا', #1
u'وبفجء': u'وَبِفَجْءِ', #1
u'وبفجاء': u'وَبِفِجَاءِ', #2
u'وبفرمود': u'وبفرمود', #1
u'وبفعائل': u'وَبِفَعَائِلَ', #5
u'وبفعول': u'وَبِفَعُولٍ', #1
u'وبفقط': u'وَبِفَقَطْ', #3
u'وبفوريته': u'وَبِفَوْرِيَّتِهِ', #2
u'وبقبقبه': u'وَبِقَبْقَبِهِ', #1
u'وبقرأين': u'وَبِقُرْأَيْنِ', #1
u'وبقفيز': u'وَبِقَفِيزٍ', #3
u'وبقم': u'وَبُقَّمٍ', #2
u'وبقم': u'وَبَقَّمٍ', #3
u'وبقير': u'وَبَقِيرٌ', #1
u'وبقيرات،': u'وَبُقَيْرَاتٌ،', #1
u'وبكا': u'وَبُكَا', #3
u'وبكاسقني': u'وَبِكَاسْقِنِي', #6
u'وبكبعني': u'وَبِكَبِعْنِي', #1
u'وبكبيع': u'وَبِكَبَيْعِ', #1
u'وبكثوا': u'وَبَكَثُوا', #1
u'وبكداء': u'وَبِكَدَاءَ', #1
u'وبكساقني': u'وَبِكَسَاقِنِي', #1
u'وبكظهر': u'وِبِكَظَهْرِ', #2
u'وبكظهر': u'وَبِكَظَهْرِ', #3
u'وبكلبس': u'وَبِكَلُبْسٍ', #1
u'وبكلبس': u'وَبِكَلُبْسِ', #2
u'وبكلبى': u'وَبِكَلْبِى', #3
u'وبكوهبت': u'وَبِكَوَهَبْت', #1
u'وبكوهبت': u'وَبِكَوَهَبْتُ', #3
u'وبكويد': u'وبكويد', #1
u'وبكى': u'وَبُكًى', #2
u'وبكيا': u'وَبُكِيًّا', #17
u'وبكيرا': u'وَبُكَيْرًا', #1
u'وبلادر': u'وَبَلَادِرَ', #1
u'وبلاع': u'وَبَلَّاعٌ', #1
u'وبلانة': u'وَبَلَّانَةِ', #1
u'وبلجرشي': u'وبلجرشي', #1
u'وبلحارث': u'وَبَلْحَارِثُ', #1
u'وبلخش': u'وبلخش', #2
u'وبلدح': u'وَبَلْدَحُ', #1
u'وبلدمة': u'وَبُلْدُمَةُ', #2
u'وبلسام': u'وَبِلْسَامٌ', #1
u'وبلعام': u'وَبَلْعَامَ', #1
u'وبلغتنى': u'وَبَلَّغْتَنِى', #1
u'وبلغما': u'وَبَلْغَمًا', #1
u'وبلغنى': u'وبلغنى', #1
u'وبلغنى': u'وَبَلَغَنِى', #51
u'وبلقرن': u'وبلقرن', #1
u'وبلقلقه': u'وَبِلَقْلَقِهِ', #1
u'وبلقين': u'وبلقين', #1
u'وبلقين': u'وَبَلْقَيْنَ', #1
u'وبلقين': u'وَبَلْقَيْن', #2
u'وبلنسية': u'وَبَلَنْسِيَةَ', #2
u'وبلوى': u'وَبَلْوًى', #2
u'وبلى': u'وَبَلَى', #91
u'وبليس': u'وَبِلَيْسَ', #2
u'وبليق': u'وَبُلَيْقُ', #1
u'وبليمتنعن': u'وبِلَيَمْتَنِعَنَّ', #2
u'وبمباحا': u'وَبِمُبَاحًا', #1
u'وبمترصات': u'وَبِمُتْرِصَاتٍ', #1
u'وبمترصات': u'وَبِمُتْرَصَاتِ', #3
u'وبمثلا': u'وَبِمَثَلًا', #1
u'وبمثناتين': u'وَبِمُثَنَّاتَيْنِ', #1
u'وبمزهق': u'وَبِمُزْهِقٍ', #1
u'وبمسمى': u'وَبِمُسَمًّى', #1
u'وبمصلى': u'وَبِمُصَلًّى', #1
u'وبمطلقا': u'وَبِمُطْلَقًا', #2
u'وبمطمئنا': u'وَبِمُطْمَئِنًّا', #1
u'وبمعاطاة': u'وَبِمُعَاطَاةٍ', #1
u'وبمعطن': u'وَبِمَعْطِنِ', #5
u'وبمعنى': u'وَبِمَعْنًى', #10
u'وبمعينا': u'وَبِمُعَيَّنًا', #1
u'وبمقصودا': u'وَبِمَقْصُودًا', #1
u'وبمكترى': u'وَبِمُكْتَرًى', #3
u'وبمنى': u'وَبِمِنًى', #14
u'وبمهما': u'وَبِمَهْمَا', #2
u'وبموكلان': u'وبموكلان', #1
u'وبمؤنة': u'وَبِمُؤْنَةِ', #1
u'وبنانة': u'وَبُنَانَةُ', #2
u'وبندار،': u'وبندار،', #1
u'وبندار': u'وَبِنْدَارٍ', #1
u'وبندار،': u'وَبُنْدَارٌ،', #1
u'وبندار': u'وبندار', #2
u'وبندار': u'وَبِنْدَارٌ', #2
u'وبندار': u'وَبُنْدَارٌ', #4
u'وبندار': u'وَبُنْدَارٍ', #6
u'وبندار،': u'وَبُنْدَارٍ،', #7
u'وبنزديك': u'وبنزديك', #2
u'وبنضوض': u'وَبِنَضُوضٍ', #1
u'وبنغش': u'وَبِنَغْشٍ', #1
u'وبنقلان': u'وَبِنُقْلَانِ', #1
u'وبنيسابور': u'وَبِنَيْسَابُورَ', #1
u'وبهاران': u'وَبَهَارَانِ', #1
u'وبهرام': u'وَبَهْرَامٌ', #1
u'وبهرام': u'وَبَهْرَامَ', #14
u'وبهرام': u'وَبَهْرَامُ', #20
u'وبهزا': u'وبهزا', #1
u'وبهمن': u'وبهمن', #1
u'وبهير': u'وَبُهَيْرُ', #1
u'وبوارحا': u'وَبَوَارِحَا', #2
u'وبوش': u'وبوش', #1
u'وبوقات': u'وَبُوقَاتٍ', #1
u'وبوقفا': u'وَبِوَقَفَا', #1
u'وبولاق': u'وَبُولَاقِ', #1
u'وبولاق': u'وَبُولَاقَ', #3
u'وبولس': u'وَبُولَسُ', #1
u'وبولص': u'وَبُولِصَ', #1
u'وبوى': u'وبوى', #1
u'وبوىء': u'وبوىء', #1
u'وبى': u'وَبِى', #1
u'وبيا': u'وَبِيَا', #2
u'وبيأض': u'وَبَيْأَضٌ', #1
u'وبياها': u'وَبَيَّاهَا', #1
u'وبية': u'وَبِيَّةٍ', #2
u'وبيتوتة': u'وَبَيْتُوتَةٌ', #1
u'وبيتوتة': u'وَبَيْتُوتَةُ', #1
u'وبيتوتته': u'وبيتوتته', #1
u'وبيتى': u'وَبَيْتِى', #2
u'وبيحيى': u'وَبِيَحْيَى', #1
u'وبيرحمكم': u'وَبِيَرْحَمُكُمْ', #1
u'وبيري': u'وَبِيرِيٌّ', #1
u'وبيسان': u'وَبَيْسَانَ', #3
u'وبيستأجر': u'وَبِيَسْتَأْجِرُ', #1
u'وبيشة': u'وَبِيشَةُ', #1
u'وبيشة': u'وَبِيشَةَ', #2
u'وبيشتري': u'وبيشتري', #1
u'وبيص': u'وَبِيصَ', #27
u'وبيص': u'وَبِيصُ', #4
u'وبيص': u'وَبِيص', #5
u'وبيص': u'وَبِيصِ', #74
u'وبيصا': u'وَبِيصًا', #3
u'وبيصبح': u'وَبِيُصْبِحُ', #1
u'وبيصح': u'وَبِيَصِحُّ', #2
u'وبيصه': u'وَبِيصَهُ', #1
u'وبيصه': u'وَبِيصُهُ', #1
u'وبيصه': u'وَبِيصِهِ', #2
u'وبيع': u'وَبَيْعً', #1
u'وبيعتلجان': u'وَبِيَعْتَلِجَانِ', #1
u'وبيكره': u'وَبِيُكْرَهُ', #1
u'وبيكند': u'وَبِيكَنْدَ', #1
u'وبينى': u'وَبَيْنِى', #3
u'وبيهقي': u'وَبَيْهَقِيٌّ', #1
u'وة': u'وَةِ', #1
u'وت': u'وَتّ', #2
u'وتأبر': u'وَتَأَبَّرَ', #2
u'وتأبرت': u'وَتَأَبَّرَتْ', #4
u'وتأبرها': u'وَتَأْبُرُهَا', #1
u'وتابغا': u'وَتَابِغًا', #1
u'وتأتنف': u'وَتَأْتَنِفُ', #8
u'وتاح': u'وَتَاحَ', #1
u'وتأدت': u'وَتَأَدَّتْ', #12
u'وتأدى': u'وَتَأَدَّى', #11
u'وتأديها': u'وَتَأَدِّيهَا', #1
u'وتأذت': u'وَتَأَذَّتْ', #16
u'وتأذيت': u'وَتَأَذَّيْت', #1
u'وتأذيه': u'وَتَأَذِّيه', #1
u'وتأذيه': u'وَتَأَذِّيهِ', #3
u'وتأذيها': u'وَتَأَذِّيهَا', #2
u'وتاران': u'وَتَارَانُ', #1
u'وتاركت': u'وَتَارَكْت', #1
u'وتاركني': u'وَتَارِكْنِي', #1
u'وتأريبها': u'وَتَأْرِيبِهَا', #1
u'وتاريس': u'وتاريس', #1
u'وتأزير': u'وَتَأْزِيرٌ', #1
u'وتازير': u'وَتَازِيرٌ', #1
u'وتآزير': u'وَتَآزِيرِ', #2
u'وتآزيره': u'وَتَآزِيرِهِ', #2
u'وتأزيره': u'وَتَأْزِيرُهُ', #2
u'وتأزيره': u'وَتَأْزِيرِهِ', #5
u'وتاسوع': u'وَتَاسُوعِ', #1
u'وتأشرون': u'وَتَأْشِرُونَ', #1
u'وتأشرون،': u'وَتَأْشِرُونَ،', #1
u'وتاشفين،': u'وَتاشَفِينُ،', #1
u'وتأشموا': u'وَتَأَشَّمُوا', #1
u'وتأقيت': u'وَتَأْقِيتٍ', #1
u'وتالرحمن': u'وَتَالرَّحْمَنِ', #6
u'وتالف': u'وَتَالِفٌ', #1
u'وتالف': u'وَتَالِفٍ', #2
u'وتالفة': u'وَتَالِفَةٌ', #1
u'وتأنبه': u'وَتَأَنُّبِهِ', #1
u'وتأنه': u'وَتَأَنَّهُ', #1
u'وتأوبته': u'وَتَأَوّبَتْهُ', #1
u'وتأوى': u'وَتَأْوِى', #1
u'وتاويل': u'وتاويل', #1
u'وتأيم': u'وَتَأَيَّمَ', #1
u'وتأيمت': u'وَتَأَيَّمَتْ', #9
u'وتباءس': u'وَتَبَاءَسُ', #5
u'وتباب': u'وَتَبَابٌ', #1
u'وتبابه': u'وَتَبَابُهُ', #1
u'وتباضعها': u'وَتُبَاضِعُهَا', #1
u'وتباعة': u'وَتِبَاعَةٌ', #1
u'وتبالهت': u'وَتَبَالَهْتُ', #1
u'وتباهلت': u'وَتَبَاهَلْتُ', #1
u'وتباؤس': u'وَتَبَاؤُسٌ', #1
u'وتبائع': u'وَتَبَائِعَ', #1
u'وتبائع': u'وَتَبَائِعُ', #2
u'وتبتدي': u'وَتَبْتَدِيَ', #1
u'وتبتديه': u'وَتَبْتَدِيهِ', #1
u'وتبحيره': u'وَتَبْحِيرُهُ', #1
u'وتبدئة': u'وَتَبْدِئَةَ', #2
u'وتبدئة': u'وَتَبْدِئَةُ', #4
u'وتبديع': u'وَتَبْدِيعِ', #1
u'وتبرءوا': u'وَتَبَرّءُوا', #1
u'وتبرديكر': u'وتبرديكر', #1
u'وتبريء': u'وَتَبْرِيءِ', #1
u'وتبشبش': u'وَتَبَشْبَشَ', #1
u'وتبصرة': u'وَتَبْصِرَةً', #1
u'وتبصرة': u'وَتَبْصِرَةِ', #6
u'وتبطيله': u'وَتَبْطِيلِهِ', #1
u'وتبعثنى': u'وَتَبْعَثُنِى', #1
u'وتبعضها': u'وَتُبَعِّضُهَا', #1
u'وتبغيت': u'وَتَبَغّيْتَ', #1
u'وتبغيل': u'وتَبْغيل', #1
u'وتبغيل': u'وَتَبْغِيلُ', #2
u'وتبوكا،': u'وتبوكًا،', #1
u'وتبوئتها': u'وَتَبْوِئَتُهَا', #3
u'وتبياض،': u'وَتَبْيَاضُّ،', #1
u'وتبيعا': u'وَتَبِيعًا', #10
u'وتبيعة': u'وَتَبِيعَةً', #1
u'وتبيعة': u'وَتَبِيعَةٍ', #1
u'وتبيعتان': u'وَتَبِيعَتَانِ', #1
u'وتت': u'وتت', #138
u'وتت': u'وَتت', #5
u'وتتأدى': u'وَتَتَأَدَّى', #17
u'وتتأذى': u'وَتَتَأَذَّى', #4
u'وتتأذين': u'وَتَتَأَذَّيْنَ', #1
u'وتتارخانية': u'وتتارخانية', #5
u'وتتام': u'وَتَتَامَّ', #1
u'وتتام': u'وَتَتَامّ', #7
u'وتتامت': u'وَتَتَامّتْ', #1
u'وتتاموا': u'وَتَتَامُّوا', #1
u'وتتايع': u'وَتَتَايَعَ', #1
u'وتتبعض': u'وَتَتَبَعَّضُ', #1
u'وتتبغض': u'وَتَتَبَغَّضُ', #1
u'وتتحتم': u'وَتَتَحَتَّمُ', #19
u'وتتحرم': u'وَتَتَحَرَّمَ', #2
u'وتتحيض': u'وَتُتَحَيَّضُ', #1
u'وتتخالج': u'وَتَتَخَالَجُ', #1
u'وتترادان': u'وَتَتَرَادَّانِ', #1
u'وتترسهم': u'وَتَتَرُّسُهُمْ', #1
u'وتترسهم': u'وَتَتَرُّسِهِمْ', #1
u'وتترى': u'وَتَتْرَى', #1
u'وتتريب': u'وَتَتْرِيبُ', #1
u'وتتريب': u'وَتَتْرِيبِ', #1
u'وتتريبه': u'وَتَتْرِيبِهِ', #3
u'وتتريبها': u'وَتَتْرِيبِهَا', #1
u'وتتساويان': u'وَتَتَسَاوَيَانِ', #1
u'وتتسخط': u'وَتَتَسَخَّطُ', #1
u'وتتشام': u'وَتَتَشَامّ', #1
u'وتتصرخ': u'وَتَتَصَرَّخَ', #1
u'وتتصفى': u'وَتَتَصَفَّى', #1
u'وتتعمر': u'وَتَتَعَمَّرُ', #1
u'وتتعير': u'وَتَتَعَيَّرُ', #1
u'وتتقلق': u'وَتَتَقَلَّقُ', #1
u'وتتلجم': u'وَتَتَلَجَّمَ', #4
u'وتتمحض': u'وَتَتَمَحَّضُ', #1
u'وتتناتج': u'وَتَتَنَاتَجُ', #1
u'وتتوضئوا': u'وَتَتَوَضَّئُوا', #1
u'وتثاوب': u'وَتَثَاوُبٌ', #1
u'وتثاوب': u'وَتَثَاوُبٍ', #1
u'وتثاوب': u'وَتَثَاوَبَ', #3
u'وتثاور': u'وَتَثَاوَرَ', #1
u'وتجانف': u'وَتَجَانَفَ', #3
u'وتجاولا،': u'وتجاولا،', #1
u'وتجاولا': u'وَتَجَاوَلَا', #3
u'وتجايشوا': u'وَتَجَايَشُوا', #1
u'وتجتزئ': u'وَتَجْتَزِئَ', #1
u'وتجتزئ': u'وَتَجْتَزِئُ', #3
u'وتجتلدوا': u'وَتَجْتَلِدُوا', #2
u'وتجتلي': u'وَتَجْتَلِي', #1
u'وتجرئة': u'وَتَجْرِئَةً', #1
u'وتجزئان': u'وَتُجْزِئَانِ', #2
u'وتجسيس': u'وَتَجْسِيسٍ', #1
u'وتجسيس': u'وَتَجْسِيسِ', #1
u'وتجشيه': u'وَتَجَشِّيهِ', #1
u'وتجمعى': u'وَتَجْمَعِى', #1
u'وتجميره': u'وَتَجْمِيرُهُ', #8
u'وتجوزتها': u'وَتَجَوَّزْتُهَا', #1
u'وتجويرا': u'وَتَجْوِيرًا', #1
u'وتجىء': u'وَتَجِىءُ', #4
u'وتجيئني': u'وَتَجِيئَنِي', #1
u'وتجيئني': u'وَتَجِيئُنِي', #1
u'وتحاجز': u'وَتَحَاجَزَ', #2
u'وتحاجزهم': u'وَتَحَاجُزُهُمْ', #1
u'وتحاص': u'وتحاص', #1
u'وتحاص': u'وَتَحَاصُّ', #1
u'وتحاص': u'وَتُحَاصَّ', #1
u'وتحاص': u'وَتُحَاصُّ', #3
u'وتحاص': u'وَتَحَاصَّ', #4
u'وتحاصا': u'وَتَحَاصَّا', #2
u'وتحاصت': u'وَتَحَاصَّتْ', #1
u'وتحاصص': u'وَتَحَاصَصَ', #2
u'وتحاصص': u'وَتُحَاصَصُ', #3
u'وتحاصص': u'وَتُحَاصِصُ', #4
u'وتحاصصه': u'وَتَحَاصَصَهُ', #1
u'وتحاصوا': u'وَتُحَاصُوا', #1
u'وتحاصوا': u'وَتَحَاصُّوا', #2
u'وتحالل': u'وَتَحَالُلِ', #1
u'وتحالم': u'وَتَحَالَمَ', #1
u'وتحاوزوا': u'وَتَحَاوَزُوا', #2
u'وتحايشوا': u'وَتَحَايَشُوا', #1
u'وتحتجم': u'وَتَحْتَجِمُ', #1
u'وتحتجم': u'وَتَحْتَجِمَ', #2
u'وتحتشي': u'وَتَحْتَشِي', #2
u'وتحتمت': u'وَتَحَتَّمَتْ', #3
u'وتحتى': u'وَتَحْتِى', #8
u'وتحدثنى': u'وَتُحَدِّثُنِى', #1
u'وتحذيف': u'وَتَحْذِيفٍ', #2
u'وتحفزإلى': u'وَتَحَفُّزٍإِلَى', #1
u'وتحفيتهم': u'وَتَحْفِيَتِهِمْ', #1
u'وتحميدة': u'وَتَحْمِيدَةٍ', #6
u'وتحنيث': u'وَتَحْنِيثِ', #2
u'وتحويلة': u'وتحويلة', #1
u'وتحى': u'وَتَحَّى', #1
u'وتحياة': u'وَتَحَيَاةِ', #3
u'وتحيضت': u'وَتَحَيَّضَتْ', #4
u'وتحيى': u'وَتُحْيِى', #1
u'وتخارج': u'وَتُخَارَجُ', #1
u'وتخاله': u'وَتَخَالُهُ', #2
u'وتخامصت': u'وَتَخَامَصَتْ', #1
u'وتخبارها': u'وَتَخْبَارِهَا', #1
u'وتخبرونى': u'وَتُخْبِرُونِى', #1
u'وتخبيب': u'وَتَخْبِيبُ', #1
u'وتخبيبهم': u'وَتَخْبِيبِهِمْ', #1
u'وتخبيته': u'وَتَخْبِيَتُهُ', #1
u'وتخبيط': u'وَتَخْبِيطٌ', #1
u'وتختروان': u'وَتَخْتَرْوَانٍ', #1
u'وتختلع': u'وَتَخْتَلِعْ', #1
u'وتختما': u'وَتَخَتُّمًا', #1
u'وتخدج': u'وَتَخْدِجُ', #1
u'وتخذف؟': u'وَتَخْذِفُ؟', #1
u'وتخربت': u'وَتَخَرَّبَتْ', #1
u'وتخريص': u'وَتَخْرِيصُ', #1
u'وتخزيته': u'وَتَخْزِيَتِهِ', #1
u'وتخففا': u'وَتَخَفّفًا', #1
u'وتخلدت': u'وَتَخَلَّدَتْ', #5
u'وتخنقت': u'وتخنقت', #1
u'وتخنقت': u'وَتَخَنَّقَتْ', #1
u'وتدالون': u'وَتُدَالُونَ', #3
u'وتدانت': u'وَتَدَانَتْ', #1
u'وتدرية': u'وَتَدْرِيَةٍ', #1
u'وتذكيرى': u'وَتَذْكِيرِى', #1
u'وتذوقى': u'وَتَذُوقِى', #4
u'وتذيفون': u'وَتَذِيفُونَ', #1
u'وتراجيح': u'وَتَرَاجِيحُ', #1
u'وترأسا': u'وَتَرَأُّسًا', #1
u'وتراكه': u'وَتَرَاكَهُ', #7
u'وترائغا': u'وَتَرَائِغًا', #1
u'وتربدت': u'وَتَرَبَّدَتْ', #1
u'وتربيتة': u'وَتَرْبِيتَةَ', #1
u'وترة': u'وَتَرَةٌ', #1
u'وترة': u'وَتِرَةً', #1
u'وترة': u'وَتِرَةٌ', #1
u'وترة': u'وَتَرَةَ', #2
u'وترة': u'وَتَرَةِ', #2
u'وترتاض': u'وَتَرْتَاضُ', #1
u'وترتجع': u'وَتُرْتَجَعُ', #2
u'وترتروه': u'وَتَرْتِرُوهُ', #1
u'وترتضع': u'وَتَرْتَضِعُ', #2
u'وترحلت': u'وترحلت', #1
u'وترحمنى': u'وَتَرْحَمْنِى', #1
u'وترخصتا': u'وَتَرَخَّصَتَا', #3
u'وترسابد': u'وترسابد', #1
u'وترست': u'وَتَرّسْت', #1
u'وترشيش': u'وَتَرْشِيشٌ', #1
u'وترشيش': u'وَتَرْشِيشٍ', #1
u'وترعيده': u'وَتَرْعِيدُهُ', #4
u'وترغام': u'وَتِرْغَامٌ', #1
u'وتركاش': u'وتركاش', #1
u'وتركنى': u'وَتَرَكَنِى', #1
u'وترمذ': u'وَتِرْمِذَ', #1
u'وترنجبيل': u'وَتَرْنْجَبِيلٍ', #1
u'وترنجبيل': u'وترنجبيل', #2
u'وترهينه': u'وَتَرْهِينُهُ', #1
u'وترهينها': u'وَتَرْهِينِهَا', #1
u'وتروث': u'وَتَرُوثُ', #7
u'وترياع': u'وَتِرْيَاعٌ', #1
u'وتزاجروا': u'وَتَزَاجَرُوا', #1
u'وتزبئر': u'وتَزْبَئِرُّ', #1
u'وتزدلف': u'وَتَزْدَلِفُ', #1
u'وتزريبها': u'وَتَزْرِيبِهَا', #1
u'وتزريبها': u'وَتَزْرِيبُهَا', #2
u'وتزريره': u'وَتَزْرِيرِهِ', #1
u'وتزريق': u'وَتَزْرِيقٌ', #1
u'وتزريق': u'وَتَزْرِيقٍ', #1
u'وتزليعه': u'وَتَزْلِيعِهِ', #5
u'وتزوجتيه': u'وَتَزَوَّجْتِيهِ', #1
u'وتزوجنيها': u'وَتُزَوِّجْنِيهَا', #1
u'وتزودناها': u'وَتَزَوَّدْنَاهَا', #1
u'وتساحق': u'وَتُسَاحَقُ', #1
u'وتسالب': u'وَتَسَالُبٍ', #1
u'وتسألونى': u'وَتَسْأَلُونِى', #1
u'وتساويتا': u'وَتَسَاوَيَتَا', #1
u'وتساويتا': u'وَتَسَاوِيَتَا', #1
u'وتستتاب': u'وَتُسْتَتَابُ', #3
u'وتستثفر': u'وَتَسْتَثْفِرَ', #1
u'وتستثفر': u'وَتَسْتَثْفِرْ', #2
u'وتستثفر': u'وَتَسْتَثْفِرُ', #5
u'وتستحاض': u'وَتُسْتَحَاضُ', #5
u'وتستحد': u'وَتَسْتَحِدُّ', #1
u'وتستحد': u'وَتَسْتَحِدَّ', #13
u'وتستحيى': u'وَتُسْتَحْيَى', #1
u'وتستخلي': u'وَتَسْتَخْلِي', #2
u'وتستدخله': u'وَتَسْتَدْخِلَهُ', #3
u'وتستذفر': u'وَتَسْتَذْفِرَ', #1
u'وتستذفر': u'وَتَسْتَذْفِرُ', #1
u'وتستذفر': u'وَتَسْتَذْفِرْ', #1
u'وتستسعي': u'وَتَسْتَسْعِي', #1
u'وتستصبح': u'وَتَسْتَصْبِحُ', #1
u'وتستضر': u'وَتَسْتَضِرُّ', #1
u'وتستطهر': u'وَتَسْتَطْهِرُ', #1
u'وتستعقب': u'وَتَسْتَعْقِبُ', #1
u'وتستفتونى': u'وَتَسْتَفْتُونِى', #1
u'وتستقذره': u'وَتَسْتَقْذِرُهُ', #3
u'وتستقطر': u'وَتُسْتَقْطَرَ', #1
u'وتستكسب': u'وَتَسْتَكْسِبُ', #1
u'وتستنجح': u'وَتُسْتَنْجَحُ', #1
u'وتستنصرونى': u'وَتَسْتَنْصِرُونِى', #1
u'وتستنفق': u'وَتَسْتَنْفِقُ', #1
u'وتستنيب': u'وَتَسْتَنِيبُ', #1
u'وتستوق': u'وَتُسْتُوقٌ', #1
u'وتسجنا': u'وَتَسَجُّنًا', #2
u'وتسخيم': u'وَتَسْخِيمُ', #2
u'وتسرة': u'وَتَسِرَّةً', #1
u'وتسريا': u'وَتَسَرِّيًا', #1
u'وتسريت': u'وَتَسَرَّيْت', #1
u'وتسعيان': u'وَتَسْعَيَانِ', #2
u'وتسقيمها': u'وَتَسْقِيمِهَا', #1
u'وتسكينة': u'وَتَسْكِينَةٍ', #1
u'وتسليم': u'وَتَسْلِيمً', #1
u'وتسليمة': u'وَتَسْلِيمَةٌ', #10
u'وتسليمة': u'وَتَسْلِيمَةً', #3
u'وتسليمة': u'وَتَسْلِيمَةُ', #3
u'وتسليمة': u'وَتَسْلِيمَةِ', #4
u'وتسليمة': u'وَتَسْلِيمَةٍ', #6
u'وتسليمتان': u'وَتَسْلِيمَتَانِ', #1
u'وتسليمتين': u'وَتَسْلِيمَتَيْنِ', #4
u'وتسميعة': u'وَتَسْمِيعَةٍ', #3
u'وتشامت': u'وَتَشَامَّتِ', #1
u'وتشحيذ': u'وَتَشْحِيذَ', #1
u'وتشحيذ': u'وَتَشْحِيذُ', #1
u'وتشربت': u'وَتَشَرَّبَتْ', #2
u'وتشرمSمن': u'وَتُشْرَمُSمِنْ', #1
u'وتشريج': u'وَتَشْرِيجُ', #2
u'وتشريجها': u'وَتَشْرِيجُهَا', #1
u'وتشزن': u'وَتَشَزَّنَ', #1
u'وتشعيرة': u'وَتَشْعِيرَةٍ', #2
u'وتشفقا': u'وَتَشَفُّقًا', #1
u'وتشييصها': u'وَتَشْيِيصِهَا', #1
u'وتصحفت': u'وَتَصَحَّفَتْ', #1
u'وتصدقى': u'وَتَصَدَّقِى', #3
u'وتصرية': u'وَتَصْرِيَةَ', #1
u'وتصرية': u'وَتَصْرِيَةِ', #1
u'وتصرية': u'وَتَصْرِيَةُ', #6
u'وتصعدا': u'وَتَصَعُّدًا', #2
u'وتصفار': u'وتصفار', #1
u'وتصفار': u'وَتَصْفَارَّ', #2
u'وتصفار': u'وَتَصْفَارُّ', #3
u'وتصقيل': u'وَتَصْقِيلِ', #1
u'وتصلبنى': u'وَتَصْلُبُنِى', #1
u'وتصوبت': u'وَتَصَوَّبَتِ', #1
u'وتضبيب': u'وَتَضْبِيبُ', #1
u'وتضبيبه': u'وَتَضْبِيبُهُ', #2
u'وتضميرها': u'وَتَضْمِيرُهَا', #1
u'وتضميرها': u'وَتَضْمِيرِهَا', #1
u'وتضهد': u'وَتُضْهَدْ', #2
u'وتطارشت': u'وَتَطَارَشَتْ', #3
u'وتطامن': u'وَتَطَامُنِ', #1
u'وتطامنها': u'وَتَطَامُنُهَا', #1
u'وتطرية': u'وَتَطْرِيَةٍ', #6
u'وتطعمت': u'وَتَطَعَّمْتَ', #1
u'وتطلاب': u'وَتِطْلَابُ', #1
u'وتطلابها': u'وَتَطْلَابِهَا', #2
u'وتطلقت': u'وَتَطَلَّقْتِ', #1
u'وتطليقة': u'وَتَطْلِيقَةُ', #2
u'وتطليقة': u'وَتَطْلِيقَةٍ', #3
u'وتطليقة': u'وَتَطْلِيقَةً', #4
u'وتطليقة': u'وَتَطْلِيقَةٌ', #6
u'وتطليقتين': u'وَتَطْلِيقَتَيْنِ', #1
u'وتطهيرة': u'وَتَطْهِيرَة', #1
u'وتطؤه': u'وَتَطَؤُهُ', #21
u'وتطيلسا': u'وَتَطَيْلُسًا', #1
u'وتظنيا': u'وَتَظَنّيًا', #1
u'وتعابس': u'وَتَعَابُسِ', #1
u'وتعارضنى': u'وَتُعَارِضُنِى', #1
u'وتعارفناها': u'وَتَعَارَفْنَاهَا', #1
u'وتعازير': u'وَتَعَازِيرَ', #1
u'وتعازير': u'وَتَعَازِيرِ', #1
u'وتعازيره': u'وَتَعَازِيرِهِ', #6
u'وتعاناه': u'وَتَعَانَّاهُ', #1
u'وتعاينتم': u'وَتَعَايَنْتُمْ', #1
u'وتعبأت': u'وَتَعَبّأَتْ', #2
u'وتعبأت': u'وَتَعَبَّأَتْ', #2
u'وتعتار': u'وَتِعْتَارٍ', #1
u'وتعتلف': u'وَتُعْتَلَفُ', #1
u'وتعتلف': u'وَتَعْتَلِفُ', #2
u'وتعتوره': u'وَتَعْتَوِرُهُ', #2
u'وتعجلى': u'وَتُعَجِّلِى', #1
u'وتعرقب': u'وَتُعَرْقَبُ', #1
u'وتعرقته': u'وَتَعَرَّقْتهُ', #1
u'وتعرقته': u'وَتَعَرَّقْتُهُ', #2
u'وتعزة': u'وَتَعِزَّةِ', #1
u'وتعزيل': u'وَتَعْزِيلُ', #1
u'وتعسكرهم': u'وَتَعَسْكُرُهُمْ', #1
u'وتعسكرهم': u'وَتَعَسْكُرِهِمْ', #1
u'وتعشار': u'وَتِعْشَارٌ', #2
u'وتعصيته': u'وَتَعْصِيَتُهُ', #1
u'وتعطينى': u'وَتُعْطِيَنِى', #1
u'وتعفيش': u'وَتَعْفِيشُ', #2
u'وتعفيشه': u'وَتَعْفِيشِهِ', #3
u'وتعقاد': u'وَتَعْقَادُ', #4
u'وتعيبت': u'وَتَعَيَّبَتْ', #13
u'وتغ': u'وَتِغَ', #1
u'وتغالت': u'وَتَغَالَتْ', #1
u'وتغالظا': u'وَتَغَالَظَا', #1
u'وتغالظا،': u'وَتَغَالَظَا،', #1
u'وتغبطهم': u'وَتَغْبِطُهُمْ', #1
u'وتغبيط': u'وَتَغْبِيطٌ', #2
u'وتغبيطه': u'وَتَغْبِيطِهِ', #1
u'وتغبيطهم': u'وَتَغْبِيطُهُمْ', #1
u'وتغتدي': u'وَتَغْتَدِي', #1
u'وتغشانى': u'وَتَغَشَّانِى', #1
u'وتغلمين': u'وَتَغْلَمَيْنِ', #1
u'وتغمص': u'وَتَغْمِصُ', #1
u'وتغمص': u'وتغمص', #2
u'وتفاجت': u'وَتَفَاجَّتْ', #1
u'وتفاريع': u'وَتَفَارِيعُ', #1
u'وتفاريع': u'وَتَفَارِيعَ', #2
u'وتفاريعه': u'وَتَفَارِيعِهِ', #1
u'وتفاريعه': u'وَتَفَارِيعُهُ', #2
u'وتفاريعها': u'وَتَفَارِيعَهَا', #1
u'وتفاريعها': u'وَتَفَارِيعُهَا', #1
u'وتفاريعها': u'وَتَفَارِيعِهَا', #2
u'وتفاريعهم': u'وَتَفَارِيعهمْ', #1
u'وتفاريعهم': u'وَتَفَارِيعِهِمْ', #1
u'وتفتض': u'وَتَفْتَضُّ', #2
u'وتفحيص': u'وَتَفْحِيصٍ', #1
u'وتفخما': u'وَتَفَخُّمًا', #1
u'وتفرقواSشعر': u'وَتَفَرّقُواSشِعْرُ', #1
u'وتفعلة': u'وَتَفْعِلَةٌ', #1
u'وتفوح': u'وَتَفُوحُ', #2
u'وتفوضت': u'وَتَفَوَّضَتْ', #1
u'وتفيهق': u'وَتَفَيْهُقٍ', #1
u'وتقاديرها': u'وَتَقَادِيرِهَا', #2
u'وتقاديرهم': u'وَتَقَادِيرِهِمْ', #1
u'وتقارا': u'وَتَقَارًّا', #1
u'وتقاررا': u'وَتَقَارَرَا', #1
u'وتقايأه': u'وَتَقَايَأَهُ', #2
u'وتقايئه': u'وَتَقَايُئِهِ', #1
u'وتقدع': u'وَتُقْدَعُ', #2
u'وتقدعهم': u'وَتَقْدَعُهُمْ', #1
u'وتقرءون': u'وَتَقْرَءُونَ', #1
u'وتقرؤه': u'وَتَقْرَؤُهُ', #1
u'وتقصار': u'وَتِقْصَارٌ', #2
u'وتقطعتكم': u'وَتَقَطَّعَتْكُمُ', #2
u'وتقلس': u'وَتَقَلّسَ', #1
u'وتقمره': u'وَتَقَمَّرَهُ', #2
u'وتقمله': u'وَتَقَمُّلِهِ', #1
u'وتقمئة': u'وَتَقْمِئَةً', #3
u'وتقواله': u'وَتِقْوَالِهِ', #1
u'وتقيير': u'وَتَقْيِيرِ', #1
u'وتكا،': u'وَتَكَا،', #1
u'وتكاثم': u'وَتَكَاثُمِ', #1
u'وتكاميش': u'وَتَكَامِيشُ', #1
u'وتكتبت': u'وَتَكَتَّبَتْ', #1
u'وتكرمنى': u'وَتُكْرِمَنِى', #1
u'وتكريت': u'وَتَكْرِيتَ', #1
u'وتكفيان': u'وَتَكْفِيَانِ', #2
u'وتكلأت': u'وَتَكَلَّأْتُ', #1
u'وتكليفناها': u'وتَكْلِيفُناها', #1
u'وتكليفناها': u'وَتَكْلِيفُنَاهَا', #2
u'وتكنع': u'وَتُكَنّعُ', #1
u'وتلبطت': u'وَتَلَبَّطَتْ', #1
u'وتلتلوه': u'وَتَلْتِلُوهُ', #1
u'وتلجمت': u'وَتَلَجَّمَتْ', #1
u'وتلحلح': u'وَتَلَحْلَحَ', #1
u'وتلحلحوا': u'وَتَلَحْلَحُوا', #1
u'وتلداغا': u'وَتَلْدَاغًا', #1
u'وتلعاب': u'وَتِلْعَابٌ', #1
u'وتلعبت': u'وَتَلَعَّبَتْ', #1
u'وتلعفر': u'وتلعفر', #1
u'وتلفاق': u'وَتِلْفَاقٌ', #1
u'وتلقام': u'وَتِلْقَامٌ', #1
u'وتليط': u'وَتُلِيطُ', #1
u'وتليق': u'وَتَلِيقُ', #1
u'وتماضر': u'وَتُمَاضِرُ', #2
u'وتمالؤ': u'وَتَمَالُؤٍ', #1
u'وتماهل': u'وَتَمَاهَلَ', #1
u'وتمتحق': u'وَتَمْتَحِقُ', #1
u'وتمجس': u'وَتَمَجَّسَ', #1
u'وتمجس': u'وَتَمَجُّسُ', #1
u'وتمجسه': u'وَتَمَجُّسُهُ', #1
u'وتمجسها': u'وَتَمَجُّسُهَا', #1
u'وتمحيق': u'وَتَمْحِيقِ', #2
u'وتمرشه': u'وَتَمْرُشهُ', #1
u'وتمرضت': u'وَتَمَرَّضَتْ', #1
u'وتمسخر': u'وَتَمَسْخُرٍ', #1
u'وتمشدق': u'وَتَمَشْدُقٍ', #1
u'وتمعدد': u'وَتَمَعْدَدْ', #1
u'وتمعددوا': u'وَتَمَعْدَدُوا', #7
u'وتمعر': u'وَتَمَعَّر', #1
u'وتمعر': u'وَتَمَعَّرَ', #2
u'وتمعززوا': u'وَتَمَعْزَزُوا', #1
u'وتمعش': u'وَتَمَعُّشٍ', #1
u'وتمعط': u'وَتَمَعَّطَ', #1
u'وتمعط': u'وَتَمَعُّطُ', #1
u'وتمعكت': u'وَتَمَعَّكَتْ', #1
u'وتمكحل': u'وَتَمَكْحَلَ', #1
u'وتمكننى': u'وَتُمَكِّنَنِى', #1
u'وتمكنى': u'وَتُمَكِّنِّى', #1
u'وتمنعونى': u'وَتَمْنَعُونِى', #2
u'وتمير': u'وَتَمَيُّرُ', #1
u'وتميما': u'وَتَمِيمًا', #9
u'وتميمها': u'وَتَمِيمُهَا', #1
u'وتناكدا': u'وَتَنَاكُدًا', #1
u'وتناكل': u'وَتَنَاكُلٌ', #1
u'وتنثوي': u'وَتَنْثَوِي', #1
u'وتنجيري': u'وَتَنْجِيرِيٌّ', #1
u'وتنديم': u'وَتَنْدِيمٍ', #1
u'وتنزال': u'وَتِنْزَالٌ', #1
u'وتنضيض': u'وَتَنْضِيضُ', #5
u'وتنضيضه': u'وَتَنْضِيضَهُ', #1
u'وتنضيضه': u'وَتَنْضِيضِهِ', #1
u'وتنضيضه': u'وَتَنْضِيضُهُ', #2
u'وتنفارها': u'وَتَنْفَارِهَا', #1
u'وتنفحج': u'وَتَنْفَحِجُ', #1
u'وتنفيان': u'وَتَنْفِيَانِ', #1
u'وتنقدح': u'وَتَنْقَدِحَ', #1
u'وتنقدح': u'وَتَنْقَدِحُ', #3
u'وتنوخ': u'وَتَنُوخِ', #1
u'وتنوخ': u'وَتَنُوخُ', #2
u'وتنوخ': u'وَتَنُوخَ', #5
u'وتهابه': u'وَتَهَابُهُ', #3
u'وتهابهم': u'وَتَهَابُهُمْ', #1
u'وتهارج': u'وَتَهَارَجَ', #1
u'وتهارجا': u'وَتَهَارَجَا', #1
u'وتهارجا': u'وَتَهَارُجًا', #1
u'وتهامة': u'وَتِهَامَة', #1
u'وتهامة': u'وَتِهَامَةٌ', #1
u'وتهامة': u'وَتِهَامَةُ', #1
u'وتهامة': u'وَتِهَامَةَ', #27
u'وتهامته': u'وَتِهَامَتُهُ', #1
u'وتهانؤ': u'وَتَهَانُؤُ', #1
u'وتهانؤ': u'وَتَهَانُؤٌ', #2
u'وتهايآ': u'وَتَهَايَآ', #2
u'وتهايأ': u'وَتَهَايَأَ', #2
u'وتهايآه': u'وَتَهَايَآهُ', #1
u'وتهايؤ': u'وَتَهَايُؤ', #1
u'وتهايؤ': u'وَتَهَايُؤٌ', #1
u'وتهايئا': u'وَتَهَايَئَا', #1
u'وتهراق': u'وَتُهَرَاقُ', #2
u'وتهراق': u'وَتُهْرَاقُ', #2
u'وتهرت': u'وَتَهَرَّتْ', #3
u'وتهرى': u'وَتَهَرَّى', #1
u'وتهزءوا': u'وَتَهَزَّءُوا', #1
u'وتهصرت': u'وَتَهَصّرَتْ', #2
u'وتهليلة': u'وَتَهْلِيلَةٍ', #4
u'وتهممت': u'وَتَهَمَّمَتْ', #1
u'وتهواء': u'وَتَهْوَاءٌ', #1
u'وتهواء': u'وَتِهْوَاءَ', #1
u'وتؤاخذ': u'وَتُؤَاخِذُ', #1
u'وتؤاخذ': u'وَتُؤَاخَذُ', #9
u'وتواخيا': u'وَتَوَاخِيَا', #1
u'وتواخيا': u'وَتَوَاخَيَا', #2
u'وتوأد': u'وَتَوَأَّدَ', #1
u'وتواسعت': u'وَتَوَاسَعَتْ', #1
u'وتوافت': u'وَتَوَافَتْ', #1
u'وتوالبها': u'وَتَوَالِبُهَا', #1
u'وتواليفه': u'وَتَوَالِيفُهُ', #1
u'وتؤام': u'وَتُؤَامٌ', #2
u'وتؤامر': u'وَتُؤَامَرُ', #1
u'وتؤانس': u'وَتُؤَانِسُ', #2
u'وتوبى': u'وَتُوبِى', #6
u'وتوحيشا': u'وَتَوْحِيشًا', #3
u'وتورا': u'وَتُورَا', #1
u'وتوز': u'وَتَوْزٍ', #1
u'وتوشيرها': u'وَتَوْشِيرِهَا', #1
u'وتوضعا': u'وَتَوَضُعًا', #1
u'وتوضئى': u'وَتَوَضَئِى', #1
u'وتوضئى': u'وَتَوَضَّئِى', #7
u'وتوضيت': u'وَتَوَضَّيْت', #1
u'وتوطئان': u'وَتُوطَئَانِ', #1
u'وتوفنى': u'وَتَوَفَّنِى', #4
u'وتوقافهم': u'وَتَوْقَافِهِمْ', #2
u'وتوقانا': u'وَتَوَقَانًا', #1
u'وتوكذبا': u'وتوكذبا', #1
u'وتوكذبانومنى': u'وتوكذبانومنى', #1
u'وتولنى': u'وَتَوَلَّنِى', #5
u'وتوماس': u'وَتُومَاسُ', #2
u'وتؤمرنى': u'وَتُؤَمِّرُنِى', #2
u'وتئوب': u'وَتَئُوبُ', #2
u'وتئول': u'وَتَئُولُ', #2
u'وتيام': u'وتيام', #1
u'وتيتل': u'وَتَيْتُلٍ', #1
u'وتيرا': u'وتيرا', #1
u'وتيرح': u'وَتَيْرَحُ', #1
u'وتيزخر': u'وتيزخر', #1
u'وتيمار': u'وتيمار', #1
u'وتيمار': u'وَتَيْمَارٍ', #4
u'وتيمارات': u'وَتَيْمَارَاتٍ', #1
u'وتينى': u'وَتِينِى', #1
u'وثء': u'وَثْءٍ', #1
u'وثء': u'وَثْء', #3
u'وثأط': u'وثأط', #1
u'وثأط': u'وَثَأْطَ', #1
u'وثاط': u'وثاط', #1
u'وثأط': u'وَثَأْطٍ', #2
u'وثاعب': u'وَثَاعِبٌ', #2
u'وثال': u'وَثَّالِ', #1
u'وثانى': u'وَثَانِى', #1
u'وثاورته': u'وثاورته', #1
u'وثاورته': u'وَثَاوَرْتُهُ', #1
u'وثاورته،': u'وَثَاوَرْتُهُ،', #1
u'وثبار': u'وَثِبَارٌ', #1
u'وثبتنى': u'وَثَبَّتَنِى', #1
u'وثبتنيه': u'وَثَبَّتَنِيهِ', #1
u'وثبنة': u'وَثُبْنَةً', #1
u'وثبيت': u'وَثُبَيْتُ', #1
u'وثبير': u'وَثَبِيرُ', #1
u'وثبير': u'وثَبِيرٍ', #2
u'وثبير': u'وَثَبِيرٍ', #2
u'وثبير': u'وَثَبِيرٌ', #3
u'وثجيره': u'وَثَجِيرِهِ', #1
u'وثخانة': u'وَثَخَانَةً', #2
u'وثخانة': u'وَثَخَانَةٌ', #2
u'وثخانة': u'وَثَخَانَةٍ', #3
u'وثخانته': u'وَثَخَانَتُهُ', #1
u'وثخانته': u'وَثَخَانَتَهُ', #3
u'وثخنا': u'وَثِخَنًا', #3
u'وثخنه': u'وَثُخْنِهِ', #1
u'وثخنه': u'وَثِخَنِهِ', #2
u'وثخنها': u'وَثِخَنِهَا', #4
u'وثديى': u'وَثَدْيِى', #1
u'وثعالة': u'وَثُعَالَةَ', #1
u'وثفر': u'وَثُفْرٌ', #1
u'وثفر': u'وَثُفْرٍ', #1
u'وثفر': u'وَثُفْرِ', #1
u'وثفر': u'وَثَفَرٍ', #2
u'وثفر': u'وَثَفَرٌ', #7
u'وثفره': u'وَثُفْرِهِ', #1
u'وثقاقيل': u'وَثَقَاقِيلُ', #1
u'وثقفى': u'وَثَقَفِىٌّ', #1
u'وثقيب': u'وَثُقَيْبٌ', #1
u'وثلاثمائةوالوجه': u'وَثَلاثَمِائَةٍوَالْوَجْهُ', #1
u'وثلاثه': u'وثلاثه', #1
u'وثلاثون': u'وَثَلاَثُونً', #1
u'وثلثمائة': u'وَثَلَثَمِائَةِ', #2
u'وثلثمائة': u'وَثَلَثُمِائَةٍ', #23
u'وثلثمائة': u'وَثَلَثِمِائَةٍ', #31
u'وثلثمائة': u'وَثَلَثِمِائَةِ', #5
u'وثلثمائة': u'وَثَلَثُمِائَةِ', #8
u'وثلثمائة': u'وَثَلَثَمِائَةٍ', #9
u'وثلثى': u'وَثُلُثَىِ', #1
u'وثلطت': u'وَثَلَطَتْ', #2
u'وثلوم': u'وَثُلُومٍ', #1
u'وثمغ': u'وَثَمَغٌ', #1
u'وثمغ': u'وَثَمَغُ', #1
u'وثمغ': u'وَثَمْغٌ', #2
u'وثمودا': u'وثمودا', #1
u'وثمودا': u'وثموداً', #1
u'وثنتيان': u'وَثِنْتِيَانِ', #1
u'وثندوتي': u'وَثُنْدُوَتَيْ', #2
u'وثؤاج': u'وَثُؤَاجُ', #1
u'وثووبا': u'وَثُوُوبًا', #1
u'وثويبة': u'وَثُوَيْبَةُ', #3
u'وثوير': u'وَثُوَيْرُ', #1
u'وثي': u'وَثْيٍ', #3
u'وثى': u'وَثْىٍ', #4
u'وثئا': u'وَثْئًا', #3
u'وثئت': u'وَثِئَتْ', #2
u'وثيابة': u'وَثَيَابَةً', #1
u'وثيابة': u'وَثِيَابَةً', #1
u'وثيابته': u'وَثِيَابَتِهِ', #4
u'وثيابتها': u'وَثِيَابَتِهَا', #1
u'وثيت': u'وُثِيَتْ', #1
u'وثيتل': u'وثيتل', #1
u'وثيمة،': u'وَثِيمَةَ،', #3
u'وثيمة': u'وَثِيمَةَ', #6
u'وثيمة': u'وَثِيمَةُ', #7
u'وثيوبة': u'وَثُيُوبَةِ', #1
u'وثيوبة': u'وَثُيُوبَةً', #2
u'وثيوبة': u'وَثُيُوبَةٍ', #22
u'وثيوبة': u'وَثُيُوبَةٌ', #9
u'وثيوبتها': u'وَثُيُوبَتُهَا', #1
u'وثيوبتها': u'وَثُيُوبَتِهَا', #2
u'وجأ': u'وجَأ', #1
u'وجأ': u'وَجَأَ', #10
u'وجاء': u'وِجَاءً', #3
u'وجاءة': u'وِجَاءَةٌ', #1
u'وجاءنى': u'وَجَاءَنِى', #3
u'وجاءوا': u'وجاءوا', #2
u'وجاءوا': u'وَجَاءُوا', #75
u'وجاءوه': u'وَجَاءُوهُ', #2
u'وجابرصا': u'وَجَابَرْصَا', #1
u'وجابلق': u'وَجَابَلْقُ', #1
u'وجأة': u'وَجْأَةً', #3
u'وجاحا': u'وَجَاحًا', #1
u'وجاريتى': u'وَجَارِيَتِى', #1
u'وجاعلوا': u'وَجَاعِلُوا', #1
u'وجالينوس': u'وَجَالِينُوسُ', #1
u'وجامكية': u'وَجَامِكِيَّةٌ', #2
u'وجامكيته': u'وَجَامِكِيَّتِهِ', #2
u'وجأه': u'وَجَأَهُ', #8
u'وجأها': u'وَجَأَهَا', #2
u'وجاؤه': u'وِجَاؤُهُ', #1
u'وجاويشية': u'وَجَاوِيشِيَّةٌ', #1
u'وجاويشية': u'وَجَاوِيشِيَّةَ', #1
u'وجاويشية': u'وَجَاوِيشِيَّةٍ', #2
u'وجاي': u'وَجَاي', #1
u'وجباء': u'وَجِبَاءً', #1
u'وجبرانين': u'وَجُبْرَانَيْنِ', #6
u'وجبرائيل': u'وَجَبْرَائِيلَ', #2
u'وجبرائيل': u'وَجَبْرَائِيلُ', #4
u'وجبرون': u'وَجَبْرُونَ', #1
u'وجبريائى': u'وَجِبْرِيَائِى', #1
u'وجبنة': u'وَجُبْنَةٌ', #2
u'وجبوذلك': u'وَجَبَوَذَلِكَ', #1
u'وجبير': u'وجبير', #1
u'وجبير،': u'وَجُبَيْرٍ،', #1
u'وجبير': u'وَجُبَيْرِ', #13
u'وجبير': u'وَجُبَيْرُ', #25
u'وجبير': u'وجُبير', #3
u'وجبير': u'وجُبَيْر', #3
u'وجبير': u'وَجُبَيْرٍ', #3
u'وجبير': u'وَجُبَيْرَ', #3
u'وجبير': u'وَجُبَيْرٌ', #4
u'وجبير': u'وجُبَير', #5
u'وجبيرة': u'وَجَبِيرَةٍ', #3
u'وجبيلة': u'وَجُبَيْلَةُ', #1
u'وجثيثة': u'وَجَثِيثَةٌ', #1
u'وجحدب': u'وَجُحْدُبٍ', #1
u'وجحرة': u'وَجِحَرَةٌ', #1
u'وجحف': u'وَجَحَفَ', #1
u'وجحفة': u'وَجُحْفَةٌ', #1
u'وجحفة': u'وَجُحْفَةُ', #2
u'وجحفة': u'وَجُحْفَةَ', #3
u'وجحل': u'وَجَحَلٌ', #1
u'وجحل': u'وَجَحْلٍ', #1
u'وجحل': u'وَجَحْلٌ', #2
u'وجحلا': u'وَجَحْلًا', #1
u'وجحيش': u'وَجُحَيْشُ', #1
u'وجداية': u'وَجِدَايَةٍ', #1
u'وجداية': u'وَجِدَايَةَ', #1
u'وجداية': u'وَجَدَايَةٍ', #7
u'وجدنى': u'وَجَدَنِى', #1
u'وجدوالوجه': u'وَجَدَوَالْوَجْهُ', #1
u'وجدى': u'وَجَدِّى', #4
u'وجديس': u'وَجَدِيسٌ', #1
u'وجديس': u'وجديس', #2
u'وجديس': u'وَجَدِيسٍ', #2
u'وجذامة': u'وَجُذَامَةُ', #2
u'وجذاوند': u'وجذاوند', #1
u'وجذة': u'وَجُذَّةٌ', #1
u'وجذعة': u'وَجَذَعَةِ', #1
u'وجذعة': u'وَجَذَعَةَ', #2
u'وجذعة': u'وَجَذَعَةٌ', #28
u'وجذعة': u'وَجَذَعَةً', #6
u'وجذعة': u'وَجَذَعَةٍ', #9
u'وجذعتان': u'وَجَذَعَتَانِ', #7
u'وجذعتين': u'وَجَذَعَتَيْنِ', #1
u'وجرادين': u'وَجَرَادِينَ', #1
u'وجراكسة': u'وَجَرَاكِسَةٌ', #1
u'وجراكسة': u'وَجَرَاكِسَةٍ', #1
u'وجرائحي': u'وَجَرَائِحِيٌّ', #1
u'وجرائحي': u'وَجَرَائِحِيٍّ', #3
u'وجرائحيين': u'وجَرَائِحَيَّيْنِ', #1
u'وجراية': u'وَجِرَايَةٌ', #1
u'وجرجان': u'وَجُرْجَانَ', #2
u'وجرجانية': u'وَجُرْجَانِيَّةَ', #1
u'وجرجير': u'وجُرْجير', #1
u'وجرجير': u'وَجِرْجِيرٌ', #1
u'وجرض': u'وَجَرْضِ', #1
u'وجرعاء': u'وَجَرْعَاءَ', #1
u'وجرموق': u'وَجُرْمُوقٌ', #1
u'وجرموق': u'وَجُرْمُوقٍ', #1
u'وجرموقا': u'وَجُرْمُوقًا', #1
u'وجرهد': u'وَجَرْهَدٍ', #2
u'وجروة': u'وَجِرْوَةُ', #1
u'وجرول': u'وَجَرْوَلُ', #2
u'وجرول': u'وَجَرْوَلَ', #3
u'وجرون': u'وَجُرُونٌ', #1
u'وجريب': u'وَجَرِيبِ', #13
u'وجريبا': u'وَجَرِيبَا', #1
u'وجريباء': u'وَجَرِيبَاءَ', #1
u'وجريج،': u'وَجُرَيْجٌ،', #1
u'وجزء': u'وَجُزْءً', #1
u'وجزافان': u'وَجُزَافَانِ', #4
u'وجزآن': u'وَجُزْآنِ', #1
u'وجزأوا': u'وجزأوا', #1
u'وجزيز': u'وَجَزِيزٌ', #1
u'وجسة': u'وَجَسَّةٍ', #1
u'وجشاعة': u'وَجَشَاعَةٌ', #1
u'وجشرته': u'وَجَشَرْتُهُ', #1
u'وجشيم': u'وَجُشَيْمٌ', #1
u'وجض': u'وَجَضّ', #1
u'وجعار': u'وَجَعَار', #1
u'وجعال': u'وَجُعَالُ', #1
u'وجعالة': u'وَجَعَالَةُ', #1
u'وجعالة': u'وَجَعَالَةً', #10
u'وجعالة': u'وَجَعَالَةٍ', #28
u'وجعالة': u'وَجِعَالَةً', #3
u'وجعالة': u'وَجِعَالَةٌ', #3
u'وجعالة': u'وَجِعَالَةٍ', #6
u'وجعالة': u'وَجَعَالَةٌ', #9
u'وجعثمة': u'وَجُعْثُمَةُ', #2
u'وجعشم': u'وَجُعْشُمٍ', #1
u'وجعف': u'وجعف', #1
u'وجعفة': u'وَجِعْفَةٍ', #1
u'وجعفد': u'وَجَعْفَدَ', #1
u'وجعفرا': u'وَجَعْفَرًا', #13
u'وجعفي': u'وَجُعْفِيّ', #2
u'وجعفي': u'وَجُعْفِيٌّ', #3
u'وجعفيان': u'وَجُعْفَيَانِ', #1
u'وجعيلة': u'وَجَعِيلَةُ', #1
u'وجعيلة': u'وَجَعِيلَةً', #2
u'وجفانة': u'وَجِفَانَةٍ', #3
u'وجفير': u'وَجَفِيرُ', #1
u'وجفير': u'وَجَفِيرِ', #3
u'وجفيرها': u'وَجَفِيرِهَا', #2
u'وجفينة': u'وجفينة', #1
u'وجفينة': u'وجُفَيْنَةَ', #1
u'وجفينة،': u'وَجُفَيْنَةَ،', #1
u'وجفينة،': u'وجُفَيْنة،', #2
u'وجفينة،': u'وجُفَيْنَة،', #2
u'وجفينة': u'وَجُفَيْنَةَ', #3
u'وجلiacratic': u'وجلiacratic', #80
u'وجلiacraticValue': u'وجلiacraticValue', #20
u'وجلisplay': u'وجلisplay', #9
u'وجلابي': u'وَجَلَّابِي', #2
u'وجلاجل': u'وَجَلَاجِلَ', #1
u'وجلاجل': u'وَجَلَاجِلُ', #1
u'وجلالى': u'وَجَلاَلِى', #1
u'وجلاياها': u'وَجَلَايَاهَا', #1
u'وجلح': u'وَجَلْح', #1
u'وجلدات': u'وَجَلَدَاتٍ', #1
u'وجلدات': u'وَجَلَدَاتُ', #11
u'وجلدات': u'وَجَلَدَاتِ', #2
u'وجلدات': u'وَجَلَدَاتٌ', #4
u'وجلرضي': u'وجلرضي', #18
u'وجلعليه': u'وجلعليه', #10
u'وجلق': u'وَجِلِّقٌ', #1
u'وجلق': u'وَجِلّقٍ', #2
u'وجلهمة': u'وَجَلْهَمَةَ', #1
u'وجلهمة': u'وَجُلْهُمَةُ', #2
u'وجلوروي': u'وَجَلَّوَرُوِيَ', #2
u'وجلولاء': u'وجَلُولاءَ', #1
u'وجلولاء': u'وَجَلُولَاءُ', #3
u'وجليحة': u'وجُلَيْحَة', #1
u'وجماء': u'وَجَمَّاءُ', #2
u'وجمادتين': u'وَجَمَادَتَيْنِ', #1
u'وجمانة': u'وَجُمَانَةً', #1
u'وجمائله': u'وَجَمَائِله', #1
u'وجمشيد': u'وَجَمْشِيدُ', #1
u'وجناء': u'وَجْناءُ', #1
u'وجناء': u'وَجْنَاءُ', #8
u'وجنادة': u'وجُنَادة', #1
u'وجنادة': u'وَجُنَادَةَ', #1
u'وجنادة': u'وَجُنَادَةُ', #7
u'وجنبون': u'وَجُنُبُونَ', #3
u'وجنديسابور،': u'وَجُنْدِيسَابُورَ،', #1
u'وجنز': u'وَجَنَزَ', #1
u'وجنزرلي': u'وجنزرلي', #1
u'وجنوءا': u'وَجُنُوءًا', #1
u'وجنيبة': u'وَجَنِيبَةُ', #1
u'وجنيبة': u'وَجَنِيبَةٍ', #2
u'وجنيبة': u'وَجَنِيبَةٌ', #4
u'وجنيبته': u'وَجَنِيبَتُهُ', #1
u'وجنيبه': u'وَجَنِيبِهِ', #1
u'وجنيبه': u'وَجَنِيبُهُ', #2
u'وجنيد': u'وَجُنَيْدٌ', #1
u'وجه': u'وَجْهً', #1
u'وجهادتها': u'وَجِهَادَتِهَا', #1
u'وجهجا': u'وَجَهْجَا', #1
u'وجهضم': u'وَجَهْضَمُ', #1
u'وجهلى': u'وَجَهْلِى', #1
u'وجهنى': u'وَجَّهَنِىَ', #1
u'وجههاإلا': u'وَجْهِهَاإِلَّا', #1
u'وجههه،': u'وجههه،', #1
u'وجهودان': u'وجهودان', #1
u'وجهونى': u'وَجِّهُونِى', #1
u'وجهيز': u'وَجَهِيزٌ', #2
u'وجهيزة': u'وَجَهِيزَةُ', #1
u'وجهيقال': u'وَجْهِيقَالَ', #1
u'وجهينة': u'وجُهَيْنة', #1
u'وجهينة': u'وَجُهَينة', #1
u'وجهينة': u'وُجُهَيْنَةَ', #1
u'وجهينة،': u'وَجُهَيْنَةَ،', #1
u'وجهينة،': u'وَجُهَيْنَةُ،', #1
u'وجهينة': u'وَجُهَيْنَةَ', #12
u'وجهينة': u'وَجُهَيْنَةُ', #23
u'وجواثا': u'وَجُوَاثَا', #1
u'وجواثى': u'وَجُوَاثَى', #1
u'وجوارش': u'وجوارش', #4
u'وجوارى': u'وَجَوَارِى', #1
u'وجوازل': u'وَجَوَازِلَ', #2
u'وجوالقات': u'وَجُوَالِقَاتٌ', #1
u'وجوالقات': u'وُجُوَالِقَاتٌ', #1
u'وجوانيت': u'وَجَوَانِيتَ', #1
u'وجؤائي': u'وَجُؤَائِي', #1
u'وجوب': u'وُجُوبً', #1
u'وجوذاب': u'وَجُوذَابٌ', #1
u'وجؤذر': u'وَجُؤْذَرٍ', #1
u'وجوشن': u'وَجَوْشَنٍ', #2
u'وجوشيده': u'وجوشيده', #1
u'وجوههاالوجه': u'وُجُوهِهَاالْوَجْهُ', #1
u'وجويبر': u'وَجُوَيْبِرٌ', #1
u'وجويبر': u'وَجُوَيْبِرٍ', #2
u'وجويبر،': u'وَجُوَيْبِرٍ،', #2
u'وجويرة': u'وَجُوَيْرَةَ', #2
u'وجويرية': u'وجويرية', #1
u'وجويرية': u'وجُوَيرية', #1
u'وجويرية': u'وَجُوَيْرِيَّة', #1
u'وجويرية،': u'وَجُوَيْرِيَةُ،', #1
u'وجويرية': u'وَجُوَيْرِيَةَ', #11
u'وجويرية': u'وَجُوَيْرِيَةُ', #19
u'وجى': u'وَجًى', #1
u'وجى': u'وَجَى', #2
u'وجىء': u'وَجِىءَ', #9
u'وجئا': u'وَجْئًا', #1
u'وجيادات': u'وَجِيَادَاتٌ', #1
u'وجيادة': u'وَجِيَادَةِ', #1
u'وجيأل': u'وَجَيْأَل', #1
u'وجيايد': u'وَجَيَايِدُ', #1
u'وجيحون': u'وَجَيْحُونُ', #11
u'وجيحون': u'وَجِيحُونَ', #2
u'وجيحون': u'وَجَيْحُونَ', #31
u'وجيرانى': u'وَجِيرَانِى', #5
u'وجيعر': u'وجيعر', #1
u'وجيلانا': u'وَجِيلَانًا', #1
u'وحا': u'وَحَا', #2
u'وحآجه': u'وَحَآجَّهُ', #1
u'وحارجها': u'وَحَارِجَهَا', #1
u'وحارصة': u'وَحَارِصَةٍ', #7
u'وحاصت': u'وَحَاصَتْ', #1
u'وحاصت': u'وَحَاصَّتْ', #9
u'وحاصتهما': u'وَحَاصَّتْهُمَا', #1
u'وحاصص': u'وَحَاصَصَ', #19
u'وحاصصهم': u'وَحَاصَصَهُمْ', #1
u'وحاصه': u'وَحَاصَّهُ', #7
u'وحاظر': u'وَحَاظِرٍ', #3
u'وحاكورة': u'وَحَاكُورَةٌ', #1
u'وحامدية': u'وَحَامِدِيَّةٌ', #1
u'وحامقته': u'وَحَامَقْتُهُ', #1
u'وحاوح': u'وَحَاوِحْ', #2
u'وحائش': u'وَحَائِشِ', #1
u'وحائص': u'وَحَائِصٍ', #1
u'وحايز': u'وَحَايزٌ', #1
u'وحايز': u'وَحَايِزٌ', #1
u'وحبء': u'وَحَبَءٌ', #1
u'وحبأة': u'وَحَبَأَةٌ', #1
u'وحببة': u'وَحِبَبَةٌ', #3
u'وحبسنى': u'وَحَبَسَنِى', #1
u'وحبشى': u'وَحَبَشِىٌّ', #1
u'وحبونة': u'وَحَبَوْنَةَ', #1
u'وحبونن': u'وَحَبَوْنَنُ', #1
u'وحبيش': u'وَحُبَيْشٌ', #3
u'وحثوات': u'وَحَثْوَاتٍ', #1
u'وحثوات': u'وَحَثَوَاتٍ', #3
u'وحثى': u'وَحَثَى', #6
u'وحثيات': u'وَحَثَيَاتٍ', #5
u'وحجاجة': u'وَحَجَّاجَةٍ', #1
u'وحجاح': u'وَحَجَّاحٌ', #2
u'وحجدوا': u'وَحَجَدُوا', #1
u'وحجرى': u'وَحَجْرِى', #1
u'وحجفة': u'وَحَجَفَةٍ', #1
u'وحجونا': u'وَحَجُونًا', #1
u'وحجير': u'وَحُجَيْرٌ', #1
u'وحجير': u'وَحُجَيْرٍ', #1
u'وحجير': u'وَحُجَيْرُ', #1
u'وحداقة': u'وَحَدَّاقَةٌ', #1
u'وحدآن': u'وَحِدْآنِ', #1
u'وحدثانيه': u'وَحَدَّثَانِيهِ', #1
u'وحدثتنى': u'وَحَدَّثَتْنِى', #4
u'وحدثنى': u'وحدثنى', #1
u'وحدثنى': u'وَحَدَّثَنِى', #1566
u'وحدثنيه': u'وحدثنيه', #2
u'وحدثنيه': u'وَحَدَّثَنِيهِ', #267
u'وحدثنيه': u'وَحَدّثَنِيهِ', #9
u'وحدهSاعتزال': u'وَحْدَهُSاعْتِزَالُ', #1
u'وحدودوى': u'وحدودوى', #1
u'وحديج،': u'وَحُدَيْجٌ،', #1
u'وحذام': u'وَحَذَامَ', #1
u'وحذام': u'وَحَذَامُ', #1
u'وحذام': u'وَحَذَامِ', #1
u'وحذام': u'وَحِذَامُ', #1
u'وحذم': u'وَحَذْمِ', #1
u'وحر': u'وَحُرًّ', #2
u'وحراء': u'وَحِرَاءَ', #1
u'وحراء': u'وَحِرَاءُ', #5
u'وحراض': u'وَحُرَاضٌ', #1
u'وحرائبكم': u'وَحَرَائِبُكُمْ', #1
u'وحرائها': u'وَحِرَائِهَا', #1
u'وحرزة': u'وَحَرَزَةُ', #1
u'وحرقدته': u'وَحَرْقَدَتِهِ', #1
u'وحرملة،': u'وَحَرْمَلَةَ،', #1
u'وحرملة': u'وَحَرْمَلَةُ', #106
u'وحرملة': u'وَحَرْمَلَةَ', #27
u'وحروثهم': u'وَحُرُوثِهِمْ', #4
u'وحروراء': u'وَحَرُورَاءُ', #1
u'وحروشة': u'وَحُرُوشَةٌ', #1
u'وحريث': u'وحريث', #1
u'وحريث': u'وَحُرَيْثُ', #1
u'وحريسة': u'وَحَرِيسَةٌ', #1
u'وحريسة': u'وَحَرِيسَةُ', #1
u'وحريش': u'وحريش', #1
u'وحريمة': u'وَحَرِيمَةٍ', #1
u'وحريملا': u'وحريملا', #1
u'وحزامة': u'وَحَزَامَةٍ', #1
u'وحزتيه': u'وَحُزْتِيهِ', #3
u'وحزرات': u'وَحَزَرَاتِ', #1
u'وحزراتها': u'وَحَزَرَاتِهَا', #2
u'وحزقيل': u'وَحِزْقِيلُ', #1
u'وحزقيل': u'وَحِزْقِيلَ', #2
u'وحزماء': u'وَحُزَمَاءُ', #1
u'وحزون': u'وَحُزُونُ', #1
u'وحزونة': u'وَحُزُونَةً', #8
u'وحزونته': u'وَحُزُونَتِهِ', #1
u'وحزيم': u'وَحَزِيمٌ', #2
u'وحسبتنى': u'وَحَسِبْتُنِى', #1
u'وحسل': u'وَحِسْلٌ', #1
u'وحسمى': u'وَحِسْمَى', #1
u'وحسيل': u'وَحُسَيْلٌ', #1
u'وحسيل': u'وَحُسَيْلٍ', #1
u'وحسيل': u'وَحُسَيْلُ', #3
u'وحسينا': u'وَحُسَيْنًا', #20
u'وحسينا،': u'وَحُسَيْنًا،', #3
u'وحشاء': u'وَحْشَاءَ', #1
u'وحشوش': u'وَحُشُوشُ', #1
u'وحشى': u'وَحَشًى', #1
u'وحصحط': u'وَحَصْحَطُ', #1
u'وحضوضى': u'وَحَضَوْضَى', #1
u'وحطة': u'وَحِطَّةٌ', #1
u'وحطة': u'وَحِطّةٌ', #2
u'وحطيمه': u'وَحَطِيمِهِ', #1
u'وحفد': u'وَحَفَدَ', #1
u'وحفدانا': u'وَحَفَدَانًا', #1
u'وحفزنى': u'وَحَفَزَنِى', #1
u'وحفش': u'وَحِفْشِ', #1
u'وحفوة': u'وَحُفْوَةً', #1
u'وحفودا': u'وَحُفُودًا', #1
u'وحفيدته': u'وحفيدته', #1
u'وحفيلها': u'وَحَفِيلُهَا', #4
u'وحقاف': u'وَحِقَافِ', #3
u'وحقبيته': u'وحقبيته', #1
u'وحقهاى': u'وحقهاى', #2
u'وحقيته': u'وَحَقِّيَّتِهِ', #2
u'وحكواتي': u'وَحَكَوَاتِيٌّ', #2
u'وحلام': u'وَحُلّامُ', #1
u'وحلام': u'وَحُلَّامٌ', #1
u'وحلقنى': u'وَحَلَقَنِى', #1
u'وحلوس': u'وَحُلُوسٌ', #1
u'وحلوس': u'وَحُلُوسٍ', #1
u'وحلولو': u'وَحَلُولُو', #1
u'وحلولو': u'وَحُلُولُو', #7
u'وحمء': u'وَحَمْءٌ', #1
u'وحماقى': u'وَحَمَاقَى', #2
u'وحمدله': u'وَحَمْدَلَهْ', #1
u'وحمدون': u'وَحَمْدُونَ', #1
u'وحمدون': u'وَحَمْدُونِ', #1
u'وحمدون': u'وَحَمْدُونُ', #4
u'وحمدين': u'وَحَمْدِينُ', #1
u'وحمش': u'وَحَمْشُ', #1
u'وحمشت': u'وَحَمَشْت', #2
u'وحمنانة': u'وَحَمْنَانَةٌ', #1
u'وحمنانة': u'وَحَمْنَانَةٍ', #1
u'وحمنة،': u'وحمنة،', #1
u'وحمنة': u'وحَمْنةُ', #1
u'وحمنة': u'وَحِمْنَةُ', #1
u'وحمنة': u'وَحَمْنَةَ', #13
u'وحمنة': u'وَحَمْنَةُ', #22
u'وحميديا': u'وَحُمَيْدِيًّا', #1
u'وحميرية': u'وَحِمْيَرِيَّةً', #2
u'وحناتم': u'وَحَنَاتِمَ', #1
u'وحنذها': u'وَحَنَذَهَا', #1
u'وحنيذة': u'وَحَنِيذَةً', #1
u'وحواب': u'وَحَوَابٍ', #1
u'وحوابي': u'وَحَوَابِيٍّ', #1
u'وحوارى': u'وَحَوَارِىَّ', #4
u'وحواريى': u'وَحَوَارِيِّى', #1
u'وحوتكة': u'وَحَوْتَكَةُ', #2
u'وحوتكة': u'وَحَوْتَكَةَ', #4
u'وحوثرة': u'وَحَوْثَرَةُ', #1
u'وحوثرة': u'وَحَوْثَرَةَ', #5
u'وحوشب': u'وحَوْشَب', #1
u'وحوشبا': u'وَحَوْشَبًا', #2
u'وحوص': u'وَحَوَصٍ', #2
u'وحويرث': u'وَحُوَيْرِثٌ', #1
u'وحويصة': u'وَحُوَيّصَةَ', #1
u'وحويصة': u'وَحُوَيّصَةُ', #1
u'وحويصة': u'وَحُوَيْصَةُ', #1
u'وحويصة،': u'وَحُوَيِّصَةُ،', #1
u'وحويصة': u'وَحُوَيِّصَةُ', #18
u'وحويصة': u'وَحُوَيّصَة', #2
u'وحويصة': u'وَحُوَيِّصَة', #2
u'وحويصة': u'وَحُوَيِّصَةَ', #3
u'وحويطب': u'وحُوَيطب', #1
u'وحويطب': u'وَحُوَيْطَبُ', #1
u'وحويطب': u'وَحُوَيْطِب', #1
u'وحويطب': u'وَحُوَيْطِبٌ', #1
u'وحويطب': u'وُحَوَيْطِبَ', #1
u'وحويطب': u'وَحُوَيْطِبُ', #11
u'وحويطب': u'وَحُوَيْطِبِ', #2
u'وحويطب': u'وَحُوَيْطِبَ', #6
u'وحويطبا،': u'وحُوَيْطبًا،', #1
u'وحيادة': u'وَحَيَادَةُ', #1
u'وحياطة': u'وَحِيَاطَةٌ', #1
u'وحياطة': u'وَحِيَاطَةً', #4
u'وحياطته': u'وَحِيَاطَتُهُ', #1
u'وحياطته': u'وَحِيَاطَتِهِ', #1
u'وحياطتها': u'وَحِيَاطَتِهَا', #1
u'وحياطتها': u'وَحِيَاطَتُهَا', #4
u'وحياطتهم': u'وحياطتهم', #1
u'وحياطتهم': u'وَحِيَاطَتِهِمْ', #1
u'وحيالى': u'وَحَيَالَى', #1
u'وحيثل': u'وحيثل', #1
u'وحيد': u'وَحِيدً', #1
u'وحيدرة': u'وَحَيْدَرَةُ', #3
u'وحيس': u'وَحِيسَ', #1
u'وحيس': u'وَحَيْسٍ', #1
u'وحيس،': u'وَحَيْسٍ،', #1
u'وحيسة': u'وَحَيْسَةٍ', #1
u'وحيطا': u'وَحُيّطًا', #1
u'وحيوة': u'وحَيْوَة', #1
u'وحيوة': u'وَحَيْوَةُ', #11
u'وحيوة': u'وَحَيْوَةَ', #6
u'وخابوراء': u'وَخَابُورَاءُ', #1
u'وخاتون': u'وَخَاتُونُ', #4
u'وخاربين': u'وَخَارِبَيْنِ', #1
u'وخارصة': u'وَخَارِصَةٍ', #2
u'وخارف': u'وَخَارِفُ', #1
u'وخافإن': u'وَخَافَإِنْ', #1
u'وخاقان': u'وَخَاقَانَ', #2
u'وخالتى': u'وَخَالَتِى', #5
u'وخالى': u'وَخَالِى', #1
u'وخانكاة': u'وَخَانْكَاةٍ', #2
u'وخانكاه': u'وَخَانِكَاهٍ', #1
u'وخاوفني': u'وَخَاوَفَنِي', #1
u'وخباثة': u'وَخَبَاثَةٌ', #1
u'وخباثتها': u'وَخَبَاثَتهَا', #1
u'وخباثتها': u'وَخَبَاثَتُهَا', #1
u'وخثاء': u'وَخُثَاءُ', #1
u'وخثعم': u'وَخَثْعَمُ', #1
u'وخثعم': u'وَخَثْعَمَ', #14
u'وخثعم': u'وَخَثْعَمٌ', #3
u'وخثعم': u'وَخَثْعَمٍ', #5
u'وخثى': u'وَخَثَى', #1
u'وخثيل': u'وَخُثَيْلٌ', #1
u'وخثيم': u'وَخُثَيْمُ', #1
u'وخدارة': u'وَخُدَارَةُ', #2
u'وخداش': u'وَخِدَاشٌ', #1
u'وخدلج': u'وَخَدَلَّجُ', #1
u'وخديج': u'وخديج', #1
u'وخديج': u'وَخُدَيْجُ', #1
u'وخديج': u'وَخَدِيجُ', #2
u'وخديخة،': u'وَخَدِيخَةُ،', #1
u'وخدينه': u'وَخَدِينُهُ', #1
u'وخذام': u'وَخِذَامُ', #1
u'وخذام،': u'وَخِذَامٌ،', #1
u'وخذف': u'وَخَذَفَ', #1
u'وخذف': u'وَخَذْفٍ', #1
u'وخذفها': u'وَخَذْفُهَا', #1
u'وخذى': u'وَخُذِى', #1
u'وخرء': u'وَخُرْءَ', #1
u'وخرء': u'وَخُرْءُ', #13
u'وخرء': u'وَخُرْءِ', #14
u'وخرء': u'وَخَرْءُ', #8
u'وخرء': u'وَخَرْءِ', #8
u'وخرءا': u'وَخُرْءًا', #1
u'وخراجات': u'وَخُرَّاجَاتِ', #1
u'وخراش': u'وَخِرَاشٌ', #1
u'وخراش': u'وَخِرَاشُ', #1
u'وخراما': u'وخراما', #1
u'وخرأه': u'وَخَرْأَهُ', #1
u'وخرأه': u'وَخُرْأَهُ', #1
u'وخرأها': u'وَخُرْأَهَا', #1
u'وخرأهما': u'وَخُرْأَهُمَا', #1
u'وخربزه': u'وخربزه', #1
u'وخرثي': u'وَخُرْثِيٌّ', #2
u'وخرزاذ': u'وَخُرَّزَاذُ', #1
u'وخرشة': u'وخرشة', #1
u'وخرشة': u'وَخَرَشَةَ', #1
u'وخرشة': u'وَخَرَشَةُ', #2
u'وخركاة': u'وَخَرْكَاةٌ', #1
u'وخركاه': u'وخَرْكَاهُ', #1
u'وخرميان': u'وَخَرْمَيَانُ', #1
u'وخروبة': u'وَخَرُّوبَةً', #2
u'وخرؤه': u'وَخُرْؤُهُ', #6
u'وخرؤها': u'وَخَرْؤُهَا', #1
u'وخرؤها': u'وَخُرْؤُهَا', #7
u'وخرؤهما': u'وَخَرْؤُهُمَا', #1
u'وخرؤهما': u'وَخُرْؤُهُمَا', #3
u'وخرئه': u'وَخُرْئِهِ', #2
u'وخرئهما': u'وَخَرْئِهِمَا', #1
u'وخريدم': u'وخريدم', #1
u'وخريم': u'وخُرَيم', #1
u'وخريم': u'وَخُرَيْمٌ', #1
u'وخزام': u'وَخِزَامُ', #1
u'وخزاما': u'وَخِزَامًا', #1
u'وخزمة': u'وخَزَمة', #1
u'وخزمها': u'وَخَزْمَهَا', #2
u'وخزيمة': u'وخُزَيْمة', #1
u'وخزيمة': u'وَخُزَيْمَة', #1
u'وخزيمة': u'وَخُزَيْمَةُ', #16
u'وخزيمة': u'وَخُزَيْمَةَ', #20
u'وخسق': u'وَخَسْقٍ', #1
u'وخشاف': u'وَخُشَافٌ', #2
u'وخشافا': u'وَخَشَّافًا', #1
u'وخشافا': u'وَخُشَافًا', #1
u'وخشة': u'وَخْشَةً', #1
u'وخشة': u'وَخْشَةٍ', #1
u'وخشكار': u'وخشكار', #1
u'وخشكنان': u'وخشكنان', #1
u'وخشكنان': u'وَخُشْكَنَانَ', #1
u'وخشكنان': u'وَخُشْكَنَانٍ', #3
u'وخشكنانك': u'وخشكنانك', #1
u'وخشكنانه': u'وَخَشْكِنَانِهِ', #1
u'وخصمى': u'وَخَصْمِى', #1
u'وخضب': u'وَخَضْبً', #1
u'وخضخاض': u'وَخِضْخَاضٍ', #1
u'وخضخاض': u'وَخَضْخَاضٍ', #5
u'وخضخضته': u'وَخَضْخَضَتِهِ', #2
u'وخضخضته': u'وَخَضْخَضَتُهُ', #7
u'وخضد': u'وَخَضّدَ', #1
u'وخضرمنا': u'وَخَضْرَمْنَا', #5
u'وخضمات': u'وَخَضِمَاتٌ', #1
u'وخطاته': u'وَخَطَاتُهُ', #1
u'وخطاى': u'وَخَطَاىَ', #1
u'وخطاى': u'وَخُطَاىَ', #1
u'وخطبنى': u'وَخَطَبَنِى', #1
u'وخطمة،': u'وَخَطْمَةَ،', #1
u'وخطمة': u'وخَطْمَةُ', #2
u'وخطمة': u'وَخَطْمَةُ', #2
u'وخطمة': u'وَخَطْمَةَ', #5
u'وخطئى': u'وَخَطَئِى', #1
u'وخفاياتها': u'وَخَفَايَاتِهَا', #1
u'وخلفى': u'وَخَلْفِى', #4
u'وخلقى': u'وَخُلُقِى', #2
u'وخلوعا': u'وَخُلُوعًا', #1
u'وخلوقة': u'وَخُلُوقَةُ', #1
u'وخلول': u'وَخُلُولٍ', #4
u'وخلولها': u'وَخُلُولُهَا', #5
u'وخليد': u'وخُلَيْد', #1
u'وخليد': u'وَخُلَيْدُ', #1
u'وخليد': u'وَخُلَيْدٌ', #2
u'وخليد،': u'وَخُلَيْدٌ،', #2
u'وخليدة': u'وخليدة', #1
u'وخليدة': u'وَخُلَيْدَةُ', #3
u'وخليص': u'وَخُلَيْصٍ', #2
u'وخليصا': u'وَخُلَيْصًا', #1
u'وخمسمئ': u'وَخَمْسِمِئٍ', #1
u'وخمطا': u'وَخَمْطًا', #1
u'وخمهافر': u'وخمهافر', #1
u'وخميص': u'وَخَمِيصُ', #1
u'وخميصة': u'وخميصة', #1
u'وخميصة': u'وَخَمِيصَةٌ', #1
u'وخميصة،': u'وَخَمِيصَةً،', #1
u'وخناث': u'وَخَنَاثٌ', #1
u'وخناث': u'وَخَنَاثٍ', #1
u'وخنبقاته': u'وخنبقاته', #1
u'وخنة': u'وَخَنّةُ', #1
u'وخندف': u'وَخِنْدَفٌ', #1
u'وخندف': u'وَخِنْدَفُ', #1
u'وخندف': u'وَخِنْدِفَ', #1
u'وخندف': u'وَخِنْدِفُ', #6
u'وخنيس': u'وخُنَيْس', #1
u'وخنيس': u'وَخُنَيْسٍ', #1
u'وخنيس': u'وَخُنَيْسَ', #1
u'وخنيس': u'وَخُنَيْسُ', #6
u'وخوارم': u'وَخَوَارِمُ', #1
u'وخوارم': u'وَخَوَارِمِ', #4
u'وخوازق': u'وَخَوَازِقُ', #1
u'وخواسته': u'وخواسته', #1
u'وخوانقها': u'وَخَوَانِقِهَا', #1
u'وخواهر': u'وخواهر', #6
u'وخواهر': u'وَخُوَاهَرْ', #9
u'وخواهي': u'وخواهي', #1
u'وخود': u'وَخُودٌ', #1
u'وخودا': u'وَخَوّدَا', #2
u'وخوردن': u'وخوردن', #1
u'وخوردند': u'وخوردند', #1
u'وخورستان': u'وَخُورِسْتَانَ', #1
u'وخورسية': u'وَخُورْسِيَّةٌ', #1
u'وخورمشهر': u'وخورمشهر', #1
u'وخوزستان': u'وَخُوزِسْتَانُ', #1
u'وخوندة': u'وخُونْدَةَ', #1
u'وخويز': u'وَخُوَيْزِ', #1
u'وخويش': u'وخويش', #1
u'وخويصة': u'وَخُوَيِّصَةَ', #1
u'وخويصة': u'وَخُوَيْصَة', #1
u'وخويصة': u'وَخُوَيْصَّةَ', #3
u'وخئولته': u'وَخُئُولَتُهُ', #1
u'وخياتيم': u'وَخَيَاتِيمُ', #1
u'وخيبر': u'وخيبر', #1
u'وخيبر،': u'وخيبر،', #1
u'وخيبر،': u'وخَيْبَرَ،', #1
u'وخيبر،': u'وَخَيبرَ،', #1
u'وخيبر': u'وَخَيْبَرُ', #15
u'وخيبر': u'وَخَيْبَر', #2
u'وخيبر،': u'وَخَيْبَرَ،', #2
u'وخيبر': u'وَخَيْبَرَ', #65
u'وخيبرا': u'وَخَيْبَرَا', #1
u'وخيتام': u'وَخَيْتَامٌ', #4
u'وخيتوم': u'وَخَيْتُومٌ', #1
u'وخيثمة،': u'وَخَيْثَمَةَ،', #1
u'وخيثمة': u'وخيثمة', #2
u'وخيثمة': u'وَخَيْثَمَةُ', #2
u'وخيثمة': u'وَخَيْثَمَةَ', #3
u'وخيسه': u'وَخَيَّسَهُ', #1
u'وخيلة': u'وَخِيلَةٌ', #1
u'وخيوان': u'وَخَيْوَانَ', #1
u'وخيوان': u'وَخَيْوَانُ', #5
u'وداتورة': u'وَدَاتُورَةٍ', #1
u'وداذويه': u'وَدَاذَوَيْهَ', #1
u'وداذويه،': u'وَدَاذُوَيْهِ،', #1
u'وداذويه': u'وَدَاذَوَيْهِ', #2
u'وداسم': u'وداسم', #1
u'وداسم،': u'وداسم،', #1
u'وداسم': u'وَدَاسِمٌ', #2
u'وداعةأنه': u'وَدَاعَةَأَنَّهُ', #1
u'وداعسا': u'وَدَاعِسًا', #1
u'ودافة': u'وَدَافَّةُ', #1
u'وداقنتي': u'وَدَاقِنَتِي', #1
u'وداقورة': u'وَدَاقُورَةٍ', #2
u'ودانق': u'وَدَانِقُ', #2
u'ودانق': u'وَدَانَقُ', #3
u'ودانق': u'وَدَانَقٍ', #4
u'ودانق': u'وَدَانَقٌ', #5
u'ودانق': u'وَدَانِقٌ', #5
u'ودانق': u'وَدَانِقٍ', #8
u'ودانقا': u'وَدَانَقًا', #2
u'ودانقا': u'وَدَانِقًا', #3
u'ودانقان': u'وَدَانِقَانِ', #3
u'ودباء،': u'وَدُبَّاءٍ،', #1
u'ودباء': u'وَدُبَّاءَ', #2
u'ودباء': u'وَدُبَّاءٍ', #4
u'ودبيره': u'وَدَبِيرَهُ', #1
u'ودبيل': u'وَدَبِيلٌ', #1
u'ودثاب،': u'ودَثَّابٌ،', #1
u'ودجائج': u'وَدَجَائِجُ', #1
u'ودجيل': u'وَدُجَيْلٌ', #1
u'ودحيبة': u'وَدُحَيْبَةُ', #4
u'ودحية': u'وَدِحْيَةُ', #1
u'ودحية': u'وَدِحْيَةَ', #4
u'ودحيم،': u'وَدُحَيْمٌ،', #1
u'ودحيم': u'وَدُحَيْمٌ', #4
u'ودخاريص': u'وَدَخَارِيصَ', #5
u'ودختروى': u'ودختروى', #1
u'ودخريص': u'وَدِخْرِيصٍ', #2
u'ودخين': u'وَدُخَيْنُ', #1
u'ودرآب': u'ودرآب', #1
u'ودراريب': u'وَدَرَارِيبَ', #1
u'ودراريب': u'وَدَرَارِيبِ', #2
u'ودراهمقوله': u'وَدَرَاهِمَقَوْلُهُ', #1
u'ودرايب': u'وَدَرَايِبِ', #1
u'ودربست': u'ودربست', #1
u'ودرخانه': u'ودرخانه', #1
u'ودردست': u'ودردست', #5
u'ودرعى': u'وَدِرْعِى', #1
u'ودركردن': u'ودركردن', #1
u'ودرود': u'ودرود', #1
u'ودروددان': u'ودروددان', #1
u'ودروغ': u'ودروغ', #1
u'ودريج': u'وَدِرِّيجٍ', #1
u'ودريد': u'وَدُرَيْدُ', #1
u'ودريسا': u'وَدَرِيسًا', #2
u'ودستار': u'ودستار', #1
u'ودستار': u'وَدِسْتَارِ', #1
u'ودسعة': u'وَدَسْعَةٍ', #1
u'ودسكره': u'وَدَسْكَرَهْ', #1
u'ودسومة': u'وَدُسُومَةٍ', #1
u'ودسومة': u'وَدُسُومَةٌ', #2
u'ودسومها': u'وَدُسُومِهَا', #1
u'ودشتا': u'وَدَشْتًا', #1
u'ودشمن': u'ودشمن', #1
u'ودعانى': u'وَدَعَانِى', #2
u'ودعجاء': u'وَدَعْجَاءَ', #1
u'ودعدى': u'وَدُعْدَى', #1
u'ودعلج': u'وَدَعْلَجُ', #1
u'ودعلج': u'وَدَعْلَجِ', #1
u'ودعلج،': u'وَدَعْلَجٍ،', #1
u'ودعنى': u'ودعنى', #1
u'ودعنى': u'وَدَّعَنِى', #1
u'ودعنى': u'وَدَعْنِى', #2
u'ودعونى': u'وَدَعُونِى', #1
u'ودعى': u'ودعى', #1
u'ودعى': u'وَدَعِى', #4
u'ودعى': u'وَدُعِىَ', #4
u'ودغفل': u'وَدَغْفَلُ', #1
u'ودغينة': u'وَدُغَيْنَةٍ', #1
u'ودغينة': u'وَدُغَيْنَةُ', #1
u'ودفار': u'وَدَفَارِ', #2
u'ودفاق': u'وَدُفَاقٍ', #1
u'ودفره': u'وَدَفَرَهُ', #1
u'ودفره': u'وَدَفْرَهُ', #2
u'ودقاس': u'وَدُقَاسٍ', #1
u'ودقل': u'وَدَقَلٍ', #2
u'ودقلها': u'وَدَقْلِهَا', #1
u'ودقلها': u'وَدَقَلِهَا', #2
u'ودكمة': u'وَدَكْمَةُ', #1
u'ودلقاء': u'وَدَلْقَاءُ', #1
u'ودلم': u'وَدَلَمٍ', #1
u'ودلهى': u'وَدَلْهَى', #1
u'ودمامين': u'وَدَمَامِينُ', #1
u'ودمهوجي': u'وَدَمْهُوجِيٌّ', #1
u'ودمون': u'وَدَمّونُ', #1
u'ودمياط': u'وَدِمْيَاطَ', #5
u'ودنباوند': u'وَدُنْبَاوَنْدُ', #1
u'ودنة': u'وَدْنَةٍ', #1
u'ودنياى': u'وَدُنْيَاىَ', #2
u'ودنيائي': u'وَدُنْيَائِي', #1
u'ودنينير': u'وَدُنَيْنِيرٌ', #1
u'ودهير': u'وَدُهَيْرُ', #1
u'ودهير': u'وَدَهِيرُ', #3
u'ودوالبها': u'وَدَوَالِبَهَا', #1
u'ودوالها': u'وَدَوَالُّهَا', #1
u'ودوانيق': u'وَدَوَانِيقَ', #2
u'ودوايا': u'وَدِوَايًا', #1
u'ودوديكر': u'ودوديكر', #1
u'ودومة': u'وَدُومَةَ', #1
u'ودومة': u'ودَوْمَة', #1
u'ودومة': u'وَدَوْمَةُ', #1
u'ودومة': u'وَدُومَةُ', #4
u'ودومة': u'وَدَوْمَةِ', #4
u'ودونالبغل،': u'وَدُونَالْبَغْلِ،', #1
u'ودويرات': u'وَدُوَيْرَاتٍ', #1
u'ودويرات': u'وَدُوَيْرَاتِ', #1
u'ودويراته': u'وَدُوَيْرَاتِهِ', #1
u'ودويرة': u'وَدُوَيْرَةُ', #1
u'وديابج': u'وَدَيَابِجُ', #2
u'ودياس': u'وَدِيَاسُ', #1
u'ودياس': u'وَدِيَاسٍ', #14
u'ودياسه': u'وَدِيَاسِهِ', #1
u'ودياوين': u'وَدَيَاوِينَ', #1
u'ودياوين': u'وَدَيَاوِينُ', #1
u'وديعت': u'وديعت', #3
u'وديق': u'وَديقٍ', #1
u'وديقا': u'وَدِيقًا', #1
u'وديكر': u'وديكر', #1
u'وديكرازين': u'وديكرازين', #1
u'وديورة': u'وَدُيُورَةٍ', #1
u'وذادة': u'وَذَادَةٍ', #1
u'وذادويه': u'وَذَادَوَيْهِ', #2
u'وذار': u'وَذَارٍ', #1
u'وذار': u'وَذَارَ', #2
u'وذراريم': u'وذراريم', #1
u'وذروان': u'وَذَرْوَانَ', #1
u'وذروان': u'وَذَرْوَانُ', #1
u'وذروح': u'وَذُرُّوحٍ', #1
u'وذروح': u'وَذُرُّوحٌ', #2
u'وذرود': u'وَذَرْوَدُ', #1
u'وذريح': u'وذريح', #1
u'وذريرة': u'وَذَرِيرَةَ', #1
u'وذريرة': u'وَذَرِيرَةٍ', #2
u'وذريرة': u'وَذَرِيرَةِ', #2
u'وذريرة': u'وَذَرِيرَةُ', #3
u'وذريرته': u'وَذَرِيرَتُهُ', #1
u'وذفة': u'وَذَفَةَ', #2
u'وذفة': u'وَذْفَةَ', #4
u'وذفريه': u'وَذِفْرَيْهِ', #2
u'وذقة': u'وَذَقَةَ', #1
u'وذقتمو': u'وَذُقْتُمُو', #1
u'وذكارة': u'وَذِكَارَةٌ', #4
u'وذكرالنبي': u'وَذَكَرَالنَّبِيَّ', #1
u'وذكوانا': u'وَذَكْوَانًا', #1
u'وذكوريته': u'وَذُكُورِيَّتُهُ', #5
u'وذكوريتهم': u'وَذُكُورِيَّتُهُمْ', #1
u'وذلكa': u'وَذَلِكَa', #1
u'وذلكإذا': u'وَذَلِكَإِذَا', #1
u'وذلوه': u'وَذَلُّوهُ', #2
u'وذهبداود': u'وَذَهَبَدَاوُدُ', #2
u'وذهبمالك': u'وَذَهَبَمَالِكٌ', #1
u'وذوابا': u'وَذَوَابًا', #1
u'وذيخ': u'وَذِيخٌ', #1
u'وذيخة': u'وَذِيخَة', #1
u'وذيلة': u'وَذِيلَةٍ', #1
u'وذيوعة': u'وَذِيُوعَةً', #1
u'ورءاه': u'وَرَءَاهُ', #1
u'ورءوس': u'وَرُءُوسٌ', #1
u'ورءوس': u'وَرُءُوسُ', #19
u'ورءوس': u'وَرُءُوسٍ', #2
u'ورءوس': u'وَرُءُوسِ', #36
u'ورءوس': u'وَرُءُوسَ', #8
u'ورءوسا': u'وَرُءُوسًا', #4
u'ورءوسكم': u'وَرُءُوسَكُمْ', #1
u'ورءوسه': u'وَرُءُوسِهِ', #2
u'ورءوسها': u'وَرُءُوسُهَا', #3
u'ورءوسها': u'وَرُءُوسِهَا', #6
u'ورءوسهم': u'وَرُءُوسَهُمْ', #2
u'ورءوسهم': u'وَرُءُوسُهُمْ', #3
u'ورءوسهم': u'وَرُءُوسِهِمْ', #8
u'ورءوسهما': u'وَرُءُوسُهُمَا', #1
u'ورءوسهن': u'وَرُءُوسِهِنَّ', #4
u'ورءوف': u'وَرَءُوفٍ', #1
u'ورا': u'وَرَا', #6
u'ورابغ': u'وَرَابِغ', #1
u'ورابغ': u'وَرَابِغُ', #1
u'ورابغ': u'وَرَابِغٌ', #3
u'وراة،': u'وَرَاةَ،', #1
u'وراتح': u'وراتح', #1
u'ورأد': u'وَرَأْدٍ', #1
u'وراددوه': u'وَرَادَدُوهُ', #1
u'ورازيانج': u'ورازيانج', #1
u'وراسخت': u'وَرَاسَخَتٍ', #1
u'وراسخت': u'وَرَاسَخْت', #1
u'وراسخت': u'وَرَاسُخْتَ', #1
u'وراسخت': u'وراسخت', #2
u'ورأسى؟': u'وَرَأْسِى؟', #1
u'ورأسى': u'وَرَأْسِى', #3
u'ورافقنى': u'وَرَافَقَنِى', #2
u'ورال': u'وَرَالٌ', #1
u'ورامة': u'وَرَامَةَ', #1
u'ورامهرمز،': u'ورامَهُرْمُز،', #1
u'ورانج': u'وَرَانِجُ', #1
u'ورانج': u'وَرَانِجٍ', #3
u'ورآنى': u'وَرَآنِى', #1
u'ورأوت': u'وَرَأَوْت', #1
u'وراوى': u'وَرَاوِى', #1
u'ورائطة': u'ورائطة', #1
u'ورآئكم': u'وَرَآئِكُمْ', #1
u'ورائى': u'وَرَائِى', #14
u'ورأيتن': u'وَرَأَيْتُنَّ', #1
u'ورأيتنى': u'وَرَأَيْتَنِى', #1
u'ورأيتيه': u'وَرَأَيْتِيهِ', #1
u'وربعى': u'وَرِبْعِىُّ', #1
u'وربيح': u'وَرَبِيح', #1
u'وربيح': u'وَرَبِيحٌ', #1
u'وربيح': u'وَرُبَيْحٌ', #1
u'ورتبيل': u'وَرُتْبِيلَ', #1
u'ورتقاء': u'وَرَتْقَاء', #1
u'ورتقاء': u'وَرَتْقَاءَ', #29
u'ورتقاء': u'وَرَتْقَاءُ', #9
u'ورثتى': u'وَرَثَتِى', #4
u'ورثيث': u'وَرَثِيثُ', #1
u'ورجأهم': u'وَرَجَّأَهُمْ', #1
u'ورجاوة': u'وَرَجَاوَةً', #1
u'ورجائب': u'وَرَجَائِبَ', #1
u'ورجائى': u'وَرَجَائِى', #2
u'ورجبات': u'وَرَجَبَاتٍ', #1
u'ورجلاى': u'وَرِجْلاَى', #1
u'ورجلاى': u'وَرِجْلاَىَ', #2
u'ورجوعة': u'ورجوعة', #1
u'ورجوعى': u'وَرُجُوعِى', #3
u'ورجئت': u'وَرُجِئَتْ', #1
u'ورجيح': u'وَرَجِيحُ', #1
u'ورحا': u'وَرَحًا', #5
u'ورحتمة': u'ورحتمة', #1
u'ورحرحان': u'وَرَحْرَحَانَ', #1
u'ورحقان': u'وَرَحْقَانَ', #1
u'ورحمانيته': u'وَرَحْمَانِيَّتُهُ', #1
u'ورحى': u'وَرَحًى', #36
u'ورحيلة': u'وَرُحَيْلَةُ', #1
u'ورخيلة': u'ورخيلة', #1
u'وردء': u'وَرِدْء', #1
u'وردء': u'وَرِدْءٌ', #1
u'وردء': u'وَرِدْءٍ', #1
u'وردء': u'وَرِدْءُ', #2
u'وردءا،': u'وَرِدْءًا،', #1
u'ورداغ': u'وَرِدَاغٌ', #1
u'ورداوته': u'وَرَدَاوَتِهِ', #1
u'وردب': u'وَرَدْب', #1
u'وردتنى': u'وَرَدَّتْنِى', #4
u'ورددتنى': u'وَرَدَدْتَنِى', #2
u'وردغ': u'وَرَدْغٍ', #1
u'وردغة': u'وَرَدْغَةٌ', #1
u'وردغة': u'وَرَدْغَةِ', #1
u'وردغة': u'وَرَدْغَةٍ', #14
u'وردغة': u'وَرَدْغَةُ', #4
u'وردنى': u'وَرَدَّنِى', #3
u'ورزغة': u'وَرَزْغَةُ', #1
u'ورزقنيه': u'وَرَزَقْنِيهِ', #1
u'ورزقنيه': u'وَرَزَقَنِيهِ', #17
u'ورزيدن': u'ورزيدن', #1
u'ورزيق': u'ورزيق', #1
u'ورزيق': u'وَرُزَيْق', #1
u'ورساتيق': u'وَرَسَاتِيقَ', #1
u'ورسال': u'وَرَسَّالٍ', #2
u'ورساله': u'وَرِسَالِهِ', #1
u'ورستاقه': u'وَرُسْتَاقُهُ', #1
u'ورسولى': u'وَرَسُولِى', #1
u'ورشدين': u'وَرِشْدِينُ', #2
u'ورصوفا': u'وَرُصُوفًا', #1
u'ورضراضه': u'وَرَضْرَاضُهُ', #1
u'ورضعات': u'وَرَضَعَاتُ', #1
u'ورعاء': u'وَرِعَاءً', #1
u'ورعثة': u'ورَعْثَةٌ', #1
u'ورعل': u'وَرِعْلٍ', #6
u'ورعلا': u'وَرِعْلا', #1
u'ورعلا': u'وَرَعْلا', #2
u'ورعلا،': u'وَرَعْلا،', #3
u'ورعلا': u'وَرِعْلًا', #4
u'ورعلا': u'وَرِعْلاً', #6
u'ورعيم،': u'وَرُعَيْمٌ،', #1
u'ورغفان': u'وَرُغْفَانٌ', #2
u'ورغفان': u'وَرُغْفَانٍ', #7
u'ورفائيل،': u'وَرَفَائِيلَ،', #1
u'ورفغ': u'وَرُفْغٍ', #1
u'ورفغيه': u'وَرَفْغَيْهِ', #3
u'ورفغيه': u'وَرُفْغَيْهِ', #5
u'ورقأ': u'وَرَقَأَ', #1
u'ورقاش': u'ورقاش', #1
u'ورقاش': u'وَرَقَاشَ', #1
u'ورقاش': u'وَرَقَاشِ', #2
u'ورقبات': u'وَرَقَبَاتٌ', #1
u'ورقبى': u'وَرُقْبَى', #6
u'ورقطى': u'وَرَقْطَى', #1
u'ورقوءا': u'وَرُقُوءًا', #1
u'ورقيط': u'وَرُقَيْطُ', #1
u'وركاز': u'وَرِكَازٍ', #20
u'وركاز': u'وَرِكَازٌ', #3
u'وركايا': u'وَرَكَايَا', #1
u'وركبانا': u'وَرُكْبَانًا', #33
u'وركبتنى': u'وَرَكِبَتْنِى', #1
u'وركبنى': u'وَرَكِبَنِى', #1
u'وركدة': u'وَرَكْدَةٌ', #2
u'وركعتى': u'وَرَكْعَتَىِ', #7
u'وركعيتن': u'وركعيتن', #1
u'وركنيته': u'وَرُكْنِيَّتَهُ', #1
u'وركنيته': u'وَرُكْنِيَّتِهِ', #1
u'وركنيته': u'وَرُكْنِيَّتُهُ', #2
u'وركنيتها': u'وَرُكْنِيَّتِهَا', #1
u'وركنيتهما': u'وَرُكْنِيَّتِهِمَا', #1
u'وركوات': u'وَرِكْوَاتٍ', #1
u'ورماض': u'وَرِمَاضٌ', #1
u'ورماض': u'وَرَمَاضٌ', #2
u'ورماضي': u'وَرَمَاضِيّ', #1
u'ورماضي': u'وَرَمَاضِيٌّ', #1
u'ورمحى': u'وَرُمْحِى', #1
u'ورمر': u'ورمر', #1
u'ورمص': u'وَرَمَصٌ', #1
u'ورمص': u'وَرَمَصٍ', #1
u'ورمص': u'وَرَمْصٍ', #1
u'ورميثة': u'وَرُمَيْثَةُ', #1
u'ورهجة': u'وَرَهْجَةَ', #1
u'ورهننى': u'وَرَهَنَنِى', #1
u'ورؤاسي': u'وَرُؤَاسِيٌّ', #1
u'وروافي': u'وَرَوَافِي', #1
u'وروبيل': u'وَرُوبِيلُ', #1
u'وروبيل،': u'وَرُوبِيلُ،', #1
u'وروبيل': u'ورُوبِيلَ', #3
u'وروثة': u'وَرَوْثَةٍ', #26
u'وروثة': u'وَرَوْثَةً', #3
u'وروثة': u'وَرَوْثَةُ', #3
u'وروحنة': u'وَرَوْحَنَةً', #1
u'وروحنة': u'وَرَوْحَنَةٌ', #2
u'وروزيء': u'وروزيء', #1
u'ورؤي': u'وَرُؤِيَ', #2
u'ورؤيا': u'وَرُؤْيًا', #1
u'وروىابن': u'وَرَوَىابْنُ', #1
u'ورويحة': u'وَرُوَيْحَةٌ', #1
u'ورويس': u'وَرُوَيْسٌ', #1
u'وروىعلي': u'وَرَوَىعَلِيُّ', #2
u'وروىعيسى': u'وَرَوَىعِيسَى', #1
u'ورويفع': u'وَرُوِيَفع', #1
u'ورويفع': u'وَرُوَيْفِعِ', #3
u'وروىمطرف': u'وَرَوَىمُطَرِّفٌ', #1
u'وروىمعمر': u'وَرَوَىمَعْمَرٌ', #1
u'ورئاء': u'وَرِئَاءَ', #10
u'ورئاء': u'وَرِئَاءً', #2
u'ورئاما': u'وَرِئَامًا', #1
u'ورئائهم': u'وَرِئَائِهِمْ', #1
u'ورئى': u'وَرُئِىَ', #3
u'ورياب،': u'وَرَيَّابُ،', #1
u'ورية': u'وِرْيَةٌ', #1
u'وريسمان': u'وريسمان', #1
u'وريطة': u'وَرَيْطَةُ', #2
u'وريطة': u'وريطة', #3
u'وزاءين': u'وَزَاءَيْنِ', #1
u'وزاءين': u'وِزَاءَيْنِ', #6
u'وزابلستان': u'وَزَابُلِسْتَانَ', #1
u'وزادأنه': u'وَزَادَأَنَّهُ', #1
u'وزادفي': u'وَزَادَفِي', #1
u'وزادنى': u'وَزَادَنِى', #12
u'وزادوإذا': u'وَزَادَوَإِذَا', #1
u'وزادوالمؤمن': u'وَزَادَوَالْمُؤْمِنُ', #1
u'وزاذان': u'وَزَاذَانَ', #3
u'وزاقرت': u'وَزَاقَرْت', #1
u'وزآنكه': u'وزآنكه', #1
u'وزانئ': u'وَزَانِئُ', #1
u'وزاين': u'وزاين', #2
u'وزبار': u'وَزِبَارٍ', #2
u'وزباره': u'وَزبَارِهِ', #1
u'وزبرهمان': u'وزبرهمان', #1
u'وزبنة': u'وَزَبْنَةً', #1
u'وزبنة': u'وَزَبْنَةٍ', #1
u'وزبيد': u'وزُبَيْد', #1
u'وزبيد': u'وَزَبِيدٌ', #1
u'وزبيد': u'وَزُبَيْدُ', #1
u'وزبيد': u'وَزُبَيْدٌ', #10
u'وزبيد': u'وَزُبَيْدٍ', #11
u'وزبيد،': u'وزبيد،', #2
u'وزبيد': u'وَزَبِيدٍ', #2
u'وزبيد،': u'وَزُبَيْدٍ،', #4
u'وزبيد': u'وزبيد', #5
u'وزة': u'وَزَّةٍ', #1
u'وزت': u'وَزَّتِ', #1
u'وزتوق': u'وَزُتُوقِ', #1
u'وزحشمت': u'وزحشمت', #1
u'وزدر': u'وزدر', #1
u'وزدنى': u'وَزِدْنِى', #2
u'وزدي': u'وزدي', #1
u'وزرابيب': u'وَزَرَابِيبُ', #2
u'وزراجين': u'وَزَرَاجِينِ', #1
u'وزراجينه': u'وَزَرَاجِينِهِ', #1
u'وزراجينها': u'وَزَرَاجِينَهَا', #1
u'وزراجينها': u'وَزَرَاجِينِهَا', #1
u'وزراقات': u'وَزَرَّاقَاتُ', #2
u'وزربول': u'وَزُرْبُولٍ', #2
u'وزرجون': u'وَزَرَجُونِ', #1
u'وزرقون': u'وَزَرْقُونٌ', #1
u'وزروق': u'وَزَرُّوقٍ', #5
u'وزروق': u'وَزَرُّوقٌ', #8
u'وزشد': u'وزشد', #1
u'وزطيا': u'وَزُطِّيًّا', #1
u'وزطيان': u'وَزُطِّيَّانِ', #1
u'وزعب': u'وَزِعْبٍ', #1
u'وزعبل': u'وَزَعْبَلٍ', #3
u'وزغابة': u'وزَغَابة', #1
u'وزغابة': u'وَزُغَابَةَ', #1
u'وزغابة': u'وَزَغَابَةَ', #4
u'وزففتها': u'وَزَفَفْتُهَا', #1
u'وزلنبور،': u'وزلنبور،', #1
u'وزلنبور': u'وَزَلَنْبُورٌ', #1
u'وزلنبور': u'وزلنبور', #2
u'وزمستاني': u'وزمستاني', #1
u'وزمنة': u'وَزَمِنَةٍ', #3
u'وزمنى': u'وَزَمْنَى', #1
u'وزمين': u'وَزُمَيْن', #1
u'وزن': u'وَزْنً', #1
u'وزنأت': u'وَزَنَأَتْ', #1
u'وزنأت': u'وَزَنَأْتِ', #1
u'وزنأت': u'وَزَنَأْت', #5
u'وزنجفر': u'وزنجفر', #1
u'وزندورد': u'وَزَنْدَوَرْدٍ', #1
u'وزنكويى': u'وزنكويى', #1
u'وزنوءا': u'وَزُنُوءًا', #1
u'وزنيرة،': u'وَزِنِّيرَةَ،', #1
u'وزنيرة': u'وَزِنّيرَةُ', #2
u'وزهدم': u'وزَهدم', #1
u'وزهدم': u'وزَهْدَم', #1
u'وزهريكى': u'وزهريكى', #1
u'وزهومة': u'وَزُهُومَةً', #1
u'وزهومة': u'وَزُهُومَةٍ', #2
u'وزهومته': u'وَزُهُومَتُهُ', #1
u'وزهومته': u'وَزُهُومَتِهِ', #1
u'وزهومتها': u'وَزُهُومَتُهَا', #1
u'وزوجتكها': u'وَزَوَّجْتُكَهَا', #2
u'وزوجتكها': u'وَزَوَّجْتُكهَا', #4
u'وزوجكها': u'وَزَوَّجَكَهَا', #2
u'وزوجناكها': u'وَزَوَّجْنَاكَهَا', #2
u'وزوجنى': u'وَزَوَّجَنِى', #1
u'وزوجنى': u'وَزَوِّجْنِى', #1
u'وزوجنيها': u'وَزَوِّجْنِيهَا', #1
u'وزورة': u'وَزَوْرَةُ', #1
u'وزى': u'وَزِىَّ', #4
u'وزياد': u'وَزِيَادً', #1
u'وزيادا': u'وَزِيَادًا', #1
u'وزيادا،': u'وَزِيَادًا،', #1
u'وزياده': u'وَزِيَادُهُ', #1
u'وزيال': u'وَزِيَالِ', #1
u'وزيدين': u'وَزَيْدَيْنِ', #1
u'وزيلعي': u'وَزَيْلَعِيٌّ', #14
u'وزيود': u'وَزُيُودٌ', #1
u'وسآءت': u'وَسَآءتْ', #1
u'وساباط': u'وَسَابَاطُ', #1
u'وساباط': u'وَسَابَاطٍ', #15
u'وساباط': u'وَسَابَاطٌ', #2
u'وساباطا': u'وَسَابَاطًا', #2
u'وساباطات': u'وَسَابَاطَاتٍ', #1
u'وسابور': u'وَسَابُورٌ', #1
u'وسابور': u'وَسَابُورُ', #2
u'وساجة': u'وَسَاجَةٍ', #1
u'وسأحذركموه': u'وَسَأُحَذِّرُكُمُوهُ', #1
u'وسادتى': u'وِسَادَتِى', #2
u'وساسان': u'وَسَاسَانَ', #1
u'وساف': u'وَسَافٍ', #1
u'وساقنى': u'وَسَاقَنِى', #1
u'وسألتنى': u'وَسَأَلْتَنِى', #2
u'وسالحين': u'وَسَالِحِينَ', #1
u'وسألنى': u'وَسَأَلَنِى', #2
u'وسآما': u'وَسَآمًا', #2
u'وسامتت': u'وَسَامَتَتْ', #1
u'وسائرالخلق': u'وسائرالخلق', #1
u'وسايس': u'وَسَايِسٍ', #2
u'وسايستنا': u'وَسَايِسَتُنَا', #2
u'وسباء': u'وَسِبَاءً', #1
u'وسباءى': u'وَسَبَاءَى', #1
u'وسباكي': u'وَسَبَّاكِي', #1
u'وسباؤهم': u'وَسَبَاؤُهُمْ', #1
u'وسباؤهم': u'وَسِبَاؤُهُمْ', #1
u'وسببى': u'وَسَبَبِى', #2
u'وسبتية': u'وَسِبْتِيَّةٍ', #2
u'وسبج': u'وَسَبَج', #1
u'وسبج': u'وَسَبَجٍ', #1
u'وسبخات': u'وَسَبَخَاتٍ', #1
u'وسبرة': u'وسبرة', #1
u'وسبرة': u'وَسَبْرَةَ', #2
u'وسبرة': u'وَسَبْرَةُ', #2
u'وسبطر': u'وَسِبَطْرٍ', #1
u'وسبوح': u'وَسُبُّوحٍ', #1
u'وسبوح': u'وَسُبُّوحٌ', #2
u'وسبوطة': u'وَسُبُوطَةٍ', #2
u'وسبوطته': u'وَسُبُوطَتِهِ', #1
u'وسبوغته': u'وَسُبُوغَتِهِ', #3
u'وسبيع': u'وَسُبَيْعُ', #4
u'وسبيعة': u'وَسُبَيْعَةَ', #1
u'وسبيعة': u'وَسُبَيْعَةُ', #1
u'وستأتيان': u'وَسَتَأْتِيَانِ', #2
u'وستاندن': u'وستاندن', #1
u'وستربصاقه': u'وَسَتَرَبُصَاقَهُ', #1
u'وستوق': u'وَسَتُّوقٍ', #2
u'وستوقة': u'وَسَتُّوقَةٌ', #3
u'وستونقوله': u'وَسِتُّونَقَوْلُهُ', #1
u'وستيتة': u'وَسُتَيْتَةُ', #3
u'وسجاح': u'وَسَجَاحَ', #1
u'وسجدناها': u'وَسَجَدْنَاهَا', #1
u'وسجدوها': u'وَسَجَدُوهَا', #3
u'وسجستان': u'وَسِجِسْتَانُ', #1
u'وسجم': u'وَسَجَمَ', #1
u'وسحال': u'وَسَحَالٍ', #1
u'وسحالتها': u'وَسِحَالَتُهَا', #1
u'وسحبان': u'وَسَحْبَانُ', #3
u'وسحل': u'وَسُحُلٌ', #1
u'وسحل': u'وَسُحُلٍ', #1
u'وسحل': u'وَسُحِلَ', #1
u'وسحلها': u'وَسَحْلُهَا', #1
u'وسحلها': u'وَسَحْلِهَا', #1
u'وسحنون': u'وَسَحْنُون', #1
u'وسحنون': u'وَسَحْنُونَ', #1
u'وسحنون': u'وَسَحْنُونُ', #2
u'وسحنون': u'وَسَحْنُونٍ', #215
u'وسحنون': u'وَسَحْنُونٌ', #224
u'وسحنونإذا': u'وَسَحْنُونٌإِذَا', #1
u'وسحول': u'وَسَحُولُ', #2
u'وسحول': u'وَسُحُولٌ', #2
u'وسحولية': u'وَسَحُولِيَّةٍ', #1
u'وسحيما': u'وَسُحَيْمًا', #1
u'وسحيما': u'وسحيما', #2
u'وسخابها': u'وَسِخَابَهَا', #3
u'وسخال': u'وَسِخَالٍ', #1
u'وسخال': u'وَسِخَالٌ', #3
u'وسخالها': u'وسخالها', #2
u'وسخبرة': u'وَسَخْبَرَةُ', #4
u'وسخل': u'وَسَخْلٌ', #1
u'وسخلان': u'وَسَخْلَانِ', #1
u'وسخلة': u'وَسَخْلَةً', #2
u'وسخلة': u'وَسَخْلَةٍ', #2
u'وسخلة': u'وَسَخْلَةٌ', #3
u'وسخلتها': u'وَسَخَلْتهَا', #1
u'وسخلتها': u'وَسَخْلَتِهَا', #5
u'وسخم': u'وَسَخِمَ', #1
u'وسخم': u'وَسَخَّمَ', #14
u'وسخموا': u'وَسَخَّمُوا', #1
u'وسخموا': u'وَسَخِّمُوا', #2
u'وسددنى': u'وَسَدِّدْنِى', #1
u'وسدف': u'وسدف', #1
u'وسدوم': u'وَسَدُومَ', #1
u'وسدوم،': u'وَسَدُومَ،', #1
u'وسدوما،': u'وَسَدُومًا،', #1
u'وسديسة': u'وَسَدِيسَةٌ', #2
u'وسرابادين': u'وسرابادين', #1
u'وسراحين': u'وَسَرَاحِينُ', #1
u'وسرايجه': u'وسرايجه', #1
u'وسرتو': u'وسرتو', #2
u'وسردد': u'وَسُرْدَدٍ', #1
u'وسردد': u'وَسُرْدَدِ', #4
u'وسرغ': u'وسَرْغ', #1
u'وسرغ': u'وَسَرْغَ', #1
u'وسرف': u'وَسَرَفِ', #1
u'وسرف': u'وَسَرَفٌ', #13
u'وسرف': u'وَسَرَفٍ', #2
u'وسرف': u'وَسَرِفَ', #2
u'وسرفا': u'وَسَرَفًا', #1
u'وسرفه': u'وَسَرَفُهُ', #1
u'وسرقين': u'وَسِرْقِينٌ', #1
u'وسرقين': u'وَسِرْقِينٍ', #2
u'وسرموذة': u'وسرموذة', #1
u'وسرموزة': u'وسرموزة', #2
u'وسرموزة': u'وَسُرْمُوزَةٍ', #2
u'وسرناي': u'وَسِرْنَايٌ', #1
u'وسرنديب': u'وَسَرَنْدِيبُ', #1
u'وسروالة': u'وَسِرْوَالَةٍ', #1
u'وسريج،': u'وَسُرَيْجٍ،', #21
u'وسريج': u'وَسُرَيْجُ', #25
u'وسريج': u'وَسُرَيْجٍ', #3
u'وسريج': u'وَسُرَيْجِ', #4
u'وسريج': u'وَسُرَيْجٌ', #43
u'وسريج،': u'وَسُرَيْجٌ،', #8
u'وسريجة': u'وَسُرَيْجَةُ', #1
u'وسريطى': u'وَسُرّيْطَى', #1
u'وسصفح': u'وسصفح', #1
u'وسطانية': u'وَسْطَانِيَّةً', #2
u'وسطيح': u'وَسَطِيحٌ', #1
u'وسطيح': u'وَسُطَيْحٍ', #1
u'وسطيح': u'وَسَطِيحٍ', #3
u'وسطيحا': u'وَسَطِيحًا', #1
u'وسعط': u'وَسَعَطَ', #1
u'وسعط': u'وَسُعِطَ', #1
u'وسعفص': u'وَسَعْفَص', #1
u'وسعنة': u'وَسُعْنَةَ', #1
u'وسعوط': u'وَسَعُوطٌ', #11
u'وسعوط': u'وَسَعُوطٍ', #2
u'وسعوطه': u'وَسَعُوطُهُ', #1
u'وسعوطه': u'وَسُعُوطُهُ', #1
u'وسغد': u'وَسُغْدَ', #2
u'وسفاتج': u'وَسَفَاتِج', #1
u'وسفاتج': u'وَسَفَاتِجَ', #1
u'وسفاتج': u'وَسَفَاتِجُ', #1
u'وسفرى': u'وَسَفْرَى', #3
u'وسقانى': u'وَسَقَانِى', #1
u'وسقب': u'وَسَقَبْ', #1
u'وسقبت': u'وَسَقِبْت', #1
u'وسقرق': u'وسقرق', #1
u'وسقلاب': u'وسقلاب', #1
u'وسقمونيا': u'وَسَقَمُونْيَا', #2
u'وسقيتيها': u'وَسَقَيْتِيهَا', #2
u'وسكاج': u'وَسَكَاجٍ', #1
u'وسكنجبيل': u'وسكنجبيل', #1
u'وسكنجبين': u'وَسَكَنْجَبِينٍ', #1
u'وسكنجبين': u'وَسَكَنْجَبِينَ', #1
u'وسكندرية': u'وَسَكَنْدَرِيَّةٍ', #1
u'وسلأ': u'وَسَلَأَ', #1
u'وسلأت': u'وَسَلَأَتْ', #1
u'وسلاس': u'وسلاس', #1
u'وسلاليم': u'وَسَلَالِيمِ', #1
u'وسلأه': u'وَسَلَأَهُ', #1
u'وسلجم': u'وَسَلْجَمٍ', #2
u'وسلحفات': u'وَسُلَحْفَاتٍ', #1
u'وسلطاس': u'وسلطاس', #1
u'وسلطيس': u'وَسُلْطَيْسَ', #1
u'وسلطيس': u'وَسُلْطَيْسُ', #1
u'وسلمltText': u'وسلمltText', #10
u'وسلمnalysis': u'وسلمnalysis', #10
u'وسلمrial؛': u'وسلمrial؛', #10
u'وسلمSصفة': u'وَسَلّمَSصِفَةُ', #1
u'وسلمSكتاب': u'وَسَلّمَSكِتَابُ', #1
u'وسلمTION': u'وسلمTION', #10
u'وسلمt': u'وسلمt', #10
u'وسلمإذا': u'وَسَلَّمَإِذَا', #1
u'وسلمأراد': u'وَسَلَّمَأَرَادَ', #1
u'وسلماستعمل': u'وَسَلَّمَاسْتَعْمَلَ', #1
u'وسلمأقام': u'وَسَلَّمَأَقَامَ', #1
u'وسلمأنهم': u'وَسَلَّمَأَنَّهُمُ', #1
u'وسلمحين': u'وَسَلَّمَحِينَ', #1
u'وسلمفلما': u'وَسَلَّمَفَلَمَّا', #1
u'وسلمقال': u'وَسَلَّمَقَالَ', #1
u'وسلمقد': u'وَسَلَّمَقَدْ', #1
u'وسلمقسم': u'وَسَلَّمَقَسَمَ', #1
u'وسلمقوله': u'وَسَلَّمَقَوْلُهُ', #1
u'وسلملا': u'وَسَلَّمَلا', #1
u'وسلملم': u'وَسَلَّمَلَمْ', #1
u'وسلمنيها': u'وَسَلَّمَنِيهَا', #4
u'وسلموالوجه': u'وَسَلَّمَوَالْوَجْهُ', #1
u'وسلموروي': u'وَسَلَّمَوَرُوِيَ', #1
u'وسلموهو': u'وَسَلَّمَوَهُوَ', #2
u'وسلميدعوعلى': u'وَسَلَّمَيَدْعُوَعَلَى', #1
u'وسلميصليها': u'وَسَلَّمَيُصَلِّيَهَا', #1
u'وسلهب': u'وَسَلْهَبُ', #1
u'وسلول': u'وسلول', #2
u'وسلول': u'وَسَلُولُ', #5
u'وسليع': u'وَسُلَيْعٌ', #1
u'وسلينى': u'وَسَلِينِى', #2
u'وسمادير': u'وَسَمَادِيرُ', #2
u'وسماقة': u'وَسَمَاقَةٌ', #1
u'وسمحاق': u'وَسِمْحَاقٌ', #7
u'وسمحاق': u'وَسِمْحَاقٍ', #8
u'وسمعةإلا': u'وَسُمْعَةًإِلَّا', #1
u'وسمعتعبد': u'وَسَمِعْتُعَبْدَ', #1
u'وسمهرية': u'وَسَمْهَرِيَّةِ', #1
u'وسموحة': u'وَسُمُوحَةً', #1
u'وسميساط': u'وسُمَيْساط', #1
u'وسنأتى': u'وَسَنَأْتِى', #1
u'وسنامكي': u'وَسَنَامَكِيٍّ', #1
u'وسنباطي': u'وَسَنْبَاطِيٌّ', #1
u'وسنتى': u'وَسُنَّتِى', #1
u'وسنجاة': u'وَسَنْجَاةِ', #1
u'وسنداسا': u'وَسِنْدَاسًا', #1
u'وسندبيس': u'وَسَنْدَبِيسُ', #1
u'وسندروس': u'وسندروس', #2
u'وسنكساركنيد': u'وسنكساركنيد', #1
u'وسنوطل': u'وَسَنَوْطَلٍ', #1
u'وسهمى': u'وَسَهْمِى', #1
u'وسوابغ': u'وَسَوَابِغَ', #2
u'وسوادة': u'وسوادة', #1
u'وسوادة': u'وَسَوَادَةُ', #1
u'وسواسة': u'وسواسة', #1
u'وسوبيا': u'وَسُوبْيَا', #9
u'وسوج': u'وَسَوْجٌ', #1
u'وسودة': u'وسودة', #1
u'وسودة': u'وَسَوْدَة', #1
u'وسودة': u'وَسَوْدَةُ', #18
u'وسودة،': u'وَسَوْدَةُ،', #3
u'وسودة': u'وَسَوْدَةَ', #8
u'وسودد': u'وَسُوْدُدِ', #2
u'وسوددا': u'وسُودَدًا', #2
u'وسوددا': u'وَسُوْدُدًا', #3
u'وسوددكم': u'وَسُودَدُكُمْ', #1
u'وسوددكم': u'وَسُوْدُدُكُمْ', #1
u'وسورج': u'وسورج', #1
u'وسورج': u'وَسَوْرَجَ', #1
u'وسوطل': u'وَسَوْطَلٍ', #1
u'وسوفسطا': u'وَسُوفُسْطَا', #1
u'وسوقة': u'وَسُوقَةٍ', #3
u'وسوكند': u'وسوكند', #2
u'وسويبط': u'وسويبط', #1
u'وسويبط': u'وَسُوَيْبِطٌ', #1
u'وسويبط': u'وَسُوَيْبِطُ', #14
u'وسويدا': u'وَسُوَيْدًا', #2
u'وسويط': u'وَسُوَيْطُ', #1
u'وسويق': u'وَسَوِيقُ', #1
u'وسويق،': u'وَسَوِيقٍ،', #1
u'وسويق': u'وَسَوِيقٍ', #18
u'وسويق': u'وَسَوِيقٌ', #2
u'وسويق': u'وَسَوِيقِ', #2
u'وسويقا': u'وَسَوِيقًا', #3
u'وسويقه': u'وَسَوِيقُهُ', #11
u'وسويقه': u'وَسَوِيقَهُ', #3
u'وسويقه': u'وَسَوِيقِهِ', #5
u'وسويقها': u'وَسَوِيقَهَا', #3
u'وسويقها': u'وَسَوِيقُهَا', #5
u'وسويقها': u'وَسَوِيقِهَا', #7
u'وسويقهما': u'وَسَوِيقَهُمَا', #1
u'وسويقهما': u'وَسَوِيقِهِمَا', #1
u'وسويقهما': u'وَسُوَيْقِهِمَا', #1
u'وسويقهما': u'وَسَوِيقُهُمَا', #5
u'وسئلأترى': u'وَسُئِلَأَتَرَى', #1
u'وسئلما': u'وَسُئِلَمَا', #1
u'وسيابة': u'وَسَيَّابَة', #1
u'وسياتي': u'وَسِيَاتِي', #2
u'وسيأتى': u'وَسَيَأْتِى', #3
u'وسيأتيان': u'وسيأتيان', #1
u'وسيأتيان': u'وَسَيَأْتِيَانِ', #18
u'وسيبا': u'وَسَيْبًا', #1
u'وسية': u'وَسِيَةَ', #1
u'وسيجة': u'وَسِيجَةٌ', #1
u'وسيدية': u'وَسَيِّدِيَّةَ', #1
u'وسيديته': u'وَسَيِّدِيَّتِهِ', #1
u'وسيراء': u'وَسِيَرَاءُ', #1
u'وسيراف': u'وَسِيرَافُ', #1
u'وسيعة': u'وَسِيعَةٌ', #1
u'وسيعة': u'وَسِيعَةٍ', #1
u'وسيعة': u'وَسِيعَةُ', #1
u'وسيهات': u'وَسَيْهَاتُ', #1
u'وسيور': u'وَسُيُورٌ', #1
u'وسيور': u'وَسُيُورَ', #1
u'وسيور': u'وَسُيُورِ', #4
u'وسيون': u'وسيون', #1
u'وشأبة': u'وَشَأْبَةٌ', #2
u'وشادوران': u'وشادوران', #2
u'وشاذروانه': u'وَشَاذَرْوَانُهُ', #1
u'وشاذروانه': u'وَشَاذَرْوَانِهِ', #2
u'وشارفاى': u'وَشَارِفَاىَ', #2
u'وشاس': u'وَشَاسُ', #1
u'وشأس': u'وَشَأْسُ', #11
u'وشأس': u'وَشَأْسٌ', #2
u'وشاصر': u'وَشَاصِر', #1
u'وشاصر،': u'وَشَاصِرٌ،', #1
u'وشاطة': u'وَشَاطَّةُ', #2
u'وشآم': u'وَشَآمٌ', #1
u'وشآم': u'وَشَآمُ', #1
u'وشاهان': u'وَشَاهَانْ', #7
u'وشاهدى': u'وَشَاهِدَىْ', #15
u'وشاول': u'وَشَاوَلَ', #1
u'وشايحت': u'وَشَايَحْتَ', #1
u'وشبابة،': u'وشبابة،', #1
u'وشبابة': u'وَشَبَّابَةً', #1
u'وشبابة،': u'وَشَبَابَةَ،', #1
u'وشبابة': u'وَشَبَابَةَ', #2
u'وشبابة': u'وَشَبَّابَةَ', #2
u'وشبابة،': u'وَشَبَابَةُ،', #2
u'وشبابة': u'وَشَبَّابَةٌ', #3
u'وشبابة': u'وَشَبَّابَةٍ', #3
u'وشبابة': u'وَشَبَابَةُ', #4
u'وشبابته': u'وَشَبَّابَتِهِ', #1
u'وشبة': u'وَشَبَّةٌ', #1
u'وشبث': u'وشبَث', #1
u'وشبث': u'وشَبَث', #1
u'وشبث': u'وَشَبَثُ', #1
u'وشبرقه': u'وَشَبْرِقَهٌ', #2
u'وشبرقه': u'وَشِبْرِقَهُ', #3
u'وشبههقوله': u'وَشِبْهُهُقَوْلُهُ', #1
u'وشبوبية': u'وَشُبُوبِيَّةً', #1
u'وشبيب،': u'وشبيب،', #1
u'وشبيب': u'وَشُبَيْبٍ', #1
u'وشبيب': u'وشبيب', #2
u'وشبيب': u'وَشَبِيبٍ', #2
u'وشبيب': u'وَشَبِيبُ', #2
u'وشبيب': u'وَشَبِيبِ', #2
u'وشبير': u'وَشَبِيرٍ', #1
u'وشبير': u'وَشَبِيرُ', #2
u'وشبير': u'وَشُبَيْرٍ', #3
u'وشبيرا': u'وَشَبِيرًا', #1
u'وشتل': u'وَشَتْلٌ', #1
u'وشتير': u'وَشُتَيْرُ', #1
u'وشث': u'وَشَثٍّ', #4
u'وشثن': u'وَشَثْنُ', #1
u'وشخوت': u'وَشُخُوتٍ', #1
u'وشداقة': u'وَشَدَّاقَةٌ', #1
u'وشدخ': u'وَشَدْخِ', #1
u'وشدخ': u'وَشَدْخُ', #3
u'وشرابة': u'وشرابة', #1
u'وشرابة': u'وَشَرَابَةٍ', #1
u'وشرابة': u'وَشُرَابَةً', #1
u'وشرابة': u'وَشِرَابَةٍ', #1
u'وشرابة': u'وَشِرَابَةٌ', #2
u'وشراريف': u'وَشَرَارِيفٍ', #1
u'وشراريف': u'وَشَرَارِيفَ', #1
u'وشراقيا': u'وَشَرَاقِيَا', #1
u'وشرائج': u'وَشَرَائِجَ', #2
u'وشرحبيل': u'وشُرَحْبيل', #1
u'وشرحبيل': u'وَشُرَحْبِيلِ', #1
u'وشرحبيل': u'وَشُرَحْبِيلَ', #16
u'وشرحبيل': u'وَشُرَحْبِيلُ', #16
u'وشرحبيل': u'وشرحبيل', #2
u'وشرطما': u'وَشَرَطْمَا', #1
u'وشرقاء': u'وَشَرْقَاءَ', #4
u'وشرقاوي': u'وَشَرْقَاوِيٌّ', #1
u'وشرنبلالي': u'وَشُرُنْبُلَالِيُّ', #1
u'وشرنبلالية': u'وشُرُنْبُلالِيَّة', #9
u'وشرواذ': u'وشرواذ', #1
u'وشروحاتها': u'وَشُرُوحَاتِهَا', #1
u'وشرورى': u'وَشَرَوْرَى', #1
u'وشريبه،': u'وَشَرِيبَهُ،', #1
u'وشريبه': u'وَشَرِيبَهُ', #5
u'وشريكهوفي': u'وَشَرِيكَهُوَفِي', #1
u'وشريكى': u'وَشَرِيكِى', #1
u'وشسته': u'وشسته', #1
u'وشسع': u'وَشِسْعَ', #1
u'وشسع': u'وَشِسْعُ', #1
u'وشسع': u'وَشِسْعٍ', #3
u'وشسع': u'وَشِسْعِ', #4
u'وشطح': u'وَشَطْحِ', #3
u'وشطحهم': u'وَشَطْحُهُمْ', #1
u'وشعبذة': u'وَشَعْبَذَةٍ', #3
u'وشعيبا': u'وَشُعَيْبًا', #1
u'وشقادفهم': u'وَشَقَادِفُهُمْ', #1
u'وشقحب': u'وشقحب', #1
u'وشقحة': u'وَشُقْحَةٍ', #1
u'وشقدف': u'وَشُقْدُفٍ', #5
u'وشقذف': u'وَشُقْذُفٍ', #1
u'وشقران': u'وشقران', #1
u'وشقران': u'وَشُقْرَان', #1
u'وشقران': u'وَشُقْرَانُ', #17
u'وشقران': u'وَشُقْرَانَ', #6
u'وشقرى': u'وَشَقْرَى', #2
u'وشقص': u'وَشِقْصِ', #1
u'وشقص': u'وَشِقْصٌ', #3
u'وشقص': u'وَشِقْصُ', #3
u'وشقص': u'وَشِقْصٍ', #8
u'وشقصا': u'وَشِقْصًا', #6
u'وشقصه': u'وَشِقْصِهِ', #1
u'وشقم': u'وشقم', #1
u'وشقى': u'وَشَقِىٌّ', #3
u'وشكى': u'وَشَكَى', #1
u'وشكير': u'وشكير', #1
u'وشكير': u'وَشَكِيرٌ', #1
u'وشكيل': u'وَشُكَيْلِ', #1
u'وشلسن': u'وشلسن', #1
u'وشلم': u'وَشَلّمُ', #1
u'وشليل': u'وَشُلَيْلٌ', #1
u'وشليلها': u'وَشَلِيلَهَا', #1
u'وشماريخ': u'وَشَمَارِيخَ', #1
u'وشماريخ': u'وَشَمَارِيخُ', #1
u'وشماريخ': u'وَشَمَارِيخِ', #1
u'وشماريخه': u'وَشَمَارِيخِهِ', #1
u'وشماريخه': u'وَشَمَارِيخُهُ', #3
u'وشمأل': u'وَشَمْأَلٌ', #1
u'وشمأل': u'وَشَمْأَلٍ', #1
u'وشمالى': u'وَشِمَالِى', #1
u'وشمعون': u'وَشَمْعُونَ', #1
u'وشمعون،': u'وَشَمْعُونُ،', #2
u'وشمكير': u'وَشْمَكِيرَ', #2
u'وشمكير': u'وَشْمَكِيرُ', #3
u'وشملجه': u'وشملجه', #1
u'وشموصا': u'وَشَمُوصًا', #1
u'وشمويل': u'وَشَمْوِيلُ', #4
u'وشمويل': u'وَشَمْويِلُ', #4
u'وشميسة': u'وَشُمَيْسَة', #1
u'وشميسة': u'وَشُمَيْسَةَ', #1
u'وشميسة': u'وَشُمَيْسَةُ', #1
u'وشنار': u'وَشَنَار', #1
u'وشنار': u'وَشَنَارٌ', #19
u'وشنارا': u'وَشَنَارًا', #4
u'وشناره': u'وَشَنَارَهُ', #1
u'وشندخي': u'وشندخي', #1
u'وشندخي': u'وَشَنْدَخِي', #1
u'وشندخي': u'وَشَنْدَخِيٌّ', #1
u'وشندخي': u'وَشِنْدِخِيٌّ', #1
u'وشندخية': u'وَشُنْدَخِيَّةٌ', #1
u'وشندخية': u'وَشُنْدُخُيَةٌ', #1
u'وشندي': u'وَشِنْدِيّ', #6
u'وشنوق': u'وَشَنُوقٌ', #1
u'وشهدنى': u'وَشَهِدَنِى', #1
u'وشهريران': u'وشهريران', #1
u'وشواربيته': u'وَشَوَارِبِيَّتُهُ', #1
u'وشوالات': u'وَشَوَّالَاتٍ', #1
u'وشوبري': u'وَشَوْبَرِيٌّ', #30
u'وشورة': u'وَشَوْرَةُ', #1
u'وشورة': u'وَشَوْرَةِ', #1
u'وشورة': u'وَشُورَةِ', #2
u'وشوصة': u'وَشُوصَةٍ', #1
u'وشونيز': u'وَشُونِيزٍ', #2
u'وشوهريم': u'وشوهريم', #1
u'وشوئيم': u'وشوئيم', #1
u'وشويس': u'وَشُوَيْسِ', #1
u'وشويم': u'وشويم', #2
u'وشىء': u'وَشَىْءٌ', #1
u'وشىء': u'وَشَىْءٍ', #7
u'وشياع': u'وَشِيَاعُ', #1
u'وشياعها': u'وَشِيَاعُهَا', #1
u'وشيث': u'وَشِيث', #1
u'وشيث': u'وَشِيثٍ', #14
u'وشيث': u'وَشِيثَ', #2
u'وشيث': u'وَشِيثُ', #3
u'وشيث': u'وَشِيثٌ', #4
u'وشيرازه': u'وَشِيرَازِهِ', #4
u'وشيرازها': u'وَشِيرَازِهَا', #1
u'وشيرجة': u'وَشَيْرَجَةٍ', #1
u'وشيرخشك': u'وشيرخشك', #2
u'وشيطانة': u'وَشَيْطَانَةٍ', #1
u'وشيظة': u'وَشِيظَةٍ', #2
u'وشيوخة': u'وَشُيُوخَةً', #1
u'وشيوعة': u'وَشُيُوعَةً', #2
u'وصاءا': u'وَصَاءَا', #1
u'وصاآ': u'وَصَاآ', #1
u'وصابوما': u'وَصَابُومًا', #1
u'وصاة': u'وَصَاةً', #3
u'وصاة': u'وَصَاةَ', #3
u'وصاة': u'وَصَاةُ', #4
u'وصاتى': u'وَصَاتَى', #1
u'وصاحبى': u'وَصَاحِبِى', #9
u'وصادقية': u'وَصَادِقِيَّةُ', #1
u'وصارور': u'وَصَارُورٌ', #1
u'وصارورة': u'وَصَارُورَةٌ', #1
u'وصأصأ': u'وَصَأْصَأَ', #1
u'وصأصأتم': u'وَصَأْصَأْتُمْ', #5
u'وصانعيته': u'وَصَانِعِيَّتِهِ', #1
u'وصائي': u'وَصَائِي', #1
u'وصائي': u'وَصَائِيٌّ', #1
u'وصايي': u'وَصَايِيٌّ', #1
u'وصبى': u'وَصَبِىٍّ', #1
u'وصبى': u'وَصِبَى', #1
u'وصبى': u'وَصِبًى', #3
u'وصجنان،': u'وَصَجْنَانُ،', #1
u'وصحبان': u'وَصُحْبَانٌ', #2
u'وصداء': u'وَصُدَاءُ', #1
u'وصراصر': u'وصراصر', #1
u'وصراصر': u'وَصَرَاصِرُ', #2
u'وصرائح': u'وَصَرَائِحُ', #2
u'وصرائحه': u'وَصَرَائِحِهِ', #1
u'وصرج': u'وَصَرَّجَ', #2
u'وصرحة': u'وَصَرْحَة', #1
u'وصرخد': u'وَصَرْخَدَ', #1
u'وصرخد': u'وَصَرْخَدُ', #3
u'وصرصار': u'وَصِرْصَارٍ', #1
u'وصرناي': u'وَصُرْنَايٍ', #1
u'وصروري': u'وَصَرُورِيٌّ', #1
u'وصرى': u'وَصَرَّى', #2
u'وصريته': u'وَصَرَّيْتُهُ', #1
u'وصعر': u'وَصَعَّرَ', #1
u'وصعصعة': u'وصعصعة', #1
u'وصعصعة': u'وَصَعْصَعَةَ', #1
u'وصعصعة،': u'وَصَعْصَعَةُ،', #1
u'وصعصعة': u'وَصَعْصَعَةُ', #2
u'وصعوة': u'وَصَعْوَةٌ', #1
u'وصعوة': u'وَصَعْوَةَ', #1
u'وصعوة': u'وَصَعْوَةٍ', #8
u'وصغد': u'وَصُغْدُ', #2
u'وصغيا': u'وَصَغْيًا', #1
u'وصفنة': u'وَصَفْنَةَ', #1
u'وصلاتى': u'وَصَلاَتِى', #5
u'وصلائح': u'وَصَلَائِحَ', #1
u'وصلتمو': u'وَصَلْتُمُو', #1
u'وصلدد': u'وَصَلْدَدِ', #3
u'وصلق': u'وَصَلْقٌ', #1
u'وصلق': u'وَصَلْقَ', #1
u'وصلق': u'وَصَلْقِ', #1
u'وصلق': u'وَصُلِقَ', #2
u'وصلق': u'وَصَلَقَ', #3
u'وصلنى': u'وَصَلَنِى', #1
u'وصليع': u'وصليع', #1
u'وصمديته': u'وَصَمَدِيَّته', #1
u'وصمصامة': u'وَصَمْصَامَةُ', #1
u'وصمصامته': u'وَصَمْصَامَتُهُ', #1
u'وصمع': u'وَصَمَعٍ', #1
u'وصمعاء': u'وَصَمْعَاءُ', #3
u'وصمعاء': u'وَصَمْعَاءَ', #5
u'وصمعج': u'وصمعج', #1
u'وصنابح': u'وَصُنَابِحُ', #1
u'وصنجاته': u'وَصَنَجَاتِهِ', #1
u'وصنجة': u'وَصَنْجَةٍ', #1
u'وصنجة': u'وَصَنْجَةِ', #1
u'وصنجة': u'وَصَنْجَةٌ', #2
u'وصهرى': u'وَصِهْرِى', #2
u'وصهوبته': u'وَصُهُوبَتُهُ', #3
u'وصهوبته': u'وَصُهُوبَتِهِ', #4
u'وصهيبا': u'وَصُهَيْبًا', #6
u'وصهيبة': u'وَصُهَيْبَةُ', #1
u'وصؤاب': u'وَصُؤَابُ', #1
u'وصؤاب': u'وَصُؤَابٌ', #2
u'وصواحباتها': u'وَصَوَاحِبَاتُهَا', #1
u'وصواحباتها': u'وَصَوَاحِبَاتِهَا', #1
u'وصواحباتها': u'وَصُوَاحِبَاتِهَا', #1
u'وصواديد': u'وَصَوَادِيدِ', #1
u'وصوباشي': u'وَصُوبَاشِي', #1
u'وصومى': u'وَصُومِى', #3
u'وصئبان': u'وَصِئْبَانٍ', #1
u'وصئبانا': u'وَصِئْبَانًا', #1
u'وصئبانه': u'وَصِئْبَانَهُ', #1
u'وصئبانه': u'وَصِئْبَانِهِ', #5
u'وصيال': u'وَصِيَالِ', #3
u'وصيانا': u'وَصِيَانًا', #1
u'وصيةوقال': u'وَصِيَّةًوَقَالَ', #1
u'وصيتى': u'وَصِيَّتِى', #5
u'وصيدناني': u'وَصَيْدَنَانِيِّ', #1
u'وصيصيتها': u'وَصِيصِيَتُهَا', #1
u'وصيصيتها': u'وَصِيصِيَتَهَا', #2
u'وصيفى': u'وَصَيْفِىُّ', #1
u'وصيقل': u'وَصَيْقَلَ', #1
u'وصيقلا': u'وَصَيْقَلًا', #1
u'وصيود': u'وَصُيُودٍ', #2
u'وضأة': u'وَضْأَةٍ', #1
u'وضاجروهن': u'وَضَاجِرُوهُنَّ', #1
u'وضائف': u'وَضَائِفٍ', #1
u'وضباعة': u'وَضُبَاعَةَ', #2
u'وضباعة': u'وَضُبَاعَةُ', #2
u'وضببته': u'وَضَبَّبْتُهُ', #1
u'وضبعانة': u'وَضُبْعَانَةُ', #2
u'وضبيت': u'وَضُبِيَتْ', #1
u'وضجيعيه': u'وَضَجِيعِيهِ', #1
u'وضجيعيه': u'وَضَجِيعَيْهِ', #4
u'وضرباءه': u'وضرباءه', #1
u'وضربنى': u'وَضَرَبَنِى', #2
u'وضربوب': u'وضربوب', #1
u'وضربوب': u'وَضُرْبُوبٌ', #1
u'وضربوب': u'وَضَرْبُوبٍ', #2
u'وضربوب': u'وَضُرْبُوبٍ', #2
u'وضربونى': u'وَضَرَبُونِى', #1
u'وضريطى': u'وَضُرّيْطَى', #1
u'وضع': u'وَضْعً', #1
u'وضعفى': u'وَضَعْفَى', #1
u'وضغابيس': u'وَضَغَابِيسَ', #9
u'وضلواعن': u'وَضَلُّواعَنْ', #1
u'وضمائم': u'وَضَمَائِمَ', #1
u'وضمى': u'وَضُمِّى', #2
u'وضميرة': u'وَضُمَيْرَةُ', #1
u'وضنء': u'وَضِنْءٌ', #1
u'وضنة': u'وَضِنَةٌ', #1
u'وضو': u'وُضُو', #2
u'وضوء': u'وُضُوءً', #12
u'وضوءات': u'وُضُوءَاتٍ', #3
u'وضوآت': u'وُضُوآتٍ', #14
u'وضوآت': u'وُضُوآتِ', #2
u'وضوآتها': u'وُضُوآتِهَا', #1
u'وضوأي': u'وُضُوأَيْ', #1
u'وضوأين': u'وُضُوأَيْنِ', #5
u'وضوئى': u'وُضُوئِى', #21
u'وضوئين،': u'وُضُوئَيْنِ،', #1
u'وضئنى': u'وَضِّئْنِى', #1
u'وضية': u'وَضِيَّةُ', #1
u'وضيح': u'وضيح', #15
u'وضيح': u'وَضَيْحٍ', #3
u'وضيمة': u'وَضِيمَةٍ', #1
u'وضيمة': u'وَضَيْمَةُ', #1
u'وضيمة': u'وَضِيمَةُ', #3
u'وضيمة': u'وَضِيمَةٌ', #7
u'وضينها': u'وَضَيْنُهَا', #1
u'وضينها': u'وَضِينُهَا', #11
u'وطء': u'وَطْءً', #11
u'وطأ': u'وَطْأً', #1
u'وطابة': u'وَطَابَةَ', #1
u'وطابة': u'وَطَابَةُ', #5
u'وطابغا': u'وَطَابِغًا', #1
u'وطارقت': u'وَطَارَقْتُ', #4
u'وطاعةرسوله': u'وَطَاعَةِرَسُولِهِ', #1
u'وطاعه': u'وَطَاعَهُ', #3
u'وطالوت': u'وَطَالُوتُ', #2
u'وطآن': u'وَطْآنِ', #1
u'وطاهريته': u'وَطَاهِرِيَّتَهُ', #1
u'وطاوس': u'وَطَاوُسٍ', #151
u'وطاوس،': u'وطاوس،', #2
u'وطاوس': u'وَطَاوُسُ', #2
u'وطاوس،': u'وَطَاوُسَ،', #2
u'وطاوس،': u'وَطَاوُسٍ،', #33
u'وطاوس،': u'وَطَاوُسٌ،', #7
u'وطاوس': u'وَطَاوُسٌ', #79
u'وطاوسا،': u'وطاوسا،', #1
u'وطاوسا': u'وَطَاوُسًا', #9
u'وطآئفة': u'وَطَآئِفَةٌ', #1
u'وطأيهما': u'وَطْأَيْهِمَا', #4
u'وطبابيع': u'وَطَبَابِيعَ', #1
u'وطبابيع': u'وَطَبَابِيعُ', #1
u'وطبة': u'وَطْبَةً', #1
u'وطبخة': u'وَطَبْخَةٍ', #1
u'وطبختين': u'وَطَبْخَتَيْنِ', #1
u'وطبرزد': u'وَطَبَرْزَدْ', #1
u'وطبرستان': u'وَطَبَرِسْتَانُ', #1
u'وطبرستان': u'وَطَبَرِسْتَانَ', #2
u'وطبرية': u'وَطَبَرِيَّة', #1
u'وطبرية': u'وَطَبَرِيَّةٌ', #1
u'وطبرية': u'وَطَبَرِيَّةُ', #1
u'وطبلاوي': u'وَطَبَلَاوِيٌّ', #1
u'وطبوع': u'وَطَبُّوعٌ', #1
u'وطبوع': u'وَطُبُوعٍ', #2
u'وطتجير': u'وطتجير', #1
u'وطحينة': u'وَطَحِينَةٌ', #1
u'وطخاء': u'وَطَخَاءُ', #1
u'وطخفة': u'وَطِخْفَةُ', #2
u'وطخية': u'وَطُخْيَةِ', #1
u'وطرآن': u'وَطَرَآنُ', #2
u'وطرآنه': u'وَطَرَآنُهُ', #1
u'وطربة': u'وَطَرِبَةٍ', #1
u'وطربة': u'وَطَرْبَةٍ', #1
u'وطرسوس': u'وَطَرَسُوسَ', #1
u'وطرطوشة': u'وَطَرْطُوشَةَ', #1
u'وطروقة': u'وَطَرُوقَةُ', #1
u'وطرى': u'وَطُرَى', #1
u'وطرياق': u'وَطِرْيَاقٌ', #1
u'وطريانه': u'وَطَرَيَانُهُ', #1
u'وطسة': u'وَطَسَّةٌ', #1
u'وطسم': u'وطَسْم', #1
u'وطسم': u'وَطَسْمٍ', #1
u'وطسم': u'وَطسم', #2
u'وطسوج': u'وَطُسُوجَ', #1
u'وطسوس': u'وَطُسُوسٌ', #1
u'وطسوس': u'وَطُسُوسٍ', #1
u'وطسيس': u'وَطَسِيسٌ', #2
u'وطعيمة': u'وَطَعِيمَةُ', #1
u'وطعيمة': u'وَطُعَيْمَةَ', #2
u'وطعيمة': u'وَطُعَيْمَةُ', #5
u'وطغامهم': u'وَطَغَامُهُمْ', #1
u'وطفاء': u'وَطَفَاءَ', #1
u'وطفاء': u'وَطْفَاءَ', #2
u'وطفافه': u'وَطِفَافُهُ', #1
u'وطفى': u'وطفى', #18
u'وطفيل': u'وطفيل', #2
u'وطفيل': u'وَطُفَيْلُ', #2
u'وطفيل': u'وَطُفَيْلِ', #2
u'وطفيل': u'وَطَفِيلٌ', #3
u'وطفيل': u'وَطُفَيْلٌ', #4
u'وطفيل': u'وَطَفِيلُ', #7
u'وطقز': u'وطقز', #1
u'وطقز': u'وَطَقَزَ', #4
u'وطلاغ': u'وطلاغ', #1
u'وطلاغ': u'وَطَلَاغٍ', #1
u'وطلاغ': u'وَطَلَاغٌ', #3
u'وطليب': u'وَطَلِيبِ', #1
u'وطليب': u'وَطُلَيْبُ', #3
u'وطليع': u'وَطُلَيْعٌ', #1
u'وطليع': u'وَطَلِيعٍ', #2
u'وطمء': u'وَطَمْءٌ', #1
u'وطمرة': u'وَطِمَرّةٍ', #1
u'وطمرة': u'وَطِمِرّةٍ', #1
u'وطمطم': u'وَطُمْطُمٌ', #1
u'وطمنت': u'وَطَمّنْتَ', #2
u'وطمنوها': u'وَطَمِنُوهَا', #1
u'وطنبذ': u'وَطُنْبُذُ', #1
u'وطنى': u'وَطَنِى', #1
u'وطهرين': u'وَطُهْرَيْنِ', #11
u'وطهوراوروي': u'وَطُهُورًاوَرُوِيَ', #1
u'وطواسين': u'وَطَوَاسِينَ', #1
u'وطوانة': u'وَطُوَّانَةَ', #1
u'وطوفتان': u'وَطَوْفَتَانِ', #3
u'وطومان': u'وَطُومَانَ', #1
u'وطويس': u'وَطُوَيْسُ', #1
u'وطى': u'وَطْىَ', #1
u'وطىء': u'وَطِىءَ', #2
u'وطئة': u'وَطِئَةً', #1
u'وطئة': u'وَطِئَةٌ', #1
u'وطئة': u'وَطْئَةً', #1
u'وطئة': u'وَطْئَةٍ', #4
u'وطئتي': u'وَطِئْتِي', #1
u'وطئنى': u'وَطِئَنِى', #1
u'وطئين': u'وَطْئَيْنِ', #2
u'وطيفور': u'وَطَيْفُورٌ', #1
u'وطيلسه': u'وَطَيْلَسِهِ', #1
u'وطيما': u'وطيما', #2
u'وطيئ': u'وطَيِّئٍ', #1
u'وطيئ': u'وَطَيّئٌ', #1
u'وطيئ': u'وَطَيّئٍ', #1
u'وطيئ': u'وَطَيِّئٌ', #1
u'وطيئ': u'وَطَيّئُ', #2
u'وطيئ': u'وَطَيِّئٍ', #2
u'وظلمانية': u'وَظُلْمَانِيَّةً', #1
u'وظنواأنه': u'وَظَنُّواأَنَّهُ', #1
u'وظنى': u'وَظَنِّى', #1
u'وظنيته': u'وَظَنِّيَّتُهُ', #3
u'وظنيتها': u'وَظَنِّيَّتُهَا', #1
u'وظنيتها': u'وَظَنِّيَّتِهَا', #1
u'وظهرانيكم': u'وَظَهْرَانِيكُمْ', #1
u'وظهرانيهم': u'وَظَهْرَانَيْهِمْ', #2
u'وظؤار': u'وَظُؤَارٌ', #1
u'وظؤرة': u'وَظُؤَرَةٌ', #1
u'وظئر': u'وَظِئْرِ', #1
u'وظئر': u'وَظِئْرٌ', #2
u'وظئر': u'وَظِئْرٍ', #5
u'وظئراهما': u'وَظِئْرَاهُمَا', #1
u'وظئور': u'وَظُئُورٌ', #1
u'وظئورة': u'وَظُئُورَةٌ', #1
u'وعاتفي،': u'وَعَاتِفِي،', #1
u'وعاتكة': u'وَعَاتِكَةَ', #5
u'وعاتكة': u'وَعَاتِكَةُ', #5
u'وعاذور': u'وَعَاذُورُ', #1
u'وعارضيته': u'وَعَارِضِيَّتِهِ', #1
u'وعاززنا': u'وَعَازَزْنَا', #1
u'وعاضدية': u'وعاضدية', #1
u'وعاضم': u'وَعَاضِمُ', #1
u'وعاضنى': u'وَعَاضَنِى', #1
u'وعافنى': u'وَعَافِنِى', #11
u'وعاقول': u'وَعَاقُولٍ', #1
u'وعامود': u'وَعَامُودُ', #1
u'وعامورا،': u'وَعَامُورًا،', #1
u'وعانقنى': u'وَعَانَقَنِى', #1
u'وعائن': u'وَعَائِنٍ', #1
u'وعاينتمالوجه': u'وَعَايَنْتُمْالْوَجْهُ', #1
u'وعباثر': u'وَعَبَاثِرُ', #1
u'وعبادان': u'وَعَبَّادَانُ', #3
u'وعباديد': u'وَعَبَادِيدَ', #1
u'وعبالة': u'وَعَبَالَةُ', #5
u'وعبالة': u'وَعَبَالَةِ', #7
u'وعبدري': u'وَعَبْدَرِيٌّ', #1
u'وعبدون': u'وَعَبْدُونٌ', #1
u'وعبديته': u'وَعَبْدِيَّتِهِ', #1
u'وعبود': u'وَعَبّودُ', #1
u'وعبوق': u'وَعُبُوقٌ', #1
u'وعبوق': u'وَعُبُوقِ', #1
u'وعبيدون': u'وَعَبِيدُونَ', #1
u'وعبيدون': u'وَعُبَيْدُونَ', #1
u'وعتر': u'وَعِتَرٌ', #1
u'وعترا': u'وَعِتْرًا', #1
u'وعتقاء': u'وَعُتَقَاءَ', #1
u'وعتقاء': u'وَعُتَقَاءُ', #3
u'وعتقاء': u'وَعُتَقَاءِ', #5
u'وعتقاءه': u'وَعُتَقَاءَهُ', #2
u'وعتقاؤه': u'وَعُتَقَاؤُهُ', #2
u'وعتقاي': u'وَعُتَقَايَ', #1
u'وعتقائه': u'وَعُتَقَائِهِ', #10
u'وعتقائهن': u'وَعُتَقَائِهِنَّ', #2
u'وعتود': u'وَعَتُودٌ', #1
u'وعتود': u'وَعِتْوَد', #1
u'وعتود': u'وَعِتْوَدَ', #1
u'وعتود': u'وَعِتْوَدٌ', #5
u'وعتود': u'وَعِتْوَدٍ', #5
u'وعتور': u'وَعَتْوَرُ', #1
u'وعتور': u'وَعِتْوَرٌ', #1
u'وعتية': u'وَعُتَيّة', #1
u'وعتيرة،': u'وَعَتِيرَةً،', #1
u'وعتيرة': u'وَعَتِيرَةٌ', #16
u'وعتيرة': u'وَعَتِيرَةً', #9
u'وعتيكة': u'وَعَتِيكَةُ', #1
u'وعثيم': u'وَعُثَيْمٌ', #1
u'وعجاجيل': u'وَعَجَاجِيلُ', #1
u'وعجاجيل': u'وَعَجَاجِيلَ', #3
u'وعجاجيلها': u'وعجاجيلها', #1
u'وعجلنى': u'وَعَجَلَنِى', #1
u'وعجور': u'وَعَجُّورٍ', #1
u'وعدتنى': u'وَعَدْتَنِى', #6
u'وعدلتان': u'وَعِدْلَتَانٍ', #1
u'وعدلتان': u'وَعَدْلَتَانِ', #2
u'وعدلتين': u'وَعَدْلَتَيْنِ', #3
u'وعدنى': u'وَعَدَنِىَ', #1
u'وعدنى': u'وَعَدَنِى', #7
u'وعذيرة': u'وَعَذِيرَةٌ', #2
u'وعذيري': u'وَعَذِيرِي', #1
u'وعذيطة': u'وعذيطة', #1
u'وعذيطة': u'وَعَذْيَطَةٌ', #1
u'وعذيطة': u'وَعَذْيَطَةٍ', #6
u'وعذيقها': u'وعُذْيقها', #1
u'وعذيقها': u'وَعُذَيْقُهَا', #8
u'وعذيوطة': u'وَعِذْيُوطَةٌ', #1
u'وعراجها': u'وَعِرَاجُهَا', #1
u'وعرباض': u'وَعِرْبَاضٌ', #1
u'وعرباض': u'وَعِرْبَاضَ', #1
u'وعرباض': u'وَعِرْبَاضُ', #1
u'وعرص': u'وَعَرْصٌ', #1
u'وعرضنى': u'وَعَرَضَنِى', #3
u'وعرضى': u'وَعِرْضِى', #3
u'وعرفجة': u'وعرفجة', #1
u'وعرفجة': u'وَعَرْفَجَة', #1
u'وعرفطة': u'وعُرْفُطَة', #1
u'وعرفطة': u'وَعُرْفُطَةُ', #3
u'وعرفنى': u'وَعَرَّفَنِى', #1
u'وعرقبته': u'وَعَرْقَبَتِهِ', #1
u'وعرقبته': u'وَعَرْقَبَتُهُ', #7
u'وعرنات': u'وَعُرَنَاتٌ', #1
u'وعرنة': u'وعرنة', #1
u'وعرنة': u'وَعَرَنَةُ', #1
u'وعرنة': u'وَعُرَنَةَ', #2
u'وعرنة': u'وَعُرَنَةُ', #5
u'وعري': u'وَعُرْيً', #1
u'وعريب': u'وعُريب', #1
u'وعزازة': u'وَعَزَازَةً', #1
u'وعزازة': u'وَعِزَازَةً', #1
u'وعزتى': u'وَعِزَّتِى', #5
u'وعزرة': u'وَعَزْرَةُ', #4
u'وعزرى': u'وَعِزْرَى', #1
u'وعزير،': u'وعزير،', #1
u'وعزير': u'وعزير', #2
u'وعزير': u'وَعُزَيْرٍ', #3
u'وعزير': u'وَعُزَيْرُ', #4
u'وعزير': u'وَعُزَيْرٌ', #9
u'وعزيرا': u'وعزيراً', #1
u'وعزيرا': u'وَعُزَيْرًا', #6
u'وعزيرة': u'وَعُزَيْرَةَ', #1
u'وعسب': u'وَعَسَبَ', #1
u'وعسب': u'وَعَسْب', #1
u'وعسب': u'وَعَسْبٌ', #1
u'وعسب': u'وَعَسْبِ', #10
u'وعسب': u'وَعَسْبُ', #5
u'وعسبار': u'وَعِسْبَارُ', #1
u'وعسبار': u'وَعِسْبَارٍ', #2
u'وعسبت': u'وَعَسَبْت', #1
u'وعسبه': u'وَعَسْبُهُ', #1
u'وعسماء': u'وَعَسْمَاءَ', #1
u'وعسيب': u'وَعَسِيبُ', #1
u'وعسيب': u'وَعَسِيبِ', #6
u'وعسيلة': u'وَعُسَيْلَةٌ', #1
u'وعشر': u'وَعَشَرً', #1
u'وعشراوات': u'وَعُشَرَاوَاتٍ', #1
u'وعشماوي': u'وَعَشْمَاوِيٌّ', #1
u'وعصبى': u'وَعَصَبِى', #3
u'وعصفر': u'وَعَصْفَرَ', #1
u'وعصفر': u'وَعُصْفُرٌ', #1
u'وعصفر': u'وَعُصْفُرَ', #1
u'وعصفر': u'وَعُصْفُرٍ', #18
u'وعصفرا': u'وَعُصْفُرًا', #5
u'وعصوبة': u'وَعُصُوبَةِ', #3
u'وعصوبة': u'وَعُصُوبَةٌ', #4
u'وعصوبة': u'وَعُصُوبَةً', #5
u'وعصوبة': u'وَعُصُوبَةٍ', #9
u'وعصوبته': u'وَعُصُوبَتُهُ', #1
u'وعصوبته': u'وَعُصُوبَتِهِ', #2
u'وعصوبتهم': u'وَعُصُوبَتُهُمْ', #1
u'وعصى': u'وَعَصًى', #1
u'وعصيم': u'وَعُصَيْمٌ', #1
u'وعصيمة': u'وعصيمة', #2
u'وعصيمة': u'وَعُصَيْمَةُ', #5
u'وعضاهه': u'وَعِضَاهِهِ', #1
u'وعضاهه': u'وَعِضَاهَهُ', #7
u'وعضائد': u'وَعَضَائِدَ', #2
u'وعضائده': u'وَعَضَائِدُهُ', #2
u'وعضب': u'وَعَضَبَ', #2
u'وعضون': u'وَعِضُونَ', #1
u'وعضين': u'وَعِضِينَ', #1
u'وعطشانا': u'وَعَطْشَانًا', #1
u'وعطنت': u'وَعُطّنَتْ', #1
u'وعطنوا': u'وَعَطّنُوا', #1
u'وعطنوا': u'وَعَطَنُوا', #3
u'وعطيات': u'وَعَطِيَّاتٍ', #1
u'وعظامى': u'وَعِظَامِى', #3
u'وعظمتى': u'وَعَظَمَتِى', #2
u'وعفار': u'وَعِفَارُ', #1
u'وعفار،': u'وَعَفَّارٌ،', #1
u'وعفار': u'وَعَفَارُ', #2
u'وعفارها': u'وَعَفَارُهَا', #1
u'وعفاصها': u'وَعِفَاصِهَا', #1
u'وعفاصها،': u'وَعِفَاصَهَا،', #2
u'وعفاصها': u'وَعِفَاصَهَا', #26
u'وعفج': u'وَعَفْجَ', #1
u'وعفص': u'وَعَفْص', #1
u'وعفص': u'وَعَفَصٍ', #2
u'وعفص': u'وَعَفْصٍ', #8
u'وعفل': u'وَعَفَلٌ', #2
u'وعفل': u'وَعَفَلٍ', #4
u'وعفلاء': u'وَعَفْلَاءَ', #1
u'وعفلاء': u'وَعَفْلَاءُ', #3
u'وعفلها': u'وَعَفَلِهَا', #6
u'وعقصة': u'وَعِقْصَةَ', #1
u'وعقيلا': u'وعَقِيلًا', #1
u'وعقيلا': u'وَعُقَيْلًا', #2
u'وعقيلا': u'وَعَقِيلًا', #6
u'وعكام': u'وَعِكَامِ', #1
u'وعكدته': u'وَعَكَدَتُهُ', #1
u'وعكراش': u'وعكراش', #1
u'وعكوسها': u'وَعُكُوسُهَا', #1
u'وعكوسها': u'وَعُكُوسَهَا', #5
u'وعلابط': u'وَعُلَابِطٍ', #1
u'وعلاق': u'وَعِلَاقِ', #1
u'وعلاكة': u'وَعِلَاكَةٌ', #1
u'وعلائمة': u'وعلائمة', #1
u'وعلس': u'وَعَلَسٌ', #1
u'وعلس': u'وَعَلَسِ', #1
u'وعلس': u'وَعَلْسٍ', #1
u'وعلس': u'وَعَلَسٍ', #6
u'وعلفتين': u'وَعَلَفَتَيْنِ', #1
u'وعلقمة،': u'وعلْقمة،', #1
u'وعلقمة،': u'وَعَلَقْمَةُ،', #1
u'وعلقمة،': u'وَعَلْقَمَةُ،', #1
u'وعلقمة،': u'وَعَلْقَمَةِ،', #1
u'وعلقمة': u'وعَلْقمة', #2
u'وعلقمة': u'وَعَلْقَمَةُ', #43
u'وعلقمة': u'وَعَلْقَمَةَ', #60
u'وعلقمة': u'وعلقمة', #7
u'وعلقمة،': u'وَعَلْقَمَةَ،', #7
u'وعلقمة،': u'وعلقمة،', #8
u'وعلمنى': u'وَعَلِّمْنِى', #2
u'وعلمنى': u'وَعَلَّمَنِى', #3
u'وعلوص': u'وَعِلَّوْصٍ', #5
u'وعلوفة': u'وَعَلُوفَةً', #1
u'وعلوفة': u'وَعُلُوفَةٌ', #1
u'وعلوفة': u'وَعُلُوفَةٍ', #1
u'وعلوفة': u'وَعُلُوفَةِ', #1
u'وعلوفة': u'وَعَلُوفَةٍ', #3
u'وعلوفتهم': u'وَعُلُوفَتَهُمْ', #1
u'وعلونته': u'وَعَلْوَنْتُهُ', #1
u'وعلي،': u'وَعَلِيًّ،', #1
u'وعليف': u'وَعَلِيفُ', #1
u'وعليف': u'وَعَلِيفٌ', #3
u'وعليفة': u'وعليفة', #1
u'وعليفة': u'وَعَلِيفَةٌ', #1
u'وعليقة': u'وَعَلِيقَةٌ', #2
u'وعمدى': u'وَعَمْدِى', #1
u'وعمرتى': u'وَعُمْرَتِى', #1
u'وعمرى': u'وَعُمْرَى', #3
u'وعملى': u'وَعَمَلِى', #1
u'وعمهاء': u'وَعَمْهَاءُ', #2
u'وعميانا': u'وَعُمْيَانًا', #9
u'وعميس': u'وَعُمَيْس', #1
u'وعناج': u'وَعِنَاجُ', #1
u'وعنباء': u'وَعِنَبَاءُ', #1
u'وعنبسة': u'وعَنْبَسَةَ', #1
u'وعنبسة': u'وَعَنْبَسَة', #1
u'وعنبسة،': u'وَعَنْبَسَةُ،', #1
u'وعنبسة،': u'وعنبسة،', #2
u'وعنبسة': u'وَعَنْبَسَةَ', #4
u'وعنبسة': u'وَعَنْبَسَةُ', #5
u'وعنة': u'وَعُنَّةِ', #1
u'وعنة': u'وَعُنَّةٍ', #25
u'وعنة': u'وَعُنَّةٌ', #4
u'وعنجدة': u'وَعُنْجُدَةُ', #2
u'وعنجها': u'وَعَنَجَها', #1
u'وعند': u'وَعِنْدً', #1
u'وعندى': u'وَعِنْدِى', #37
u'وعنزروت': u'وَعَنْزَرُوتٍ', #1
u'وعنونا': u'وَعُنُونًا', #1
u'وعنوية': u'وَعَنْوِيَّةٍ', #1
u'وعنيزة': u'وَعُنَيْزَةُ', #1
u'وعنيزة': u'وَعُنَيْزَةَ', #2
u'وعنيزتين': u'وَعُنَيْزَتَيْنِ', #1
u'وعنينا': u'وَعِنِّينًا', #3
u'وعهديته': u'وَعَهْدِيَّتُهُ', #1
u'وعهديتها': u'وَعَهْدِيَّتُهَا', #1
u'وعوارضا': u'وَعَوَارِضَا', #1
u'وعواره': u'وَعَوَارِهِ', #1
u'وعواره': u'وَعَوَارَهُ', #4
u'وعواصة': u'وَعَوَاصَةِ', #1
u'وعواميد': u'وَعَوَامِيدَ', #1
u'وعوانة': u'وَعَوَانَةَ', #2
u'وعوضونى': u'وَعَوَّضُونِى', #1
u'وعوطط': u'وَعُوطَطٌ', #1
u'وعولات': u'وَعَوْلَاتٍ', #1
u'وعولات': u'وَعَوْلَاتِ', #1
u'وعويم': u'وعُوَيْم', #1
u'وعويم': u'وَعُوَيْمِ', #1
u'وعويم': u'وَعُوَيْمُ', #11
u'وعويم': u'وعويم', #2
u'وعياب': u'وَعَيَّابٌ', #1
u'وعياد': u'وَعَيّادٍ', #2
u'وعيارة': u'وَعِيَارَةُ', #1
u'وعياش': u'وَعَيّاشٌ', #1
u'وعياش،': u'وَعَيَّاشٌ،', #1
u'وعياش': u'وَعَيَّاشُ', #13
u'وعياش': u'وَعَيّاشُ', #16
u'وعياش': u'وعياش', #2
u'وعياش': u'وَعَيّاشٍ', #2
u'وعياش': u'وَعَيّاشَ', #2
u'وعياش': u'وَعَيّاشِ', #2
u'وعياش': u'وَعَيَّاشٌ', #2
u'وعياش': u'وَعَيَّاشٍ', #2
u'وعياش': u'وَعَيَّاشِ', #2
u'وعياش': u'وَعَيَّاشَ', #25
u'وعياض': u'وَعِيَاضَ', #1
u'وعياض': u'وعياض', #2
u'وعياض': u'وَعِيَاض', #2
u'وعياض': u'وَعِيَاضِ', #3
u'وعياض': u'وَعِيَاضٍ', #47
u'وعياض': u'وَعِيَاضٌ', #67
u'وعياض': u'وَعِيَاضُ', #9
u'وعياضا': u'وَعِيَاضًا', #2
u'وعيالاتهم': u'وَعِيَالَاتِهِمْ', #2
u'وعيالمه': u'وَعَيَالِمُهُ', #1
u'وعيالى': u'وَعِيَالِى', #2
u'وعيبتى': u'وَعَيْبَتِى', #2
u'وعيثوم': u'وَعَيْثُوم', #1
u'وعيدانة': u'وَعَيْدَانَةٌ', #1
u'وعيرة': u'وُعَيْرَةَ', #1
u'وعيشوم': u'وَعَيْشُوم', #1
u'وعيطل': u'وَعَيْطَلَ', #1
u'وعيلم': u'وَعَيْلَم', #1
u'وعيير': u'وَعُيَيْرٌ', #1
u'وعيير': u'وَعُيَيْرُ', #1
u'وعيينة': u'وَعُيَيْنَة', #1
u'وعيينة': u'وَعُيَيْنَةِ', #2
u'وعيينة،': u'وَعُيَيْنَةَ،', #2
u'وعيينة': u'وَعُيَيْنَةُ', #27
u'وعيينة': u'وَعُيَيْنَةَ', #30
u'وغ': u'وغ', #1
u'وغافصه': u'وَغَافَصَهُ', #1
u'وغامد': u'وَغَامِدٌ', #1
u'وغامد': u'وَغَامِدٍ', #1
u'وغبروا': u'وَغَبَّرُوا', #1
u'وغبطه': u'وَغَبَطَهُ', #1
u'وغبنوا': u'وَغَبِنُوا', #1
u'وغبنوا': u'وَغُبِنُوا', #4
u'وغبوقا': u'وَغَبُوقًا', #1
u'وغبوقها': u'وَغَبُوقَهَا', #2
u'وغبوقها': u'وَغَبُوقِهَا', #2
u'وغبيراء': u'وَغُبَيْرَاءَ', #1
u'وغته': u'وَغَتَّهُ', #1
u'وغداف': u'وَغُدَافٌ', #1
u'وغداف': u'وَغُدَافٍ', #2
u'وغدراتك': u'وَغُدَرَاتَكَ', #1
u'وغدراتي': u'وَغُدْرَاتِي', #1
u'وغدراتي': u'وَغَدَرَاتِي', #3
u'وغديقة': u'وَغُدَيْقَةٌ', #2
u'وغرثان': u'وَغَرْثَانٍ', #1
u'وغرثان': u'وَغَرْثَانَ', #4
u'وغرثهم': u'وَغَرْثُهُمْ', #2
u'وغرسة': u'وَغَرْسَةِ', #1
u'وغرقد': u'وَغَرْقَدٌ', #1
u'وغرقد': u'وَغَرْقَدُ', #2
u'وغروسها': u'وَغُرُوسِهَا', #1
u'وغزرها': u'وَغَزْرِهَا', #1
u'وغزى': u'وَغُزًّى', #1
u'وغشوشهم': u'وَغُشُوشَهُمْ', #1
u'وغشوشهم': u'وَغُشُوشِهِمْ', #1
u'وغضيف': u'وَغُضَيْفِ', #1
u'وغفرلنا': u'وَغَفَرَلَنَا', #1
u'وغلمانى': u'وَغِلْمَانِى', #2
u'وغمدت': u'وَغَمَدْتَ', #1
u'وغمطوا': u'وَغَمَطُوا', #1
u'وغمغمه': u'وَغَمْغَمَهْ', #1
u'وغموس': u'وَغَمُوسٍ', #2
u'وغموس': u'وَغَمُوسٌ', #7
u'وغموسه': u'وَغَمُوسُهُ', #1
u'وغمى': u'وَغَمَى', #1
u'وغميت': u'وَغُمِيَتْ', #2
u'وغميس': u'وَغَمِيسِ', #1
u'وغنثر': u'وَغُنْثَرُ', #1
u'وغنجار': u'وَغُنْجَارُ', #1
u'وغنمانا': u'وَغُنْمَانًا', #2
u'وغوطة': u'وَغُوطَةِ', #1
u'وغويرها': u'وَغُوَيْرَهَا', #1
u'وغويصا': u'وَغَوِيصًا', #1
u'وغيان': u'وَغَيَّانٌ', #1
u'وغياه': u'وَغَيَّاهُ', #1
u'وغياها': u'وَغَيَّاهَا', #3
u'وغيرهاوإني': u'وَغَيْرُهَاوَإِنِّي', #1
u'وغيغ': u'وَغَيْغِ', #1
u'وفاءوا': u'وَفَاءُوا', #1
u'وفأتوا': u'وَفَأْتُوا', #1
u'وفاثور': u'وَفَاثُورٌ', #1
u'وفاثورية': u'وَفَاثُورِيّةٌ', #1
u'وفاختة': u'وَفَاخِتَةُ', #1
u'وفاختة': u'وَفَاخِتَةَ', #2
u'وفارج': u'وَفَارِجَ', #1
u'وفأسى': u'وَفَأْسِى', #1
u'وفأصغى': u'وَفَأَصْغَى', #1
u'وفاظ': u'وَفَاظَ', #1
u'وفأفاء': u'وَفَأْفَاءٌ', #1
u'وفالحديث': u'وَفالْحَدِيثُ', #1
u'وفالغ': u'وَفَالِغٌ', #1
u'وفالله': u'وَفَاللَّهِ', #1
u'وفإن': u'وفَإِنَّ', #1
u'وفإني': u'وَفَإِنِّي', #1
u'وفانيد': u'وَفَانِيدَ', #1
u'وفانيد': u'وَفَانِيدٍ', #6
u'وفانيدا': u'وَفَانِيدًا', #1
u'وفانيذ': u'وَفَانِيذٍ', #2
u'وفانيذا': u'وَفَانِيذًا', #1
u'وفاوت': u'وَفَاوَتَ', #5
u'وفاوتا': u'وَفَاوَتَا', #1
u'وفائد': u'وَفَائِد', #1
u'وفائله': u'وَفَائِلُهُ', #1
u'وفتاتى': u'وَفَتَاتِى', #1
u'وفتاق': u'وَفَتّاقُ', #1
u'وفتاى': u'وَفَتَاىَ', #1
u'وفتخ': u'وَفَتَخٌ', #1
u'وفتخ': u'وَفَتَخَ', #4
u'وفتفت': u'وفتفت', #1
u'وفتم': u'وَفُتُّمْ', #1
u'وفتمارى': u'وَفَتَمَارَى', #1
u'وفتوى': u'وَفَتْوًى', #1
u'وفجرات': u'وَفَجَرَاتٌ', #1
u'وفجرات': u'وَفَجَرَاتٍ', #1
u'وفجراتك': u'وَفَجَرَاتُكَ', #1
u'وفجراتك': u'وَفَجْرَاتَكَ', #1
u'وفجراتي': u'وَفَجْرَاتِي', #1
u'وفجراتي': u'وَفَجَرَاتِي', #3
u'وفجئه': u'وَفَجِئَهُ', #2
u'وفحشياتهم': u'وَفُحْشَيَاتِهِمْ', #1
u'وفخذى': u'وَفَخِذِى', #1
u'وفخرى': u'وَفَخْرَى', #1
u'وفد': u'وَفْدً', #1
u'وفدر': u'وَفُدُرٌ', #1
u'وفراشى': u'وَفِرَاشِى', #1
u'وفرائضيا': u'وَفَرَائِضِيًّا', #3
u'وفرتنة': u'وَفَرْتَنَةَ', #1
u'وفرتنى': u'وَفَرْتَنَى', #1
u'وفرزند': u'وفرزند', #1
u'وفرغانة': u'وَفَرْغَانَةُ', #1
u'وفرغانة،': u'وَفَرْغَانَةَ،', #1
u'وفرغانة': u'وَفَرْغَانَةَ', #3
u'وفرمودش': u'وفرمودش', #1
u'وفروخت': u'وفروخت', #2
u'وفروختم': u'وفروختم', #1
u'وفروعاتها': u'وَفُرُوعَاتِهَا', #1
u'وفريضا': u'وَفَرِيضًا', #3
u'وفزارة': u'وفَزَارَةُ', #1
u'وفزارة': u'وَفَزَارَةَ', #2
u'وفزارة،': u'وَفَزَارَةُ،', #2
u'وفزارة': u'وَفَزَارَةُ', #4
u'وفسحم': u'وَفُسْحُمٌ', #2
u'وفسده': u'وَفَسَّدَهُ', #1
u'وفسوخ': u'وفسوخ', #1
u'وفسوخها': u'وَفُسُوخِهَا', #5
u'وفسودا': u'وَفُسُودًا', #3
u'وفسول': u'وَفُسُولٌ', #1
u'وفسيد': u'وَفَسِيدٌ', #1
u'وفشار': u'وَفَشَارٍ', #1
u'وفشولتها': u'وَفَشْوَلَتِهَا', #1
u'وفشى': u'وَفَشَى', #1
u'وفصادة': u'وَفَصَادَةٌ', #1
u'وفصادة': u'وَفَصَادَةٍ', #1
u'وفصادته': u'وَفَصَادَتِهِ', #1
u'وفصادته': u'وَفِصَادَتُهُ', #1
u'وفصادته': u'وَفَصَادَتُهُ', #2
u'وفصادية': u'وَفَصَادِيَّةٍ', #3
u'وفصولين': u'وَفُصُولَيْنِ', #2
u'وفضوح': u'وفُضُوحِ', #1
u'وفضوح': u'وَفُضُوح', #1
u'وفضيته': u'وَفِضِّيَّتُهُ', #1
u'وفعائل': u'وَفَعَائِلُ', #1
u'وفعلى': u'وَفُعْلَى', #1
u'وفعول': u'وَفَعُول', #1
u'وفعول': u'وَفُعُولُ', #1
u'وفعول': u'وَفَعُولٌ', #2
u'وفعول': u'وَفَعُولٍ', #2
u'وفعيل': u'وَفَعِيلٍ', #1
u'وفعيل': u'وَفَعِيلُ', #1
u'وفعيل': u'وَفَعِيلٌ', #5
u'وفعيلا': u'وَفَعِيلًا', #7
u'وفعيلة': u'وَفَعِيلَةٍ', #1
u'وفعيلة': u'وَفُعَيْلَةٍ', #1
u'وفعيلة': u'وَفَعِيلَةٌ', #3
u'وفقء': u'وَفَقْءَ', #1
u'وفقء': u'وَفَقْءِ', #16
u'وفقء': u'وَفَقْءُ', #6
u'وفقهانا': u'وَفِقْهَانًا', #1
u'وفقهة': u'وَفَقَهَةً', #1
u'وفكيهة': u'وَفُكَيْهَةُ', #2
u'وفلد': u'وَفَلَدَ', #1
u'وفلو': u'وَفَلْو', #1
u'وفلو': u'وَفَلْوٍ', #1
u'وفلو': u'وَفَلْوِ', #1
u'وفلو': u'وَفِلْوٌ', #1
u'وفلو': u'وَفِلْوُ', #2
u'وفلو': u'وَفَلُوُّ', #3
u'وفليح': u'وَفُلَيْحٍ', #1
u'وفليح': u'وَفُلَيْحِ', #3
u'وفليح': u'وَفُلَيْحُ', #4
u'وفليلفظ': u'وَفَلْيَلْفِظْ', #1
u'وفنح': u'وَفَنْحِ', #1
u'وفنحاص': u'وَفِنْحَاصٍ', #1
u'وفنحاص': u'وَفِنْحَاصَ', #1
u'وفنحاص': u'وَفِنْحَاصُ', #2
u'وفندقلي': u'وَفُنْدُقَلِيٌّ', #1
u'وفنى': u'وَفَنَى', #1
u'وفهاب': u'وَفِهَابُ', #1
u'وفهر': u'وَفَهَّرَ', #1
u'وفهر': u'وَفِهْرٌ', #2
u'وفهر': u'وَفِهْرُ', #3
u'وفهور': u'وَفُهُور', #1
u'وفهيرة': u'وَفُهَيْرَةَ', #1
u'وفواطم': u'وَفَوَاطِمَ', #2
u'وفوائت': u'وَفَوَائِتِ', #1
u'وفوريتها': u'وَفَوْرِيَّتُهَا', #4
u'وفؤسهم،': u'وَفُؤُسِهِمْ،', #1
u'وفوقى': u'وَفَوْقِى', #2
u'وفوقيته': u'وَفَوْقِيَّته', #1
u'وفويسقا': u'وَفُوَيْسِقًا', #1
u'وفىء': u'وَفَىْءُ', #1
u'وفئوس': u'وَفُئُوسٍ', #1
u'وفيالعتبية': u'وَفِيالْعُتْبِيَّةِ', #1
u'وفيالمبسوط': u'وَفِيالْمَبْسُوطِ', #1
u'وفيتكه': u'وَفَّيْتُكَهُ', #1
u'وفيج': u'وَفَيْجٍ', #1
u'وفيج': u'وَفَيْجٌ', #3
u'وفيدا': u'وَفَيْدًا', #1
u'وفيروزج': u'وفيروزج', #1
u'وفيروزج': u'وَفَيْرُوزَجَ', #15
u'وفيروزج': u'وَفَيْرُوزَجُ', #2
u'وفيروزج': u'وَفَيْرُوزَجِ', #3
u'وفيعاء': u'وَفَيْعَاءُ', #1
u'وفيعل': u'وَفَيْعَلٌ', #1
u'وفيلبس': u'وَفِيلِبس', #1
u'وفيلبس': u'وَفِيلِبّسُ', #1
u'وفيميون': u'وفَيْمِيون', #2
u'وفيهز': u'وَفِيهِز', #1
u'وفيوء': u'وَفُيُوءٌ', #1
u'وفيوف': u'وَفُيُوفٌ', #1
u'وفيؤه': u'وَفَيْؤُهُ', #7
u'وقاثم': u'وَقَاثِمٍ', #1
u'وقاحا': u'وَقَّاحًا', #1
u'وقاحا': u'وَقَاحًا', #2
u'وقادس': u'وَقَادِسٌ', #1
u'وقاروالوجه': u'وَقَارٌوَالْوَجْهُ', #1
u'وقارؤه': u'وَقَارِؤُهُ', #1
u'وقاسمتوهم': u'وَقَاسَمْتُوهُمْ', #1
u'وقاصأن': u'وَقَّاصٍأَنَّ', #1
u'وقاعدت': u'وَقَاعَدْتُ', #1
u'وقافة': u'وَقَافَةٍ', #1
u'وقالأبو': u'وَقَالَأَبُو', #2
u'وقالعبد': u'وَقَالَعَبْدُ', #1
u'وقالمحمد': u'وَقَالَمُحَمَّدُ', #1
u'وقانف': u'وَقَانِفٍ', #1
u'وقاهث': u'وقاهث', #1
u'وقاواه': u'وَقَاوَاهُ', #1
u'وقاووت': u'وقاووت', #1
u'وقائف': u'وَقَائِفُ', #1
u'وقائف': u'وَقَائِفٌ', #3
u'وقائف': u'وَقَائِفٍ', #3
u'وقايا': u'وَقَايَا', #1
u'وقايش': u'وقايش', #1
u'وقباث': u'وَقَبَاثِ', #1
u'وقبرى': u'وَقَبْرِى', #1
u'وقبقبه': u'وَقَبْقَبِهِ', #1
u'وقبلتنا3902id': u'وقبلتنا3902id', #1
u'وقبيصة،': u'وقبيصة،', #1
u'وقبيصة': u'وقُبَيْصة', #1
u'وقبيصة،': u'وقُبَيصَة،', #1
u'وقبيصة': u'وَقَبِيصَة', #1
u'وقبيصة': u'وَقَبِيصَةً', #1
u'وقبيصة': u'وَقَبِيصَةِ', #1
u'وقبيصة': u'وَقُبَيْصَةُ', #1
u'وقبيصة': u'وَقَبِيصَةَ', #11
u'وقبيصة،': u'وَقَبِيصَةُ،', #11
u'وقبيصة': u'وَقَبِيصَةُ', #26
u'وقت': u'وَقْتً', #1
u'وقتب': u'وَقَتَبِ', #1
u'وقتب': u'وَقَتَبٍ', #3
u'وقتبان': u'وَقِتْبَانُ', #1
u'وقتبه': u'وَقَتَبُهُ', #1
u'وقتبه': u'وَقَتَبِهِ', #1
u'وقتصلاة': u'وَقْتُصَلَاةِ', #1
u'وقتهاالوجه': u'وَقْتِهَاالْوَجْهُ', #1
u'وقتيته': u'وَقْتِيَّتُهُ', #1
u'وقتيرة': u'وقُتَيْرة', #1
u'وقثام': u'وَقَثَام', #2
u'وقثآئها': u'وَقِثَّآئِهَا', #1
u'وقثائها': u'وقثائها', #1
u'وقثائها': u'وَقِثّائِهَا', #2
u'وقثائها': u'وَقِثَّائِهَا', #4
u'وقثم': u'وَقَثْمٌ', #1
u'وقثم': u'وَقَثْمِ', #1
u'وقثم': u'وَقُثْمٌ', #1
u'وقثم': u'وَقُثَمَ', #12
u'وقثم': u'وَقُثَمُ', #14
u'وقثم': u'وقثم', #2
u'وقثم': u'وَقُثَمٌ', #2
u'وقحزا': u'وَقَحْزًا', #1
u'وقحوزا': u'وَقُحُوزًا', #1
u'وقحوط': u'وَقُحُوطٌ', #1
u'وقدأخبرنا': u'وَقَدْأَخْبَرَنَا', #1
u'وقدبقيت': u'وَقَدْبَقِيَتْ', #1
u'وقدوراتها': u'وَقُدُورَاتِهَا', #1
u'وقدوسيته': u'وَقُدُوسِيَّتِهِ', #1
u'وقذرهوذكر': u'وَقَذَّرَهُوَذَكَرَ', #1
u'وقرءان': u'وَقَرْءَانِ', #1
u'وقرءان': u'وَقُرْءَانٍ', #1
u'وقرءان': u'وَقُرْءَانِ', #1
u'وقرءان': u'وَقُرْءَانَ', #2
u'وقرءانقوله': u'وَقُرْءَانِقَوْلُهُ', #1
u'وقرءانه': u'وَقُرْءَانَهُ', #2
u'وقرءوا': u'وَقَرَءُوا', #4
u'وقرءوه': u'وَقَرَءُوهُ', #1
u'وقرءوها': u'وَقَرَءُوهَا', #2
u'وقراءتى': u'وَقِرَاءَتِى', #1
u'وقرابتى': u'وَقَرَابَتِى', #1
u'وقرافة': u'وَقَرَافَةِ', #2
u'وقراوى': u'وَقَرَاوَى', #1
u'وقرائتهن': u'وَقِرَائَتِهِنَّ', #1
u'وقرأين': u'وَقُرْأَيْنِ', #1
u'وقربزان،': u'وَقُرْبُزَانَ،', #1
u'وقربزان،': u'وَقُرْبُزَانُ،', #2
u'وقربيلة': u'وَقَرْبِيلَةٍ', #1
u'وقرثع': u'وَقَرْثَعٍ', #1
u'وقردم': u'وَقَرْدَمُ', #7
u'وقرزل': u'وَقُرْزُلٌ', #1
u'وقرشى': u'وَقُرَشِىٌّ', #1
u'وقرصافة': u'وَقِرْصَافَةُ', #1
u'وقرطبان': u'وَقَرْطَبَانٍ', #1
u'وقرطة': u'وَقِرَطَةٍ', #1
u'وقرطة': u'وَقِرَطَةُ', #1
u'وقرطم': u'وَقُرْطُمٌ', #1
u'وقرطم': u'وَقِرْطِمٍ', #2
u'وقرطم': u'وَقُرْطُمٍ', #6
u'وقرظة': u'وقَرَظَة', #1
u'وقرظة': u'وَقَرَظَةَ', #1
u'وقرفين': u'وَقَرَفَيْنِ', #1
u'وقرمنا': u'وَقَرَمْنَا', #1
u'وقرمود': u'وَقُرْمُودٍ', #1
u'وقرمية': u'وَقَرْمِيَّةٍ', #1
u'وقرنبيط': u'وَقَرْنَبِيط', #1
u'وقريانها': u'وَقُرْيَانُهَا', #1
u'وقريريط': u'وَقُرَيْرِيطٌ', #1
u'وقريس': u'وَقَرِيسٌ', #1
u'وقريط': u'وَقَرِيطٍ', #2
u'وقريط': u'وَقُرَيْطٍ', #2
u'وقريظة': u'وَقُرَيْظَة', #1
u'وقريظة': u'وَقُرَيْظَةِ', #1
u'وقريظة،': u'وَقُرَيْظَةُ،', #1
u'وقريظة': u'وَقُرَيْظَةُ', #17
u'وقريظة،': u'وَقُرَيْظَةَ،', #2
u'وقريظة': u'وَقُرَيْظَةَ', #21
u'وقريع': u'وَقَرِيعَ', #1
u'وقريع': u'وَقَرِيعُ', #3
u'وقريوش': u'وَقِرْيُوشٌ', #1
u'وقزاز': u'وَقَزَازٍ', #1
u'وقزدير': u'وَقَزْدِيرٍ', #2
u'وقزع': u'وَقَزَعٍ', #1
u'وقزع': u'وَقَزْعٍ', #1
u'وقزعة': u'وقزعة', #1
u'وقزعة': u'وَقَزَعَةُ', #1
u'وقزيح': u'وَقَزِيحٌ', #1
u'وقسطنطين': u'وَقُسْطَنْطِين', #1
u'وقسميل': u'وَقِسْمِيلُ', #4
u'وقسيط': u'وَقُسَيْطٌ', #1
u'وقشير': u'وقشير', #1
u'وقشير': u'وَقُشَيْرُ', #1
u'وقصودهم': u'وَقُصُودِهِمْ', #2
u'وقصيصا': u'وَقَصِيصًا', #1
u'وقضاب': u'وَقُضَّابٍ', #1
u'وقضاي': u'وَقَضَايَ', #1
u'وقضباء': u'وَقَضْبَاءَ', #1
u'وقطمر': u'وَقِطَمْرٌ', #1
u'وقطوات': u'وَقَطَوَاتٍ', #1
u'وقطوراء': u'وَقَطُورَاءَ', #3
u'وقطوراء': u'وَقَطُورَاءُ', #3
u'وقطيط': u'وَقُطَيْطٌ', #1
u'وقعب': u'وَقَعْبُ', #2
u'وقعب': u'وَقَعْبٌ', #4
u'وقعدد،': u'وقُعْدُد،', #1
u'وقعقاع': u'وَقَعْقَاعٍ', #1
u'وقعنب': u'وقَعْنَب', #1
u'وقعنب': u'وَقَعْنَبٌ', #1
u'وقعنب،': u'وَقَعْنَبُ،', #1
u'وقعيس': u'وَقَعِيسٌ', #1
u'وقعيقعان': u'وقعيقعان', #1
u'وقعيقعان': u'وَقُعَيْقِعَانَ', #2
u'وقعيقعان': u'وَقُعَيْقِعَانُ', #2
u'وقعين': u'وَقُعَيْنُ', #1
u'وقغ': u'وقغ', #1
u'وقفاف': u'وَقِفَافٍ', #1
u'وقفانا': u'وَقِفَّانًا', #1
u'وقفتنى': u'وَقَفَتْنِى', #1
u'وقفجاقي': u'وَقَفْجَاقِيِّ', #1
u'وقفجاقي': u'وَقُفْجَاقِيٍّ', #1
u'وقفجاقي': u'وَقَفْجَاقِيٍّ', #2
u'وقفزان': u'وَقُفْزَان', #1
u'وقفزان': u'وَقُفْزَانٍ', #1
u'وقفزان': u'وَقُفْزَانُ', #1
u'وقفزان': u'وَقُفْزَانٌ', #2
u'وقفزانا': u'وَقُفْزَانًا', #1
u'وقفصل': u'وَقُفْصُلِ', #1
u'وقففة': u'وَقُفَفَةٍ', #1
u'وقفنامنذ': u'وَقَفْنَامُنْذُ', #1
u'وقفير': u'وَقَفِيرُ', #2
u'وقفيز': u'وَقَفِيزَ', #13
u'وقفيز': u'وَقَفِيزٍ', #16
u'وقفيز': u'وَقَفِيزُ', #16
u'وقفيز': u'وَقَفِيزٌ', #9
u'وقفيز': u'وَقَفِيزِ', #9
u'وقفيزا': u'وَقَفِيزًا', #22
u'وقفيزان': u'وَقَفِيزَانِ', #3
u'وقفيزاه': u'وقفيزاه', #1
u'وقفيزها': u'وَقَفِيزَهَا', #2
u'وقفيزين': u'وَقَفِيزَيْنِ', #5
u'وقلابة': u'وَقِلَابَةُ', #2
u'وقلاقة': u'وَقَلَاقَةً', #1
u'وقلاقة': u'وَقَلَاقَةٌ', #2
u'وقلائص': u'وَقَلَائِصُ', #1
u'وقلعم': u'وَقِلْعَمٌ', #1
u'وقلقيليا': u'وَقَلْقِيلِيَا', #1
u'وقليبها': u'وَقَلِيبِهَا', #1
u'وقليوبي': u'وَقَلْيُوبِيٍّ', #1
u'وقليوبي': u'وَقَلْيُوبِيٌّ', #25
u'وقماركنم': u'وقماركنم', #1
u'وقمك': u'وَقْمِك', #1
u'وقمير': u'وَقُمَيْرٌ', #1
u'وقنبر': u'وَقَنْبَرَ', #1
u'وقند': u'وَقَنْدٍ', #10
u'وقنسرين': u'وَقِنّسْرِينَ', #1
u'وقنسرين': u'وَقِنَّسْرِينَ', #2
u'وقهاب': u'وَقَهَابُ', #1
u'وقهاث': u'وَقِهَاثٌ', #1
u'وقهستاني': u'وَقُهُسْتَانِيُّ', #2
u'وقهستاني': u'وَقُهُسْتَانِيٌّ', #6
u'وقهقة': u'وَقَهْقَةٌ', #1
u'وقوادح': u'وَقَوَادِحُ', #1
u'وقوادح': u'وَقَوَادِحِ', #1
u'وقوارة': u'وَقُوَارَةً', #1
u'وقواسة': u'وَقَوَّاسَةٍ', #1
u'وقواسه': u'وَقَوَّاسِهِ', #1
u'وقوتى': u'وَقُوتِى', #1
u'وقوصرة': u'وَقَوْصَرَةَ', #1
u'وقوصرة': u'وَقَوْصَرَّةٍ', #1
u'وقوصرة': u'وَقَوْصَرَّةُ', #1
u'وقوصرة': u'وَقَوْصَرَّةِ', #1
u'وقوصرة': u'وَقَوْصَرَةٍ', #2
u'وقوطان': u'وَقَوْطَانِ', #1
u'وقولنج': u'وَقُولَنْجُ', #1
u'وقولنج': u'وَقُولَنْجِ', #6
u'وقولنجا': u'وَقَولَنْجًا', #1
u'وقولهافسلمت': u'وَقَوْلُهَافَسَلَّمْتُ', #1
u'وقولى': u'وَقُولِى', #8
u'وقومس،': u'وَقَوْمَس،', #1
u'وقونس': u'وَقَوْنَسُ', #2
u'وقياتة': u'وَقِيَاتَة', #1
u'وقيار': u'وَقَيَّارٌ', #2
u'وقيب': u'وَقِيبُ', #1
u'وقية': u'وَقِيَّةَ', #1
u'وقية': u'وَقِيَّةُ', #1
u'وقية': u'وُقِيَّةٍ', #1
u'وقية': u'وَقِيَّةٍ', #2
u'وقية': u'وَقِيَّةً', #3
u'وقية': u'وُقِيَّةٌ', #3
u'وقية،': u'وُقِيَّةً،', #3
u'وقية': u'وَقِيَّةٌ', #5
u'وقية': u'وُقِيَّةً', #7
u'وقيتين': u'وُقِيَّتَيْنِ', #1
u'وقيدر': u'وقيدر', #1
u'وقيذ': u'وَقِيذ', #2
u'وقيذ': u'وَقِيذٌ', #26
u'وقيذ،': u'وَقِيذٌ،', #5
u'وقيذا': u'وَقِيذًا', #1
u'وقيذر': u'وقَيْذَر', #1
u'وقيذما': u'وقيذما', #1
u'وقيصوم': u'وَقَيْصُومٍ', #6
u'وقيطونا': u'وَقَيْطُونًا', #1
u'وقينقاع': u'وَقَيْنُقَاعُ', #1
u'وقينقاع': u'وَقَيْنُقَاعَ', #3
u'وقيوننا': u'وَقُيُونِنَا', #1
u'وقيؤه': u'وَقَيْؤُهُ', #4
u'وقيؤهم': u'وَقَيْؤُهُمْ', #3
u'وقيؤهما': u'وَقَيْؤُهُمَا', #1
u'وك': u'وك', #10
u'وك': u'وَكَ', #33
u'وكأ': u'وَكَأَ', #1
u'وكا': u'وَكَا', #3
u'وكأبرأتني': u'وَكَأَبْرَأْتَنِي', #1
u'وكأبرأني': u'وَكَأَبْرَأَنِي', #2
u'وكأبيعك': u'وَكَأَبِيعُكَ', #2
u'وكأبيعها': u'وَكَأَبِيعُهَا', #1
u'وكاحصد': u'وَكَاحْصِدْ', #1
u'وكأحلف': u'وَكَأَحْلِفُ', #6
u'وكاخترت': u'وَكَاخْتَرْتُ', #1
u'وكادة': u'وَكَادًة', #1
u'وكادة': u'وَكَادَةُ', #1
u'وكادة': u'وَكَادَّةً', #1
u'وكادة': u'وِكَادَةُ', #1
u'وكادة': u'وَكَادَةً', #22
u'وكادة': u'وَكَادَةِ', #3
u'وكادة': u'وِكَادَةً', #8
u'وكأرت': u'وَكَأَرَتَّ', #1
u'وكأرحبية': u'وَكَأَرْحَبِيَّةٍ', #1
u'وكإردب': u'وَكَإِرْدَبِّ', #3
u'وكأرش': u'وَكَأَرْشِ', #4
u'وكارع': u'وَكَارِعٍ', #3
u'وكاركب': u'وَكَارْكَبْ', #1
u'وكاروان': u'وكاروان', #1
u'وكاز': u'وَكَازٍ', #1
u'وكازرندانست': u'وكازرندانست', #1
u'وكاستأجرتك': u'وكَاسْتَأْجَرْتُك', #3
u'وكاستجمار': u'وَكَاسْتِجْمَارٍ', #1
u'وكاستحاضة': u'وَكَاسْتِحَاضَةٍ', #1
u'وكإسرار': u'وَكَإِسْرَارٍ', #1
u'وكاشانة': u'وكاشانة', #1
u'وكاشتر': u'وَكَاشْتَرِ', #1
u'وكأشتري': u'وَكَأَشْتَرِي', #2
u'وكاشترينا': u'وَكَاشْتَرَيْنَا', #1
u'وكأشركتك': u'وَكَأَشْرَكْتُك', #1
u'وكاشغر': u'وَكَاشْغَرْ', #1
u'وكأعتقه': u'وَكَأَعْتِقْهُ', #4
u'وكأعتقوا': u'وَكَأَعْتِقُوا', #1
u'وكأعطوا': u'وَكَأَعْطُوا', #3
u'وكاعم': u'وَكَاعَمَ', #2
u'وكافورة': u'وَكَافُورَةٍ', #1
u'وكاقتضاض': u'وَكَاقْتِضَاضِ', #2
u'وكأقررت': u'وَكَأَقْرَرْتُ', #2
u'وكاكي': u'وَكَاكِيٌّ', #4
u'وكالإباق': u'وَكَالْإِبَاقِ', #1
u'وكالأرحبية': u'وكالأرحبية', #1
u'وكالاستنجاء': u'وَكَالِاسْتِنْجَاءِ', #1
u'وكالأشنان': u'وَكَالْأُشْنَانِ', #1
u'وكالأعدلية': u'وكالأعدلية', #1
u'وكالأقط': u'وَكَالْأَقِطِ', #2
u'وكالإمناء': u'وَكَالْإِمْنَاءِ', #2
u'وكالبز': u'وَكَالْبَزِّ', #1
u'وكالبزاغ': u'وَكَالْبَزَّاغِ', #4
u'وكالتالف': u'وَكَالتَّالِفِ', #1
u'وكالتبيع': u'وَكَالتَّبِيعِ', #3
u'وكالثمان': u'وَكَالثَّمَانِ', #1
u'وكالجحفة': u'وَكَالْجُحْفَةِ', #1
u'وكالجدك': u'وَكَالْجَدَكِ', #1
u'وكالدبران': u'وَكَالدَّبَرَانِ', #1
u'وكالدعج': u'وَكَالدَّعَجِ', #6
u'وكالسابرية': u'وكالسابرية', #1
u'وكالسابرية': u'وَكَالسَّابِرِيَّة', #1
u'وكالسمندل': u'وَكَالسَّمَنْدَلِ', #1
u'وكالسميهي': u'وَكَالسُّمَيْهِيِّ', #1
u'وكالصيال': u'وَكَالصِّيَالِ', #1
u'وكالعاصوي': u'وَكَالْعَاصُوِي', #1
u'وكالعباره': u'وَكَالْعِبَارَهْ', #1
u'وكالعضب': u'وَكَالْعَضْبِ', #1
u'وكالفسوخ': u'وَكَالْفُسُوخِ', #2
u'وكالقتب': u'وَكَالْقَتَبِ', #2
u'وكالكيالين': u'وَكَالْكَيَّالِينَ', #1
u'وكالمازري': u'وَكَالْمَازِرِيِّ', #1
u'وكالمبعض': u'وَكَالْمُبَعَّضِ', #1
u'وكالمجبوب': u'وَكَالْمَجْبُوبِ', #1
u'وكالمجموعتي': u'وَكَالْمَجْمُوعَتِي', #1
u'وكالمحصر': u'وَكَالْمُحْصَرِ', #2
u'وكالمختلعة': u'وَكَالْمُخْتَلِعَةِ', #2
u'وكالمذي': u'وَكَالْمَذْيِ', #2
u'وكالمزابنة': u'وَكَالْمُزَابَنَةِ', #2
u'وكالمستجمر': u'وَكَالْمُسْتَجْمَرِ', #1
u'وكالمستحاضة': u'وَكَالْمُسْتَحَاضَةِ', #1
u'وكالمستمني': u'وَكَالْمُسْتَمْنِي', #3
u'وكالمشترى': u'وَكَالْمُشْتَرَى', #1
u'وكالمنفردي': u'وَكَالْمُنْفَرِدَيْ', #1
u'وكالمنهوم': u'وَكَالْمَنْهُومِ', #1
u'وكالمهايأة': u'وَكَالْمُهَايَأَةِ', #3
u'وكالموطوءة': u'وَكَالْمَوْطُوءَةِ', #3
u'وكالمؤنة': u'وَكَالْمُؤْنَةِ', #2
u'وكالنجش': u'وَكَالنَّجْشِ', #7
u'وكالنط': u'وَكَالنَّطِّ', #1
u'وكالنطرون': u'وَكَالنُّطْرُونِ', #1
u'وكالنيك': u'وَكَالنَّيْكِ', #1
u'وكالوصايات': u'وَكَالْوِصَايَاتِ', #1
u'وكالولا': u'وَكَالْوِلَا', #1
u'وكإلى': u'وَكَإِلَى', #3
u'وكالئ': u'وَكَالِئٍ', #3
u'وكالئه': u'وَكَالَئَهُ', #1
u'وكامعه': u'وَكَامَعَهُ', #1
u'وكأنت': u'وَكَأَنْتَ', #4
u'وكأنت': u'وَكَأَنْتِ', #5
u'وكأنتم': u'وَكَأَنْتُمْ', #1
u'وكانقضا': u'وَكَانْقِضَا', #1
u'وكأنى': u'وَكَأَنِّى', #5
u'وكانية': u'وَكَانِيَةٌ', #6
u'وكأها': u'وَكَأَهَا', #1
u'وكاهي': u'وكاهي', #1
u'وكأوصيت': u'وَكَأَوْصَيْتُ', #1
u'وكبريائى': u'وَكِبْرِيَائِى', #2
u'وكبع': u'وَكَبِعْ', #1
u'وكبعتك': u'وَكَبِعْتُكَ', #1
u'وكبعتكها': u'وَكَبِعْتُكَهَا', #1
u'وكبعه': u'وَكَبِعْهُ', #2
u'وكبلاص': u'وَكَبَلَّاصِ', #1
u'وكبئونه': u'وَكَبَئُونَهْ', #1
u'وكبيس': u'وَكَبِيسٍ', #1
u'وكتأذي': u'وَكَتَأَذِّي', #1
u'وكتبوئتها': u'وَكَتَبْوِئَتِهَا', #1
u'وكتبيع': u'وَكَتَبِيعٍ', #2
u'وكتصدقت': u'وَكَتَصَدَّقْتُ', #2
u'وكتع': u'وَكَتْعٍ', #1
u'وكتعاء': u'وَكَتْعَاءَ', #1
u'وكتفى': u'وَكَتِفِى', #2
u'وكتملكت': u'وَكَتَمَلَّكْتُ', #2
u'وكثندوتي': u'وَكَثُنْدُوَتَيْ', #1
u'وكثير': u'وَكَثِيرً', #1
u'وكجعالة': u'وَكَجَعَالَةٍ', #1
u'وكجعلته': u'وَكَجَعَلْتُهُ', #2
u'وكخيبر': u'وَكَخَيْبَرِ', #2
u'وكذ': u'وَكَذَ', #1
u'وكذارواهالدستوائي،': u'وَكَذَارَوَاهُالدَّسْتُوَائِيُّ،', #1
u'وكذافأدركهم،': u'وَكَذَافَأَدْرَكَهُمْ،', #1
u'وكذافكان': u'وَكَذَافَكَانَ', #1
u'وكذبانو': u'وكذبانو', #1
u'وكذشت': u'وكذشت', #1
u'وكذى': u'وَكَذَى', #1
u'وكرازين': u'وَكَرَازِينَ', #1
u'وكرائض': u'وَكَرَائِضٍ', #1
u'وكرباس': u'وَكِرْبَاسٍ', #1
u'وكرحا': u'وَكَرَحَا', #1
u'وكرحى': u'وَكَرَحًى', #1
u'وكردار': u'وَكِرْدَارِ', #3
u'وكردن': u'وكردن', #1
u'وكردوس': u'وَكُرْدُوسٌ', #1
u'وكردوس،': u'وَكُرْدُوسٌ،', #1
u'وكرسنة': u'وَكِرْسِنَّةٍ', #1
u'وكرسوعه': u'وَكُرْسُوعَهُ', #1
u'وكرسوعه': u'وَكُرْسُوعِهِ', #1
u'وكرضا': u'وَكَرِضًا', #1
u'وكركبوا': u'وَكَرَكِبُوا', #1
u'وكرمنى': u'وَكَرَّمَنِى', #1
u'وكزوجني': u'وَكَزَوِّجْنِي', #1
u'وكستيجات': u'وَكُسْتِيجَاتُ', #1
u'وكستيجان': u'وَكُسْتِيجَانِ', #1
u'وكسروان': u'وَكِسْرَوَانَ', #1
u'وكسع': u'وَكَسْعِ', #1
u'وكسكنجيل': u'وكسكنجيل', #1
u'وكسمسمة': u'وَكَسَمْسَمَةٍ', #1
u'وكسمسمة': u'وَكَسِمْسِمَةٍ', #1
u'وكسمى': u'وَكَسُمَى', #1
u'وكسوبا': u'وَكَسُوبًا', #1
u'وكسوباتها': u'وَكَسُوبَاتِهَا', #1
u'وكسوبيا': u'وَكَسُوبْيَا', #1
u'وكشخنه': u'وَكَشْخَنَهُ', #1
u'وكشنح': u'وَكَشَنْحِ', #1
u'وكشئت': u'وَكَشِئْت', #1
u'وكطرو': u'وَكَطُرُوِّ', #8
u'وكطلقت': u'وَكَطَلُقَتْ', #1
u'وكطلقني': u'وَكَطَلِّقْنِي', #1
u'وكظمهمو': u'وَكَظْمِهِمُو', #1
u'وكظئر': u'وَكَظِئْرٍ', #3
u'وكعسبار': u'وَكَعِسْبَارٍ', #1
u'وكعسيب': u'وَكَعَسِيبِ', #7
u'وكعيبة': u'وَكُعَيْبَة', #1
u'وكفء': u'وَكُفْءً', #1
u'وكفاتا': u'وَكِفَاتًا', #1
u'وكفت': u'وَكُفْتً', #1
u'وكفرطيس': u'وكفرطيس', #1
u'وكفنونى': u'وَكَفِّنُونِى', #1
u'وكفوفهن': u'وَكُفُوفِهِنَّ', #1
u'وكقبلت': u'وَكَقَبِلْتُ', #5
u'وكقثا': u'وَكَقِثَّا', #1
u'وكقفيز': u'وَكَقَفِيزٍ', #1
u'وككالئ': u'وَكَكَالِئِ', #1
u'وككالئ': u'وَكَكَالِئٍ', #4
u'وككوم': u'وَكَكَوْمِ', #1
u'وكلاءته': u'وَكِلَاءَتِهِ', #1
u'وكلاباذ': u'وَكِلَابَاذَ', #1
u'وكلدة': u'وَكَلَدَةُ', #1
u'وكلكمو': u'وَكُلُّكُمُو', #1
u'وكلمتى': u'وَكَلِمَتَىِ', #1
u'وكلمنى': u'وَكَلَّمَنِى', #1
u'وكلنى': u'وَكَّلَنِى', #1
u'وكليبة': u'وَكُلَيْبَةٌ', #1
u'وكماة': u'وَكُمَاةِ', #1
u'وكمتى': u'وَكَمَتَى', #1
u'وكمذكى': u'وَكَمُذَكَّى', #1
u'وكمذي': u'وَكَمَذْيٍ', #1
u'وكمرأة': u'وَكَمَرْأَةٍ', #1
u'وكمرانه': u'وَكَمِرَانِهِ', #1
u'وكمرزنجوش': u'وَكَمَرْزَنْجُوشَ', #1
u'وكمزابنة': u'وَكَمُزَابَنَةٍ', #3
u'وكمزابنة': u'وَكَمُزَابَنَةِ', #4
u'وكمستبرأة': u'وَكَمُسْتَبْرَأَةٍ', #6
u'وكمستوهبها': u'وَكَمُسْتَوْهَبِهَا', #1
u'وكمشتراة': u'وَكَمُشْتَرَاةِ', #1
u'وكمشتراة': u'وَكَمُشْتَرَاةٍ', #6
u'وكممة': u'وَكَمِمَةٌ', #1
u'وكموطوءة': u'وَكَمَوْطُوءَةٍ', #1
u'وكمؤنة': u'وَكَمُؤْنَةِ', #3
u'وكميمثرية': u'وكميمثرية', #1
u'وكندة': u'وَكِنْدَةَ', #1
u'وكندة': u'وَكِنْدَةُ', #10
u'وكندس': u'وَكَنَدُسٍ', #1
u'وكنوت': u'وَكَنَوْت', #1
u'وكنوت': u'وَكَنَوْتُ', #5
u'وكوارات': u'وَكَوَّارَاتُ', #1
u'وكوارة': u'وَكِوَارَةٌ', #1
u'وكوثى': u'وَكُوثَى', #1
u'وكوذين': u'وَكُوذَيْنِ', #1
u'وكوزتبه': u'وكوزتبه', #1
u'وكوسيند': u'وكوسيند', #1
u'وكى': u'وُكِىَ', #1
u'وكيدة': u'وَكِيدَةً', #1
u'وكيدة': u'وَكِيدَةٍ', #1
u'وكيدة': u'وَكَيْدَةٍ', #1
u'وكيدة': u'وَكِيدَةٌ', #3
u'وكيزان': u'وَكِيزَانٍ', #1
u'وكيزانا': u'وَكِيزَانًا', #2
u'وكيزانه': u'وَكِيزَانُهُ', #5
u'وكيع': u'وَكيِعٌ', #1
u'وكيع،': u'وَكيِعٍ،', #1
u'وكيع،': u'َوَكِيعٍ،', #1
u'وكيع،': u'وكيع،', #135
u'وكيع': u'وَكيِعٍ', #2
u'وكيع،': u'وَكِيع،', #2
u'وكيع': u'وَكِيع', #20
u'وكيع': u'وَكِيعٌ', #2914
u'وكيع،': u'وَكِيعٍ،', #347
u'وكيع': u'وكيع', #35
u'وكيع': u'وَكِيعٍ', #381
u'وكيع': u'وَكِيعِ', #44
u'وكيع': u'وَكِيعَ', #7
u'وكيع،': u'وَكِيعٌ،', #770
u'وكيع': u'وَكِيعُ', #84
u'وكيعا': u'وَكِيعًا', #10
u'وكيعا،': u'وَكِيعًا،', #2
u'وكيع،وعبد': u'وَكِيعٌ،وَعَبْدُ', #1
u'وكيلجة،': u'وكيلجة،', #1
u'وكيلون': u'وَكِيلُونٍ', #2
u'وكيلى': u'وَكِيلِى', #2
u'وكيمانا': u'وَكِيمَانًا', #1
u'ول': u'وَلً', #1
u'ولاءان': u'وَلَاءَانِ', #1
u'ولاءتها': u'وِلَاءَتِهَا', #1
u'ولاإضرار': u'وَلاَإِضِرَارَ', #2
u'ولإباق': u'وَلِإِبَاقٍ', #1
u'ولإبن': u'وَلإِبْنِ', #12
u'ولابنى': u'وَلاِبْنَىْ', #1
u'ولإبي': u'وَلإِبِي', #28
u'ولاتحاسدوا': u'وَلاَتَحَاسَدُوا', #1
u'ولاتخلق': u'ولاتخلق', #1
u'ولأتمحلن': u'وَلأَتَمَحَّلَنَّ', #1
u'ولأتمحلن': u'وَلَأَتَمَحَّلَنَّ', #1
u'ولاتملك': u'ولاتملك', #1
u'ولاجا': u'وَلّاجًا', #1
u'ولاجا': u'وَلَّاجًا', #2
u'ولاجة': u'وَلاجَةٍ', #1
u'ولاجر': u'وَلاجْرُ', #2
u'ولاجين': u'وَلَاجِينٍ', #1
u'ولاجين': u'وَلَاجِينَ', #1
u'ولاجين': u'وَلَاجِينُ', #1
u'ولاحديثه': u'وَلاحَدِيثَهُ', #1
u'ولإحمد،': u'وَلإِحْمَدَ،', #1
u'ولإحمد': u'وَلإِحْمَدَ', #4
u'ولأحيحة': u'وَلِأُحَيْحَةَ', #1
u'ولاخسوف': u'وَلَاخُسُوفٍ', #1
u'ولادا': u'وَلَّادًا', #2
u'ولادا': u'وِلَادًا', #25
u'ولادهان': u'وَلِادِّهَانِ', #1
u'ولأرقلت': u'وَلَأَرْقَلْتُ', #1
u'ولأسامة': u'وَلأُسَامَةَ', #1
u'ولأسامة': u'وَلِأُسَامَةَ', #4
u'ولاستخباثه': u'وَلِاسْتِخْبَاثِهِ', #2
u'ولاستخباثها': u'وَلِاسْتِخْبَاثِهَا', #2
u'ولاستعراق': u'وَلِاسْتِعْرَاقِ', #1
u'ولاستفراخها': u'وَلِاسْتِفْرَاخِهَا', #2
u'ولاستكفاف': u'وَلِاسْتِكْفَافِ', #1
u'ولأسوأنك': u'وَلَأَسُوأَنَّك', #1
u'ولاشك': u'وَلاشَكَ', #1
u'ولأشيم': u'وَلِأَشْيَمَ', #1
u'ولأشيم': u'وَلِأُشَيْمٍ', #1
u'ولأصحابى': u'وَلأَصْحَابِى', #2
u'ولاضطراد': u'وَلِاضْطِرَادِ', #1
u'ولإطراد': u'وَلِإِطْرَادِ', #1
u'ولاعتلاف': u'وَلِاعْتِلَافٍ', #1
u'ولأعمى': u'وَلِأَعْمًى', #1
u'ولاغنم': u'وَلاَغَنَمٍ', #1
u'ولاقطعتم': u'وَلاَقَطَعْتُمْ', #1
u'ولآكديتها': u'وَلِآكَدِيَّتِهَا', #1
u'ولأمتى': u'وَلأُمَّتِى', #1
u'ولامدفن': u'وَلَامَدْفِنِ', #1
u'ولإنا': u'وَلِإِنَّا', #1
u'ولانفهام': u'وَلِانْفِهَامِ', #1
u'ولانقاتل': u'وَلاَنُقَاتِلُ', #1
u'ولأنكحة': u'وَلِأَنْكِحَةِ', #1
u'ولانى': u'وَلاَّنِى', #4
u'ولانيه': u'وَلَّانِيهِ', #2
u'ولانيه': u'وَلاَّنِيهِ', #2
u'ولاهبة': u'وَلَاهِبَةٍ', #1
u'ولإهل': u'وَلإِهْلِ', #4
u'ولأهلى': u'وَلأَهْلِى', #1
u'ولأواؤها': u'وَلَأْوَاؤُهَا', #1
u'ولأوائها': u'وَلأْوَائِهَا', #2
u'ولأوائها': u'وَلَأْوَائِهَا', #2
u'ولأؤثرنه': u'ولأُؤْثِرَنَّهُ', #1
u'ولاوى': u'وَلاَوِى', #1
u'ولأى': u'وَلأَىْ', #1
u'ولائج': u'وَلَائِجُ', #2
u'ولائى': u'وَلاَئِى', #2
u'ولايت': u'ولايت', #1
u'ولايتى': u'وِلاَيَتِى', #2
u'ولايعرفهن': u'وَلايَعْرِفُهُنَّ', #1
u'ولايكلمنى': u'وَلاَيُكَلِّمُنِى', #1
u'ولبأ': u'وَلِبَأً', #1
u'ولبأ': u'وَلِبَأٌ', #2
u'ولبأ': u'وَلِبَأٍ', #3
u'ولبأ': u'وَلِبَأُ', #4
u'ولبحينة': u'وَلِبُحَيْنَةَ', #3
u'ولبريدة': u'وَلِبُرَيْدَةَ', #1
u'ولتأتنف': u'وَلْتَأْتَنِفْ', #1
u'ولتأدي': u'وَلِتَأَدِّي', #1
u'ولتأديها': u'وَلِتَأَدِّيهَا', #1
u'ولتحتشى': u'وَلْتَحْتَشِى', #1
u'ولتحتشي': u'وَلْتَحْتَشِي', #2
u'ولتستثفر': u'وَلِتَسْتَثْفِرْ', #1
u'ولتستثفر': u'وَلْتَسْتَثْفِرْ', #2
u'ولتستذفر': u'وَلَتَسْتَذْفِرْ', #1
u'ولتستذفر': u'وَلْتَسْتَذْفِرْ', #1
u'ولجبير': u'ولجُبَيْر', #1
u'ولججوا': u'وَلَجَّجُوا', #3
u'ولجذعة': u'وَلِجَذَعَةٍ', #2
u'ولجريب': u'وَلِجَرِيبِ', #7
u'ولجمانة': u'ولِجُمَانَةَ', #1
u'ولجمانة': u'وَلِجُمَانَةِ', #2
u'ولحقنى': u'وَلَحِقَنِى', #1
u'ولحمنة': u'وَلِحَمْنَةَ', #2
u'ولخارص': u'وَلِخَارِصٍ', #1
u'ولخليطة': u'وَلِخَلِيطَةٍ', #1
u'ولخيبر': u'وَلِخَيْبَرِ', #1
u'ولدتيه': u'وَلِدَتَيْهِ', #1
u'ولدتيه': u'وَلَدْتِيهِ', #16
u'ولدهقوله': u'وَلَدُهُقَوْلُهُ', #1
u'ولدهوالوجه': u'وَلَدُهُوَالْوَجْهُ', #1
u'ولديدا': u'وَلَدِيدَا', #1
u'ولديغ': u'وَلَدِيغٍ', #1
u'ولذاعته': u'ولذاعته', #1
u'ولذرارى': u'وَلِذَرَارِىِّ', #1
u'ولذفر': u'وَلِذَفَرٍ', #1
u'ولرتقاء': u'وَلِرَتْقَاءَ', #1
u'ولرحى': u'وَلِرَحًى', #1
u'ولسحنون': u'وَلِسَحْنُونٍ', #23
u'ولسودة': u'وَلِسَوْدَةِ', #1
u'ولسون': u'ولسون', #1
u'ولشأنى': u'وَلَشَأْنِى', #1
u'ولشييم': u'وَلِشُيَيْمٍ', #1
u'ولضباعة': u'وِلِضُبَاعَةَ', #1
u'ولضباعة': u'وَلِضُبَاعَةَ', #2
u'ولضفادي': u'وَلِضَفَادِي', #1
u'ولطبرستان': u'وَلِطَبَرِسْتَان', #1
u'ولطخات': u'وَلَطَخَاتُ', #1
u'ولطعاء': u'وَلَطْعَاءُ', #2
u'ولطيم': u'وَلَطِيمٌ', #1
u'ولطيمة': u'وَلَطِيمَةِ', #1
u'ولطيمة': u'وَلَطِيمَةُ', #2
u'ولظما': u'وَلِظَمَا', #1
u'ولعاتكة': u'وَلِعَاتِكَةِ', #1
u'ولعاعه': u'وَلُعَاعُهُ', #1
u'ولعبدى': u'وَلِعَبْدِى', #15
u'ولعجير': u'وَلِعُجَيْرِ', #2
u'ولعساء': u'وَلَعْسَاءُ', #2
u'ولعل': u'وَلَعَلًّ', #1
u'ولعمرى': u'وَلِعَمْرَى', #1
u'ولعمرى': u'وَلِعَمْرِى', #2
u'ولعمرى': u'وَلَعَمْرِى', #3
u'ولعياض': u'وَلِعِيَاضٍ', #2
u'ولعيينة': u'ولعُيَيْنَة', #1
u'ولغية': u'وَلِغَيَّةٍ', #1
u'ولقاة': u'وَلَقَاةً', #1
u'ولقائح': u'وَلَقَائِحُ', #1
u'ولقثم': u'وَلِقُثَمَ', #1
u'ولقينى': u'وَلَقِيَنِى', #1
u'ولكاعة': u'وَلَكَاعَةٍ', #2
u'ولكنخلق': u'ولكنخَلَقَ', #1
u'ولل': u'وَلِل', #1
u'ولل': u'وَلِلْ', #2
u'وللأتقاني': u'وَلِلْأَتْقَانِيِّ', #1
u'وللأثرم': u'وَلِلْأَثْرَمِ', #5
u'وللاثنتين': u'وَلِلِاثْنَتَيْنِ', #6
u'وللاثنين': u'وَلِلْاثْنَيْنِ', #1
u'وللاثنين': u'وَلِلِاثْنَيْنِ', #6
u'وللأجهوري': u'وَلِلْأُجْهُورِيِّ', #1
u'وللاخ': u'وَلِلَاخِّ', #1
u'وللاخت': u'وَلَلَاخَتْ', #1
u'وللأرش': u'وَلِلْأَرْشِ', #1
u'وللاستحاضة': u'وَلِلِاسْتِحَاضَةِ', #2
u'وللاستخباث': u'وَلِلِاسْتِخْبَاثِ', #1
u'وللإسنوي': u'وَلِلْإِسْنَوِيِّ', #3
u'وللأسنى': u'وَلِلْأَسْنَى', #1
u'وللإشفاع': u'وَلِلْإِشْفَاعِ', #1
u'وللإقباض': u'وَلِلْإِقْبَاضِ', #1
u'وللآمدي': u'وَلِلْآمِدِيِّ', #1
u'وللأوفاق': u'وَلِلْأَوْفَاقِ', #1
u'وللآيسة': u'وَلِلْآيِسَةِ', #1
u'وللبرزلي': u'وَلِلْبَرْزَلِيِّ', #2
u'وللبلقيني': u'وَلِلْبْلْقِينِيِّ', #1
u'وللبلقيني': u'وَلِلْبُلْقِينِيِّ', #8
u'وللبهق': u'وَلِلْبَهَقِ', #1
u'وللبيهقي': u'وَلِلْبَيْهَقِيِّ', #28
u'وللتأقيت': u'وَلِلتَّأْقِيتِ', #1
u'وللتحرف': u'وَلِلتَّحَرُّفِ', #1
u'وللترخص': u'وَلِلتَّرَخُّصِ', #1
u'وللتسحر': u'وَلِلتَّسَحُّرِ', #3
u'وللتسليمة': u'وَلِلتَّسْلِيمَةِ', #1
u'وللتسليمتين': u'وَلِلتَّسْلِيمَتَيْنِ', #1
u'وللتى': u'وَلِلَّتِى', #1
u'وللثنتين': u'وَلِلثِّنْتَيْنِ', #23
u'وللجدان': u'وَلِلْجَدَّانِ', #1
u'وللجذعة': u'وَلِلْجَذَعَةِ', #1
u'وللجزولي': u'وَلِلْجُزُولِيِّ', #2
u'وللجلاب': u'وَلِلْجَلَّابِ', #1
u'وللجوزقي': u'وَلِلْجَوْزَقِيِّ', #1
u'وللجويني': u'وَلِلْجُوَيْنِيِّ', #1
u'وللحسين': u'وَلِلْحُسَيْنِ', #1
u'وللخانقاه': u'وَلِلْخَانِقَاهْ', #1
u'وللدارقطني': u'وَلِلدَّارَقُطْنِيِّ', #43
u'وللدارقطني': u'وللدارقطني', #5
u'وللداودي': u'وَلِلدَّاوُدِيِّ', #1
u'وللدبيلي': u'وَلِلدَّبِيلِيِّ', #1
u'وللدميري': u'وَلِلدَّمِيرِيِّ', #2
u'وللدنوشري': u'وللدنوشري', #1
u'وللرصغ': u'وَلِلرُّصْغِ', #2
u'وللرهاويين': u'وَلِلرّهَاوِيّين', #1
u'وللروياني': u'وَلِلرُّويَانِيِّ', #3
u'وللزمخشري': u'وَلِلزَّمَخْشَرِيِ', #1
u'وللزهرى': u'وَلِلزُّهْرِىِّ', #1
u'وللسبائيين': u'وَلِلسّبائِيّينَ', #1
u'وللسبائيين': u'وَلِلسّبَائِيّين', #1
u'وللسكيت': u'وَلِلسُّكَيْتِ', #1
u'وللسمحاق': u'وَلِلسِّمْحَاقِ', #1
u'وللسنوسي': u'وَلِلسُّنُوسِيِّ', #1
u'وللسيوري': u'وَلِلسُّيُورِيِّ', #2
u'وللشرة': u'وَلِلشِّرَّةِ', #1
u'وللشرنبلالي': u'وُلِلشُّرُنْبُلَالِيِّ', #10
u'وللشرنبلالي': u'وَلِلشُّرُنْبُلَالِيِّ', #3
u'وللطبراني': u'ولِلطَّبَرَانِيّ', #1
u'وللطبراني': u'وَلِلطَّبَرَانِيِّ', #29
u'وللطحاوي': u'وَلِلطَّحَاوِيِّ', #5
u'وللطرسوسي': u'وَلِلطَّرَسُوسِيِّ', #3
u'وللطواشي': u'وَلِلطَّوَاشِيِ', #1
u'وللطواشي': u'وَلِلطَّوَاشِيِّ', #1
u'وللطيم': u'وَلِلَّطِيمِ', #1
u'وللظئر': u'وَلِلظِّئْرِ', #1
u'وللغامدية': u'وَلِلْغَامِدِيَّةِ', #1
u'وللفجرين': u'وَلِلْفَجْرَيْنِ', #1
u'وللفسكل': u'وَلِلْفِسْكِلِ', #1
u'وللقائف': u'وَلِلْقَائِفِ', #1
u'وللقرافي': u'وَلِلْقَرَافِيِّ', #8
u'وللقزع': u'وَلِلْقَزَعِ', #2
u'وللقونوي': u'وَلِلْقُونَوِيِّ', #2
u'وللكرخي': u'وَلِلْكَرْخِيِّ', #1
u'وللكوسج': u'وَلِلْكَوْسَجِ', #1
u'وللمازري': u'وَلِلْمَازِرِيِّ', #10
u'وللماوردي': u'وَلِلْمَاوَرْدِيِّ', #1
u'وللمبتوتة': u'وَلِلْمَبْتُوتَةِ', #1
u'وللمبرأ': u'وَلِلْمُبْرَأِ', #2
u'وللمبعض': u'وَلِلْمُبَعَّضِ', #6
u'وللمبعضة': u'وَلِلْمُبَعَّضَةِ', #2
u'وللمتباذلين': u'وَلِلْمُتَبَاذِلَيْنِ', #1
u'وللمتجالة': u'وَلِلْمُتَجَالَّةِ', #1
u'وللمتساومين': u'وَلِلْمُتَسَاوِمَيْنِ', #1
u'وللمتلقى': u'وَلِلْمُتَلَقَّى', #1
u'وللمتيطي': u'وَلِلْمُتَيْطِيِّ', #2
u'وللمجتعل': u'وَلِلْمُجْتَعِلِ', #1
u'وللمجحود': u'وَلِلْمَجْحُودِ', #3
u'وللمجدود': u'وَلِلْمَجْدُودِ', #1
u'وللمحاز': u'وَلِلْمُحَازِ', #2
u'وللمحجوج': u'وَلِلْمَحْجُوجِ', #2
u'وللمحصر': u'وَلِلْمُحْصَرِ', #1
u'وللمخارجة': u'وَلِلْمُخَارَجَةِ', #1
u'وللمختلعة': u'وَلِلْمُخْتَلِعَةِ', #1
u'وللمراة': u'وَلِلْمُرَاةِ', #1
u'وللمرتضعة': u'وَلِلْمُرْتَضِعَةِ', #1
u'وللمستحاضة': u'وَلِلْمُسْتَحَاضَةِ', #4
u'وللمسترضع': u'وَلِلْمُسْتَرْضِعِ', #1
u'وللمستصنع': u'وَلِلْمُسْتَصْنِعِ', #6
u'وللمستعدى': u'وَلِلْمُسْتَعْدَى', #2
u'وللمستقرض': u'وَلِلْمُسْتَقْرِضِ', #3
u'وللمستنيب': u'وَلِلْمُسْتَنِيبِ', #4
u'وللمطموع': u'وَلِلْمَطْمُوعِ', #1
u'وللمقدورية': u'وللمقدورية', #1
u'وللمقضى': u'وَلِلْمُقْضَى', #2
u'وللمنصل': u'وَلِلْمُنْصَلِ', #1
u'وللمنكاب': u'وَلِلْمِنْكَابِ', #1
u'وللمؤاجر': u'وَلِلْمُؤَاجِرِ', #4
u'وللمؤتم': u'وَلِلْمُؤْتَمِّ', #2
u'وللموطوءة': u'وَلِلْمَوْطُوءَةِ', #13
u'وللمؤنة': u'وَلِلْمُؤْنَةِ', #1
u'وللنبى': u'وَلِلنَّبِىِّ', #1
u'ولمالك': u'وَلَمَالِكً', #1
u'ولمانعية': u'وَلِمَانِعِيَّةِ', #1
u'ولمبعض': u'وَلِمُبَعَّضٍ', #5
u'ولمحدة': u'وَلِمُحِدَّةٍ', #1
u'ولمحيصة': u'وَلِمُحَيّصَةَ', #1
u'ولمرأة': u'وَلِمَرْأَةٍ', #2
u'ولمستحاضة': u'وَلِمُسْتَحَاضَةٍ', #4
u'ولمطلوبية': u'وَلِمَطْلُوبِيَّةِ', #1
u'ولمظا': u'ولمظا', #1
u'ولمعضوب': u'وَلِمَعْضُوبٍ', #1
u'ولمعيقب': u'وَلِمُعَيْقِبٍ', #1
u'ولمعيقيب': u'وَلِمُعَيْقِيبٍ', #2
u'ولملكو': u'وَلِمَلْكُو', #2
u'ولموطوءة': u'وَلِمَوْطُوءَةٍ', #2
u'ولموطوءته': u'وَلِمَوْطُوءَتِهِ', #1
u'ولنميلة': u'وَلِنُمَيْلَةَ', #3
u'ولنى': u'وَلِّنِى', #1
u'ولهاروت': u'وَلِهَارُوتَ', #1
u'ولهوب': u'وَلُهُوبٌ', #1
u'ولوالجية': u'وَلْوَالَجِيَّة', #1
u'ولوالجية': u'وَلْوَالِجِيَّةُ', #2
u'ولوالجية': u'وَلْوَالْجِيَّةٌ', #6
u'ولوالجية': u'وَلْوَالِجِيَّةٌ', #60
u'ولوالجية': u'وَلْوَالَجِيَّةٌ', #7
u'ولوأن': u'وَلَوَأَنَّ', #1
u'ولوائل': u'وَلِوَائِلِ', #1
u'ولوة': u'وَلُوّةٌ', #1
u'ولوعنة': u'وَلَوْعُنَّةً', #2
u'ولوقدر': u'وَلَوَقُدِرَ', #1
u'ولوكانوا': u'وَلَوَكَانُوا', #1
u'ولؤلو': u'وَلُؤْلُو', #1
u'ولولو': u'وَلُولُو', #1
u'ولؤلؤة': u'وَلُؤْلُؤَةً', #4
u'ولوهائه': u'وَلِوَهَائِهِ', #1
u'ولؤي': u'وَلُؤَيٌّ', #1
u'ولي': u'وَلِيًّ', #1
u'وليأتدموا': u'وَلْيَأْتَدِمُوا', #1
u'وليأتنف': u'وَلْيَأْتَنِفْ', #1
u'وليأتنفا': u'وَلْيَأْتَنِفَا', #1
u'ولياطة': u'وَلِيَاطَةً', #2
u'وليالى': u'وَلَيَالِى', #2
u'وليتبأس': u'وَلْيَتَبَأَّسْ', #1
u'وليتضعف': u'وَلْيَتَضَعَّفْ', #1
u'وليتقسط': u'وَلِيَتَقَسَّطَ', #1
u'وليتكه': u'وَلَّيْتُكَهُ', #16
u'وليتكها،': u'وَلَّيْتُكَهَا،', #1
u'وليتنى': u'وَلَيْتَنِى', #1
u'وليتوطنه': u'وَلِيَتَوَطَّنَهُ', #1
u'وليجق': u'وليجق', #3
u'وليجنأ،': u'وَلْيَجْنَأْ،', #1
u'وليجنأ': u'وَلْيَجْنَأْ', #7
u'وليحنأ': u'وليحنأ', #1
u'وليحيى': u'وَلِيَحْيَى', #4
u'وليدتى': u'وَلِيدَتِى', #1
u'وليرتفق': u'وَلْيَرْتَفِقْ', #1
u'وليستأني': u'وَلْيَسْتَأْنِي', #1
u'وليستخر': u'وَلْيَسْتَخِرْ', #1
u'وليستنثر': u'وَلْيَسْتَنْثِرْ', #1
u'وليستنزه': u'وَلْيَسْتَنْزِهْ', #1
u'وليسئلوا': u'وَلْيَسْئَلُوا', #1
u'وليطة': u'وَلِيطَةٍ', #5
u'وليطة': u'وَلِيطَةِ', #8
u'وليقانا': u'وَلَيَقَانًا', #1
u'وليقة': u'وَلِيقَةَ', #1
u'وليقة': u'وَلَيْقَةَ', #1
u'وليقة': u'وَلَيْقَةُ', #1
u'وليقة': u'وَلَيْقَةِ', #1
u'وليقة': u'وَلِيقَةُ', #2
u'وليقة': u'وَلِيقَةِ', #3
u'وليكونا': u'وَلَيَكُونًا', #2
u'وليكونن': u'وَلَيَكُونَنً', #1
u'وليلتى': u'وَلَيْلَتِى', #1
u'وليلححوا': u'وَلْيُلْحِحُوا', #1
u'وليليت': u'وَلَيْلَيْت', #1
u'ولينوفر': u'وَلَيْنُوفَرٍ', #1
u'ولينوفر': u'وَلَيْنُوفَرُ', #1
u'ولينوفر': u'وَلَيْنَوْفَرٌ', #1
u'ولينوفر': u'وَلَيْنَوْفَرَ', #1
u'وليوشع': u'وَلِيُوشَعَ', #1
u'وليوقا': u'وَلُيُوقًا', #1
u'وليولم': u'وَلْيُولِمْ', #1
u'وليى': u'وَلِيِّىَ', #1
u'وم': u'ومِ', #1
u'وم': u'وَم', #1
u'وم': u'وَمِ', #1
u'وم': u'وْمِ', #1
u'وم': u'وَمَ', #2
u'وم': u'وَمِّ', #20
u'وم': u'وَمُ', #4
u'وم': u'وم', #42
u'ومأبور': u'وَمَأْبُورُ', #2
u'ومأبون': u'وَمَأْبُونٌ', #2
u'ومأبون': u'وَمَأْبُونٍ', #8
u'وماتريدية': u'وَمَاتُرِيدِيَّةٍ', #1
u'وماتع': u'وَمَاتِعٌ', #1
u'وماتعا': u'وَمَاتِعًا', #1
u'وماتكتمون': u'وماتكتمون', #1
u'ومأتي': u'وَمَأْتِيٌّ', #1
u'ومأثوما': u'وَمَأْثُومًا', #1
u'وماجل': u'وَمَاجِلٍ', #1
u'وماجه': u'وَمَاجَهْ', #2
u'ومأجوج': u'وَمأْجُوجُ', #1
u'ومأجوج،': u'وَمَأْجُوجَ،', #1
u'ومأجوج': u'وَمَأْجُوجُ', #18
u'ومأجوج،': u'وَمَأْجُوجُ،', #4
u'ومأجوج،': u'ومأجوج،', #5
u'ومأجوج': u'ومأجوج', #7
u'ومأجوج': u'وَمَأْجُوجَ', #80
u'ومادبا': u'ومادبا', #1
u'ومأدومها': u'وَمَأْدُومِهَا', #2
u'وماذاك': u'وَمَاذَاكَ', #1
u'وماذكر': u'وماذكر', #1
u'وماذياناتها': u'وَمَاذِيَانَاتِهَا', #1
u'ومارب': u'ومارِبُ', #1
u'ومارب': u'وَمَارِبٌ', #1
u'ومأربة': u'وَمَأْرَبَةٌ', #1
u'ومارض': u'وَمَارِضٌ', #1
u'وماروت،': u'وَمَارُوتُ،', #1
u'وماروت': u'وَمَارُوتُ', #14
u'وماروت،': u'وَمَارُوتَ،', #3
u'وماروت': u'وَمَارُوتَ', #46
u'ومازلت': u'وَمَازِلْت', #1
u'ومازلنا': u'وَمَازِلْنَا', #1
u'ومازن': u'ومازن', #1
u'ومازن': u'وَمَازِنٍ', #2
u'ومازه': u'وَمَازَهُ', #1
u'وماصدق': u'وَمَاصَدَقَ', #1
u'وماصدقا': u'وَمَاصَدَقًا', #1
u'وماصدقاته': u'وَمَاصَدَقَاتُهُ', #1
u'وماصدقاتها': u'وَمَاصَدَقَاتِهَا', #1
u'وماصر': u'وَمَاصِر', #1
u'وماصر': u'وَمَاصِرٌ', #1
u'وماصع': u'وَمَاصَعَ', #1
u'وماعزة': u'وَمَاعِزَةٍ', #1
u'وماعزة،': u'وَمَاعِزَةً،', #1
u'وماعزة': u'وَمَاعِزَةٌ', #3
u'ومأقئ': u'وَمَأْقَئٌ', #1
u'ومالك،': u'وَمَالِكً،', #1
u'ومالله': u'وَمَاللَّهِ', #1
u'ومالم': u'وَمَالَمْ', #1
u'ومالى': u'وَمَالِى', #5
u'ومالياSمن': u'وَمَالِيَاSمِنْ', #1
u'ومانعية': u'وَمَانِعِيَّةِ', #1
u'ومانعية': u'وَمَانِعِيَّةُ', #3
u'وماننداين': u'وماننداين', #1
u'وماهان': u'وَمَاهَانُ', #1
u'وماوان': u'وَمَاوَانُ', #1
u'وماوان': u'وَمَاوَانَ', #2
u'ومأي': u'وَمُأَيٌّ', #1
u'ومائتى': u'وَمِائَتَىْ', #4
u'ومائعيته': u'وَمَائِعِيَّتِهِ', #1
u'ومائنه': u'وَمَائِنُهُ', #1
u'ومائى': u'ومائى', #1
u'ومايدريك': u'وَمَايُدْرِيكَ', #1
u'ومأيوس': u'وَمَأْيُوسٌ', #1
u'ومباء': u'وَمَبَاءً', #1
u'ومباذاة': u'وَمُبَاذَاةً', #1
u'ومبارأتها': u'وَمُبَارَأَتِهَا', #1
u'ومباضعة': u'وَمُبَاضَعَةٌ', #1
u'ومباضعة': u'وَمُبَاضَعَةٍ', #2
u'ومباضعة': u'وَمُبَاضَعَةً', #5
u'ومباضعتك': u'وَمُبَاضَعَتُكَ', #2
u'ومبانة': u'وَمُبَانَةً', #1
u'ومبانة': u'وَمُبَانَةٍ', #4
u'ومباين': u'وَمُبَايِنٌ', #2
u'ومباينا': u'وَمُبَايِنًا', #1
u'ومباينة': u'وَمُبَايَنَةَ', #1
u'ومباينة': u'وَمُبَايِنَةً', #1
u'ومباينة': u'وَمُبَايِنَةٌ', #1
u'ومباينة': u'وَمُبَايَنَةِ', #2
u'ومباينة': u'وَمُبَايَنَةُ', #4
u'ومباينته': u'وَمُبَايَنَتِهِ', #2
u'ومباينتها': u'وَمُبَايَنَتِهَا', #2
u'ومبتد': u'وَمُبْتَدٍ', #1
u'ومبتناه': u'وَمُبْتَنَاهُ', #1
u'ومبتوتة': u'وَمَبْتُوتَةُ', #1
u'ومبداد': u'وَمِبْدَادٌ', #1
u'ومبرأ': u'وَمُبَرَّأً', #1
u'ومبرأ': u'وَمُبَرَّأٌ', #1
u'ومبرأ': u'وَمُبْرَأً', #2
u'ومبرسم': u'وَمُبَرْسَمٍ', #11
u'ومبرسم': u'وَمُبَرْسَمٌ', #8
u'ومبرص': u'وَمُبَرَّصٍ', #1
u'ومبركها': u'وَمَبْرَكُهَا', #2
u'ومبرود': u'وَمَبْرُودٌ', #1
u'ومبشا': u'وَمُبِشّا', #1
u'ومبعض': u'وَمُبَعَّضِ', #1
u'ومبعض': u'وَمُبَعَّضٌ', #10
u'ومبعض': u'وَمُبَعَّضٍ', #41
u'ومبعضا': u'وَمُبَعَّضًا', #20
u'ومبعضة': u'وَمُبَعَّضَةٍ', #13
u'ومبعضة': u'وَمُبَعَّضَةٌ', #2
u'ومبعضة': u'وَمُبَعَّضَةً', #4
u'ومبعضه': u'وَمُبَعَّضَهُ', #3
u'ومبعضين': u'وَمُبَعَّضِينَ', #1
u'ومبغوشة': u'وَمَبْغُوشَةٌ', #1
u'ومبقى': u'وَمُبْقًى', #1
u'ومبير': u'وَمُبِيرٌ', #2
u'ومبيرا': u'وَمُبِيرًاُُُُ', #1
u'ومبيرا،': u'وَمُبِيرًا،', #2
u'ومبيرا': u'وَمُبِيرًا', #4
u'ومبيرها': u'وَمُبِيرِهَا', #1
u'ومبيوع': u'وَمَبْيُوعٌ', #1
u'ومتاركة': u'وَمُتَارَكَةِ', #1
u'ومتاركة': u'وَمُتَارَكَةٌ', #2
u'ومتاركته': u'وَمُتَارَكَتِهِ', #1
u'ومتاركته': u'وَمُتَارَكَتَهُ', #5
u'ومتاركتهم': u'وَمُتَارَكَتَهُمْ', #1
u'ومتالع': u'وَمُتَالِعُ', #1
u'ومتبر': u'وَمُتَبَرٍّ', #1
u'ومتجالة': u'وَمُتَجَالَّةٌ', #9
u'ومتجوزا': u'وَمُتَجَوِّزًا', #1
u'ومتجوه': u'وَمُتَجَوِّهٌ', #1
u'ومتحرف': u'وَمُتَحَرِّفٌ', #1
u'ومترمد': u'وَمُتَرَمِّدٍ', #2
u'ومتزرة': u'وَمُتَّزِرَةً', #1
u'ومتزي': u'وَمُتَزَيٍّ', #3
u'ومتزيي': u'وَمُتَزَيِّي', #1
u'ومتسلما': u'وَمُتَسَلَّمًا', #1
u'ومتسلما': u'وَمُتَسَلِّمًا', #9
u'ومتشقشقة': u'وَمُتَشَقْشِقَةُ', #1
u'ومتعضد': u'وَمُتَعَضِّدٌ', #1
u'ومتفاحشه': u'وَمُتَفَاحِشُهُ', #1
u'ومتفاصلة': u'وَمُتَفَاصِلَةُ', #1
u'ومتكا': u'وَمُتَّكًّا', #1
u'ومتكار': u'وَمُتَكَارٍ', #1
u'ومتكاري': u'وَمُتَكَارِي', #1
u'ومتمحضا': u'وَمُتَمَحِّضًا', #3
u'ومتمسخر': u'وَمُتَمَسْخَرٍ', #1
u'ومتمسخر': u'وَمُتَمَسْخِرٍ', #3
u'ومتنطفة': u'وَمُتَنَطّفَةٌ', #1
u'ومتنفرا': u'وَمُتَنَفِّرًا', #1
u'ومتنقط': u'وَمُتَنَقَّطٌ', #2
u'ومتهب': u'وَمُتَّهِبٌ', #1
u'ومتهب': u'وَمُتَّهَبٍ', #2
u'ومتهب': u'وَمُتَّهِبٍ', #6
u'ومتهبط': u'وَمُتَهَبِّطٌ', #1
u'ومتهبها': u'وَمُتَّهِبَهَا', #1
u'ومتهيئ': u'وَمُتَهَيِّئٌ', #1
u'ومتولى': u'ومتولى', #1
u'ومتولى': u'وَمُتَوَلَّى', #1
u'ومتياسر': u'وَمُتَيَاسِرٌ', #1
u'ومتيعه': u'وَمُتَيْعَهُ', #1
u'ومثانين': u'وَمَثَانِينَ', #2
u'ومثدون': u'وَمَثَدُونِ', #1
u'ومثغرة': u'وَمُثْغِرَةٍ', #1
u'ومثلة،': u'وَمُثْلَةً،', #1
u'ومثلة': u'وَمُثْلَةٌ', #2
u'ومثلة': u'وَمُثْلَةٍ', #3
u'ومثلة': u'وَمُثْلَةً', #5
u'ومثلهقوله': u'وَمِثْلَهُقَوْلُهُ', #1
u'ومثمونا': u'وَمَثْمُونًا', #1
u'ومجاحة': u'وَمُجَاحَةً', #1
u'ومجادفها': u'وَمَجَادِفُهَا', #1
u'ومجاشع': u'ومُجاشع', #1
u'ومجاعل': u'وَمُجَاعِلٌ', #1
u'ومجاعلة': u'وَمُجَاعَلَةٍ', #1
u'ومجالد': u'وَمَجَالِد', #1
u'ومجالد': u'وَمُجَالِدُ', #1
u'ومجالد': u'وَمُجَالِدٌ', #16
u'ومجالد': u'وَمُجَالِدٍ', #5
u'ومجالد،': u'وَمُجَالِدٌ،', #5
u'ومجالد،': u'وَمُجَالِدٍ،', #6
u'ومجامير': u'وَمَجَامِيرَ', #1
u'ومجاهد،': u'وَمُجَاهِدً،', #1
u'ومجاولات': u'وَمُجَاوَلَاتٌ', #1
u'ومجبوب': u'وَمَجْبُوبَ', #1
u'ومجبوب': u'وَمَجْبُوبٍ', #19
u'ومجبوب': u'وَمَجْبُوبٌ', #7
u'ومجبوبا': u'وَمَجْبُوبًا', #6
u'ومجثمة': u'وَمُجَثَّمَةٍ', #3
u'ومجثمها': u'وَمَجْثَمُهَا', #1
u'ومجحود': u'وَمَجْحُودٍ', #2
u'ومجدوح': u'وَمَجْدُوح', #1
u'ومجدوح': u'وَمَجْدُوحٌ', #1
u'ومجذم': u'وَمُجْذَمٍ', #1
u'ومجذم': u'وَمُجْذَمٌ', #2
u'ومجذم': u'وَمُجَذَّمٍ', #4
u'ومجذوذ': u'وَمَجْذُوذٌ', #1
u'ومجرودة': u'وَمَجْرُودَةٌ', #1
u'ومجزل': u'وَمُجْزِلِ', #1
u'ومجزى': u'وَمُجْزَى', #1
u'ومجزيون': u'وَمَجْزِيُّونَ', #1
u'ومجشة': u'وَمَجِشّةٌ', #1
u'ومجشة': u'وَمِجَشّةً', #1
u'ومجعرة': u'وَمَجْعَرَةٌ', #1
u'ومجفرة': u'وَمَجْفَرَةٌ', #1
u'ومجلاة': u'وَمَجْلَاةٌ', #2
u'ومجلوبه': u'وَمَجْلُوبُهُ', #2
u'ومجلوبه': u'وَمَجْلُوبِهِ', #3
u'ومجمجة': u'وَمَجْمَجَةً', #1
u'ومجنأ': u'وَمُجْنَأٌ', #2
u'ومجهوليته': u'ومَجْهُولِيَّتِهِ', #1
u'ومجهوليتها': u'وَمَجْهُولِيَّتُهَا', #1
u'ومجىء': u'وَمَجِىءِ', #1
u'ومجيسة': u'وَمُجَيِّسَةٍ', #1
u'ومحابه': u'وَمَحَابِّهِ', #1
u'ومحاجير': u'وَمَحَاجِيرُ', #2
u'ومحاجيره': u'وَمَحَاجِيرُهُ', #2
u'ومحاز': u'وَمُحَازٌ', #1
u'ومحاسها': u'وَمَحَاسُّهَا', #1
u'ومحاصة': u'وَمُحَاصَّةُ', #1
u'ومحاصة': u'وَمُحَاصَّةِ', #1
u'ومحاصتها': u'وَمُحَاصَّتِهَا', #1
u'ومحاللة': u'وَمُحَالَلَةٍ', #1
u'ومحاويج': u'وَمَحَاوِيجُ', #1
u'ومحاويجهم': u'وَمَحَاوِيجِهِمْ', #3
u'ومحايض': u'وَمَحَايِضُ', #2
u'ومحبوسية': u'وَمَحْبُوسِيَّةٍ', #1
u'ومحتجم': u'وَمُحْتَجِمٍ', #2
u'ومحتفره': u'وَمُحْتَفَرُهُ', #1
u'ومحتفها': u'وَمُحْتَفُّهَا', #1
u'ومحتفها': u'وَمُحْتَفِّهَا', #1
u'ومحجلون': u'وَمُحَجَّلُونَ', #1
u'ومحجن': u'وَمِحْجَنُ', #1
u'ومحجن': u'وَمِحْجَنٌ', #4
u'ومحجنه': u'ومحجنه', #1
u'ومحجنه،': u'وَمِحْجَنِهِ،', #1
u'ومحجنها': u'وَمِحْجَنُهَا', #2
u'ومحجول': u'وَمَحْجُولِ', #2
u'ومحجوم': u'وَمَحْجُومٍ', #1
u'ومحدة': u'وَمُحِدَّةٍ', #1
u'ومحدة': u'وَمُحِدَّةٌ', #3
u'ومحدوج': u'وَمَحْدُوجٌ', #1
u'ومحرب': u'وَمِحْرَبٍ', #1
u'ومحرب': u'وَمُحْرِبُ', #2
u'ومحرسا': u'وَمُحْرِسًا', #1
u'ومحرميته': u'وَمَحْرَمِيَّتُهُ', #1
u'ومحسبة': u'وَمُحْسِبَةً', #1
u'ومحسبلا': u'وَمُحَسْبِلًا', #1
u'ومحسر': u'وَمُحَسِّر', #1
u'ومحسر': u'وَمُحَسِّرٍ', #1
u'ومحسر': u'وَمُحَسِّرٌ', #3
u'ومحسرا': u'وَمُحَسِّرًا', #3
u'ومحصارتهم': u'ومحصارتهم', #1
u'ومحمد': u'وَمُحَمَّدً', #1
u'ومحوج': u'وَمُحْوِجٌ', #3
u'ومحوقلا': u'وَمُحَوْقِلًا', #1
u'ومحياى': u'وَمَحْيَاىَ', #8
u'ومحيصة،': u'ومحيصة،', #1
u'ومحيصة': u'ومُحَيصة', #1
u'ومحيصة': u'وَمُحَيّصَةَ', #1
u'ومحيصة': u'وَمُحَيَّصَةَ', #1
u'ومحيصة،': u'وَمُحَيِّصَةَ،', #2
u'ومحيصة،': u'وَمُحَيِّصَةُ،', #2
u'ومحيصة': u'وَمُحَيِّصَةُ', #27
u'ومحيصة': u'وَمُحَيِّصَة', #3
u'ومحيصة': u'وَمُحَيّصَةُ', #5
u'ومحيصة': u'وَمُحَيِّصَةَ', #54
u'ومخارق': u'وَمَخَارِقُ', #1
u'ومخارق': u'وَمُخَارِقُ', #1
u'ومخارقه': u'وَمَخَارِقَهُ', #1
u'ومخارقها': u'وَمَخَارِقَهَا', #1
u'ومخاشاته': u'وَمُخَاشَاتِهِ', #2
u'ومخاشن': u'وَمُخَاشِنٌ', #1
u'ومخاضة': u'وَمَخَاضَةُ', #2
u'ومخالقةوالوجه': u'وَمُخَالَقَةًوَالْوَجْهُ', #1
u'ومخائل': u'وَمَخَائِلِ', #1
u'ومخبراني': u'ومخبراني', #1
u'ومختلعة': u'وَمُخْتَلِعَةٌ', #1
u'ومختلعة': u'وَمُخْتَلِعَةٍ', #1
u'ومختم': u'وَمَخْتَمٌ', #2
u'ومخدوش': u'وَمَخْدُوشٌ', #8
u'ومخذل': u'وَمُخْذِلٍ', #1
u'ومخذل': u'وَمِخْذَلٍ', #1
u'ومخرفة': u'وَمَخْرَفَةُ', #1
u'ومخرق': u'وَمُخَرَّقُ', #1
u'ومخرق': u'وَمُخْرِقٌ', #1
u'ومخرق': u'وَمُخَرَّقٌ', #5
u'ومخرقة': u'وَمُخْرَقَةُ', #1
u'ومخرمة': u'ومخرمة', #1
u'ومخرمة': u'وَمَخْرَمَةُ', #10
u'ومخرمة': u'وَمَخْرَمَةَ', #3
u'ومخرى': u'وَمُخْرَى', #1
u'ومخرئ': u'وَمُخْرِئٍ', #1
u'ومخزوما': u'وَمَخْزُومًا', #3
u'ومخضوب': u'وَمَخْضُوبٌ', #3
u'ومخطر': u'وَمُخْطِرٍ', #1
u'ومخفى': u'وَمُخْفَى', #2
u'ومخمصة': u'وَمَخْمَصَةٌ', #1
u'ومخنف': u'وَمِخْنَفُ', #1
u'ومخوساء': u'وَمِخْوَسَاءَ', #2
u'ومخوصا،': u'وَمِخْوَصًا،', #1
u'ومخى': u'وَمُخِّى', #5
u'ومخياط': u'وَمِخْيَاطٍ', #1
u'ومخيريق': u'وَمُخَيْرِيقٍ', #2
u'ومخيريق': u'وَمُخَيْرِيقٌ', #3
u'ومخيس': u'وَمُخَيَّسٌ', #1
u'ومخيس': u'وَمُخَيِّسٌ', #1
u'ومداخلا': u'وَمُدَاخِلًا', #2
u'ومدرهنا': u'وَمِدْرَهُنَا', #1
u'ومدفوق': u'وَمَدْفُوقٍ', #1
u'ومدلاج': u'وَمِدْلَاجُ', #2
u'ومدنف': u'وَمُدْنَفٌ', #1
u'ومذارعة': u'وَمُذَارَعَةً', #1
u'ومذاكر': u'وَمُذَاكِرُ', #1
u'ومذام': u'وَمَذَامَّ', #1
u'ومذام': u'وَمَذَامُّ', #1
u'ومذبة': u'وَمُذِبَّةً', #1
u'ومذبة': u'وَمُذِبَّةٌ', #1
u'ومذبة': u'وَمِذَبَّةً', #1
u'ومذحج': u'ومَذْحِج', #1
u'ومذحج': u'وَمُذْحِجُ', #1
u'ومذحج': u'وَمِذْحَجُ', #1
u'ومذحج': u'ومذحج', #2
u'ومذحج': u'وَمَذْحِجٍ', #2
u'ومذحج': u'وَمَذْحِجٌ', #3
u'ومذحج': u'وَمَذْحِجُ', #5
u'ومذرعته': u'وَمُذَرَّعَتُهُ', #1
u'ومذروع': u'وَمَذْرُوع', #1
u'ومذروع': u'وَمَذْرُوعٌ', #2
u'ومذروع': u'وَمَذْرُوعٍ', #21
u'ومذروعات': u'وَمَذْرُوعَاتٍ', #1
u'ومذفف': u'وَمُذَفِّفِ', #1
u'ومذففان': u'وَمُذَفِّفَانِ', #1
u'ومذكاة': u'وَمُذَكَّاةً', #2
u'ومذكاة': u'وَمُذَكَّاةٌ', #3
u'ومذكاة': u'وَمُذَكَّاةٍ', #6
u'ومذكاهم': u'وَمُذَكَّاهُمْ', #1
u'ومذكى': u'وَمُذَكَّى', #4
u'ومذي': u'وَمَذْي', #1
u'ومذى': u'وَمَذَّى', #1
u'ومذي': u'وَمَذْيٌ', #14
u'ومذي': u'وَمَذْيٍ', #33
u'ومذيا': u'وَمَذْيًا', #2
u'ومذينب': u'ومذينب', #2
u'ومذينب': u'وَمُذَيْنِبٍ', #6
u'ومذينيب': u'وَمُذَيْنِيبٌ', #1
u'ومذيها': u'وَمَذْيُهَا', #2
u'ومرءا': u'وَمَرْءًا', #1
u'ومراباين': u'ومراباين', #1
u'ومرابكسى': u'ومرابكسى', #1
u'ومرأة': u'وَمَرْأَةٌ', #1
u'ومراة': u'وَمُرَاةُ', #1
u'ومرأة': u'وَمَرْأَةٍ', #4
u'ومرأتين': u'وَمَرْأَتَيْنِ', #1
u'ومرازبته،': u'وَمَرَازِبَتِهِ،', #1
u'ومراضيع': u'وَمَرَاضِيعُ', #1
u'ومراطلة': u'وَمُرَاطَلَةِ', #1
u'ومراطلة': u'وَمُرَاطَلَةٍ', #2
u'ومراطلة': u'وَمُرَاطَلَةُ', #5
u'ومراعا': u'وَمَرَاعًا', #1
u'ومراغمة': u'وَمُرَاغَمَةً', #1
u'ومراغمة': u'وَمُرَاغَمَةٍ', #1
u'ومراغمة': u'وَمُرَاغَمَةُ', #1
u'ومراغمة': u'وَمُرَاغَمَةٌ', #4
u'ومراوضة': u'وَمُرَاوَضَةِ', #1
u'ومراوضة': u'وَمُرَاوَضَةٍ', #2
u'ومراوضته': u'وَمُرَاوَضَتِهِ', #1
u'ومرايتوا': u'ومرايتوا', #1
u'ومرايكسى': u'ومرايكسى', #1
u'ومربئد': u'وَمُرْبَئِدّ', #1
u'ومرتتة': u'ومرتتة', #1
u'ومرتجيا': u'وَمُرْتَجِيًا', #1
u'ومرتصدين': u'وَمُرْتَصِدِينَ', #1
u'ومرتضعة': u'وَمُرْتَضِعَةٌ', #6
u'ومرتفقا': u'وَمُرْتَفَقًا', #1
u'ومرث': u'وَمُرِثَ', #2
u'ومرثد': u'ومرثد', #1
u'ومرثد': u'وَمَرْثدُ', #1
u'ومرثد': u'ومَرْثَد', #1
u'ومرثد': u'وَمَرْثَدَ', #1
u'ومرثد': u'وَمَرْثَدِ', #1
u'ومرثد': u'وَمُرْثَدٌ', #1
u'ومرثد': u'وَمَرْثَدٌ', #3
u'ومرثد': u'وَمَرْثَدُ', #6
u'ومرجوحيتها': u'وَمَرْجُوحِيَّتِهَا', #1
u'ومرداس،': u'وَمِرْدَاسٌ،', #1
u'ومردقوش': u'وَمَرْدَقُوشٍ', #1
u'ومردى': u'وَمُرْدَى', #1
u'ومردى': u'وَمِرْدَى', #2
u'ومرذ': u'وَمُرَذّ', #1
u'ومرزجوش': u'وَمَرْزَجُوشٍ', #1
u'ومرزحوش': u'وَمَرْزَحُوشٍ', #1
u'ومرزنجوش': u'وَمَرْزَنْجُوشُ', #1
u'ومرضوض': u'وَمَرْضُوضُ', #1
u'ومرعاة': u'وَمَرْعَاةٌ', #1
u'ومرفقى': u'وَمِرْفَقَى', #1
u'ومرفوا': u'وَمَرْفُوًّا', #1
u'ومرفوعية': u'وَمَرْفُوعِيَّةُ', #1
u'ومرقوقا': u'وَمَرْقُوقًا', #3
u'ومرقوقة': u'وَمَرْقُوقَةٍ', #2
u'ومرقوقه': u'وَمَرْقُوقُهُ', #2
u'ومرقوقه': u'وَمَرْقُوقَهُ', #4
u'ومرماة': u'وَمِرْمَاةٌ', #1
u'ومرموشها': u'وَمَرْمُوشُهَا', #1
u'ومرهد': u'وَمِرْهَدُ', #5
u'ومرهمدان': u'ومرهمدان', #1
u'ومرهونية': u'وَمَرْهُونِيَّةِ', #1
u'ومروءه': u'وَمُرُوءَهْ', #1
u'ومروآت': u'وَمُرُوآتٍ', #1
u'ومروروذ': u'وَمَرْوَرُوذَ', #1
u'ومروروز': u'وَمَرْوَرُوزَ', #1
u'ومروطهن': u'وَمُرُوطُهُنَّ', #1
u'ومريت': u'وَمَرَيْت', #1
u'ومريته': u'وَمِرْيَتُهُ', #1
u'ومزابنة': u'وَمُزَابَنَةٌ', #1
u'ومزاريق': u'وَمَزَارِيقُ', #1
u'ومزاريق': u'وَمَزَارِيقَ', #4
u'ومزاناة': u'وَمُزَانَاةَ', #1
u'ومزبله': u'وَمَزْبَلَهْ', #1
u'ومزجرة': u'وَمَزْجَرَةُ', #9
u'ومزجور': u'وَمَزْجُورٌ', #1
u'ومزجورا': u'وَمَزْجُورًا', #1
u'ومزحوم': u'وَمَزْحُومٌ', #1
u'ومزحوم': u'وَمَزْحُومٍ', #2
u'ومزدجر': u'وَمُزْدَجَرٌ', #2
u'ومزدلفي': u'وَمُزْدَلِفِيٌّ', #1
u'ومزدلفي': u'وَمُزْدَلِفِيٍّ', #2
u'ومزر': u'وَمُزْرٍ', #1
u'ومزراقي': u'وَمِزْرَاقِي', #1
u'ومزرعها': u'وَمُزْرَعِهَا', #1
u'ومزعفر': u'وَمُزَعْفَرٌ', #2
u'ومزعفر': u'وَمُزَعْفَرٍ', #4
u'ومزعفرا': u'وَمُزَعْفَرًا', #1
u'ومزفوفة': u'وَمَزْفُوفَةٍ', #1
u'ومزمارة': u'وَمِزْمَارَةِ', #1
u'ومزمزوه': u'وَمَزْمِزُوهُ', #10
u'ومزنى': u'وَمُزْنًى', #1
u'ومزيقياء': u'وَمُزَيْقِيَاءُ', #1
u'ومسابكة': u'وَمُسَابَكَة', #1
u'ومساجدا،': u'وَمَسَاجِدًا،', #1
u'ومساغا': u'وَمَسَاغًا', #1
u'ومسافع': u'وَمُسَافِعُ', #3
u'ومسافعا': u'وَمُسَافِعًا', #1
u'ومساناة': u'وَمُسَانَاةٌ', #1
u'ومساناة': u'وَمُسَانَاةً', #4
u'ومسانهة': u'وَمُسَانَهَةً', #6
u'ومسانية': u'وَمُسَانِيَةً', #1
u'ومساهر': u'وَمُسَاهِرٌ', #1
u'ومسببية': u'وَمُسَبِّبِيَّةِ', #1
u'ومسببية': u'وَمُسَبَّبِيَّةِ', #2
u'ومسببيته': u'وَمُسَبَّبِيَّتُهُ', #1
u'ومسبطر': u'وَمُسْبَطِرّ', #1
u'ومسبل': u'وَمُسَبَّلٌ', #1
u'ومسبلها': u'وَمُسَبِّلُهَا', #1
u'ومسبوقية': u'وَمَسْبُوقِيَّةُ', #1
u'ومستأذيه': u'وَمُسْتَأْذِيهِ', #1
u'ومستام': u'وَمُسْتَامٍ', #6
u'ومستامة': u'وَمُسْتَامَةٍ', #2
u'ومستبرأة': u'وَمُسْتَبْرَأَةٌ', #2
u'ومستبرأة': u'وَمُسْتَبْرَأَةً', #3
u'ومستبرأة': u'وَمُسْتَبْرَأَةٍ', #5
u'ومستبضع': u'وَمُسْتَبْضِعٌ', #1
u'ومستبضع': u'وَمُسْتَبْضِعٍ', #2
u'ومستبضعا': u'وَمُسْتَبْضِعًا', #1
u'ومستبضعين': u'وَمُسْتَبْضِعَيْنِ', #1
u'ومستجاد': u'وَمُسْتَجَادٌ', #1
u'ومستجمر': u'وَمُسْتَجْمِرٍ', #1
u'ومستحاضة': u'وَمُسْتَحَاضَةً', #1
u'ومستحاضة': u'وَمُسْتَحَاضَةٍ', #3
u'ومستحاضة': u'وَمُسْتَحَاضَةٌ', #4
u'ومستحثات': u'وَمُسْتَحِثَّاتٌ', #1
u'ومستحقوا': u'وَمُسْتَحِقُّوا', #1
u'ومستدار': u'وَمُسْتَدَارُ', #1
u'ومستدخلة': u'وَمُسْتَدْخِلَةٍ', #5
u'ومستذم': u'وَمُسْتَذَمٌّ', #1
u'ومسترحما': u'وَمُسْتَرْحَمًا', #1
u'ومسترذلها': u'وَمُسْتَرْذَلِهَا', #1
u'ومستسعف': u'وَمُسْتَسْعِفِ', #1
u'ومستصفى': u'وَمُسْتَصْفَى', #1
u'ومستطرق': u'وَمُسْتَطْرِقٍ', #1
u'ومستعفيا': u'وَمُسْتَعْفِيًا', #1
u'ومستفرشة': u'وَمُسْتَفْرَشَةٍ', #2
u'ومستفعلن': u'وَمُسْتَفْعِلُنْ', #1
u'ومستقة': u'وَمُسْتَقَةٍ', #1
u'ومستقذر': u'وَمُسْتَقْذَرٍ', #2
u'ومستقذر': u'وَمُسْتَقْذَرٌ', #4
u'ومستقرض': u'وَمُسْتَقْرِضٌ', #2
u'ومستقض': u'وَمُسْتَقْضٍ', #1
u'ومستقضيا': u'وَمُسْتَقْضِيًا', #1
u'ومستقلبات': u'وَمُسْتَقْلِبَاتٍ', #1
u'ومستلحق': u'وَمُسْتَلْحِقٌ', #1
u'ومستنبح': u'وَمُسْتَنْبَحٍ', #2
u'ومستنبح': u'وَمُسْتَنْبِحٌ', #2
u'ومستنبح': u'وَمُسْتَنْبَحٌ', #3
u'ومستنة': u'وَمُسْتَنّةٌ', #1
u'ومستنجى': u'وَمُسْتَنْجًى', #4
u'ومستنقذ': u'وَمُسْتَنْقَذٌ', #3
u'ومستنقذي': u'وَمُسْتَنْقِذِي', #1
u'ومستنقصا': u'وَمُسْتَنْقِصًا', #3
u'ومستنكح': u'وَمُسْتَنْكِحٍ', #1
u'ومستنكه': u'وَمُسْتَنْكِهُ', #1
u'ومستنيب': u'وَمُسْتَنِيبٌ', #1
u'ومستنيبا': u'وَمُسْتَنِيبًا', #1
u'ومستنيبه': u'وَمُسْتَنِيبِهِ', #1
u'ومستهتك': u'وَمُسْتَهْتِكٌ', #1
u'ومستوشمة': u'وَمُسْتَوْشِمَةٌ', #1
u'ومستوفى': u'وَمُسْتَوْفًى', #9
u'ومستوهبها': u'وَمُسْتَوْهِبِهَا', #1
u'ومسجدى': u'وَمَسْجِدِى', #4
u'ومسجديتها': u'وَمَسْجِدِيَّتِهَا', #1
u'ومسحين': u'وَمَسْحَيْنِ', #1
u'ومسخريته': u'وَمَسْخَرِيَّتُهُ', #1
u'ومسخط': u'وَمُسْخِطٌ', #1
u'ومسرى': u'وَمِسْرَى', #2
u'ومسطاح': u'وَمِسْطَاحٍ', #3
u'ومسعط': u'وَمُسْعَطٌ', #1
u'ومسعط': u'وَمِسْعَطٍ', #1
u'ومسقب': u'وَمُسْقَبٌ', #1
u'ومسلاق': u'وَمِسْلَاقٌ', #2
u'ومسلمانية': u'وَمُسْلِمَانِيَّةٍ', #2
u'ومسمت': u'وَمُسَمِّتٌ', #2
u'ومسمط': u'وَمَسْمَطٍ', #4
u'ومسولة': u'وَمُسَوِّلَةُ', #1
u'ومسيكية': u'وَمُسَيْكِيَةُ', #1
u'ومشاتما': u'وَمُشَاتِمًا', #1
u'ومشاححة': u'وَمُشَاحَحَةً', #1
u'ومشاححة': u'وَمُشَاحَحَةٍ', #1
u'ومشارعه': u'وَمَشَارِعِهِ', #1
u'ومشاش': u'وَمُشَاشٌ', #1
u'ومشاينها': u'وَمَشَايِنَهَا', #1
u'ومشبر': u'وَمُشَبِّرٌُُُُ', #1
u'ومشبر': u'وَمُشَبِّرٍ', #1
u'ومشبر': u'وَمُشْبِرٍ', #1
u'ومشبرا': u'وَمُشَبِّرًا', #1
u'ومشبريييي': u'وَمُشَبِّرُيييي', #1
u'ومشتراة': u'وَمُشْتَرَاةٌ', #1
u'ومشتراة': u'وَمُشْتَرَاةٍ', #2
u'ومشتراه': u'وَمُشْتَرَاهُ', #2
u'ومشترى': u'وَمُشْتَرَى', #2
u'ومشترى': u'وَمُشْتَرًى', #9
u'ومشد': u'وَمُشِدٍّ', #1
u'ومشد': u'وَمِشَدٌّ', #1
u'ومشد': u'وَمِشَدٍّ', #1
u'ومشد': u'وَمُشِدٌّ', #2
u'ومشد': u'وَمِشَدِّ', #2
u'ومشد': u'وَمِشَدُّ', #5
u'ومشداخ': u'وَمُشْدَاخٌ', #1
u'ومشداخ': u'وَمِشْدَاخٌ', #2
u'ومشدهم': u'وَمُشِدّهُمْ', #1
u'ومشرجا': u'وَمُشَرَّجًا', #2
u'ومشرجا': u'وَمُشْرَجًا', #2
u'ومشرخاء': u'وَمِشْرَخَاءَ', #2
u'ومشركى': u'وَمُشْرِكِى', #1
u'ومشروطيتها': u'ومَشْرُوطِيَّتِهَا', #1
u'ومشروف': u'وَمَشْرُوفٌ', #2
u'ومشروك': u'وَمَشْرُوكٌ', #1
u'ومشوم': u'وَمَشُومٌ', #1
u'ومشية': u'وَمِشْيَةٌ', #1
u'ومشيش': u'وَمُشِيش', #1
u'ومشيوحاء': u'وَمَشْيُوحَاءَ', #1
u'ومشيوخاء': u'وَمَشْيُوخَاءَ', #1
u'ومصاطبهم': u'وَمَصَاطِبِهِمْ', #4
u'ومصراة': u'وَمُصَرَّاةً', #2
u'ومصطكا': u'وَمُصْطَكَا', #1
u'ومصلائي': u'وَمُصَلَّائِي', #1
u'ومصلق': u'وَمِصْلَقٍ', #1
u'ومصلوحا': u'وَمَصْلُوحًا', #1
u'ومصوع': u'وَمَصُوعُ', #1
u'ومضارج': u'وَمَضَارِجَ', #2
u'ومضببا': u'وَمُضَبَّبًا', #1
u'ومضبعة': u'وَمَضْبَعَةٌ', #1
u'ومضبعة': u'وَمَضْبَعَةٍ', #2
u'ومضتر': u'وَمُضْتَرَّ', #1
u'ومضرح': u'وَمُضَرّحِ', #1
u'ومطرورة': u'وَمَطْرُورَةُ', #1
u'ومطلوبية': u'وَمَطْلُوبِيَّةُ', #2
u'ومطلوبيته': u'وَمَطْلُوبِيَّتُه', #1
u'ومطلوقة': u'وَمَطْلُوقَةً', #1
u'ومطلوقة': u'وَمَطْلُوقَةٍ', #3
u'ومطلوقة': u'وَمَطْلُوقَةٌ', #5
u'ومظاهرا': u'وَمُظَاهِرًا', #1
u'ومظنات': u'وَمَظِنَّاتِ', #1
u'ومعاددة': u'وَمُعَادَدَةً', #1
u'ومعادى': u'وَمَعَادِى', #1
u'ومعاشى': u'وَمَعَاشِى', #3
u'ومعاطاة': u'وَمُعَاطَاةً', #1
u'ومعاطاة': u'وَمُعَاطَاةُ', #1
u'ومعاطاة': u'وَمُعَاطَاةِ', #1
u'ومعاطاته': u'وَمُعَاطَاتُهُ', #1
u'ومعاطنا': u'وَمَعَاطِنًا', #4
u'ومعافر،': u'ومَعَافِر،', #1
u'ومعافر': u'وَمُعَافِرَ', #1
u'ومعافر': u'وَمَعَافِرَ', #6
u'ومعافري': u'وَمَعَافِرِيُّ', #1
u'ومعافري': u'وَمَعَافِرِيٌّ', #3
u'ومعافرى': u'وَمَعَافِرِىٌّ', #4
u'ومعافير': u'وَمَعَافِيرُ', #1
u'ومعاقد': u'وَمَعَاقِد', #1
u'ومعاقد': u'وَمُعَاقَدُ', #1
u'ومعاقد': u'وَمُعَاقِدِ', #1
u'ومعاقد': u'وَمُعَاقَدِ', #2
u'ومعاقد': u'وَمَعَاقِدَ', #3
u'ومعاقد': u'وَمَعَاقِدُ', #4
u'ومعاقد': u'وَمَعَاقِدِ', #4
u'ومعاقده': u'وَمُعَاقِدِهِ', #1
u'ومعالى': u'وَمَعَالِىَ', #1
u'ومعاليم': u'وَمَعَالِيمَ', #1
u'ومعانى': u'وَمُعَانَى', #1
u'ومعاوض': u'وَمُعَاوِضُ', #1
u'ومعتاض': u'وَمُعْتَاضٌ', #1
u'ومعتاضا': u'وَمُعْتَاضًا', #8
u'ومعتضد': u'وَمُعْتَضَدُ', #1
u'ومعتضد': u'وَمُعْتَضَدٌ', #3
u'ومعتمل': u'وَمُعْتَمِلٍ', #3
u'ومعجوز': u'وَمَعْجُوزٍ', #3
u'ومعراض': u'وَمِعْرَاضٍ', #1
u'ومعرص': u'وَمُعَرَّصٌ', #1
u'ومعرور': u'وَمَعْرُورٌ', #2
u'ومعروريا': u'وَمُعْرَوْرِيًا', #1
u'ومعروفيته': u'وَمَعْرُوفِيَّتَهُ', #2
u'ومعزوم': u'وَمَعْزُومٌ', #1
u'ومعزوم': u'وَمَعْزُومٍ', #1
u'ومعصفر': u'وَمُعَصْفَرٍ', #12
u'ومعصفر': u'وَمُعَصْفَرٌ', #3
u'ومعصفرا': u'وَمُعَصْفَرًا', #1
u'ومعصيت': u'وَمَعْصِيَتِ', #1
u'ومعض': u'وَمَعَضِّ', #1
u'ومعض': u'وَمَعَضُّ', #8
u'ومعضه': u'وَمَعَضَّهُ', #1
u'ومعضوب': u'وَمَعْضُوبٍ', #1
u'ومعطاف': u'وَمِعْطَافٍ', #1
u'ومعطن': u'وَمَعْطِنِ', #1
u'ومعطن': u'وَمَعْطِنُ', #3
u'ومعلجة': u'وَمَعْلَجَةً', #2
u'ومعلوجاء': u'وَمَعْلُوجَاءَ', #1
u'ومعلومية': u'وَمَعْلُومِيَّةِ', #2
u'ومعلومية': u'وَمَعْلُومِيَّةُ', #9
u'ومعلوميته': u'وَمَعْلُومِيَّتَهُ', #1
u'ومعنس': u'وَمُعَنَّسٌ', #1
u'ومعهوديتها': u'ومعهوديتها', #1
u'ومعهوديتها': u'وَمَعْهُودِيَّتُهَا', #1
u'ومعيتق': u'وَمُعَيْتِقٌ', #1
u'ومعيز': u'وَمَعِيزٌ', #3
u'ومعيصرة': u'وَمُعَيْصَرَةَ', #1
u'ومعيقيب': u'وَمُعَيْقِيبُ', #6
u'ومعيوب': u'وَمَعْيُوبٌ', #2
u'ومغابن': u'وَمَغَابِنَ', #1
u'ومغابن': u'وَمَغَابِنُ', #1
u'ومغابنة': u'وَمُغَابَنَةٍ', #3
u'ومغابنه': u'وَمَغَابِنَهُ', #1
u'ومغابنه': u'وَمَغَابِنُهُ', #1
u'ومغات': u'وَمُغَاتٍ', #1
u'ومغارسة': u'وَمُغَارَسَةٍ', #1
u'ومغازى': u'وَمَغَازِى', #1
u'ومغافر': u'وَمَغَافِرُ', #1
u'ومغايظة': u'وَمُغَايَظَةً', #1
u'ومغدان': u'وَمَغْدَانُ', #2
u'ومغدق': u'وَمُغْدِقَ', #1
u'ومغدق': u'وَمُغْدِقِ', #1
u'ومغراء': u'وَمَغْرَاءُ', #1
u'ومغرة': u'وَمَغَرَةٍ', #1
u'ومغرة': u'وَمَغْرَةٍ', #17
u'ومغرفه': u'وَمَغْرَفُهُ', #1
u'ومغروزة': u'وَمَغْرُوزَةٌ', #1
u'ومغزول': u'وَمَغْزُولٌ', #1
u'ومغزول': u'وَمَغْزُولِ', #1
u'ومغزول': u'وَمَغْزُولٍ', #2
u'ومغفر': u'وَمِغْفَر', #1
u'ومغفر': u'وَمِغْفَرٍ', #1
u'ومغفر': u'وَمِغْفَرُ', #1
u'ومغفر': u'وَمِغْفَرٌ', #3
u'ومغفرا': u'وَمِغْفَرًا', #2
u'ومغفرتهقوله': u'وَمَغْفِرَتِهِقَوْلُهُ', #1
u'ومغفره': u'وَمِغْفَرِهِ', #1
u'ومغفره': u'وَمِغْفَرَهُ', #5
u'ومغفرى': u'وَمِغْفَرِى', #2
u'ومغلسا': u'وَمُغَلِّسًا', #1
u'ومغللة': u'وَمُغَلّلَةٌ', #1
u'ومغلوث': u'وَمَغْلُوثٌ', #1
u'ومغلوث': u'وَمَغْلُوثٍ', #1
u'ومغلوثة': u'وَمَغْلُوثَةٌ', #1
u'ومغيل': u'وَمُغِيل', #1
u'ومغيوثة': u'وَمَغْيُوثَةٌ', #2
u'ومفاخذة': u'وَمُفَاخَذَةٍ', #2
u'ومفادة': u'وَمُفَادَةُ', #2
u'ومفاعلة': u'وَمُفَاعَلَةٌ', #1
u'ومفاعيلن': u'وَمَفَاعِيلُنْ', #1
u'ومفالجة': u'وَمُفَالَجَةٍ', #1
u'ومفالحة': u'وَمُفَالَحَةٍ', #2
u'ومفايلة': u'وَمُفَايَلَةٌ', #1
u'ومفتات': u'وَمُفْتَاتٌ', #1
u'ومفدمة': u'وَمُفَدَّمَةٌ', #1
u'ومفرادتها': u'وَمِفْرَادَتِهَا', #1
u'ومفضوليته': u'وَمَفْضُولِيَّتِهِ', #1
u'ومفضوليته': u'وَمَفْضُولِيَّتَهُ', #2
u'ومفطور': u'وَمَفْطُورٌ', #2
u'ومفعال': u'وَمِفْعَالٍ', #1
u'ومفعالة': u'وَمُفْعَالَة', #1
u'ومفقوء': u'وَمَفْقُوءً', #1
u'ومفقوء': u'وَمَفْقُوءَ', #1
u'ومفقوءها': u'وَمَفْقُوءَهَا', #1
u'ومفلج': u'وَمُفَلَّجُ', #1
u'ومفيت': u'وَمُفِيتٌ', #1
u'ومفيت': u'وَمُفِيتٍ', #1
u'ومقاثي': u'وَمَقَاثِي', #1
u'ومقاثئ': u'وَمَقَاثِئ', #1
u'ومقاثئ': u'وَمَقَاثِئٍ', #1
u'ومقادم': u'وَمَقَادِم', #1
u'ومقادم': u'وَمَقَادِمُ', #1
u'ومقارض': u'وَمُقَارِضٍ', #4
u'ومقارضا': u'وَمُقَارِضًا', #2
u'ومقاصصتهم': u'وَمُقَاصَصَتُهُمْ', #1
u'ومقاصيصها': u'وَمَقَاصِيصِهَا', #1
u'ومقانعهن': u'وَمَقَانِعِهِنَّ', #3
u'ومقتب': u'وَمُقَتَّبٍ', #2
u'ومقتب': u'وَمُقَتَّبٌ', #3
u'ومقتداهم': u'وَمُقْتَدَاهُمْ', #1
u'ومقتص': u'وَمُقْتَصٍّ', #7
u'ومقتور': u'وَمَقْتُورٌ', #6
u'ومقثأة': u'وَمَقْثَأَةٌ', #1
u'ومقثاة': u'وَمَقْثَاةٍ', #1
u'ومقثأة': u'وَمِقْثَأَةٍ', #2
u'ومقثأة': u'وَمَقْثَأَةٍ', #20
u'ومقحط': u'وَمِقْحَطٌ', #1
u'ومقدوحا': u'وَمَقْدُوحًا', #1
u'ومقرطس': u'وَمُقَرْطَسٌ', #1
u'ومقرطس': u'وَمُقَرْطَسٍ', #1
u'ومقرطس': u'وَمُقَرْطِسٍ', #1
u'ومقروع': u'وَمَقْرُوعٍ', #1
u'ومقصول': u'وَمَقْصُولٌ', #1
u'ومقلش': u'وَمَقْلَشٍ', #1
u'ومقلوة': u'وَمَقْلُوَّةٌ', #2
u'ومقهورية': u'وَمَقْهُورِيَّةِ', #1
u'ومقير': u'وَمُقَيَّرٍ', #1
u'ومقيس': u'وَمَقِيسِ', #1
u'ومقيس': u'وَمِقْيَسٌ', #1
u'ومقيس': u'وَمِقْيَسِ', #1
u'ومقيس': u'وَمِقْيَسُ', #10
u'ومقيس': u'وَمَقِيسَ', #2
u'ومقيس': u'وَمِقْيَسَ', #2
u'ومقيس': u'وَمَقِيسٌ', #3
u'ومقيسا': u'وَمَقِيسًا', #2
u'ومقيسة': u'وَمَقِيسَةٍ', #1
u'ومكاتل': u'وَمَكَاتِلَ', #1
u'ومكاتلهم': u'وَمَكَاتِلِهِمْ', #11
u'ومكاتلهم،': u'وَمَكَاتِلِهِمْ،', #2
u'ومكادحة': u'وَمُكَادَحَةُ', #1
u'ومكاس': u'وَمَكَّاسٍ', #2
u'ومكاعبنا': u'وَمَكَاعِبِنَا', #1
u'ومكامعة': u'وْمُكَامَعَةِ', #1
u'ومكامعة': u'وَمُكَامَعَةِ', #2
u'ومكامعة': u'وَمُكَامَعَةَ', #6
u'ومكائدة': u'وَمُكَائَدَةِ', #1
u'ومكايسة': u'وَمُكَايَسَةٍ', #1
u'ومكبوبا': u'وَمَكْبُوبًا', #1
u'ومكتتم': u'وَمُكْتَتَمْ', #1
u'ومكتتم': u'وَمُكْتَتِمٍ', #1
u'ومكحول': u'ومكحول', #1
u'ومكحول،': u'ومكحول،', #1
u'ومكحول': u'وَمَكْحُولُ', #1
u'ومكحول،': u'وَمَكْحُولٌ،', #10
u'ومكحول': u'وَمَكْحُول', #2
u'ومكحول': u'وَمَكْحُولٌ', #38
u'ومكحول': u'وَمَكْحُولٍ', #42
u'ومكحول،': u'وَمَكْحُولٍ،', #51
u'ومكحولا': u'وَمَكْحُولًا', #2
u'ومكحول،أنهما': u'وَمَكْحُولٍ،أَنَّهُمَا', #1
u'ومكدوس': u'وَمَكْدُوسٌ', #3
u'ومكدوش': u'وَمَكْدُوشٌ', #5
u'ومكردس': u'وَمُكَرْدَسٌ', #1
u'ومكرز': u'وَمِكْرَزَ', #3
u'ومكرز': u'وَمِكْرَزُ', #5
u'ومكرى': u'وَمُكْرًى', #5
u'ومكز': u'وَمُكِزَ', #2
u'ومكشف': u'وَمُكْشِفِ', #1
u'ومكلب': u'وَمُكَلِّبٌ', #1
u'ومكلبين': u'وَمُكَلِّبِينَ', #3
u'وملاحيه': u'وَمَلَّاحِيهِ', #1
u'وملاكع': u'وَمَلَاكِعَ', #1
u'وملالة': u'وَمَلَالَةٌ', #1
u'وملالة': u'وَمَلَالَةٍ', #1
u'وملالة': u'وَمَلَالَةُ', #1
u'وملأم': u'وَمُلَأّمُ', #1
u'وملأم': u'وَمُلْأَمُ', #1
u'وملأوا': u'وملأوا', #1
u'وملاوح': u'وَمُلَاوِحٌ', #1
u'وملآئكته': u'وَمَلآئِكَتِهِ', #2
u'وملإيه': u'وَمَلإَيِهِ', #1
u'وملبثها': u'وَمَلْبَثُهَا', #1
u'وملتذ': u'وَمُلْتَذٌّ', #1
u'وملج': u'وَمَلَجَ', #2
u'وملجج': u'وَمُلَجَّجٍ', #2
u'وملجج': u'وَمُلَجِّجٍ', #2
u'وملجج': u'وَمُلْجِجٍ', #2
u'وملحوب': u'وَمَلْحُوبٌ', #1
u'وملذوذاته': u'وَمَلْذُوذَاتِهِ', #1
u'وملذوذاتها': u'وَمَلْذُوذَاتُهَا', #1
u'وملذوذاتها': u'وَمَلْذُوذَاتِهَا', #3
u'وملزوم': u'وَمَلْزُومُ', #5
u'وملزومه': u'وَمَلْزُومُهُ', #1
u'وملطأة': u'وَمِلْطَأَةٌ', #1
u'وملطاة': u'وَمِلْطَاةً', #1
u'وملطاة': u'وَمِلْطَاةٌ', #1
u'وملطاة': u'وَمِلْطَاةٍ', #1
u'وملطأة': u'وَمِلْطَأَةٍ', #3
u'وملطة': u'وَمُلْطَةٌ', #1
u'وملطية': u'وَمَلَطْيَةَ', #2
u'وملعوق': u'وَمَلْعُوقٍ', #1
u'وملقوح': u'وَمَلْقُوحٍ', #1
u'وملكتكه': u'وَمَلَّكْتُكَهُ', #2
u'وملكوم': u'وَمَلْكُومٌ', #1
u'وملكوما': u'وَمَلْكُومًا', #2
u'وملوط': u'وَمُلُوطٍ', #2
u'وملوط': u'وَمَلُوطٍ', #3
u'ومليحيب': u'وَمُلَيْحِيبٌ', #1
u'ومليكة': u'وَمُلَيْكَة', #2
u'ومليل': u'ومليل', #1
u'ومليل': u'وَمُلَيْلَ', #1
u'ومليل': u'وَمُلَيْلُ', #2
u'ومماتى': u'وَمَمَاتِى', #8
u'ومماذا': u'ومماذا', #1
u'وممثون': u'وَمَمْثُونٌ', #2
u'وممحض': u'وَمُمَحِّضٌ', #1
u'وممحقة': u'وَمَمْحَقَة', #1
u'وممدح': u'وَمُمَدّحٍ', #1
u'وممرجل': u'وَمُمَرْجَلٌ', #1
u'ومملوح': u'وَمَمْلُوحٌ', #6
u'ومناءة': u'وَمَنَاءَةُ', #1
u'ومنابذا': u'وَمُنَابِذًا', #1
u'ومناة': u'وَمَنَاةَ', #10
u'ومناة': u'وَمَنَاةُ', #8
u'ومنات': u'وَمَنَاتْ', #1
u'ومناجح': u'وَمَنَاجِحَ', #1
u'ومناجق': u'وَمَنَاجِقَ', #1
u'ومناجيق': u'وَمَنَاجِيقٍ', #1
u'ومناجيق': u'وَمَنَاجِيقَ', #1
u'ومناطاة': u'وَمُنَاطَاةِ', #1
u'ومنافعا': u'وَمَنَافِعًا', #1
u'ومناكر': u'وَمَنَاكِرَ', #1
u'ومناكرة': u'وَمُنَاكَرَةٍ', #1
u'ومناكرة': u'وَمُنَاكَرَةِ', #3
u'ومناكرته': u'وَمُنَاكَرَتُهُ', #1
u'ومناواة': u'وَمُنَاوَاة', #1
u'ومناواة': u'وَمُنَاوَاةً', #1
u'ومنبرى': u'وَمِنْبَرِى', #7
u'ومنبله': u'وَمُنْبِله', #1
u'ومنبله،': u'وَمُنْبِلُهُ،', #1
u'ومنبله': u'وَمُنْبِلُهُ', #2
u'ومنبله': u'وَمُنَبِّلَهُ', #3
u'ومنبله': u'وَمُنْبِلَهُ', #6
u'ومنتضح': u'وَمُنْتَضِحٌ', #1
u'ومنتقع': u'وَمُنْتَقِعٍ', #1
u'ومنتقع': u'وَمُنْتَقَعِ', #7
u'ومنتهب': u'وَمُنْتَهَبٌ', #1
u'ومنتهب': u'وَمُنْتَهِبٍ', #2
u'ومنتهب': u'وَمُنْتَهِبٌ', #5
u'ومنجا': u'وَمَنْجَا', #1
u'ومنجاب': u'وَمِنْجَابٌ', #1
u'ومنجاب': u'وَمِنْجَابُ', #1
u'ومنجنوق': u'وَمَنْجَنُوقٌ', #1
u'ومنجنوق': u'وَمَنْجَنُوقٍ', #1
u'ومنجوفة': u'وَمَنْجُوفَةٌ', #3
u'ومنحور': u'وَمَنْحُور', #1
u'ومنخل': u'وَمُنْخُلٍ', #2
u'ومنخور': u'وَمَنْخُورٌ', #1
u'ومنخور': u'وَمُنْخُورٌ', #2
u'ومنخول': u'وَمَنْخُولُ', #1
u'ومنخوله': u'وَمَنْخُولُهُ', #1
u'ومندرئات': u'وَمُنْدَرِئَاتٌ', #1
u'ومنده': u'وَمَنْدَهْ', #1
u'ومندى': u'وَمُنَدًّى', #1
u'ومنشا': u'وَمَنَشّا', #1
u'ومنشزا': u'وَمُنْشِزًا', #1
u'ومنشغه': u'وَمُنْشِغه', #1
u'ومنشى': u'وَمُنْشَى', #1
u'ومنصل': u'وَمِنْصَلِ', #1
u'ومنضولا': u'وَمَنْضُولًا', #1
u'ومنطي': u'وَمُنْطِي', #1
u'ومنطى': u'وَمُنْطَى', #1
u'ومنعل': u'وَمَنْعَلٍ', #1
u'ومنعل': u'وَمُنَعَّلٍ', #1
u'ومنعل': u'وَمُنَعَّلُ', #1
u'ومنعل': u'وَمُنْعَلٌ', #1
u'ومنعنى': u'وَمَنَعَنِى', #1
u'ومنعنيه': u'وَمَنَعَنِيهِ', #1
u'ومنفوذ': u'وَمَنْفُوذُ', #2
u'ومنفوطة': u'وَمَنْفُوطَةٌ', #1
u'ومنكورس': u'وَمِنْكَوْرَسٌ', #1
u'ومنلا': u'وَمُنْلَا', #21
u'ومنهاما': u'وَمِنْهَامَا', #1
u'ومنهاها': u'وَمَنْهَاهَا', #1
u'ومنهوس': u'وَمَنْهُوسُ', #1
u'ومنهيون': u'وَمَنْهِيُّونَ', #3
u'ومنورقة،': u'وَمَنُورْقَةَ،', #1
u'ومني': u'وَمِنًي', #1
u'ومنيحة': u'وَمَنِيحَةُ', #4
u'ومنيحتها': u'وَمَنِيحَتُهَا', #6
u'ومنيحتهم': u'وَمَنِيحَتَهُمْ', #1
u'ومهابأة': u'وَمُهَابَأَةٌ', #1
u'ومهارشة': u'وَمُهَارَشَةُ', #1
u'ومهارشة': u'وَمُهَارَشَةِ', #5
u'ومهارى': u'وَمَهَارَى', #1
u'ومهازيل': u'وَمَهَازِيلَ', #3
u'ومهازيل': u'وَمَهَازِيلُ', #3
u'ومهانأة': u'وَمُهَانَأَةٌ', #1
u'ومهايأة': u'وَمُهَايَأَةٍ', #1
u'ومهايأة': u'وَمُهَايَأَةُ', #1
u'ومهايأة': u'وَمُهَايَأَةٌ', #7
u'ومهبات': u'وَمَهَبَّاتِ', #1
u'ومهدوي': u'وَمَهْدَوِيّ', #1
u'ومهرودتان': u'وَمَهْرُودَتَانِ', #1
u'ومهزأة': u'وَمَهْزُأَةً', #1
u'ومهضم': u'وَمُهَضِّمُ', #1
u'ومهمهين': u'وَمَهْمَهَيْنِ', #1
u'ومهيعة': u'وَمَهْيَعَةٌ', #1
u'ومهيعة': u'وَمَهْيَعَةَ', #1
u'ومهيعة': u'وَمَهْيَعَةُ', #1
u'ومهيعة': u'ومَهْيَعَةُ', #2
u'ومهيعه': u'وَمَهِيعُهُ', #1
u'ومواثر': u'وَمَوَاثِرُ', #1
u'ومؤاجر': u'وَمُؤَاجَرٌ', #1
u'ومؤاجرة': u'وَمُؤَاجَرَةَ', #1
u'ومؤاجرة': u'وَمُؤَاجَرَةً', #2
u'ومؤاجرته': u'وَمُؤَاجَرَتُهُ', #1
u'ومواخي': u'وَمُوَاخِي', #2
u'وموارثة': u'وَمُوَارَثَةِ', #1
u'وموارثتهم': u'وَمُوَارَثَتِهِمْ', #1
u'ومواضعات': u'وَمُوَاضَعَاتِ', #1
u'ومواضعة': u'وَمُوَاضَعَةٍ', #16
u'ومواضعة': u'وَمُوَاضَعَةُ', #3
u'ومواضعة': u'وَمُوَاضَعَةً', #6
u'ومواضعة': u'وَمُوَاضَعَةٌ', #7
u'ومواضعتهم': u'وَمُوَاضَعَتِهِمْ', #1
u'ومواضعتهن': u'وَمُوَاضَعَتِهِنَّ', #1
u'ومواق': u'وَمَوَاقٍ', #1
u'ومؤاكر': u'وَمُؤَاكِرٌ', #1
u'ومؤاكرة': u'وَمُؤَاكَرَةً', #1
u'ومواكرة': u'وَمُوَاكَرَةً', #2
u'ومواكلون': u'وَمُوَاكِلُونَ', #1
u'وموانح': u'وَمَوَانِحَ', #1
u'وموانهم': u'وَمَوَانَهُمْ', #1
u'ومؤبر': u'وَمُؤَبَّرٌ', #3
u'ومؤتة': u'وَمُؤْتَةُ', #2
u'ومؤتة': u'وَمُؤْتَةَ', #3
u'ومؤتما': u'وَمُؤْتَمًّا', #2
u'ومؤثم': u'وَمُؤَثَّمٌ', #1
u'وموجده': u'وَمُوجِدِهِ', #1
u'وموجدها': u'وَمُوجِدُهَا', #1
u'وموجرا': u'وَمُوجَرًا', #6
u'وموجوء': u'وَمَوْجُوءٌ', #1
u'وموراته': u'وَمُورَاتِهِ', #1
u'ومورف': u'وَمُوَرّفٌ', #1
u'ومورقو': u'وَمُوَرِّقُو', #2
u'وموسقه': u'وَمَوْسَقَهْ', #1
u'وموصولية': u'وَمَوْصُولِيَّةِ', #1
u'وموضئه': u'وَمُوَضِّئُهُ', #1
u'وموطوء': u'وَمَوْطُوءٍ', #2
u'وموطوءات': u'وَمَوْطُوءَاتُ', #1
u'وموطوءات': u'وَمَوْطُوءَاتِ', #1
u'وموطوءة': u'وَمَوْطُوءَة', #1
u'وموطوءة': u'وَمَوْطُوءَةَ', #1
u'وموطوءة': u'وَمَوْطُوءَةِ', #1
u'وموطوءة': u'وَمَوْطُوءَةٌ', #3
u'وموطوءة': u'وَمَوْطُوءَةٍ', #3
u'وموطوءة': u'وَمَوْطُوءَةُ', #7
u'وموطوءته': u'وَمَوْطُوءَتِهِ', #2
u'وموطوآت': u'وَمَوْطُوآتُ', #1
u'وموطوآت': u'وَمَوْطُوآتِ', #1
u'وموطود': u'وَمَوْطُودٌ', #1
u'وموعاد': u'وَمِوْعَادٌ', #1
u'وموقات': u'وَمِوْقَاتٌ', #1
u'وموقوذة': u'وَمَوْقُوذَةٍ', #6
u'وموقوذته': u'وَمَوْقُوذَتَهُ', #2
u'ومؤلى': u'وَمُؤْلًى', #1
u'وموم': u'وَمُومٍ', #4
u'ومؤمنوا': u'وَمُؤْمِنُوا', #1
u'وموموقة': u'وَمَوْمُوقَةٌ', #1
u'ومومئ': u'وَمُومِئٍ', #2
u'ومومئ': u'وَمُومِئٌ', #4
u'وموميا': u'وَمُومِيًا', #2
u'وموميا': u'وَمُومْيَا', #8
u'ومؤنات': u'وَمُؤْنَاتِ', #1
u'ومؤنات': u'وَمُؤْنَاتُ', #2
u'ومؤناته': u'وَمُؤْنَاتِهِ', #1
u'ومؤنة': u'وَمَؤُنَةُ', #1
u'ومؤنة': u'وَمُؤْنَةِ', #112
u'ومؤنة': u'وَمُؤْنَةً', #12
u'ومؤنة': u'وَمُؤْنَةَ', #13
u'ومؤنة': u'وَمَؤُنَةِ', #2
u'ومؤنة': u'وَمُؤْنَةٌ', #237
u'ومؤنة': u'وَمُؤْنَةُ', #246
u'ومؤنة': u'وَمُؤْنَة', #4
u'ومؤنة': u'وَمُؤْنَةٍ', #43
u'ومؤنته': u'وَمُؤْنَتَهُ', #12
u'ومؤنته': u'وَمُؤْنَتِهِ', #22
u'ومؤنته': u'وَمُؤْنَتُهُ', #84
u'ومؤنتها': u'وَمُؤْنَتَهَا', #2
u'ومؤنتها': u'وَمُؤْنَتُهَا', #20
u'ومؤنتها': u'وَمُؤْنَتِهَا', #9
u'ومؤنتهم': u'وَمُؤْنَتُهُمْ', #2
u'ومؤنتهم': u'وَمُؤْنَتِهِمْ', #5
u'ومؤنتهما': u'وَمُؤْنَتُهُمَا', #2
u'ومونقا': u'وَمُونِقًا', #1
u'وموهب': u'وَمَوْهَبُ', #1
u'ومويه': u'وَمُوَيْهٍ', #1
u'ومئونات': u'وَمَئُونَاتِ', #1
u'ومئونة': u'وَمَئُونَةً', #1
u'ومئونة': u'وَمَئُونَةِ', #12
u'ومئونة': u'وَمَئُونَةٌ', #6
u'ومئونة': u'وَمَئُونَةُ', #6
u'ومئونة': u'وَمَئُونَةٍ', #8
u'ومئونته': u'وَمَئُونَتَهُ', #1
u'ومئونته': u'وَمَئُونَتِهِ', #1
u'ومئونتهم': u'وَمَئُونَتَهُمْ', #1
u'ومئونتهما': u'وَمَئُونَتُهُمَا', #1
u'ومياثر': u'وَمَيَاثِر', #1
u'ومياثر': u'وَمَيَاثِرِ', #1
u'وميافارقين': u'ومَيَّافَارِقِينِ', #1
u'ومية': u'وَمَيَّةَ', #1
u'وميثرة': u'وَمِيثَرَةِ', #1
u'وميثرة': u'وَمِيثَرَةَ', #7
u'وميدانم': u'وميدانم', #1
u'وميرتنا': u'وَمِيرَتِنَا', #4
u'وميره': u'وَمِيرَهْ', #2
u'وميري': u'وَمِيرِي', #1
u'وميرى': u'وَمِيرِى', #1
u'وميري': u'وَمِيرِيٍّ', #2
u'وميرية': u'وَمِيرِيَّةٌ', #1
u'وميسون': u'وَمَيْسُونُ', #1
u'وميشائيل،': u'وَمِيشَائِيلُ،', #1
u'وميقن': u'وَمُيْقَنٌ', #1
u'وميكال': u'وَمِيكَالَ', #22
u'وميكال': u'وَمِيكَالُ', #4
u'وميكائيل': u'وَمِيكَائيلَ', #1
u'وميكائيل،': u'وَمِيكَائِيلُ،', #11
u'وميكائيل': u'وَمِيكَائِيلُ', #32
u'وميكائيل،': u'وَمِيكَائِيلَ،', #4
u'وميكائيل': u'وَمِيكَائِيلَ', #55
u'ومينا': u'وَمَيْنًا', #4
u'ومينا': u'وَمَيْنَا', #4
u'وميولاتها': u'وَمُيُولَاتِهَا', #1
u'وميوها': u'وميوها', #1
u'وميئوسة': u'وَمَيْئُوسَةٌ', #1
u'ونأتى': u'وَنَأْتِىَ', #1
u'ونأحتها': u'وَنَأَحْتُهَا', #1
u'ونارنج': u'وَنَارَنْجٍ', #1
u'ونارنج': u'وَنَارِنْجٌ', #2
u'ونارنج': u'وَنَارِنْجٍ', #5
u'ونأرنجيل': u'وَنَأْرَنْجِيلٍ', #1
u'وناسور': u'وَنَاسُورٌ', #1
u'وناشروذ،': u'وناشروذ،', #1
u'وناصور': u'وَنَاصُورٌ', #2
u'وناصور': u'وَنَاصُورٍ', #6
u'وناضه': u'وَنَاضَّهُ', #1
u'وناطه': u'وَنَاطَهُ', #1
u'ونافجة': u'وَنَافِجَةُ', #4
u'وناقلى': u'وَنَاقِلِى', #1
u'وناكرده': u'وناكرده', #1
u'وناكور': u'وَنَاكُورُ', #2
u'وناهس': u'وَنَاهِسٌ', #1
u'وناهس': u'وَنَاهِسَ', #3
u'وناهس': u'وَنَاهِسُ', #4
u'وناهسا': u'وَنَاهِسًا', #1
u'وناووقها': u'وَنَاوُوقِهَا', #1
u'ونبطس': u'وَنَبْطَسُ', #1
u'ونبهرجة': u'وَنَبَهْرَجَةٌ', #2
u'ونبى': u'وَنَبِىٌّ', #1
u'ونبى': u'وَنَبِىٍّ', #1
u'ونبى': u'وَنَبِىُّ', #4
u'ونبيط': u'وَنُبَيطِ', #1
u'ونبيط': u'وَنُبَيْطَ', #1
u'ونبيى': u'وَنَبِيِّىَ', #1
u'ونتحاص': u'وَنَتَحَاصُّ', #1
u'ونتحجرها': u'وَنَتَحَجَّرُهَا', #2
u'ونتحذر': u'وَنَتَحَذّرُ', #1
u'ونتزوده': u'وَنَتَزَوَّدُهُ', #1
u'ونتكالأ،': u'وَنَتَكَالأُ،', #1
u'ونتناجز': u'وَنَتَنَاجَزُ', #1
u'ونثرث': u'وَنَثَرْثُ', #1
u'ونثلة': u'وَنَثْلَةٌ', #1
u'ونجانى': u'وَنَجَّانِى', #1
u'ونحتجرها': u'وَنَحْتَجِرُهَا', #2
u'ونحرماSقصيدة': u'وَنُحْرَمَاSقَصِيدَةُ', #1
u'ونحرما': u'وَنُحْرَمَا', #1
u'ونحفد': u'وَنَحْفِدُ', #40
u'ونحولته': u'وَنُحُولَتُهُ', #1
u'ونحوها': u'وَنَحْوِهًا', #2
u'ونحوهرأيت': u'وَنَحْوَهُرَأَيْتُ', #1
u'ونخسنى': u'وَنَخَسَنِى', #1
u'ونخماس': u'ونخماس', #1
u'ونخماس': u'وَنَخْمَاس', #1
u'ونخندقها': u'وَنُخَنْدِقُهَا', #1
u'ونخيلة': u'وَنَخِيلَةُ', #1
u'وندادا': u'وَنِدَادًا', #2
u'وندباردرد': u'وندباردرد', #1
u'ونذير': u'وَنَذِيرً', #1
u'ونردشير': u'ونردشير', #1
u'ونزائعا': u'وَنَزَائِعًا', #3
u'ونسباؤه': u'وَنُسَبَاؤُهُ', #3
u'ونستشفى': u'وَنَسْتَشْفِى', #1
u'ونستعفي': u'ونستعفي', #1
u'ونستعيذه': u'وَنَسْتَعِيذُهُ', #1
u'ونستنصرنا': u'وَنَسْتَنْصِرُنَا', #1
u'ونسجدها': u'وَنَسْجُدُهَا', #5
u'ونسخمهما،': u'ونُسَخِّمُهُمَا،', #1
u'ونسطور': u'وَنَسْطُور', #1
u'ونسكى': u'وَنُسُكِى', #8
u'ونسلؤها': u'وَنَسْلَؤُهَا', #1
u'ونسيبة': u'وَنَسِيبَةٍ', #1
u'ونشاء': u'وَنِشَاءً', #1
u'ونشاء': u'وَنَشَاءً', #3
u'ونشر': u'وَنَشْرً', #1
u'ونشصت': u'وَنَشَصَتْ', #1
u'ونشصت': u'وَنَشِصَتْ', #1
u'ونصاحية': u'وَنَصَاحِيَةً', #1
u'ونصبنى': u'وَنَصَبَنِى', #1
u'ونصرانة': u'وَنَصْرَانَةَ', #1
u'ونصرانى': u'وَنَصْرَانِىٍّ', #1
u'ونصرى': u'وَنَصْرَى', #1
u'ونصطبح': u'وَنَصْطَبِحُ', #2
u'ونصف': u'وَنِصْفً', #2
u'ونضاج': u'وَنِضَاجٌ', #1
u'ونضاجة': u'وَنَضَاجَةِ', #2
u'ونضاوة': u'وَنَضَاوَةٍ', #1
u'ونضاوة': u'وَنُضَاوَةٍ', #1
u'ونضضه': u'وَنَضَّضَهُ', #1
u'ونضلة': u'وَنَضْلَةُ', #1
u'ونضلة': u'وَنَضْلَةَ', #2
u'ونضوض': u'وَنَضُوضِ', #2
u'ونضيجة،': u'وَنَضِيجَةً،', #1
u'ونضيجة': u'وَنَضِيجَةً', #2
u'ونضيجه،': u'ونضيجه،', #1
u'ونضيجها': u'وَنَضِيجُهَا', #1
u'ونطاة': u'وَنَطَاةَ', #4
u'ونطاة': u'وَنَطَاةُ', #4
u'ونطراء': u'وَنُطَرَاءُ', #2
u'ونطشان': u'وَنَطْشَانَ', #1
u'ونظاوة': u'وَنَظَاوَةٍ', #1
u'ونعالات': u'وَنِعَالَاتٍ', #1
u'ونعيلة': u'وَنُعَيْلَةُ', #2
u'ونغبة': u'وَنَغْبَةٌ', #1
u'ونغتبق': u'وَنَغْتَبِقُ', #1
u'ونفطويه': u'وَنِفْطَوَيْهِ', #1
u'ونفهت': u'وَنَفِهَتِ', #1
u'ونفهت': u'وَنَفِهَتْ', #7
u'ونفيع': u'ونفيع', #1
u'ونفيع': u'وَنُفَيْعٌ', #2
u'ونقاية': u'وَنُقَايَةٌ', #1
u'ونقمى': u'وَنَقْمَى', #1
u'ونقوبها': u'وَنُقُوبُهَا', #1
u'ونقيمة': u'وَنَقِيمَةً', #1
u'ونكارةSفرض': u'وَنَكَارَةٌSفَرْضُ', #1
u'ونكلو': u'وَنَكَلُو', #1
u'ونمرود': u'وَنَمْرُودَ', #1
u'ونمرود': u'وَنُمْرُودَ', #1
u'ونميداند': u'ونميداند', #1
u'وننتهى': u'وَنَنْتَهِى', #1
u'ونهاس': u'وَنُهَاسٌ', #1
u'ونهانى': u'وَنَهَانِى', #6
u'ونهاوند': u'وَنَهَاوَنْدَ', #1
u'ونهاوند': u'وَنَهَاوَنْدُ', #1
u'ونهاوند،': u'وَنَهَاوَنْد،', #1
u'ونهشل': u'وَنَهْشَلٌ', #1
u'ونهنهت': u'وَنَهْنَهَتْ', #1
u'ونهنيه': u'وَنُهَنِّيهِ', #1
u'ونهير': u'ونهير', #1
u'ونهير': u'وَنُهَيْرُ', #2
u'ونهيهقوله': u'وَنَهْيِهِقَوْلُهُ', #1
u'ونواشغه': u'وَنَوَاشِغُهُ', #1
u'ونواقضه': u'وَنَوَاقِضُهُ', #6
u'ونواقضها': u'وَنَوَاقِضِهَا', #1
u'ونورة': u'وَنُورَة', #1
u'ونورة': u'وَنَوْرَةِ', #1
u'ونورة': u'وَنُورَةٍ', #17
u'ونورة': u'وَنَوْرَةٌ', #2
u'ونورة': u'وَنَوْرَةٍ', #21
u'ونوفل21548id': u'ونوفل21548id', #1
u'ونوكي': u'وَنُوكِي', #2
u'ونوكئ': u'وَنُوكِئَ', #2
u'ونومى': u'وَنَوِّمِى', #1
u'ونوو': u'وَنَوُو', #1
u'ونويرة': u'وَنُوَيْرَةُ', #1
u'ونئوب': u'وَنَئُوبُ', #1
u'ونياحة': u'وَنِيَاحَةٌ', #3
u'ونياحة': u'وَنِيَاحَةٍ', #8
u'ونيارامم': u'ونيارامم', #1
u'ونيسابور': u'وَنَيْسَابُورَ', #1
u'ونيص': u'وَنَيْصٍ', #1
u'ونيضالا': u'وَنِيضَالًا', #1
u'ونيضالا': u'وَنَيْضَالًا', #1
u'ونيلة': u'وَنِيلَةٍ', #6
u'ونيمسه': u'وَنِيمْسَهْ', #1
u'ونينوى': u'وَنِينَوَى', #1
u'ونينوى': u'وَنِينْوَى', #1
u'ونيئة': u'وَنِيئَةً', #5
u'ؤها': u'ؤُهَا', #1
u'وهابيل': u'وَهَابِيلُ', #2
u'وهابيل': u'وَهَابِيلَ', #7
u'وهاذم': u'وَهَاذِمٌ', #2
u'وهاذم': u'وَهَاذِمِ', #2
u'وهاذم': u'وَهَاذِمُ', #5
u'وهاذما': u'وَهَاذِمًا', #2
u'وهاروت': u'وَهَارُوتَ', #2
u'وهاروت': u'وَهَارُوتُ', #3
u'وهأنذا،': u'وَهَأَنَذَا،', #1
u'وهأنذا': u'وَهَأَنَذَا', #3
u'وهاه': u'وَهَاهْ', #1
u'وهاه': u'وَهَّاهُ', #2
u'وهاها': u'وَهَّاهَا', #1
u'وهاؤما': u'وَهَاؤُمَا', #1
u'وهاؤن': u'وَهَاؤُنْ', #1
u'وهايأ': u'وَهَايَأَ', #1
u'وهاية': u'وِهَايَةُ', #1
u'وهب،': u'وَهْبً،', #1
u'وهبار': u'وَهَبّارِ', #1
u'وهبار': u'وَهَبَّارُ', #1
u'وهبار': u'وَهَبَّارِ', #1
u'وهبار': u'وَهَبّارُ', #3
u'وهبار': u'وَهَبَّارَ', #3
u'وهبانية': u'وَهْبَانِيَّةٌ', #19
u'وهبانية': u'وَهْبَانِيَّةٍ', #46
u'وهبتكه': u'وَهَبْتُكَهُ', #12
u'وهبتكها': u'وَهَبْتُكَهَا', #2
u'وهبتكها': u'وَهَبْتُكهَا', #4
u'وهبتنيه': u'وَهَبَتْنِيهِ', #2
u'وهبتنيه': u'وَهَبْتنِيهِ', #3
u'وهبتنيه': u'وَهَبْتَنِيهِ', #6
u'وهبتنيها': u'وَهَبْتنِيهَا', #2
u'وهبتنيها': u'وَهَبْتَنِيهَا', #2
u'وهبعة': u'وَهُبَعَةَ', #1
u'وهبعن': u'وَهْبٍعَنْ', #1
u'وهبفي': u'وَهْبٍفِي', #1
u'وهبكه': u'وَهَبَكَهُ', #2
u'وهبلع': u'وَهِبْلَعٌ', #1
u'وهبنيه': u'وَهَبَنِيهِ', #2
u'وهبنيها': u'وَهَبَنِيهَا', #1
u'وهبوالقعنبي': u'وَهْبٍوَالْقَعْنَبِيُّ', #1
u'وهبيرة': u'وهُبَيْرة', #1
u'وهبيرة': u'وهُبَيْرَة', #1
u'وهبيرة': u'وَهُبَيْرَةُ', #13
u'وهبيرة': u'وَهُبَيْرَةَ', #9
u'وهتيكة': u'وَهَتِيكَةً', #1
u'وهجرع': u'وَهِجْرَعٌ', #1
u'وهجمين': u'وهجمين', #1
u'وهجهجه': u'وَهَجْهَجَهُ', #1
u'وهدءوا،': u'وَهَدَءُوا،', #1
u'وهدءوا': u'وَهَدَءُوا', #3
u'وهدوا': u'وَهُدُوًّا', #1
u'وهذ': u'وَهَذّ', #1
u'وهذا': u'وَهَذًّا', #1
u'وهذأ': u'وَهَذَأ', #3
u'وهذم': u'وَهَذَمَ', #3
u'وهذيل': u'وهُذَيل', #2
u'وهذيل': u'وَهُذَيْلٍ', #2
u'وهذيل': u'وَهُذَيْلَ', #3
u'وهذيل': u'وَهُذَيْلٌ', #4
u'وهذيم': u'وَهُذَيْمٌ', #1
u'وهذيم': u'وَهُذَيْمِ', #1
u'وهراة،': u'وهُرَاة،', #1
u'وهراة': u'وَهَرَاةَ', #3
u'وهراديه': u'وهراديه', #1
u'وهراديه': u'وَهَرَادِيهُ', #1
u'وهراديه': u'وَهَرَادِيهِ', #4
u'وهراق': u'وَهَرَاقَ', #3
u'وهراقه': u'وَهَرَاقَهُ', #1
u'وهرام،': u'وَهْرَامٍ،', #1
u'وهرام،': u'وَهْرَامَ،', #17
u'وهرام': u'وَهْرَامٍ', #3
u'وهرام': u'وَهْرَامَ', #8
u'وهرامسة': u'وَهَرَامِسَةُ', #1
u'وهراويه': u'وَهَرَاوِيهِ', #1
u'وهربار': u'وهربار', #1
u'وهرز': u'وهرز', #1
u'وهرز': u'وَهْرَزَ', #1
u'وهرز': u'وَهْرِز', #13
u'وهرز': u'وَهْرِزَ', #8
u'وهرز': u'وَهْرِزُ', #8
u'وهرزمان': u'وهرزمان', #1
u'وهركاه': u'وهركاه', #1
u'وهركه': u'وهركه', #1
u'وهروقت': u'وهروقت', #1
u'وهريق': u'وَهُرِيقَ', #1
u'وهريقوا': u'وَهَرِيقُوا', #1
u'وهريم': u'وَهُرَيْمٌ', #1
u'وهريم': u'وَهُرَيْمِ', #1
u'وهريم،': u'وَهُرَيْمٌ،', #1
u'وهريم': u'وَهُرَيْمُ', #5
u'وهزؤ': u'وَهُزُؤٌ', #1
u'وهصيص': u'وَهُصَيْصَ', #2
u'وهطه': u'وَهْطُهُ', #1
u'وهق': u'وَهَقٍ', #1
u'وهق': u'وَهْقٍ', #1
u'وهق': u'وَهَقٌ', #2
u'وهق': u'وَهْقٌ', #2
u'وهقب': u'وَهِقَبْ', #1
u'وهقط': u'وَهِقَطْ', #1
u'وهقط': u'وَهِقِطْ', #2
u'وهقل': u'وَهِقْلُ', #1
u'وهكر': u'وَهَكِرٍ', #1
u'وهللاني': u'وَهَلِّلَانِي', #2
u'وهللني': u'وَهَلَّلَنِي', #1
u'وهلممن': u'وَهَلْمُمْنَ', #1
u'وهلممنان': u'وَهَلْمُمْنَانِ', #1
u'وهلموا': u'وَهَلُمُّوا', #1
u'وهلى': u'وَهَلَى', #1
u'وهلى': u'وَهَلِى', #1
u'وهمجنين': u'وهمجنين', #2
u'وهمدانيين': u'وَهَمْدَانِيَّيْنِ', #1
u'وهمزان': u'وَهَمَزَانَ', #1
u'وهمكين': u'وهمكين', #1
u'وهمهمه': u'وَهَمْهَمَهْ', #2
u'وهمو': u'وَهُمُو', #1
u'وهميانا': u'وَهِمْيَانًا', #1
u'وهميانه': u'وَهِمْيَانَهُ', #1
u'وهميشة': u'وَهَمِيشَة', #1
u'وهنأنى': u'وَهَنَّأَنِى', #2
u'وهنجه': u'وهنجه', #2
u'وهندبا': u'وَهِنْدَبًا', #1
u'وهندباء': u'وَهِنْدِبَاء', #1
u'وهندباء': u'وَهِنْدِبَاءَ', #1
u'وهنوة': u'وَهَنْوَةٌ', #1
u'وهنون': u'وَهَنُونَ', #1
u'وهنيدة': u'وَهُنَيْدَةَ', #1
u'وههوذا': u'وَهَهُوَذَا', #1
u'وهوأحد': u'وهوأحد', #1
u'وهوازن': u'وَهَوَازِنَ', #17
u'وهوازن': u'وَهَوَازِنُ', #5
u'وهواكا': u'وَهَوَاكَا', #2
u'وهوالأظهر': u'وَهُوَالْأَظْهَرُ', #1
u'وهوالوجه': u'وَهُوَالْوَجْهُ', #1
u'وهوبا': u'وَهُوبَا', #1
u'وهوببقيع': u'وَهُوَبِبَقِيعِ', #1
u'وهوبر': u'وَهَوْبَرُ', #2
u'وهوذة،': u'وهوذة،', #1
u'وهوذة،': u'وهوْذَة،', #1
u'وهوذة،': u'وَهَوْذَةَ،', #1
u'وهوذة': u'وَهَوْذَةُ', #11
u'وهوذة': u'وَهَوْذَةَ', #6
u'وهوغضبان': u'وَهُوَغَضْبَانُ', #1
u'وهوقائم': u'وَهُوَقَائِمٌ', #1
u'وهووراء': u'وَهُوَوَرَاءَ', #1
u'وهويدعوهم': u'وَهُوَيَدْعُوهُمْ', #1
u'وهويسه': u'وَهَوِيسه', #1
u'وهويسه': u'وَهَوِيسِهِ', #1
u'وهويقول': u'وَهُوَيَقُولُ', #1
u'وهى': u'وَهًى', #3
u'وهية': u'وَهِيَّةٍ', #1
u'وهيشات': u'وَهَيْشَاتِ', #4
u'ووا': u'وَوَا', #1
u'ووابصة': u'ووابصة', #1
u'ووابصة': u'وَوَابِصَةُ', #2
u'وواثلة': u'وَوَاثِلَةِ', #1
u'وواثلة': u'وَوَاثِلَةَ', #15
u'وواثلة': u'وواثلة', #2
u'وواثلة': u'وَوَاثِلَةُ', #7
u'وواثله': u'وَوَاثِلَهْ', #2
u'وواجر': u'وَوَاجِرْ', #1
u'وواخيت': u'وَوَاخَيْتُ', #1
u'ووادى': u'وَوَادَى', #1
u'ووادى': u'وَوَادِى', #1
u'وواسانى': u'وَوَاسَانِى', #1
u'وواقد': u'وواقد', #1
u'وواقد': u'وَوَاقِدٍ', #1
u'وواقد': u'وَوَاقِدُ', #16
u'وواقد': u'وَوَاقِدٌ', #2
u'وواقفية': u'وَوَاقِفِيَّةٍ', #4
u'ووالان': u'وَوَالانُ', #1
u'ووالان': u'وَوَالَانُ', #1
u'ووالسماء': u'وَوَالسَّمَاءِ', #2
u'ووالله': u'وواللَّه', #1
u'ووالله': u'وَوَالله', #1
u'ووالله': u'وَوَاللّهِ', #11
u'ووالله': u'وَوَاللهِ', #2
u'ووالله': u'وَوَاللَّهِ', #74
u'ووامى': u'ووامى', #1
u'ووائل،': u'وَوَائِلٍ،', #1
u'ووائل': u'وَوَائِلٍ', #11
u'ووائل': u'وَوَائِل', #4
u'ووائل': u'وَوَائِلٌ', #5
u'ووائل': u'وَوَائِلُ', #5
u'ووائل': u'وَوَائِلِ', #6
u'ووائلة': u'وَوَائِلَةُ', #1
u'ووائلة': u'وَوَائِلَةَ', #2
u'ووبص': u'وَوَبَصَ', #1
u'ووترة': u'وَوَتْرَةٌ', #1
u'ووثأتها': u'وَوَثَأْتهَا', #1
u'ووجأ': u'وَوَجَأَ', #2
u'ووجاء': u'وَوِجَاءً', #1
u'ووجاء': u'وَوِجَاءٍ', #2
u'ووجاءة': u'وَوِجَاءَةٍ', #1
u'ووجأه': u'وَوَجَأَهُ', #2
u'ووجائبه': u'ووجائبه', #1
u'ووجائهما': u'وَوِجَائِهِمَا', #1
u'ووجرة': u'وَوَجْرَةُ', #1
u'ووجهنى': u'وَوَجِّهْنِى', #1
u'ووجوهم': u'وَوَجَوْهُمْ', #1
u'ووجئ': u'وَوَجِئَ', #1
u'ووجيفا': u'وَوَجِيفًا', #1
u'ووخش': u'وَوَخْشٌ', #1
u'ووخش': u'وَوَخْشِ', #4
u'ووخشه': u'وَوَخْشِهِ', #1
u'ووديعت': u'ووديعت', #1
u'ووراشين': u'وَوَرَاشِينُ', #1
u'وورثنى': u'وَوَرِثَنِى', #1
u'وورخه': u'وَوَرَّخَهُ', #1
u'وورية': u'وَوْرَيَةٌ', #1
u'ووزانين': u'وَوَزَّانِينَ', #1
u'ووزغات': u'وَوَزَغَاتٌ', #2
u'ووشاق': u'وَوُشَّاق', #1
u'ووضاعين': u'وَوَضَّاعِينَ', #1
u'ووضر': u'وَوَضَرَ', #1
u'ووضرا': u'وَوَضَرًا', #1
u'ووضم': u'وَوَضْمُ', #1
u'ووضو': u'وَوُضُو', #1
u'ووضوءان': u'وَوُضُوءَانِ', #3
u'ووضيمة': u'وَوَضِيمَةٌ', #4
u'ووطبة': u'وَوَطْبَةً', #3
u'ووطىء': u'وَوَطِىءَ', #1
u'ووطيناهم': u'وَوَطَيْنَاهُمْ', #1
u'ووعدنى': u'وَوَعَدَنِى', #2
u'ووغى': u'وَوَغًى', #1
u'ووفا': u'وَوَفَا', #1
u'ووقاح': u'وَوَقَاحٌ', #1
u'ووقاص': u'ووقاص', #1
u'ووقانى': u'وَوَقَانِى', #1
u'ووقائعة': u'وَوَقَائِعَةٌ', #1
u'ووقذه': u'وَوَقَذَهُ', #3
u'ووقص': u'وَوَقْصٍ', #1
u'ووقص': u'وَوَقْصُ', #1
u'ووقصت': u'وَوَقَصَتْ', #1
u'ووقصتك': u'وَوَقَصَتْك', #1
u'ووقصها': u'وَوَقَصُهَا', #1
u'ووقفيته': u'وَوَقْفِيَّتِهِ', #1
u'ووقمدوا': u'ووقمدوا', #1
u'ووقوت': u'وَوُقُوتٍ', #1
u'ووقوى': u'وَوَقْوَى', #1
u'ووكادة': u'وَوَكَادَةً', #1
u'ووكادة': u'وَوَكَادَةِ', #1
u'ووكادته': u'وَوَكَادَتَهُ', #1
u'ووكع': u'وَوَكَعٍ', #1
u'ووكيد': u'وَوَكِيدِ', #1
u'ووكيع': u'وَوِكيعٍ', #1
u'ووكيع،': u'وَوَكَيِعٍ،', #1
u'ووكيع': u'وَوَكِيعٌ', #138
u'ووكيع': u'وَوَكِيع', #2
u'ووكيع،': u'ووكيع،', #25
u'ووكيع،': u'وَوَكِيعٌ،', #27
u'ووكيع': u'وَوَكِيعُ', #3
u'ووكيع': u'وَوَكِيعِ', #4
u'ووكيع': u'وَوَكِيعٍ', #48
u'ووكيع': u'ووكيع', #5
u'ووكيع،': u'وَوَكِيعٍ،', #97
u'ووكيعا': u'وَوَكِيعًا', #4
u'ووكيع،عن': u'وَوَكِيعٌ،عَنْ', #1
u'ووكيلئى': u'ووكيلئى', #1
u'وولاد': u'وَوِلَادٍ', #1
u'وولادا': u'وَوِلَادًا', #1
u'وولجمها': u'وَوَلَجَمَهَا', #1
u'وولدى': u'وَوَلَدِى', #5
u'وونسك': u'وَوَنَسَكِ', #1
u'وونيم': u'وَوَنِيمُ', #1
u'وونيم': u'وَوَنِيمِ', #14
u'ووه': u'ووه', #1
u'ووهاء': u'وَوَهَاءٌ', #1
u'ووهاطها': u'وَوِهَاطَهَا', #2
u'ووهاه': u'وَوَهَّاهُ', #3
u'ووهبا': u'وَوَهَبًا', #1
u'ووهبا': u'وَوَهْبًا', #3
u'ووهبانية': u'وَوَهْبَانِيَّةٌ', #1
u'ووهرز': u'وَوَهْرَزَ', #1
u'ووهوب': u'وَوَهُوبٌ', #1
u'ووهيب،': u'وَوهَيْبٌ،', #1
u'ووهيب،': u'وَوُهَيْبٍ،', #2
u'ووهيب': u'وَوُهَيْبٍ', #3
u'ووهيب،': u'وَوُهَيْبٌ،', #4
u'ووهيب': u'وَوُهَيْبُ', #7
u'ووهيب': u'وَوُهَيْبٌ', #8
u'ووى': u'ووى', #3
u'وويبات': u'وَوَيْبَاتٍ', #1
u'وويبة': u'وَوَيْبَةً', #2
u'وويبة': u'وَوَيْبَةٌ', #5
u'وويبة': u'وَوَيْبَةٍ', #6
u'وويرا': u'وويرا', #1
u'وويغث': u'وَوَيْغَثُ', #1
u'وى': u'وَى', #2
u'وى': u'وى', #73
u'وئاب،': u'وئاب،', #1
u'ويا': u'ويا', #2
u'ويا': u'وَيَا', #426
u'ويأبق': u'وَيَأْبِقُ', #1
u'ويأبق': u'وَيَأْبَقُ', #2
u'ويابني،': u'ويابني،', #2
u'ويأبيه': u'وَيَأْبِيهِ', #1
u'ويأتدموها': u'وَيَأْتَدِمُوهَا', #1
u'ويأتنف': u'وَيَأْتَنِفَ', #2
u'ويأتنفان': u'وَيَأْتَنِفَانِ', #8
u'ويأتى': u'وَيَأْتِى', #8
u'ويأتيان': u'وَيَأْتِيَانِ', #7
u'وياجرا': u'وياجرا', #1
u'ويأجوج': u'وَيَأَجُوجُ', #1
u'ويأجوج': u'وَيَأْجُوجَ', #6
u'ويأجوج': u'وَيَأْجُوجُ', #7
u'ويأذنه': u'وَيَأْذَنَهُ', #1
u'ويأذنه': u'وَيَأْذَنُهُ', #1
u'ويازده': u'ويازده', #4
u'وىازروى': u'وىازروى', #1
u'ويافا': u'وَيَافَا', #1
u'ويافاء': u'وَيَافَاءَ', #1
u'ويافتم': u'ويافتم', #1
u'ويافث': u'وَيَافِثٌ', #1
u'ويافث،': u'وَيَافِثٌ،', #1
u'ويافث': u'وَيَافِثُ', #12
u'ويافث': u'وَيَافِثَ', #2
u'وياقطين': u'وَيَاقْطِينٍ', #1
u'ويالله': u'وَيَاللَّهِ', #2
u'ويام': u'وَيَام', #1
u'ويام': u'وَيَامٌ', #1
u'ويام': u'وَيَامُ', #1
u'ويام': u'ويام', #2
u'ويام': u'وَيَامٍ', #2
u'ويأمرنى': u'وَيَأْمُرُنِى', #2
u'وياممته': u'وَيَامَمْتُهُ', #1
u'ويايكى': u'ويايكى', #1
u'ويباعدنى': u'وَيُبَاعِدُنِى', #2
u'ويباهل': u'وَيُبَاهِلُ', #2
u'ويباين': u'وَيُبَايَن', #1
u'ويباين': u'وَيُبَايِنُ', #10
u'ويباين': u'وَيُبَايَنُ', #17
u'ويباين': u'وَيُبَايِنَ', #9
u'ويبايناها': u'وَيُبَايِنَاهَا', #1
u'ويباينها': u'وَيُبَايِنَهَا', #1
u'ويباينها': u'وَيُبَايِنُهَا', #2
u'ويباينهما': u'وَيُبَايِنهُمَا', #1
u'ويباينهما': u'وَيُبَايِنُهُمَا', #4
u'ويباينهن': u'وَيُبَايِنُهُنَّ', #1
u'ويبة': u'وَيْبَةً', #12
u'ويبة': u'وَيْبَةِ', #3
u'ويبة': u'وَيْبَةٌ', #7
u'ويبة': u'وَيْبَةٍ', #9
u'ويبتدي': u'وَيَبْتَدِي', #1
u'ويبتدئان': u'وَيَبْتَدِئَانِ', #2
u'ويبتدينا': u'وَيَبْتَدِينَا', #1
u'ويبتديه': u'وَيَبْتَدِيهِ', #6
u'ويبتضعون': u'وَيَبْتَضِعُونَ', #1
u'ويبتهرها': u'وَيَبْتَهِرُهَا', #1
u'ويبتين': u'وَيْبَتَيْنِ', #2
u'ويبدءوا': u'وَيَبْدَءُوا', #4
u'ويبدءون': u'وَيَبْدَءُونَ', #4
u'ويبديان': u'وَيُبْدِيَانِ', #1
u'ويبرءوا': u'وَيَبْرَءُوا', #1
u'ويبرءون': u'وَيَبْرَءُونَ', #7
u'ويبرآن': u'وَيَبْرَآنِ', #3
u'ويبرؤ': u'وَيَبْرُؤُ', #1
u'ويبسطنى': u'وَيَبْسُطُنِى', #1
u'ويبط': u'وَيَبُطَّ', #1
u'ويبط': u'وَيَبُطُّ', #1
u'ويبعج': u'وَيَبْعَجُ', #1
u'ويبعج': u'وَيُبْعَجُ', #11
u'ويبعضها': u'وَيُبَعِّضُهَا', #1
u'ويبغامبر': u'ويبغامبر', #1
u'ويبقيان': u'وَيَبْقَيَانِ', #12
u'ويبكت': u'وَيُبَكَّتَ', #1
u'ويبندقها': u'وَيُبَنْدِقُهَا', #1
u'ويبنيان': u'وَيَبْنِيَانِ', #6
u'ويت': u'وَيْتَ', #1
u'ويتأتيان': u'وَيَتَأَتَّيَانِ', #2
u'ويتاجرهم': u'وَيُتَاجِرُهُمْ', #1
u'ويتأدم': u'وَيَتَأَدَّمُ', #1
u'ويتأدمون': u'وَيَتَأَدَّمُونَ', #4
u'ويتأدى': u'وَيَتَأَدَّى', #21
u'ويتأديان': u'وَيَتَأَدَّيَانِ', #1
u'ويتأديانها': u'وَيَتأَدَّيانِهَا', #1
u'ويتأدياها': u'وَيَتَأَدَّيَاهَا', #1
u'ويتأذون': u'وَيَتَأَذَّوْنَ', #3
u'ويتأذى': u'وَيَتَأَذَّى', #26
u'ويتأقت': u'وَيَتَأَقَّتُ', #1
u'ويتألفهم': u'وَيَتَأَلَّفُهُمْ', #1
u'ويتباذلون': u'وَيَتَبَاذَلُونَ', #1
u'ويتباريان': u'وَيَتَبَارَيَانِ', #1
u'ويتبايعونه': u'وَيَتَبَايَعُونَهُ', #3
u'ويتبرءون': u'وَيَتَبَرَّءُونَ', #2
u'ويتبرى': u'وَيَتَبَرَّى', #1
u'ويتبزل': u'وَيَتَبَزَّلُ', #1
u'ويتبطن': u'وَيَتَبَطَّنُ', #1
u'ويتبعض': u'وَيَتَبَعَّضُ', #4
u'ويتتعتع': u'وَيَتَتَعْتَعُ', #4
u'ويتجرجر': u'وَيَتَجَرْجَرُ', #1
u'ويتجره': u'وَيَتْجُرُهُ', #1
u'ويتجلجل': u'وَيَتَجَلْجَلُ', #2
u'ويتجهر': u'وَيَتَجَهَّرُ', #1
u'ويتحاص': u'وَيَتَحَاصُّ', #9
u'ويتحاصان': u'وَيَتَحَاصَّانِ', #6
u'ويتحاصص': u'وَيَتَحَاصَصُ', #6
u'ويتحاصون': u'وَيَتَحَاصُّونَ', #12
u'ويتحالان': u'وَيَتَحَالَّانِ', #5
u'ويتحتم': u'وَيَتَحَتَّمُ', #9
u'ويتحذر': u'وَيَتَحَذَّرُ', #1
u'ويتحطبون': u'وَيَتَحَطَّبُونَ', #1
u'ويتحيل': u'وَيَتَحَيَّلُ', #1
u'ويتحيلون': u'وَيَتَحَيَّلُونَ', #1
u'ويتخالج': u'وَيَتَخَالَجُ', #1
u'ويتخالجها': u'وَيَتَخَالَجُهَا', #1
u'ويتخايرا': u'وَيَتَخَايَرَا', #1
u'ويتخايران': u'وَيَتَخَايَرَانِ', #3
u'ويتختم': u'وَيَتَخَتَّمُ', #10
u'ويتخرص': u'وَيَتَخَرَّصُ', #7
u'ويتخصر': u'وَيَتَخَصَّرُ', #1
u'ويتخلد': u'وَيَتَخَلَّدُ', #1
u'ويتدارون': u'وَيَتَدَارَوْنَ', #1
u'ويتدانى': u'وَيَتَدَانَى', #1
u'ويتدبق': u'وَيَتَدَبَّقُ', #1
u'ويتدلس': u'وَيَتَدَلَّسَ', #1
u'ويتدلس': u'وَيَتَدَلَّسُ', #1
u'ويتذكرنى': u'ويتذكرنى', #1
u'ويتراجزون': u'وَيَتَرَاجَزُونَ', #1
u'ويتراد': u'وَيَتَرَادُّ', #2
u'ويتراد': u'وَيَتَرَادَّ', #3
u'ويترادا': u'وَيَتَرَادَّا', #2
u'ويترادان': u'وَيُتَرَادَّانِ', #10
u'ويترادان': u'وَيَتَرَادَّانِ', #80
u'ويترادون': u'وَيَتَرَادُّونَ', #2
u'ويتراضيان': u'وَيَتَرَاضَيَانِ', #1
u'ويتربح': u'وَيَتَرَبَّحُ', #1
u'ويترخص': u'وَيَتَرَخَّصَ', #1
u'ويترخص': u'وَيُتَرَخَّصُ', #2
u'ويترخص': u'وَيَتَرَخَّصُ', #3
u'ويتزوده': u'وَيَتَزَوَّدُهُ', #1
u'ويتزيد': u'وَيَتَزَيَّدُ', #1
u'ويتساويان': u'وَيَتَسَاوَيَانِ', #5
u'ويتسجى': u'وَيَتَسَجَّى', #1
u'ويتسحر': u'وَيَتَسحَّرُ', #1
u'ويتسحر': u'وَيَتَسَحَّرُ', #1
u'ويتسحر': u'وَيَتَسَحَّرَ', #2
u'ويتسخط': u'وَيَتَسَخَّط', #1
u'ويتسخط': u'وَيَتَسَخَّطُ', #1
u'ويتسرى': u'وَيَتَسَرَّى', #3
u'ويتسوف': u'وَيَتَسَوَّفَ', #1
u'ويتسوف': u'وَيَتَسَوَّفُ', #1
u'ويتسوك': u'وَيَتَسَوَّكَ', #1
u'ويتشرب': u'وَيَتَشَرَّبُ', #3
u'ويتشطر': u'وَيَتَشَطَّرُ', #14
u'ويتصفى': u'وَيَتَصَفَّى', #1
u'ويتصلف': u'وَيَتَصَلَّفَ', #1
u'ويتضعف': u'وَيَتَضَعَّفُ', #1
u'ويتطلس': u'وَيَتَطَلَّسَ', #1
u'ويتطوقونه': u'وَيَتَطَوَّقُونَهُ', #1
u'ويتطيلس': u'وَيَتَطَيْلَسُ', #2
u'ويتطيلس': u'وَيَتَطَيْلَسَ', #4
u'ويتعاقل': u'وَيَتَعَاقَلُ', #5
u'ويتعسس': u'وَيَتَعَسَّسُ', #1
u'ويتعنتونه': u'وَيَتَعَنّتُونَهُ', #4
u'ويتعير': u'وَيَتَعَيَّرُ', #1
u'ويتعيرون': u'وَيَتَعَيَّرُونَ', #14
u'ويتغاشون': u'وَيَتَغَاشَوْنَ', #1
u'ويتغالى': u'وَيَتَغَالَى', #1
u'ويتفاصلا': u'وَيَتَفَاصَلَا', #2
u'ويتفاقرون': u'وَيَتَفَاقَرُونَ', #1
u'ويتقابضا': u'وَيَتَقَابَضَا', #8
u'ويتقابضان': u'وَيَتَقَابَضَانِ', #3
u'ويتقاص': u'وَيَتَقَاصُّ', #1
u'ويتقاصا': u'وَيَتَقَاصَّا', #1
u'ويتقاصان': u'وَيَتَقَاصَّانِ', #29
u'ويتقايأه': u'وَيَتَقَايَأَهُ', #5
u'ويتقايؤه': u'وَيَتَقَايَؤُهُ', #1
u'ويتقسط': u'وَيَتَقَسَّطُ', #4
u'ويتقفرون': u'وَيَتَقَفَّرُونَ', #1
u'ويتقمقم': u'وَيَتَقَمْقَمُ', #1
u'ويتقيأه': u'وَيَتَقَيَّأَهُ', #2
u'ويتكافآن': u'وَيَتَكَافَآنِ', #1
u'ويتكتم': u'وَيَتَكَتَّمُ', #1
u'ويتكنزها،': u'وَيَتَكَنَّزُهَا،', #1
u'ويتلاحن': u'وَيَتَلاحَنُ', #1
u'ويتلاحن،': u'وَيَتَلاحَنَ،', #1
u'ويتلازمان': u'وَيَتَلَازَمَانِ', #1
u'ويتلمح': u'وَيَتَلَمَّحُ', #1
u'ويتلمح': u'وَيُتَلَمَّحُ', #1
u'ويتلمظ،': u'وَيَتَلَمَّظُ،', #1
u'ويتمالئون': u'وَيَتَمَالَئُونَ', #1
u'ويتمحض': u'وَيَتَمَحَّضُ', #1
u'ويتمحلوا': u'وَيَتَمَحَّلُوا', #2
u'ويتمدح': u'وَيَتَمَدَّحُ', #1
u'ويتمعر': u'وَيَتَمَعَّرُ', #1
u'ويتمعش': u'وَيَتَمَعَّشُ', #1
u'ويتناصفانه': u'وَيَتَنَاصَفَانِهِ', #3
u'ويتناصفاه': u'وَيَتَنَاصَفَاهُ', #1
u'ويتناصفاها': u'وَيَتَنَاصَفَاهَا', #1
u'ويتنخعه': u'وَيَتَنَخَّعُهُ', #1
u'ويتهادينه': u'وَيَتَهَادَيْنَهُ', #1
u'ويتهايأ': u'وَيَتَهَايَأُ', #1
u'ويتهايآن': u'وَيَتَهَايَآنِ', #1
u'ويتهايئون': u'وَيَتَهَايَئُونَ', #4
u'ويتهبه': u'وَيَتَّهِبُهُ', #1
u'ويتهيئوا': u'وَيَتَهَيَّئُوا', #1
u'ويتهيئون': u'وَيَتَهَيَّئُونَ', #1
u'ويتواطآن': u'وَيَتَوَاطَآنِ', #1
u'ويتواطئوا': u'وَيَتَوَاطَئُوا', #1
u'ويتوجأ': u'وَيَتَوَجَّأُ', #1
u'ويتوضئوا': u'وَيَتَوَضَّئُوا', #1
u'ويتوضئون': u'وَيَتَوَضّئُونَ', #1
u'ويتوقت': u'وَيَتَوَقَّتُ', #1
u'ويثفل': u'وَيُثْفَلَ', #1
u'ويثيع': u'وَيَثِيعُ', #1
u'ويجاسر': u'وَيُجَاسِرُ', #1
u'ويجتري': u'وَيَجْتَرِي', #1
u'ويجتزأ': u'وَيَجْتَزِأُ', #1
u'ويجتزأ': u'وَيُجْتَزَأُ', #7
u'ويجتزى': u'وَيُجْتَزَى', #2
u'ويجتزي': u'وَيَجْتَزِي', #4
u'ويجتزئ': u'وَيَجْتَزِئ', #1
u'ويجتزئ': u'وَيَجْتَزِئُ', #10
u'ويجحفها': u'وَيُجْحِفُهَا', #1
u'ويجرجم': u'وَيُجَرْجَمُ', #1
u'ويجريان': u'وَيُجْرِيَانِ', #1
u'ويجريان': u'وَيَجْرِيَانِ', #67
u'ويجزئان': u'وَيُجْزِئَانِ', #2
u'ويجزيان': u'وَيَجْزِيَانِ', #1
u'ويجنأ': u'وَيَجْنَأُ', #1
u'ويجنئ': u'وَيُجْنِئُ', #1
u'ويجهرالمأموم': u'وَيَجْهَرُالْمَأْمُومُ', #1
u'ويجىء': u'وَيَجِىءُ', #7
u'ويحابر': u'وَيُحَابِرُ', #2
u'ويحاس': u'وَيُحَاسُ', #1
u'ويحاص': u'وَيُحَاصُّ', #32
u'ويحاص': u'وَيُحَاصَّ', #8
u'ويحاصص': u'ويحاصص', #1
u'ويحاصص': u'وَيُحَاصِصَ', #20
u'ويحاصص': u'وَيُحَاصِصُ', #38
u'ويحاصص': u'وَيُحَاصَصُ', #4
u'ويحاصصهم': u'وَيُحَاصِصُهُمْ', #1
u'ويحاصصونهم': u'وَيُحَاصِصُونَهُمْ', #1
u'ويحاصه': u'وَيُحَاصُّهُ', #2
u'ويحاصهم': u'وَيُحَاصُّهُمْ', #2
u'ويحتاجه': u'وَيَحْتَاجُهُ', #4
u'ويحتاجها': u'وَيَحْتَاجُهَا', #1
u'ويحتجره': u'وَيَحْتَجِرهُ', #1
u'ويحتجرها': u'وَيَحْتَجِرهَا', #1
u'ويحتجرها': u'وَيَحْتَجِرُهَا', #1
u'ويحتجم': u'وَيَحْتَجِمَ', #4
u'ويحتش': u'وَيَحْتَشَّ', #1
u'ويحتش': u'وَيَحْتَشُّ', #1
u'ويحتشي': u'وَيَحْتَشِي', #1
u'ويحتق': u'وَيُحْتَقُّ', #1
u'ويحثي': u'وَيَحْثِي', #1
u'ويحثيه': u'وَيَحْثِيهِ', #1
u'ويحذرناه': u'وَيُحَذِّرُنَاهُ', #1
u'ويحذرناه،': u'وَيُحَذِّرَنَاهُ،', #1
u'ويحفي': u'وَيُحْفِيَ', #4
u'ويحنة': u'وَيُحَنّةَ', #1
u'ويحنس': u'وَيُحَنِّسُ', #1
u'ويحنس': u'وَيُحَنّسُ', #5
u'ويحيى': u'وَيَحْيى', #1
u'ويحيى،': u'ويحيى،', #10
u'ويحيى': u'وَيُحْيِى', #3
u'ويحيى': u'ويحيى', #44
u'ويحيى،': u'وَيَحْيَى،', #71
u'ويحيى': u'وَيَحْيَى', #953
u'ويخارج': u'وَيُخَارَجُ', #3
u'ويخببوا': u'وَيُخَبَّبُوا', #1
u'ويخبرنى': u'وَيُخْبِرُنِى', #1
u'ويخزيان': u'وَيُخْزَيَانِ', #1
u'ويخضخض': u'وَيُخَضْخَضُ', #3
u'ويخضخضه': u'وَيُخَضْخِضُهُ', #2
u'ويخفيان': u'وَيُخْفِيَانِ', #2
u'ويدالون': u'وَيُدَالُونَ', #2
u'ويدرءون': u'وَيَدْرَءُونَ', #5
u'ويدرأون': u'وَيَدْرَأونَ', #1
u'ويدرأون': u'وَيَدْرَأُونَ', #3
u'ويدرؤه': u'وَيَدْرَؤُهُ', #1
u'ويدعوان': u'وَيَدْعُوَانِ', #1
u'ويدعيان': u'وَيُدْعَيَانِ', #2
u'ويدعيان': u'وَيَدَّعِيَانِ', #5
u'ويدولبهم': u'وَيُدَوْلِبُهُمْ', #1
u'ويديل': u'وَيُدِيلُ', #1
u'ويذكرونى': u'وَيَذْكُرُونِى', #1
u'ويذير': u'ويذير', #2
u'ويذيرفت': u'ويذيرفت', #1
u'ويرا': u'ويرا', #7
u'ويرادرين': u'ويرادرين', #1
u'ويراست': u'ويراست', #1
u'ويراشوى': u'ويراشوى', #1
u'ويرامغ': u'ويرامغ', #1
u'ويرانى': u'وَيَرَانِى', #1
u'ويراوض': u'وَيُرَاوِضْ', #1
u'ويرائي': u'وَيُرَائِي', #1
u'ويرائي': u'وَيُرَائِيَ', #1
u'ويرايك': u'ويرايك', #1
u'ويربحوننى': u'وَيُرْبِحُونَنِى', #1
u'ويرتاض': u'وَيَرْتَاضُ', #2
u'ويرتجز': u'وَيَرْتَجِزُ', #1
u'ويرتجز،': u'وَيَرْتَجِزُ،', #3
u'ويرتجزون': u'وَيَرْتَجِزُونَ', #2
u'ويرتجع': u'وَيَرْتَجِعَ', #1
u'ويرتجع': u'وَيَرْتَجِعْ', #1
u'ويرتجع': u'وَيَرْتَجِعُ', #5
u'ويرتجعه': u'وَيَرْتَجِعُهُ', #1
u'ويرتجعها': u'وَيَرْتَجِعُهَا', #8
u'ويرتفض': u'وَيُرْتَفَضُ', #2
u'ويرتفض': u'وَيَرْتَفِضُ', #9
u'ويرتفق': u'وَيُرْتَفَقُ', #1
u'ويرتفق': u'وَيَرْتَفِقُ', #4
u'ويرخيان': u'وَيُرْخَيَانِ', #1
u'ويردعليه': u'وَيَرُدُّعَلَيْهِ', #1
u'ويردفنى': u'وَيُرْدِفُنِى', #1
u'ويرضح': u'وَيُرْضَحُ', #1
u'ويرضيان': u'وَيُرْضِيَانِ', #1
u'ويرميان': u'وَيُرْمَيَانِ', #1
u'ويرميان': u'وَيَرْمِيَانِ', #3
u'ويروث': u'وَيَرُوثُ', #1
u'ويروثون': u'وَيَرُوثُونَ', #1
u'ويريان': u'وَيَرَيَانِ', #5
u'ويز': u'ويز', #2
u'ويزدجرد': u'وَيَزْدَجْرِدُ', #1
u'ويزدجرد': u'وَيَزْدَجْرِدَ', #2
u'ويزفنون': u'وَيَزْفِنُونَ', #4
u'ويزكيان': u'وَيُزَكِّيَانِ', #3
u'ويزيدنى': u'وَيَزِيدُنِى', #1
u'ويسافده': u'وَيُسَافِدُهُ', #1
u'ويست': u'ويست', #1
u'ويستأدي': u'وَيَسْتَأْدِيَ', #1
u'ويستاك': u'وَيُسْتَاكُ', #2
u'ويستاك': u'وَيَسْتَاكُ', #31
u'ويستاك': u'وَيَسْتَاكَ', #4
u'ويستأنى': u'وَيُسْتَأْنَى', #13
u'ويستأني': u'وَيَسْتَأْنِي', #5
u'ويستبحث': u'وَيَسْتَبْحِثُ', #1
u'ويستبرد': u'وَيُسْتَبْرَدُ', #1
u'ويستبسط': u'وَيَسْتَبْسِطُ', #1
u'ويستبضع': u'وَيَسْتَبْضِعَ', #1
u'ويستبطيه': u'وَيَسْتَبْطِيهِ', #1
u'ويستبي': u'وَيُسْتَبِيَ', #1
u'ويستتاب': u'وَيُسْتَتَابُ', #32
u'ويستتاب': u'وَيُسْتَتَابَ', #4
u'ويستتابان': u'وَيُسْتَتَابَانِ', #2
u'ويستتابوا': u'وَيُسْتَتَابُوا', #1
u'ويستتابون': u'وَيُسْتَتَابُونَ', #1
u'ويستتمه': u'وَيَسْتَتِمَّهُ', #1
u'ويستتيب': u'وَيَسْتَتِيبَ', #1
u'ويستثبت': u'وَيَسْتَثْبِتُ', #1
u'ويستجاد': u'وَيُسْتَجَادُ', #1
u'ويستجاز': u'وَيُسْتَجَازُ', #1
u'ويستجذ': u'وَيُسْتَجَذُّ', #1
u'ويستجرينكم': u'وَيَسْتجْرِيَنّكم', #1
u'ويستجزئ': u'وَيَسْتَجْزِئُ', #1
u'ويستجمر': u'وَيَسْتَجْمِرَ', #1
u'ويستجمر': u'وَيَسْتَجْمِرُ', #3
u'ويستجني': u'وَيَسْتَجْنِيَ', #1
u'ويستجيز': u'وَيَسْتَجِيزَ', #1
u'ويستجيز': u'وَيَسْتَجِيزُ', #2
u'ويستجيع': u'وَيَسْتَجِيعُ', #1
u'ويستحصى': u'وَيُسْتَحْصَى', #1
u'ويستحى': u'وَيُسْتَحَى', #2
u'ويستحيى': u'وَيَسْتَحْيِى', #1
u'ويستخبثه': u'وَيَسْتَخْبِثُهُ', #4
u'ويستخلي': u'وَيَسْتَخْلِي', #1
u'ويستخير': u'وَيَسْتَخِيرُ', #6
u'ويستدق': u'وَيَسْتَدِقُّ', #1
u'ويستذل': u'وَيُسْتَذَلُّ', #2
u'ويستراب': u'وَيُسْتَرَابُ', #1
u'ويستربح': u'وَيَسْتَرْبِحُ', #1
u'ويسترجح': u'وَيَسْتَرْجِحُ', #1
u'ويسترفد': u'وَيَسْتَرْفِدُ', #1
u'ويسترفقه': u'وَيَسْتَرْفِقُهُ', #4
u'ويسترم': u'وَيَسْتَرِمُّ', #1
u'ويستريب': u'وَيَسْتَرِيبَ', #1
u'ويستسر': u'وَيَسْتَسِرُّ', #1
u'ويستسرون': u'وَيَسْتَسِرُّونَ', #1
u'ويستسعوه': u'وَيَسْتَسْعُوهُ', #1
u'ويستسعى': u'وَيُسْتَسْعَى', #24
u'ويستسعي': u'وَيَسْتَسْعِيَ', #4
u'ويستسعي': u'وَيَسْتَسْعِي', #6
u'ويستسعيان': u'وَيَسْتَسْعِيَانِ', #1
u'ويستسعيان': u'وَيُسْتَسْعَيَانِ', #1
u'ويستسعيانه': u'وَيَسْتَسْعِيَانِهِ', #1
u'ويستسعيه': u'وَيَسْتَسْعِيه', #3
u'ويستسعيه': u'وَيَسْتَسْعِيهِ', #7
u'ويستسعيها': u'وَيَسْتَسْعِيهَا', #3
u'ويستسقط': u'وَيَسْتَسْقِطَ', #1
u'ويستسقطان': u'وَيَسْتَسْقِطَانِ', #7
u'ويستسمع': u'وَيَسْتَسْمِعَ', #1
u'ويستشق': u'وَيَسْتَشِقُّ', #1
u'ويستشنع': u'وَيُسْتَشْنَعُ', #1
u'ويستصبح': u'وَيَسْتَصْبِحُ', #12
u'ويستصبح': u'وَيَسْتَصْبِح', #2
u'ويستصبح': u'وَيُسْتَصْبَحُ', #6
u'ويستصحون': u'وَيَسْتَصِحّونَ', #1
u'ويستصنع': u'وَيَسْتَصْنِعَ', #1
u'ويستضر': u'وَيُسْتَضَرُّ', #1
u'ويستضر': u'وَيَسْتَضِرَّ', #2
u'ويستضر': u'وَيَسْتَضِرُّ', #6
u'ويستضمنوها': u'وَيَسْتَضْمِنُوهَا', #1
u'ويستطرق': u'وَيَسْتَطْرِقُ', #6
u'ويستعبره': u'وَيَسْتَعْبِرُهُ', #1
u'ويستعقب': u'وَيَسْتَعْقِبُ', #3
u'ويستعيذه': u'وَيَسْتَعِيذُهُ', #1
u'ويستغنم': u'وَيَسْتَغْنِمَ', #1
u'ويستغنيان': u'وَيَسْتَغْنِيَانِ', #1
u'ويستفحشه': u'وَيَسْتَفْحِشُهُ', #1
u'ويستفحشونه': u'وَيَسْتَفْحِشُونَهُ', #1
u'ويستفرشها': u'وَيَسْتَفْرِشُهَا', #1
u'ويستفصل': u'وَيَسْتَفْصِلَ', #1
u'ويستفصل': u'وَيُسْتَفْصَلُ', #1
u'ويستفضل': u'وَيُسْتَفْضَلُ', #1
u'ويستفيده': u'وَيَسْتَفِيدُهُ', #4
u'ويستفيدها': u'وَيَسْتَفِيدُهَا', #1
u'ويستقاد': u'وَيُسْتَقَادُ', #1
u'ويستقتل': u'وَيَسْتَقْتِلَ', #1
u'ويستقذر': u'وَيُسْتَقْذَرُ', #2
u'ويستقذره': u'وَيَسْتَقْذِرُهُ', #1
u'ويستقذرون': u'وَيُسْتَقْذَرُونَ', #1
u'ويستقرض': u'وَيَسْتَقْرِضَ', #3
u'ويستقرض': u'وَيُسْتَقْرَضُ', #5
u'ويستقرض': u'وَيَسْتَقْرِضُ', #7
u'ويستقرضه': u'وَيَسْتَقْرِضَهُ', #2
u'ويستقضي': u'وَيَسْتَقْضِيَ', #1
u'ويستقضى': u'وَيُسْتَقْضَى', #2
u'ويستقطر': u'وَيُسْتَقْطَرَ', #1
u'ويستقيدوا': u'وَيَسْتَقِيدُوا', #1
u'ويستكرونها': u'وَيَسْتَكْرُونَهَا', #2
u'ويستكسب': u'وَيُسْتَكْسَبُ', #3
u'ويستكسب': u'وَيَسْتَكْسِبُ', #7
u'ويستكسبان': u'وَيَسْتَكْسِبَانِ', #2
u'ويستكسبها': u'وَيَسْتَكْسِبُهَا', #1
u'ويستكسبهما': u'ويستكسبهما', #3
u'ويستكفي': u'وَيَسْتَكْفِيَ', #1
u'ويستلحق': u'وَيُسْتَلْحَقُ', #1
u'ويستلحقني': u'وَيَسْتَلْحِقُنِي', #1
u'ويستمطر': u'وَيُسْتَمْطَرُ', #1
u'ويستن': u'وَيَسْتَنُّ', #2
u'ويستناب': u'وَيُسْتَنَابُ', #9
u'ويستنبتونها': u'ويَسْتَنْبِتُونها', #1
u'ويستنثر': u'وَيَسْتَنْثِرْ', #1
u'ويستنثر': u'وَيَسْتَنْثِرَ', #4
u'ويستنثر': u'وَيَسْتَنْثِرُ', #6
u'ويستنثره': u'وَيَسْتَنْثِرُهُ', #2
u'ويستنجسون': u'وَيُسْتَنْجَسُونَ', #1
u'ويستنكه': u'وَيُسْتَنْكَهَ', #2
u'ويستنهي': u'وَيَسْتَنْهِي', #1
u'ويستنون': u'وَيَسْتَنُّونَ', #4
u'ويستنيب': u'وَيَسْتَنِيبَ', #4
u'ويستنيب': u'وَيَسْتَنِيبُ', #48
u'ويستنيبه': u'وَيَسْتَنِيبَهُ', #1
u'ويستنيبه': u'وَيَسْتَنِيبُهُ', #1
u'ويستنيبهم': u'وَيَسْتَنِيبَهُمْ', #1
u'ويستنيبون': u'وَيَسْتَنِيبُونَ', #9
u'ويستهمان': u'وَيَسْتَهِمَانِ', #1
u'ويستهمون': u'وَيَسْتَهِمُونَ', #1
u'ويستوشيه': u'وَيَسْتَوْشِيهِ', #3
u'ويستوفيان': u'وَيَسْتَوْفِيَانِ', #3
u'ويستوهب': u'وَيَسْتَوْهِبُ', #1
u'ويستويان': u'وَيَسْتَوِيَانِ', #35
u'ويسجده': u'وَيَسْجُدُهُ', #4
u'ويسجدها': u'وَيَسْجُدَهَا', #3
u'ويسجدها': u'وَيَسْجُدُهَا', #30
u'ويسجدهما': u'وَيَسْجُدَهُمَا', #1
u'ويسجدونها': u'وَيَسْجُدُونَهَا', #7
u'ويسخم': u'وَيُسَخَّمَ', #1
u'ويسخم': u'وَيُسَخَّمُ', #7
u'ويسعط': u'وَيُسْعَطُ', #1
u'ويسعيان': u'وَيَسْعَيَانِ', #7
u'ويسقينى': u'وَيَسْقِينِى', #10
u'ويسمعناها': u'وَيُسْمِعُنَاهَا', #1
u'ويسميان': u'وَيُسَمَّيَانِ', #12
u'ويسميان': u'وَيُسَمِّيَانِ', #2
u'ويسوءون': u'وَيَسُوءُونَ', #1
u'ويسوكه': u'وَيُسَوِّكُهُ', #2
u'ويسىء': u'وَيُسِىءُ', #1
u'ويسئلونك': u'وَيَسْئَلُونَكَ', #1
u'ويسئلونك': u'وَيُسْئِلُونَك', #1
u'ويشتريان': u'وَيَشْتَرِيَانِ', #5
u'ويشدخ': u'وَيُشْدَخُ', #1
u'ويشرجه': u'وَيَشْرُجَهُ', #1
u'ويشرجه': u'وَيُشَرِّجَهُ', #1
u'ويصطدق': u'وَيُصْطَدَقُ', #2
u'ويصلق': u'وَيُصْلِقَ', #1
u'ويصليان': u'وَيُصَلِّيَانِ', #7
u'ويضطبع': u'وَيُضْطَبَعُ', #2
u'ويضطبع': u'وَيَضْطَبِعُ', #6
u'ويضىء': u'ويضىء', #1
u'ويضيره': u'وَيَضِيرهُ', #1
u'ويطاهر': u'وَيُطَاهِرُ', #1
u'ويطفي': u'وَيُطْفِي', #1
u'ويطؤه': u'وَيَطَؤُهُ', #2
u'ويطؤها': u'وَيَطَؤُهَا', #44
u'ويطؤهن': u'وَيَطَؤُهُنَّ', #3
u'ويطويان': u'وَيَطْوِيَانِ', #1
u'ويطئون': u'وَيَطَئُونَ', #1
u'ويعايا': u'وَيُعَايَا', #25
u'ويعايي': u'وَيُعَايِي', #1
u'ويعايى': u'وَيُعَايَى', #17
u'ويعتاف': u'وَيَعْتَافُ', #2
u'ويعتجر': u'وَيَعْتَجِرُ', #2
u'ويعتضد': u'وَيَعْتَضِدَ', #1
u'ويعتضد': u'وَيُعْتَضَد', #1
u'ويعتضد': u'وَيُعْتَضَدَ', #1
u'ويعتضد': u'وَيَعْتَضِدُ', #3
u'ويعتضد': u'وَيُعْتَضَدُ', #5
u'ويعتضدون': u'وَيَعْتَضِدُونَ', #1
u'ويعتلم': u'وَيَعْتَلِمُ', #1
u'ويعجبنى': u'وَيُعْجِبُنِى', #3
u'ويعرص': u'وَيَعْرِصُ', #1
u'ويعرفونى': u'وَيَعْرِفُونِى', #1
u'ويعضب': u'وَيُعْضَبَ', #1
u'ويعطيان': u'وَيُعْطِيَانِ', #1
u'ويعطيان': u'وَيُعْطَيَانِ', #7
u'ويعطيكها': u'وَيُعْطِيكَهَا', #3
u'ويعطيناه': u'وَيُعْطِينَاهُ', #3
u'ويعطينيها': u'وَيُعْطِينِيهَا', #1
u'ويعفشه': u'وَيُعَفِّشُهُ', #1
u'ويعفوعن': u'وَيَعْفُوعَنْ', #1
u'ويعقوبس': u'وَيَعْقُوبُسُ', #2
u'ويعلمهموه': u'وَيُعَلِّمُهُمُوهُ', #1
u'ويعيينى': u'وَيُعِيينُى', #1
u'ويغابنهم': u'وَيُغَابِنُهُمْ', #1
u'ويغت': u'وَيَغُتُّ', #1
u'ويغتاض': u'وَيَغْتَاضُ', #1
u'ويغتدي': u'وَيَغْتَدِي', #5
u'ويغترق': u'وَيَغْتَرِقُ', #1
u'ويغتفلان': u'ويغتفلان', #1
u'ويغثي': u'وَيُغْثِي', #2
u'ويغشيان': u'وَيُغَشِّيَانِ', #1
u'ويغطئل': u'وَيَغْطَئِلّ', #1
u'ويغمص': u'وَيَغْمِصُ', #1
u'ويغمص': u'وَيُغْمِصُ', #1
u'ويغنيان': u'وَيُغَنِّيَانِ', #3
u'ويغوث،': u'وَيَغُوثُ،', #1
u'ويفالس': u'وَيُفَالِسُ', #1
u'ويفاوت': u'وَيُفَاوِتَ', #1
u'ويفاوت': u'وَيُفَاوَتُ', #10
u'ويفاوت': u'وَيُفَاوِتُ', #22
u'ويفتات': u'وَيُفَتَاتُ', #1
u'ويفتات': u'وَيُفْتَاتُ', #2
u'ويفتخ': u'وَيَفْتَخ', #1
u'ويفتضها': u'وَيَفْتَضَّهَا', #2
u'ويفتضها': u'وَيَفْتَضُّهَا', #2
u'ويفثؤه': u'وَيَفْثَؤُهُ', #1
u'ويفججانه': u'وَيُفَجِّجَانِهِ', #1
u'ويفديان': u'وَيَفْدِيَانِ', #2
u'ويفطرنى': u'وَيُفَطِّرُنِى', #1
u'ويفقئون': u'وَيَفْقَئُونَ', #1
u'ويفوح': u'وَيَفُوحُ', #2
u'ويفوحه': u'وَيُفَوِّحُهُ', #1
u'ويفيته': u'وَيُفِيتُهُ', #2
u'ويفيتها': u'وَيُفِيتُهَا', #2
u'ويقاتلنى': u'وَيُقَاتِلَنِى', #1
u'ويقاتلنى': u'وَيُقَاتِلُنِى', #1
u'ويقايل': u'وَيُقَايِلُ', #1
u'ويقتديان': u'وَيَقْتَدِيَانِ', #2
u'ويقتصف': u'وَيَقْتَصِفْ', #1
u'ويقرءوا': u'وَيَقْرَءُوا', #2
u'ويقرءون': u'وَيَقْرَءُونَ', #29
u'ويقرءونه': u'وَيَقْرَءُونَهُ', #2
u'ويقرءونها': u'وَيَقْرَءُونَهَا', #2
u'ويقرأون': u'ويقرأون', #1
u'ويقرؤه': u'وَيَقْرَؤُهُ', #9
u'ويقرؤها': u'وَيَقْرَؤُهَا', #2
u'ويقرؤهما': u'وَيَقْرَؤُهُمَا', #2
u'ويقضيان': u'وَيَقْضِيَانِ', #7
u'ويقطعونى': u'وَيَقْطَعُونِى', #1
u'ويقظانا': u'وَيَقْظَانًا', #2
u'ويقولأذهب': u'وَيَقُولُأَذْهِبِ', #1
u'ويقولإن': u'وَيَقُولُإِنَّ', #1
u'ويقولرأيت': u'وَيَقُولُرَأَيْتُ', #1
u'ويقولصحبت': u'وَيَقُولُصَحِبْتُ', #1
u'ويقولوقع': u'وَيَقُولُوَقَعَ', #1
u'ويقى': u'وَيَقِى', #2
u'ويكعظ': u'وَيُكْعَظْ', #1
u'ويكفيان': u'وَيَكْفِيَانِ', #3
u'ويكلؤهم': u'وَيَكْلَؤُهُمْ', #1
u'ويكي': u'وَيَكِي', #1
u'ويكى': u'ويكى', #1
u'ويكيد': u'وَيَكِيدُ', #1
u'ويكيدون': u'وَيَكِيدُونَ', #1
u'ويلبيان': u'وَيُلَبِّيَانِ', #1
u'ويلتقيان': u'وَيَلْتَقِيَانِ', #1
u'ويلتى': u'وَيْلَتَى', #6
u'ويلجيهم': u'وَيُلْجِيهِمْ', #1
u'ويلحقنى': u'وَيَلْحَقُنِى', #1
u'ويلغوان': u'وَيَلْغُوَانِ', #1
u'ويلقيان': u'وَيُلْقِيَانِ', #1
u'ويلهمنى': u'وَيُلْهِمُنِى', #1
u'ويلى': u'وَيَلِى', #1
u'ويلى': u'وَيْلِى', #1
u'ويليق': u'وَيَلِيقُ', #9
u'ويليقان': u'وَيَلِيقَانِ', #1
u'ويمجدونكا': u'وَيُمَجّدُونَكَا', #3
u'ويمجسانه': u'وَيُمَجّسَانِهِ', #1
u'ويمجسانه': u'وَيُمَجِّسَانِهِ', #11
u'ويمحيه': u'وَيَمْحِيه', #1
u'ويمحيه': u'وَيَمْحِيهِ', #1
u'ويمرخ': u'وَيُمْرَخُ', #1
u'ويمشيان': u'وَيَمْشِيَانِ', #1
u'ويمضيان': u'وَيَمْضِيَانِ', #8
u'ويملؤه': u'وَيَمْلَؤُهُ', #1
u'ويملؤها': u'وَيَمْلَؤُهَا', #1
u'ويملئوا': u'وَيَمْلَئُوا', #1
u'ويملئون': u'وَيَمْلَئُونَ', #2
u'ويمير': u'وَيَمِيرُ', #4
u'ويناقصني': u'وَيُنَاقِصُنِي', #2
u'ويناكر': u'وَيُنَاكِرَ', #2
u'ويناكرها': u'وَيُنَاكِرُهَا', #3
u'ويناوح': u'وَيُنَاوِحُ', #1
u'ويناويهم': u'ويناويهم', #1
u'وينبغى': u'وَيَنْبَغِى', #2
u'وينبي': u'وَيُنْبِي', #1
u'وينتثر': u'وَيَنْتَثِرُ', #3
u'وينتثره': u'وَيَنْتَثِرُهُ', #1
u'وينتثل': u'وَيُنْتَثَلَ', #1
u'وينتزي': u'وَيَنْتَزِي', #2
u'وينتفيان': u'وَيَنْتَفِيَانِ', #1
u'وينجدرهم': u'وينجدرهم', #1
u'وينحجر': u'وَيَنْحَجِرُ', #7
u'وينحفظ': u'وَيَنْحَفِظُ', #1
u'ويندرئ': u'وَيَنْدَرِئُ', #1
u'وينزي': u'وَيُنْزِي', #2
u'وينسئون': u'وَيُنْسِئُونَ', #1
u'وينصدرون': u'وَيَنْصَدِرُونَ', #1
u'وينصرنى': u'وَيَنْصُرُنِى', #1
u'وينعوج': u'وَيَنْعَوِجَ', #2
u'وينعوج': u'وَيَنْعَوِجُ', #2
u'وينفرش': u'وَيَنْفَرِشُ', #1
u'وينفيان': u'وَيَنْفِيَانِ', #1
u'وينفيان': u'وَيُنْفَيَانِ', #2
u'وينقدح': u'وَيَنْقَدِحُ', #13
u'وينقدونى': u'وَيَنْقُدُونِى', #1
u'وينقضيان': u'وَيَنْقَضِيَانِ', #1
u'وينماع': u'وَيَنْمَاعُ', #2
u'وينمزج': u'وَيَنْمَزِجُ', #2
u'وينهيان': u'وَيَنْهَيَانِ', #2
u'وينهيان': u'وَيُنْهِيَانِ', #2
u'وينوطون': u'وَيَنُوطُونَ', #1
u'وينويان': u'وَيَنْوِيَانِ', #5
u'ويها': u'وَيْهًا', #5
u'ويهابه': u'وَيَهَابُهُ', #4
u'ويهابهما': u'وَيَهَابُهُمَا', #2
u'ويهابونه': u'وَيَهَابُونَهُ', #2
u'ويهديان': u'وَيُهْدِيَانِ', #4
u'ويهراق': u'وَيُهَرَاقُ', #1
u'ويهراق': u'وَيُهْرَاقَ', #1
u'ويهراق': u'وَيُهْرَاقُ', #1
u'ويهريق': u'وَيُهَرِيقُ', #2
u'ويهريق': u'وَيُهْرِيقُ', #6
u'ويهريقوا': u'وَيُهْرِيقُوا', #1
u'ويهريقون': u'ويُهْرِيقُونَ', #1
u'ويهريقون': u'وَيُهْرِيقُونَ', #1
u'ويهللونك': u'وَيُهَلِّلُونَكَ', #2
u'ويهللوه': u'وَيُهَلِّلُوهُ', #1
u'ويهني': u'وَيُهِنِّي', #1
u'ويهوذى،': u'وَيَهُوذَى،', #1
u'ويواتيهم': u'وَيُوَاتِيهِمْ', #1
u'ويؤاجر': u'وَيُؤَاجِرَ', #3
u'ويؤاجر': u'وَيُؤَاجَرُ', #6
u'ويؤاجر': u'وَيُؤَاجِرُ', #9
u'ويؤاجرا': u'وَيُؤَاجِرَا', #1
u'ويؤاجراها': u'وَيُؤَاجِرَاهَا', #1
u'ويؤاجره': u'وَيُؤَاجِرُهُ', #10
u'ويؤاجره': u'وَيُؤَاجِرَهُ', #12
u'ويؤاجرها': u'وَيُؤَاجِرَهَا', #5
u'ويؤاجرها': u'وَيُؤَاجِرُهَا', #8
u'ويؤاجرهم': u'وَيُؤَاجِرَهُمْ', #1
u'ويؤاجرون': u'وَيُؤَاجِرُونَ', #3
u'ويؤاجرونها': u'وَيُؤَاجِرُونَهَا', #1
u'ويؤاخذ': u'وَيُؤَاخَذَ', #1
u'ويؤاخذ': u'وَيُؤَاخَذُ', #83
u'ويؤاخذان': u'وَيُؤَاخَذَانِ', #2
u'ويؤاخذون': u'وَيُؤَاخَذُونَ', #1
u'ويوارث': u'وَيُوَارَثُ', #1
u'ويوارث': u'وَيُوَارِثُ', #1
u'ويوارثه': u'وَيُوَارِثُهُ', #1
u'ويوارثهما': u'ويوارثهما', #1
u'ويؤازي': u'وَيُؤَازِي', #1
u'ويؤاكل': u'وَيُؤَاكِلُ', #2
u'ويؤاكلون': u'وَيُؤَاكِلُونَ', #1
u'ويؤاكلوه': u'وَيُؤَاكِلُوهُ', #1
u'ويؤانس': u'وَيُؤَانِسُ', #1
u'ويؤانسه': u'وَيُؤَانِسُهُ', #1
u'ويؤانسهم': u'وَيُؤَانِسُهُمْ', #2
u'ويؤبدونه': u'وَيُؤَبِّدُونَهُ', #1
u'ويؤتدم': u'وَيُؤْتَدَمُ', #1
u'ويؤتنف': u'وَيُؤْتَنَفُ', #3
u'ويؤديان': u'وَيُؤَدَّيَانِ', #1
u'ويؤديان': u'وَيُؤَدِّيَانِ', #2
u'ويؤذينى': u'وَيُؤْذِينِى', #3
u'ويوشع': u'وَيُوشَعَ', #4
u'ويوصفها': u'وَيُوصِفُهَا', #1
u'ويوضؤه': u'وَيُوَضِّؤُهُ', #1
u'ويوكي': u'وَيُوكِي', #1
u'ويومة': u'وَيُومَةُ', #1
u'ويومى': u'وَيَوْمِى', #1
u'ويوميء': u'وَيُومِيءُ', #1
u'ويومئان': u'وَيُومِئَانِ', #1
u'ويومئها': u'وَيُومِئُهَا', #1
u'ويئوب': u'وَيَئُوبَ', #1
u'ويئوبون': u'وَيَئُوبُونَ', #1
u'ويئول': u'وَيَئُولُ', #11
u'ويئولهم': u'وَيَئُولُهُمْ', #1
u'ويين': u'وَيَيْنُ', #1
u'ئبكر': u'ئبَكْرِ', #1
u'ئتوا': u'ئْتُوا', #1
u'ئظ': u'ئِظِ', #2
u'ئنا': u'ئِنَا', #2
u'ئها': u'ئها', #1
u'ئ‰ئ‰اة': u'ئ‰ئ‰َاةِ', #1
u'يأ': u'يأ', #1
u'ياءات': u'يَاءَات', #1
u'ياءات': u'يَاءَاتٍ', #3
u'ياأهل': u'يَاأَهْلَ', #5
u'ياأيها': u'يَاأَيُّهَا', #32
u'يابازر': u'يابازر', #1
u'يابد': u'يابد', #1
u'يأبر': u'يأبر', #1
u'يابر': u'يابر', #1
u'يأبرون': u'يَأْبُرُونَ', #1
u'يأبرونه': u'يَأْبُرُونَهُ', #1
u'يأبس': u'يَأْبِسُ', #2
u'يأبق': u'يَأْبِق', #1
u'يأبق': u'يَأْبِقُ', #24
u'يأبق': u'يَأْبَقَ', #26
u'يأبق': u'يَأْبِقَ', #3
u'يأبق': u'يَأْبَقْ', #33
u'يأبق': u'يَأْبَقُ', #42
u'يأبق': u'يَأْبِقْ', #6
u'يأبقن': u'يَأْبَقَنَّ', #1
u'يأبقن،': u'يَأْبَقَنَّ،', #1
u'يأبقه': u'يَأْبِقُهُ', #1
u'يأبقون': u'يَأْبَقُونَ', #3
u'يابكابين': u'يابكابين', #1
u'يابكار': u'يابكار', #1
u'يابني،': u'يابني،', #1
u'يابي': u'يابي', #1
u'يأبي': u'يأبي', #2
u'يأبيان': u'يَأْبَيَانِ', #2
u'يات': u'يات', #1
u'يأتجر': u'يَأْتَجِرُ', #2
u'يأتدم': u'يَأْتَدِمُ', #16
u'يأتدم': u'يَأْتَدِمَ', #3
u'يأتدمه': u'يَأْتَدِمُهُ', #1
u'يأتدمون': u'يَأْتَدِمُونَ', #2
u'ياترده': u'ياترده', #1
u'يأتقطوا': u'يَأْتَقِطُوا', #2
u'يأتما': u'يَأْتَمَّا', #1
u'يأتمان': u'يَأْتَمَّانِ', #1
u'يأتموا': u'يَأْتَمُّوا', #5
u'يأتمون': u'يَأْتَمُّونَ', #12
u'يأتنس': u'يَأْتَنِس', #1
u'يأتنف': u'يَأْتَنِفْ', #1
u'يأتنف': u'يَأْتَنِفَ', #3
u'يأتنف': u'يَأْتَنِفُ', #8
u'يأتنفا': u'يَأْتَنِفَا', #2
u'يأتنفان': u'يَأْتَنِفَانِ', #4
u'يأتنفها': u'يَأْتَنِفُهَا', #1
u'يأتنفون': u'يَأْتَنِفُونَ', #1
u'يأتنفون،': u'يَأْتَنِفُونَ،', #1
u'ياتوا': u'ياتوا', #1
u'يأتوابه': u'يَأْتُوابِهِ', #1
u'يأتونى': u'يَأْتُونِى', #1
u'يأتى': u'يَأَْتِىَ', #1
u'ياتي': u'يَاتِي', #1
u'يأتى': u'يَأْتِىَ', #103
u'يأتى': u'يَأْتِى', #166
u'يأتى': u'يأتى', #8
u'يأتيان': u'يَأْتِيَانِ', #69
u'يأتينى': u'يَأْتِينِى', #25
u'يأتينى': u'يَأْتِيَنِى', #3
u'ياج': u'يَاجَ', #1
u'يأجح': u'يَأْجَحَ', #1
u'يأجرنى': u'يَأْجُرَنِى', #1
u'يأجوج،': u'يأجوج،', #1
u'يأجوج': u'يأجوج', #11
u'يأجوج': u'يَأْجُوجُ', #15
u'يأجوج': u'يَأْجُوجَ', #74
u'ياحسرتا': u'يَاحَسْرَتَا', #1
u'يأخده': u'يَأْخُدُهُ', #1
u'يأخذنى': u'يأخذنى', #1
u'يأخذنى': u'يَأْخُذَنِى', #1
u'يأخذنى': u'يَأْخُذُنِى', #2
u'يأخذهSقدوم': u'يَأْخُذُهُSقُدُومُ', #1
u'ياخود': u'ياخود', #1
u'ياخيره': u'ياخيره', #1
u'ياداود': u'يَادَاوُدُ', #1
u'يادرزي': u'يادرزي', #2
u'يادركاه': u'يادركاه', #2
u'يادركاي': u'يادركاي', #1
u'يادكار': u'يادكار', #1
u'يادكار': u'يَادَكَارُ', #1
u'يادكار': u'يَادِكَارِ', #2
u'يادكاري': u'يادكاري', #2
u'يادكاري': u'يَادَكَارِي', #2
u'يادكارى': u'يادكارى', #2
u'يادكردده': u'يادكردده', #1
u'يادكرده': u'يادكرده', #4
u'يأدم': u'يَأْدَمُ', #1
u'يأدم': u'يَأْدُمُ', #1
u'يأدم': u'يَأْدِم', #1
u'يأدم': u'يَأْدِمُ', #1
u'يأدمه': u'يَأْدِمُهُ', #1
u'ياذا': u'يَاذَا', #1
u'ياذرية': u'ياذرية', #1
u'يأذنه': u'يأذنه', #1
u'يأذنه': u'يَأْذَنَهُ', #11
u'يأذنه': u'يَأْذَنْهُ', #37
u'يأذنه': u'يَأْذَنُهُ', #4
u'يأذنها': u'يَأْذَنَهَا', #1
u'يأذنها': u'يَأْذَنُهَا', #1
u'يأذنها': u'يَأْذَنْهَا', #3
u'يأذنهما': u'يَأْذَنْهُمَا', #2
u'يأذنوني': u'يَأْذَنُونِي', #1
u'يارب،': u'يَاربِّ،', #1
u'يارب،': u'يَارَبِّ،', #4
u'يارب،': u'يارب،', #5
u'يارب': u'يَارَبِّ', #5
u'يارد،': u'يَارَدَ،', #1
u'يأرز': u'يأرز', #2
u'يأرز': u'يَأْرُزُ', #2
u'يأرز': u'يَأْرِزُ', #4
u'يارسول': u'يَارَسُولَ', #25
u'يارى': u'يارى', #3
u'يأريق': u'يَأْرِيقُ', #2
u'ياز': u'ياز', #6
u'يازدة': u'يازدة', #1
u'يازده': u'يازده', #117
u'يازده': u'يَازْدَهْ', #2
u'يازر،': u'يَازَرَ،', #1
u'يازن': u'يازن', #1
u'يازنانه': u'يازنانه', #1
u'ياس': u'يَاسٍ', #2
u'ياس': u'يَاسَ', #2
u'ياست': u'يَاسِتَّ', #1
u'ياسمون': u'يَاسَمُونُ', #1
u'ياسن': u'يَاسِنٍ', #4
u'يأشر': u'يَأْشَرْ', #1
u'ياشيد': u'ياشيد', #1
u'ياعاني': u'يَاعَانِي', #1
u'ياف': u'يَافٍ', #1
u'يافا': u'يَافَا', #7
u'يافاع': u'يَافَاعٍ', #2
u'يافت': u'يافت', #1
u'يافث': u'يافث', #1
u'يافث،': u'يَافِثُ،', #1
u'يافث': u'يَافِثٍ', #2
u'يافث': u'يَافِثِ', #2
u'يافث': u'يَافِثَ', #7
u'يافل': u'يَافُلُ', #1
u'يافنة،': u'يَافِنَةَ،', #1
u'يأفنه': u'يَأْفِنُهُ', #1
u'يأفوخا': u'يَأْفُوخًا', #1
u'يآفيخ': u'يَآفِيخٌ', #1
u'ياق': u'يَاق', #1
u'ياقباث': u'ياقباث', #1
u'ياقع': u'يَاقِعُ', #1
u'ياقوب': u'يَاقُوبُ', #1
u'ياقوم': u'يَاقُومُ', #1
u'ياك': u'ياك', #1
u'ياكدبانو': u'ياكدبانو', #1
u'ياكدباني': u'ياكدباني', #1
u'يالثارات': u'يالثارات', #1
u'يالله': u'يَالَلَّهِ', #1
u'يالله': u'يَالِلَّهِ', #1
u'يالله': u'يَالِلَّهُ', #2
u'يألمه': u'يَأْلَمُهُ', #1
u'يالى': u'يالى', #1
u'ياليتنا': u'ياليتنا', #1
u'ياليل': u'يالَيِل', #1
u'ياليل': u'يَالَيلَ', #1
u'ياليل،': u'يَالِيل،', #1
u'ياليل،': u'يَالِيلِ،', #1
u'ياليل': u'يَالِيلَ', #15
u'ياليل': u'يَالِيل', #2
u'ياليل،': u'يَالِيلَ،', #2
u'ياليل': u'يَالَيْل', #22
u'ياليل': u'يَالِيلِ', #3
u'ياليل': u'ياليل', #4
u'ياليل': u'يالَيْل', #9
u'ياليل': u'يَالَيْلَ', #9
u'يام': u'يَامَ', #1
u'يام': u'يَامُ', #1
u'يام': u'يَامْ', #1
u'يام': u'يَام', #2
u'يام': u'يَامٍ', #3
u'يأمرانى': u'يَأْمُرَانِى', #3
u'يأمرنى': u'يَأْمُرْنِى', #4
u'يأمرنى': u'يَأْمُرُنِى', #7
u'يأمروننى': u'يَأْمُرُونَنِى', #1
u'يأمرونى': u'يَأْمُرُونِّى', #1
u'يامعشر': u'يامعشر', #1
u'يامعشر': u'يَاٍٍٍٍمَعْشَرَ', #1
u'يأمننى': u'يَأْمَنُنِى', #1
u'ياموسي': u'ياموسي', #1
u'يأمونه': u'يَأُمُّونَهُ', #1
u'يامين': u'يَامِينٍ', #1
u'يامين،': u'يَامِينَ،', #2
u'يامين': u'يَامِينَ', #20
u'يامين': u'يَامِينُ', #6
u'يانا': u'يَانًا', #1
u'يأنج': u'يَأْنِجُ', #1
u'يأنح': u'يَأْنِحُ', #4
u'يانس': u'يَانِسَ', #1
u'يانش': u'يانِشَ', #2
u'يانش': u'يَانِشَ', #2
u'يانكني': u'يانكني', #1
u'يانى': u'يانى', #1
u'يأنى': u'يَأْنَى', #2
u'ياني': u'ياني', #7
u'يانيد': u'يانيد', #1
u'ياه': u'يَّاهُ', #1
u'ياها': u'يَاهَا', #1
u'ياهناه': u'يَاهَنَّاهُ', #1
u'ياهنة': u'يَاهَنَّة', #1
u'يأواه': u'يَأْوَاهُ', #2
u'يأول': u'يُأَوِّلُ', #1
u'ياولي': u'ياولي', #1
u'يأوى': u'يُأْوَى', #1
u'يأوى': u'يَأْوِى', #8
u'يب': u'يب', #1
u'يب': u'يَبْ', #1
u'يب': u'يْبِ', #1
u'يبادرنى': u'يُبَادِرُنِى', #2
u'يبارئ': u'يُبَارِئُ', #2
u'يبارئ': u'يُبَارِئَ', #3
u'يبارئها': u'يُبَارِئَهَا', #2
u'يبازون': u'يُبَازُونَ', #1
u'يباشرنى': u'يُبَاشِرُنِى', #3
u'يباضعها': u'يُبَاضِعَهَا', #1
u'يباضعها': u'يُبَاضِعُهَا', #1
u'يباعدنى': u'يُبَاعِدُنِى', #1
u'يباغي': u'يُبَاغِي', #1
u'يباليان': u'يُبَالِيَانِ', #3
u'يباهلون': u'يُبَاهِلُونَ', #2
u'يبايتك': u'يُبَايِتُكَ', #1
u'يباين': u'يُبَايَنَ', #1
u'يباين': u'يُبَايَنُ', #1
u'يباين': u'يُبَايِن', #1
u'يباين': u'يُبَايِنْ', #3
u'يباين': u'يُبَايِنُ', #40
u'يباين': u'يُبَايِنَ', #7
u'يباينان': u'يُبَايِنَانِ', #2
u'يباينه': u'يُبَايِنُهُ', #13
u'يباينه': u'يُبَايِنَهُ', #3
u'يباينها': u'يُبَايِنُهَا', #2
u'يباينها': u'يُبَايِنَهَا', #4
u'يباينهم': u'يُبَايِنُهُمْ', #5
u'يباينهما': u'يُبَايِنُهُمَا', #7
u'يباينهن': u'يُبَايِنُهُنَّ', #3
u'يبتد': u'يَبْتَدِ', #2
u'يبتدءوا': u'يُبْتَدَءُوا', #2
u'يبتدءون': u'يَبْتَدِءُونَ', #1
u'يبتدر': u'يبتدر', #1
u'يبتدر': u'يَبْتَدِرَ', #1
u'يبتدر': u'يُبْتَدَرْ', #1
u'يبتدر': u'يَبْتَدِرُ', #3
u'يبتدراني': u'يَبْتَدِرَانِي', #2
u'يبتدرن': u'يَبْتَدِرْنَ', #7
u'يبتدره': u'يَبْتَدِرُهُ', #2
u'يبتدره': u'يَبْتَدِرَهُ', #7
u'يبتدرون': u'يَبْتَدِرُونَ', #21
u'يبتدرونه': u'يَبْتَدِرُونَهُ', #2
u'يبتدرونها': u'يَبْتَدِرُونَهَا', #14
u'يبتدرونهم': u'يَبْتَدِرُونَهُمْ', #2
u'يبتده': u'يَبْتَدِهِ', #1
u'يبتدي': u'يَبْتَدِيَ', #1
u'يبتدي': u'يَبْتَدِي', #16
u'يبتدئان': u'يَبْتَدِئَانِ', #6
u'يبتديك': u'يَبْتَدِيك', #1
u'يبتديه': u'يَبْتَدِيهِ', #4
u'يبتديها': u'يَبْتَدِيهَا', #2
u'يبتلغ': u'يَبْتَلِغَ', #1
u'يبتئر': u'يبتئر', #1
u'يبتئر': u'يَبْتَئِرَ', #1
u'يبتئر': u'يَبْتَئِرْ', #5
u'يبخشونها': u'يَبْخَشُونَهَا', #1
u'يبخلنا': u'يُبْخِلنَا', #1
u'يبخلنا': u'يُبَخِّلُنَا', #1
u'يبخلوني': u'يُبَخِّلُونِي', #1
u'يبخلوني': u'يُبْخِلُونِي', #1
u'يبخلونى': u'يُبَخِّلُونِى', #1
u'يبخونه': u'يَبُخُّونَهُ', #2
u'يبدءوا': u'يُبَدَّءُوا', #1
u'يبدءوا': u'يُبْدَءُوا', #3
u'يبدءوا': u'يَبْدَءُوا', #33
u'يبدءون': u'يُبَدَّءُونَ', #1
u'يبدءون': u'يبدءون', #2
u'يبدءون': u'يُبْدَءُونَ', #2
u'يبدءون': u'يَبْدَءُونَ', #28
u'يبدءونا': u'يَبْدَءُونَا', #4
u'يبدءونك': u'يَبْدَءُونَكَ', #1
u'يبدءونهم': u'يَبْدَءُونَهُمْ', #2
u'يبدءوه': u'يَبْدَءُوهُ', #7
u'يبدا': u'يُبْدَا', #1
u'يبدا': u'يَبْدَا', #2
u'يبدآن': u'يَبْدَآنِ', #3
u'يبدهه': u'يَبْدَهَهُ', #1
u'يبدؤا': u'يبدؤا', #1
u'يبدوان': u'يَبْدُوَانِ', #1
u'يبدؤكم': u'يَبْدَؤُكُمْ', #1
u'يبدؤنا': u'يَبْدَؤُنَا', #5
u'يبدؤه': u'يَبْدَؤُهُ', #8
u'يبدؤها': u'يَبْدَؤُهَا', #4
u'يبدؤهم': u'يَبْدَؤُهُمْ', #8
u'يبدؤهما': u'يَبْدَؤُهُمَا', #2
u'يبذ': u'يَبُذّ', #2
u'يبذو': u'يَبْذُو', #3
u'يبرءان': u'يَبْرَءَانِ', #1
u'يبرءوا': u'يَبْرَءُوا', #9
u'يبرءون': u'يُبَرَّءُونَ', #1
u'يبرءون': u'يُبَرِّءُونَ', #1
u'يبرءون': u'يَبْرَءُونَ', #28
u'يبرآن': u'يَبْرَآنِ', #25
u'يبريء': u'يُبْرِيءُ', #1
u'يبرىء': u'يبرىء', #1
u'يبرئنى': u'يُبَرِّئُنِى', #1
u'يبزر': u'يُبْزَرُ', #1
u'يبزنى': u'يَبُزَّنِى', #1
u'يبزى': u'يُبْزَى', #2
u'يبس،': u'يَبَسً،', #1
u'يبسون': u'يُبِسُّونَ', #2
u'يبسون': u'يَبُسُّونَ', #24
u'يبسون': u'يَبِسُّونَ', #4
u'يبسونه': u'يَبُسُّونَهُ', #2
u'يبشرنى': u'يُبَشِّرُنِى', #4
u'يبشرونى': u'يُبَشِّرُونِى', #1
u'يبص': u'يَبِصُ', #1
u'يبص': u'يَبِصُّ', #1
u'يبط': u'يُبَطَّ', #1
u'يبط': u'يُبَطُّ', #1
u'يبط': u'يَبُطُّ', #5
u'يبط': u'يَبُطَّ', #6
u'يبعثنى': u'يَبْعَثَنِى', #1
u'يبعثنى': u'يَبْعَثْنِى', #2
u'يبعثنى': u'يَبْعَثُنِى', #4
u'يبعثونى': u'يَبْعَثُونِى', #1
u'يبعج': u'يُبَعَّجُ', #1
u'يبعج': u'يُبْعَجُ', #1
u'يبعج': u'يَبْعَجَ', #2
u'يبعض': u'يُبَعِّضَ', #1
u'يبعض': u'يُبَعَّضُ', #15
u'يبعض': u'يُبَعَّضَ', #2
u'يبعض': u'يُبَعِّضْ', #4
u'يبعض': u'يُبَعِّضُ', #7
u'يبعضا': u'يُبَعَّضَا', #2
u'يبعضان': u'يُبَعَّضَانِ', #1
u'يبعضه': u'يُبَعِّضُهُ', #1
u'يبعضه': u'يُبْعِضُهُ', #2
u'يبعضها': u'يُبَعِّضُهَا', #1
u'يبعضها': u'يُبَعِّضَهَا', #2
u'يبعل': u'يَبْعَلْ', #1
u'يبعيه،': u'يَبِعْيهُ،', #1
u'يبعيه': u'يَبِعْيهُ', #2
u'يبغضنى': u'يُبْغِضَنِى', #1
u'يبغيان': u'يَبْغِيَانِ', #4
u'يبقيان': u'يُبْقَيَانِ', #1
u'يبقيان': u'يَبْقَيَانِ', #30
u'يبكته': u'يُبَكِّتُهُ', #2
u'يبكته': u'يُبَكِّتْهُ', #3
u'يبكتون': u'يُبَكِّتُونَ', #1
u'يبكيان': u'يَبْكِيَانِ', #44
u'يبكيان،': u'يَبْكِيَانِ،', #7
u'يبلغنى': u'يُبَلِّغْنِى', #3
u'يبلغنى': u'يَبْلُغَنِى', #4
u'يبلغنى': u'يَبْلُغُنِى', #4
u'يبلغنى': u'يَبْلُغْنِى', #7
u'يبنيان،': u'يَبْنِيَانِ،', #1
u'يبنيان': u'يَبْنِيَانِ', #11
u'يبنيان': u'يُبْنَيَانِ', #8
u'يبوعه': u'يَبُوعَهُ', #1
u'يبوكها': u'يَبُوكُهَا', #1
u'يبئ': u'يُبِئْ', #1
u'يبيء': u'يُبِيءُ', #2
u'يبيب': u'يَبِيبُ', #1
u'يبيحمس': u'يُبِيحُمَسَّ', #1
u'يبيعنى': u'يَبِيعَنِى', #1
u'يبيعونى': u'يَبِيعُونِى', #2
u'ية': u'يَةِ', #1
u'يتأبر': u'يَتَأَبَّرْ', #16
u'يتأبر': u'يَتَأَبَّرُ', #3
u'يتأتيان': u'يَتَأَتَّيَانِ', #5
u'يتاحف': u'يُتَاحِفُ', #1
u'يتأخره': u'يَتَأَخَّرُهُ', #1
u'يتأد': u'يُتَأَدَّ', #1
u'يتأد': u'يَتَأَدَّ', #13
u'يتأدم': u'يُتَأَدَّمُ', #1
u'يتأدم': u'يَتَأَدَّمُ', #2
u'يتأدى': u'يُتَأَدَّى', #2
u'يتأدى': u'يَتَأَدَّى', #520
u'يتأديان': u'يَتَأَدَّيَانِ', #5
u'يتأذ': u'يَتَأَذَّ', #69
u'يتأذون': u'يَتَأَذُّونَ', #1
u'يتأذون': u'يَتَأَذَّوْنَ', #25
u'يتأذى': u'يتأذى', #1
u'يتأذى': u'يُتَأَذَّى', #18
u'يتأذى': u'يَتَأَذّى', #2
u'يتأذى': u'يَتَأَذَّى', #404
u'يتأذيان': u'يَتَأَذَّيَانِ', #4
u'يتأرب': u'يَتَأَرَّبُ', #1
u'يتاركه': u'يُتَارِكُهُ', #1
u'يتاركها': u'يُتَارِكَهَا', #1
u'يتأقت': u'يَتَأَقَّتُ', #22
u'يتأل': u'يَتَأَلّ', #1
u'يتأل': u'يَتَأَلَّ', #1
u'يتألفكما': u'يَتَأَلَّفْكُمَا', #1
u'يتألفكما': u'يَتَأَلَّفُكُمَا', #2
u'يتألفني': u'يَتَأَلَّفُنِي', #1
u'يتألفه،': u'يَتَأَلَّفُهُ،', #1
u'يتألفهم': u'يَتَأَلَّفُهُمُ', #1
u'يتألفهم': u'يَتَأَلَّفُهُمْ', #12
u'يتألفهم': u'يَتَأَلَّفَهُمْ', #2
u'يتألفهم': u'يَتَأَلّفُهُمْ', #5
u'يتألفهما': u'يَتَأَلَّفُهُمَا', #1
u'يتألى': u'يَتَأَلَّى', #6
u'يتأنف': u'يَتَأَنَّفُ', #1
u'يتايم': u'يَتَايَمُ', #1
u'يتباذلون،': u'يَتَبَاذَلُونَ،', #1
u'يتباذلون': u'يَتَبَاذَلُونَ', #3
u'يتبارآ': u'يَتَبَارَآ', #1
u'يتبارآن': u'يَتَبَارَآنِ', #1
u'يتباعثون': u'يَتَبَاعَثُونَ', #1
u'يتباقى': u'يَتَبَاقَى', #3
u'يتبالى': u'يَتَبَالَى', #1
u'يتبايعانه،': u'يَتَبَايَعَانِهِ،', #2
u'يتبايعانه': u'يَتَبَايَعَانِهِ', #4
u'يتبايعاهما': u'يَتَبَايَعَاهُمَا', #1
u'يتبايعه': u'يَتَبَايَعُهُ', #6
u'يتبايعها': u'يَتَبَايَعُهَا', #2
u'يتبايعونه': u'يَتَبَايَعُونَهُ', #2
u'يتبايعونها': u'يَتَبَايَعُونَهَا', #10
u'يتبايعوه': u'يَتَبَايَعُوهُ', #1
u'يتبايعوها': u'يَتَبَايَعُوهَا', #1
u'يتبخس': u'يَتَبَخّسُ', #1
u'يتبذل': u'يَتَبَذَّلَ', #1
u'يتبذل': u'يَتَبَذَّلْ', #1
u'يتبذل': u'يُتَبَذَّلُ', #1
u'يتبذلهن': u'يَتَبَذَّلَهُنَّ', #1
u'يتبرءوا': u'يَتَبَرَّءُوا', #1
u'يتبرءون': u'يَتَبَرَّءُونَ', #2
u'يتبرض': u'يُتَبَرّضُ', #4
u'يتبرضه': u'يتبرّضه', #1
u'يتبرضه': u'يَتَبَرَّضُهُ', #2
u'يتبرى': u'يَتَبَرَّى', #2
u'يتبشبش': u'يَتَبَشْبَشُ', #4
u'يتبعد': u'يَتَبَعَّد', #1
u'يتبعض': u'يَتَبَعّضُ', #1
u'يتبعض': u'يَتَبَعَّضَ', #13
u'يتبعض': u'يَتَبَعَّضُ', #314
u'يتبعض': u'يَتَبَعَّضْ', #6
u'يتبعضا': u'يَتَبَعَّضَا', #2
u'يتبعضان': u'يَتَبَعَّضَانِ', #1
u'يتبعنى': u'يَتْبَعْنِى', #2
u'يتبعونى': u'يَتَّبِعُونِى', #1
u'يتبكر': u'يَتَبَكَّرَ', #1
u'يتبوءون': u'يَتَبَوَّءُونَ', #1
u'يتبيغ': u'يَتَبَيَّغ', #1
u'يتتاركا': u'يَتَتَارَكَا', #18
u'يتتاركان': u'يَتَتَارَكَانِ', #1
u'يتترس': u'يَتَتَرَّسْ', #2
u'يتترس': u'يَتَتَرَّسُ', #9
u'يتترسوا': u'يَتَتَرَّسُوا', #1
u'يتتعتع': u'يتتعتع', #1
u'يتتعتع': u'يَتَتَعْتَع', #1
u'يتتعتع': u'يَتَتَعْتَعُ', #5
u'يتتمر': u'يَتَتَمَّرْ', #3
u'يتتمر': u'يَتَتَمَّرُ', #47
u'يتتمر': u'يَتَتَمَّرَ', #8
u'يتثاوب': u'يَتَثَاوَبَ', #1
u'يتثاورون': u'يَتَثَاوَرُونَ', #1
u'يتثاورون،': u'يَتَثَاوَرُونَ،', #1
u'يتثبط': u'يَتَثَبَّطُ', #3
u'يتثقفونه': u'يَتَثَقَّفُونَهُ', #1
u'يتثقل': u'يَتَثَقَّل', #1
u'يتثقلون': u'يَتَثَقَّلُونَ', #1
u'يتثمر': u'يَتَثَمَّرُ', #1
u'يتثنيان': u'يَتَثَنَّيَانِ', #1
u'يتثورون': u'يَتَثَوَّرُونَ', #1
u'يتجاحدا': u'يَتَجَاحَدَا', #2
u'يتجاحدون': u'يَتَجَاحَدُونَ', #1
u'يتجاذون': u'يَتَجَاذَوْنَ', #1
u'يتجار': u'يَتَجَارُّ', #1
u'يتجارون': u'يَتَجَارَوْنَ', #1
u'يتجارى': u'يَتَجَارَى', #15
u'يتجازى': u'يَتَجَازَى', #2
u'يتجاعلون': u'يَتَجَاعَلُونَ', #2
u'يتجان': u'يَتَجَانَّ', #2
u'يتجانف': u'يَتَجَانَفَ', #2
u'يتجانن': u'يَتَجَانَنُ', #3
u'يتجاولان': u'يَتَجَاوَلَانِ', #1
u'يتجحدل': u'يَتَجَحْدَلُ', #1
u'يتجرءون': u'يَتَجَرَّءُونَ', #1
u'يتجرجر': u'يَتَجَرْجَرُ', #1
u'يتجزءان': u'يَتَجَزَّءَانِ', #1
u'يتجزآن': u'يَتَجَزَّآنِ', #17
u'يتجزى': u'يَتَجَزَّى', #20
u'يتجشى': u'يَتَجَشَّى', #5
u'يتجلجل': u'يتجلجل', #2
u'يتجلجل': u'يَتَجَلْجَلُ', #49
u'يتجمر': u'يَتَجَمَّرَ', #1
u'يتجمر': u'يَتَجَمَّرُ', #5
u'يتحاجزون': u'يَتَحَاجَزُونَ', #1
u'يتحادر': u'يَتَحَادَرُ', #4
u'يتحاذيان': u'يَتَحَاذَيَانِ', #7
u'يتحارسون': u'يَتَحَارَسُونَ', #1
u'يتحاشا': u'يَتَحَاشَا', #1
u'يتحاص': u'يَتَحَاصَّ', #2
u'يتحاص': u'يُتَحَاصُّ', #4
u'يتحاص': u'يَتَحَاصُّ', #7
u'يتحاصا': u'يَتَحَاصَّا', #5
u'يتحاصان': u'يَتَحَاصَّانِ', #102
u'يتحاصص': u'يُتَحَاصَصُ', #1
u'يتحاصص': u'يَتَحَاصَصَ', #2
u'يتحاصص': u'يَتَحَاصَصُ', #2
u'يتحاصوا': u'يَتَحَاصُّوا', #1
u'يتحاصون': u'يَتَحَاصُّونَ', #46
u'يتحاضون': u'يَتَحَاضُّونَ', #1
u'يتحالل': u'يَتَحَالَلَ', #1
u'يتحالوا': u'يَتَحَالَوْا', #1
u'يتحبس': u'يَتَحَبَّسُ', #1
u'يتحتت': u'يَتَحَتَّتُ', #1
u'يتحتم': u'يَتَحَتَّمُ', #155
u'يتحتم': u'يَتَحَتَّمْ', #24
u'يتحتم': u'يَتَحَتَّمَ', #5
u'يتحجرها': u'يَتَحَجَّرَهَا', #2
u'يتحدثونه': u'يَتَحَدَّثُونَهُ', #1
u'يتحدقوا': u'يَتَحَدَّقُوا', #2
u'يتحذر': u'يَتَحَذَّرُ', #1
u'يتحرسون': u'يَتَحَرَّسُونَ', #1
u'يتحرف': u'يَتَحَرَّفْ', #1
u'يتحرف': u'يُتَحَرَّفُ', #1
u'يتحرف': u'يَتَحَرَّفُ', #2
u'يتحرف': u'يَتَحَرَّفَ', #3
u'يتحرفون': u'يَتَحَرَّفُونَ', #1
u'يتحرم': u'يَتَحَرَّمُ', #1
u'يتحرم': u'يَتَحَرَّمَ', #2
u'يتحرم': u'يَتَحَرَّمْ', #3
u'يتحريان': u'يَتَحَرَّيَانِ', #1
u'يتحزن': u'يَتَحَزَّنُ', #3
u'يتحزنوا': u'يَتَحَزَّنُوا', #2
u'يتحصله': u'يَتَحَصَّلَهُ', #1
u'يتحطب': u'يَتَحَطَّبُ', #1
u'يتحمد': u'يَتَحَمَّدْ', #1
u'يتحنبلوا': u'يَتَحَنْبَلُوا', #1
u'يتحنط': u'يَتَحَنَّطُ', #3
u'يتحنكون': u'يَتَحَنَّكُونَ', #1
u'يتحنن': u'يَتَحَنّنُ', #1
u'يتحنن': u'يَتَحَنَّنُ', #1
u'يتحيل': u'يُتَحَيَّلَ', #1
u'يتحيل': u'يُتَحَيَّلُ', #1
u'يتحيل': u'يَتَحَيَّلْ', #10
u'يتحيل': u'يَتَحَيَّلُ', #6
u'يتحيل': u'يَتَحَيَّلَ', #8
u'يتحيلوا': u'يَتَحَيَّلُوا', #2
u'يتحيلون': u'يَتَحَيَّلُونَ', #4
u'يتخارج': u'يَتَخَارَجُ', #3
u'يتخارجان': u'يَتَخَارَجَانِ', #1
u'يتخارجه': u'يَتَخَارَجُهُ', #2
u'يتخارجوه': u'يتخارجوه', #1
u'يتخاطون': u'يَتَخَاطُّونَ', #2
u'يتخالج': u'يَتَخَالَجَ', #1
u'يتخالج': u'يُتَخَالَجَ', #1
u'يتخالج': u'يَتَخَالَجُ', #2
u'يتخالون': u'يتخالون', #1
u'يتخاونا': u'يَتَخَاوَنَا', #1
u'يتخايرا': u'يَتَخَايَرَا', #9
u'يتخايران': u'يَتَخَايَرَانِ', #1
u'يتختم': u'يَتَخَتَّمَ', #11
u'يتختم': u'يَتَخَتَّم', #2
u'يتختم': u'يُتَخَتَّمَ', #2
u'يتختم': u'يَتَخَتَّمُ', #55
u'يتختم': u'يُتَخَتَّمُ', #8
u'يتختمن': u'يَتَخَتَّمْنَ', #1
u'يتختمون': u'يَتَخَتَّمُونَ', #7
u'يتخدمه': u'يَتَخَدَّمُهُ', #1
u'يتخرجه': u'يَتَخَرَّجْهُ', #3
u'يتخرص': u'يَتَخَرَّصُ', #1
u'يتخزق': u'يَتَخَزَّقْ', #1
u'يتخصر': u'يتخصَّر', #1
u'يتخصر': u'يَتَخَصَّرُ', #4
u'يتخضخض': u'يَتَخَضْخَضُ', #4
u'يتخضع': u'يَتَخَضَّعَ', #1
u'يتخطر': u'يَتَخَطَّرُ', #1
u'يتخطط': u'يَتَخَطَّطْ', #1
u'يتخلج': u'يَتَخَلَّجُ', #1
u'يتخلجن': u'يَتَخَلَّجَنَّ', #1
u'يتخلد': u'يَتَخَلَّدَ', #14
u'يتخلد': u'يَتَخَلَّدْ', #2
u'يتخلصه': u'يَتَخَلَّصْهُ', #1
u'يتخلصها': u'يَتَخَلَّصَهَا', #1
u'يتخلصها': u'يَتَخَلَّصْهَا', #1
u'يتخليان': u'يَتَخَلَّيَانِ', #1
u'يتخوضون': u'يَتَخَوَّضُونَ', #2
u'يتخول': u'يتخول', #2
u'يتخول': u'يَتَخَوَّلُ', #2
u'يتخولنا': u'يتخولنا', #1
u'يتخولنا،': u'يتخولنا،', #1
u'يتخولنا': u'يَتَخَوّلُنَا', #1
u'يتخولنا': u'يَتَخَوَّلُنَا', #12
u'يتخونهم': u'يَتَخَوَّنَهُمْ', #3
u'يتخونهم': u'يَتَخَوَّنُهُمْ', #7
u'يتخيرما': u'يَتَخَيَّرمَا', #1
u'يتدارءون': u'يَتَدَارَءُونَ', #1
u'يتداركنى': u'يَتَدَارَكَنِىَ', #1
u'يتداعيان': u'يَتَدَاعَيَانِ', #5
u'يتدافن': u'يتدافن', #1
u'يتدافنون،': u'يَتَدَافَنُونَ،', #1
u'يتدانى': u'يتدانى', #1
u'يتدانى': u'يَتَدَانَى', #3
u'يتداهى': u'يَتَدَاهَى', #1
u'يتداينه': u'يَتَدَايَنُهُ', #1
u'يتداينه': u'يَتَدَايَنْهُ', #1
u'يتداينها': u'يَتَدَايَنْهَا', #1
u'يتدفى': u'يَتَدَفَّى', #1
u'يتدلدل': u'يَتَدَلْدَل', #1
u'يتدلدل': u'يَتَدَلْدَلُ', #1
u'يتدمر': u'يَتَدَمَّرْ', #1
u'يتدهده': u'يَتَدَهْدَه', #1
u'يتدهده': u'يَتَدَهْدَهُ', #1
u'يتذاود': u'يَتَذَاوَدُ', #1
u'يتذك': u'يَتَذَكَّ', #3
u'يتذكى': u'يَتَذَكَّى', #8
u'يتذمم': u'يَتَذَمَّمُ', #1
u'يتراد': u'يَتَرادَّ', #1
u'يتراد': u'يُتَرَادُّ', #1
u'يتراد': u'يَتَرَادَّ', #7
u'يتراد': u'يَتَرَادُّ', #9
u'يترادا': u'يُتَرَادَّا', #1
u'يترادا': u'يَتَرَادَّا', #15
u'يترادان': u'يترادان', #1
u'يترادان': u'يَتَرَادَّانِ', #58
u'يترادن': u'يَتَرَادَّنِ', #1
u'يترادون': u'يَتَرَادُّونَ', #6
u'يترادونها': u'يَتَرَادُّونَهَا', #1
u'يتراضيان': u'يَتَرَاضَيَانِ', #36
u'يتراطلا': u'يَتَرَاطَلَا', #2
u'يتراعون': u'يتراعون', #1
u'يترامونها': u'يَتَرَامَوْنَهَا', #3
u'يتراميان': u'يَتَرَامَيَانِ', #3
u'يتراودان': u'يَتَرَاوَدَانِ', #2
u'يتراوض': u'يَتَرَاوَضَ', #4
u'يتراوضا': u'يَتَرَاوَضَا', #2
u'يتراوضان': u'يَتَرَاوَضَانِ', #1
u'يترائينها': u'يَتَرَائَيْنَهَا', #1
u'يترائينها،': u'يَتَرَائَيْنَهَا،', #1
u'يترايا': u'يَتَرَايَا', #1
u'يتربد': u'يَتَرَبّدُ', #2
u'يترحلا': u'يَتَرَحَّلَا', #1
u'يترحلون': u'يَتَرَحَّلُونَ', #4
u'يترخص': u'يَتَرَخَّص', #1
u'يترخص': u'يُتَرَخَّصَ', #1
u'يترخص': u'يُتَرَخَّصُ', #10
u'يترخص': u'يَتَرَخَّصُ', #144
u'يترخص': u'يَتَرَخَّصَ', #24
u'يترخص': u'يُتَرَخَّصْ', #3
u'يترخص': u'يَتَرَخَّصْ', #43
u'يترخصان': u'يَتَرَخَّصَانِ', #5
u'يترخصبه': u'يُتَرَخَّصَبِهِ', #1
u'يترخصوا': u'يَتَرَخَّصُوا', #1
u'يترخصون': u'يَتَرَخَّصُونَ', #5
u'يترخصونه': u'يَتَرَخَّصُونَهُ', #1
u'يترس': u'يُتَرّسُ', #1
u'يترشد': u'يَتَرَشَّدُ', #1
u'يترشدوا': u'يَتَرَشَّدُوا', #1
u'يترشرش': u'يَتَرَشْرَشَ', #3
u'يترشرش': u'يَتَرَشْرَشُ', #5
u'يترطل': u'يَتَرَطَّلُ', #1
u'يتركنى': u'يَتْرُكْنِى', #1
u'يترمد': u'يَتَرَمَّدُ', #4
u'يترى': u'يَتْرَى', #1
u'يتريب': u'يَتَرَيَّبُ', #1
u'يتريع': u'يَتَرَيّعُ', #2
u'يتزارعون': u'يَتَزَارَعُونَ', #1
u'يتزحف': u'يَتَزَحَّفُ', #1
u'يتزع': u'يَتَّزِع', #1
u'يتزعفر': u'يَتَزَعْفَر', #1
u'يتزعفر': u'يَتَزَعْفَرَ', #20
u'يتزلع': u'يَتَزَلَّعَ', #2
u'يتزلعون': u'يَتَزَلَّعُونَ', #1
u'يتزوجنى': u'يَتَزَوَّجَنِى', #1
u'يتزوده': u'يَتَزَوَّدُهُ', #1
u'يتزوده': u'يَتَزَوَّدَهُ', #2
u'يتزودونه': u'يَتَزَوَّدُونَهُ', #2
u'يتزيد': u'يَتَزَيَّدَ', #1
u'يتزيد': u'يُتَزَيَّدْ', #1
u'يتزيد': u'يَتَزَيَّدُ', #3
u'يتزيد': u'يَتَزَيَّدْ', #3
u'يتسافكوا': u'يَتَسَافَكُوا', #3
u'يتساكتون': u'يَتَسَاكَتُونَ', #1
u'يتسامتا': u'يَتَسَامَتَا', #1
u'يتسامحه': u'يَتَسَامَحُهُ', #1
u'يتساندوا': u'يَتَسَانَدُوا', #1
u'يتساهما': u'يَتَسَاهَمَا', #1
u'يتساوقان': u'يَتَسَاوَقَانِ', #1
u'يتساوقن': u'يَتَسَاوَقْنَ', #1
u'يتساوكن': u'يَتَسَاوَكْنَ', #1
u'يتساولان': u'يَتَسَاوَلَانِ', #1
u'يتساويان': u'يَتَسَاوَيَانِ', #73
u'يتسايون': u'يَتَسَايُونَ', #1
u'يتسبسب': u'يَتَسَبْسَبُ', #1
u'يتسبع': u'يَتَسَبَّعُ', #4
u'يتسحب': u'يُتَسَحَّبُ', #1
u'يتسحر،': u'يَتَسَحَّرَ،', #1
u'يتسحر': u'يَتَسَحَّرَ', #11
u'يتسحر': u'يَتَسَحّرُ', #2
u'يتسحر': u'يَتَسَحَّر', #2
u'يتسحر': u'يُتَسَحَّر', #2
u'يتسحر': u'يَتَسَحَّرُ', #25
u'يتسحر': u'يَتَسَحَّرْ', #6
u'يتسحر': u'يُتَسَحَّرُ', #9
u'يتسحرون': u'يَتَسَحَّرُونَ', #3
u'يتسخط': u'يَتَسَخّطُ', #2
u'يتسخط': u'يَتَسَخَّطَ', #4
u'يتسخط': u'يَتَسَخَّطُ', #4
u'يتسخطه': u'يَتَسَخَّطَهُ', #1
u'يتسخطها': u'يَتَسَخَّطُهَا', #2
u'يتسر': u'يَتَسَرَّ', #3
u'يتسراها': u'يَتَسَرَّاهَا', #3
u'يتسرر': u'يَتَسَرَّرُ', #4
u'يتسرر': u'يَتَسَرَّرَ', #7
u'يتسررها': u'يَتَسَرَّرُهَا', #1
u'يتسررها': u'يَتَسَرَّرَهَا', #2
u'يتسررها': u'يَتَسَرَّرْهَا', #2
u'يتسررون': u'يَتَسَرَّرُونَ', #1
u'يتسرق': u'يَتَسَرَّقُ', #1
u'يتسرها': u'يَتَسَرَّهَا', #1
u'يتسروا': u'يَتَسَرُّوا', #1
u'يتسرون': u'يَتَسَرَّوْنَ', #1
u'يتسرى': u'يَتَسَرَّى', #181
u'يتسريان': u'يَتَسَرَّيَانِ', #1
u'يتسطط': u'يُتَسَطَّطُ', #1
u'يتسمح': u'يَتَسَمَّحَ', #1
u'يتسمح': u'يُتَسَمَّحَ', #1
u'يتسمح': u'يَتَسَمَّحُ', #3
u'يتسمحون': u'يَتَسَمَّحُونَ', #5
u'يتسمنون': u'يَتَسَمَّنُونَ', #2
u'يتسود': u'يَتَسَوَّدْ', #2
u'يتسوك': u'يَتَسَوَّكُ', #17
u'يتسوك': u'يَتَسَوَّكْ', #2
u'يتسوك': u'يُتَسَوَّكُ', #3
u'يتسوك': u'يَتَسَوَّكَ', #5
u'يتسير': u'يَتَسَيَّرُ', #1
u'يتشافعون': u'يتشافعون', #1
u'يتشافعون': u'يَتَشَافَعُونَ', #5
u'يتشافى': u'يَتَشَافَى', #1
u'يتشحط': u'يَتَشَحَّط', #2
u'يتشحط': u'يَتَشَحَّطُ', #28
u'يتشحطون': u'يَتَشَحَّطُونَ', #1
u'يتشدخ': u'يَتَشَدَّخَ', #3
u'يتشرب': u'يُتَشَرَّبْ', #1
u'يتشرب': u'يَتَشَرَّبْ', #2
u'يتشرب': u'يَتَشَرَّبُ', #25
u'يتشرب': u'يَتَشَرَّبَ', #3
u'يتشرب': u'يُتَشَرَّبُ', #8
u'يتشربه': u'يَتَشَرَّبُهُ', #7
u'يتشربها': u'يَتَشَرَّبْهَا', #1
u'يتشرط': u'يَتَشَرَّطْ', #1
u'يتشرع': u'يُتَشَرَّعُ', #1
u'يتشرع': u'يَتَشَرَّعُ', #2
u'يتشطر': u'يَتَشَطَّرْ', #1
u'يتشطر': u'يَتَشَطَّرُ', #40
u'يتشطر': u'يَتَشَطَّرَ', #6
u'يتشطط': u'يَتَشَطَّطَ', #1
u'يتشططون': u'يَتَشَطَّطُونَ', #1
u'يتشطى': u'يَتَشَطَّى', #1
u'يتشغلا': u'يَتَشَغَّلَا', #1
u'يتشقص': u'يَتَشَقَّصُ', #1
u'يتشهده': u'يَتَشَهَّدُهُ', #1
u'يتصارفا': u'يَتَصَارَفَا', #3
u'يتصارفان': u'يَتَصَارَفَانِ', #1
u'يتصارفوا': u'يَتَصَارَفُوا', #1
u'يتصارفون': u'يَتَصَارَفُونَ', #1
u'يتصامم': u'يَتَصَامَمْ', #1
u'يتصحف': u'يَتَصَحّفُ', #1
u'يتصحف': u'يَتَصَحَّفَ', #1
u'يتصدقه': u'يَتَصَدَّقُهُ', #1
u'يتصرع': u'يَتَصَرَّعُ', #1
u'يتصرفه': u'يَتَصَرَّفَهُ', #1
u'يتصعد': u'يَتَصَعَّدُ', #1
u'يتصفق': u'يَتَصَفّقُ', #1
u'يتصفى': u'يَتَصَفَّى', #5
u'يتصلق': u'يَتَصَلِّقُ', #1
u'يتضار': u'يَتَضَارَّ', #1
u'يتضارطون': u'يَتَضَارَطُونَ', #2
u'يتضاغون': u'يتضاغون', #1
u'يتضاغون': u'يَتَضَاغَوْنَ', #12
u'يتضاغى': u'يَتَضَاغَى', #1
u'يتضبطها': u'يَتَضَبَّطُهَا', #1
u'يتضحى': u'يتضحى', #1
u'يتضرب': u'يَتَضَرَّبَ', #1
u'يتضرب': u'يَتَضَرَّبُ', #1
u'يتضيف': u'يُتَضَيَّفُ', #1
u'يتضيفهم': u'يتضيفهم', #1
u'يتطاعم': u'يَتَطَاعَمَ', #1
u'يتطالبان': u'يَتَطَالَبَانِ', #1
u'يتطاويان': u'يَتَطَاوَيَانِ', #1
u'يتطرقه': u'يَتَطَرَّقَهُ', #1
u'يتطرقه': u'يَتَطَرَّقُهُ', #1
u'يتطعم': u'يُتَطَعَّمُ', #4
u'يتطعمه': u'يَتَطَعَّمُهُ', #1
u'يتطوق': u'يُتَطَوَّقَ', #1
u'يتطؤها': u'يَتَّطِؤُهَا', #1
u'يتطئها': u'يَتَّطِئُهَا', #2
u'يتطيلس': u'يَتَطَيْلَسُ', #1
u'يتطيلسون': u'يَتَطَيْلَسُونَ', #1
u'يتظالمون': u'يَتَظَالَمُونَ', #1
u'يتظهرون': u'يَتَظَهَّرُونَ', #1
u'يتعار': u'يَتَعَارَّ', #1
u'يتعارضه': u'يَتَعَارَضْهُ', #1
u'يتعارفه': u'يَتَعَارَفهُ', #2
u'يتعارفه': u'يَتَعَارَفُهُ', #25
u'يتعارفها': u'يَتَعَارَفُهَا', #3
u'يتعارفونه': u'يَتَعَارَفُونَهُ', #16
u'يتعارفونها': u'يَتَعَارَفُونَهَا', #3
u'يتعارفوه': u'يَتَعَارَفُوهُ', #7
u'يتعارون': u'يَتَعَارُّونَ', #1
u'يتعاطسون': u'يتعاطسون', #1
u'يتعاطسون': u'يَتَعَاطَسُونَ', #7
u'يتعاقبانها': u'يَتَعَاقَبَانِهَا', #1
u'يتعاقدها': u'يَتَعَاقَدُهَا', #1
u'يتعاقرون': u'يَتَعَاقَرُونَ', #2
u'يتعاقل': u'يَتَعَاقَلُ', #3
u'يتعاقلا': u'يَتَعَاقَلَا', #1
u'يتعاقلان': u'يَتَعَاقَلَانِ', #1
u'يتعاقلون': u'يَتَعَاقَلُونَ', #66
u'يتعامله': u'يَتَعَامَلُهُ', #1
u'يتعاملونه': u'يَتَعَامَلُونَهُ', #3
u'يتعاملونها': u'يَتَعَامَلُونَهَا', #2
u'يتعاناه': u'يَتَعَانَاهُ', #1
u'يتعانى': u'يتعانى', #1
u'يتعانى': u'يَتَعَانَى', #8
u'يتعاوض': u'يُتَعَاوَضُ', #2
u'يتعاوضه': u'يَتَعَاوَضْهُ', #1
u'يتعاوون': u'يَتَعَاوَوْنَ', #2
u'يتعايا': u'يَتَعَايَا', #3
u'يتعايرونه': u'يَتَعَايَرُونَهُ', #1
u'يتعجز': u'يَتَعَجَّز', #1
u'يتعدل': u'يَتَعَدَّلَ', #1
u'يتعدل': u'يَتَعَدَّلُ', #1
u'يتعدلا': u'يَتَعَدَّلَا', #1
u'يتعدلون': u'يَتَعَدَّلُونَ', #1
u'يتعديان': u'يَتَعَدَّيَانِ', #6
u'يتعرصون': u'يَتَعَرَّصُونَ', #3
u'يتعز': u'يَتَعَزَّ', #3
u'يتعزر': u'يَتَعَزَّرُ', #1
u'يتعزى': u'يَتَعَزَّى', #3
u'يتعسل': u'يَتَعَسَّلَ', #1
u'يتعضد': u'يَتَعَضَّدُ', #1
u'يتعطاها': u'يَتَعَطَّاهَا', #1
u'يتعنت': u'يَتَعَنَّتْ', #1
u'يتعنت': u'يَتَعَنَّتَ', #4
u'يتعنت': u'يَتَعَنَّتُ', #7
u'يتعورون': u'يَتَعَوَّرُونَ', #3
u'يتعيب': u'يَتَعَيَّبَ', #2
u'يتعيب': u'يَتَعَيَّبْ', #20
u'يتعيب': u'يَتَعَيَّبُ', #35
u'يتعيبان': u'يَتَعَيَّبَانِ', #1
u'يتعير': u'يَتَعَيَّرُ', #16
u'يتعير': u'يُتَعَيَّرُ', #2
u'يتعيرون': u'يَتَعَيَّرُونَ', #15
u'يتغادر': u'يَتَغَادَرْ', #1
u'يتغالون': u'يَتَغَالَوْنَ', #3
u'يتغالى': u'يَتَغَالَى', #5
u'يتغدد': u'يَتَغَدَّدَ', #1
u'يتغديانه': u'يَتَغَدّيَانِهِ', #2
u'يتغذاه': u'يَتَغَذَّاهُ', #1
u'يتغر': u'يَتَّغِرْ', #1
u'يتغرر': u'يَتَغَرَّرُ', #1
u'يتغرض': u'يَتَغَرَّضَ', #1
u'يتغسل': u'يَتَغَسَّلُ', #1
u'يتغل': u'يَتَغَلَّ', #1
u'يتغلظ': u'يَتَغَلَّظْ', #2
u'يتغلظ': u'يَتَغَلَّظُ', #8
u'يتغمدنى': u'يَتَغَمَّدَنِى', #2
u'يتغمدنى': u'يَتَغَمَّدَنِىَ', #7
u'يتغمر': u'يَتَغَمَّرْ', #1
u'يتغنيان': u'يَتَغَنَّيَانِ', #1
u'يتغوثون': u'يَتَغَوَّثُونَ', #1
u'يتغوطه': u'يَتَغَوَّطَهُ', #4
u'يتفاصل': u'يَتَفَاصَلُ', #3
u'يتفاصلا': u'يَتَفَاصَلَا', #7
u'يتفاقز': u'يَتَفَاقَزُ', #1
u'يتفالس': u'يَتَفَالَسْ', #1
u'يتفاهمه': u'يَتَفَاهَمُهُ', #3
u'يتفاهمونه': u'يَتَفَاهَمُونَهُ', #1
u'يتفداني': u'يَتَفَدَّانِي', #1
u'يتفرخ': u'يَتَفَرَّخَ', #1
u'يتفزع': u'يَتَفَزَّعُ', #1
u'يتفصى': u'يَتَفَصَّى', #1
u'يتفعل': u'يَتَفَعَّلَ', #1
u'يتفلع': u'يَتَفَلّعُ', #1
u'يتفور': u'يَتَفَوَّرُ', #3
u'يتفيهق': u'يَتَفَيْهَقُ', #1
u'يتفيئون': u'يَتَفَيَّئُونَ', #1
u'يتقابحه': u'يَتَقَابَحُهُ', #1
u'يتقابضا': u'يَتَقَابَضَا', #91
u'يتقابضان': u'يَتَقَابَضَانِ', #2
u'يتقابضاه': u'يَتَقَابَضَاهُ', #1
u'يتقابضوا': u'يَتَقَابَضُوا', #7
u'يتقاحمون': u'يَتَقَاحَمُونَ', #1
u'يتقار': u'يَتَقَارَّ', #1
u'يتقارا': u'يَتَقَارَّا', #1
u'يتقارر': u'يَتَقَارَرَ', #2
u'يتقاررا': u'يَتَقَارَرَا', #3
u'يتقارران': u'يَتَقَارَرَانِ', #2
u'يتقارروا': u'يَتَقَارَرُوا', #1
u'يتقارشون': u'يَتَقَارَشُونَ', #1
u'يتقازوا،': u'يَتَقَازُّوا،', #1
u'يتقاص': u'يَتَقَاصَّ', #1
u'يتقاص': u'يَتَقَاصُّ', #3
u'يتقاصا': u'يَتَقَاصَّا', #31
u'يتقاصان': u'يَتَقَاصَّانِ', #32
u'يتقاصاه': u'يَتَقَاصَّاهُ', #1
u'يتقاصوا': u'يَتَقَاصَّوا', #1
u'يتقالها': u'يَتَقَالُّهَا', #8
u'يتقاودان': u'يَتَقَاوَدَانِ', #1
u'يتقاويان': u'يَتَقَاوَيَانِ', #1
u'يتقايأ': u'يَتَقَايَأَ', #1
u'يتقايأ': u'يَتَقَايَأُ', #13
u'يتقايأ': u'يَتَقَايَأْ', #2
u'يتقاياه': u'يَتَقَايَاهُ', #3
u'يتقايأه': u'يَتَقَايَأَهُ', #7
u'يتقايسان': u'يَتَقَايَسَانِ', #1
u'يتقايلاها': u'يَتَقَايَلَاهَا', #1
u'يتقايؤه': u'يَتَقَايَؤُهُ', #1
u'يتقدح': u'يَتَقَدَّحُ', #1
u'يتقردا': u'يُتَقَرَّدَا', #2
u'يتقرض': u'يَتَقَرَّضُ', #2
u'يتقسط': u'يَتَقَسَّطُ', #22
u'يتقعقع': u'يَتَقَعْقَعُ', #7
u'يتقفأ': u'يَتَقَفَّأَ', #1
u'يتقفر': u'يتقفر', #1
u'يتقلتسون': u'يتقلتسون', #1
u'يتقلل': u'يَتَقَلَّلُ', #5
u'يتقللها': u'يَتَقَلَلُهَا', #1
u'يتقللها': u'يَتَقَلَّلُهَا', #1
u'يتقمس': u'يَتَقَمَّسُ', #1
u'يتقوته': u'يتقوته', #1
u'يتقوله': u'يَتَقَوَّلُهُ', #1
u'يتقيآن': u'يَتَقَيّآنِ', #2
u'يتقيأه': u'يَتَقَيَّأْهُ', #1
u'يتقيأه': u'يَتَقَيَّأَهُ', #6
u'يتقيأها': u'يَتَقَيَّأُهَا', #1
u'يتقيأها': u'يَتَقَيَّأَهَا', #2
u'يتقيأها': u'يَتَقَيَّأْهَا', #4
u'يتقيده': u'يَتَقَيَّدْهُ', #1
u'يتقيؤها،': u'يَتَقَيَّؤُهَا،', #1
u'يتقيؤها': u'يَتَقَيَّؤُهَا', #4
u'يتكأدك': u'يَتَكَأَّدُكَ', #1
u'يتكاراه': u'يَتَكَارَاهُ', #2
u'يتكاراها': u'يَتَكَارَاهَا', #7
u'يتكارون': u'يَتَكَارُونَ', #3
u'يتكارى': u'يُتَكَارَى', #12
u'يتكارى': u'يَتَكَارَى', #58
u'يتكاريان': u'يَتَكَارَيَانِ', #1
u'يتكافا': u'يَتَكَافَّا', #1
u'يتكافآن': u'يَتَكَافَآنِ', #4
u'يتكافروا': u'يَتَكَافَرُوا', #2
u'يتكافئوا': u'يَتَكَافَئُوا', #1
u'يتكافئون': u'يَتَكَافَئُونَ', #2
u'يتكالمان': u'يَتَكَالَمَانِ', #1
u'يتكايس': u'يَتَكَايَسُ', #2
u'يتكد': u'يَتَّكِدُ', #1
u'يتكفأ': u'يَتَكَفّأُ', #1
u'يتكفأ': u'يَتَكَفَّأُ', #8
u'يتكفؤها': u'يَتَكَفَّؤُهَا', #1
u'يتكلب': u'يَتَكَلَّبُ', #1
u'يتكمه': u'يَتَكَمَّهُ', #1
u'يتكيء': u'يتكيء', #1
u'يتكئان': u'يَتّكِئَانِ', #1
u'يتكين': u'يَتَّكِينَ', #1
u'يتلازم': u'يَتَلَازَمْ', #2
u'يتلازم': u'يَتَلَازَمُ', #6
u'يتلازمان': u'يَتَلَازَمَانِ', #5
u'يتلاقح': u'يَتَلَاقَحُ', #1
u'يتلاقيان': u'يَتَلَاقَيَانِ', #3
u'يتلألؤ،': u'يَتَلأْلَؤُ،', #1
u'يتلبط': u'يَتَلَبَّطُ', #3
u'يتلبطون': u'يَتَلَبَّطُونَ', #1
u'يتلتلون': u'يُتَلْتَلُونَ', #1
u'يتلح': u'يَتَلَحَّ', #2
u'يتلحى': u'يَتَلَحَّى', #2
u'يتلدد': u'يَتَلَدَّدُ', #1
u'يتلدد': u'يَتَلَدّدُ', #2
u'يتلصق': u'يَتَلَصَّقُ', #1
u'يتلعب': u'يَتَلَعَّبَ', #1
u'يتلعب': u'يَتَلَعَّبُ', #1
u'يتلفق': u'يَتَلَفَّقُ', #4
u'يتلقانى': u'يَتَلَقَّانِى', #1
u'يتلقيان': u'يَتَلَقَّيَانِ', #1
u'يتلمح': u'يَتَلَمَّحَ', #1
u'يتلمح': u'يَتَلَمَّحُ', #2
u'يتلمح': u'يُتَلَمَّحُ', #4
u'يتلمط': u'يَتَلَمَّطُ', #1
u'يتلمظ': u'يَتَلَمَّظََََُ', #1
u'يتلمظ،': u'يَتَلَمَّظُ،', #1
u'يتلمظ': u'يَتَلَمَّظُ', #12
u'يتلمظ': u'يتلمظ', #2
u'يتلمظ': u'يَتَلَمَّظ', #2
u'يتلمظه': u'يَتَلَمَّظُهُ', #2
u'يتلمظها': u'يَتَلَمَّظُهَا', #1
u'يتلمظون': u'يَتَلَمّظُونَ', #1
u'يتلوان': u'يَتْلُوَانِ', #4
u'يتلوذون': u'يَتَلَوَّذُونَ', #1
u'يتلوعليهم': u'يَتْلُوعَلَيْهِمْ', #1
u'يتماريان': u'يَتَمَارَيَانِ', #1
u'يتماسح': u'يَتَمَاسَحُ', #1
u'يتماسحون': u'يَتَمَاسَحُونَ', #1
u'يتماشطن': u'يَتَمَاشَطْنَ', #1
u'يتماشيان': u'يَتَمَاشَيَانِ', #1
u'يتماقلان': u'يَتَمَاقَلَانِ', #1
u'يتماقلان': u'يَتَمَاقَلاَنِ', #1
u'يتماقلون': u'يَتَمَاقَلُونَ', #1
u'يتمالآ': u'يَتَمَالَآ', #10
u'يتمالأ': u'يَتَمَالَأَ', #3
u'يتمالأ': u'يُتَمَالَأْ', #3
u'يتمالأ': u'يَتَمَالَأْ', #7
u'يتمالئوا': u'يَتَمَالَئُوا', #9
u'يتمانع': u'يَتَمَانَعُ', #2
u'يتمانعون': u'يَتَمَانَعُونَ', #4
u'يتماهل': u'يتماهل', #1
u'يتمجس': u'يَتَمَجَّسُ', #2
u'يتمجع': u'يَتَمَجَّعُ', #1
u'يتمحض': u'يُتَمَحَّضُ', #1
u'يتمحض': u'يِتَمَحَّضْ', #2
u'يتمحض': u'يَتَمَحَّضَ', #5
u'يتمحض': u'يَتَمَحَّضُ', #66
u'يتمحض': u'يَتَمَحَّضْ', #81
u'يتمحضون': u'يَتَمَحَّضُونَ', #1
u'يتمحل': u'يُتَمَحَّلَ', #3
u'يتمحل': u'يُتَمَحَّلُ', #3
u'يتمحل': u'يَتَمَحَّلُ', #4
u'يتمحل': u'يَتَمَحَّلَ', #6
u'يتمخر': u'يَتَمَخَّرُ', #1
u'يتمدح': u'يَتَمَدَّحَ', #1
u'يتمدح': u'يُتَمَدَّحُ', #2
u'يتمدح': u'يَتَمَدَّحُ', #4
u'يتمدحوا': u'يَتَمَدَّحُوا', #1
u'يتمدحون': u'يَتَمَدَّحُونَ', #1
u'يتمسخر': u'يَتَمَسْخَرُ', #1
u'يتمسخر': u'يَتَمَسْخَرْ', #1
u'يتمسكه': u'يَتَمَسَّكُهُ', #1
u'يتمشط': u'يُتَمَشَّطَ', #1
u'يتمشط': u'يَتَمَشَّطُ', #2
u'يتمشط': u'يَتَمَشَّطَ', #4
u'يتمشطن': u'يَتَمَشَّطْنَ', #1
u'يتمشمش': u'يَتَمَشْمَشُ', #1
u'يتمشيان': u'يَتَمَشَّيَانِ', #3
u'يتمعر': u'يَتَمَعَّرُ', #1
u'يتمعزل': u'يَتَمَعْزَلْ', #1
u'يتمعش': u'يَتَمَعَّشُ', #4
u'يتمعشون': u'يَتَمَعَّشُونَ', #1
u'يتمعك': u'يَتَمَعَّكَ', #1
u'يتمعك': u'يَتَمَعَّكُ', #1
u'يتمعيشون': u'يَتَمَعْيَشُونَ', #1
u'يتمنيان': u'يَتَمَنَّيَانِ', #1
u'يتميزها': u'يَتَمَيَّزُهَا', #1
u'يتناتج': u'يَتَنَاتَجُ', #1
u'يتناجز': u'يَتَنَاجَزُ', #1
u'يتناجزا': u'يَتَنَاجَزَا', #1
u'يتناجش،': u'يَتَنَاجَشَ،', #1
u'يتناجشوا': u'يَتَنَاجَشُوا', #3
u'يتناجيان': u'يتناجيان', #1
u'يتناجيان': u'يَتَنَاجَيَانِ', #1
u'يتناشب': u'يَتَنَاشَبْ', #1
u'يتناصفاه': u'يَتَنَاصَفَاهُ', #1
u'يتناصفاها': u'يَتَنَاصَفَاهَا', #3
u'يتنافيان': u'يَتَنَافَيَانِ', #40
u'يتناقدا': u'يَتَنَاقَدَا', #3
u'يتناقدان': u'يَتَنَاقَدَانِ', #1
u'يتناقدونه': u'يَتَنَاقَدُونَهُ', #1
u'يتنبذ': u'يَتَنَبَّذَ', #1
u'يتنبهه': u'يَتَنَبَّهْهُ', #1
u'يتنجى': u'يُتَنَجَّى', #1
u'يتنحت': u'يتنحت', #1
u'يتنخع': u'يتنخع', #1
u'يتنخع': u'يَتَنَخَّعُ', #1
u'يتنخع': u'يُتَنَخَّعَ', #1
u'يتنخعن': u'يَتَنَخَّعَنَّ', #2
u'يتنخم': u'يتنخم', #1
u'يتنخم': u'يَتَنَخّمُ', #1
u'يتنخم': u'يُتَنَخَّمَ', #1
u'يتنخم': u'يَتَنَخَّمْ', #11
u'يتنخم': u'يَتَنَخَّمَ', #2
u'يتنخم': u'يَتَنَخَّمُ', #4
u'يتنخمن': u'يَتَنَخَّمَنَّ', #11
u'يتنخمون': u'يَتَنَخَّمُونَ', #1
u'يتنفج': u'يَتَنَفَّجُ', #1
u'يتنفله': u'يَتَنَفَّلَهُ', #1
u'يتهاترتان': u'يَتَهَاتَرَتَانِ', #1
u'يتهاداها': u'يَتَهَادَاهَا', #1
u'يتهارجون': u'يتهارجون', #1
u'يتهارجون': u'يَتَهَارَجَونَ', #1
u'يتهارجون': u'يَتَهَارَجُونَ', #4
u'يتهازلون': u'يَتَهَازَلُونَ', #2
u'يتهاود': u'يَتَهَاوَدَ', #1
u'يتهاوشون': u'يَتَهَاوَشُونَ', #2
u'يتهايأ': u'يَتَهَايَأُ', #1
u'يتهايأ': u'يَتَهَايَأْ', #1
u'يتهايأ': u'يَتَهَايَأَ', #5
u'يتهايآ': u'يَتَهَايَآ', #8
u'يتهايآن': u'يَتَهَايَآنِ', #6
u'يتهايآنها': u'يَتَهَايَآنِهَا', #3
u'يتهايؤن': u'يَتَهَايَؤُنَ', #1
u'يتهايئون': u'يَتَهَايَئُونَ', #7
u'يتهب': u'يَتَّهِبُ', #3
u'يتهب': u'يُتَّهَبُ', #5
u'يتهب': u'يَتَّهِبَ', #6
u'يتهبان': u'يَتَّهِبَانِ', #1
u'يتهبه': u'يَتَّهِبُهُ', #1
u'يتهبه': u'يَتَّهِبَهُ', #2
u'يتهبها': u'يَتَّهِبُهَا', #1
u'يتهر': u'يَتَهَرَّ', #4
u'يتهرع': u'يَتَهَرّعُ', #1
u'يتهرى': u'يَتَهَرَّى', #3
u'يتهنوا': u'يَتَهَنَّوْا', #1
u'يتهوع': u'يَتَهَوَّعُ', #3
u'يتهيآن': u'يَتَهَيَّآنِ', #2
u'يتهيئوا': u'يَتَهَيَّئُوا', #6
u'يتواخاه': u'يَتَوَاخَاهُ', #1
u'يتوازعانه': u'يَتَوَازَعَانِهِ', #1
u'يتوازعه': u'يَتَوَازَعَهُ', #1
u'يتواسون': u'يَتَوَاسُونَ', #1
u'يتواسون': u'يَتَوَاسَوْنَ', #1
u'يتواسى': u'يَتَوَاسَى', #1
u'يتواضعانها': u'يَتَوَاضَعَانِهَا', #6
u'يتواضعاها': u'يَتَوَاضَعَاهَا', #5
u'يتواطآن': u'يَتَوَاطَآنِ', #3
u'يتواطئوا': u'يَتَوَاطَئُوا', #10
u'يتواطئون': u'يَتَوَاطَئُونَ', #3
u'يتواعده': u'يَتَوَاعَدُهُ', #1
u'يتوافوا': u'يتوافوا', #1
u'يتوالاه': u'يَتَوَالَاهُ', #1
u'يتواليان': u'يَتَوَالَيَانِ', #1
u'يتوبونوالوجه': u'يَتُوبُونَوَالْوَجْهُ', #1
u'يتوجأ': u'يتوجأ', #1
u'يتوجأ': u'يَتَوَجّأُ', #1
u'يتوجأ': u'يَتَوَجَّأُ', #5
u'يتوح': u'يَتُوحُ', #1
u'يتودهم': u'يتودهم', #1
u'يتوذف': u'يتوذف', #1
u'يتوذف': u'يَتَوَذَّفُ', #1
u'يتورثا': u'يَتَوَرَّثَا', #1
u'يتوسعوه': u'يَتَوَسَّعُوهُ', #3
u'يتوسوس': u'يَتَوَسْوَسَ', #1
u'يتوسوس': u'يَتَوَسْوَسُ', #2
u'يتوشحنى': u'يَتَوَشَّحُنِى', #1
u'يتوضآن': u'يَتَوَضَّآنِ', #1
u'يتوضآن': u'يَتَوَضَّآَنِ', #1
u'يتوضأه': u'يَتَوَضَّأْهُ', #1
u'يتوضئوا': u'يَتَوَضَّئُوا', #20
u'يتوضئون': u'يَتَوَضَّئُونَ', #106
u'يتوضئون،': u'يَتَوَضَّئُونَ،', #2
u'يتوضيا': u'يَتَوَضَّيَا', #3
u'يتوطنها': u'يَتَوَطَّنْهَا', #3
u'يتوطؤه': u'يَتَوَطَّؤُهُ', #5
u'يتوقت': u'يَتَوَقَّتُ', #125
u'يتوقت': u'يَتَوَقَّتَ', #2
u'يتوقت': u'يَتَوَقَّتْ', #2
u'يتوقت': u'يُتَوَقَّتُ', #3
u'يتوقتان': u'يَتَوَقَّتَانِ', #3
u'يتوقص': u'يتوقص', #1
u'يتوقص': u'يَتَوَقَّصُ', #7
u'يتوكف': u'يَتَوَكَّفُ', #2
u'يتوكفان': u'يَتَوَكَّفَانِ', #1
u'يتوكفوا': u'يَتَوَكَّفُوا', #1
u'يتوكئون': u'يَتَوَكَّئُونَ', #3
u'يتولده': u'يَتَوَلَّدُهُ', #1
u'يتوليان': u'يَتَوَلَّيَانِ', #3
u'يتوي': u'يَتْوِيَ', #2
u'يتوي': u'يَتْوِي', #9
u'يتئد': u'يتئد', #2
u'يتئدون': u'يَتَّئِدُونَ', #2
u'يتيما': u'يَتِيًمَا', #1
u'يتيمتى': u'يَتِيمَتِى', #1
u'يتيمى؟': u'يَتِيمِى؟', #1
u'يتيمى': u'يَتِيمِى', #2
u'يثا': u'يُثَا', #1
u'يثافن': u'يُثَافَنْ', #1
u'يثتغر': u'يَثْتَغِر', #1
u'يثربي': u'يثربي', #1
u'يثربي': u'يَثْرِبِيٌّ', #1
u'يثربي': u'يَثْرِبِيِّ', #1
u'يثربى': u'يَثْرِبِىٍّ', #1
u'يثربي': u'يَثْرِبِيٍّ', #10
u'يثربى': u'يَثْرِبِىِّ', #2
u'يثربي': u'يَثْرِبِيّ', #4
u'يثرث': u'يُثْرَثُ', #1
u'يثعب': u'يثعب', #1
u'يثعب': u'يُثْعَبُ', #1
u'يثعب': u'يَثْعَب', #2
u'يثعب': u'يَثْعَبُ', #22
u'يثغب': u'يَثْغَبُ', #1
u'يثقه': u'يَثِقُهُ', #2
u'يثلطون': u'يَثْلَطُونَ', #1
u'يثلطون': u'يَثْلِطُونَ', #2
u'يثلغ': u'يثلغ', #1
u'يثلغ': u'يَثْلَغُ', #1
u'يثلغ': u'يُثْلَغُ', #3
u'يثلغوا': u'يَثْلَغُوا', #4
u'يثنيان': u'يُثْنيان', #1
u'يثهت': u'يَثْهَتُ', #1
u'يثيع': u'يَثِيعَ', #1
u'يثيع،': u'يُثَيْعٍ،', #4
u'يثيع': u'يُثَيْعٍ', #9
u'يج': u'يج', #2
u'يجابذني': u'يُجَابِذُنِي', #2
u'يجابهم': u'يُجَابِهُّمْ', #1
u'يجادلنى': u'يُجَادِلُنِى', #1
u'يجاعل': u'يُجَاعِلَ', #14
u'يجاعله': u'يُجَاعِلْهُ', #2
u'يجاعله': u'يُجَاعِلُهُ', #3
u'يجاعله': u'يُجَاعِلَهُ', #4
u'يجامعقال': u'يُجَامِعَقَالَ', #1
u'يجانئ': u'يُجَانِئُ', #6
u'يجبأ': u'يَجْبَأُ', #2
u'يجبنى': u'يُجِبْنِى', #1
u'يجبهماSتأويل': u'يُجِبْهُمَاSتَأْوِيلُ', #1
u'يجتبرها': u'يَجْتَبِرُهَا', #1
u'يجتبرونها': u'يَجْتَبِرُونَهَا', #1
u'يجتبرونها': u'يَجْتَبْرُونَهَا', #1
u'يجتدي': u'يَجْتَدِي', #2
u'يجتدى': u'يُجْتَدَى', #2
u'يجتدينا': u'يَجْتَدينا', #1
u'يجتدينا': u'يَجْتَدِينَا', #1
u'يجترم': u'يَجْتَرِمُ', #1
u'يجترؤن': u'يَجْتَرِؤُنَ', #1
u'يجترى': u'يُجْتَرَى', #1
u'يجتزأ': u'يَجْتَزِأُ', #1
u'يجتزأ': u'يُجْتَزَأ', #1
u'يجتزأ': u'يُجْتَزَأُ', #28
u'يجتزأ': u'يُجْتَزَأَ', #3
u'يجتزى': u'يَجْتَزِى', #1
u'يجتزى': u'يُجْتَزَى', #12
u'يجتزي': u'يَجْتَزِي', #14
u'يجتزي': u'يَجْتَزِيَ', #3
u'يجتزئ': u'يَجْتَزِئْ', #1
u'يجتزئ': u'يَجْتَزِئَ', #16
u'يجتزئ': u'يَجْتَزِئُ', #52
u'يجتزئوا': u'يجتزئوا', #1
u'يجتزئوا': u'يَجْتَزِئُوا', #1
u'يجتعل': u'يَجْتَعِلَ', #1
u'يجتلدون': u'يَجْتَلِدُونَ', #5
u'يجتلها': u'يَجْتَلَّهَا', #1
u'يجتلي': u'يَجْتَلِي', #4
u'يجتليكن': u'يجتليكُنّ', #1
u'يجتمعوها': u'يَجْتَمِعُوهَا', #1
u'يجتويني': u'يَجْتَوِينِي', #1
u'يجثو': u'يَجْثُوَ', #1
u'يجثو': u'يجثو', #2
u'يجثو': u'يَجْثُو', #5
u'يجثي': u'يَجْثِي', #1
u'يجحدوالوجه': u'يَجْحَدُوَالْوَجْهُ', #1
u'يجدونى': u'يَجِدُونِى', #1
u'يجرنى': u'يَجُرُّنِى', #2
u'يجريان': u'يُجْرَيَانِ', #1
u'يجريان': u'يُجْرِيَانِ', #2
u'يجريان': u'يَجْرِيَانِ', #84
u'يجزءوا': u'يُجَزَّءُوا', #1
u'يجزءون': u'يُجَزَّءُونَ', #10
u'يجزآن': u'يُجَزِّآنِ', #1
u'يجزنى': u'يُجِزْنِى', #7
u'يجزؤه': u'يُجْزِؤُهُ', #1
u'يجزئان': u'يُجْزِئَانِ', #14
u'يجزيان': u'يَجْزِيَانِ', #7
u'يجزيان': u'يُجْزِيَانِ', #9
u'يجزينى': u'يُجْزِينِى', #1
u'يجزينى': u'يَجْزِينِى', #2
u'يجعلنى': u'يَجْعَلْنِى', #1
u'يجعلنى': u'يَجْعَلَنِى', #19
u'يجلجلها': u'يُجَلْجِلُهَا', #1
u'يجلدنى': u'يَجْلِدْنِى', #1
u'يجلسقبل': u'يَجْلِسَقَبْلَ', #1
u'يجلسولا': u'يَجْلِسُوَلَا', #1
u'يجلعها': u'يَجْلَعَهَا', #1
u'يجنأ': u'يجنأ', #1
u'يجنأ': u'يَجْنَأَ', #1
u'يجنأ': u'يَجْنَأُ', #12
u'يجنز': u'يَجْنُزُ', #1
u'يجنز': u'يَجْنِزُ', #2
u'يجنزه': u'يُجَنِّزُهُ', #2
u'يجنزه': u'يَجْنِزُهُ', #3
u'يجنف': u'يَجْنَفُ', #1
u'يجنو': u'يَجْنُو', #1
u'يجنئ': u'يُجْنِئُ', #4
u'يجنيان': u'يَجْنِيَانِ', #2
u'يجوزله': u'يَجُوزُلَهُ', #1
u'يجؤه': u'يَجَؤُهُ', #2
u'يجي': u'يَجِي', #1
u'يجىء': u'يَجِىءْ', #1
u'يجىء': u'يَجِىءَ', #26
u'يجىء': u'يجىء', #3
u'يجىء': u'يَجِىءُ', #47
u'يجيزي': u'يجيزي', #1
u'يجيئك': u'يَجِيئُك', #3
u'يجيئكم': u'يَجِيئُكُمْ', #1
u'يجيئنا': u'يَجِيئنَا', #1
u'يجيئنا': u'يَجِيئَنَا', #1
u'يجيئنا': u'يَجِيئُنَا', #1
u'يجيئني': u'يَجِيئنِي', #1
u'يجيئني': u'يَجِيئَنِي', #1
u'يجيئني': u'يَجِيئُنِي', #2
u'يجيئنى': u'يَجِيئُنِى', #3
u'يجيئه': u'يَجِيئهُ', #2
u'يجيئه': u'يَجِيئَهُ', #6
u'يجيئه': u'يَجِيئُهُ', #7
u'يجيئها': u'يَجِيئُهَا', #1
u'يجيئهم': u'يَجِيئَهُمْ', #1
u'يحابر': u'يحابر', #1
u'يحابر': u'يُحَابِر', #1
u'يحابر': u'يُحَابِرُ', #2
u'يحآجوكم': u'يُحَآجُّوكُمْ', #1
u'يحادي': u'يُحَادِي', #1
u'يحاذيان': u'يُحَاذِيَانِ', #1
u'يحارف': u'يُحَارَفْ', #1
u'يحارف': u'يُحَارِفُ', #1
u'يحازونه': u'يُحَازُونَهُ', #1
u'يحازي': u'يُحَازِي', #1
u'يحاس': u'يُحَاسُ', #7
u'يحاسس': u'يُحَاسِسُ', #1
u'يحاص': u'يُحَاصُّ', #102
u'يحاص': u'يُحَاصّ', #2
u'يحاص': u'يُحَاصَّ', #22
u'يحاصص': u'يُحَاصَصْ', #1
u'يحاصص': u'يُحَاصَصُ', #11
u'يحاصص': u'يُحَاصِصَ', #14
u'يحاصص': u'يُحَاصِصْ', #2
u'يحاصص': u'يُحَاصِصُ', #77
u'يحاصصن': u'يُحَاصِصْنَ', #1
u'يحاصصه': u'يُحَاصِصْهُ', #3
u'يحاصصهم': u'يُحَاصِصُهُم', #1
u'يحاصصهم': u'يُحَاصِصُهُمْ', #4
u'يحاصصونهم': u'يُحَاصِصُونَهُمْ', #1
u'يحاصه': u'يُحَاصُّهُ', #1
u'يحاصه': u'يُحَاصَّهُ', #3
u'يحاصهم': u'يَحَاصُّهُمْ', #1
u'يحاصهم': u'يُحَاصَّهُمْ', #3
u'يحاصهم': u'يُحَاصُّهُمْ', #7
u'يحاصون': u'يُحَاصُّونَ', #5
u'يحاصونها': u'يُحَاصُّونَهَا', #1
u'يحاقنى': u'يُحَاقُّنِى', #2
u'يحالله': u'يُحَالِلَهُ', #1
u'يحاوزهما': u'يحاوزهما', #1
u'يحاوزهن': u'يُحَاوِزُهُنَّ', #1
u'يحببنى': u'يُحَبِّبَنِى', #1
u'يحبنى': u'يُحِبَّنِى', #1
u'يحبي': u'يُحْبِيَ', #1
u'يحتاجانه': u'يَحْتَاجَانِهِ', #2
u'يحتاجه': u'يَحْتَاجَهُ', #11
u'يحتاجه': u'يَحْتَاجهُ', #3
u'يحتاجه': u'يَحْتَاجُهُ', #309
u'يحتاجها': u'يَحْتَاجَهَا', #1
u'يحتاجها': u'يَحْتَاجُهَا', #66
u'يحتاجهم': u'يَحْتَاجُهُمْ', #2
u'يحتاجهما': u'يَحْتَاجُهُمَا', #9
u'يحتاجهن': u'يَحْتَاجُهُنَّ', #1
u'يحتاجونه': u'يَحْتَاجُونَهُ', #6
u'يحتاجونها': u'يَحْتَاجُونَهَا', #2
u'يحتاجوه': u'يَحْتَاجُوهُ', #1
u'يحتازها': u'يَحْتَازُهَا', #1
u'يحتازونا': u'يَحْتَازُونَا', #2
u'يحتاشها': u'يَحْتَاشُهَا', #1
u'يحتاله': u'يَحْتَالُهُ', #3
u'يحتبش': u'يَحْتَبِشُ', #1
u'يحتبيان': u'يَحْتَبِيَانِ', #2
u'يحتثوا': u'يَحْتَثُوا', #1
u'يحتثى': u'يَحْتَثِى', #1
u'يحتثي': u'يَحْتَثِي', #2
u'يحتجر': u'يَحْتَجِرَ', #1
u'يحتجر': u'يَحْتَجِرُ', #2
u'يحتجره': u'يَحْتَجِرُهُ', #1
u'يحتجم': u'يَحْتَجِمَ', #16
u'يحتجم،': u'يَحْتَجِمُ،', #2
u'يحتجم': u'يَحْتَجِمْ', #5
u'يحتجم': u'يَحْتَجِمُ', #90
u'يحتجمان': u'يَحْتَجِمَانِ', #3
u'يحتدره': u'يَحْتَدِرُهُ', #1
u'يحتدى': u'يُحْتَدَى', #1
u'يحترزه': u'يَحْتَرِزُهُ', #1
u'يحتز': u'يَحْتَزَّ', #1
u'يحتز': u'يحتز', #2
u'يحتز': u'يَحْتَزُّ', #27
u'يحتزم': u'يَحْتَزِمَ', #11
u'يحتزم': u'يَحْتَزِم', #2
u'يحتزم': u'يَحْتَزِمُ', #5
u'يحتزوا': u'يَحْتَزّوا', #1
u'يحتش': u'يَحْتَشُّ', #2
u'يحتش': u'يُحْتَشَّ', #3
u'يحتش': u'يَحْتَشَّ', #5
u'يحتش': u'يُحْتَشُّ', #5
u'يحتشا': u'يُحْتَشَّا', #1
u'يحتشا': u'يَحْتَشَّا', #4
u'يحتشه': u'يَحْتَشَّهُ', #1
u'يحتشه': u'يَحْتَشُّهُ', #1
u'يحتشي': u'يَحْتَشِي', #1
u'يحتشي': u'يَحْتَشِيَ', #4
u'يحتفر': u'يُحْتَفَرُ', #1
u'يحتفره': u'يَحْتَفِرُهُ', #1
u'يحتفره': u'يَحْتَفِرهُ', #2
u'يحتفرها': u'يَحْتَفِرْهَا', #1
u'يحتفرها': u'يَحْتَفِرَهَا', #2
u'يحتفرها': u'يَحْتَفِرُهَا', #3
u'يحتفرونها': u'يَحْتَفِرُونَهَا', #2
u'يحتفز': u'يَحْتَفِزُ', #3
u'يحتفه': u'يَحْتِفُهُ', #1
u'يحتقان': u'يحتقان', #1
u'يحتقان': u'يَحْتَقَّانِ', #3
u'يحتقون': u'يَحْتَقُّونَ', #1
u'يحتلم': u'يَحْتَلِمًّ', #1
u'يحتنكون': u'يَحْتَنِكُونَ', #1
u'يحتوش': u'يَحْتَوِشُ', #1
u'يحتوش': u'يَحْتَوِشْ', #9
u'يحتوشه': u'يَحْتَوِشْهُ', #2
u'يحتوشها': u'يَحْتَوِشُهَا', #1
u'يحثثننى': u'يَحْثُثْنَنِى', #2
u'يحثم': u'يَحْثُمَ', #1
u'يحثي': u'يُحْثِي', #2
u'يحثي': u'يَحْثِي', #31
u'يحثي': u'يَحْثِيَ', #4
u'يحججان': u'يَحْجُجَانِ', #1
u'يحجف': u'يُحْجَفُ', #1
u'يحجف': u'يُحْجِفُ', #1
u'يحدت': u'يُحَدِّتُ', #1
u'يحدثكموه': u'يُحَدِّثُكُمُوهُ', #2
u'يحدثناه': u'يُحَدِّثُنَاهُ', #1
u'يحدثناها': u'يُحَدِّثُنَاهَا', #1
u'يحدثنى': u'يُحَدِّثَنِى', #1
u'يحدثنى': u'يُحَدِّثْنِى', #4
u'يحدثنى': u'يُحَدِّثُنِى', #6
u'يحدثنيه': u'يُحَدِّثَنِيهِ', #1
u'يحدثنيه': u'يُحَدِّثُنِيهِ', #1
u'يحدثنيه': u'يُحَدِّثْنِيهِ', #1
u'يحدثونى': u'يُحَدِّثُونِى', #1
u'يحدوان': u'يَحْدُوَانِ', #1
u'يحدي': u'يَحْدِي', #1
u'يحذم': u'يَحْذِمُ', #1
u'يحذيان': u'يُحْذَيَانِ', #1
u'يحرسنى': u'يَحْرُسُنِى', #2
u'يحرقS': u'يُحْرَقْS', #1
u'يحزننى': u'يُحْزِنُنِى', #1
u'يحزننى': u'يَحْزُنُنِى', #2
u'يحشرنى': u'يَحْشُرَنِى', #1
u'يحصبنى': u'يَحْصِبُنِى', #1
u'يحضرنى': u'يَحْضُرْنِى', #3
u'يحضرنى': u'يَحْضُرُنِى', #4
u'يحظلا': u'يُحْظَلَا', #2
u'يحظو': u'يَحْظُو', #1
u'يحفد': u'يَحْفِدُ', #2
u'يحفده': u'يَحْفِدُهُ', #1
u'يحفذ': u'يَحْفِذُ', #1
u'يحفظنى': u'يَحْفَظَنِى', #1
u'يحفظنى': u'يَحْفَظَنِىَ', #1
u'يحفي': u'يحفي', #1
u'يحفي': u'يحفِي', #1
u'يحفي': u'يُحفي', #1
u'يحفي': u'يُحْفِي', #5
u'يحفيان': u'يَحْفَيَانِ', #1
u'يحفيه': u'يُحْفِيَهُ', #1
u'يحفيه': u'يُحْفِيه', #2
u'يحفيه': u'يُحْفِيهِ', #3
u'يحكيان': u'يَحْكِيَانِ', #1
u'يحمار': u'يَحْمَارَّ', #1
u'يحمار': u'يَحْمَارُّ', #1
u'يحمدنكا': u'يَحْمَدُنّكَا', #1
u'يحمدونكا': u'يَحْمَدُونَكَا', #3
u'يحمش': u'يَحْمُشُ', #1
u'يحملنى': u'يَحْمِلُنِى', #5
u'يحنأ': u'يَحْنَأُ', #3
u'يحنة': u'يُحَنّةَ', #1
u'يحنة': u'يُحَنّةُ', #3
u'يحنة': u'يُحَنَّةُ', #3
u'يحنج': u'يُحْنِجْ', #1
u'يحنج': u'يُحْنَجْ', #2
u'يحنس': u'يُحَنَّسَ', #15
u'يحنس،': u'يُحَنَّسَ،', #2
u'يحنس،': u'يُحَنِّسَ،', #2
u'يحنس': u'يُحَنَّسُ', #3
u'يحنس': u'يُحَنّسُ', #4
u'يحنس': u'يُحَنِّسَ', #6
u'يحنئ': u'يَحْنِئُ', #1
u'يحوبه': u'يَحُوبُهُ', #1
u'يحوبها': u'يُحَوِّبهَا', #1
u'يحوكه': u'يَحُوكَهُ', #1
u'يحوكه': u'يَحُوكُهُ', #1
u'يحولق': u'يُحَوْلِقُ', #1
u'يحى': u'يحى', #1
u'يحيبوا': u'يُحِيبُوا', #1
u'يحيث': u'يُحِيث', #3
u'يحيف': u'يَحِيفَ', #23
u'يحيف': u'يَحِيف', #3
u'يحيف': u'يَحِيفُ', #4
u'يحيفان': u'يَحِيفَانِ', #1
u'يحيى،': u'يَحيَى،', #1
u'يحيى': u'يَحَّيَى', #1
u'يحيى': u'يَحْيَىَ', #1
u'يحيى': u'يَحْيَىُ', #1
u'يحيى': u'يُحْيَى', #1
u'يحيى': u'يَحْيى', #11
u'يحيى،': u'يحيى،', #123
u'يحيى': u'يُحْيِىَ', #2
u'يحيى،': u'يَحْيَى،', #2260
u'يحيى': u'يَحْيَى', #26882
u'يحيى': u'يَحْيَىِ', #3
u'يحيى': u'يُحَيَّى', #3
u'يحيى': u'يحيى', #473
u'يحيى': u'يُحْيِى', #8
u'يحيى،أنبأ': u'يَحْيَى،أَنْبَأَ', #8
u'يحيى،عن': u'يَحْيَى،عَنْ', #1
u'يحييون': u'يَحْيَيَوْنَ', #1
u'يخارج': u'يُخَارِجُ', #1
u'يخارج': u'يُخَارَجُ', #4
u'يخارجهم': u'يُخَارِجُهُمْ', #1
u'يخالجنى': u'يُخَالِجُنِى', #1
u'يخالجنيها،': u'يُخَالِجَنِيهَا،', #1
u'يخالل،': u'يخالل،', #1
u'يخالل': u'يُخَالِلُ', #3
u'يخالل': u'يُخَالِلْ', #9
u'يخاله': u'يَخَالُهُ', #2
u'يخببهم': u'يُخَبِّبَهُمْ', #1
u'يخببوا': u'يُخَبِّبُوا', #3
u'يخببوا': u'يُخَبَّبُوا', #5
u'يخبركموالوجه': u'يُخْبِرْكُمْوَالْوَجْهُ', #1
u'يخبرنى': u'يُخْبِرَنِى', #1
u'يخبرنى': u'يُخْبِرُنِى', #7
u'يخبؤها': u'يَخْبَؤُهَا', #1
u'يخبئان': u'يُخَبِّئَانِ', #3
u'يختبط': u'يُخْتَبَطُ', #1
u'يختدم': u'يَخْتَدِمُ', #2
u'يختدمانه': u'يَخْتَدِمَانِهِ', #2
u'يختدمه': u'يَخْتَدِمَهُ', #1
u'يختدمه': u'يَخْتَدِمُهُ', #18
u'يخترط': u'يَخْتَرِطُ', #1
u'يخترف': u'يُخْتَرَف', #1
u'يخترف': u'يُخْتَرَفُ', #2
u'يخترف': u'يَخْتَرِفُ', #5
u'يخترفها': u'يَخْتَرِفُهَا', #1
u'يخترم': u'يُخْتَرَمَ', #1
u'يخترم': u'يُخْتَرَمْ', #2
u'يختشيه': u'يَخْتَشِيهِ', #4
u'يختطلون': u'يَخْتَطِلُونَ', #1
u'يختلع': u'يَخْتَلِعَ', #11
u'يختلع': u'يَخْتَلِعُ', #7
u'يختلعن': u'يَخْتَلِعْنَ', #1
u'يختلعها': u'يَخْتَلِعُهَا', #2
u'يختلعها': u'يَخْتَلِعَهَا', #7
u'يختليان': u'يَخْتَلِيَانِ', #1
u'يخدج': u'يُخْدَجْ', #1
u'يخدمنى': u'يَخْدُمُنِى', #5
u'يخذف': u'يخذف', #1
u'يخذف': u'يُخْذَفُ', #1
u'يخذف': u'يَخْذِفُ', #13
u'يخذف،': u'يَخْذِفُ،', #6
u'يخذفون': u'يَخْذِفُونَ', #2
u'يخرأ': u'يَخْرَأُ', #1
u'يخرجنى': u'يُخْرِجَنِى', #1
u'يخسق': u'يَخْسِقُ', #1
u'يخشيان': u'يَخْشَيَانِ', #1
u'يخضخض': u'يُخَضْخِضَ', #2
u'يخضخضه': u'يُخَضْخِضْهُ', #2
u'يخضد': u'يَخْضِد', #1
u'يخطبنى': u'يَخْطِبُنِى', #1
u'يخطبنى': u'يَخْطُبُنِى', #3
u'يخطرف': u'يُخَطْرَفَ', #1
u'يخطرف': u'يُخَطْرِفَ', #1
u'يخطرفها': u'يُخَطْرِفَهَا', #1
u'يخطىء': u'يخطىء', #1
u'يخطئان': u'يُخْطِئَانِ', #1
u'يخفو،': u'يَخْفُو،', #1
u'يخفونقوله': u'يُخْفُونَقَوْلُهُ', #1
u'يخفىSشعر': u'يَخْفَىSشِعْرُ', #1
u'يخفيان': u'يخفيان', #1
u'يخفيان': u'يَخْفَيَانِ', #3
u'يخلج': u'يَخْلُجُ', #1
u'يخلصنى': u'يُخَلِّصَنِى', #1
u'يخلقنى': u'يَخْلُقَنِى', #2
u'يخلوان': u'يَخْلُوَانِ', #9
u'يخليان': u'يُخَلِّيَانِ', #1
u'يخيس': u'يَخِيسُ', #2
u'يداSحكم': u'يَدَاSحُكْمُ', #1
u'يداى': u'يَدَاىَ', #1
u'يدبه': u'يَدِبُّهُ', #1
u'يدة': u'يدة', #1
u'يدخلنى': u'يُدْخِلُنِى', #3
u'يدخلنى': u'يَدْخُلُنِى', #4
u'يدرءون': u'يَدْرَءُونَ', #5
u'يدرأمن': u'يَدْرَأَمَنْ', #1
u'يدرآن': u'يُدْرَآنِ', #2
u'يدرد': u'يَدْرَدَ', #1
u'يدرد': u'يَدْرَدُ', #1
u'يدردني': u'يُدْرِدَنِيَ', #1
u'يدردني': u'يُدْرِدَنِي', #2
u'يدردنى': u'يُدْرِدَنِى', #2
u'يدركلون': u'يُدَرْكِلُونَ', #1
u'يدركمعه': u'يُدْرِكْمَعَهُ', #1
u'يدركنى': u'يُدْرِكْنِى', #3
u'يدركنى': u'يُدْرِكَنِى', #5
u'يدرو': u'يدرو', #1
u'يدرؤه': u'يَدْرَؤُهُ', #2
u'يدرؤها': u'يَدْرَؤُهَا', #1
u'يدريان': u'يدريان', #1
u'يدريان،': u'يَدْرِيَانِ،', #1
u'يدريان': u'يَدْرِيَانِ', #17
u'يدرينى': u'يُدْرِينِى', #3
u'يدطرح': u'يَدْطَرِحُ', #1
u'يدعنى': u'يَدَعَنِى', #1
u'يدعوان': u'يدعوان', #1
u'يدعوان': u'يَدْعُوَانِ', #7
u'يدعوننى': u'يَدْعُونَنِى', #1
u'يدعونى': u'يَدْعُونِى', #12
u'يدعيان': u'يَدَّعِيَانِ', #70
u'يدفئنى': u'يُدْفِئُنِى', #1
u'يدكردن': u'يدكردن', #1
u'يدلسه': u'يُدَلِّسُهُ', #1
u'يدلسه': u'يُدَلِّسْهُ', #1
u'يدلسها': u'يُدَلِّسُهَا', #1
u'يدليان': u'يُدْلِيَانِ', #29
u'يدنتوان': u'يدنتوان', #1
u'يدنينى': u'يُدْنِينِى', #1
u'يدهده': u'يُدَهْدِهُ', #4
u'يدهمق': u'يُدَهْمَقُ', #2
u'يدوب': u'يدوب', #1
u'يدوترا': u'يدوترا', #1
u'يدولبه': u'يُدَوْلِبُهُ', #1
u'يدية': u'يدية', #1
u'يدية': u'يُدَيَّةٍ', #1
u'يديل': u'يُدِيلُ', #2
u'يديلنا': u'يُدِيلُنَا', #1
u'يديهإلا': u'يَدَيْهِإِلَّا', #1
u'يذبي': u'يَذْبِي', #1
u'يذتا': u'يذتا', #1
u'يذرؤكم': u'يَذْرَؤُكُمْ', #4
u'يذفر': u'يَذْفَرُ', #1
u'يذكار': u'يذكار', #1
u'يذكاره': u'يذكاره', #1
u'يذكاري': u'يذكاري', #2
u'يذكرخير': u'يَذْكُرْخَيْرٌ', #1
u'يذكرنى': u'يَذْكُرْنِى', #2
u'يذكرنى': u'يَذْكُرُنِى', #3
u'يذكرنيهم': u'يُذَكِّرُنِيهِمْ', #1
u'يذير': u'يذير', #5
u'يذيرفت': u'يذيرفت', #3
u'يذيرفتم': u'يذيرفتم', #2
u'يذيرفتى': u'يذيرفتى', #1
u'يراء': u'يُرَاءِ', #12
u'يرآءون': u'يُرَآءُونَ', #1
u'يراءون': u'يُرَاءُونَ', #27
u'يراجعنى': u'يُرَاجِعُنِى', #3
u'يرادعوى': u'يرادعوى', #1
u'يراطل': u'يُرَاطِلُ', #3
u'يراطل': u'يُرَاطِلَ', #4
u'يراطلك': u'يُرَاطِلُكَ', #1
u'يراطله': u'يُرَاطِلُهُ', #1
u'يراطله': u'يُرَاطِلْهُ', #1
u'يراطله': u'يُرَاطِلَهُ', #2
u'يراعيان': u'يُرَاعَيَانِ', #2
u'يراكا': u'يَرَاكَا', #2
u'يرانهما': u'يُرَانِهِمَا', #1
u'يرانى': u'يَرَانِى', #9
u'يراهنني': u'يراهنني', #1
u'يراهننى؟': u'يُرَاهِنُنِى؟', #1
u'يراهني': u'يُرَاهِنِّي', #1
u'يراوض': u'يُرَاوِضَ', #2
u'يراوضه': u'يُرَاوِضُهُ', #3
u'يراوضه': u'يُرَاوِضَهُ', #5
u'يراؤن،': u'يراؤن،', #1
u'يرآؤون': u'يُرَآؤُونَ', #1
u'يراؤون': u'يراؤون', #1
u'يرائي': u'يرائي', #1
u'يرائى': u'يُرَائِى', #2
u'يرائي': u'يُرَائِيَ', #4
u'يرائي': u'يُرَائِي', #45
u'يرائيه': u'يُرَائِيَهُ', #1
u'يربحنى': u'يُرْبِحُنِى', #1
u'يربنى': u'يَرُبَّنِى', #2
u'يربؤها': u'يَرْبَؤُهَا', #1
u'يربئون': u'يَرْبَئُونَ', #1
u'يرة': u'يْرَةَ', #1
u'يرتاض': u'يَرْتَاضَ', #1
u'يرتاض': u'يَرْتَاضُ', #3
u'يرتاض': u'يُرْتَاضَ', #3
u'يرتث': u'يَرْتَثِ', #1
u'يرتث': u'يَرْتَثَّ', #2
u'يرتث': u'يُرْتَثَّ', #6
u'يرتثوا': u'يُرْتَثُّوا', #1
u'يرتجز': u'يرتجز', #1
u'يرتجز': u'يَرْتَجِز', #1
u'يرتجز': u'يَرْتَجِزَ', #2
u'يرتجز،': u'يَرْتَجِزُ،', #4
u'يرتجز': u'يَرْتَجِزُ', #55
u'يرتجزان': u'يَرْتَجِزَانِ', #2
u'يرتجزن': u'يَرْتَجِزْنَ', #1
u'يرتجزون،': u'يَرْتَجِزُونَ،', #2
u'يرتجزون': u'يَرْتَجِزُونَ', #20
u'يرتجع': u'يرْتَجِعَ', #1
u'يرتجع': u'يَرْتَجِعْ', #19
u'يرتجع': u'يرتجع', #2
u'يرتجع': u'يَرْتَجِعَ', #21
u'يرتجع': u'يَرْتَجِعُ', #36
u'يرتجعه': u'يَرْتَجِعْهُ', #1
u'يرتجعه': u'يَرْتَجِعَهُ', #2
u'يرتجعه': u'يَرْتَجِعُهُ', #2
u'يرتجعها': u'يَرْتَجِعهَا', #1
u'يرتجعها': u'يَرْتَجِعُهَا', #14
u'يرتجعها': u'يَرْتَجِعْهَا', #20
u'يرتجعها': u'يَرْتَجِعَهَا', #33
u'يرتجعهن': u'يَرْتَجِعَهُنَّ', #1
u'يرتدف': u'يَرْتَدِفُ', #15
u'يرتدف': u'يَرْتَدِفْ', #2
u'يرتدف': u'يُرْتَدَفُ', #4
u'يرتدفان': u'يَرْتَدِفَانِ', #1
u'يرتشح': u'يَرْتَشِحُ', #1
u'يرتصون': u'يَرْتَصُّونَ', #1
u'يرتضع': u'يَرْتَضِعُ', #1
u'يرتضع': u'يَرْتَضِعْ', #1
u'يرتضع': u'يَرْتَضِعَ', #9
u'يرتضعها': u'يَرْتَضِعَهَا', #1
u'يرتضيان': u'يَرْتَضِيَانِ', #1
u'يرتعيه': u'يَرْتَعِيهِ', #1
u'يرتفض': u'يُرْتَفَضُ', #31
u'يرتفض': u'يَرْتَفِضُ', #37
u'يرتفض': u'يَرْتَفِضَ', #5
u'يرتفض': u'يَرْتَفِضْ', #5
u'يرتفض': u'يُرْتَفَضْ', #7
u'يرتفضان': u'يَرْتَفِضَانِ', #5
u'يرتفضان': u'يُرْتَفَضَانِ', #5
u'يرتفق': u'يَرْتَفِق', #1
u'يرتفق': u'يُرْتَفَقَ', #1
u'يرتفق': u'يَرْتَفِقْ', #10
u'يرتفق': u'يُرْتَفَقُ', #12
u'يرتفق': u'يَرْتَفِقَ', #21
u'يرتفق': u'يَرْتَفِقُ', #90
u'يرتفقان': u'يَرْتَفِقَانِ', #3
u'يرتفقهما': u'يَرْتَفِقُهُمَا', #1
u'يرتفقون': u'يَرْتَفِقُونَ', #5
u'يرتقع': u'يَرْتَقِع', #1
u'يرتقع': u'يَرْتَقِعُ', #2
u'يرتميان': u'يَرْتَمِيَانِ', #2
u'يرتهناه': u'يَرْتَهِنَاهُ', #1
u'يرتهنه': u'يَرْتَهِنُهُ', #4
u'يرتهنه': u'يَرْتَهِنَهُ', #6
u'يرتهنها': u'يَرْتَهِنَهَا', #2
u'يرتهنها': u'يَرْتَهِنُهَا', #4
u'يرتئى': u'يَرْتَئِىَ', #1
u'يرثنى': u'يَرِثُنِى', #8
u'يرجعقوله': u'يَرْجِعَقَوْلُهُ', #1
u'يردعليك': u'يَرُدُّعَلَيْكَ', #1
u'يردفنى': u'يُرْدِفُنِى', #1
u'يردنى': u'يَرُدَّنِى', #2
u'يردؤ': u'يَرْدُؤُ', #2
u'يرزقكه': u'يَرْزُقُكَهُ', #2
u'يرزقكها': u'يَرْزُقَكِهَا', #2
u'يرزقكيها': u'يَرْزُقَكِيهَا', #1
u'يرزؤه': u'يرزؤه', #1
u'يرزؤه': u'يَرْزَؤُهُ', #2
u'يرزئوا': u'يَرْزِئُوا', #1
u'يرست': u'يرست', #1
u'يرسلنى': u'يُرْسِلْنِى', #1
u'يرضعنى': u'يُرْضِعْنِى', #3
u'يرضيان': u'يَرْضَيَانِ', #15
u'يرضيكا': u'يُرْضِيكَا', #1
u'يرعنى': u'يَرُعْنِى', #5
u'يرعيان': u'يَرْعَيَانِ', #6
u'يرفي': u'يُرْفِي', #1
u'يرفيه': u'يُرْفِيهِ', #1
u'يرفيها': u'يُرْفِيهَا', #1
u'يرقأ': u'يرقأ', #1
u'يرقأ': u'يَرْقَأ', #2
u'يرقأ': u'يُرْقَأْ', #2
u'يرقإ': u'يَرْقَإِ', #2
u'يرقأ': u'يَرْقَأِ', #3
u'يرقأ': u'يَرْقَأْ', #5
u'يرقأ': u'يَرْقَأُ', #57
u'يرقأ': u'يُرْقَأُ', #9
u'يرقآن': u'يَرْقَآنِ', #1
u'يرقل': u'يُرْقَلُ', #1
u'يرقل': u'يُرْقِلُ', #1
u'يرقينى': u'يَرْقِينِى', #1
u'يرمثا': u'يَرْمِثَا', #1
u'يرمقنى': u'يَرْمُقُنِى', #2
u'يرميان': u'يَرْمِيَانِ', #13
u'يرنأ': u'يَرْنَأَ', #1
u'يروث': u'يَرُوثُ', #1
u'يرونى': u'يَرَوْنِى', #2
u'يروئ': u'يُرَوِّئُ', #2
u'يرويان': u'يُرْوَيَانِ', #1
u'يرويان': u'يَرْوِيَانِ', #6
u'يريان،': u'يَرَيَانِ،', #1
u'يريان': u'يَرَيَانِ', #80
u'يريان': u'يُرَيَانِ', #9
u'يريبنى': u'يَرِيبَنِى', #1
u'يريبنى': u'يُرِيبُنِى', #1
u'يريبنى': u'يَرِيبُنِى', #4
u'يريدإلى': u'يُرِيدُإِلَى', #1
u'يريدونالوجه': u'يُرِيدُونَالْوَجْهُ', #1
u'يريغ': u'يُرِيغُ', #1
u'يريكموها': u'يُرِيكُمُوهَا', #3
u'يريكموهم': u'يُرِيكُمُوهُمْ', #7
u'يريكموهما': u'يُرِيكُمُوهُمَا', #1
u'يريكهم': u'يُرِيكَهُمْ', #1
u'يريكهم': u'يُرِيكَهُمُ', #9
u'يريمه': u'يَرِيمُهُ', #1
u'يرينى': u'يُرِيَنِىَ', #1
u'يزاني': u'يُزَانِي', #1
u'يزانيها': u'يُزَانِيهَا', #1
u'يزحمونى': u'يَزْحَمُونِى', #2
u'يزدجرد': u'يزدجرد', #1
u'يزدجرد': u'يزْدَجِرد', #1
u'يزدجرد': u'يزْدجِرْد', #1
u'يزدجرد': u'يَزْدَجرْدَ', #1
u'يزدجرد': u'يزْدَجِرْد', #1
u'يزدجرد': u'يَزْدَجِرْدُ', #1
u'يزدجرد': u'يَزْدَجْرِدُ', #1
u'يزدجرد': u'يَزْدَجْرِدْ', #10
u'يزدجرد': u'يزّدَجِرْد', #2
u'يزدجرد': u'يَزْدَجِرْد', #3
u'يزدجرد': u'يَزْدَجِرْدَ', #3
u'يزدجرد': u'يَزْدَجْرِدَ', #4
u'يزدرع': u'يُزْدَرَعُ', #2
u'يزدرعها': u'يَزْدَرِعُهَا', #1
u'يزدلف': u'يَزْدَلِفُ', #1
u'يزدلفن': u'يَزْدَلِفْنَ', #11
u'يزدلفون': u'يَزْدَلِفُونَ', #1
u'يزدنى': u'يَزِدْنِى', #1
u'يزدهيني': u'يَزْدَهِينِي', #2
u'يزدويه': u'يَزْدَوَيْهِ', #2
u'يزريان': u'يَزْرِيَانِ', #1
u'يزعمونSغزوة': u'يَزْعُمُونَSغَزْوَةُ', #1
u'يزغد': u'يَزْغُدُ', #1
u'يزغل': u'يُزْغِلُ', #2
u'يزغلون': u'يَزْغَلُونَ', #1
u'يزفنون': u'يَزْفِنُونَ', #10
u'يزكيان': u'يُزَكِّيَانِ', #16
u'يزكيان': u'يُزَكَّيَانِ', #21
u'يزكيوالوجه': u'يُزَكِّيوَالْوَجْهُ', #1
u'يزنأ': u'يَزْنَأُ', #2
u'يزنيان': u'يَزْنِيَانِ', #13
u'يزنية': u'يَزَنِيّةً', #1
u'يزنية': u'يَزْنِيّةً', #1
u'يزوجنيها': u'يُزَوِّجْنِيهَا', #1
u'يزوجنيها': u'يُزَوِّجَنِيهَا', #2
u'يزوجنيها': u'يُزَوِّجُنِيهَا', #6
u'يزوح': u'يَزُوحُ', #1
u'يزيدقال': u'يَزِيدَقَالَ', #1
u'يزيدنى': u'يَزِيدُنِى', #1
u'يزيذفتم': u'يزيذفتم', #1
u'يزيلونى': u'يُزِيلُونِى', #1
u'يساب': u'يُسَابَّ', #1
u'يساب': u'يُسَابُّ', #3
u'يسابب': u'يُسَابِبِ', #2
u'يساحق': u'يُسَاحِقَ', #1
u'يساحق': u'يُسَاحِقُ', #2
u'يسارغير': u'يَسَارٍغَيْرَ', #1
u'يسارهقوله': u'يَسَارِهِقَوْلُهُ', #1
u'يساف': u'يساف', #1
u'يساف': u'يسَاف', #1
u'يساف': u'يَسَّافٍ', #1
u'يساف': u'يِسَافِ', #1
u'يساف،': u'يِسَافٍ،', #11
u'يساف': u'يَسَاف', #2
u'يساف': u'يَسَافٌ', #2
u'يساف،': u'يَسَافَ،', #2
u'يساف،': u'يَسَافٍ،', #25
u'يساف،': u'يساف،', #3
u'يساف': u'يِسَافٍ', #43
u'يساف': u'يَسَافَ', #5
u'يساف': u'يَسَافٍ', #76
u'يسافد': u'يُسَافِدُ', #1
u'يسافده': u'يُسَافِدُهُ', #3
u'يساف،في': u'يَسَافٍ،فِي', #1
u'يسالفه': u'يُسَالِفَهُ', #3
u'يسألكموها': u'يَسْأَلْكُمُوهَا', #1
u'يسألننى': u'يَسْأَلْنَنِى', #2
u'يسألنى': u'يَسْأَلُنِى', #15
u'يسألنى': u'يَسْأَلَنِى', #3
u'يسألهعن': u'يَسْأَلُهُعَنْ', #1
u'يسالهم': u'يَسَالُهُمْ', #1
u'يسالونه': u'يَسَالُونَهُ', #1
u'يسالونها': u'يسالْوَنها', #1
u'يسألونى': u'يَسْأَلُونِى', #6
u'يسامت': u'يُسَامَتْ', #1
u'يسامت': u'يُسَامِتُ', #13
u'يسامت': u'يُسَامِتَ', #6
u'يسامت': u'يُسَامِتْ', #9
u'يسامته': u'يُسَامِتُهُ', #2
u'يسامته': u'يُسَامِتْهُ', #3
u'يسامتها': u'يُسَامِتَهَا', #1
u'يسامتها': u'يُسَامِتُهَا', #3
u'يساوق': u'يُسَاوِقُ', #1
u'يساوقه': u'يُسَاوِقُهُ', #1
u'يساويان': u'يُسَاوِيَانِ', #10
u'يساويان': u'يُسَاوَيَانِ', #11
u'يسائلنى': u'يُسَائِلُنِى', #1
u'يسبقنى': u'يَسْبِقُنِى', #2
u'يسبقنى': u'يَسْبِقْنِى', #2
u'يسبقونى': u'يَسْبِقُونِى', #2
u'يسبيان': u'يُسْبَيَانِ', #1
u'يست': u'يست', #2
u'يستأتي': u'يَسْتَأْتِي', #1
u'يستأتى': u'يُسْتَأْتَى', #3
u'يستأدي': u'يَسْتَأْدِي', #1
u'يستأذني': u'يَسْتَأْذِنّي', #1
u'يستاس': u'يَسْتَاسُ', #1
u'يستاسب': u'يستاسب', #7
u'يستأسر': u'يُسْتَأْسَرَ', #1
u'يستأسر،': u'يَسْتَأْسِرَ،', #1
u'يستأسر،': u'يُسْتَأْسَرَ،', #2
u'يستأسر': u'يَسْتَأْسِرَ', #6
u'يستأسروا': u'يُسْتَأْسَرُوا', #1
u'يستأسروا': u'يَسْتَأْسِرُوا', #3
u'يستأسرون': u'يَسْتَأْسِرُونَ', #1
u'يستاك': u'يَسْتَاكُ', #122
u'يستاك': u'يُسْتَاكُ', #17
u'يستاك': u'يستاك', #2
u'يستاك': u'يَسْتَاك', #2
u'يستاك،': u'يَسْتَاكُ،', #4
u'يستاك': u'يَسْتَاكَ', #47
u'يستأكل': u'يَسْتَأْكِلَ', #1
u'يستأكل': u'يَسْتَأْكِلُ', #1
u'يستأكلوا': u'يَسْتَأْكِلُوا', #1
u'يستأكلون': u'يَسْتَأْكِلُونَ', #1
u'يستاكوا': u'يَسْتَاكُوا', #1
u'يستاكون': u'يَسْتَاكُونَ', #4
u'يستألفهم': u'يستألفهم', #2
u'يستألفهم': u'يَسْتَأْلِفُهُمْ', #3
u'يستام': u'يُسْتَامُ', #1
u'يستام': u'يَسْتَامُ', #15
u'يستام': u'يَسْتَامَ', #16
u'يستام': u'يَسْتَامْ', #3
u'يستأمن': u'يَسْتَأْمِنَّ', #1
u'يستأمن': u'يَسْتَأْمِنْ', #11
u'يستأمن': u'يَسْتَأْمِنَ', #2
u'يستأمن': u'يُسْتَأْمَنُ', #3
u'يستأمن': u'يُسْتَأْمَنْ', #3
u'يستأمن': u'يَسْتَأْمِنُ', #7
u'يستأمنا': u'يُسْتَأْمَنَا', #1
u'يستأمنا': u'يَسْتَأْمِنَا', #2
u'يستأمنان': u'يَسْتَأْمِنَانِ', #1
u'يستأمنه': u'يَسْتَأْمِنْهُ', #3
u'يستأمنه': u'يَسْتَأْمِنَهُ', #4
u'يستأمنه': u'يَسْتَأْمِنُهُ', #5
u'يستأمنوا': u'يَسْتَأْمِنُوا', #3
u'يستأمنوه': u'يَسْتَأْمِنُوهُ', #4
u'يستأنوا': u'يَسْتَأْنُوا', #2
u'يستأنى': u'يُسْتَأْنَى', #108
u'يستأني': u'يَسْتَأْنِيَ', #2
u'يستأنى': u'يَسْتَأْنِىَ', #3
u'يستأني': u'يَسْتَأْنِي', #44
u'يستبحر': u'يَسْتَبْحِرْ', #11
u'يستبحر': u'يَسْتَبْحِرَ', #2
u'يستبحر': u'يُسْتَبْحَرْ', #7
u'يستبديه': u'يَسْتَبْدِيهِ', #1
u'يستبذله': u'يَسْتَبْذِلَهُ', #1
u'يستبذله': u'يَسْتَبْذِلُهُ', #2
u'يستبري': u'يَسْتَبْرِي', #1
u'يستبرين': u'يَسْتَبْرِينَ', #3
u'يستبضع': u'يُسْتَبْضَعُ', #1
u'يستبضع': u'يَسْتَبْضِعُ', #2
u'يستبل': u'يَسْتَبِلَّ', #1
u'يستبلون': u'يَسْتَبِلّونَ', #1
u'يستبون': u'يستبون', #1
u'يستبيع': u'يَسْتَبِيعَ', #2
u'يستتاب': u'يُسْتَتَابُ', #185
u'يستتاب': u'يُسْتَتَابَ', #20
u'يستتابا': u'يُسْتَتَابَا', #3
u'يستتابوا': u'يُسْتَتَابُوا', #4
u'يستتابون': u'يُسْتَتَابُونَ', #7
u'يستتبهم': u'يَسْتَتِبْهُمْ', #3
u'يستتجر': u'يَسْتَتْجِرُ', #1
u'يستتجر': u'يَسْتَتْجِرَ', #4
u'يستتجره': u'يَسْتَتْجِرُهُ', #1
u'يستتربه': u'يَسْتَتِرُبِهِ', #1
u'يستتم': u'يَسْتَتِمّ', #1
u'يستتم': u'يَسْتَتِمَّ', #47
u'يستتم': u'يَسْتَتِمُّ', #6
u'يستتمه': u'يَسْتَتِمّهُ', #1
u'يستتمه': u'يَسْتَتِمَّهُ', #2
u'يستتمها،': u'يَسْتَتِمَّهَا،', #1
u'يستتمها': u'يَسْتَتِمَّهَا', #7
u'يستتيبه': u'يَسْتَتِيبُهُ', #1
u'يستتيبه،': u'يَسْتَتِيبَهُ،', #1
u'يستتيبه': u'يَسْتَتِيبَهُ', #3
u'يستتيبهم': u'يَسْتَتِيبَهُمْ', #1
u'يستثبت': u'يَسْتَثْبِتَ', #1
u'يستثبت': u'يَسْتَثْبِتُ', #1
u'يستثبت': u'يَسْتَثْبِتْ', #1
u'يستثبته': u'يَسْتَثْبِتَهُ', #1
u'يستثفر': u'يَسْتَثْفِرَ', #1
u'يستثنيان': u'يُسْتَثْنَيَانِ', #5
u'يستجاد': u'يُسْتَجَادُ', #1
u'يستجاز': u'يُسْتَجَازُ', #2
u'يستجبرون': u'يَسْتَجْبِرُونَ', #1
u'يستجرئ': u'يَسْتَجْرِئُ', #2
u'يستجرئنكم': u'يَسْتَجْرِئَنَّكُمُ', #2
u'يستجرينكم': u'يستجرينكم', #1
u'يستجرينكم': u'يسْتَجْرِيَنّكُمْ', #2
u'يستجز': u'يَسْتَجِزْ', #4
u'يستجمر': u'يَسْتَجْمِرُ', #31
u'يستجمر': u'يَسْتَجْمِرْ', #4
u'يستجمر': u'يَسْتَجْمِرَ', #7
u'يستجمر': u'يُسْتَجْمَرُ', #8
u'يستجمروا': u'يَسْتَجْمِرُوا', #2
u'يستجمرون': u'يَسْتَجْمِرُونَ', #1
u'يستجن': u'يَسْتَجِنُّ', #1
u'يستجني': u'يَسْتَجْنِي', #1
u'يستجنى': u'يُسْتَجْنَى', #2
u'يستجنيه': u'يَسْتَجْنِيهِ', #1
u'يستجهل': u'يُسْتَجْهَلَ', #2
u'يستجوينكم': u'يَسْتجْوِيَنّكم', #1
u'يستجيروننى': u'يَسْتَجِيرُونَنِى', #1
u'يستجيز': u'يَسْتَجِيزُ', #25
u'يستجيزه': u'يَسْتَجِيزُهُ', #2
u'يستجيزون': u'يَسْتَجِيزُونَ', #5
u'يستجيش': u'يَسْتَجِيشُ', #1
u'يستجيشهم': u'يَسْتَجِيشُهُمْ', #1
u'يستح': u'يَسْتَحِ', #4
u'يستحجر': u'يستحجر', #9
u'يستحد': u'يُسْتَحَدُّ', #1
u'يستحد': u'يَسْتَحِدَّ', #5
u'يستحد': u'يَسْتَحِدُّ', #5
u'يستحر': u'يَسْتَحِرَّ', #5
u'يستحصده': u'يَسْتَحْصِدَهُ', #2
u'يستحلب': u'يُسْتَحْلَب', #1
u'يستحلقه': u'يَسْتَحْلِقُهُ', #1
u'يستحمد': u'يَسْتَحْمِدُ', #1
u'يستحى': u'يَسْتَحِى', #1
u'يستحى': u'يُسْتَحَى', #34
u'يستحين': u'يَسْتَحْيِنَ', #1
u'يستحين': u'يَسْتَحْيِنِ', #1
u'يستحين': u'يَسْتَحِينَ', #2
u'يستحيى': u'يَسْتَحْيِى', #16
u'يستحيى': u'يُسْتَحْيَى', #8
u'يستحييان': u'يَسْتَحْيِيَانِ', #1
u'يستخار': u'يُسْتَخَارُ', #2
u'يستخبث': u'يَسْتَخْبِثُ', #1
u'يستخبث': u'يُسْتَخْبَثُ', #3
u'يستخبثه': u'يَسْتَخْبِثُهُ', #6
u'يستخر': u'يَسْتَخِرْ', #1
u'يستخص': u'يَسْتَخِصَّ', #1
u'يستخليني': u'يَسْتَخْلِينِي', #1
u'يستخم': u'يَسْتَخِمَّ', #1
u'يستخموا': u'يَسْتَخِمُوا', #1
u'يستخير': u'يَسْتَخِيرُ', #28
u'يستخير': u'يَسْتَخِيرَ', #4
u'يستخيط': u'يَسْتَخِيطُ', #2
u'يستد': u'يَسْتَدُّ', #1
u'يستدبرهابفرجه': u'يَسْتَدْبِرُهَابِفَرْجِهِ', #1
u'يستدخل': u'يُسْتَدْخَلْ', #1
u'يستدخل': u'يَسْتَدْخِلُ', #2
u'يستدخلوا': u'يَسْتَدْخِلُوا', #2
u'يستدق': u'يَسْتَدِقَّ', #1
u'يستدق': u'يَسْتَدِقُّ', #1
u'يستدق': u'يُسْتَدَقُّ', #1
u'يستدق': u'يُسْتَدَقَّ', #2
u'يستدلونها': u'يَسْتَدِلُّونَهَا', #1
u'يستذبح': u'يُسْتَذْبَحُ', #1
u'يستذل': u'يَسْتَذِلُّ', #1
u'يستذل': u'يُسْتَذَلَّ', #1
u'يستذل': u'يُسْتَذَلُّ', #3
u'يستذله': u'يَسْتَذِلَّهُ', #1
u'يستذله': u'يَسْتَذِلُّهُ', #1
u'يستذلوا': u'يَسْتَذِلُّوا', #1
u'يستذلوا،': u'يُسْتَذَلُّوا،', #1
u'يستذلون': u'يُسْتَذَلّونَ', #1
u'يستراب': u'يُسْتَرَابَ', #1
u'يستراب': u'يُسْتَرَابُ', #7
u'يسترب': u'يُسْتَرَبْ', #1
u'يسترب': u'يَسْتَرِبْ', #4
u'يستربح': u'يُسْتَرْبَحُ', #1
u'يستربح': u'يَسْتَرْبِحْ', #2
u'يستربح': u'يَسْتَرْبِحَ', #5
u'يستربحا': u'يَسْتَرْبِحَا', #1
u'يستربحان': u'يَسْتَرْبِحَانِ', #1
u'يسترذل': u'يُسْتَرْذَلُ', #2
u'يسترذله': u'يَسْتَرْذِلْهُ', #2
u'يسترذلونها': u'يَسْتَرْذِلُونَهَا', #1
u'يسترفدكم،': u'يَسْتَرْفِدُكُمْ،', #1
u'يسترفع': u'يُسْتَرْفَعُ', #1
u'يسترفقه': u'يَسْتَرْفِقُهُ', #1
u'يسترققن': u'يُسْتَرْقَقْنَ', #2
u'يسترقي': u'يَسْتَرْقِي', #1
u'يسترقى': u'يُسْتَرْقَى', #1
u'يسترقيه': u'يَسْتَرْقِيَهُ', #1
u'يسترم': u'يَسْتَرِمُّ', #3
u'يسترنى': u'يسترنى', #2
u'يسترنى': u'يَسْتُرُنِى', #5
u'يسترهنك': u'يَسْتَرْهِنَكَ', #1
u'يسترهنونه': u'يَسْتَرْهِنُونَهُ', #1
u'يسترى': u'يُسْتَرَى', #1
u'يستريب': u'يَسْتَرِيب', #1
u'يستريب': u'يَسْتَرِيبُ', #14
u'يستريب': u'يَسْتَرِيبَ', #4
u'يستريبون': u'يَسْتَرِيبُونَ', #1
u'يستزرى': u'يُسْتَزْرَى', #2
u'يستزكى': u'يُسْتَزْكَى', #1
u'يستزلونى': u'يَسْتَزِلُّونِى', #1
u'يستسب': u'يَسْتَسِبَّ', #1
u'يستسبوا': u'يَسْتَسِبُّوا', #1
u'يستسحر': u'يَسْتَسْحِرُ', #1
u'يستسر': u'يَسْتَسِرُّ', #1
u'يستسرج': u'يَسْتَسْرِجُ', #1
u'يستسرجه': u'يَسْتَسْرِجَهُ', #1
u'يستسرون': u'يَسْتَسِرُّونَ', #1
u'يستسعاها': u'يَسْتَسْعَاهَا', #1
u'يستسعط': u'يَسْتَسْعِطَ', #3
u'يستسعه': u'يَسْتَسْعِهِ', #1
u'يستسعوا': u'يَسْتَسْعَوْا', #1
u'يستسعوا': u'يُسْتَسْعَوْا', #1
u'يستسعوا': u'يَسْتَسْعُوا', #2
u'يستسعون': u'يَسْتَسْعُونَ', #1
u'يستسعونه': u'يَسْتَسْعُونَهُ', #1
u'يستسعونه': u'يَسْتَسْعَوْنَهُ', #4
u'يستسعونها': u'يَسْتَسْعُونَهَا', #2
u'يستسعوه': u'يَسْتَسْعُوهُ', #2
u'يستسعي': u'يَسْتَسْعِي', #19
u'يستسعى': u'يَسْتَسْعَى', #2
u'يستسعى': u'يُسْتَسْعَى', #60
u'يستسعي': u'يَسْتَسْعِيَ', #76
u'يستسعيان': u'يُسْتَسْعَيَانِ', #2
u'يستسعيانه': u'يَسْتَسْعِيَانِهِ', #4
u'يستسعين': u'يَسْتَسْعِينَ', #1
u'يستسعين': u'يُسْتَسْعَيْنَ', #3
u'يستسعيه': u'يَسْتَسْعِيه', #1
u'يستسعيه': u'يَسْتَسْعِيَهُ', #23
u'يستسعيه': u'يَسْتَسْعِيهِ', #5
u'يستسعيها': u'يَسْتَسْعِيَهَا', #12
u'يستسعيها': u'يَسْتَسْعِيهَا', #8
u'يستسعيهم': u'يَسْتَسْعِيَهُمْ', #3
u'يستسقطان': u'يَسْتَسْقِطَانِ', #1
u'يستسقطه': u'يَسْتَسْقِطَهُ', #1
u'يستسقينى': u'يَسْتَسْقِينِى', #1
u'يستسلف': u'يَسْتَسْلِفُ', #3
u'يستسلف': u'يَسْتَسْلِفَ', #5
u'يستسلفه': u'يَسْتَسْلِفُهُ', #1
u'يستسلفوا': u'يَسْتَسْلِفُوا', #1
u'يستسيل': u'يَسْتَسِيلُ', #1
u'يستشب': u'يستشب', #1
u'يستشركوهم': u'يَسْتَشْرِكُوهُمْ', #1
u'يستشفيك': u'يَسْتَشْفِيكَ', #1
u'يستشق': u'يَسْتَشِقُّ', #1
u'يستشقه': u'يَسْتَشِقُّهُ', #12
u'يستشكله': u'يَسْتَشْكِلَهُ', #1
u'يستشكله': u'يَسْتَشْكِلُهُ', #2
u'يستشن': u'يُسْتَشَنُّ', #1
u'يستشنع': u'يَسْتَشْنِعُ', #1
u'يستشنع': u'يُسْتَشْنَعُ', #2
u'يستشنعه': u'يَسْتَشْنِعُهُ', #2
u'يستشنعون': u'يَسْتَشْنِعُونَ', #1
u'يستصبح': u'يستصبح', #1
u'يستصبح': u'يُسْتَصْبَحُ', #13
u'يستصبح': u'يَسْتَصْبِحُ', #4
u'يستصبح': u'يَسْتَصْبِحَ', #5
u'يستصبح': u'يُسْتَصْبَحَ', #6
u'يستصبحوا': u'يَسْتَصْبِحُوا', #2
u'يستصنع': u'يُسْتَصْنَعُ', #1
u'يستصنع': u'يَسْتَصْنِعَ', #2
u'يستصنع': u'يَسْتَصْنِعُ', #2
u'يستصنعه': u'يَسْتَصْنِعْهُ', #2
u'يستضام': u'يُسْتَضَامَ', #1
u'يستضر': u'يُسْتَضَرُّ', #3
u'يستضر': u'يَسْتَضِرُّ', #55
u'يستضر': u'يَسْتَضِرَّ', #8
u'يستضربه': u'يَسْتَضْرِبُهُ', #1
u'يستضروا': u'يَسْتَضِرُّوا', #1
u'يستطحنون': u'يَسْتَطْحِنُونَ', #1
u'يستطحنوهم': u'يَسْتَطْحِنُوهُمْ', #1
u'يستطرق': u'يَسْتَطْرِقُ', #11
u'يستطرق': u'يَسْتَطْرِقْ', #2
u'يستطرق': u'يَسْتَطْرِقَ', #7
u'يستطرقه': u'يَسْتَطْرِقُهُ', #2
u'يستطرقه': u'يَسْتَطْرِقَهُ', #3
u'يستطعون': u'يَسْتَطِعُونَ', #1
u'يستطيعهإلا': u'يَسْتَطِيعُهُإِلَّا', #1
u'يستعدل': u'يُسْتَعْدَلُ', #2
u'يستعذر': u'يَسْتَعْذِرُ', #1
u'يستعفي': u'يَسْتَعْفِي', #1
u'يستعفي': u'يَسْتَعْفِيَ', #1
u'يستعفى': u'يُسْتَعْفَى', #1
u'يستعفيه': u'يَسْتَعْفِيَهُ', #1
u'يستعقب': u'يَسْتَعْقِبُ', #53
u'يستعقب': u'يَسْتَعْقِبَ', #6
u'يستعقب': u'يَسْتَعْقِبْ', #7
u'يستعقبان': u'يَسْتَعْقِبَانِ', #1
u'يستعقبه': u'يَسْتَعْقِبُهُ', #6
u'يستعقبها': u'يَسْتَعْقِبَهَا', #2
u'يستعقبها': u'يَسْتَعْقِبُهَا', #2
u'يستعلن': u'يَسْتَعْلِنَ', #1
u'يستعلن': u'يَسْتَعْلِنْ', #1
u'يستعلن': u'يَسْتَعْلِنُ', #3
u'يستعوي': u'يَسْتَعْوِي', #1
u'يستغششك': u'يَسْتَغْشِشْك', #1
u'يستغفرنى': u'يَسْتَغْفِرُنِى', #3
u'يستغنم': u'يَسْتَغْنِمُ', #1
u'يستغنم': u'يُسْتَغْنَمُ', #2
u'يستغنيان': u'يَسْتَغْنِيَانِ', #8
u'يستغورهم': u'يَسْتَغْوِرَهُمْ', #1
u'يستفادان': u'يُسْتَفَادَانِ', #5
u'يستفتيان': u'يُسْتَفْتَيَانِ', #1
u'يستفحشه': u'يَسْتَفْحِشُهُ', #10
u'يستفحشونها': u'يَسْتَفْحِشُونَهَا', #1
u'يستفده': u'يَسْتَفِدْهُ', #10
u'يستفرش': u'يَسْتَفْرِشَ', #2
u'يستفرشها': u'يَسْتَفْرِشُهَا', #1
u'يستفرشها': u'يَسْتَفْرِشَهَا', #2
u'يستفرقه': u'يَسْتَفْرِقُهُ', #1
u'يستفصل': u'يُسْتَفْصَلَ', #1
u'يستفصل': u'يَسْتَفْصِلْ', #32
u'يستفصل': u'يَسْتَفْصِلَ', #4
u'يستفصل': u'يُسْتَفْصَلُ', #4
u'يستفصل': u'يَسْتَفْصِلُ', #6
u'يستفصله': u'يَسْتَفْصِلَهُ', #2
u'يستفصله': u'يَسْتَفْصِلْهُ', #8
u'يستفصلها': u'يَسْتَفْصِلْهَا', #3
u'يستفصلوا': u'يَسْتَفْصِلُوا', #5
u'يستفضل': u'يُسْتَفْضَلَ', #1
u'يستفضل': u'يَسْتَفْضِلْ', #2
u'يستفضل': u'يَسْتَفْضِلَ', #9
u'يستفضلوا': u'يَسْتَفْضِلُوا', #1
u'يستفعل': u'يَسْتَفْعِلُ', #1
u'يستفكه': u'يَسْتَفِكَّهُ', #1
u'يستفل': u'يَسْتَفِلْ', #1
u'يستفيده': u'يَسْتَفِيدهُ', #2
u'يستفيده': u'يَسْتَفِيدَهُ', #5
u'يستفيده': u'يَسْتَفِيدُهُ', #75
u'يستفيدها': u'يَسْتَفِيدُهَا', #11
u'يستفيدونه': u'يَسْتَفِيدُونَهُ', #1
u'يستفيدوه': u'يَسْتَفِيدُوهُ', #1
u'يستفيه': u'يَسْتَفِيهِ', #1
u'يستقاد': u'يُسْتَقَادُ', #15
u'يستقاد': u'يُسْتَقَادَ', #8
u'يستقتل': u'يَسْتَقْتِلَ', #2
u'يستقد': u'يُسْتَقَدْ', #1
u'يستقذر': u'يَسْتَقْذِرُ', #1
u'يستقذر': u'يُسْتَقْذَر', #1
u'يستقذر': u'يُسْتَقْذَرْ', #3
u'يستقذر': u'يُسْتَقْذَرُ', #36
u'يستقذره': u'يَسْتَقْذِرُهُ', #19
u'يستقذره': u'يَسْتَقْذِرهُ', #2
u'يستقذره': u'يَسْتَقْذِرْهُ', #2
u'يستقذرونه': u'يَسْتَقْذِرُونَهُ', #1
u'يستقرب': u'يَسْتَقْرِبَ', #1
u'يستقرب': u'يَسْتَقْرِبُ', #1
u'يستقربنا': u'يَسْتَقْرِبُنَا', #1
u'يستقربهم': u'يَسْتَقْرِبُهُمُ', #1
u'يستقربون': u'يَسْتَقْرِبُونَ', #2
u'يستقرض': u'يُسْتَقْرَضَ', #1
u'يستقرض': u'يُسْتَقْرَضْ', #1
u'يستقرض': u'يُسْتَقْرَضُ', #11
u'يستقرض': u'يَسْتَقْرِضْ', #3
u'يستقرض': u'يَسْتَقْرِضُ', #70
u'يستقرض': u'يَسْتَقْرِضَ', #92
u'يستقرضك': u'يَسْتَقْرِضُك', #3
u'يستقرضه': u'يَسْتَقْرِضَهُ', #3
u'يستقرضه': u'يَسْتَقْرِضُهُ', #9
u'يستقرضها': u'يَسْتَقْرِضُهَا', #4
u'يستقرضون': u'يَسْتَقْرِضُونَ', #4
u'يستقرضونه': u'يَسْتَقْرِضُونَهُ', #1
u'يستقصر': u'يَسْتَقْصِرُ', #1
u'يستقصر': u'يُسْتَقْصَرُ', #2
u'يستقصرها': u'يَسْتَقْصِرُهَا', #1
u'يستقض': u'يَسْتَقْضِ', #2
u'يستقضون': u'يَسْتَقْضُونَ', #1
u'يستقضي': u'يَسْتَقْضِيَ', #18
u'يستقضي': u'يَسْتَقْضِي', #6
u'يستقضى': u'يُسْتَقْضَى', #9
u'يستقضيهم': u'يَسْتَقْضِيَهُمْ', #1
u'يستقطر': u'يُسْتَقْطَرُ', #3
u'يستقنى': u'يُسْتَقْنَى', #1
u'يستقئ': u'يستقئ', #1
u'يستقئ': u'يَسْتَقِئَ', #1
u'يستقئ': u'يَسْتَقِئْ', #1
u'يستقيان': u'يَسْتَقِيَانِ', #5
u'يستقيد،': u'يَسْتَقِيدَ،', #1
u'يستقيد،': u'يَسْتَقِيدُ،', #1
u'يستقيد': u'يَسْتَقِيدَ', #12
u'يستقيد': u'يَسْتَقِيدُ', #7
u'يستقيظ': u'يستقيظ', #1
u'يستكتمني': u'يَسْتَكْتِمُنِي', #2
u'يستكتمه': u'يَسْتَكْتِمْهُ', #3
u'يستكر': u'يَسْتَكْرِ', #3
u'يستكرون': u'يَسْتَكْرُونَ', #2
u'يستكرى': u'يُسْتَكْرَى', #1
u'يستكري': u'يَسْتَكْرِي', #6
u'يستكري': u'يَسْتَكْرِيَ', #7
u'يستكريها': u'يَسْتَكْرِيَهَا', #6
u'يستكسب': u'يَسْتَكْسِبُ', #3
u'يستكسبه': u'يَسْتَكْسِبْهُ', #2
u'يستكسبهما': u'يَسْتَكْسِبُهُمَا', #3
u'يستكف': u'يَسْتَكِفُّ', #5
u'يستكفى': u'يُسْتَكْفَى', #1
u'يستكفئ': u'يَسْتَكْفِئَ', #1
u'يستكفيه': u'يَسْتَكْفِيهِ', #1
u'يستكهم': u'يستكهم', #1
u'يستلحق': u'يُسْتَلْحَقُ', #11
u'يستلحق': u'يَسْتَلْحِقَ', #16
u'يستلحق': u'يَسْتَلْحِقُ', #26
u'يستلحق': u'يَسْتَلْحِقْ', #3
u'يستلحق': u'يُسْتَلْحَقَ', #5
u'يستلحقه': u'يَسْتَلْحِقَهُ', #11
u'يستلحقه': u'يَسْتَلْحِقُهُ', #15
u'يستلحقه': u'يَسْتَلْحِقْهُ', #26
u'يستلحقهما': u'يَسْتَلْحِقَهُمَا', #1
u'يستم': u'يَسْتَمِ', #2
u'يستم': u'يَسْتَمْ', #2
u'يستمخر': u'يَسْتَمْخِرُ', #1
u'يستمسكه': u'يَسْتَمْسِكُهُ', #1
u'يستمشي': u'يَسْتَمْشِي', #2
u'يستمطر': u'يَسْتَمْطِرُ', #5
u'يستمكن': u'يَسْتَمْكِن', #1
u'يستمكن': u'يَسْتَمْكِنُ', #3
u'يستمكن': u'يَسْتَمْكِنَ', #7
u'يستمنح': u'يَسْتَمْنِحُ', #1
u'يستمنحه': u'يَسْتَمْنِحهُ', #1
u'يستمنحه': u'يَسْتَمْنِحُهُ', #2
u'يستمني': u'يَسْتَمْنِي', #3
u'يستمني': u'يَسْتَمْنِيَ', #6
u'يستن': u'يستن', #1
u'يستن،': u'يستن،', #1
u'يستن': u'يَسْتَنُّ', #15
u'يستن': u'يُسْتَنّ', #2
u'يستن': u'يَسْتَنَّ', #22
u'يستن': u'يُسْتَنَّ', #3
u'يستن': u'يَسْتَنّ', #4
u'يستن': u'يُسْتَنُّ', #4
u'يستناب': u'يُسْتَنَابَ', #10
u'يستناب': u'يُسْتَنَابُ', #10
u'يستنابون': u'يُسْتَنَابُونَ', #2
u'يستنب': u'يُسْتَنَبْ', #1
u'يستنب': u'يَسْتَنِبْ', #17
u'يستنبت': u'يَسْتَنْبِتَ', #1
u'يستنبت': u'يُسْتَنْبَتَ', #2
u'يستنبت': u'يُسْتَنْبَتُ', #27
u'يستنبت': u'يَسْتَنْبِتُ', #8
u'يستنبته': u'يَسْتَنْبِتُهُ', #16
u'يستنبته': u'يَسْتَنْبِتَهُ', #7
u'يستنبتونه': u'يَسْتَنْبِتُونَهُ', #4
u'يستنبه': u'يَسْتَنْبِهُ', #1
u'يستنبه': u'يَسْتَنِبْهُ', #2
u'يستنثر': u'يَسْتَنْثِر', #1
u'يستنثر': u'يَسْتَنْثِرَ', #2
u'يستنثر': u'يَسْتَنْثِرُ', #9
u'يستنثره': u'يَسْتَنْثِرَهُ', #1
u'يستنجح': u'يَسْتَنْجِحُ', #1
u'يستنجز': u'يَسْتَنْجِزُ', #1
u'يستنجزون': u'يَسْتَنْجِزُونَ', #1
u'يستنجيبه': u'يَسْتَنْجِيَبِهِ', #1
u'يستنزه': u'يُسْتَنْزَهَ', #1
u'يستنزه': u'يُسْتَنْزَهُ', #1
u'يستنزه': u'يَسْتَنْزِهُ', #17
u'يستنزه': u'يَسْتَنْزِه', #2
u'يستنزهه': u'يَسْتَنْزِهْهُ', #1
u'يستنزهون': u'يَسْتَنْزِهُونَ', #1
u'يستنصت': u'يَسْتَنْصِتَ', #2
u'يستنصت': u'يَسْتَنْصِتُ', #3
u'يستنصحهم': u'يَسْتَنْصِحُهُمْ', #1
u'يستنظر': u'يَسْتَنْظِرُ', #1
u'يستنظف': u'يَسْتَنْظِفَ', #1
u'يستنفع': u'يَسْتَنْفِعَ', #1
u'يستنفع': u'يَسْتَنْفِعُ', #1
u'يستنفع': u'يُسْتَنْفَعَ', #2
u'يستنفق': u'يَسْتَنْفِقَ', #2
u'يستنفق': u'يَسْتَنْفِقُ', #2
u'يستنفق': u'يُسْتَنْفَقُ', #3
u'يستنفقها': u'يَسْتَنْفِقَهَا', #1
u'يستنفقوا': u'يَسْتَنْفِقُوا', #1
u'يستنقع': u'يَسْتَنْقِع', #1
u'يستنقع': u'يَسْتَنْقِعَ', #2
u'يستنقع': u'يُسْتَنْقَعُ', #3
u'يستنقع': u'يَسْتَنْقِعُ', #7
u'يستنكح': u'يَسْتَنْكِحَ', #1
u'يستنكح': u'يُسْتَنْكَحُ', #1
u'يستنكح': u'يُسْتَنْكَحْ', #1
u'يستنكح': u'يَسْتَنْكِحْ', #2
u'يستنكحه': u'يَسْتَنْكِحْهُ', #2
u'يستنكحه': u'يَسْتَنْكِحُهُ', #3
u'يستنكحه': u'يَسْتَنْكِحَهُ', #4
u'يستنكحها': u'يَسْتَنْكِحَهَا', #25
u'يستنكه': u'يُسْتَنْكَهَ', #1
u'يستنكه': u'يُسْتَنْكَهْ', #1
u'يستنكهه': u'يستنكهه', #1
u'يستنكهه': u'يَسْتَنْكِهْهُ', #1
u'يستنمى': u'يُسْتَنْمَى', #5
u'يستنميه': u'يَسْتَنْمِيَهُ', #1
u'يستنن': u'يَسْتَنِنْ', #1
u'يستنوا': u'يَسْتَنُّوا', #1
u'يستنون': u'يَسْتَنُّونَ', #15
u'يستنيب': u'يَسْتَنِيب', #1
u'يستنيب': u'يَسْتَنِيبَ', #155
u'يستنيب': u'يَسْتَنِيبُ', #94
u'يستنيبان': u'يَسْتَنِيبَانِ', #2
u'يستنيبه': u'يَسْتَنِيبُهُ', #14
u'يستنيبه': u'يَسْتَنِيبَهُ', #9
u'يستنيبوا': u'يَسْتَنِيبُوا', #2
u'يستنيبون': u'يَسْتَنِيبُونَ', #1
u'يستهدم': u'يُسْتَهْدَمَ', #1
u'يستهزءون': u'يَسْتَهْزِءُونَ', #7
u'يستهزؤن': u'يَسْتَهْزِؤُنَ', #1
u'يستهزؤون': u'يَسْتَهْزَؤُونَ', #1
u'يستهكله': u'يَسْتَهْكِلُهُ', #1
u'يستهم': u'يستهم', #1
u'يستهما': u'يَسْتَهِمَا', #13
u'يستهمان': u'يَسْتَهِمَانِ', #4
u'يستهموا': u'يَسْتَهِمُوا', #29
u'يستوجس': u'يَسْتَوْجِسُ', #1
u'يستوجه': u'يَسْتَوْجِهْ', #1
u'يستوجها': u'يَسْتَوْجِهَا', #1
u'يستوزر': u'يَسْتَوْزِرَ', #6
u'يستوسق': u'يُسْتَوْسَقُ', #2
u'يستوشي': u'يَسْتَوْشِي', #1
u'يستوشيه': u'يَسْتَوْشِيه', #1
u'يستوشيه': u'يَسْتَوْشِيهِ', #8
u'يستوضع': u'يستوضع', #1
u'يستوضع': u'يَسْتَوْضِعَ', #2
u'يستوضع': u'يَسْتَوْضِعُ', #4
u'يستوطئ': u'يَسْتَوْطِئَ', #1
u'يستوفز': u'يَسْتَوْفِزَ', #1
u'يستوفيان': u'يُسْتَوْفَيَانِ', #1
u'يستوفيان': u'يَسْتَوْفِيَانِ', #14
u'يستوله': u'يَسْتَوْلَهُ', #1
u'يستوني': u'يَسْتَوْنِي', #1
u'يستوهب': u'يُسْتَوْهَبُ', #1
u'يستوهب': u'يَسْتَوْهِبَ', #2
u'يستوهب': u'يَسْتَوْهِبُ', #2
u'يستوهبك': u'يَسْتَوْهِبَكَ', #1
u'يستوهبه': u'يُسْتَوْهَبَهُ', #1
u'يستوهبه': u'يَسْتَوْهِبُهُ', #3
u'يستوهبه': u'يَسْتَوْهِبَهُ', #6
u'يستوهبها': u'يَسْتَوْهِبَهَا', #1
u'يستوهبها': u'يَسْتَوْهِبُهَا', #1
u'يستويان': u'يستويان', #1
u'يستويان': u'يَسْتَوِيَانِ', #191
u'يستويان،': u'يَسْتَوِيَانِ،', #2
u'يستيع': u'يَسْتِيعُ', #1
u'يسجده': u'يَسْجُدُهُ', #18
u'يسجده': u'يَسْجُدْهُ', #2
u'يسجدها': u'يَسْجُدَهَا', #52
u'يسجدها': u'يَسْجُدْهَا', #55
u'يسجدها': u'يَسْجُدُهَا', #88
u'يسجدهما': u'يسجدهما', #1
u'يسجدهما': u'يَسْجُدْهُمَا', #17
u'يسجدهما': u'يَسْجُدَهُمَا', #5
u'يسجدهما': u'يَسْجُدُهُمَا', #8
u'يسجدونها': u'يَسْجُدُونَهَا', #14
u'يسجدوها': u'يَسْجُدُوهَا', #7
u'يسحبنى': u'يَسْحَبُنِى', #1
u'يسحل': u'يسحل', #1
u'يسحل': u'يُسْحِل', #1
u'يسحلها': u'يَسْحَلُهَا', #2
u'يسحلها': u'يُسْحِلُهَا', #3
u'يسخب': u'يسخب', #1
u'يسخب،': u'يَسْخَبْ،', #1
u'يسخب': u'يَسْخَبْ', #2
u'يسخم': u'يُسَخَّمَ', #1
u'يسخم': u'يُسَخَّمُ', #2
u'يسخم': u'يُسَخِّمَ', #4
u'يسخم': u'يُسَخِّمُ', #5
u'يسخمه': u'يُسَخِّمُهُ', #7
u'يسرعم': u'يسرعم', #1
u'يسرنى': u'يَسُرُّنِى', #13
u'يسسكر': u'يُسسْكِرُ', #1
u'يسطنطين': u'يُسْطَنْطِين', #1
u'يسطيع': u'يَسْطِيع', #1
u'يسطيع': u'يَسْطِيعُ', #1
u'يسعط': u'يسعط', #1
u'يسعط': u'يُسْعَط', #1
u'يسعط': u'يُسْعَطَ', #1
u'يسعط': u'يُسْعِطُ', #2
u'يسعط': u'يُسْعَطُ', #7
u'يسعنى': u'يَسَعَنِى', #2
u'يسعنى': u'يَسَعُنِى', #2
u'يسعي': u'يَسْعِي', #1
u'يسعيان': u'يَسْعَيَانِ', #21
u'يسفي': u'يَسْفِي', #2
u'يسقب': u'يَسْقَبُ', #3
u'يسقيان': u'يُسْقَيَانِ', #2
u'يسقيان': u'يَسْقِيَانِ', #5
u'يسقينى': u'يَسْقِينِى', #1
u'يسقينى': u'يَسْقِيَنِى', #1
u'يسكتونى': u'يُسَكِّتُونِى', #2
u'يسلأ': u'يَسْلَأَ', #1
u'يسلبكموه': u'يَسْلِبَكُمُوهُ', #1
u'يسلبكموه': u'يَسْلُبَكُمُوهُ', #2
u'يسلمولا': u'يُسْلِمُوَلَا', #1
u'يسلئوا': u'يَسْلَئُوا', #1
u'يسلئون': u'يَسْلَئُونَ', #1
u'يسلئون': u'يُسْلَئُونَ', #1
u'يسمعناه': u'يُسْمِعنَاهُ', #1
u'يسمعناه': u'يُسْمِعُنَاهُ', #5
u'يسمعنى': u'يُسْمِعُنِى', #1
u'يسمعهموه': u'يُسْمِعُهُمُوهُ', #2
u'يسمنى': u'يُسَمِّنِى', #1
u'يسميان': u'يُسَمّيَانِ', #4
u'يسميان': u'يُسَمَّيَانِ', #42
u'يسميان': u'يُسَمِّيَانِ', #8
u'يسوع': u'يَسُوعُ', #2
u'يسوكه': u'يَسُوكَهُ', #1
u'يسوكه': u'يُسَوِّكُهُ', #1
u'يسوكه': u'يَسُوكُهُ', #5
u'يسوؤك،': u'يسوؤك،', #1
u'يسوؤني': u'يسوؤني', #1
u'يسويان': u'يُسَوَّيَانِ', #1
u'يسويان': u'يُسَوِّيَانِ', #1
u'يسىء': u'يُسِىءُ', #2
u'يسئل': u'يُسْئَلْ', #1
u'يسئل': u'يُسْئِلُ', #2
u'يسئل': u'يُسْئَلُ', #3
u'يسئله': u'يسئله', #1
u'يسئلون': u'يُسْئِلُونَ', #2
u'يسئلونك': u'يَسْئَلُونَكَ', #2
u'يسئلونه،': u'يَسْئَلُونَهُ،', #1
u'يسئمنك': u'يُسْئِمَنَّكَ', #1
u'يسيخ': u'يَسِيخُ', #1
u'يسيئه': u'يُسِيئُهُ', #1
u'يشإ': u'يَشإِ', #1
u'يشا': u'يشا', #1
u'يشا': u'يَشَا', #10
u'يشإ': u'يَشَإِ', #2
u'يشاءقوله': u'يَشَاءُقَولُهُ', #1
u'يشامر': u'يشامر', #2
u'يشأها': u'يَشَأْهَا', #6
u'يشأهما': u'يَشَأْهُمَا', #3
u'يشاؤه': u'يَشَاؤُهُ', #8
u'يشاؤها': u'يَشَاؤُهَا', #1
u'يشبهما': u'يُشِبْهُمَا', #1
u'يشتار': u'يَشْتَارُ', #1
u'يشتدخهم،': u'يَشْتَدِخَهُمْ،', #1
u'يشتركانه': u'يَشْتَرِكَانِهِ', #2
u'يشتريان': u'يَشْتَرِيَانِ', #40
u'يشتريان': u'يُشْتَرَيَانِ', #5
u'يشتزك': u'يَشْتَزُّكَ', #1
u'يشتط': u'يُشْتَطُّ', #1
u'يشتطوا': u'يَشْتَطُّوا', #1
u'يشتكه': u'يَشْتَكِهِ', #4
u'يشتكيك': u'يَشْتَكِيكَ', #1
u'يشتكيه': u'يَشْتَكِيه', #1
u'يشتكيه': u'يَشْتَكِيهِ', #3
u'يشتكيها': u'يَشْتَكِيهَا', #1
u'يشتمله': u'يَشْتَمِلُهُ', #1
u'يشتمنى': u'يَشْتِمُنِى', #3
u'يشتهره': u'يَشْتَهِرُهُ', #1
u'يشتهيان': u'يَشْتَهِيَانِ', #1
u'يشتهيان': u'يُشْتَهَيَانِ', #2
u'يشتوون': u'يَشْتَوُونَ', #1
u'يشتوي': u'يَشْتَوِي', #3
u'يشدخ': u'يَشْدَخُ', #1
u'يشدخ': u'يُشْدَخَ', #2
u'يشدخه': u'يَشْدَخُهُ', #2
u'يشربS': u'يَشْرَبُS', #1
u'يشرج': u'يَشْرُجُ', #1
u'يشرج': u'يَشْرُجْ', #1
u'يشرج': u'يُشْرَجُ', #1
u'يشرجه': u'يُشْرِجَهُ', #1
u'يشرجه': u'يُشَرِّجْهُ', #2
u'يشرجه': u'يُشْرِجْهُ', #2
u'يشرجه': u'يُشَرِّجَهُ', #5
u'يشرجها': u'يُشْرِجَهَا', #2
u'يشركنى': u'يَشْرَكُنِى', #1
u'يشعرنى': u'يُشْعِرْنِى', #1
u'يشغلنى': u'يَشْغَلُنِى', #2
u'يشقتها': u'يَشُقُّتهُا', #1
u'يشقح': u'يُشَقَّحَ', #1
u'يشقح': u'يُشَقِّحَ', #1
u'يشقح': u'يُشْقِحَ', #1
u'يشقح؟': u'يُشْقَحُ؟', #1
u'يشقح': u'يُشْقَحَ', #2
u'يشقص': u'يُشَقَّصُ', #1
u'يشكنى': u'يَشْكُنِى', #1
u'يشكيك': u'يُشْكِيك', #1
u'يشليها': u'يُشْلِيهَا', #1
u'يشمتنى': u'يُشَمِّتْنِى', #1
u'يشنؤك': u'يَشْنَؤُك', #1
u'يشنؤه': u'يَشْنَؤُهُ', #1
u'يشنؤهم': u'يَشْنَؤُهُمْ', #5
u'يشهدالحديبية': u'يَشْهَدْالْحُدَيْبِيَةَ', #1
u'يشهدقوله': u'يَشْهَدُقَوْلُهُ', #1
u'يشهدوننى': u'يُشْهِدُونَنِى', #1
u'يشوب': u'يَشُوبُ', #11
u'يشوب': u'يَشُوبَ', #2
u'يشوبه': u'يَشُوبهُ', #1
u'يشوبه': u'يَشُوبَهُ', #3
u'يشوبه': u'يَشُوبُهُ', #59
u'يشوبها': u'يَشُوبُهَا', #22
u'يشوبها': u'يَشُوبَهَا', #5
u'يشئزك': u'يَشْئِزك', #1
u'يشئزك': u'يُشْئِزُك', #1
u'يشئزك': u'يُشْئِزُكَ', #1
u'يشيموا': u'يَشِيمُوا', #1
u'يصابها': u'يُصَابِهَا', #1
u'يصأك': u'يَصْأَكُ', #1
u'يصالحنى': u'يُصَالِحَنِى', #1
u'يصبنى': u'يُصِبْنِى', #1
u'يصبيها': u'يُصْبِيَهَا', #1
u'يصدنى': u'يَصُدُّنِى', #1
u'يصرج': u'يُصَرِّجُ', #1
u'يصرخها': u'يَصْرُخُهَا', #1
u'يصري': u'يَصْرِي', #1
u'يصري': u'يِصْرِيٌّ', #1
u'يصري': u'يُصَرِّي', #3
u'يصرينى': u'يصرينى', #1
u'يصريني': u'يَصْرِينِي', #2
u'يصرينى': u'يَصْرِينِى', #2
u'يصريه': u'يَصْرِيه', #1
u'يصطبح': u'يَصْطَبِحُ', #2
u'يصطدعان': u'يَصْطَدِعَانِ', #1
u'يصطرف': u'يَصْطَرِفَ', #1
u'يصطرف': u'يَصْطَرِفُ', #4
u'يصطرما': u'يَصْطَرِمَا', #1
u'يصطلم': u'يَصْطَلِمَ', #2
u'يصعر': u'يُصَعِّرَ', #1
u'يصعر': u'يُصَعِّرُ', #1
u'يصفار': u'يَصْفَارَّ', #1
u'يصفار': u'يَصْفَارُّ', #1
u'يصلحنى': u'يُصْلِحُنِى', #2
u'يصلقوا': u'يَصْلُقُوا', #3
u'يصلونفرأى': u'يُصَلُّونَفَرَأَى', #1
u'يصليإلى': u'يُصَلِّيإِلَى', #1
u'يصليان': u'يُصَلّيَانِ', #3
u'يصليان،': u'يُصَلِّيَانِ،', #3
u'يصليان': u'يُصَلِّيَانِ', #54
u'يصليان': u'يُصَلَّيَانِ', #6
u'يصليدونها': u'يُصَلِّيَدُونَهَا', #1
u'يصليعلى': u'يُصَلِّيعَلَى', #1
u'يصمتوننى': u'يُصَمِّتُونَنِى', #1
u'يصمتونى': u'يُصَمِّتُونِى', #2
u'يصنعSموت': u'يَصْنَعُSمَوْتُ', #1
u'يصيبنى': u'يُصِيبُنِى', #1
u'يصيبنى': u'يُصِيبَنِى', #4
u'يصيغها': u'يُصَيِّغُهَا', #1
u'يصيغون': u'يَصِيغُونَ', #1
u'يضآر': u'يُضَآرَّ', #1
u'يضاهئون': u'يُضَاهِئُونَ', #12
u'يضاهئون': u'يضاهئون', #2
u'يضبع': u'يَضْبَعُ', #1
u'يضحيان': u'يُضَحِّيَانِ', #23
u'يضربنى': u'يَضْرِبَنِى', #1
u'يضربنى': u'يَضْرِبُنِى', #3
u'يضربونS': u'يَضْرِبُونَS', #1
u'يضري': u'يَضْرِي', #1
u'يضطبع': u'يَضْطَبِعَ', #11
u'يضطبع': u'يُضْطَبَعُ', #5
u'يضطبع': u'يَضْطَبِعُ', #7
u'يضطغنا،': u'يَضْطَغِنا،', #1
u'يضطني': u'يَضْطَنِي', #1
u'يضىء': u'يُضِىءَ', #1
u'يضىء': u'يُضِىءُ', #1
u'يضير،': u'يَضِيرُ،', #1
u'يضير': u'يَضِيرُ', #2
u'يضير': u'يُضِيرُ', #3
u'يضيرك': u'يَضِيرَك', #1
u'يضيرك': u'يَضِيرُك', #2
u'يضيعنى': u'يُضَيِّعَنِى', #2
u'يضيفنى': u'يُضَيِّفُنِى', #1
u'يطا': u'يَطَا', #3
u'يطاطي': u'يُطَاطِي', #1
u'يطآن': u'يَطَآنِ', #3
u'يطأوهم،': u'يَطَأَوهُمْ،', #1
u'يطايل': u'يُطَايِلُ', #1
u'يطعمنى': u'يُطْعِمُنِى', #10
u'يطعمنيها': u'يُطْعِمُنِيهَا', #1
u'يطفي': u'يُطْفِي', #1
u'يطفيء': u'يطفيء', #1
u'يطلبنى': u'يَطْلُبُنِى', #2
u'يطلقوالوجه': u'يُطَلِّقَوَالْوَجْهُ', #1
u'يطوشه': u'يُطَوِّشْهُ', #1
u'يطؤك': u'يَطَؤُك', #1
u'يطؤه': u'يطؤه', #1
u'يطؤه': u'يَطَؤُهُ', #2
u'يطؤها،': u'يَطَؤُهَا،', #2
u'يطؤها': u'يَطَؤُهَا', #609
u'يطؤهم': u'يَطَؤُهُمْ', #3
u'يطؤهما': u'يَطَؤُهُمَا', #5
u'يطؤهن': u'يَطَؤُهُنَّ', #4
u'يطويان': u'يُطْوَيَانِ', #1
u'يطئانها': u'يَطَئَانِهَا', #1
u'يطئوا': u'يَطَئُوا', #2
u'يطئون': u'يَطَئُونَ', #29
u'يطئونهم': u'يَطَئُونَهُمْ', #3
u'يطئونهن': u'يَطَئُونَهُنَّ', #1
u'يطيقيان،': u'يطيقيان،', #1
u'يطيلونالخطبة': u'يُطِيلُونَالْخُطْبَةَ', #1
u'يظمي': u'يُظْمِي', #1
u'يظهرإليه': u'يَظْهَرُإِلَيْهِ', #1
u'يظهرسلعة': u'يُظْهِرَسِلْعَةً', #1
u'يعارضة': u'يعارضة', #1
u'يعارضنى': u'يُعَارِضُنِى', #1
u'يعاطه': u'يُعَاطِهِ', #1
u'يعاطون': u'يُعَاطُونَ', #2
u'يعاطيهم': u'يُعَاطِيهِمُ', #2
u'يعاليل': u'يَعالِيل', #1
u'يعاليل': u'يَعالِيلُ', #1
u'يعاليل': u'يَعَالِيلُ', #1
u'يعايا': u'يُعَايَا', #9
u'يعايي': u'يُعَايِيَ', #1
u'يعايى': u'يُعَايَى', #28
u'يعايي': u'يُعَايِي', #3
u'يعبأوا': u'يَعْبَأُوا', #1
u'يعبلن': u'يَعْبِلْنَ', #1
u'يعتاف،': u'يَعْتَافُ،', #1
u'يعتاف': u'يَعْتَافُ', #3
u'يعتافون': u'يَعْتَافُونَ', #2
u'يعتان': u'يَعْتَانَ', #1
u'يعتان': u'يَعْتَانُ', #1
u'يعتزي': u'يَعْتَزِي', #1
u'يعتسف': u'يَعْتَسِفُ', #1
u'يعتضد': u'يُعْتَضَد', #1
u'يعتضد': u'يَعْتَضِدُ', #10
u'يعتضد': u'يُعْتَضَدُ', #10
u'يعتضد': u'يَعْتَضِدَ', #4
u'يعتضد': u'يُعْتَضَدْ', #4
u'يعتضد': u'يَعْتَضِدْ', #5
u'يعتفين': u'يَعْتَفِيَن', #1
u'يعتقب': u'يَعْتَقِبُ', #2
u'يعتقبان': u'يَعْتَقِبَانِ', #8
u'يعتقبانه': u'يَعْتَقِبَانِهِ', #5
u'يعتقبه': u'يَعْتَقِبُهُ', #1
u'يعتقبون': u'يَعْتَقِبُونَ', #16
u'يعتقبونها': u'يَعْتَقِبُونَهَا', #1
u'يعتقبونها،': u'يَعْتَقِبُونَهَا،', #1
u'يعتقرونه': u'يعتقرونه', #1
u'يعتقين': u'يَعْتَقِينَ', #1
u'يعتكفه': u'يَعْتَكِفَهُ', #3
u'يعتكفه': u'يَعْتَكِفُهُ', #3
u'يعتكفه': u'يَعْتَكِفْهُ', #5
u'يعتكفها': u'يَعْتَكِفَهَا', #2
u'يعتكفها': u'يَعْتَكِفُهَا', #2
u'يعتلج': u'يَعْتَلِجُ', #1
u'يعتلجان': u'يَعْتَلِجَانِ', #1
u'يعتلف': u'يَعْتَلِفْ', #1
u'يعتلف': u'يُعْتَلَفْ', #1
u'يعتلف': u'يَعْتَلِفُ', #5
u'يعتلفون': u'يَعْتَلِفُونَ', #1
u'يعتمل': u'يُعْتَمَلْ', #1
u'يعتمل': u'يَعْتَمِل', #2
u'يعتمل': u'يُعْتَمَلُ', #2
u'يعتمل': u'يَعْتَمِلُ', #5
u'يعتملون': u'يَعْتَمِلُونَ', #1
u'يعتملوها': u'يَعْتَمِلُوهَا', #6
u'يعتنونه': u'يَعْتَنُونَهُ', #1
u'يعتور': u'يَعْتَوِرُ', #5
u'يعتوران': u'يُعْتَوَرَانِ', #1
u'يعتوره': u'يَعْتَوِرهُ', #1
u'يعتوره': u'يَعْتَوِرُهُ', #7
u'يعتورها': u'يَعْتَوِرُهَا', #3
u'يعتورهم': u'يَعْتَوِرُهُمْ', #1
u'يعجبنى': u'يُعْجِبُنِى', #6
u'يعجعج': u'يُعَجْعَجُ', #1
u'يعجعج': u'يُعَجْعِجُ', #1
u'يعدلنى': u'يَعْدِلُنِى', #1
u'يعدوان': u'يَعْدُوَانِ', #6
u'يعديان': u'يُعْدِيَانِ', #2
u'يعذبنى': u'يُعَذِّبَنِى', #1
u'يعذبنى': u'يُعَذِّبُنِى', #2
u'يعذرنى': u'يَعْذِرُنِى', #4
u'يعرد': u'يُعَرّدُ', #1
u'يعرص': u'يَعْرِصْ', #1
u'يعرفنى': u'يَعْرَفْنِى', #1
u'يعرفوننى': u'يَعْرِفُونَنِى', #1
u'يعرقب': u'يُعَرْقَبُ', #1
u'يعرقب': u'يُعَرْقِبُ', #1
u'يعرقب': u'يُعَرْقِبَ', #3
u'يعرقبها': u'يُعَرْقِبَهَا', #2
u'يعرقبها': u'يُعَرْقِبُهَا', #2
u'يعرقبون': u'يُعَرْقِبُونَ', #1
u'يعرقبوه': u'يُعَرْقِبُوهُ', #2
u'يعزيان': u'يُعَزَّيَانِ', #1
u'يعزيان': u'يُعْزَيَانِ', #1
u'يعسبه': u'يَعْسِبُهُ', #1
u'يعسبها': u'يَعْسِبُهَا', #1
u'يعشقه': u'يَعْشَقُهُ', #6
u'يعصنى': u'يَعْصِنِى', #1
u'يعصيان': u'يَعْصِيَانِ', #1
u'يعضب': u'يَعْضِبَ', #1
u'يعضب': u'يَعْضِبْ', #1
u'يعضب': u'يُعْضَبَ', #1
u'يعضب': u'يُعْضَبْ', #1
u'يعطكه': u'يُعْطِكَهُ', #1
u'يعطناه': u'يُعْطِنَاهُ', #1
u'يعطنى': u'يُعْطِنِى', #6
u'يعطوكها': u'يُعْطُوكَهَا', #1
u'يعطيان': u'يُعْطَيَانِ', #32
u'يعطيان': u'يُعْطِيَانِ', #8
u'يعطية': u'يعطية', #1
u'يعطيكموه': u'يُعْطِيكُمُوهُ', #1
u'يعطيكه': u'يُعْطِيكَهُ', #3
u'يعطيكها': u'يُعْطِيكهَا', #1
u'يعطيكهن': u'يُعْطِيكَهُنَّ', #1
u'يعطيناه': u'يُعْطِينَاهُ', #1
u'يعطيناها': u'يُعْطِينَاهَا', #3
u'يعطينى': u'يُعْطِينِى', #14
u'يعطينيه': u'يُعْطِينِيهِ', #1
u'يعطينيها': u'يُعْطِينِيهَا', #1
u'يعطيهوالوجه': u'يُعْطِيهِوَالْوَجْهُ', #1
u'يعفج': u'يَعْفِجُ', #2
u'يعفش': u'يَعْفِشُ', #2
u'يعفشه': u'يَعْفِشُهُ', #1
u'يعفشها': u'يَعْفِشُهَا', #1
u'يعفنى': u'يُعْفِنِى', #1
u'يعقلااااا': u'يَعْقِلَااااا', #1
u'يعقى': u'يُعْقَى', #1
u'يعلمالناس': u'يُعَلِّمُالنَّاسَ', #1
u'يعلمنى': u'يُعَلِّمُنِى', #5
u'يعلمنيه': u'يُعَلِّمُنِيهِ', #11
u'يعلمنيها': u'يُعَلِّمُنِيهَا', #2
u'يعلمواأنه': u'يَعْلَمُواأَنَّهُ', #1
u'يعلمونهالوجه': u'يَعْلَمُونَهُالْوَجْهُ', #1
u'يعلول': u'يَعْلُولٌ', #1
u'يعمرواوروي': u'يَعْمُرُواوَرُوِيَ', #1
u'يعمري': u'يَعْمُرِيٌّ', #1
u'يعملات': u'يَعْمُلَاتٍ', #1
u'يعملة': u'يَعْمَلَةٍ', #1
u'يعملة': u'يَعْمُلَةٍ', #1
u'يعنى': u'يًعْنِى', #53
u'يعنيإثما': u'يَعْنِيإِثْمًا', #1
u'يعنيأحاديث': u'يَعْنِيأَحَادِيثَ', #1
u'يعنيإذا': u'يَعْنِيإِذَا', #1
u'يعنياستغفار': u'يَعْنِياسْتِغْفَارَ', #1
u'يعنيإسرائيل': u'يَعْنِيإِسْرَائِيلَ', #1
u'يعنيأسير': u'يَعْنِيأَسِيرَ', #1
u'يعنياطبع': u'يَعْنِياطْبَعْ', #1
u'يعنيالأرحام،': u'يَعْنِيالأَرْحَامَ،', #1
u'يعنيالأشراف': u'يَعْنِيالأَشْرَافَ', #1
u'يعنيالأنبياء': u'يَعْنِيالأَنْبِيَاءَ', #1
u'يعنيالبينات،': u'يَعْنِيالْبَيِّنَاتِ،', #1
u'يعنيالتواب': u'يَعْنِيالتَّوَّابَ', #1
u'يعنيالحافظين': u'يَعْنِيالْحَافِظِينَ', #1
u'يعنيالداريان،': u'يَعْنِيالدَّارِيَّانِ،', #1
u'يعنيالدرج': u'يَعْنِيالدَّرَجَ', #1
u'يعنيالذي': u'يَعْنِيالَّذِي', #1
u'يعنيالذين': u'يَعْنِيالَّذِينَ', #2
u'يعنيالرجم': u'يَعْنِيالرَّجْمَ', #1
u'يعنيالركون': u'يَعْنِيالرُّكُونَ', #1
u'يعنيالشكقال': u'يَعْنِيالشَّكَّقَالَ', #1
u'يعنيالشكوروي': u'يَعْنِيالشَّكَوَرُوِيَ', #1
u'يعنيالشهادة': u'يَعْنِيالشَّهَادَةَ', #1
u'يعنيالعرب': u'يَعْنِيالْعَرَبَ', #1
u'يعنيالعقوبة': u'يَعْنِيالْعُقُوبَةَ', #1
u'يعنيالقائمين': u'يَعْنِيالْقَائِمِينَ', #1
u'يعنيالقرآن': u'يَعْنِيالْقُرْآنَ', #1
u'يعنيالكفار': u'يَعْنِيالْكُفَّارَ', #1
u'يعنيالكفار،': u'يَعْنِيالْكُفَّارَ،', #2
u'يعنيالمشركين': u'يَعْنِيالْمُشْرِكِينَ', #2
u'يعنيالمصدقين': u'يَعْنِيالْمُصَدِّقِينَ', #1
u'يعنيالموت': u'يَعْنِيالْمَوْتَ', #1
u'يعنيالموتوروي': u'يَعْنِيالْمَوْتَوَرُوِيَ', #1
u'يعنيالموحدين': u'يَعْنِيالْمُوَحِّدِينَ', #2
u'يعنيالنبيين': u'يَعْنِيالنَّبِيِّينَ', #1
u'يعنيالهجرة': u'يعنيالْهِجْرَةَ', #1
u'يعنيالهجرة،': u'يَعْنِيالْهِجْرَةَ،', #1
u'يعنيأمما': u'يَعْنِيأُمَمًا', #1
u'يعنيآمن': u'يَعْنِيآمَنَ', #1
u'يعنيأن': u'يَعْنِيأَنَّ', #1
u'يعنيأن': u'يَعْنِيأَنْ', #1
u'يعنيان': u'يعنيان', #1
u'يعنيان': u'يَعْنِيانِ', #1
u'يعنيان': u'يَعْنِيَانِ', #30
u'يعنيإنه': u'يَعْنِيإِنَّهُ', #1
u'يعنيأهل': u'يَعْنِيأَهْلَ', #6
u'يعنيأيكم': u'يَعْنِيأَيُّكُمْ', #1
u'يعنيبالتوحيد': u'يَعْنِيبِالتَّوْحِيدِ', #1
u'يعنيبالزكاة': u'يَعْنِيبِالزَّكَاةِ', #1
u'يعنيبالعدل': u'يَعْنِيبِالْعَدْلِ', #1
u'يعنيبالعيلة': u'يعنيبالعيلة', #1
u'يعنيبالقائم': u'يَعْنِيبِالْقَائِمِ', #1
u'يعنيبطلت': u'يَعْنِيبَطَلَتْ', #1
u'يعنيبلغة': u'يَعْنِيبِلُغَةِ', #1
u'يعنيبما': u'يَعْنِيبِمَا', #1
u'يعنيتبيانا': u'يَعْنِيتِبْيَانًا', #1
u'يعنيتحت': u'يَعْنِيتَحْتَ', #1
u'يعنيجزاء': u'يَعْنِيجَزَاءً', #1
u'يعنيجعل': u'يَعْنِيجُعِلَ', #1
u'يعنيخلفوا': u'يَعْنِيخُلِّفُوا', #1
u'يعنيدائما': u'يَعْنِيدَائِمًا', #3
u'يعنيذلك': u'يَعْنِيذَلِكَ', #1
u'يعنيرءوس': u'يَعْنِيرُءُوسَ', #1
u'يعنيرجلا': u'يَعْنِيرَجُلا', #1
u'يعنيسكرات': u'يَعْنِيسَكَرَاتِ', #1
u'يعنيشديدا': u'يَعْنِيشَدِيدًا', #1
u'يعنيشواه': u'يَعْنِيشَوَاهُ', #1
u'يعنيعالما': u'يَعْنِيعَالِمًا', #1
u'يعنيعذابا': u'يَعْنِيعَذَابًا', #1
u'يعنيعصبة': u'يَعْنِيعُصْبَةَ', #1
u'يعنيعن': u'يَعْنِيعَنِ', #1
u'يعنيغفور': u'يَعْنِيغَفُورَ', #1
u'يعنيفضيلة': u'يَعْنِيفَضِيلَةً', #1
u'يعنيفي': u'يَعْنِيفِي', #4
u'يعنيقواعده': u'يَعْنِيقَوَاعِدَهُ', #1
u'يعنيقوم': u'يَعْنِيقَوْمَ', #1
u'يعنيكل': u'يَعْنِيكُلَّ', #1
u'يعنيلا': u'يَعْنِيلا', #3
u'يعنيللمصدقين': u'يَعْنِيلِلْمُصَدِّقِينَ', #1
u'يعنيليخبركم': u'يَعْنِيلِيُخْبِرَكُمْ', #1
u'يعنيليصدقوا': u'يَعْنِيلِيُصَدِّقُوا', #1
u'يعنيما': u'يَعْنِيمَا', #1
u'يعنيمتاع': u'يَعْنِيمَتَاعَ', #1
u'يعنيمحمدا': u'يَعْنِيمُحَمَّدًا', #1
u'يعنيمسجد': u'يَعْنِيمَسْجِدَ', #1
u'يعنيمن': u'يَعْنِيمَنْ', #1
u'يعنيمن': u'يَعْنِيمِنَ', #2
u'يعنيمن': u'يَعْنِيمِنْ', #3
u'يعنيمنهزمين': u'يَعْنِيمُنْهَزِمِينَ', #1
u'يعنينزل': u'يَعْنِينَزَلَ', #1
u'يعنيهذه': u'يَعْنِيهَذِهِ', #1
u'يعنيهذهقوله': u'يَعْنِيهَذِهِقَوْلُهُ', #1
u'يعنيهكذا': u'يَعْنِيهَكَذَا', #1
u'يعنيولا': u'يَعْنِيوَلا', #1
u'يعنيوما': u'يَعْنِيومَا', #1
u'يعنييتجاوز': u'يَعْنِييَتَجَاوَزُ', #1
u'يعنييحمدون': u'يَعْنِييَحْمَدُونَ', #1
u'يعنييرجون': u'يَعْنِييَرْجُونَ', #1
u'يعنييعبدون': u'يَعْنِييَعْبُدُونَ', #1
u'يعنيينجز': u'يَعْنِييُنْجِزُ', #1
u'يعودانى': u'يَعُودَانِى', #1
u'يعودنى': u'يَعُودُنِى', #12
u'يعودونإليه': u'يَعُودُونَإِلَيْهِ', #1
u'يعودونقوله': u'يَعُودُونَقَوْلُهُ', #1
u'يعيدق': u'يُعِيدُق', #1
u'يعيرنى': u'يُعِيرُنِى', #1
u'يعيننى': u'يُعِينَنِى', #1
u'يعينونى': u'يُعِينُونِى', #2
u'يغارمه': u'يُغَارِمُهُ', #1
u'يغازي': u'يُغَازِي', #5
u'يغازيان': u'يغازيان', #1
u'يغازيان': u'يُغَازِيَانِ', #2
u'يغافل': u'يُغَافَلَ', #3
u'يغالق': u'يُغَالَقُ', #1
u'يغالق': u'يُغَالِقُ', #3
u'يغان': u'يغان', #1
u'يغان': u'يُغَانُ', #4
u'يغبط': u'يُغْبَطَ', #1
u'يغبط': u'يُغْبَطُ', #1
u'يغبط': u'يُغْبَطْ', #2
u'يغبط': u'يَغْبِطُ', #3
u'يغبطني': u'يَغْبِطُنِي', #2
u'يغبطه': u'يغبطه', #1
u'يغبطه': u'يَغْبِطهُ', #1
u'يغبطه': u'يَغْبِطُهُ', #4
u'يغبطهم': u'يُغَبِّطُهُمْ', #1
u'يغبطهم': u'يَغْبِطُهُمْ', #24
u'يغبطهم': u'يَغْبِطُهُمُ', #4
u'يغبطوا': u'يُغْبَطُوا', #1
u'يغبطوا': u'يُغْبِطُوا', #1
u'يغبطون': u'يَغْبِطُونَ', #1
u'يغبنوا': u'يَغْبِنُوا', #2
u'يغبنوا': u'يُغْبَنُوا', #2
u'يغبيه': u'يُغَبِّيهِ', #1
u'يغت': u'يغت', #1
u'يغت': u'يَغُتُّ', #3
u'يغتدى': u'يُغْتَدَى', #1
u'يغترق': u'يُغْتَرَقُ', #1
u'يغترق': u'يَغْتَرِقَ', #2
u'يغترق': u'يَغْتَرِقْ', #3
u'يغترق': u'يَغْتَرِقُ', #47
u'يغترقه': u'يَغْتَرِقُهُ', #3
u'يغترقها': u'يَغْتَرِقُهَا', #6
u'يغترقهم': u'يَغْتَرِقُهُمْ', #6
u'يغتزي': u'يَغْتَزِي', #1
u'يغتفل': u'يغتفل', #1
u'يغتفل': u'يَغْتَفِلَ', #1
u'يغتفل': u'يُغْتَفَلَ', #1
u'يغتفل': u'يُغْتَفَلُ', #1
u'يغتفله': u'يَغْتَفِلْهُ', #1
u'يغتفلها': u'يَغْتَفِلَهَا', #2
u'يغتفلهما': u'يَغْتَفِلَهُمَا', #1
u'يغتلونه': u'يَغْتَلُّونَهُ', #1
u'يغثي': u'يُغْثِي', #1
u'يغثي': u'يَغْثِي', #3
u'يغثيه': u'يُغَثِّيهِ', #1
u'يغثيه': u'يُغْثِيهِ', #1
u'يغدوان': u'يغدوان', #2
u'يغذوان': u'يَغْذُوَانِ', #1
u'يغراقراخان': u'يغراقراخان', #1
u'يغزوان': u'يَغْزُوَانِ', #1
u'يغشيان': u'يَغْشَيَانِ', #2
u'يغضضه': u'يَغْضُضْهُ', #1
u'يغطال': u'يَغْطَالّ', #1
u'يغطئل': u'يَغْطَئِلّ', #1
u'يغطيان': u'يُغَطِّيَانِ', #2
u'يغلبنى': u'يَغْلِبَنِى', #1
u'يغلبنى': u'يَغْلِبْنِى', #1
u'يغلبنى': u'يَغْلِبُنِى', #2
u'يغليان': u'يَغْلِيَانِ', #1
u'يغمبررابذيرفتم': u'يغمبررابذيرفتم', #1
u'يغمزنى': u'يَغْمِزُنِى', #1
u'يغمص': u'يَغْمِصُ', #1
u'يغمص': u'يُغْمَصَ', #1
u'يغمص': u'يُغْمَصْ', #1
u'يغمى': u'يُغَمّى', #1
u'يغمى': u'يُغْمَى', #17
u'يغنمكموها': u'يُغْنِمكُمُوهَا', #1
u'يغنمناها': u'يَغْنِمْنَاهَا', #1
u'يغنيان': u'يُغَنِّيَانِ', #2
u'يغنيان': u'يُغْنِيَانِ', #6
u'يغوث': u'يُغَوّثُ', #1
u'يغوث،': u'يَغُوثَ،', #12
u'يغوث': u'يَغُوث', #2
u'يغوث': u'يَغُوثُ', #3
u'يغوث': u'يَغُوثَ', #62
u'يغوث': u'يغوث', #9
u'يغوثهم': u'يُغِوثْهُمْ', #1
u'يغوط': u'يَغُوطُ', #2
u'يغي': u'يُغَيَّ', #1
u'يغي': u'يُغَيِّ', #1
u'يغيا': u'يُغَيَّا', #1
u'يغيا': u'يُغْيَا', #1
u'يغيط': u'يَغِيطُ', #1
u'يغيه': u'يُغَيِّهِ', #1
u'يغيون': u'يُغَيُّونَ', #1
u'يفاترني': u'يُفَاتِرُنِي', #1
u'يفاجىء': u'يفاجىء', #1
u'يفاحش': u'يُفَاحِشَ', #1
u'يفاحشها': u'يُفَاحِشَهَا', #1
u'يفارقنى': u'يُفَارِقْنِى', #2
u'يفارقونى': u'يُفَارِقُونِى', #1
u'يفأم': u'يُفْأَمُ', #1
u'يفاوت': u'يُفَاوَتُ', #1
u'يفاوت': u'يُفَاوِت', #1
u'يفاوت': u'يُفَاوِتَ', #15
u'يفاوت': u'يُفَاوَتَ', #2
u'يفاوت': u'يُفَاوِتْ', #4
u'يفاوت': u'يُفَاوِتُ', #8
u'يفتأت': u'يُفْتَأَتَ', #1
u'يفتات': u'يُفْتَاتُ', #10
u'يفتات': u'يَفْتَاتَ', #5
u'يفتات': u'يُفْتَاتَ', #7
u'يفتات': u'يَفْتَاتُ', #8
u'يفتال': u'يَفْتَالُ', #1
u'يفترغه': u'يَفْتَرِغُهُ', #1
u'يفتض': u'يُفْتَضُّ', #9
u'يفتضها': u'يَفْتَضُّهَا', #1
u'يفتضها': u'يَفْتَضَّهَا', #4
u'يفتطن': u'يَفْتَطِنْ', #1
u'يفتننى': u'يَفْتِنُنِى', #1
u'يفتنونى': u'يَفْتِنُونِى', #3
u'يفتئت': u'يَفْتَئِتَ', #1
u'يفتيان': u'يُفْتَيَانِ', #1
u'يفتيان': u'يُفْتِيَانِ', #9
u'يفتيكموه': u'يُفْتِيكُمُوهُ', #1
u'يفتيكموه': u'يُفْتِيَكُمُوهُ', #1
u'يفجأة': u'يفجأة', #1
u'يفجؤه': u'يَفْجَؤُهُ', #9
u'يفجؤها': u'يَفْجَؤُهَا', #3
u'يفجؤهم': u'يَفْجَؤُهُمْ', #1
u'يفحشه': u'يُفْحِشُهُ', #1
u'يفديان': u'يَفْدِيَانِ', #4
u'يفدينى': u'يَفْدِينِى', #1
u'يفزغهم': u'يفزغهم', #1
u'يفضخ': u'يُفْضَخَ', #4
u'يفضيان': u'يُفْضِيَانِ', #7
u'يفطرنى': u'يُفَطِّرُنِى', #1
u'يفعول': u'يَفْعُولٍ', #2
u'يفعول': u'يَفْعُولُ', #2
u'يفقئوا': u'يَفْقَئُوا', #12
u'يفقئون': u'يَفْقَئُونَ', #1
u'يفكهما': u'يَفُكُّهُمَا', #1
u'يفكوه': u'يَفُكُّوهُ', #1
u'يفلعون': u'يَفْلَعُونَ', #1
u'يفنيان': u'يَفْنَيَانِ', #10
u'يفنيان': u'يُفْنِيَانِ', #2
u'يفنيكم': u'يُفْنِيكُمْ', #1
u'يفنينا': u'يُفْنِينَا', #1
u'يفنيه': u'يُفْنِيهِ', #8
u'يفنيهم،': u'يُفْنِيهِمْ،', #1
u'يفنيهم': u'يُفْنِيَهُمْ', #1
u'يفنيهما': u'يُفْنِيهِمَا', #23
u'يفنيهما': u'يُفْنِيَهُمَا', #4
u'يفهق': u'يَفْهَقُ', #1
u'يفوح': u'يَفُوحَ', #1
u'يفوح': u'يَفُوحُ', #33
u'يفوح': u'يَفُوح', #8
u'يفود': u'يَفُودُ', #1
u'يفى': u'يَفِىَ', #5
u'يفى': u'يَفِى', #7
u'يفىء': u'يُفِىءُ', #2
u'يفىء': u'يَفِىءَ', #8
u'يفيان': u'يَفِيَانِ', #1
u'يفيت': u'يُفِيتَ', #2
u'يفيت': u'يُفِيتُ', #82
u'يفيتان': u'يُفِيتَانِ', #4
u'يفيتانها': u'يُفِيتَانِهَا', #1
u'يفيتنا': u'يُفِيتُنَا', #1
u'يفيته': u'يُفِيتَهُ', #2
u'يفيته': u'يُفِيتُهُ', #64
u'يفيتها': u'يُفِيتُهَا', #59
u'يفيتهما': u'يُفِيتُهُمَا', #11
u'يفيتهن': u'يُفِيتُهُنَّ', #6
u'يفيص': u'يَفِيصُ', #2
u'يفيكها': u'يَفِيكَهَا', #1
u'يقاعد': u'يُقَاعِدُ', #1
u'يقاعد': u'يُقَاعِدَ', #3
u'يقاعدونه': u'يُقَاعِدُونَهُ', #3
u'يقالالذين': u'يُقَالُالَّذِينَ', #1
u'يقالها': u'يُقَالُهَا', #1
u'يقاوي': u'يُقَاوِي', #1
u'يقايل': u'يُقَايِلُ', #1
u'يقايل': u'يُقَايِلْ', #1
u'يقايل': u'يُقَايِلَ', #11
u'يقبضنى': u'يَقْبِضُنِى', #1
u'يقبضنيه': u'يُقْبِضَنِيهِ', #1
u'يقبضوناها': u'يُقْبِضُونَاهَا', #1
u'يقبلنى': u'يُقَبِّلَنِى', #1
u'يقبلنى': u'يُقَبِّلُنِى', #1
u'يقتري': u'يَقْتَرِي', #1
u'يقترئ': u'يَقْتَرِئْ', #1
u'يقترئ': u'يَقْتَرِئُ', #5
u'يقترئون': u'يَقْتَرِئُونَ', #1
u'يقتصه': u'يَقْتَصَّهُ', #1
u'يقتصه': u'يَقْتَصُّهُ', #1
u'يقتضيان': u'يَقْتَضِيَانِ', #59
u'يقتعطها': u'يَقْتَعِطُهَا', #1
u'يقتلنى': u'يَقْتُلَنِى', #1
u'يقتلوننى': u'يَقْتُلُونَنِى', #1
u'يقتلونى': u'يَقْتُلُونِى', #1
u'يقتلونى؟': u'يَقْتُلُونِى؟', #1
u'يقتنيان': u'يَقْتَنِيَانِ', #1
u'يقدرو': u'يَقْدِرُو', #2
u'يقدع': u'يُقْدَعُ', #2
u'يقرءو': u'يَقْرَءُو', #1
u'يقرءوا': u'يَقْرَءُوا', #17
u'يقرءون': u'يَقْرَءُونٍٍٍٍَ', #1
u'يقرءون': u'يَقْرَءُونِ', #1
u'يقرءون': u'يَقْرِءُونَ', #1
u'يقرءون': u'يقرءون', #2
u'يقرءون': u'يَقْرَءُونَ', #254
u'يقرءونه،': u'يَقْرَءُونَهُ،', #1
u'يقرءونه': u'يَقْرَءُونَهُ', #12
u'يقرءونها': u'يَقْرَءُونَهَا', #2
u'يقرءونهما': u'يَقْرَءُونَهُمَا', #1
u'يقرءوه': u'يُقْرِءُوهُ', #1
u'يقرءوه': u'يَقْرَءُوهُ', #3
u'يقرءوها': u'يَقْرَءُوهَا', #3
u'يقرإ': u'يَقْرَإِ', #2
u'يقرأالقرآن': u'يَقْرَأُالْقُرْآنَ', #1
u'يقرأان': u'يُقْرَأَانِ', #1
u'يقرأف': u'يقرأف', #1
u'يقرأفي': u'يَقْرَأُفِي', #1
u'يقرآن': u'يُقْرَآنِ', #1
u'يقرآن': u'يَقْرَآنِ', #23
u'يقرأوا': u'يَقْرَأُوا', #1
u'يقرأون': u'يَقْرَأُونَ', #1
u'يقرأون': u'يقرأون', #5
u'يقرأونها': u'يَقْرَأونَهَا', #1
u'يقربنى': u'يَقَرِّبُنِى', #1
u'يقربنى': u'يَقْرَبْنِى', #1
u'يقربنى': u'يُقَرِّبُنِى', #2
u'يقرزم': u'يُقَرْزِمُ', #1
u'يقرم': u'يَقْرِمَ', #1
u'يقرنى': u'يَقْرِنِى', #1
u'يقرؤه،': u'يقرؤه،', #1
u'يقرؤه': u'يَقْرَؤُهُ', #150
u'يقرؤها': u'يُقْرِؤُهَا', #1
u'يقرؤها': u'يَقْرَؤُهَا', #190
u'يقرؤها': u'يَقْرَؤهَا', #3
u'يقرؤها': u'يقرؤها', #8
u'يقرؤها،': u'يَقْرَؤُهَا،', #8
u'يقرؤهما': u'يَقْرَؤُهُمَا', #13
u'يقرؤهن': u'يُقْرَؤُهُنَّ', #1
u'يقرؤهن': u'يَقْرَؤُهُنَّ', #8
u'يقرئان': u'يُقْرِئَانِ', #2
u'يقرئنيها': u'يُقْرِئْنِيهَا', #5
u'يقسيان': u'يُقَسِّيَانِ', #1
u'يقسيان': u'يُقْسِيَانِ', #1
u'يقصرالصلاة': u'يَقْصُرُالصَّلَاةَ', #1
u'يقضيان': u'يُقْضَيَانِ', #3
u'يقضيان': u'يَقْضِيَانِ', #35
u'يقضيكها': u'يقضيكها', #1
u'يقظانا،': u'يَقْظَانًا،', #1
u'يقظانا': u'يَقْظَانًا', #4
u'يقعدنى': u'يُقْعِدُنِى', #1
u'يقعطها': u'يَقْعَطُهَا', #1
u'يقعيان': u'يُقْعَيَانِ', #1
u'يقعيان': u'يُقْعِيَانَ', #1
u'يقعيان': u'يَقْعَيَانِ', #2
u'يقعيان': u'يُقْعِيَانِ', #2
u'يقفأ': u'يَقْفَأَ', #1
u'يقلس': u'يقلّس', #1
u'يقلس': u'يُقَلَّسُ', #4
u'يقلس': u'يَقْلِسُ', #6
u'يقلسون': u'يقلّسون', #1
u'يقلسون': u'يُقْلِسُونَ', #1
u'يقلسون': u'يُقَلِّسُونَ', #2
u'يقمره': u'يَقْمُرَهُ', #1
u'يقمره': u'يُقَمِّرَهُ', #1
u'يقمون': u'يقمون', #7
u'يقنأ': u'يَقْنَأَ', #1
u'يقنأ': u'يَقْنَأُ', #1
u'يقنعنى': u'يُقْنِعُنِى', #2
u'يقنئوا': u'يَقْنَئُوا', #1
u'يقوتا': u'يَقُوتًا', #1
u'يقوتناه': u'يُقَوِّتُنَاهُ', #1
u'يقودنى': u'يَقُودُنِى', #3
u'يقولالعزيز': u'يَقُولُالْعَزِيزُ', #1
u'يقولالله': u'يَقُولُاللَّهُ', #1
u'يقولثم': u'يَقُولُثُمَّ', #1
u'يقولفي': u'يقولفِي', #3
u'يقولكان': u'يَقُولُكَانَ', #1
u'يقولم': u'يقولم', #1
u'يقولمعشبة': u'يَقُولُمُعْشِبَةٌ', #1
u'يقولونإنك': u'يَقُولُونَإِنَّكَ', #1
u'يقولونيا': u'يَقُولُونَيَا', #1
u'يقويان': u'يُقَوِّيَانِ', #1
u'يقى': u'يَقِى', #1
u'يقىء': u'يَقِىءُ', #5
u'يقيت': u'يقيت', #1
u'يقيت': u'يُقِيتُ', #1
u'يقيتنا': u'يُقِيتُنَا', #1
u'يقيته': u'يُقِيتُهُ', #7
u'يقينياتها': u'يَقِينِيَّاتِهَا', #1
u'يك‍ارها': u'يُكَ‍ارِّهَا', #1
u'يكاسب': u'يُكَاسِبُ', #1
u'يكامل': u'يُكَامِلُ', #1
u'يكبار': u'يكبار', #3
u'يكتريان': u'يَكْتَرِيَانِ', #2
u'يكتفل': u'يَكْتَفِلُ', #1
u'يكتفيان': u'يَكْتَفِيَانِ', #8
u'يكتنوا': u'يَكْتَنُوا', #4
u'يكتنون': u'يَكْتَنُونَ', #1
u'يكتنى': u'يَكْتَنِى', #2
u'يكتنى': u'يُكْتَنَى', #3
u'يكدرم': u'يكدرم', #2
u'يكذلك': u'يُكَذْلِكَ', #1
u'يكرثه': u'يَكْرِثُهُ', #2
u'يكرج': u'يَكْرَجُ', #1
u'يكركه': u'يكركه', #1
u'يكرمي': u'يكرمي', #1
u'يكسال': u'يكسال', #3
u'يكساله': u'يكساله', #1
u'يكسوم': u'يَكسومَ', #1
u'يكسوم': u'يَكْسُومٍ', #1
u'يكسوم': u'يكْسوم', #2
u'يكسوم': u'يَكْسُومُ', #4
u'يكسوم': u'يَكْسوم', #6
u'يكسوم': u'يَكْسُومَ', #8
u'يكسيان': u'يُكْسَيَانِ', #1
u'يكع': u'يَكِعُّ', #1
u'يكفت': u'يكفت', #1
u'يكفت': u'يَكْفِت', #1
u'يكفت': u'يَكْفِتَ', #3
u'يكفت': u'يَكْفِتُ', #3
u'يكفته': u'يَكْفِتَهُ', #1
u'يكفته': u'يَكْفِتُهُ', #1
u'يكفنيهم': u'يَكْفِنِيهِمْ', #1
u'يكفؤها': u'يَكْفَؤُهَا', #1
u'يكفؤها،': u'يَكْفَؤُهَا،', #1
u'يكفيان': u'يَكْفِيَانِ', #8
u'يكفيكا': u'يَكْفِيكَا', #3
u'يكفيكموه': u'يَكْفِيكُمُوهُ', #1
u'يكفيكه': u'يَكْفِيكَهُ', #2
u'يكفيكهم': u'يكْفِيكَهُمُ', #1
u'يكفيكهم': u'يَكْفِيَكَهُمُ', #1
u'يكفيكهم': u'يَكْفِيكَهُمُ', #4
u'يكفيناك': u'يَكْفِينَاكَ', #1
u'يكفيناه': u'يَكْفِينَاهُ', #1
u'يكفيناهم': u'يَكْفِيَنَاهُمْ', #1
u'يكفينى': u'يَكْفِينِى', #10
u'يكلمن-ا': u'يُكَلِّمُنَ-ا', #1
u'يكلمنى': u'يُكَلِّمَنِى', #1
u'يكلمنى': u'يُكَلِّمْنِى', #2
u'يكلمنى': u'يُكَلِّمُنِى', #3
u'يكلؤكم': u'يَكْلَؤُكُمْ', #6
u'يكلؤنا': u'يكلؤنا', #1
u'يكلؤنا': u'يَكْلَؤُنَا', #21
u'يكلؤه': u'يَكْلَؤُهُ', #5
u'يكمهان': u'يُكْمِهَانِ', #1
u'يكمؤها': u'يَكْمَؤُهَا', #1
u'يكنع': u'يُكْنَع', #1
u'يكنع': u'يُكْنَعُ', #1
u'يكنم': u'يكنم', #1
u'يكنو': u'يَكْنُو', #2
u'يكنونى': u'يَكْنُونِى', #1
u'يكهر': u'يكهر', #1
u'يكهرون': u'يُكْهَرُونَ', #1
u'يكهرون،': u'يُكْهَرُونَ،', #2
u'يكول': u'يَكُولُ', #1
u'يكونعثمان': u'يَكُونَعُثْمَانُ', #1
u'يكونقوله': u'يَكُونُقَوْلُهُ', #1
u'يكونوالوجه': u'يَكُونُوَالْوَجْهُ', #1
u'يكونونعنده': u'يَكُونُونَعِنْدَهُ', #1
u'يكى': u'يكى', #16
u'يكي': u'يكي', #2
u'يكي': u'يَكِي', #3
u'يكيار': u'يكيار', #1
u'يكيد': u'يَكيِدُ', #1
u'يكيد': u'يكيد', #2
u'يكيد': u'يَكِيدُ', #7
u'يكيدنا': u'يَكِيدُنَا', #2
u'يكيدوا': u'يَكِيدُوا', #2
u'يكيدون': u'يَكِيدُونَ', #4
u'يكيدوه': u'يَكِيدُوهُ', #1
u'يكيست': u'يكيست', #1
u'يلاقيان': u'يُلَاقِيَانِ', #1
u'يلامق': u'يَلامِقِ', #1
u'يلامق': u'يَلَامِقِ', #1
u'يلاومني': u'يُلَاوِمُنِي', #1
u'يلاومنى': u'يُلاَوِمُنِى', #1
u'يلائمنى': u'يَلاَئِمُنِى', #1
u'يلايمكم': u'يُلاَيِمْكُمْ', #1
u'يلايمني': u'يُلَايِمُنِي', #1
u'يلايمهم': u'يُلايِمُهُمْ', #1
u'يلبسنيها': u'يُلْبِسُنِيهَا', #1
u'يلبغا': u'يَلْبُغَا', #2
u'يلبيان،': u'يلبيان،', #1
u'يلبيان': u'يُلَبِّيَانِ', #1
u'يلتام': u'يَلْتَامُ', #2
u'يلتثم': u'يَلْتَثِمُ', #1
u'يلتج': u'يَلْتَجِ', #1
u'يلتدمون': u'يَلْتَدِمُونَ', #1
u'يلتدمون،': u'يَلْتَدِمُونَ،', #1
u'يلتعنا': u'يَلْتَعِنَا', #7
u'يلتقيان،': u'يَلْتَقِيَانِ،', #3
u'يلتقيان': u'يَلْتَقِيَانِ', #83
u'يلتمع': u'يَلْتَمِع', #1
u'يلتمع': u'يَلْتَمِعُ', #1
u'يلتمع': u'يُلْتَمَعَ', #3
u'يلتمعان': u'يَلْتَمِعَانِ', #4
u'يلحاكم': u'يَلْحَاكُمْ', #1
u'يلزمهممن': u'يَلْزَمُهُمْمِنْ', #1
u'يلسه': u'يلسه', #1
u'يلطح': u'يَلْطَح', #2
u'يلطح': u'يَلْطَحُ', #9
u'يلعنهقوله': u'يَلْعَنُهُقَوْلُهُ', #1
u'يلغوان': u'يَلْغُوَانِ', #4
u'يلغيان': u'يُلْغِيَانِ', #4
u'يلغيان': u'يُلْغَيَانِ', #5
u'يلقانى': u'يَلْقَانِى', #4
u'يلقمنيها': u'يَلْقُمُنِيهَا', #1
u'يلقنى': u'يَلْقَنِى', #3
u'يلقيان': u'يُلْقَيَانِ', #1
u'يلمق': u'يلمق', #1
u'يلمق': u'يَلْمُقُ', #1
u'يلمقه': u'يَلْمُقهُ', #1
u'يلنجوج': u'يَلَنْجُوجٍ', #1
u'يلنجوج': u'يَلَنْجُوجُ', #1
u'يلنجوجا': u'يَلَنْجُوجًا', #1
u'يلهزانه': u'يَلْهَزَانِهِ', #3
u'يلهمنيه': u'يُلْهِمُنِيهِ', #1
u'يلهينى': u'يُلْهِينِى', #1
u'يلهينى': u'يُلْهِيَنِى', #1
u'يلونى': u'يَلُونِى', #1
u'يلى': u'يَلِىَ', #1
u'يلى': u'يلى', #2
u'يلى': u'يَلِى', #54
u'يليان': u'يليان', #1
u'يليان': u'يَلِيَانَ', #1
u'يليان': u'يَلِيَانِ', #45
u'يليته': u'يَلِيتُهُ', #1
u'يليس': u'يليس', #1
u'يليط': u'يُلِيطُ', #4
u'يليط': u'يَلِيطُ', #5
u'يليق': u'يُلِيقُ', #1
u'يليق': u'يَلِيقُ', #1695
u'يليق': u'يَلِيقَ', #19
u'يليق': u'يَلِيق', #48
u'يليقا': u'يَلِيقَا', #7
u'يليقان': u'يَلِيقَانِ', #15
u'يليقها': u'يَلِيقهَا', #1
u'يليقون': u'يُلِيقُونَ', #1
u'يلينى': u'يَلِينِى', #4
u'يماذى': u'يُمَاذِى', #1
u'يماز': u'يُمَازُ', #1
u'يماسكه': u'يُمَاسِكْهُ', #1
u'يمالؤنهم': u'يُمَالِؤنَهُمْ', #1
u'يمامى': u'يَمَامِىٌّ', #1
u'يمامى': u'يَمَامِىُّ', #1
u'يمانى': u'يَمَانِىٌّ', #1
u'يمايل': u'يُمَايِلَ', #1
u'يمتار،': u'يَمْتَارُ،', #1
u'يمتار': u'يَمْتَارُ', #4
u'يمتاره': u'يَمْتَارُهُ', #2
u'يمتاروا': u'يَمْتَارُوا', #3
u'يمتارون': u'يمتارون', #1
u'يمتارون': u'يَمْتَارُونَ', #6
u'يمتري': u'يَمْتَرِي', #8
u'يمتلىء': u'يمتلىء', #2
u'يمتلئان': u'يَمْتَلِئَانِ', #1
u'يمجسانه': u'يمجسانه', #1
u'يمجسانه': u'يُمَجِّسَانِهِ', #20
u'يمجساه': u'يُمَجِّسَاهُ', #2
u'يمحشني': u'يَمْحَشَنِي', #1
u'يمحشني،': u'يَمْحَشُنِي،', #1
u'يمدحونكا': u'يَمْدَحُونَكَا', #2
u'يمدر': u'يمدر', #1
u'يمدر': u'يَمْدُرُ', #1
u'يمذ': u'يُمْذِ', #11
u'يمذي': u'يَمْذِيَ', #1
u'يمذى': u'يُمْذِى', #1
u'يمذي': u'يُمْذِي', #20
u'يمذي': u'يَمْذِي', #5
u'يمذي': u'يُمْذِيَ', #7
u'يمرط': u'يَمْرُطُ', #3
u'يمري': u'يَمْرِي', #2
u'يمسنى': u'يَمَسَّنِى', #2
u'يمسنى': u'يَمَسُّنِى', #2
u'يمسهإلا': u'يَمَسُّهُإِلَّا', #1
u'يمشيان': u'يمشيان', #2
u'يمشيان،': u'يَمْشِيَانِ،', #3
u'يمشيان': u'يَمْشِيَانِ', #85
u'يمصعن': u'يَمْصَعْنَ', #1
u'يمضيان': u'يَمْضِيَانِ', #9
u'يمعمع': u'يُمَعْمِعُ', #3
u'يمقر': u'يَمْقُرُ', #1
u'يمقع': u'يَمْقَعْ', #1
u'يمكننى': u'يُمَكِّنُنِى', #1
u'يمكنى': u'يُمْكِنِّى', #3
u'يملآن': u'يَمْلَآنِ', #1
u'يملآن': u'يَمْلآَنِ', #2
u'يملج': u'يَمْلُجُ', #1
u'يملشقع': u'يملشقع', #1
u'يملؤه': u'يَمْلَؤهُ', #1
u'يملؤه': u'يَمْلَؤُهُ', #14
u'يملؤها': u'يَمْلَؤُهَا', #8
u'يملئوا': u'يَمْلَئُوا', #5
u'يملئون': u'يَمْلَئُونَ', #3
u'يملئونه': u'يَمْلَئُونَهُ', #1
u'يملئونها': u'يَمْلَئُونَهَا', #1
u'يمنعنى': u'يَمْنَعُنِى', #13
u'يمنعنى': u'يَمْنَعْنِى', #14
u'يمنعنيها': u'يَمْنَعنِيهَا', #1
u'يمنعنيها': u'يَمْنَعَنِيهَا', #1
u'يمنعنيها': u'يَمْنَعُنِيهَا', #1
u'يمنعنيها': u'يَمْنَعْنِيهَا', #1
u'يمنعونى': u'يَمْنَعُونِى', #1
u'يمنو': u'يَمْنُو', #1
u'يمنى': u'يُمْنًى', #1
u'يموتوروى': u'يَمُوتَوَرَوَى', #1
u'يموس': u'يَمُوسُ', #1
u'يمير': u'يُمِيرَ', #2
u'يمير': u'يَمِيرَ', #3
u'يمير': u'يَمِيرُ', #7
u'يميرونهم': u'يَمِيرُونَهُمْ', #1
u'يميلإلى': u'يَمِيلُإِلَى', #1
u'يمين': u'يَمِينً', #1
u'يمينكوالوجه': u'يَمِينِكِوَالْوَجْهُ', #1
u'يمينى': u'يَمِيِنِى', #1
u'يمينى': u'يَمِينِى', #26
u'ينابع': u'يَنَابِعِ', #1
u'يناحزهم،': u'يناحزهم،', #1
u'ينادن': u'يُنَادِنّ', #1
u'يناديان،': u'يُنَادِيَانِ،', #1
u'يناديان': u'يُنَادِيَانِ', #12
u'ينازعنى': u'يُنَازِعُنِى', #4
u'ينازعنيه': u'يُنَازِعَنِيهِ', #2
u'يناطها': u'يُنَاطُهَا', #1
u'ينافقهم': u'يُنَافِقُهُمْ', #1
u'ينافيان': u'يُنَافَيَانِ', #1
u'ينافيان': u'يُنَافِيَانِ', #35
u'يناق': u'يَنَاقٍ', #1
u'يناق': u'يَنَّاقٍ', #14
u'يناق': u'يَنَاقَ', #2
u'يناق': u'يَنَّاق', #2
u'يناق،': u'يَنَّاقٍ،', #6
u'يناق': u'يَنَّاقَ', #7
u'يناقص': u'يُنَاقِصُ', #2
u'يناقصني': u'يُنَاقِصُنِي', #1
u'يناكر': u'يُنَاكِرُ', #11
u'يناكر': u'يُنَاكِرَ', #5
u'يناكر': u'يُنَاكِرْ', #7
u'يناكره': u'يُنَاكِرُهُ', #1
u'يناكره': u'يُنَاكِرْهُ', #1
u'يناكره': u'يُنَاكِرُهْ', #2
u'يناكرها': u'يُنَاكِرُهَا', #14
u'يناكرها': u'يُنَاكِرْهَا', #3
u'يناكرها': u'يُنَاكِرَهَا', #54
u'يناولناه': u'يُنَاوِلُنَاهُ', #2
u'يناولنى': u'يُنَاوِلُنِى', #1
u'يناولنيها،': u'يُنَاوِلُنِيهَا،', #1
u'يناوى': u'يناوى', #1
u'يناوي': u'يُنَاوِي', #3
u'ينبخس': u'يَنْبَخِسْ', #1
u'ينبسطه': u'يَنْبَسِطُهُ', #1
u'ينبسطه': u'يَنْبِسَطُهُ', #1
u'ينبشر': u'يَنْبَشِرُ', #1
u'ينبعيا': u'يَنْبُعِيًّا', #1
u'ينبغى': u'ينبغى', #1
u'ينبغى': u'يَنْبَغِى', #96
u'ينبغين': u'يَنْبَغِينَ', #1
u'ينبل': u'يَنْبُلُ', #7
u'ينبنيان': u'يَنْبَنِيَانِ', #3
u'ينبي': u'ينبي', #1
u'ينبي': u'يُنْبِي', #8
u'ينبئان': u'يُنْبِئَانِ', #13
u'ينبيك': u'يُنْبِيكَ', #4
u'ينبيني': u'يُنْبِينِي', #1
u'ينبيها': u'يُنَبّيهَا', #1
u'ينبيها': u'يُنْبِيهَا', #1
u'ينة': u'ينة', #1
u'ينتتف': u'يُنْتَتَفُ', #2
u'ينتتف': u'يَنْتَتِفَ', #4
u'ينتتف': u'يُنْتَتَفَ', #5
u'ينتثر': u'يَنْتَثِرْ', #1
u'ينتثر': u'يَنْتَثِرَ', #4
u'ينتثر': u'يَنْتَثِرُ', #6
u'ينتثل': u'ينتثل', #1
u'ينتثل': u'يَنْتَثِلُ', #1
u'ينتثل': u'يُنْتَثَلَ', #1
u'ينتثل': u'يُنْتَثَلُ', #1
u'ينتجز': u'يَنْتَجِزُ', #1
u'ينتجز': u'ينتجز', #2
u'ينتحت': u'يُنْتَحَتُ', #1
u'ينتخل': u'يُنْتَخَلَ', #2
u'ينتشف': u'يَنْتَشِفُ', #1
u'ينتضل': u'ينتضل', #1
u'ينتضل': u'يَنْتَضِل', #2
u'ينتضل،': u'يَنْتَضِلُ،', #2
u'ينتضل': u'يَنْتَضِلُ', #5
u'ينتضلون': u'يَنْتَضِلُونَ', #3
u'ينتطق': u'يُنْتَطَقُ', #1
u'ينتفعه': u'يَنْتَفِعُهُ', #1
u'ينتفيان': u'يَنْتَفِيَانِ', #3
u'ينتقب': u'يَنْتَقِبَ', #1
u'ينتقر': u'يَنْتَقِرْ', #2
u'ينتقر': u'يَنْتَقِرُ', #3
u'ينتقع': u'يَنْتَقِعْ', #1
u'ينتقع': u'يُنْتَقَع', #1
u'ينتقع': u'يُنْتَقَعُ', #7
u'ينتقعون': u'يَنْتَقِعُونَ', #1
u'ينتكل': u'يَنْتَكِلَ', #2
u'ينتميه': u'يَنْتَمِيهِ', #1
u'ينتنوالوجه': u'يُنْتِنْوَالْوَجْهُ', #1
u'ينتهيان': u'يَنْتَهِيَانِ', #5
u'ينثعبان': u'يَنْثَعِبَانِ', #2
u'ينثلج': u'يَنْثَلِجُ', #1
u'ينجا': u'ينجا', #1
u'ينجاباشي': u'ينجاباشي', #1
u'ينجثم': u'يَنْجَثِمَ', #1
u'ينجحر': u'يَنْجَحِرُ', #7
u'ينجرح': u'يَنْجَرِحَ', #1
u'ينجرح': u'يَنْجَرِحْ', #1
u'ينجزكموه': u'يُنْجِزَكُمُوهُ', #3
u'ينجش': u'يَنْجُشُ', #1
u'ينجعل': u'يَنْجَعِلْ', #1
u'ينجعل': u'يَنْجَعِلُ', #5
u'ينجفل': u'ينجفل', #1
u'ينجفل': u'يَنْجَفِلُ', #1
u'ينجفل': u'يَنْجَفِلَ', #2
u'ينجمد': u'ينجمد', #1
u'ينجمد': u'يَنْجَمِدُ', #1
u'ينجنى': u'يُنَجِّنِى', #1
u'ينجينى': u'يُنَجِّينِى', #1
u'ينحبط': u'يَنْحَبِطُ', #1
u'ينحتم': u'يَنْحَتِمَ', #1
u'ينحجر': u'يَنْحَجِرُ', #70
u'ينحجر': u'يَنْحَجِرْ', #8
u'ينحجز': u'يَنْحَجِزُ', #1
u'ينحجز': u'يُنْحَجَزُ', #1
u'ينحجزوا': u'يَنْحَجِزُوا', #9
u'ينحفظ': u'ينحفظ', #1
u'ينحفظ': u'يَنْحَفِظُ', #5
u'ينحمل': u'يَنْحَمِلُ', #1
u'ينحنيان': u'يَنْحَنِيَانِ', #11
u'ينحوم': u'ينحوم', #1
u'ينحيان': u'يُنَحّيَانِ', #1
u'يندار': u'يَنْدَارَ', #2
u'يندرئ': u'يَنْدَرِئْ', #1
u'يندرئ': u'يَنْدَرِئُ', #181
u'يندرئان': u'يَنْدَرِئَانِ', #1
u'ينزي': u'يَنْزِي', #1
u'ينزي': u'يُنْزِي', #4
u'ينزي': u'يُنْزِيَ', #7
u'ينزيه': u'يُنْزِيَهُ', #1
u'ينزيه': u'يُنْزِيهِ', #3
u'ينزيها': u'يُنْزِيهَا', #5
u'ينساع': u'يَنْسَاعُ', #1
u'ينساغ': u'يَنْسَاغُ', #11
u'ينسئ': u'يَنْسِئُ', #1
u'ينسئون': u'يَنْسَئُونَ', #2
u'ينسىوالوجه': u'يَنْسَىوَالْوَجْهُ', #1
u'ينشآن': u'يَنْشَآنِ', #1
u'ينشآنه': u'يَنْشَآنِهِ', #1
u'ينشدنى': u'يُنْشِدُنِى', #1
u'ينشع': u'يَنْشَعُ', #2
u'ينشغ': u'يَنْشَغُ', #3
u'ينشلم': u'يَنْشَلِمْ', #1
u'ينشئان': u'يُنْشِئَانِ', #4
u'ينشيها': u'يُنْشِيهَا', #1
u'ينصبغ': u'يَنْصَبِغُ', #2
u'ينصدم': u'يَنْصَدِمَ', #1
u'ينصدم': u'يَنْصَدِمْ', #4
u'ينصرنى': u'يَنْصُرُنِى', #1
u'ينضام': u'ينضام', #1
u'ينضام': u'يَنْضَامُّ', #1
u'ينضجع': u'يَنْضَجِعُ', #1
u'ينطرد': u'يَنْطَرِدُ', #1
u'ينظرنى': u'يَنْظُرُنِى', #2
u'ينظرونقوله': u'يَنْظُرُونَقَوْلُهُ', #1
u'ينعقل': u'يَنْعَقِلُ', #1
u'ينعلق': u'يَنْعَلِقُ', #2
u'ينعلق': u'يَنْعَلِقْ', #2
u'ينغمونها': u'يُنَغِّمُونَهَا', #1
u'ينفحم': u'يَنْفَحِمَ', #1
u'ينفز': u'يُنَفّزُ', #1
u'ينفسد': u'يَنْفَسِدُ', #1
u'ينفضخ': u'يَنْفَضِخَ', #1
u'ينفضونإذا': u'يَنْفُضُونَإِذَا', #1
u'ينفعة': u'ينفعة', #1
u'ينفعنى': u'يَنْفَعُنِى', #8
u'ينفلكموها': u'يُنَفِّلَكُمُوهَا', #1
u'ينفلكموها،': u'يُنْفِلُكُمُوهَا،', #1
u'ينفلكموها': u'يُنْفِلُكُمُوهَا', #2
u'ينفيان': u'ينفيان', #1
u'ينفيان': u'يَنْفِيَانِ', #20
u'ينفيان': u'يُنْفَيَانِ', #7
u'ينقاع': u'َيْنُقَاعَ', #1
u'ينقخ': u'يَنْقَخُ', #1
u'ينقدح': u'يَنْقَدِحَ', #2
u'ينقدح': u'يَنْقَدِحْ', #2
u'ينقدح': u'يَنْقَدِحُ', #94
u'ينقضيان': u'يَنْقَضِيَانِ', #1
u'ينقلبونه': u'يَنْقَلِبُونَهُ', #1
u'ينقمع': u'يَنْقَمِعُ', #1
u'ينقمعن': u'ينقمعن', #1
u'ينقمعن': u'يَنْقَمِعْنَ', #6
u'ينقمعون': u'يَنْقَمِعُونَ', #1
u'ينكفي': u'يَنْكَفِي', #1
u'ينماث': u'يَنْمَاثُ', #2
u'ينماع': u'يَنْمَاعُ', #24
u'ينمدت': u'ينمدت', #1
u'ينميان': u'يَنْمِيَانِ', #1
u'ينهابود': u'ينهابود', #1
u'ينهاناوهذا': u'يَنْهَانَاوَهَذَا', #1
u'ينهانى': u'يَنْهَانِى', #3
u'ينهتن': u'يَنْهِتْنَ', #1
u'ينهدر': u'يَنْهَدِرُ', #1
u'ينهري': u'يَنْهَرِي', #1
u'ينهس': u'يَنْهَسُ', #4
u'ينهسه': u'يَنْهَسُهُ', #1
u'ينهمل': u'يَنْهَمِلَ', #1
u'ينهنهنا': u'يُنَهْنِهُنَا', #6
u'ينهنهها': u'يُنَهْنِهْهَا', #1
u'ينهنى': u'يَنْهَنِى', #1
u'ينهوننى': u'يَنْهَوْنَنِى', #1
u'ينهونى': u'يَنْهَوْنِى', #1
u'ينهيان': u'يُنْهَيَانِ', #1
u'ينهيان': u'يُنْهِيَانِ', #1
u'ينهيان': u'يَنْهَيَانِ', #10
u'ينوطون': u'يَنُوطُونَ', #1
u'ينويان': u'يَنْوِيَانِ', #6
u'ينيرمايه': u'ينيرمايه', #1
u'ينيكها': u'يَنِيكُهَا', #1
u'يهابنا': u'يَهَابُنَا', #1
u'يهابه': u'يَهَابُهُ', #15
u'يهابه': u'يَهَابَهُ', #3
u'يهابها': u'يَهَابُهَا', #3
u'يهابوننا': u'يَهَابُونَنَا', #2
u'يهابونه': u'يَهَابُونَهُ', #3
u'يهابونها': u'يَهَابُونَهَا', #3
u'يهارش': u'يُهَارِشُ', #2
u'يهايأ': u'يُهَايَأَ', #2
u'يهايأ': u'يُهَايَأُ', #4
u'يهايئ': u'يُهَايِئْ', #1
u'يهايئ': u'يُهَايِئَ', #3
u'يهايئ': u'يُهَايِئُ', #4
u'يهايئان': u'يُهَايِئَانِ', #1
u'يهايئه': u'يُهَايِئَهُ', #2
u'يهايئه': u'يُهَايِئْهُ', #3
u'يهايئهما': u'يُهَايِئُهُمَا', #1
u'يهايئون': u'يُهَايِئُونَ', #1
u'يهبوث': u'يَهْبُوثُ', #1
u'يهتديSعن': u'يَهْتَدِيSعَنْ', #1
u'يهتديان': u'يَهْتَدِيَانِ', #1
u'يهتضم': u'يَهْتَضِمُ', #2
u'يهتضم': u'يُهْتَضَمُ', #2
u'يهجاه': u'يُهَجَّاهُ', #1
u'يهجاها': u'يُهَجَّاهَا', #1
u'يهدس': u'يهدَسَّ', #1
u'يهديان': u'يُهْدِيَانِ', #1
u'يهذم': u'يَهْذِمُ', #1
u'يهذو': u'يَهْذُو', #1
u'يهراق': u'يُهَرَاقْ', #1
u'يهراق': u'يُهَرَاقُ', #10
u'يهراق': u'يُهَرَاقَ', #2
u'يهراق': u'يُهْرَاقُ', #24
u'يهراق': u'يُهْرَاق', #3
u'يهراق': u'يُهْرَاقَ', #6
u'يهري': u'يَهْرِي', #1
u'يهريق': u'يُهْرِيقَ', #13
u'يهريق': u'يُهْرِيقُ', #13
u'يهريق': u'يُهْرِيق', #3
u'يهريق': u'يُهَرِيقُ', #4
u'يهريق': u'يُهَرِيق', #9
u'يهريقه': u'يُهْرِيقَهُ', #2
u'يهريقه': u'يُهَرِيقهُ', #3
u'يهريقه': u'يُهْرِيقُهُ', #6
u'يهريقها': u'يُهْرِيقُهَا', #1
u'يهريقها': u'يُهَرِيقهَا', #2
u'يهريقها': u'يُهْرِيقَهَا', #3
u'يهريقوا': u'يُهَرِيقُوا', #5
u'يهريقوا': u'يُهْرِيقُوا', #8
u'يهريقون': u'يَهْرِيقُونَ', #1
u'يهريقون': u'يُهْرِيقُونَ', #3
u'يهريقوها': u'يُهَرِيقُوهَا', #1
u'يهريقوها': u'يُهْرِيقُوهَا', #1
u'يهزءون': u'يَهْزَءُونَ', #5
u'يهزئون': u'يَهْزَئُونَ', #1
u'يهمطهم': u'يَهْمِطُهُمْ', #2
u'يهمطون': u'يَهْمِطُونَ', #3
u'يهنأصحاب': u'يَهِنَأَصْحَابُ', #1
u'يهنو': u'يَهْنُو', #1
u'يهنى': u'يُهَنَّى', #1
u'يهنى': u'يُهِنِّى', #2
u'يهني': u'يُهِنِّي', #3
u'يهني': u'يُهِنّي', #5
u'يهنئونى': u'يُهَنِّئُونِى', #2
u'يهنيك': u'يَهْنِيكَ', #3
u'يهنيه': u'يُهَنِّيهِ', #2
u'يهودى': u'يَهُودِىٌّ', #24
u'يهودى': u'يَهُودِىٍّ', #27
u'يهودى': u'يَهُودِىُّ', #3
u'يهوذ': u'يَهُوذُ', #1
u'يهويان': u'يُهَوِّيَانِ', #1
u'يهيدنكم': u'يَهِيدَنَّكُمْ', #1
u'يهيؤها': u'يُهَيِّؤُهَا', #1
u'يهيؤها،': u'يُهَيِّؤُهَا،', #1
u'يو': u'يو', #4
u'يوا': u'يوا', #1
u'يواتك': u'يُوَاتِك', #1
u'يواتيك': u'يُوَاتِيك', #1
u'يواتيك': u'يُوَاتِيكَ', #2
u'يؤاتيني': u'يُؤَاتِيَنِي', #1
u'يواتيني': u'يُوَاتِينِي', #2
u'يؤاجر': u'يُؤَاجِرْ', #11
u'يؤاجر': u'يُؤَاجِرُ', #134
u'يؤاجر': u'يُؤَاجِرَ', #253
u'يؤاجر': u'يُؤَاجَرَ', #7
u'يؤاجر': u'يُؤَاجَرُ', #70
u'يؤاجرا': u'يُؤَاجِرَا', #5
u'يؤاجران': u'يُؤَاجِرَانِ', #1
u'يؤاجراها': u'يُؤَاجِرَاهَا', #1
u'يؤاجراهما': u'يُؤَاجِرَاهُمَا', #2
u'يؤاجرن': u'يُؤَاجَرْنَ', #1
u'يؤاجره': u'يُؤَاجِرْهُ', #2
u'يؤاجره': u'يُؤَاجِرُهُ', #33
u'يؤاجره': u'يُؤَاجِرَهُ', #81
u'يؤاجرها': u'يُؤَاجِرْهَا', #13
u'يؤاجرها': u'يُؤَاجِرُهَا', #37
u'يؤاجرها': u'يُؤَاجِرَهَا', #57
u'يؤاجرهم': u'يُؤَاجِرْهُمْ', #3
u'يؤاجرهم': u'يُؤَاجِرَهُمْ', #8
u'يؤاجرهما': u'يُؤَاجِرُهُمَا', #2
u'يؤاجرهما': u'يُؤَاجِرَهُمَا', #6
u'يؤاجرهن': u'يُؤَاجِرَهُنَّ', #2
u'يؤاجروا': u'يُؤَاجِرُوا', #5
u'يؤاجرون': u'يُؤَاجِرُونَ', #12
u'يؤاجرونه': u'يُؤَاجِرُونَهُ', #1
u'يؤاجرونها': u'يُؤَاجِرُونَهَا', #4
u'يؤاخذ': u'يؤاخذ', #1
u'يؤاخذ': u'يُؤَاخِذِ', #2
u'يؤاخذ': u'يُؤَاخِذَ', #25
u'يؤاخذ': u'يُؤَاخِذُ', #48
u'يؤاخذ': u'يُؤَاخِذْ', #6
u'يؤاخذ': u'يُؤَاخَذَ', #60
u'يؤاخذ': u'يُؤَاخَذُ', #818
u'يؤاخذ': u'يُؤَاخَذْ', #82
u'يؤاخذ': u'يُؤَاخَذ', #9
u'يؤاخذان': u'يُؤَاخِذَانِ', #1
u'يؤاخذان': u'يُؤَاخَذَانِ', #29
u'يؤاخذك': u'يُؤَاخِذُكَ', #2
u'يؤاخذكم': u'يُؤَاخِذُكُمْ', #158
u'يؤاخذكم': u'يُؤَاخِذُكُم', #2
u'يؤاخذكم': u'يُؤَاخِذُكُمُ', #20
u'يؤاخذنا': u'يُؤَاخِذُنَا', #1
u'يؤاخذني': u'يُؤَاخِذنِي', #1
u'يؤاخذني': u'يُؤَاخِذُنِي', #1
u'يؤاخذه': u'يُؤَاخِذَهُ', #15
u'يؤاخذه': u'يُؤَاخِذُهُ', #17
u'يؤاخذه': u'يُؤَاخِذْهُ', #4
u'يؤاخذهم': u'يُؤَاخِذهُمْ', #1
u'يؤاخذهم': u'يُؤَاخِذَهُمْ', #1
u'يؤاخذهم': u'يُؤَاخِذُهُمْ', #18
u'يؤاخذهم': u'يُؤَاخِذْهُمْ', #5
u'يؤاخذهما': u'يُؤَاخِذَهُمَا', #1
u'يؤاخذهوروي': u'يُؤَاخِذُهُوَرُوِيَ', #1
u'يؤاخذوا': u'يُؤَاخَذُوا', #4
u'يؤاخذون': u'يُؤَاخَذُونَ', #29
u'يؤاخذوه': u'يُؤَاخِذُوهُ', #1
u'يؤاخوهم': u'يُؤَاخُوهُمْ', #1
u'يؤاخي': u'يُؤَاخِي', #1
u'يؤاخى': u'يُؤَاخَى', #1
u'يواخي': u'يُوَاخِي', #1
u'يواخي': u'يُوَاخِيَ', #1
u'يوأد': u'يُوأَدَ', #1
u'يوأد': u'يُوأَدِ', #1
u'يوادونهمافأنزل': u'يُوَادُّونَهُمَافَأَنْزَلَ', #1
u'يوارث': u'يُوارِثُ', #1
u'يوارث': u'يُوَارِثَ', #1
u'يوارثه': u'يُوَارِثْهُ', #1
u'يوارثه': u'يُوَارِثُهُ', #4
u'يوارثونه': u'يُوَارِثُونَه', #1
u'يوارثونه': u'يُوَارِثُونَهُ', #1
u'يواريان': u'يُوَارِيَانِ', #1
u'يؤازره': u'يُؤَازِرُهُ', #4
u'يوازيان': u'يُوَازِيَانِ', #3
u'يواست': u'يواست', #1
u'يؤاسون': u'يُؤَاسُونَ', #2
u'يواضع': u'يُوَاضَعُ', #1
u'يواضع': u'يُوَاضِعُ', #1
u'يواظبننى': u'يُوَاظِبْنَنِى', #1
u'يوافينى': u'يَوُافِيَنِى', #1
u'يواقيت': u'يَوَاقِيتُ', #1
u'يواقيت': u'يَوَاقِيتَ', #2
u'يواقيت': u'يَوَاقِيتِ', #7
u'يواكس': u'يُوَاكِسُ', #1
u'يؤاكل': u'يُؤَاكِلُ', #1
u'يؤاكل': u'يُؤَاكِلْ', #1
u'يؤاكل': u'يُؤَاكَلُ', #5
u'يؤاكلني': u'يُؤَاكِلُنِي', #1
u'يؤاكله': u'يُؤَاكِلَهُ', #1
u'يؤاكله': u'يُؤَاكِلْهُ', #1
u'يواكله': u'يُوَاكِلَهُ', #2
u'يؤاكله': u'يُؤَاكِلُهُ', #7
u'يؤاكلها': u'يُؤَاكِلَهَا', #2
u'يؤاكلهم': u'يُؤَاكِلُهُمْ', #1
u'يؤاكلونها': u'يُؤَاكِلُونَهَا', #1
u'يواكلوها': u'يُوَاكِلُوهَا', #1
u'يؤاكلوها': u'يُؤَاكِلُوهَا', #11
u'يواكلوهن': u'يُوَاكِلُوهُنَّ', #1
u'يؤاكلوهن': u'يُؤَاكِلُوهُنَّ', #3
u'يؤالف': u'يُؤَالِفُ', #4
u'يؤالفان': u'يُؤَالِفَانِ', #1
u'يؤامر': u'يُؤَامِرُ', #1
u'يؤامر': u'يُؤَامِرْ', #1
u'يؤامر': u'يُؤَامِرَ', #2
u'يؤامره': u'يُؤَامِرْهُ', #2
u'يؤامرها': u'يُؤَامِرْهَا', #1
u'يؤانس': u'يُؤَانِسُ', #1
u'يؤانسها': u'يُؤَانِسُهَا', #2
u'يؤانسهم': u'يُؤَانِسَهُمْ', #1
u'يؤانسونه': u'يُؤَانِسُونَهُ', #3
u'يواهق': u'يُوَاهِقُ', #4
u'يؤبد': u'يُؤَبِّدَ', #1
u'يؤبد': u'يُؤَبِّدُ', #16
u'يؤبد': u'يُؤَبَّدْ', #4
u'يؤبد': u'يُؤَبَّدُ', #7
u'يؤبد': u'يُؤَبِّدْ', #7
u'يؤبر': u'يُؤَبّرُ', #1
u'يؤبر': u'يُؤَبَّر', #1
u'يؤبر': u'يُؤَبَّرُ', #11
u'يؤبر': u'يُؤَبَّرْ', #138
u'يؤبر': u'يُؤْبَرْ', #2
u'يؤبر': u'يُؤَبِّرْ', #3
u'يؤبر': u'يُؤَبَّرَ', #5
u'يؤبرا': u'يُؤْبَرَا', #2
u'يؤبره': u'يُؤَبِّرُهُ', #1
u'يؤبروا': u'يُؤَبِّرُوا', #1
u'يؤبرون': u'يُؤَبِّرُونَ', #2
u'يؤبرونه': u'يُؤَبِّرُونَهُ', #1
u'يؤبرونها': u'يُؤَبِّرُونَهَا', #1
u'يؤتدم': u'يُؤْتَدَمَ', #1
u'يؤتدم': u'يُؤْتَدَم', #2
u'يؤتدم': u'يُؤْتَدَمُ', #7
u'يوتطؤها': u'يَوْتَطِؤُهَا', #1
u'يوتغ': u'يُوتِغُ', #4
u'يوتقي': u'يَوْتَقِي', #1
u'يؤتنف': u'يُؤْتَنَفَ', #1
u'يؤتنف': u'يُؤْتَنَفْ', #1
u'يؤتنف': u'يُؤْتَنَفُ', #10
u'يؤتيناه': u'يُؤْتِينَاهُ', #2
u'يؤتينيه': u'يُؤْتِينِيهِ', #2
u'يؤثفين': u'يُؤَثْفَيْنِ', #1
u'يؤثفين': u'يُؤْثَفَيْنِ', #1
u'يوجأ': u'يُوجَأَ', #1
u'يوجأ': u'يَوْجَأُ', #1
u'يوجذ': u'يُوجِذْ', #1
u'يوجره': u'يُوجِرَهُ', #1
u'يوجرها': u'يُوجِرَهَا', #4
u'يوجهنى': u'يُوَجِّهُنِى', #1
u'يوحنس': u'يُوحَنَّسَ', #4
u'يوحنس': u'يُوحَنَّسُ', #4
u'يوحنه': u'يُوحَنَّهْ', #1
u'يؤخد': u'يُؤْخَدُ', #1
u'يؤخرالصلاة': u'يُؤَخِّرُالصَّلاَةَ', #1
u'يودس': u'يُودِسَ', #2
u'يؤدم': u'يُؤْدِم', #1
u'يؤدم': u'يُؤْدِمَ', #1
u'يؤدم': u'يُؤْدَم', #4
u'يؤدم': u'يُؤْدَمَ', #44
u'يؤدم': u'يُؤْدَمُ', #5
u'يؤديان': u'يُؤَدَّيَانِ', #14
u'يؤديان': u'يُؤَدِّيَانِ', #31
u'يوديها': u'يُودِيهَا', #1
u'يؤذنإذا': u'يُؤَذِّنُإِذَا', #1
u'يؤذنونى': u'يُؤْذِنُونِى', #1
u'يؤذيان': u'يُؤْذِيانِ', #1
u'يؤذيان': u'يُؤْذِيَانِ', #2
u'يؤذينى': u'يُؤْذِينِى', #6
u'يؤربهم': u'يُؤْرِبَهُمْ', #1
u'يورخ': u'يُورَخ', #1
u'يؤزونهم': u'يَؤُزُّونَهُمْ', #1
u'يوستين': u'يوستين', #1
u'يوسففي': u'يُوسُفَفِي', #1
u'يوشع': u'يُوشَعَ', #18
u'يوشع': u'يُوشَعُ', #18
u'يوشع': u'يوشع', #2
u'يوصفها': u'يُوَصِّفْهَا', #1
u'يوصينى': u'يُوصِينِى', #9
u'يوضآن': u'يُوَضَّآنِ', #2
u'يوضون': u'يُوَضُّونَ', #1
u'يوضيه': u'يُوَضِّيهِ', #1
u'يوعظه': u'يُوعِظُهُ', #1
u'يوفضون': u'يُوفِضُونَ', #1
u'يوفقنى': u'يُوَفِّقُنِى', #1
u'يوفيان': u'يُوفِيَانِ', #1
u'يوفيكها': u'يُوفِيكهَا', #1
u'يؤقت': u'يُؤَقِّتَ', #12
u'يؤقت': u'يُؤَقَّتُ', #13
u'يؤقت': u'يُؤَقَّتَ', #2
u'يؤقت': u'يُؤَقِّتْ', #47
u'يؤقت': u'يُؤَقِّتُ', #6
u'يؤقت': u'يُؤَقَّتْ', #7
u'يؤقتا': u'يُؤَقَّتَا', #1
u'يؤقتا': u'يُؤَقِّتَا', #3
u'يؤقته': u'يُؤَقِّتُهُ', #1
u'يؤقته': u'يُؤَقِّتْهُ', #3
u'يؤقتها': u'يُؤَقِّتَهَا', #1
u'يوقظنى': u'يُوقِظُنِى', #1
u'يوك': u'يُوكَ', #2
u'يوكأ،': u'يُوكَأْ،', #1
u'يوكأ': u'يُوكَأُ', #3
u'يوكي': u'يُوكِي', #1
u'يوكي': u'يُوكِيَ', #1
u'يوكى': u'يوكى', #1
u'يوكى': u'يُوكَى', #5
u'يوكئ': u'يُوكِئَ', #1
u'يولم': u'يُولِمَ', #11
u'يولم': u'يُولِمُ', #2
u'يولم': u'يُولِمْ', #5
u'يوليان': u'يُوَلَّيَانِ', #1
u'يوليان': u'يُوَلِّيَانِ', #1
u'يولينى': u'يُوَلِّينِى', #1
u'يوم': u'يَوْمً', #1
u'يومأ': u'يومًأ', #1
u'يومأحدسبعون': u'يَوْمَأُحُدٍسَبْعُونَ', #1
u'يومأحدفي': u'يَوْمَأُحُدٍفِي', #1
u'يومبدر': u'يَوْمَبَدْرٍ', #2
u'يؤمبه': u'يَؤُمَّبِهِ', #1
u'يومعرفة': u'يَوْمَعَرَفَةَ', #1
u'يؤمنقوله': u'يُؤْمِنَقَوْلُهُ', #1
u'يؤمننى': u'يُؤَمِّنُنِى', #2
u'يومون': u'يُومُونَ', #4
u'يومى': u'يَوْمِى', #23
u'يومىء': u'يومىء', #1
u'يومئان': u'يُومِئَانِ', #2
u'يؤمئذ': u'يَؤْمَئِذٍ', #2
u'يومئذعلى': u'يَوْمَئِذٍعَلَى', #1
u'يوميحلف،': u'يَوْمٍيَحْلِفُ،', #1
u'يؤنبوننى': u'يُؤَنِّبُونَنِى', #1
u'يؤنبونى': u'يُؤَنِّبُونِى', #1
u'يونسا': u'يُونُسَا', #1
u'يونسا': u'يُونُسًا', #2
u'يونق': u'يُونِقُ', #1
u'يويه': u'يويه', #1
u'يي': u'يي', #1
u'ىى': u'ىى', #2
u'يئث': u'يَئِثُّ', #1
u'يئط': u'يَئِطُّ', #3
u'يئوب': u'يَئُوبَ', #2
u'يئوب': u'يَئُوبُ', #26
u'يئوبا': u'يَئُوبَا', #1
u'يئوبان': u'يَئُوبَانِ', #1
u'يئوبوا': u'يَئُوبُوا', #3
u'يئوده': u'يَئُودُهُ', #9
u'يئوس': u'يَئُوسٌ', #3
u'يئول': u'يئول', #1
u'يئول': u'يَئُول', #1
u'يئول': u'يَئُولُ', #528
u'يئول': u'يَئُولَ', #53
u'يئولان': u'يَئُولَانِ', #2
u'يئومها': u'يَئُومُهَا', #1
u'يئووه': u'يُئْوُوهُ', #2
u'يئووهم': u'يُئْوُوهُمْ', #1
u'يئوي': u'يُئوِي', #1
u'يئوينى': u'يُئْوِينِى', #2
u'يئويه': u'يُئْوِيهِ', #1
u'يئيض': u'يَئِيضُ', #2
u'ييش': u'ييش', #1
u'يين': u'يَيْن', #1
u'يين': u'يَيْنَ', #1
u'يين': u'يَيْنُ', #1
u'ييي': u'ييي', #1
u'يييي': u'يييي', #2
u'ے': u'ے', #88
}

        
